<?php

declare(strict_types=1);

namespace SimpleSAML\SAML2\Binding;

/**
 * Interface grouping common functionality for synchronous bindings.
 *
 * @package simplesamlphp/saml2
 */
interface SynchronousBindingInterface
{
}
