<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Вақти миёнаи Гринвич (Абидҷон)',
        'Africa/Accra' => 'Вақти миёнаи Гринвич (Аккра)',
        'Africa/Addis_Ababa' => 'Вақти Африқои Шарқӣ (Аддис-Абеба)',
        'Africa/Algiers' => 'Вақти Аврупоии Марказӣ (Алҷазоир)',
        'Africa/Asmera' => 'Вақти Африқои Шарқӣ (Асмара)',
        'Africa/Asmara' => 'Вақти Африқои Шарқӣ (Асмара)',
        'Africa/Bamako' => 'Вақти миёнаи Гринвич (Бамако)',
        'Africa/Bangui' => 'Вақти Африқои Ғарбӣ (Бангуи)',
        'Africa/Banjul' => 'Вақти миёнаи Гринвич (Банҷул)',
        'Africa/Bissau' => 'Вақти миёнаи Гринвич (Бисау)',
        'Africa/Blantyre' => 'Вақти Африқои Марказӣ (Блантайр)',
        'Africa/Brazzaville' => 'Вақти Африқои Ғарбӣ (Браззавил)',
        'Africa/Bujumbura' => 'Вақти Африқои Марказӣ (Буҷумбура)',
        'Africa/Cairo' => 'Вақти аврупоии шарқӣ (Қоҳира)',
        'Africa/Casablanca' => 'Вақти аврупоии ғарбӣ (Касабланка)',
        'Africa/Ceuta' => 'Вақти Аврупоии Марказӣ (Сеута)',
        'Africa/Conakry' => 'Вақти миёнаи Гринвич (Конакри)',
        'Africa/Dakar' => 'Вақти миёнаи Гринвич (Дакар)',
        'Africa/Dar_es_Salaam' => 'Вақти Африқои Шарқӣ (Доруссалом)',
        'Africa/Djibouti' => 'Вақти Африқои Шарқӣ (Ҷибути)',
        'Africa/Douala' => 'Вақти Африқои Ғарбӣ (Дуала)',
        'Africa/El_Aaiun' => 'Вақти аврупоии ғарбӣ (Эл Аиун)',
        'Africa/Freetown' => 'Вақти миёнаи Гринвич (Фритаун)',
        'Africa/Gaborone' => 'Вақти Африқои Марказӣ (Габороне)',
        'Africa/Harare' => 'Вақти Африқои Марказӣ (Хараре)',
        'Africa/Johannesburg' => 'Вақти стандартии Африқои Ҷанубӣ (Йоханнесбург)',
        'Africa/Juba' => 'Вақти Африқои Марказӣ (Ҷуба)',
        'Africa/Kampala' => 'Вақти Африқои Шарқӣ (Кампала)',
        'Africa/Khartoum' => 'Вақти Африқои Марказӣ (Хартум)',
        'Africa/Kigali' => 'Вақти Африқои Марказӣ (Кигали)',
        'Africa/Kinshasa' => 'Вақти Африқои Ғарбӣ (Киншаса)',
        'Africa/Lagos' => 'Вақти Африқои Ғарбӣ (Лагос)',
        'Africa/Libreville' => 'Вақти Африқои Ғарбӣ (Либревиль)',
        'Africa/Lome' => 'Вақти миёнаи Гринвич (Ломе)',
        'Africa/Luanda' => 'Вақти Африқои Ғарбӣ (Луанда)',
        'Africa/Lubumbashi' => 'Вақти Африқои Марказӣ (Лубумбаши)',
        'Africa/Lusaka' => 'Вақти Африқои Марказӣ (Лусака)',
        'Africa/Malabo' => 'Вақти Африқои Ғарбӣ (Малабо)',
        'Africa/Maputo' => 'Вақти Африқои Марказӣ (Мапуту)',
        'Africa/Maseru' => 'Вақти стандартии Африқои Ҷанубӣ (Масеру)',
        'Africa/Mbabane' => 'Вақти стандартии Африқои Ҷанубӣ (Мбабане)',
        'Africa/Mogadishu' => 'Вақти Африқои Шарқӣ (Могадишо)',
        'Africa/Monrovia' => 'Вақти миёнаи Гринвич (Монровия)',
        'Africa/Nairobi' => 'Вақти Африқои Шарқӣ (Найроби)',
        'Africa/Ndjamena' => 'Вақти Африқои Ғарбӣ (Нҷамена)',
        'Africa/Niamey' => 'Вақти Африқои Ғарбӣ (Ниамей)',
        'Africa/Nouakchott' => 'Вақти миёнаи Гринвич (Нуакшот)',
        'Africa/Ouagadougou' => 'Вақти миёнаи Гринвич (Уагадугу)',
        'Africa/Porto-Novo' => 'Вақти Африқои Ғарбӣ (Порто-Ново)',
        'Africa/Sao_Tome' => 'Вақти миёнаи Гринвич (Сан-Томе)',
        'Africa/Tripoli' => 'Вақти аврупоии шарқӣ (Триполи)',
        'Africa/Tunis' => 'Вақти Аврупоии Марказӣ (Тунис)',
        'Africa/Windhoek' => 'Вақти Африқои Марказӣ (Виндхук)',
        'America/Adak' => 'Вақти Ҳавайӣ-Алеутӣ (Адак)',
        'America/Anchorage' => 'Вақти Аляска (Анкорич)',
        'America/Anguilla' => 'Вақти атлантикӣ (Ангиля)',
        'America/Antigua' => 'Вақти атлантикӣ (Антигуа)',
        'America/Araguaina' => 'Вақти Бразилия (Арагуайна)',
        'America/Argentina/La_Rioja' => 'Вақти Аргентина (Ла Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Вақти Аргентина (Рио Галлегос)',
        'America/Argentina/Salta' => 'Вақти Аргентина (Салта)',
        'America/Argentina/San_Juan' => 'Вақти Аргентина (Сан-Хуан)',
        'America/Argentina/San_Luis' => 'Вақти Аргентина (Сан Луис)',
        'America/Argentina/Tucuman' => 'Вақти Аргентина (Тукуман)',
        'America/Argentina/Ushuaia' => 'Вақти Аргентина (Ушуайя)',
        'America/Aruba' => 'Вақти атлантикӣ (Аруба)',
        'America/Asuncion' => 'Вақти Парагвай (Асунсион)',
        'America/Bahia' => 'Вақти Бразилия (Бахия)',
        'America/Bahia_Banderas' => 'Вақти марказӣ (Бахия де Бандерас)',
        'America/Barbados' => 'Вақти атлантикӣ (Барбадос)',
        'America/Belem' => 'Вақти Бразилия (Белем)',
        'America/Belize' => 'Вақти марказӣ (Белиз)',
        'America/Blanc-Sablon' => 'Вақти атлантикӣ (Блан-Саблон)',
        'America/Boa_Vista' => 'Вақти Амазон (Боа Виста)',
        'America/Bogota' => 'Вақти Колумбия (Богота)',
        'America/Boise' => 'Вақти кӯҳӣ (Бойз)',
        'America/Buenos_Aires' => 'Вақти Аргентина (Буэнос-Айрес)',
        'America/Argentina/Buenos_Aires' => 'Вақти Аргентина (Буэнос-Айрес)',
        'America/Cambridge_Bay' => 'Вақти кӯҳӣ (Кембриҷ Бэй)',
        'America/Campo_Grande' => 'Вақти Амазон (Кампо Гранде)',
        'America/Cancun' => 'Вақти шарқӣ (Канкун)',
        'America/Caracas' => 'Вақти Венесуэла (Каракас)',
        'America/Catamarca' => 'Вақти Аргентина (Катамарка)',
        'America/Argentina/Catamarca' => 'Вақти Аргентина (Катамарка)',
        'America/Cayenne' => 'Вақти Гвианаи Фаронса (Кайен)',
        'America/Cayman' => 'Вақти шарқӣ (Кайман)',
        'America/Chicago' => 'Вақти марказӣ (Чикаго)',
        'America/Chihuahua' => 'Вақти марказӣ (Чихуахуа)',
        'America/Ciudad_Juarez' => 'Вақти кӯҳӣ (Сюдад Хуарес)',
        'America/Coral_Harbour' => 'Вақти шарқӣ (Атикокан)',
        'America/Atikokan' => 'Вақти шарқӣ (Атикокан)',
        'America/Cordoba' => 'Вақти Аргентина (Кордоба)',
        'America/Argentina/Cordoba' => 'Вақти Аргентина (Кордоба)',
        'America/Costa_Rica' => 'Вақти марказӣ (Коста Рика)',
        'America/Coyhaique' => 'Вақти Чили (Койҳайке)',
        'America/Creston' => 'Вақти кӯҳӣ (Крестон)',
        'America/Cuiaba' => 'Вақти Амазон (Куяба)',
        'America/Curacao' => 'Вақти атлантикӣ (Кюрасао)',
        'America/Danmarkshavn' => 'Вақти миёнаи Гринвич (Данмаркшавн)',
        'America/Dawson' => 'Вақти Юкон (Доусон)',
        'America/Dawson_Creek' => 'Вақти кӯҳӣ (Доусон Крик)',
        'America/Denver' => 'Вақти кӯҳӣ (Денвер)',
        'America/Detroit' => 'Вақти шарқӣ (Детройт)',
        'America/Dominica' => 'Вақти атлантикӣ (Доминика)',
        'America/Edmonton' => 'Вақти кӯҳӣ (Эдмонтон)',
        'America/Eirunepe' => 'Вақти Бразилия (Эйрунепе)',
        'America/El_Salvador' => 'Вақти марказӣ (Сальвадор)',
        'America/Fort_Nelson' => 'Вақти кӯҳӣ (Форт Нелсон)',
        'America/Fortaleza' => 'Вақти Бразилия (Форталеза)',
        'America/Glace_Bay' => 'Вақти атлантикӣ (Глэйс Бэй)',
        'America/Godthab' => 'Вақти Гренландия (Нуук)',
        'America/Nuuk' => 'Вақти Гренландия (Нуук)',
        'America/Goose_Bay' => 'Вақти атлантикӣ (Гус Бэй)',
        'America/Grand_Turk' => 'Вақти шарқӣ (Гранд Терк)',
        'America/Grenada' => 'Вақти атлантикӣ (Гренада)',
        'America/Guadeloupe' => 'Вақти атлантикӣ (Гваделупа)',
        'America/Guatemala' => 'Вақти марказӣ (Гватемала)',
        'America/Guayaquil' => 'Вақти Эквадор (Гуаякил)',
        'America/Guyana' => 'Вақти Гайана',
        'America/Halifax' => 'Вақти атлантикӣ (Галифакс)',
        'America/Havana' => 'Вақти Куба (Ҳавана)',
        'America/Hermosillo' => 'Вақти Уқёнуси Ором Мексика (Эрмосилло)',
        'America/Indiana/Knox' => 'Вақти марказӣ (Нокс, Индиана)',
        'America/Indiana/Marengo' => 'Вақти шарқӣ (Маренго, Индиана)',
        'America/Indiana/Petersburg' => 'Вақти шарқӣ (Петербург, Индиана)',
        'America/Indiana/Tell_City' => 'Вақти марказӣ (Тел Сити, Индиана)',
        'America/Indiana/Vevay' => 'Вақти шарқӣ (Вевай, Индиана)',
        'America/Indiana/Vincennes' => 'Вақти шарқӣ (Винсенс, Индиана)',
        'America/Indiana/Winamac' => 'Вақти шарқӣ (Винамак, Индиана)',
        'America/Indianapolis' => 'Вақти шарқӣ (Индианаполис)',
        'America/Indiana/Indianapolis' => 'Вақти шарқӣ (Индианаполис)',
        'America/Inuvik' => 'Вақти кӯҳӣ (Инувик)',
        'America/Iqaluit' => 'Вақти шарқӣ (Икалуит)',
        'America/Jamaica' => 'Вақти шарқӣ (Ямайка)',
        'America/Jujuy' => 'Вақти Аргентина (Ҷуҷуй)',
        'America/Argentina/Jujuy' => 'Вақти Аргентина (Ҷуҷуй)',
        'America/Juneau' => 'Вақти Аляска (Ҷуно)',
        'America/Kentucky/Monticello' => 'Вақти шарқӣ (Монтичелло, Кентукки)',
        'America/Kralendijk' => 'Вақти атлантикӣ (Кралендйк)',
        'America/La_Paz' => 'Вақти Боливия (Ла-Пас)',
        'America/Lima' => 'Вақти Перу (Лима)',
        'America/Los_Angeles' => 'Вақти Уқёнуси Ором (Лос-Анҷелес)',
        'America/Louisville' => 'Вақти шарқӣ (Луисвилл)',
        'America/Kentucky/Louisville' => 'Вақти шарқӣ (Луисвилл)',
        'America/Lower_Princes' => 'Вақти атлантикӣ (Квартали Поёни Принс)',
        'America/Maceio' => 'Вақти Бразилия (Масейо)',
        'America/Managua' => 'Вақти марказӣ (Манагуа)',
        'America/Manaus' => 'Вақти Амазон (Манаус)',
        'America/Marigot' => 'Вақти атлантикӣ (Мариго)',
        'America/Martinique' => 'Вақти атлантикӣ (Мартиника)',
        'America/Matamoros' => 'Вақти марказӣ (Матаморос)',
        'America/Mazatlan' => 'Вақти Уқёнуси Ором Мексика (Мазатлан)',
        'America/Mendoza' => 'Вақти Аргентина (Мендоза)',
        'America/Argentina/Mendoza' => 'Вақти Аргентина (Мендоза)',
        'America/Menominee' => 'Вақти марказӣ (Меномин)',
        'America/Merida' => 'Вақти марказӣ (Мерида)',
        'America/Metlakatla' => 'Вақти Аляска (Метлакатла)',
        'America/Mexico_City' => 'Вақти марказӣ (Мехико)',
        'America/Miquelon' => 'Вақти Сент-Пиер ва Микелон',
        'America/Moncton' => 'Вақти атлантикӣ (Монктон)',
        'America/Monterrey' => 'Вақти марказӣ (Монтеррей)',
        'America/Montevideo' => 'Вақти Уругвай (Монтевидео)',
        'America/Montserrat' => 'Вақти атлантикӣ (Монсеррат)',
        'America/Nassau' => 'Вақти шарқӣ (Нассау)',
        'America/New_York' => 'Вақти шарқӣ (Ню-Йорк)',
        'America/Nome' => 'Вақти Аляска (Ном)',
        'America/Noronha' => 'Вақти Фернандо де Норонха',
        'America/North_Dakota/Beulah' => 'Вақти марказӣ (Бейла, Дакотаи Шимолӣ)',
        'America/North_Dakota/Center' => 'Вақти марказӣ (Сентр, Дакотаи Шимолӣ)',
        'America/North_Dakota/New_Salem' => 'Вақти марказӣ (Ню Салем, Дакотаи Шимолӣ)',
        'America/Ojinaga' => 'Вақти марказӣ (Ожинага)',
        'America/Panama' => 'Вақти шарқӣ (Панама)',
        'America/Paramaribo' => 'Вақти Суринам (Парамарибо)',
        'America/Phoenix' => 'Вақти кӯҳӣ (Финикс)',
        'America/Port-au-Prince' => 'Вақти шарқӣ (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'Вақти атлантикӣ (Порти Испания)',
        'America/Porto_Velho' => 'Вақти Амазон (Порту Велхо)',
        'America/Puerto_Rico' => 'Вақти атлантикӣ (Пуэрто-Рико)',
        'America/Punta_Arenas' => 'Вақти Чили (Пунта Аренас)',
        'America/Rankin_Inlet' => 'Вақти марказӣ (Ранкин Инлет)',
        'America/Recife' => 'Вақти Бразилия (Ресифи)',
        'America/Regina' => 'Вақти марказӣ (Регина)',
        'America/Resolute' => 'Вақти марказӣ (Резолют)',
        'America/Rio_Branco' => 'Вақти Бразилия (Рио Бранко)',
        'America/Santarem' => 'Вақти Бразилия (Сантарем)',
        'America/Santiago' => 'Вақти Чили (Сантьяго)',
        'America/Santo_Domingo' => 'Вақти атлантикӣ (Санто Доминго)',
        'America/Sao_Paulo' => 'Вақти Бразилия (Сан-Паулу)',
        'America/Scoresbysund' => 'Вақти Гренландия (Иттоккортоормиит)',
        'America/Sitka' => 'Вақти Аляска (Ситка)',
        'America/St_Barthelemy' => 'Вақти атлантикӣ (Сент Бартелеми)',
        'America/St_Johns' => 'Вақти Нюфаундленд (Сент Ҷонс)',
        'America/St_Kitts' => 'Вақти атлантикӣ (Сент Китс)',
        'America/St_Lucia' => 'Вақти атлантикӣ (Сент-Люсия)',
        'America/St_Thomas' => 'Вақти атлантикӣ (Сент Томас)',
        'America/St_Vincent' => 'Вақти атлантикӣ (Сент Винсент)',
        'America/Swift_Current' => 'Вақти марказӣ (Свифт-Каррент)',
        'America/Tegucigalpa' => 'Вақти марказӣ (Тегусигалпа)',
        'America/Thule' => 'Вақти атлантикӣ (Туле)',
        'America/Tijuana' => 'Вақти Уқёнуси Ором (Тихуана)',
        'America/Toronto' => 'Вақти шарқӣ (Торонто)',
        'America/Tortola' => 'Вақти атлантикӣ (Тортола)',
        'America/Vancouver' => 'Вақти Уқёнуси Ором (Ванкувер)',
        'America/Whitehorse' => 'Вақти Юкон (Уайтхорс)',
        'America/Winnipeg' => 'Вақти марказӣ (Виннипег)',
        'America/Yakutat' => 'Вақти Аляска (Якутат)',
        'Antarctica/Casey' => 'Вақти Австралияи Ғарбӣ (Кейси)',
        'Antarctica/Davis' => 'Вақти Давис (Дэвис)',
        'Antarctica/DumontDUrville' => 'Вақти Дюмон-д’Урвил (Дюмон д’Урвилл)',
        'Antarctica/Macquarie' => 'Вақти Австралияи Шарқӣ (Маккуари)',
        'Antarctica/Mawson' => 'Вақти Мавсон',
        'Antarctica/McMurdo' => 'Вақти Зеландияи Нав (Макмердо)',
        'Antarctica/Palmer' => 'Вақти Чили (Палмер)',
        'Antarctica/Rothera' => 'Вақти Ротера',
        'Antarctica/Syowa' => 'Вақти Сёва',
        'Antarctica/Troll' => 'Вақти миёнаи Гринвич (Тролл)',
        'Antarctica/Vostok' => 'Вақти Восток',
        'Arctic/Longyearbyen' => 'Вақти Аврупоии Марказӣ (Лонгйербён)',
        'Asia/Aden' => 'Вақти Арабистон (Адан)',
        'Asia/Almaty' => 'Вақти Қазоқистон (Алмаато)',
        'Asia/Amman' => 'Вақти аврупоии шарқӣ (Аммон)',
        'Asia/Anadyr' => 'Вақти Русия (Анадир)',
        'Asia/Aqtau' => 'Вақти Қазоқистон (Актау)',
        'Asia/Aqtobe' => 'Вақти Қазоқистон (Актобе)',
        'Asia/Ashgabat' => 'Вақти Туркманистон (Ашхобод)',
        'Asia/Atyrau' => 'Вақти Қазоқистон (Атирау)',
        'Asia/Baghdad' => 'Вақти Арабистон (Багдод)',
        'Asia/Bahrain' => 'Вақти Арабистон (Баҳрайн)',
        'Asia/Baku' => 'Вақти Озарбойҷон (Боку)',
        'Asia/Bangkok' => 'Вақти Ҳиндучин (Бангкок)',
        'Asia/Barnaul' => 'Вақти Красноярск (Барнаул)',
        'Asia/Beirut' => 'Вақти аврупоии шарқӣ (Бейрут)',
        'Asia/Bishkek' => 'Вақти Қирғизистон (Бишкек)',
        'Asia/Brunei' => 'Вақти Бруней Доруссалом',
        'Asia/Calcutta' => 'Вақти стандартии Ҳиндустон (Колката)',
        'Asia/Kolkata' => 'Вақти стандартии Ҳиндустон (Колката)',
        'Asia/Chita' => 'Вақти Якутск (Чита)',
        'Asia/Colombo' => 'Вақти стандартии Ҳиндустон (Коломбо)',
        'Asia/Damascus' => 'Вақти аврупоии шарқӣ (Димишқ)',
        'Asia/Dhaka' => 'Вақти Бангладеш (Дакка)',
        'Asia/Dili' => 'Вақти Тимори Шарқӣ (Дили)',
        'Asia/Dubai' => 'Вақти стандартии Халиҷи Форс (Дубай)',
        'Asia/Dushanbe' => 'Вақти Тоҷикистон (Душанбе)',
        'Asia/Famagusta' => 'Вақти аврупоии шарқӣ (Фамагуста)',
        'Asia/Gaza' => 'Вақти аврупоии шарқӣ (Ғазза)',
        'Asia/Hebron' => 'Вақти аврупоии шарқӣ (Хеброн)',
        'Asia/Hong_Kong' => 'Вақти Ҳонконг',
        'Asia/Hovd' => 'Вақти Ховд',
        'Asia/Irkutsk' => 'Вақти Иркутск',
        'Asia/Jakarta' => 'Вақти Индонезияи Ғарбӣ (Ҷакарта)',
        'Asia/Jayapura' => 'Вақти шарқии Индонезия (Ҷаяпура)',
        'Asia/Jerusalem' => 'Вақти Исроил (Йерусалим)',
        'Asia/Kabul' => 'Вақти Афғонистон (Кобул)',
        'Asia/Kamchatka' => 'Вақти Русия (Камчатка)',
        'Asia/Karachi' => 'Вақти Покистон (Карачи)',
        'Asia/Katmandu' => 'Вақти Непал (Катманду)',
        'Asia/Kathmandu' => 'Вақти Непал (Катманду)',
        'Asia/Khandyga' => 'Вақти Якутск (Хандига)',
        'Asia/Krasnoyarsk' => 'Вақти Красноярск',
        'Asia/Kuala_Lumpur' => 'Вақти Малайзия (Куала Лумпур)',
        'Asia/Kuching' => 'Вақти Малайзия (Кучинг)',
        'Asia/Kuwait' => 'Вақти Арабистон (Кувайт)',
        'Asia/Macau' => 'Вақти Чин (Макао)',
        'Asia/Magadan' => 'Вақти Магадан',
        'Asia/Makassar' => 'Вақти Индонезияи Марказӣ (Макасар)',
        'Asia/Manila' => 'Вақти Филиппин (Манила)',
        'Asia/Muscat' => 'Вақти стандартии Халиҷи Форс (Маскат)',
        'Asia/Nicosia' => 'Вақти аврупоии шарқӣ (Никосия)',
        'Asia/Novokuznetsk' => 'Вақти Красноярск (Новокузнетск)',
        'Asia/Novosibirsk' => 'Вақти Красноярск (Новосибирск)',
        'Asia/Omsk' => 'Вақти Омск',
        'Asia/Oral' => 'Вақти Қазоқистон (Орал)',
        'Asia/Phnom_Penh' => 'Вақти Ҳиндучин (Пномпен)',
        'Asia/Pontianak' => 'Вақти Индонезияи Ғарбӣ (Понтианак)',
        'Asia/Pyongyang' => 'Вақти Корея (Пхенян)',
        'Asia/Qatar' => 'Вақти Арабистон (Қатар)',
        'Asia/Qostanay' => 'Вақти Қазоқистон (Кустанай)',
        'Asia/Qyzylorda' => 'Вақти Қазоқистон (Қизилорда)',
        'Asia/Rangoon' => 'Вақти Мянма (Янгон)',
        'Asia/Yangon' => 'Вақти Мянма (Янгон)',
        'Asia/Riyadh' => 'Вақти Арабистон (Риёз)',
        'Asia/Saigon' => 'Вақти Ҳиндучин (Хо Ши Мин)',
        'Asia/Ho_Chi_Minh' => 'Вақти Ҳиндучин (Хо Ши Мин)',
        'Asia/Sakhalin' => 'Вақти Магадан (Сахалин)',
        'Asia/Samarkand' => 'Вақти Ӯзбекистон (Самарқанд)',
        'Asia/Seoul' => 'Вақти Корея (Сеул)',
        'Asia/Shanghai' => 'Вақти Чин (Шанхай)',
        'Asia/Singapore' => 'Вақти стандартии Сингапур',
        'Asia/Srednekolymsk' => 'Вақти Магадан (Среднеколимск)',
        'Asia/Taipei' => 'Вақти Тайбэй',
        'Asia/Tashkent' => 'Вақти Ӯзбекистон (Тошкент)',
        'Asia/Tbilisi' => 'Вақти Гурҷистон (Тбилиси)',
        'Asia/Tehran' => 'Вақти Эрон (Теҳрон)',
        'Asia/Thimphu' => 'Вақти Бутан (Тимфу)',
        'Asia/Tokyo' => 'Вақти Ҷопон (Токио)',
        'Asia/Tomsk' => 'Вақти Красноярск (Томск)',
        'Asia/Ulaanbaatar' => 'Вақти Улан-Батор',
        'Asia/Urumqi' => 'Вақти Хитой (Урумчи)',
        'Asia/Ust-Nera' => 'Вақти Владивосток (Уст-Нера)',
        'Asia/Vientiane' => 'Вақти Ҳиндучин (Вьентян)',
        'Asia/Vladivostok' => 'Вақти Владивосток',
        'Asia/Yakutsk' => 'Вақти Якутск',
        'Asia/Yekaterinburg' => 'Вақти Екатеринбург',
        'Asia/Yerevan' => 'Вақти Арманистон (Ереван)',
        'Atlantic/Azores' => 'Вақти Азор (Ҷазираҳои Азор)',
        'Atlantic/Bermuda' => 'Вақти атлантикӣ (Бермуда)',
        'Atlantic/Canary' => 'Вақти аврупоии ғарбӣ (Канария)',
        'Atlantic/Cape_Verde' => 'Вақти Кабо Верде',
        'Atlantic/Faeroe' => 'Вақти аврупоии ғарбӣ (Фарер)',
        'Atlantic/Faroe' => 'Вақти аврупоии ғарбӣ (Фарер)',
        'Atlantic/Madeira' => 'Вақти аврупоии ғарбӣ (Мадейра)',
        'Atlantic/Reykjavik' => 'Вақти миёнаи Гринвич (Рейкявик)',
        'Atlantic/South_Georgia' => 'Вақти Ҷорҷияи Ҷанубӣ',
        'Atlantic/St_Helena' => 'Вақти миёнаи Гринвич (Сент Елена)',
        'Atlantic/Stanley' => 'Вақти Ҷазираҳои Фолкленд (Стэнли)',
        'Australia/Adelaide' => 'Вақти Австралияи Марказӣ (Аделаида)',
        'Australia/Brisbane' => 'Вақти Австралияи Шарқӣ (Брисбен)',
        'Australia/Broken_Hill' => 'Вақти Австралияи Марказӣ (Брокен-Хилл)',
        'Australia/Darwin' => 'Вақти Австралияи Марказӣ (Дарвин)',
        'Australia/Eucla' => 'Вақти Ғарбии Марказии Австралия (Эукла)',
        'Australia/Hobart' => 'Вақти Австралияи Шарқӣ (Хобарт)',
        'Australia/Lindeman' => 'Вақти Австралияи Шарқӣ (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд Хоу Time',
        'Australia/Melbourne' => 'Вақти Австралияи Шарқӣ (Мелбурн)',
        'Australia/Perth' => 'Вақти Австралияи Ғарбӣ (Перт)',
        'Australia/Sydney' => 'Вақти Австралияи Шарқӣ (Сидней)',
        'Etc/GMT' => 'Вақти миёнаи Гринвич',
        'Etc/UTC' => 'Вақти ҷаҳонии ҳамоҳангсозӣ',
        'Europe/Amsterdam' => 'Вақти Аврупоии Марказӣ (Амстердам)',
        'Europe/Andorra' => 'Вақти Аврупоии Марказӣ (Андорра)',
        'Europe/Astrakhan' => 'Вақти Русия (Астрахань)',
        'Europe/Athens' => 'Вақти аврупоии шарқӣ (Афина)',
        'Europe/Belgrade' => 'Вақти Аврупоии Марказӣ (Белград)',
        'Europe/Berlin' => 'Вақти Аврупоии Марказӣ (Берлин)',
        'Europe/Bratislava' => 'Вақти Аврупоии Марказӣ (Братислава)',
        'Europe/Brussels' => 'Вақти Аврупоии Марказӣ (Брюссел)',
        'Europe/Bucharest' => 'Вақти аврупоии шарқӣ (Бухарест)',
        'Europe/Budapest' => 'Вақти Аврупоии Марказӣ (Будапешт)',
        'Europe/Busingen' => 'Вақти Аврупоии Марказӣ (Бусинген)',
        'Europe/Chisinau' => 'Вақти аврупоии шарқӣ (Кишинёв)',
        'Europe/Copenhagen' => 'Вақти Аврупоии Марказӣ (Копенгаген)',
        'Europe/Dublin' => 'Вақти миёнаи Гринвич (Дублин)',
        'Europe/Gibraltar' => 'Вақти Аврупоии Марказӣ (Гибралтар)',
        'Europe/Guernsey' => 'Вақти миёнаи Гринвич (Гернси)',
        'Europe/Helsinki' => 'Вақти аврупоии шарқӣ (Хелсинки)',
        'Europe/Isle_of_Man' => 'Вақти миёнаи Гринвич (Ҷазираи Ман)',
        'Europe/Istanbul' => 'Вақти Туркия (Истанбул)',
        'Europe/Jersey' => 'Вақти миёнаи Гринвич (Ҷерси)',
        'Europe/Kaliningrad' => 'Вақти аврупоии шарқӣ (Калининград)',
        'Europe/Kiev' => 'Вақти аврупоии шарқӣ (Киев)',
        'Europe/Kyiv' => 'Вақти аврупоии шарқӣ (Киев)',
        'Europe/Kirov' => 'Вақти Москва (Киров)',
        'Europe/Lisbon' => 'Вақти аврупоии ғарбӣ (Лиссабон)',
        'Europe/Ljubljana' => 'Вақти Аврупоии Марказӣ (Любляна)',
        'Europe/London' => 'Вақти миёнаи Гринвич (Лондон)',
        'Europe/Luxembourg' => 'Вақти Аврупоии Марказӣ (Люксембург)',
        'Europe/Madrid' => 'Вақти Аврупоии Марказӣ (Мадрид)',
        'Europe/Malta' => 'Вақти Аврупоии Марказӣ (Малта)',
        'Europe/Mariehamn' => 'Вақти аврупоии шарқӣ (Марихамн)',
        'Europe/Minsk' => 'Вақти Москва (Минск)',
        'Europe/Monaco' => 'Вақти Аврупоии Марказӣ (Монако)',
        'Europe/Moscow' => 'Вақти Москва',
        'Europe/Oslo' => 'Вақти Аврупоии Марказӣ (Осло)',
        'Europe/Paris' => 'Вақти Аврупоии Марказӣ (Париж)',
        'Europe/Podgorica' => 'Вақти Аврупоии Марказӣ (Подгоритса)',
        'Europe/Prague' => 'Вақти Аврупоии Марказӣ (Прага)',
        'Europe/Riga' => 'Вақти аврупоии шарқӣ (Рига)',
        'Europe/Rome' => 'Вақти Аврупоии Марказӣ (Рим)',
        'Europe/Samara' => 'Вақти Русия (Самара)',
        'Europe/San_Marino' => 'Вақти Аврупоии Марказӣ (Сан-Марино)',
        'Europe/Sarajevo' => 'Вақти Аврупоии Марказӣ (Сараево)',
        'Europe/Saratov' => 'Вақти Русия (Саратов)',
        'Europe/Simferopol' => 'Вақти Москва (Симферопол)',
        'Europe/Skopje' => 'Вақти Аврупоии Марказӣ (Скопйе)',
        'Europe/Sofia' => 'Вақти аврупоии шарқӣ (София)',
        'Europe/Stockholm' => 'Вақти Аврупоии Марказӣ (Стокголм)',
        'Europe/Tallinn' => 'Вақти аврупоии шарқӣ (Таллин)',
        'Europe/Tirane' => 'Вақти Аврупоии Марказӣ (Тиран)',
        'Europe/Ulyanovsk' => 'Вақти Русия (Уляновск)',
        'Europe/Vaduz' => 'Вақти Аврупоии Марказӣ (Вадуз)',
        'Europe/Vatican' => 'Вақти Аврупоии Марказӣ (Ватикан)',
        'Europe/Vienna' => 'Вақти Аврупоии Марказӣ (Вена)',
        'Europe/Vilnius' => 'Вақти аврупоии шарқӣ (Вилнюс)',
        'Europe/Volgograd' => 'Вақти Москва (Волгоград)',
        'Europe/Warsaw' => 'Вақти Аврупоии Марказӣ (Варшава)',
        'Europe/Zagreb' => 'Вақти Аврупоии Марказӣ (Загреб)',
        'Europe/Zurich' => 'Вақти Аврупоии Марказӣ (Сюрих)',
        'Indian/Antananarivo' => 'Вақти Африқои Шарқӣ (Антананариву)',
        'Indian/Chagos' => 'Вақти уқёнуси Ҳинд (Чагос)',
        'Indian/Christmas' => 'Вақти ҷазираи Мавлуди Исо (Кристмас)',
        'Indian/Cocos' => 'Вақти Ҷазираҳои Кокос',
        'Indian/Comoro' => 'Вақти Африқои Шарқӣ (Коморо)',
        'Indian/Kerguelen' => 'Вақти ҷанубӣ ва Антарктидаи Фаронса (Кергулен)',
        'Indian/Mahe' => 'Вақти Сейшел (Махе)',
        'Indian/Maldives' => 'Вақти Малдив',
        'Indian/Mauritius' => 'Вақти Маврикий',
        'Indian/Mayotte' => 'Вақти Африқои Шарқӣ (Майотта)',
        'Indian/Reunion' => 'Вақти Реюнион',
        'Pacific/Apia' => 'Вақти Апиа',
        'Pacific/Auckland' => 'Вақти Зеландияи Нав (Окленд)',
        'Pacific/Bougainville' => 'Вақти Папуа Гвинеяи Нав (Бугенвилл)',
        'Pacific/Chatham' => 'Вақти Чатам',
        'Pacific/Easter' => 'Вақти ҷазираи Пасха (Истер)',
        'Pacific/Efate' => 'Вақти Вануату (Эфате)',
        'Pacific/Enderbury' => 'Вақти Ҷазираҳои Финикс (Кантон)',
        'Pacific/Kanton' => 'Вақти Ҷазираҳои Финикс (Кантон)',
        'Pacific/Fakaofo' => 'Вақти Токелау (Факаофо)',
        'Pacific/Fiji' => 'Вақти Фиҷи',
        'Pacific/Funafuti' => 'Вақти Тувалу (Фунафути)',
        'Pacific/Galapagos' => 'Вақти Галапагос',
        'Pacific/Gambier' => 'Вақти Гамбир',
        'Pacific/Guadalcanal' => 'Вақти Ҷазираҳои Соломон (Гвадалканал)',
        'Pacific/Guam' => 'Вақти стандартии Чаморро (Гуам)',
        'Pacific/Honolulu' => 'Вақти стандартии Ҳавайӣ-Алеутӣ (Honolulu)',
        'Pacific/Kiritimati' => 'Вақти Ҷазираҳои Лин (Киритимати)',
        'Pacific/Kosrae' => 'Вақти Косрае',
        'Pacific/Kwajalein' => 'Вақти Ҷазираҳои Маршалл (Кважалейн)',
        'Pacific/Majuro' => 'Вақти Ҷазираҳои Маршалл (Мажуро)',
        'Pacific/Marquesas' => 'Вақти Маркес',
        'Pacific/Midway' => 'Вақти Самоа (Мидвей)',
        'Pacific/Nauru' => 'Вақти Науру',
        'Pacific/Niue' => 'Вақти Ниуэ',
        'Pacific/Norfolk' => 'Вақти ҷазираи Норфолк',
        'Pacific/Noumea' => 'Вақти Каледонияи Нав (Нумеа)',
        'Pacific/Pago_Pago' => 'Вақти Самоа (Паго Паго)',
        'Pacific/Palau' => 'Вақти Палау',
        'Pacific/Pitcairn' => 'Вақти Питкэрн',
        'Pacific/Ponape' => 'Ponape Time (Понпей)',
        'Pacific/Pohnpei' => 'Ponape Time (Понпей)',
        'Pacific/Port_Moresby' => 'Вақти Папуа Гвинеяи Нав (Порт Морсби)',
        'Pacific/Rarotonga' => 'Вақти ҷазираҳои Кук (Раротонга)',
        'Pacific/Saipan' => 'Вақти стандартии Чаморро (Сайпан)',
        'Pacific/Tahiti' => 'Вақти Таити',
        'Pacific/Tarawa' => 'Вақти Ҷазираҳои Гилберт (Тарава)',
        'Pacific/Tongatapu' => 'Вақти Тонга (Тонгатапу)',
        'Pacific/Truk' => 'Вақти Чук',
        'Pacific/Chuuk' => 'Вақти Чук',
        'Pacific/Wake' => 'Вақти бедории ҷазира (Вейк)',
        'Pacific/Wallis' => 'Вақти Уоллис ва Футуна',
    ],
    'Meta' => [],
];
