<?php

return [
    'UserAssignedNames' => [
        'XK' => 'Cosovo',
    ],
    'Names' => [
        'AD' => 'Andorra',
        'AE' => 'Emirats Arabs Unids',
        'AF' => 'Afganistan',
        'AG' => 'Antigua e Barbuda',
        'AI' => 'Anguilla',
        'AL' => 'Albania',
        'AM' => 'Armenia',
        'AO' => 'Angola',
        'AQ' => 'Antarctica',
        'AR' => 'Argentina',
        'AS' => 'Samoa Americana',
        'AT' => 'Austria',
        'AU' => 'Australia',
        'AW' => 'Aruba',
        'AX' => 'Inslas Aland',
        'AZ' => 'Aserbaidschan',
        'BA' => 'Bosnia ed Erzegovina',
        'BB' => 'Barbados',
        'BD' => 'Bangladesch',
        'BE' => 'Belgia',
        'BF' => 'Burkina Faso',
        'BG' => 'Bulgaria',
        'BH' => 'Bahrain',
        'BI' => 'Burundi',
        'BJ' => 'Benin',
        'BL' => 'Son Barthélemy',
        'BM' => 'Bermudas',
        'BN' => 'Brunei',
        'BO' => 'Bolivia',
        'BQ' => 'Pajais Bass caribics',
        'BR' => 'Brasilia',
        'BS' => 'Bahamas',
        'BT' => 'Butan',
        'BV' => 'Insla da Bouvet',
        'BW' => 'Botsuana',
        'BY' => 'Belarus',
        'BZ' => 'Belize',
        'CA' => 'Canada',
        'CC' => 'Inslas Cocos',
        'CD' => 'Congo-Kinshasa',
        'CF' => 'Republica Centralafricana',
        'CG' => 'Congo-Brazzaville',
        'CH' => 'Svizra',
        'CI' => 'Costa d’Ivur',
        'CK' => 'Inslas Cook',
        'CL' => 'Chile',
        'CM' => 'Camerun',
        'CN' => 'China',
        'CO' => 'Columbia',
        'CR' => 'Costa Rica',
        'CU' => 'Cuba',
        'CV' => 'Cap Verd',
        'CW' => 'Curaçao',
        'CX' => 'Insla da Nadal',
        'CY' => 'Cipra',
        'CZ' => 'Tschechia',
        'DE' => 'Germania',
        'DJ' => 'Dschibuti',
        'DK' => 'Danemarc',
        'DM' => 'Dominica',
        'DO' => 'Republica Dominicana',
        'DZ' => 'Algeria',
        'EC' => 'Ecuador',
        'EE' => 'Estonia',
        'EG' => 'Egipta',
        'EH' => 'Sahara Occidentala',
        'ER' => 'Eritrea',
        'ES' => 'Spagna',
        'ET' => 'Etiopia',
        'FI' => 'Finlanda',
        'FJ' => 'Fidschi',
        'FK' => 'Inslas Falkland',
        'FM' => 'Micronesia',
        'FO' => 'Inslas Feroe',
        'FR' => 'Frantscha',
        'GA' => 'Gabun',
        'GB' => 'Reginavel Unì',
        'GD' => 'Grenada',
        'GE' => 'Georgia',
        'GF' => 'Guyana Franzosa',
        'GG' => 'Guernsey',
        'GH' => 'Ghana',
        'GI' => 'Gibraltar',
        'GL' => 'Grönlanda',
        'GM' => 'Gambia',
        'GN' => 'Guinea',
        'GP' => 'Guadalupa',
        'GQ' => 'Guinea Equatoriala',
        'GR' => 'Grezia',
        'GS' => 'Georgia dal Sid e las Inslas Sandwich dal Sid',
        'GT' => 'Guatemala',
        'GU' => 'Guam',
        'GW' => 'Guinea-Bissau',
        'GY' => 'Guyana',
        'HK' => 'Regiun d’administraziun speziala Hongkong, China',
        'HM' => 'Inslas da Heard e McDonald',
        'HN' => 'Honduras',
        'HR' => 'Croazia',
        'HT' => 'Haiti',
        'HU' => 'Ungaria',
        'ID' => 'Indonesia',
        'IE' => 'Irlanda',
        'IL' => 'Israel',
        'IM' => 'Insla da Man',
        'IN' => 'India',
        'IO' => 'Territori Britannic da l’Ocean Indic',
        'IQ' => 'Irac',
        'IR' => 'Iran',
        'IS' => 'Islanda',
        'IT' => 'Italia',
        'JE' => 'Jersey',
        'JM' => 'Giamaica',
        'JO' => 'Jordania',
        'JP' => 'Giapun',
        'KE' => 'Kenia',
        'KG' => 'Kirghistan',
        'KH' => 'Cambodscha',
        'KI' => 'Kiribati',
        'KM' => 'Comoras',
        'KN' => 'Son Cristof e Nevis',
        'KP' => 'Corea dal Nord',
        'KR' => 'Corea dal Sid',
        'KW' => 'Kuwait',
        'KY' => 'Inslas Cayman',
        'KZ' => 'Kasachstan',
        'LA' => 'Laos',
        'LB' => 'Libanon',
        'LC' => 'Sontga Lucia',
        'LI' => 'Liechtenstein',
        'LK' => 'Sri Lanka',
        'LR' => 'Liberia',
        'LS' => 'Lesotho',
        'LT' => 'Lituania',
        'LU' => 'Luxemburg',
        'LV' => 'Lettonia',
        'LY' => 'Libia',
        'MA' => 'Maroc',
        'MC' => 'Monaco',
        'MD' => 'Moldavia',
        'ME' => 'Montenegro',
        'MF' => 'Saint Martin',
        'MG' => 'Madagascar',
        'MH' => 'Inslas da Marshall',
        'MK' => 'Macedonia dal Nord',
        'ML' => 'Mali',
        'MM' => 'Myanmar (Burma)',
        'MN' => 'Mongolia',
        'MO' => 'Regiun d’administraziun speziala Macao, China',
        'MP' => 'Inslas Mariannas dal Nord',
        'MQ' => 'Martinica',
        'MR' => 'Mauretania',
        'MS' => 'Montserrat',
        'MT' => 'Malta',
        'MU' => 'Mauritius',
        'MV' => 'Maledivas',
        'MW' => 'Malawi',
        'MX' => 'Mexico',
        'MY' => 'Malaisia',
        'MZ' => 'Mosambic',
        'NA' => 'Namibia',
        'NC' => 'Nova Caledonia',
        'NE' => 'Niger',
        'NF' => 'Insla Norfolk',
        'NG' => 'Nigeria',
        'NI' => 'Nicaragua',
        'NL' => 'Pajais Bass',
        'NO' => 'Norvegia',
        'NP' => 'Nepal',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'Nova Zelanda',
        'OM' => 'Oman',
        'PA' => 'Panama',
        'PE' => 'Peru',
        'PF' => 'Polinesia Franzosa',
        'PG' => 'Papua Nova Guinea',
        'PH' => 'Filippinas',
        'PK' => 'Pakistan',
        'PL' => 'Pologna',
        'PM' => 'Saint Pierre e Miquelon',
        'PN' => 'Pitcairn',
        'PR' => 'Puerto Rico',
        'PS' => 'Territori Palestinais',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'PY' => 'Paraguai',
        'QA' => 'Qatar',
        'RE' => 'Réunion',
        'RO' => 'Rumenia',
        'RS' => 'Serbia',
        'RU' => 'Russia',
        'RW' => 'Ruanda',
        'SA' => 'Arabia Saudita',
        'SB' => 'Inslas da Salomon',
        'SC' => 'Seychellas',
        'SD' => 'Sudan',
        'SE' => 'Svezia',
        'SG' => 'Singapur',
        'SH' => 'Sontg’Elena',
        'SI' => 'Slovenia',
        'SJ' => 'Svalbard e Jan Mayen',
        'SK' => 'Slovachia',
        'SL' => 'Sierra Leone',
        'SM' => 'Son Marin',
        'SN' => 'Senegal',
        'SO' => 'Somalia',
        'SR' => 'Surinam',
        'SS' => 'Sudan dal Sid',
        'ST' => 'São Tomé e Príncipe',
        'SV' => 'El Salvador',
        'SX' => 'Sint Maarten',
        'SY' => 'Siria',
        'SZ' => 'Eswatini',
        'TC' => 'Inslas Turks e Caicos',
        'TD' => 'Tschad',
        'TF' => 'Territoris Franzos Meridiunals',
        'TG' => 'Togo',
        'TH' => 'Tailanda',
        'TJ' => 'Tadschikistan',
        'TK' => 'Tokelau',
        'TL' => 'Timor da l’Ost',
        'TM' => 'Turkmenistan',
        'TN' => 'Tunesia',
        'TO' => 'Tonga',
        'TR' => 'Tirchia',
        'TT' => 'Trinidad e Tobago',
        'TV' => 'Tuvalu',
        'TW' => 'Taiwan',
        'TZ' => 'Tansania',
        'UA' => 'Ucraina',
        'UG' => 'Uganda',
        'UM' => 'Inslas Pitschnas Perifericas dals Stadis Unids da l’America',
        'US' => 'Stadis Unids da l’America',
        'UY' => 'Uruguai',
        'UZ' => 'Usbekistan',
        'VA' => 'Citad dal Vatican',
        'VC' => 'Son Vincenz e las Grenadinas',
        'VE' => 'Venezuela',
        'VG' => 'Inslas Virginas Britannicas',
        'VI' => 'Inslas Virginas Americanas',
        'VN' => 'Vietnam',
        'VU' => 'Vanuatu',
        'WF' => 'Wallis e Futuna',
        'WS' => 'Samoa',
        'YE' => 'Jemen',
        'YT' => 'Mayotte',
        'ZA' => 'Africa dal Sid',
        'ZM' => 'Sambia',
        'ZW' => 'Simbabwe',
    ],
];
