<?php

return [
    'UserAssignedNames' => [],
    'Names' => [
        'AF' => 'Afghanistani',
        'AG' => 'Antigua na Babuda',
        'AI' => 'Anguila',
        'AQ' => 'Antaktika',
        'AZ' => 'Azabajani',
        'BB' => 'Babados',
        'BJ' => 'Benini',
        'BS' => 'Bahamas',
        'BT' => 'Bhutani',
        'BY' => 'Belarusi',
        'CC' => 'Visiwa vya Kokos (Keeling)',
        'CV' => 'Kepuvede',
        'CW' => 'Kurakao',
        'EC' => 'Ekwado',
        'GA' => 'Gaboni',
        'GP' => 'Gwadelupe',
        'GS' => 'Visiwa vya Jojia Kusini na Sandwich Kusini',
        'GT' => 'Gwatemala',
        'GU' => 'Guami',
        'HR' => 'Kroashia',
        'JO' => 'Yordani',
        'LA' => 'Laosi',
        'LB' => 'Lebanoni',
        'LI' => 'Lishenteni',
        'LS' => 'Lesotho',
        'LU' => 'Lasembagi',
        'LV' => 'Lativia',
        'MA' => 'Moroko',
        'MC' => 'Monako',
        'MK' => 'Masedonia',
        'MM' => 'Myama (Burma)',
        'MS' => 'Montserati',
        'NC' => 'Nyukaledonia',
        'NE' => 'Nijeri',
        'NO' => 'Norwe',
        'NP' => 'Nepali',
        'OM' => 'Omani',
        'PF' => 'Polinesia ya Ufaransa',
        'PG' => 'Papua Guinea Mpya',
        'PL' => 'Polandi',
        'PM' => 'St. Pierre na Miquelon',
        'PR' => 'Pwetoriko',
        'PS' => 'Himaya za Palestina',
        'PY' => 'Paragwai',
        'QA' => 'Katari',
        'SG' => 'Singapuri',
        'ST' => 'Sao Tome na Prinsipe',
        'SV' => 'Elsalvado',
        'SY' => 'Shamu',
        'TD' => 'Chadi',
        'TH' => 'Thailandi',
        'TM' => 'Turukimenstani',
        'TW' => 'Taiwani',
        'UA' => 'Ukreni',
        'UY' => 'Urugwai',
        'VA' => 'Mji wa Vatikani',
        'VG' => 'Visiwa vya Virgin vya Uingereza',
        'VI' => 'Visiwa vya Virgin vya Marekani',
        'YT' => 'Mayote',
    ],
];
