<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Apvienoto Arābu Emirātu dirhēms',
        ],
        'AFN' => [
            'AFN',
            'Afganistānas afgāns',
        ],
        'ALL' => [
            'ALL',
            'Albānijas leks',
        ],
        'AMD' => [
            'AMD',
            'Armēnijas drams',
        ],
        'ANG' => [
            'ANG',
            'Nīderlandes Antiļu guldenis',
        ],
        'AOA' => [
            'AOA',
            'Angolas kvanza',
        ],
        'ARS' => [
            'ARS',
            'Argentīnas peso',
        ],
        'ATS' => [
            'ATS',
            'Austrijas šiliņš',
        ],
        'AUD' => [
            'AU$',
            'Austrālijas dolārs',
        ],
        'AWG' => [
            'AWG',
            'Arubas guldenis',
        ],
        'AZM' => [
            'AZM',
            'Azerbaidžānas manats (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'Azerbaidžānas manats',
        ],
        'BAM' => [
            'BAM',
            'Bosnijas un Hercogovinas konvertējamā marka',
        ],
        'BBD' => [
            'BBD',
            'Barbadosas dolārs',
        ],
        'BDT' => [
            'BDT',
            'Bangladešas taka',
        ],
        'BEF' => [
            'BEF',
            'Beļģijas franks',
        ],
        'BGN' => [
            'BGN',
            'Bulgārijas leva',
        ],
        'BHD' => [
            'BHD',
            'Bahreinas dinārs',
        ],
        'BIF' => [
            'BIF',
            'Burundi franks',
        ],
        'BMD' => [
            'BMD',
            'Bermudu dolārs',
        ],
        'BND' => [
            'BND',
            'Brunejas dolārs',
        ],
        'BOB' => [
            'BOB',
            'Bolīvijas boliviano',
        ],
        'BRL' => [
            'R$',
            'Brazīlijas reāls',
        ],
        'BSD' => [
            'BSD',
            'Bahamu dolārs',
        ],
        'BTN' => [
            'BTN',
            'Butānas ngultrums',
        ],
        'BWP' => [
            'BWP',
            'Botsvanas pula',
        ],
        'BYN' => [
            'BYN',
            'Baltkrievijas rubelis',
        ],
        'BYR' => [
            'BYR',
            'Baltkrievijas rubelis (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Belizas dolārs',
        ],
        'CAD' => [
            'CA$',
            'Kanādas dolārs',
        ],
        'CDF' => [
            'CDF',
            'KDR franks',
        ],
        'CHF' => [
            'CHF',
            'Šveices franks',
        ],
        'CLP' => [
            'CLP',
            'Čīles peso',
        ],
        'CNH' => [
            'CNH',
            'Ķīnas juaņa (ofšors)',
        ],
        'CNY' => [
            'CN¥',
            'Ķīnas juaņs',
        ],
        'COP' => [
            'COP',
            'Kolumbijas peso',
        ],
        'COU' => [
            'COU',
            'Kolumbijas reāls',
        ],
        'CRC' => [
            'CRC',
            'Kostarikas kolons',
        ],
        'CUC' => [
            'CUC',
            'Kubas konvertējamais peso',
        ],
        'CUP' => [
            'CUP',
            'Kubas peso',
        ],
        'CVE' => [
            'CVE',
            'Kaboverdes eskudo',
        ],
        'CYP' => [
            'CYP',
            'Kipras mārciņa',
        ],
        'CZK' => [
            'CZK',
            'Čehijas krona',
        ],
        'DEM' => [
            'DEM',
            'Vācijas marka',
        ],
        'DJF' => [
            'DJF',
            'Džibutijas franks',
        ],
        'DKK' => [
            'DKK',
            'Dānijas krona',
        ],
        'DOP' => [
            'DOP',
            'Dominikānas peso',
        ],
        'DZD' => [
            'DZD',
            'Alžīrijas dinārs',
        ],
        'EEK' => [
            'EEK',
            'Igaunijas krona',
        ],
        'EGP' => [
            'EGP',
            'Ēģiptes mārciņa',
        ],
        'ERN' => [
            'ERN',
            'Eritrejas nakfa',
        ],
        'ESP' => [
            'ESP',
            'Spānijas peseta',
        ],
        'ETB' => [
            'ETB',
            'Etiopijas birs',
        ],
        'EUR' => [
            '€',
            'eiro',
        ],
        'FIM' => [
            'FIM',
            'Somijas marka',
        ],
        'FJD' => [
            'FJD',
            'Fidži dolārs',
        ],
        'FKP' => [
            'FKP',
            'Folklenda Salu mārciņa',
        ],
        'FRF' => [
            'FRF',
            'Francijas franks',
        ],
        'GBP' => [
            '£',
            'Lielbritānijas mārciņa',
        ],
        'GEL' => [
            'GEL',
            'Gruzijas lari',
        ],
        'GHS' => [
            'GHS',
            'Ganas sedi',
        ],
        'GIP' => [
            'GIP',
            'Gibraltāra mārciņa',
        ],
        'GMD' => [
            'GMD',
            'Gambijas dalasi',
        ],
        'GNF' => [
            'GNF',
            'Gvinejas franks',
        ],
        'GRD' => [
            'GRD',
            'Grieķijas drahma',
        ],
        'GTQ' => [
            'GTQ',
            'Gvatemalas ketsals',
        ],
        'GYD' => [
            'GYD',
            'Gajānas dolārs',
        ],
        'HKD' => [
            'HK$',
            'Honkongas dolārs',
        ],
        'HNL' => [
            'HNL',
            'Hondurasas lempīra',
        ],
        'HRK' => [
            'HRK',
            'Horvātijas kuna',
        ],
        'HTG' => [
            'HTG',
            'Haiti gurds',
        ],
        'HUF' => [
            'HUF',
            'Ungārijas forints',
        ],
        'IDR' => [
            'IDR',
            'Indonēzijas rūpija',
        ],
        'IEP' => [
            'IEP',
            'Īrijas mārciņa',
        ],
        'ILS' => [
            '₪',
            'Izraēlas šekelis',
        ],
        'INR' => [
            '₹',
            'Indijas rūpija',
        ],
        'IQD' => [
            'IQD',
            'Irākas dinārs',
        ],
        'IRR' => [
            'IRR',
            'Irānas riāls',
        ],
        'ISK' => [
            'ISK',
            'Islandes krona',
        ],
        'ITL' => [
            'ITL',
            'Itālijas lira',
        ],
        'JMD' => [
            'JMD',
            'Jamaikas dolārs',
        ],
        'JOD' => [
            'JOD',
            'Jordānas dinārs',
        ],
        'JPY' => [
            '¥',
            'Japānas jena',
        ],
        'KES' => [
            'KES',
            'Kenijas šiliņš',
        ],
        'KGS' => [
            'KGS',
            'Kirgizstānas soms',
        ],
        'KHR' => [
            'KHR',
            'Kambodžas riels',
        ],
        'KMF' => [
            'KMF',
            'Komoru franks',
        ],
        'KPW' => [
            'KPW',
            'Ziemeļkorejas vona',
        ],
        'KRW' => [
            '₩',
            'Dienvidkorejas vona',
        ],
        'KWD' => [
            'KWD',
            'Kuveitas dinārs',
        ],
        'KYD' => [
            'KYD',
            'Kaimanu salu dolārs',
        ],
        'KZT' => [
            'KZT',
            'Kazahstānas tenge',
        ],
        'LAK' => [
            'LAK',
            'Laosas kips',
        ],
        'LBP' => [
            'LBP',
            'Libānas mārciņa',
        ],
        'LKR' => [
            'LKR',
            'Šrilankas rūpija',
        ],
        'LRD' => [
            'LRD',
            'Libērijas dolārs',
        ],
        'LSL' => [
            'LSL',
            'Lesoto loti',
        ],
        'LTL' => [
            'LTL',
            'Lietuvas lits',
        ],
        'LUF' => [
            'LUF',
            'Luksemburgas franks',
        ],
        'LVL' => [
            'Ls',
            'Latvijas lats',
        ],
        'LVR' => [
            'LVR',
            'Latvijas rublis',
        ],
        'LYD' => [
            'LYD',
            'Lībijas dinārs',
        ],
        'MAD' => [
            'MAD',
            'Marokas dirhēms',
        ],
        'MDL' => [
            'MDL',
            'Moldovas leja',
        ],
        'MGA' => [
            'MGA',
            'Madagaskaras ariari',
        ],
        'MKD' => [
            'MKD',
            'Maķedonijas denārs',
        ],
        'MLF' => [
            'MLF',
            'CFA (Āfrikas) franks',
        ],
        'MMK' => [
            'MMK',
            'Mjanmas kjats',
        ],
        'MNT' => [
            'MNT',
            'Mongolijas tugriks',
        ],
        'MOP' => [
            'MOP',
            'Makao pataka',
        ],
        'MRO' => [
            'MRO',
            'Mauritānijas ugija (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Mauritānijas ugija',
        ],
        'MTL' => [
            'MTL',
            'Maltas lira',
        ],
        'MTP' => [
            'MTP',
            'Maltas mārciņa',
        ],
        'MUR' => [
            'MUR',
            'Maurīcijas rūpija',
        ],
        'MVR' => [
            'MVR',
            'Maldīvijas rūfija',
        ],
        'MWK' => [
            'MWK',
            'Malāvijas kvača',
        ],
        'MXN' => [
            'MX$',
            'Meksikas peso',
        ],
        'MYR' => [
            'MYR',
            'Malaizijas ringits',
        ],
        'MZE' => [
            'MZE',
            'Mozambikas eskudo',
        ],
        'MZM' => [
            'MZM',
            'Mozambikas vecais metikals',
        ],
        'MZN' => [
            'MZN',
            'Mozambikas metikals',
        ],
        'NAD' => [
            'NAD',
            'Namībijas dolārs',
        ],
        'NGN' => [
            'NGN',
            'Nigērijas naira',
        ],
        'NIO' => [
            'NIO',
            'Nikaragvas kordoba',
        ],
        'NLG' => [
            'NLG',
            'Nīderlandes guldenis',
        ],
        'NOK' => [
            'NOK',
            'Norvēģijas krona',
        ],
        'NPR' => [
            'NPR',
            'Nepālas rūpija',
        ],
        'NZD' => [
            'NZ$',
            'Jaunzēlandes dolārs',
        ],
        'OMR' => [
            'OMR',
            'Omānas riāls',
        ],
        'PAB' => [
            'PAB',
            'Panamas balboa',
        ],
        'PEN' => [
            'PEN',
            'Peru sols',
        ],
        'PGK' => [
            'PGK',
            'Papua-Jaungvinejas kina',
        ],
        'PHP' => [
            'PHP',
            'Filipīnu peso',
        ],
        'PKR' => [
            'PKR',
            'Pakistānas rūpija',
        ],
        'PLN' => [
            'PLN',
            'Polijas zlots',
        ],
        'PTE' => [
            'PTE',
            'Portugāles eskudo',
        ],
        'PYG' => [
            'PYG',
            'Paragvajas guarani',
        ],
        'QAR' => [
            'QAR',
            'Kataras riāls',
        ],
        'ROL' => [
            'ROL',
            'Rumānijas vecā leja',
        ],
        'RON' => [
            'RON',
            'Rumānijas leja',
        ],
        'RSD' => [
            'RSD',
            'Serbijas dinārs',
        ],
        'RUB' => [
            'RUB',
            'Krievijas rublis',
        ],
        'RWF' => [
            'RWF',
            'Ruandas franks',
        ],
        'SAR' => [
            'SAR',
            'Saūda Arābijas riāls',
        ],
        'SBD' => [
            'SBD',
            'Zālamana Salu dolārs',
        ],
        'SCR' => [
            'SCR',
            'Seišelu salu rūpija',
        ],
        'SDG' => [
            'SDG',
            'Sudānas mārciņa',
        ],
        'SEK' => [
            'SEK',
            'Zviedrijas krona',
        ],
        'SGD' => [
            'SGD',
            'Singapūras dolārs',
        ],
        'SHP' => [
            'SHP',
            'Sv.Helēnas salas mārciņa',
        ],
        'SIT' => [
            'SIT',
            'Slovēnijas tolars',
        ],
        'SKK' => [
            'SKK',
            'Slovakijas krona',
        ],
        'SLE' => [
            'SLE',
            'Sjerraleones leone',
        ],
        'SLL' => [
            'SLL',
            'Sjerraleones leone (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Somālijas šiliņš',
        ],
        'SRD' => [
            'SRD',
            'Surinamas dolārs',
        ],
        'SRG' => [
            'SRG',
            'Surinamas guldenis',
        ],
        'SSP' => [
            'SSP',
            'Dienvidsudānas mārciņa',
        ],
        'STD' => [
            'STD',
            'Santome un Prinsipi dobra (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Santome un Prinsipi dobra',
        ],
        'SVC' => [
            'SVC',
            'Salvadoras kolons',
        ],
        'SYP' => [
            'SYP',
            'Sīrijas mārciņa',
        ],
        'SZL' => [
            'SZL',
            'Svazilendas lilangeni',
        ],
        'THB' => [
            '฿',
            'Taizemes bāts',
        ],
        'TJS' => [
            'TJS',
            'Tadžikistānas somons',
        ],
        'TMM' => [
            'TMM',
            'Turkmenistānas manats (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'Turkmenistānas manats',
        ],
        'TND' => [
            'TND',
            'Tunisijas dinārs',
        ],
        'TOP' => [
            'TOP',
            'Tongas paanga',
        ],
        'TRL' => [
            'TRL',
            'Turcijas lira (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'Turcijas lira',
        ],
        'TTD' => [
            'TTD',
            'Trinidādas un Tobāgo dolārs',
        ],
        'TWD' => [
            'NT$',
            'Taivānas jaunais dolārs',
        ],
        'TZS' => [
            'TZS',
            'Tanzānijas šiliņš',
        ],
        'UAH' => [
            'UAH',
            'Ukrainas grivna',
        ],
        'UGX' => [
            'UGX',
            'Ugandas šiliņš',
        ],
        'USD' => [
            '$',
            'ASV dolārs',
        ],
        'UYU' => [
            'UYU',
            'Urugvajas peso',
        ],
        'UZS' => [
            'UZS',
            'Uzbekistānas sums',
        ],
        'VEB' => [
            'VEB',
            'Venecuēlas bolivārs (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'Venecuēlas bolivārs (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Venecuēlas bolivārs',
        ],
        'VND' => [
            '₫',
            'Vjetnamas dongi',
        ],
        'VUV' => [
            'VUV',
            'Vanuatu vatu',
        ],
        'WST' => [
            'WST',
            'Samoa tala',
        ],
        'XAF' => [
            'FCFA',
            'Centrālāfrikas CFA franks',
        ],
        'XCD' => [
            'EC$',
            'Austrumkarību dolārs',
        ],
        'XCG' => [
            'Cg.',
            'Karību guldenis',
        ],
        'XEU' => [
            'XEU',
            'Eiropas norēķinu vienība',
        ],
        'XFO' => [
            'XFO',
            'Francijas zelta franks',
        ],
        'XFU' => [
            'XFU',
            'Francijas UIC franks',
        ],
        'XOF' => [
            'F CFA',
            'Rietumāfrikas CFA franks',
        ],
        'XPF' => [
            'CFPF',
            'CFP franks',
        ],
        'YER' => [
            'YER',
            'Jemenas riāls',
        ],
        'ZAR' => [
            'ZAR',
            'Dienvidāfrikas rends',
        ],
        'ZMK' => [
            'ZMK',
            'Zambijas kvača (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Zambijas kvača',
        ],
        'ZWD' => [
            'ZWD',
            'Zimbabves dolārs',
        ],
        'ZWG' => [
            'ZWG',
            'Zimbabves zelts',
        ],
        'ZWL' => [
            'ZWL',
            'Zimbabves dolārs (2009)',
        ],
    ],
];
