<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Abidjan)',
        'Africa/Accra' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Accra)',
        'Africa/Bamako' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Bamako)',
        'Africa/Banjul' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Banjul)',
        'Africa/Bissau' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Bissau)',
        'Africa/Conakry' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Conakry)',
        'Africa/Dakar' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Dakar)',
        'Africa/Freetown' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Freetown)',
        'Africa/Gaborone' => 'Botswana (Gaborone)',
        'Africa/Johannesburg' => 'Aforika Borwa (Johannesburg)',
        'Africa/Lome' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Lomé)',
        'Africa/Monrovia' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Monrovia)',
        'Africa/Nouakchott' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Ouagadougou)',
        'Africa/Sao_Tome' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (São Tomé)',
        'America/Danmarkshavn' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Danmarkshavn)',
        'Antarctica/Troll' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Troll)',
        'Atlantic/Reykjavik' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Reykjavik)',
        'Atlantic/St_Helena' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (St. Helena)',
        'Etc/GMT' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich',
        'Europe/Dublin' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Dublin)',
        'Europe/Guernsey' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Guernsey)',
        'Europe/Isle_of_Man' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Isle of Man)',
        'Europe/Jersey' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (Jersey)',
        'Europe/London' => 'Palogare ya nako ya ngwaga le ngwaga ya Greenwich (London)',
    ],
    'Meta' => [],
];
