<?php

return [
    'Names' => [
        'af_ZA' => 'Èdè Afrikani (Gúúshù Áfíríkà)',
        'ar_AE' => 'Èdè Lárúbáwá (Ɛmirate ti Awɔn Arabu)',
        'ar_DJ' => 'Èdè Lárúbáwá (Díbɔ́ótì)',
        'ar_EH' => 'Èdè Lárúbáwá (Ìwɔ̀òòrùn Sàhárà)',
        'ar_IL' => 'Èdè Lárúbáwá (Iserɛli)',
        'ar_JO' => 'Èdè Lárúbáwá (Jɔdani)',
        'ar_OM' => 'Èdè Lárúbáwá (Ɔɔma)',
        'ar_PS' => 'Èdè Lárúbáwá (Agbègbè ara Palɛsítínì)',
        'ar_TD' => 'Èdè Lárúbáwá (Shààdì)',
        'ar_TN' => 'Èdè Lárúbáwá (Tunishia)',
        'az_AZ' => 'Èdè Asabaijani (Asɛ́bájánì)',
        'az_Cyrl' => 'Èdè Asabaijani (èdè ilɛ̀ Rɔ́shíà)',
        'az_Cyrl_AZ' => 'Èdè Asabaijani (èdè ilɛ̀ Rɔ́shíà, Asɛ́bájánì)',
        'az_Latn_AZ' => 'Èdè Asabaijani (Èdè Látìn, Asɛ́bájánì)',
        'ba_RU' => 'Èdè Bashiri (Rɔshia)',
        'bo_CN' => 'Tibetán (Sháínà)',
        'bs_BA' => 'Èdè Bosnia (Bɔ̀síníà àti Ɛtisɛgófínà)',
        'bs_Cyrl' => 'Èdè Bosnia (èdè ilɛ̀ Rɔ́shíà)',
        'bs_Cyrl_BA' => 'Èdè Bosnia (èdè ilɛ̀ Rɔ́shíà, Bɔ̀síníà àti Ɛtisɛgófínà)',
        'bs_Latn_BA' => 'Èdè Bosnia (Èdè Látìn, Bɔ̀síníà àti Ɛtisɛgófínà)',
        'ce_RU' => 'Èdè Chechen (Rɔshia)',
        'cs_CZ' => 'Èdè Seeki (Shɛ́ɛ́kì)',
        'cv' => 'Èdè Shufasi',
        'cv_RU' => 'Èdè Shufasi (Rɔshia)',
        'cy_GB' => 'Èdè Welshi (Gɛ̀ɛ́sì)',
        'da_DK' => 'Èdè Denmaki (Dɛ́mákì)',
        'de_BE' => 'Èdè Jámánì (Bégíɔ́mù)',
        'de_LI' => 'Èdè Jámánì (Lɛshitɛnisiteni)',
        'en' => 'Èdè Gɛ̀ɛ́sì',
        'en_001' => 'Èdè Gɛ̀ɛ́sì (Agbáyé)',
        'en_150' => 'Èdè Gɛ̀ɛ́sì (Yúróòpù)',
        'en_AE' => 'Èdè Gɛ̀ɛ́sì (Ɛmirate ti Awɔn Arabu)',
        'en_AG' => 'Èdè Gɛ̀ɛ́sì (Ààntígúà àti Báríbúdà)',
        'en_AI' => 'Èdè Gɛ̀ɛ́sì (Ààngúlílà)',
        'en_AS' => 'Èdè Gɛ̀ɛ́sì (Sámóánì ti Orílɛ́ède Àméríkà)',
        'en_AT' => 'Èdè Gɛ̀ɛ́sì (Asítíríà)',
        'en_AU' => 'Èdè Gɛ̀ɛ́sì (Austrálíà)',
        'en_BB' => 'Èdè Gɛ̀ɛ́sì (Bábádósì)',
        'en_BE' => 'Èdè Gɛ̀ɛ́sì (Bégíɔ́mù)',
        'en_BI' => 'Èdè Gɛ̀ɛ́sì (Bùùrúndì)',
        'en_BM' => 'Èdè Gɛ̀ɛ́sì (Bémúdà)',
        'en_BS' => 'Èdè Gɛ̀ɛ́sì (Bàhámásì)',
        'en_BW' => 'Èdè Gɛ̀ɛ́sì (Bɔ̀tìsúwánà)',
        'en_BZ' => 'Èdè Gɛ̀ɛ́sì (Bèlísɛ̀)',
        'en_CA' => 'Èdè Gɛ̀ɛ́sì (Kánádà)',
        'en_CC' => 'Èdè Gɛ̀ɛ́sì (Erékùsù Cocos [Keeling])',
        'en_CH' => 'Èdè Gɛ̀ɛ́sì (Súwísìlanìdì)',
        'en_CK' => 'Èdè Gɛ̀ɛ́sì (Etíokun Kùúkù)',
        'en_CM' => 'Èdè Gɛ̀ɛ́sì (Kamerúúnì)',
        'en_CX' => 'Èdè Gɛ̀ɛ́sì (Erékùsù Christmas)',
        'en_CY' => 'Èdè Gɛ̀ɛ́sì (Kúrúsì)',
        'en_CZ' => 'Èdè Gɛ̀ɛ́sì (Shɛ́ɛ́kì)',
        'en_DE' => 'Èdè Gɛ̀ɛ́sì (Jámánì)',
        'en_DK' => 'Èdè Gɛ̀ɛ́sì (Dɛ́mákì)',
        'en_DM' => 'Èdè Gɛ̀ɛ́sì (Dòmíníkà)',
        'en_EE' => 'Èdè Gɛ̀ɛ́sì (Esitonia)',
        'en_ER' => 'Èdè Gɛ̀ɛ́sì (Eritira)',
        'en_ES' => 'Èdè Gɛ̀ɛ́sì (Sípéìnì)',
        'en_FI' => 'Èdè Gɛ̀ɛ́sì (Filandi)',
        'en_FJ' => 'Èdè Gɛ̀ɛ́sì (Fíjì)',
        'en_FK' => 'Èdè Gɛ̀ɛ́sì (Etikun Fakalandi)',
        'en_FM' => 'Èdè Gɛ̀ɛ́sì (Makoronesia)',
        'en_FR' => 'Èdè Gɛ̀ɛ́sì (Faranse)',
        'en_GB' => 'Èdè Gɛ̀ɛ́sì (Gɛ̀ɛ́sì)',
        'en_GD' => 'Èdè Gɛ̀ɛ́sì (Genada)',
        'en_GE' => 'Èdè Gɛ̀ɛ́sì (Gɔgia)',
        'en_GG' => 'Èdè Gɛ̀ɛ́sì (Guernsey)',
        'en_GH' => 'Èdè Gɛ̀ɛ́sì (Gana)',
        'en_GI' => 'Èdè Gɛ̀ɛ́sì (Gibaratara)',
        'en_GM' => 'Èdè Gɛ̀ɛ́sì (Gambia)',
        'en_GS' => 'Èdè Gɛ̀ɛ́sì (Gúúsù Georgia àti Gúúsù Àwɔn Erékùsù Sandwich)',
        'en_GU' => 'Èdè Gɛ̀ɛ́sì (Guamu)',
        'en_GY' => 'Èdè Gɛ̀ɛ́sì (Guyana)',
        'en_HK' => 'Èdè Gɛ̀ɛ́sì (Agbègbè Ìshàkóso Ìshúná Hong Kong Tí Shánà Ń Darí)',
        'en_HU' => 'Èdè Gɛ̀ɛ́sì (Hungari)',
        'en_ID' => 'Èdè Gɛ̀ɛ́sì (Indonéshíà)',
        'en_IE' => 'Èdè Gɛ̀ɛ́sì (Ailandi)',
        'en_IL' => 'Èdè Gɛ̀ɛ́sì (Iserɛli)',
        'en_IM' => 'Èdè Gɛ̀ɛ́sì (Erékùshù ilɛ̀ Man)',
        'en_IN' => 'Èdè Gɛ̀ɛ́sì (Íńdíà)',
        'en_IO' => 'Èdè Gɛ̀ɛ́sì (Etíkun Índíánì ti Ìlú Bírítísì)',
        'en_IT' => 'Èdè Gɛ̀ɛ́sì (Itáli)',
        'en_JE' => 'Èdè Gɛ̀ɛ́sì (Jɛsì)',
        'en_JM' => 'Èdè Gɛ̀ɛ́sì (Jamaika)',
        'en_JP' => 'Èdè Gɛ̀ɛ́sì (Japani)',
        'en_KE' => 'Èdè Gɛ̀ɛ́sì (Kenya)',
        'en_KI' => 'Èdè Gɛ̀ɛ́sì (Kiribati)',
        'en_KN' => 'Èdè Gɛ̀ɛ́sì (Kiiti ati Neefi)',
        'en_KY' => 'Èdè Gɛ̀ɛ́sì (Etíokun Kámánì)',
        'en_LC' => 'Èdè Gɛ̀ɛ́sì (Lushia)',
        'en_LR' => 'Èdè Gɛ̀ɛ́sì (Laberia)',
        'en_LS' => 'Èdè Gɛ̀ɛ́sì (Lesoto)',
        'en_LT' => 'Èdè Gɛ̀ɛ́sì (Lituania)',
        'en_LV' => 'Èdè Gɛ̀ɛ́sì (Latifia)',
        'en_MG' => 'Èdè Gɛ̀ɛ́sì (Madasika)',
        'en_MH' => 'Èdè Gɛ̀ɛ́sì (Etikun Máshali)',
        'en_MO' => 'Èdè Gɛ̀ɛ́sì (Agbègbè Ìshàkóso Pàtàkì Macao)',
        'en_MP' => 'Èdè Gɛ̀ɛ́sì (Etikun Guusu Mariana)',
        'en_MS' => 'Èdè Gɛ̀ɛ́sì (Motserati)',
        'en_MT' => 'Èdè Gɛ̀ɛ́sì (Malata)',
        'en_MU' => 'Èdè Gɛ̀ɛ́sì (Maritiusi)',
        'en_MV' => 'Èdè Gɛ̀ɛ́sì (Maladifi)',
        'en_MW' => 'Èdè Gɛ̀ɛ́sì (Malawi)',
        'en_MY' => 'Èdè Gɛ̀ɛ́sì (Malasia)',
        'en_NA' => 'Èdè Gɛ̀ɛ́sì (Namibia)',
        'en_NF' => 'Èdè Gɛ̀ɛ́sì (Erékùsù Nɔ́úfókì)',
        'en_NG' => 'Èdè Gɛ̀ɛ́sì (Nàìjíríà)',
        'en_NL' => 'Èdè Gɛ̀ɛ́sì (Nedalandi)',
        'en_NO' => 'Èdè Gɛ̀ɛ́sì (Nɔɔwii)',
        'en_NR' => 'Èdè Gɛ̀ɛ́sì (Nauru)',
        'en_NU' => 'Èdè Gɛ̀ɛ́sì (Niue)',
        'en_NZ' => 'Èdè Gɛ̀ɛ́sì (Shilandi Titun)',
        'en_PG' => 'Èdè Gɛ̀ɛ́sì (Paapu ti Giini)',
        'en_PH' => 'Èdè Gɛ̀ɛ́sì (Filipini)',
        'en_PK' => 'Èdè Gɛ̀ɛ́sì (Pakisitan)',
        'en_PL' => 'Èdè Gɛ̀ɛ́sì (Polandi)',
        'en_PN' => 'Èdè Gɛ̀ɛ́sì (Pikarini)',
        'en_PR' => 'Èdè Gɛ̀ɛ́sì (Pɔto Riko)',
        'en_PT' => 'Èdè Gɛ̀ɛ́sì (Pɔ́túgà)',
        'en_PW' => 'Èdè Gɛ̀ɛ́sì (Paalu)',
        'en_RO' => 'Èdè Gɛ̀ɛ́sì (Romaniya)',
        'en_RW' => 'Èdè Gɛ̀ɛ́sì (Ruwanda)',
        'en_SB' => 'Èdè Gɛ̀ɛ́sì (Etikun Solomoni)',
        'en_SC' => 'Èdè Gɛ̀ɛ́sì (Sheshɛlɛsi)',
        'en_SD' => 'Èdè Gɛ̀ɛ́sì (Sudani)',
        'en_SE' => 'Èdè Gɛ̀ɛ́sì (Swidini)',
        'en_SG' => 'Èdè Gɛ̀ɛ́sì (Singapo)',
        'en_SH' => 'Èdè Gɛ̀ɛ́sì (Hɛlena)',
        'en_SI' => 'Èdè Gɛ̀ɛ́sì (Silofania)',
        'en_SK' => 'Èdè Gɛ̀ɛ́sì (Silofakia)',
        'en_SL' => 'Èdè Gɛ̀ɛ́sì (Siria looni)',
        'en_SS' => 'Èdè Gɛ̀ɛ́sì (Gúúsù Sudan)',
        'en_SX' => 'Èdè Gɛ̀ɛ́sì (Síntì Mátɛ́ɛ̀nì)',
        'en_SZ' => 'Èdè Gɛ̀ɛ́sì (Sashiland)',
        'en_TC' => 'Èdè Gɛ̀ɛ́sì (Tɔɔki ati Etikun Kakɔsi)',
        'en_TK' => 'Èdè Gɛ̀ɛ́sì (Tokelau)',
        'en_TO' => 'Èdè Gɛ̀ɛ́sì (Tonga)',
        'en_TT' => 'Èdè Gɛ̀ɛ́sì (Tirinida ati Tobaga)',
        'en_TV' => 'Èdè Gɛ̀ɛ́sì (Tufalu)',
        'en_TZ' => 'Èdè Gɛ̀ɛ́sì (Tàǹsáníà)',
        'en_UA' => 'Èdè Gɛ̀ɛ́sì (Ukarini)',
        'en_UG' => 'Èdè Gɛ̀ɛ́sì (Uganda)',
        'en_UM' => 'Èdè Gɛ̀ɛ́sì (Àwɔn Erékùsù Kékèké Agbègbè US)',
        'en_US' => 'Èdè Gɛ̀ɛ́sì (Amɛrikà)',
        'en_VC' => 'Èdè Gɛ̀ɛ́sì (Fisɛnnti ati Genadina)',
        'en_VG' => 'Èdè Gɛ̀ɛ́sì (Etíkun Fágínì ti ìlú Bírítísì)',
        'en_VI' => 'Èdè Gɛ̀ɛ́sì (Etikun Fagini ti Amɛrika)',
        'en_VU' => 'Èdè Gɛ̀ɛ́sì (Faniatu)',
        'en_WS' => 'Èdè Gɛ̀ɛ́sì (Samɔ)',
        'en_ZA' => 'Èdè Gɛ̀ɛ́sì (Gúúshù Áfíríkà)',
        'en_ZM' => 'Èdè Gɛ̀ɛ́sì (Shamibia)',
        'en_ZW' => 'Èdè Gɛ̀ɛ́sì (Shimibabe)',
        'es' => 'Èdè Sípáníìshì',
        'es_419' => 'Èdè Sípáníìshì (Látín Amɛ́ríkà)',
        'es_AR' => 'Èdè Sípáníìshì (Agentínà)',
        'es_BO' => 'Èdè Sípáníìshì (Bɔ̀lífíyà)',
        'es_BR' => 'Èdè Sípáníìshì (Bàràsílì)',
        'es_BZ' => 'Èdè Sípáníìshì (Bèlísɛ̀)',
        'es_CL' => 'Èdè Sípáníìshì (Shílè)',
        'es_CO' => 'Èdè Sípáníìshì (Kòlómíbìa)',
        'es_CR' => 'Èdè Sípáníìshì (Kuusita Ríkà)',
        'es_CU' => 'Èdè Sípáníìshì (Kúbà)',
        'es_DO' => 'Èdè Sípáníìshì (Dòmíníkánì)',
        'es_EC' => 'Èdè Sípáníìshì (Ekuádò)',
        'es_ES' => 'Èdè Sípáníìshì (Sípéìnì)',
        'es_GQ' => 'Èdè Sípáníìshì (Ekutoria Gini)',
        'es_GT' => 'Èdè Sípáníìshì (Guatemálà)',
        'es_HN' => 'Èdè Sípáníìshì (Hondurasi)',
        'es_MX' => 'Èdè Sípáníìshì (Mesiko)',
        'es_NI' => 'Èdè Sípáníìshì (Nikaragua)',
        'es_PA' => 'Èdè Sípáníìshì (Paramá)',
        'es_PE' => 'Èdè Sípáníìshì (Pèérù)',
        'es_PH' => 'Èdè Sípáníìshì (Filipini)',
        'es_PR' => 'Èdè Sípáníìshì (Pɔto Riko)',
        'es_PY' => 'Èdè Sípáníìshì (Paraguye)',
        'es_SV' => 'Èdè Sípáníìshì (Ɛɛsáfádò)',
        'es_US' => 'Èdè Sípáníìshì (Amɛrikà)',
        'es_UY' => 'Èdè Sípáníìshì (Úrúgúwè)',
        'es_VE' => 'Èdè Sípáníìshì (Fɛnɛshuɛla)',
        'ff_Adlm_SN' => 'Èdè Fúlàní (Èdè Adam, Sɛnɛga)',
        'ff_Latn_SN' => 'Èdè Fúlàní (Èdè Látìn, Sɛnɛga)',
        'ff_SN' => 'Èdè Fúlàní (Sɛnɛga)',
        'fo_DK' => 'Èdè Faroesi (Dɛ́mákì)',
        'fo_FO' => 'Èdè Faroesi (Àwɔn Erékùsù ti Faroe)',
        'fr_BE' => 'Èdè Faransé (Bégíɔ́mù)',
        'fr_BJ' => 'Èdè Faransé (Bɛ̀nɛ̀)',
        'fr_BL' => 'Èdè Faransé (Ìlú Bátílɛ́mì)',
        'fr_DJ' => 'Èdè Faransé (Díbɔ́ótì)',
        'fr_GF' => 'Èdè Faransé (Firenshi Guana)',
        'fr_PF' => 'Èdè Faransé (Firenshi Polinesia)',
        'fr_PM' => 'Èdè Faransé (Pɛɛri ati mikuloni)',
        'fr_SC' => 'Èdè Faransé (Sheshɛlɛsi)',
        'fr_SN' => 'Èdè Faransé (Sɛnɛga)',
        'fr_TD' => 'Èdè Faransé (Shààdì)',
        'fr_TN' => 'Èdè Faransé (Tunishia)',
        'ga_GB' => 'Èdè Ireland (Gɛ̀ɛ́sì)',
        'gd_GB' => 'Èdè Gaelik ti Ilu Scotland (Gɛ̀ɛ́sì)',
        'gv_IM' => 'Máǹkì (Erékùshù ilɛ̀ Man)',
        'he_IL' => 'Èdè Heberu (Iserɛli)',
        'hr_BA' => 'Èdè Kroatia (Bɔ̀síníà àti Ɛtisɛgófínà)',
        'id' => 'Èdè Indonéshíà',
        'id_ID' => 'Èdè Indonéshíà (Indonéshíà)',
        'ie' => 'Èdè àtɔwɔ́dá',
        'ie_EE' => 'Èdè àtɔwɔ́dá (Esitonia)',
        'ii' => 'Shíkuán Yì',
        'ii_CN' => 'Shíkuán Yì (Sháínà)',
        'is_IS' => 'Èdè Icelandic (Ashilandi)',
        'jv_ID' => 'Èdè Javanasi (Indonéshíà)',
        'ka_GE' => 'Èdè Georgia (Gɔgia)',
        'kk' => 'Kashakì',
        'kk_Arab' => 'Kashakì (èdè Lárúbáwá)',
        'kk_Arab_CN' => 'Kashakì (èdè Lárúbáwá, Sháínà)',
        'kk_Cyrl' => 'Kashakì (èdè ilɛ̀ Rɔ́shíà)',
        'kk_Cyrl_KZ' => 'Kashakì (èdè ilɛ̀ Rɔ́shíà, Kashashatani)',
        'kk_KZ' => 'Kashakì (Kashashatani)',
        'ko_CN' => 'Èdè Kòríà (Sháínà)',
        'ko_KP' => 'Èdè Kòríà (Guusu Kɔria)',
        'ko_KR' => 'Èdè Kòríà (Ariwa Kɔria)',
        'ks' => 'Kashímirì',
        'ks_Arab' => 'Kashímirì (èdè Lárúbáwá)',
        'ks_Arab_IN' => 'Kashímirì (èdè Lárúbáwá, Íńdíà)',
        'ks_Deva' => 'Kashímirì (Dɛfanagárì)',
        'ks_Deva_IN' => 'Kashímirì (Dɛfanagárì, Íńdíà)',
        'ks_IN' => 'Kashímirì (Íńdíà)',
        'ku' => 'Kɔdishì',
        'ku_Latn' => 'Kɔdishì (Èdè Látìn)',
        'ku_Latn_IQ' => 'Kɔdishì (Èdè Látìn, Iraki)',
        'ku_Latn_SY' => 'Kɔdishì (Èdè Látìn, Siria)',
        'ku_Latn_TR' => 'Kɔdishì (Èdè Látìn, Tɔɔki)',
        'ku_SY' => 'Kɔdishì (Siria)',
        'ku_TR' => 'Kɔdishì (Tɔɔki)',
        'kw' => 'Èdè Kɔ́nììshì',
        'kw_GB' => 'Èdè Kɔ́nììshì (Gɛ̀ɛ́sì)',
        'ky_KG' => 'Kírígíìsì (Kurishisitani)',
        'lb' => 'Lùshɛ́mbɔ́ɔ̀gì',
        'lb_LU' => 'Lùshɛ́mbɔ́ɔ̀gì (Lusemogi)',
        'mi_NZ' => 'Màórì (Shilandi Titun)',
        'ms_BN' => 'Èdè Malaya (Búrúnɛ́lì)',
        'ms_ID' => 'Èdè Malaya (Indonéshíà)',
        'nb' => 'Nɔ́ɔ́wè Bokímàl',
        'nb_NO' => 'Nɔ́ɔ́wè Bokímàl (Nɔɔwii)',
        'nb_SJ' => 'Nɔ́ɔ́wè Bokímàl (Sífábáàdì àti Jánì Máyɛ̀nì)',
        'nd_ZW' => 'Àríwá Ndebele (Shimibabe)',
        'nl' => 'Èdè Dɔ́ɔ̀shì',
        'nl_AW' => 'Èdè Dɔ́ɔ̀shì (Árúbà)',
        'nl_BE' => 'Èdè Dɔ́ɔ̀shì (Bégíɔ́mù)',
        'nl_BQ' => 'Èdè Dɔ́ɔ̀shì (Kàríbíánì ti Nɛ́dálándì)',
        'nl_CW' => 'Èdè Dɔ́ɔ̀shì (Curaçao)',
        'nl_NL' => 'Èdè Dɔ́ɔ̀shì (Nedalandi)',
        'nl_SR' => 'Èdè Dɔ́ɔ̀shì (Surinami)',
        'nl_SX' => 'Èdè Dɔ́ɔ̀shì (Síntì Mátɛ́ɛ̀nì)',
        'nn' => 'Nɔ́ɔ́wè Nínɔ̀sìkì',
        'nn_NO' => 'Nɔ́ɔ́wè Nínɔ̀sìkì (Nɔɔwii)',
        'no_NO' => 'Èdè Norway (Nɔɔwii)',
        'oc' => 'Èdè Ɔ̀kísítáànì',
        'oc_ES' => 'Èdè Ɔ̀kísítáànì (Sípéìnì)',
        'oc_FR' => 'Èdè Ɔ̀kísítáànì (Faranse)',
        'om' => 'Òròmɔ́',
        'om_ET' => 'Òròmɔ́ (Etopia)',
        'om_KE' => 'Òròmɔ́ (Kenya)',
        'os' => 'Ɔshɛ́tíìkì',
        'os_GE' => 'Ɔshɛ́tíìkì (Gɔgia)',
        'os_RU' => 'Ɔshɛ́tíìkì (Rɔshia)',
        'pt' => 'Èdè Pɔtogí',
        'pt_AO' => 'Èdè Pɔtogí (Ààngólà)',
        'pt_BR' => 'Èdè Pɔtogí (Bàràsílì)',
        'pt_CH' => 'Èdè Pɔtogí (Súwísìlanìdì)',
        'pt_CV' => 'Èdè Pɔtogí (Etíokun Kápé féndè)',
        'pt_GQ' => 'Èdè Pɔtogí (Ekutoria Gini)',
        'pt_GW' => 'Èdè Pɔtogí (Gene-Busau)',
        'pt_LU' => 'Èdè Pɔtogí (Lusemogi)',
        'pt_MO' => 'Èdè Pɔtogí (Agbègbè Ìshàkóso Pàtàkì Macao)',
        'pt_MZ' => 'Èdè Pɔtogí (Moshamibiku)',
        'pt_PT' => 'Èdè Pɔtogí (Pɔ́túgà)',
        'pt_ST' => 'Èdè Pɔtogí (Sao tomi ati piriishipi)',
        'pt_TL' => 'Èdè Pɔtogí (Tímɔ̀ Lɛsiti)',
        'qu' => 'Kúɛ́ńjùà',
        'qu_BO' => 'Kúɛ́ńjùà (Bɔ̀lífíyà)',
        'qu_EC' => 'Kúɛ́ńjùà (Ekuádò)',
        'qu_PE' => 'Kúɛ́ńjùà (Pèérù)',
        'rm' => 'Rómáǹshì',
        'rm_CH' => 'Rómáǹshì (Súwísìlanìdì)',
        'ru' => 'Èdè Rɔ́shíà',
        'ru_BY' => 'Èdè Rɔ́shíà (Bélárúsì)',
        'ru_KG' => 'Èdè Rɔ́shíà (Kurishisitani)',
        'ru_KZ' => 'Èdè Rɔ́shíà (Kashashatani)',
        'ru_MD' => 'Èdè Rɔ́shíà (Modofia)',
        'ru_RU' => 'Èdè Rɔ́shíà (Rɔshia)',
        'ru_UA' => 'Èdè Rɔ́shíà (Ukarini)',
        'sd_Deva' => 'Èdè Sindhi (Dɛfanagárì)',
        'sd_Deva_IN' => 'Èdè Sindhi (Dɛfanagárì, Íńdíà)',
        'se_NO' => 'Apáàríwá Sami (Nɔɔwii)',
        'sh_BA' => 'Èdè Serbo-Croatiani (Bɔ̀síníà àti Ɛtisɛgófínà)',
        'sn' => 'Shɔnà',
        'sn_ZW' => 'Shɔnà (Shimibabe)',
        'so_DJ' => 'Èdè ara Somalia (Díbɔ́ótì)',
        'sr_BA' => 'Èdè Serbia (Bɔ̀síníà àti Ɛtisɛgófínà)',
        'sr_Cyrl' => 'Èdè Serbia (èdè ilɛ̀ Rɔ́shíà)',
        'sr_Cyrl_BA' => 'Èdè Serbia (èdè ilɛ̀ Rɔ́shíà, Bɔ̀síníà àti Ɛtisɛgófínà)',
        'sr_Cyrl_ME' => 'Èdè Serbia (èdè ilɛ̀ Rɔ́shíà, Montenégrò)',
        'sr_Cyrl_RS' => 'Èdè Serbia (èdè ilɛ̀ Rɔ́shíà, Sɛ́bíà)',
        'sr_Latn_BA' => 'Èdè Serbia (Èdè Látìn, Bɔ̀síníà àti Ɛtisɛgófínà)',
        'sr_Latn_RS' => 'Èdè Serbia (Èdè Látìn, Sɛ́bíà)',
        'sr_RS' => 'Èdè Serbia (Sɛ́bíà)',
        'st_ZA' => 'Èdè Sesoto (Gúúshù Áfíríkà)',
        'su_ID' => 'Èdè Sudanísì (Indonéshíà)',
        'su_Latn_ID' => 'Èdè Sudanísì (Èdè Látìn, Indonéshíà)',
        'sv_AX' => 'Èdè Suwidiisi (Àwɔn Erékùsù ti Aland)',
        'tk_TM' => 'Èdè Turkmen (Tɔ́kìmɛ́nísítànì)',
        'tn_BW' => 'Èdè Suwana (Bɔ̀tìsúwánà)',
        'tn_ZA' => 'Èdè Suwana (Gúúshù Áfíríkà)',
        'tr' => 'Èdè Tɔɔkisi',
        'tr_CY' => 'Èdè Tɔɔkisi (Kúrúsì)',
        'tr_TR' => 'Èdè Tɔɔkisi (Tɔɔki)',
        'tt_RU' => 'Tátárì (Rɔshia)',
        'ug' => 'Yúgɔ̀',
        'ug_CN' => 'Yúgɔ̀ (Sháínà)',
        'uz_Cyrl' => 'Èdè Uzbek (èdè ilɛ̀ Rɔ́shíà)',
        'uz_Cyrl_UZ' => 'Èdè Uzbek (èdè ilɛ̀ Rɔ́shíà, Nshibɛkisitani)',
        'uz_Latn_UZ' => 'Èdè Uzbek (Èdè Látìn, Nshibɛkisitani)',
        'uz_UZ' => 'Èdè Uzbek (Nshibɛkisitani)',
        'vi_VN' => 'Èdè Jetinamu (Fɛtinami)',
        'wo' => 'Wɔ́lɔ́ɔ̀fù',
        'wo_SN' => 'Wɔ́lɔ́ɔ̀fù (Sɛnɛga)',
        'xh_ZA' => 'Èdè Xhosa (Gúúshù Áfíríkà)',
        'yo_BJ' => 'Èdè Yorùbá (Bɛ̀nɛ̀)',
        'za' => 'Shúwáànù',
        'za_CN' => 'Shúwáànù (Sháínà)',
        'zh' => 'Edè Sháínà',
        'zh_CN' => 'Edè Sháínà (Sháínà)',
        'zh_HK' => 'Edè Sháínà (Agbègbè Ìshàkóso Ìshúná Hong Kong Tí Shánà Ń Darí)',
        'zh_Hans' => 'Edè Sháínà (tí wɔ́n mú rɔrùn.)',
        'zh_Hans_CN' => 'Edè Sháínà (tí wɔ́n mú rɔrùn., Sháínà)',
        'zh_Hans_HK' => 'Edè Sháínà (tí wɔ́n mú rɔrùn., Agbègbè Ìshàkóso Ìshúná Hong Kong Tí Shánà Ń Darí)',
        'zh_Hans_MO' => 'Edè Sháínà (tí wɔ́n mú rɔrùn., Agbègbè Ìshàkóso Pàtàkì Macao)',
        'zh_Hans_MY' => 'Edè Sháínà (tí wɔ́n mú rɔrùn., Malasia)',
        'zh_Hans_SG' => 'Edè Sháínà (tí wɔ́n mú rɔrùn., Singapo)',
        'zh_Hant' => 'Edè Sháínà (Àbáláyé)',
        'zh_Hant_HK' => 'Edè Sháínà (Àbáláyé, Agbègbè Ìshàkóso Ìshúná Hong Kong Tí Shánà Ń Darí)',
        'zh_Hant_MO' => 'Edè Sháínà (Àbáláyé, Agbègbè Ìshàkóso Pàtàkì Macao)',
        'zh_Hant_MY' => 'Edè Sháínà (Àbáláyé, Malasia)',
        'zh_Hant_TW' => 'Edè Sháínà (Àbáláyé, Taiwani)',
        'zh_MO' => 'Edè Sháínà (Agbègbè Ìshàkóso Pàtàkì Macao)',
        'zh_SG' => 'Edè Sháínà (Singapo)',
        'zh_TW' => 'Edè Sháínà (Taiwani)',
        'zu' => 'Èdè Shulu',
        'zu_ZA' => 'Èdè Shulu (Gúúshù Áfíríkà)',
    ],
];
