<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'am' => 'амҳарӣ',
        'ar' => 'арабӣ',
        'as' => 'ассомӣ',
        'az' => 'озарбойҷонӣ',
        'ba' => 'бошқирдӣ',
        'ban' => 'балинӣ',
        'be' => 'белорусӣ',
        'bem' => 'бемба',
        'bg' => 'булғорӣ',
        'bn' => 'бинғолӣ',
        'bo' => 'тибетӣ',
        'br' => 'бретонӣ',
        'bs' => 'босниягӣ',
        'ca' => 'каталонӣ',
        'ceb' => 'себуано',
        'cgg' => 'Чига',
        'chm' => 'марӣ',
        'chr' => 'черокӣ',
        'ckb' => 'курдии марказӣ',
        'co' => 'корсиканӣ',
        'cs' => 'чехӣ',
        'cy' => 'валлӣ',
        'da' => 'даниягӣ',
        'de' => 'немисӣ',
        'dsb' => 'сербии поёнӣ',
        'dv' => 'дивеҳӣ',
        'dz' => 'дзонгха',
        'el' => 'юнонӣ',
        'en' => 'англисӣ',
        'eo' => 'эсперанто',
        'es' => 'испанӣ',
        'et' => 'эстонӣ',
        'eu' => 'баскӣ',
        'fa' => 'форсӣ',
        'ff' => 'фулаҳ',
        'fi' => 'финӣ',
        'fil' => 'филиппинӣ',
        'fo' => 'фарерӣ',
        'fr' => 'франсузӣ',
        'fy' => 'фризии ғарбӣ',
        'ga' => 'ирландӣ',
        'gd' => 'шотландии гэлӣ',
        'gl' => 'галисиягӣ',
        'gn' => 'гуаранӣ',
        'gu' => 'гуҷаротӣ',
        'ha' => 'ҳауса',
        'haw' => 'ҳавайӣ',
        'he' => 'ибронӣ',
        'hi' => 'ҳиндӣ',
        'hil' => 'ҳилигайнон',
        'hr' => 'хорватӣ',
        'hsb' => 'сербии болоӣ',
        'ht' => 'гаитии креолӣ',
        'hu' => 'маҷорӣ',
        'hy' => 'арманӣ',
        'hz' => 'ҳереро',
        'ibb' => 'ибибио',
        'id' => 'индонезӣ',
        'ig' => 'игбо',
        'is' => 'исландӣ',
        'it' => 'италиявӣ',
        'iu' => 'инуктитутӣ',
        'ja' => 'японӣ',
        'ka' => 'гурҷӣ',
        'kk' => 'қазоқӣ',
        'km' => 'кхмерӣ',
        'kn' => 'каннада',
        'ko' => 'кореягӣ',
        'kok' => 'конканӣ',
        'kr' => 'канурӣ',
        'kru' => 'курукс',
        'ks' => 'кашмирӣ',
        'ku' => 'курдӣ',
        'ky' => 'қирғизӣ',
        'la' => 'лотинӣ',
        'lb' => 'люксембургӣ',
        'lo' => 'лаосӣ',
        'lt' => 'литвонӣ',
        'lv' => 'латишӣ',
        'men' => 'менде',
        'mg' => 'малагасӣ',
        'mi' => 'маорӣ',
        'mk' => 'мақдунӣ',
        'ml' => 'малаяламӣ',
        'mn' => 'муғулӣ',
        'mni' => 'манипурӣ',
        'moh' => 'моҳок',
        'mr' => 'маратҳӣ',
        'ms' => 'малайӣ',
        'mt' => 'малтӣ',
        'my' => 'бирманӣ',
        'ne' => 'непалӣ',
        'niu' => 'ниуэӣ',
        'nl' => 'голландӣ',
        'no' => 'норвегӣ',
        'ny' => 'нянҷа',
        'oc' => 'окситанӣ',
        'om' => 'оромо',
        'or' => 'одия',
        'pa' => 'панҷобӣ',
        'pap' => 'папиаменто',
        'pl' => 'лаҳистонӣ',
        'ps' => 'пушту',
        'pt' => 'португалӣ',
        'qu' => 'кечуа',
        'quc' => 'киче',
        'rm' => 'ретороманӣ',
        'ro' => 'руминӣ',
        'ru' => 'русӣ',
        'rw' => 'киняруанда',
        'sa' => 'санскрит',
        'sah' => 'саха',
        'sat' => 'санталӣ',
        'sd' => 'синдӣ',
        'se' => 'самии шимолӣ',
        'si' => 'сингалӣ',
        'sk' => 'словакӣ',
        'sl' => 'словенӣ',
        'sma' => 'самии ҷанубӣ',
        'smj' => 'луле самӣ',
        'smn' => 'инари самӣ',
        'sms' => 'сколти самӣ',
        'so' => 'сомалӣ',
        'sq' => 'албанӣ',
        'sr' => 'сербӣ',
        'sv' => 'шведӣ',
        'syr' => 'суриёнӣ',
        'ta' => 'тамилӣ',
        'te' => 'телугу',
        'tg' => 'тоҷикӣ',
        'th' => 'тайӣ',
        'ti' => 'тигриня',
        'tk' => 'туркманӣ',
        'to' => 'тонганӣ',
        'tr' => 'туркӣ',
        'tt' => 'тоторӣ',
        'tzm' => 'тамазайти Атласи Марказӣ',
        'ug' => 'ӯйғурӣ',
        'uk' => 'украинӣ',
        'ur' => 'урду',
        'uz' => 'ӯзбекӣ',
        've' => 'венда',
        'vi' => 'ветнамӣ',
        'wo' => 'волоф',
        'yi' => 'идиш',
        'yo' => 'йоруба',
        'zh' => 'хитоӣ',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Стандарти муосири арабӣ',
        'de_AT' => 'немисии австриягӣ',
        'de_CH' => 'немисии швейсарии болоӣ',
        'en_AU' => 'англисии австралиягӣ',
        'en_CA' => 'англисии канадагӣ',
        'en_GB' => 'англисии британӣ',
        'en_US' => 'англисии америкоӣ',
        'es_419' => 'испании америкоии лотинӣ',
        'es_ES' => 'испании аврупоӣ',
        'es_MX' => 'испании мексикоӣ',
        'fr_CA' => 'франсузии канадагӣ',
        'fr_CH' => 'франсузии швейсарӣ',
        'nl_BE' => 'Фламандӣ',
        'pt_BR' => 'португалии бразилиягӣ',
        'pt_PT' => 'португалии аврупоӣ',
        'zh_Hans' => 'хитоии осонфаҳм',
        'zh_Hant' => 'хитоии анъанавӣ',
    ],
];
