<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Peseta de Andorra',
        ],
        'AED' => [
            'AED',
            'Dirham dos Emirados Árabes Unidos',
        ],
        'AFA' => [
            'AFA',
            'Afegane (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'Afegane afegão',
        ],
        'ALK' => [
            'ALK',
            'Lek Albanês (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'Lek albanês',
        ],
        'AMD' => [
            'AMD',
            'Dram armênio',
        ],
        'ANG' => [
            'ANG',
            'Florim das Antilhas Holandesas',
        ],
        'AOA' => [
            'AOA',
            'Kwanza angolano',
        ],
        'AOK' => [
            'AOK',
            'Cuanza angolano (1977–1990)',
        ],
        'AON' => [
            'AON',
            'Novo cuanza angolano (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Cuanza angolano reajustado (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Austral argentino',
        ],
        'ARL' => [
            'ARL',
            'Peso lei argentino (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'Peso argentino (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'Peso argentino (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'Peso argentino',
        ],
        'ATS' => [
            'ATS',
            'Xelim austríaco',
        ],
        'AUD' => [
            'AU$',
            'Dólar australiano',
        ],
        'AWG' => [
            'AWG',
            'Florim arubano',
        ],
        'AZM' => [
            'AZM',
            'Manat azerbaijano (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'Manat azeri',
        ],
        'BAD' => [
            'BAD',
            'Dinar da Bósnia-Herzegovina (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'Marco conversível da Bósnia e Herzegovina',
        ],
        'BAN' => [
            'BAN',
            'Novo dinar da Bósnia-Herzegovina (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'Dólar barbadense',
        ],
        'BDT' => [
            'BDT',
            'Taka bengali',
        ],
        'BEC' => [
            'BEC',
            'Franco belga (conversível)',
        ],
        'BEF' => [
            'BEF',
            'Franco belga',
        ],
        'BEL' => [
            'BEL',
            'Franco belga (financeiro)',
        ],
        'BGL' => [
            'BGL',
            'Lev forte búlgaro',
        ],
        'BGM' => [
            'BGM',
            'Lev socialista búlgaro',
        ],
        'BGN' => [
            'BGN',
            'Lev búlgaro',
        ],
        'BGO' => [
            'BGO',
            'Lev búlgaro (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'Dinar bareinita',
        ],
        'BIF' => [
            'BIF',
            'Franco burundiano',
        ],
        'BMD' => [
            'BMD',
            'Dólar bermudense',
        ],
        'BND' => [
            'BND',
            'Dólar bruneano',
        ],
        'BOB' => [
            'BOB',
            'Boliviano da Bolívia',
        ],
        'BOL' => [
            'BOL',
            'Boliviano (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'Peso boliviano',
        ],
        'BOV' => [
            'BOV',
            'Mvdol boliviano',
        ],
        'BRB' => [
            'BRB',
            'Cruzeiro novo brasileiro (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Cruzado brasileiro (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'Cruzeiro brasileiro (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'Real brasileiro',
        ],
        'BRN' => [
            'BRN',
            'Cruzado novo brasileiro (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'Cruzeiro brasileiro (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'Cruzeiro brasileiro (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'Dólar bahamense',
        ],
        'BTN' => [
            'BTN',
            'Ngultrum butanês',
        ],
        'BUK' => [
            'BUK',
            'Kyat birmanês',
        ],
        'BWP' => [
            'BWP',
            'Pula botsuanesa',
        ],
        'BYB' => [
            'BYB',
            'Rublo novo bielo-russo (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'Rublo bielorrusso',
        ],
        'BYR' => [
            'BYR',
            'Rublo bielorrusso (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Dólar belizenho',
        ],
        'CAD' => [
            'CA$',
            'Dólar canadense',
        ],
        'CDF' => [
            'CDF',
            'Franco congolês',
        ],
        'CHE' => [
            'CHE',
            'Euro WIR',
        ],
        'CHF' => [
            'CHF',
            'Franco suíço',
        ],
        'CHW' => [
            'CHW',
            'Franco WIR',
        ],
        'CLE' => [
            'CLE',
            'Escudo chileno',
        ],
        'CLF' => [
            'CLF',
            'Unidades de Fomento chilenas',
        ],
        'CLP' => [
            'CLP',
            'Peso chileno',
        ],
        'CNH' => [
            'CNH',
            'Yuan chinês (offshore)',
        ],
        'CNX' => [
            'CNX',
            'Dólar do Banco Popular da China',
        ],
        'CNY' => [
            'CN¥',
            'Yuan chinês',
        ],
        'COP' => [
            'COP',
            'Peso colombiano',
        ],
        'COU' => [
            'COU',
            'Unidade de Valor Real',
        ],
        'CRC' => [
            'CRC',
            'Colón costarriquenho',
        ],
        'CSD' => [
            'CSD',
            'Dinar sérvio (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'Coroa Forte checoslovaca',
        ],
        'CUC' => [
            'CUC',
            'Peso cubano conversível',
        ],
        'CUP' => [
            'CUP',
            'Peso cubano',
        ],
        'CVE' => [
            'CVE',
            'Escudo cabo-verdiano',
        ],
        'CYP' => [
            'CYP',
            'Libra cipriota',
        ],
        'CZK' => [
            'CZK',
            'Coroa tcheca',
        ],
        'DDM' => [
            'DDM',
            'Ostmark da Alemanha Oriental',
        ],
        'DEM' => [
            'DEM',
            'Marco alemão',
        ],
        'DJF' => [
            'DJF',
            'Franco djiboutiano',
        ],
        'DKK' => [
            'DKK',
            'Coroa dinamarquesa',
        ],
        'DOP' => [
            'DOP',
            'Peso dominicano',
        ],
        'DZD' => [
            'DZD',
            'Dinar argelino',
        ],
        'ECS' => [
            'ECS',
            'Sucre equatoriano',
        ],
        'ECV' => [
            'ECV',
            'Unidade de Valor Constante (UVC) do Equador',
        ],
        'EEK' => [
            'EEK',
            'Coroa estoniana',
        ],
        'EGP' => [
            'EGP',
            'Libra egípcia',
        ],
        'ERN' => [
            'ERN',
            'Nakfa da Eritreia',
        ],
        'ESA' => [
            'ESA',
            'Peseta espanhola (conta A)',
        ],
        'ESB' => [
            'ESB',
            'Peseta espanhola (conta conversível)',
        ],
        'ESP' => [
            'ESP',
            'Peseta espanhola',
        ],
        'ETB' => [
            'ETB',
            'Birr etíope',
        ],
        'EUR' => [
            '€',
            'Euro',
        ],
        'FIM' => [
            'FIM',
            'Marca finlandesa',
        ],
        'FJD' => [
            'FJD',
            'Dólar fijiano',
        ],
        'FKP' => [
            'FKP',
            'Libra malvinense',
        ],
        'FRF' => [
            'FRF',
            'Franco francês',
        ],
        'GBP' => [
            '£',
            'Libra esterlina',
        ],
        'GEK' => [
            'GEK',
            'Cupom Lari georgiano',
        ],
        'GEL' => [
            'GEL',
            'Lari georgiano',
        ],
        'GHC' => [
            'GHC',
            'Cedi de Gana (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'Cedi ganês',
        ],
        'GIP' => [
            'GIP',
            'Libra de Gibraltar',
        ],
        'GMD' => [
            'GMD',
            'Dalasi gambiano',
        ],
        'GNF' => [
            'GNF',
            'Franco guineano',
        ],
        'GNS' => [
            'GNS',
            'Syli da Guiné',
        ],
        'GQE' => [
            'GQE',
            'Ekwele da Guiné Equatorial',
        ],
        'GRD' => [
            'GRD',
            'Dracma grego',
        ],
        'GTQ' => [
            'GTQ',
            'Quetzal guatemalteco',
        ],
        'GWE' => [
            'GWE',
            'Escudo da Guiné Portuguesa',
        ],
        'GWP' => [
            'GWP',
            'Peso da Guiné-Bissau',
        ],
        'GYD' => [
            'GYD',
            'Dólar guianense',
        ],
        'HKD' => [
            'HK$',
            'Dólar de Hong Kong',
        ],
        'HNL' => [
            'HNL',
            'Lempira hondurenha',
        ],
        'HRD' => [
            'HRD',
            'Dinar croata',
        ],
        'HRK' => [
            'HRK',
            'Kuna croata',
        ],
        'HTG' => [
            'HTG',
            'Gourde haitiano',
        ],
        'HUF' => [
            'HUF',
            'Florim húngaro',
        ],
        'IDR' => [
            'IDR',
            'Rupia indonésia',
        ],
        'IEP' => [
            'IEP',
            'Libra irlandesa',
        ],
        'ILP' => [
            'ILP',
            'Libra israelita',
        ],
        'ILR' => [
            'ILR',
            'Sheqel antigo israelita',
        ],
        'ILS' => [
            '₪',
            'Novo shekel israelense',
        ],
        'INR' => [
            '₹',
            'Rupia indiana',
        ],
        'IQD' => [
            'IQD',
            'Dinar iraquiano',
        ],
        'IRR' => [
            'IRR',
            'Rial iraniano',
        ],
        'ISJ' => [
            'ISJ',
            'Coroa antiga islandesa',
        ],
        'ISK' => [
            'ISK',
            'Coroa islandesa',
        ],
        'ITL' => [
            'ITL',
            'Lira italiana',
        ],
        'JMD' => [
            'JMD',
            'Dólar jamaicano',
        ],
        'JOD' => [
            'JOD',
            'Dinar jordaniano',
        ],
        'JPY' => [
            'JP¥',
            'Iene japonês',
        ],
        'KES' => [
            'KES',
            'Xelim queniano',
        ],
        'KGS' => [
            'KGS',
            'Som quirguiz',
        ],
        'KHR' => [
            'KHR',
            'Riel cambojano',
        ],
        'KMF' => [
            'KMF',
            'Franco comoriano',
        ],
        'KPW' => [
            'KPW',
            'Won norte-coreano',
        ],
        'KRH' => [
            'KRH',
            'Hwan da Coreia do Sul (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'Won da Coreia do Sul (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'Won sul-coreano',
        ],
        'KWD' => [
            'KWD',
            'Dinar kuwaitiano',
        ],
        'KYD' => [
            'KYD',
            'Dólar das Ilhas Cayman',
        ],
        'KZT' => [
            'KZT',
            'Tenge cazaque',
        ],
        'LAK' => [
            'LAK',
            'Kip laosiano',
        ],
        'LBP' => [
            'LBP',
            'Libra libanesa',
        ],
        'LKR' => [
            'LKR',
            'Rupia cingalesa',
        ],
        'LRD' => [
            'LRD',
            'Dólar liberiano',
        ],
        'LSL' => [
            'LSL',
            'Loti lesotiano',
        ],
        'LTL' => [
            'LTL',
            'Litas lituano',
        ],
        'LTT' => [
            'LTT',
            'Talonas lituano',
        ],
        'LUC' => [
            'LUC',
            'Franco conversível de Luxemburgo',
        ],
        'LUF' => [
            'LUF',
            'Franco luxemburguês',
        ],
        'LUL' => [
            'LUL',
            'Franco financeiro de Luxemburgo',
        ],
        'LVL' => [
            'LVL',
            'Lats letão',
        ],
        'LVR' => [
            'LVR',
            'Rublo letão',
        ],
        'LYD' => [
            'LYD',
            'Dinar líbio',
        ],
        'MAD' => [
            'MAD',
            'Dirham marroquino',
        ],
        'MAF' => [
            'MAF',
            'Franco marroquino',
        ],
        'MCF' => [
            'MCF',
            'Franco monegasco',
        ],
        'MDC' => [
            'MDC',
            'Cupon moldávio',
        ],
        'MDL' => [
            'MDL',
            'Leu moldávio',
        ],
        'MGA' => [
            'MGA',
            'Ariary malgaxe',
        ],
        'MGF' => [
            'MGF',
            'Franco de Madagascar',
        ],
        'MKD' => [
            'MKD',
            'Dinar macedônio',
        ],
        'MKN' => [
            'MKN',
            'Dinar macedônio (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'Franco de Mali',
        ],
        'MMK' => [
            'MMK',
            'Quiate mianmarense',
        ],
        'MNT' => [
            'MNT',
            'Tugrik mongol',
        ],
        'MOP' => [
            'MOP',
            'Pataca macaense',
        ],
        'MRO' => [
            'MRO',
            'Ouguiya mauritana (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Ouguiya mauritana',
        ],
        'MTL' => [
            'MTL',
            'Lira maltesa',
        ],
        'MTP' => [
            'MTP',
            'Libra maltesa',
        ],
        'MUR' => [
            'MUR',
            'Rupia mauriciana',
        ],
        'MVR' => [
            'MVR',
            'Rupia maldivana',
        ],
        'MWK' => [
            'MWK',
            'Kwacha malauiana',
        ],
        'MXN' => [
            'MX$',
            'Peso mexicano',
        ],
        'MXP' => [
            'MXP',
            'Peso Prata mexicano (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Unidade Mexicana de Investimento (UDI)',
        ],
        'MYR' => [
            'MYR',
            'Ringgit malaio',
        ],
        'MZE' => [
            'MZE',
            'Escudo de Moçambique',
        ],
        'MZM' => [
            'MZM',
            'Metical de Moçambique (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'Metical moçambicano',
        ],
        'NAD' => [
            'NAD',
            'Dólar namibiano',
        ],
        'NGN' => [
            'NGN',
            'Naira nigeriana',
        ],
        'NIC' => [
            'NIC',
            'Córdoba nicaraguense (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'Córdoba nicaraguense',
        ],
        'NLG' => [
            'NLG',
            'Florim holandês',
        ],
        'NOK' => [
            'NOK',
            'Coroa norueguesa',
        ],
        'NPR' => [
            'NPR',
            'Rupia nepalesa',
        ],
        'NZD' => [
            'NZ$',
            'Dólar neozelandês',
        ],
        'OMR' => [
            'OMR',
            'Rial omanense',
        ],
        'PAB' => [
            'PAB',
            'Balboa panamenho',
        ],
        'PEI' => [
            'PEI',
            'Inti peruano',
        ],
        'PEN' => [
            'PEN',
            'Novo sol peruano',
        ],
        'PES' => [
            'PES',
            'Sol peruano (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'Kina papuásia',
        ],
        'PHP' => [
            'PHP',
            'Peso filipino',
        ],
        'PKR' => [
            'PKR',
            'Rupia paquistanesa',
        ],
        'PLN' => [
            'PLN',
            'Zloty polonês',
        ],
        'PLZ' => [
            'PLZ',
            'Zloti polonês (1950–1995)',
        ],
        'PTE' => [
            'Esc.',
            'Escudo português',
        ],
        'PYG' => [
            'PYG',
            'Guarani paraguaio',
        ],
        'QAR' => [
            'QAR',
            'Rial catariano',
        ],
        'RHD' => [
            'RHD',
            'Dólar rodesiano',
        ],
        'ROL' => [
            'ROL',
            'Leu romeno (1952–2006)',
        ],
        'RON' => [
            'RON',
            'Leu romeno',
        ],
        'RSD' => [
            'RSD',
            'Dinar sérvio',
        ],
        'RUB' => [
            'RUB',
            'Rublo russo',
        ],
        'RUR' => [
            'RUR',
            'Rublo russo (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'Franco ruandês',
        ],
        'SAR' => [
            'SAR',
            'Riyal saudita',
        ],
        'SBD' => [
            'SBD',
            'Dólar das Ilhas Salomão',
        ],
        'SCR' => [
            'SCR',
            'Rupia seichelense',
        ],
        'SDD' => [
            'SDD',
            'Dinar sudanês (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'Libra sudanesa',
        ],
        'SDP' => [
            'SDP',
            'Libra sudanesa (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'Coroa sueca',
        ],
        'SGD' => [
            'SGD',
            'Dólar singapuriano',
        ],
        'SHP' => [
            'SHP',
            'Libra de Santa Helena',
        ],
        'SIT' => [
            'SIT',
            'Tolar Bons esloveno',
        ],
        'SKK' => [
            'SKK',
            'Coroa eslovaca',
        ],
        'SLE' => [
            'SLE',
            'Leone de Serra Leoa',
        ],
        'SLL' => [
            'SLL',
            'Leone de Serra Leoa (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Xelim somali',
        ],
        'SRD' => [
            'SRD',
            'Dólar surinamês',
        ],
        'SRG' => [
            'SRG',
            'Florim do Suriname',
        ],
        'SSP' => [
            'SSP',
            'Libra sul-sudanesa',
        ],
        'STD' => [
            'STD',
            'Dobra de São Tomé e Príncipe (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Dobra de São Tomé e Príncipe',
        ],
        'SUR' => [
            'SUR',
            'Rublo soviético',
        ],
        'SVC' => [
            'SVC',
            'Colom salvadorenho',
        ],
        'SYP' => [
            'SYP',
            'Libra síria',
        ],
        'SZL' => [
            'SZL',
            'Lilangeni suazi',
        ],
        'THB' => [
            '฿',
            'Baht tailandês',
        ],
        'TJR' => [
            'TJR',
            'Rublo do Tadjiquistão',
        ],
        'TJS' => [
            'TJS',
            'Somoni tadjique',
        ],
        'TMM' => [
            'TMM',
            'Manat do Turcomenistão (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'Manat turcomeno',
        ],
        'TND' => [
            'TND',
            'Dinar tunisiano',
        ],
        'TOP' => [
            'TOP',
            'Paʻanga tonganesa',
        ],
        'TPE' => [
            'TPE',
            'Escudo timorense',
        ],
        'TRL' => [
            'TRL',
            'Lira turca (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'Lira turca',
        ],
        'TTD' => [
            'TTD',
            'Dólar de Trinidad e Tobago',
        ],
        'TWD' => [
            'NT$',
            'Novo dólar taiwanês',
        ],
        'TZS' => [
            'TZS',
            'Xelim tanzaniano',
        ],
        'UAH' => [
            'UAH',
            'Hryvnia ucraniano',
        ],
        'UAK' => [
            'UAK',
            'Karbovanetz ucraniano',
        ],
        'UGS' => [
            'UGS',
            'Xelim ugandense (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'Xelim ugandense',
        ],
        'USD' => [
            'US$',
            'Dólar americano',
        ],
        'USN' => [
            'USN',
            'Dólar norte-americano (Dia seguinte)',
        ],
        'USS' => [
            'USS',
            'Dólar norte-americano (Mesmo dia)',
        ],
        'UYI' => [
            'UYI',
            'Peso uruguaio en unidades indexadas',
        ],
        'UYP' => [
            'UYP',
            'Peso uruguaio (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'Peso uruguaio',
        ],
        'UZS' => [
            'UZS',
            'Som uzbeque',
        ],
        'VEB' => [
            'VEB',
            'Bolívar venezuelano (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'Bolívar venezuelano (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Bolívar venezuelano',
        ],
        'VND' => [
            '₫',
            'Dong vietnamita',
        ],
        'VNN' => [
            'VNN',
            'Dong vietnamita (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'Vatu de Vanuatu',
        ],
        'WST' => [
            'WST',
            'Tala samoano',
        ],
        'XAF' => [
            'FCFA',
            'Franco CFA de BEAC',
        ],
        'XCD' => [
            'EC$',
            'Dólar do Caribe Oriental',
        ],
        'XCG' => [
            'Cg.',
            'Florim do Caribe',
        ],
        'XEU' => [
            'XEU',
            'Unidade de Moeda Europeia',
        ],
        'XFO' => [
            'XFO',
            'Franco-ouro francês',
        ],
        'XFU' => [
            'XFU',
            'Franco UIC francês',
        ],
        'XOF' => [
            'F CFA',
            'Franco CFA de BCEAO',
        ],
        'XPF' => [
            'CFPF',
            'Franco CFP',
        ],
        'XRE' => [
            'XRE',
            'Fundos RINET',
        ],
        'YDD' => [
            'YDD',
            'Dinar iemenita',
        ],
        'YER' => [
            'YER',
            'Rial iemenita',
        ],
        'YUD' => [
            'YUD',
            'Dinar forte iugoslavo (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'Dinar noviy iugoslavo (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'Dinar conversível iugoslavo (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'Dinar reformado iugoslavo (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'Rand sul-africano (financeiro)',
        ],
        'ZAR' => [
            'ZAR',
            'Rand sul-africano',
        ],
        'ZMK' => [
            'ZMK',
            'Cuacha zambiano (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Kwacha zambiano',
        ],
        'ZRN' => [
            'ZRN',
            'Zaire Novo zairense (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'Zaire zairense (1971–1993)',
        ],
        'ZWD' => [
            'ZWD',
            'Dólar do Zimbábue (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'Ouro zimbabueano',
        ],
        'ZWL' => [
            'ZWL',
            'Dólar do Zimbábue (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'Dólar do Zimbábue (2008)',
        ],
    ],
];
