<?php

return [
    'Names' => [
        'Arab' => 'arába',
        'Cyrl' => 'kyrillalaš',
        'Grek' => 'greikkalaš',
        'Hang' => 'hangul',
        'Hani' => 'kiinnaš',
        'Hans' => 'álki',
        'Hant' => 'árbevirolaš',
        'Hira' => 'hiragana',
        'Kana' => 'katakana',
        'Latn' => 'láhtenaš',
        'Zxxx' => 'orrut chállojuvvot',
    ],
];
