<?php

return [
    'Names' => [
        'alt' => 'sør-altaj',
        'ang' => 'gammalengelsk',
        'asa' => 'asu (Tanzania)',
        'bas' => 'basa',
        'bss' => 'bakossi',
        'car' => 'carib',
        'chg' => 'tsjagataisk',
        'ckb' => 'sorani',
        'crj' => 'sørleg aust-cree',
        'crl' => 'nordleg aust-cree',
        'crs' => 'seselwa (fransk-kreolsk)',
        'cu' => 'kyrkjeslavisk',
        'cv' => 'tsjuvansk',
        'den' => 'slavej',
        'dsb' => 'lågsorbisk',
        'ebu' => 'embu',
        'egy' => 'gammalegyptisk',
        'elx' => 'elamite',
        'fro' => 'gammalfransk',
        'frs' => 'austfrisisk',
        'fur' => 'friulisk',
        'gmh' => 'mellomhøgtysk',
        'goh' => 'gammalhøgtysk',
        'grc' => 'gammalgresk',
        'gv' => 'manx',
        'hax' => 'sørleg haida',
        'hsb' => 'høgsorbisk',
        'ikt' => 'vestleg kanadisk inuktitut',
        'kl' => 'grønlandsk (kalaallisut)',
        'krc' => 'karatsjaiisk-balkarsk',
        'kum' => 'kumyk',
        'lad' => 'ladino',
        'lez' => 'lezghian',
        'lrc' => 'nord-lurisk',
        'lus' => 'lushai',
        'luy' => 'olulujia',
        'mfe' => 'morisyen',
        'mg' => 'madagassisk',
        'mzn' => 'mazanderani',
        'nds' => 'lågtysk',
        'ne' => 'nepalsk',
        'niu' => 'niuisk',
        'nog' => 'nogai',
        'non' => 'gammalnorsk',
        'nqo' => 'n’ko',
        'nso' => 'nordsotho',
        'nwc' => 'klassisk newarisk',
        'ojb' => 'nordvestleg ojibwa',
        'ojw' => 'vestleg ojibwa',
        'pcm' => 'nigeriansk pidgin',
        'peo' => 'gammalpersisk',
        'pro' => 'gammalprovençalsk',
        'quc' => 'k’iche',
        'rup' => 'arumensk',
        'sc' => 'sardinsk',
        'sga' => 'gammalirsk',
        'slh' => 'sørleg lushootseed',
        'srn' => 'sranan tongo',
        'st' => 'sørsotho',
        'swb' => 'shimaore',
        'syr' => 'syrisk',
        'tce' => 'sørleg tutchone',
        'tiv' => 'tivi',
        'tkl' => 'tokelau',
        'tog' => 'tonga (Nyasa)',
        'ttm' => 'nordleg tutchone',
        'tvl' => 'tuvalu',
        'tyv' => 'tuvinisk',
        'tzm' => 'sentral-tamazight',
        'udm' => 'udmurt',
        'war' => 'waray',
        'xal' => 'kalmykisk',
        'zap' => 'zapotec',
        'zbl' => 'blissymbol',
        'zgh' => 'standard marokkansk tamazight',
    ],
    'LocalizedNames' => [
        'nds_NL' => 'lågsaksisk',
        'ro_MD' => 'moldavisk',
        'zh_Hans' => 'forenkla kinesisk',
    ],
];
