<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abxaz',
        'ace' => 'achin',
        'ada' => 'adangme',
        'ady' => 'adigey',
        'af' => 'afrikaans',
        'agq' => 'agem',
        'ain' => 'aynu',
        'ak' => 'akan',
        'ale' => 'aleut',
        'alt' => 'janubiy oltoy',
        'am' => 'amxar',
        'an' => 'aragon',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arab',
        'arn' => 'mapuche',
        'arp' => 'arapaxo',
        'ars' => 'najd arab',
        'as' => 'assam',
        'asa' => 'asu',
        'ast' => 'asturiy',
        'atj' => 'atikamek',
        'av' => 'avar',
        'awa' => 'avadxi',
        'ay' => 'aymara',
        'az' => 'ozarbayjon',
        'ba' => 'boshqird',
        'bal' => 'baluj',
        'ban' => 'bali',
        'bas' => 'basa',
        'be' => 'belarus',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'bolgar',
        'bgc' => 'harianvi',
        'bgn' => 'g‘arbiy baluj',
        'bho' => 'bxojpuri',
        'bi' => 'bislama',
        'bin' => 'bini',
        'bla' => 'siksika',
        'blo' => 'Anii',
        'bm' => 'bambara',
        'bn' => 'bengal',
        'bo' => 'tibet',
        'br' => 'breton',
        'brx' => 'bodo',
        'bs' => 'bosniy',
        'bug' => 'bugi',
        'byn' => 'blin',
        'ca' => 'katalan',
        'cay' => 'kayuga',
        'ccp' => 'chakma',
        'ce' => 'chechen',
        'ceb' => 'sebuan',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chk' => 'chukot',
        'chm' => 'mari',
        'cho' => 'choktav',
        'chp' => 'chipevyan',
        'chr' => 'cheroki',
        'chy' => 'cheyenn',
        'ckb' => 'sorani-kurd',
        'clc' => 'chilkotin',
        'co' => 'korsikan',
        'crg' => 'michif',
        'crj' => 'janubi-sharqiy kri',
        'crk' => 'tekislik kri',
        'crl' => 'shomoli-sharqiy kri',
        'crm' => 'mus kri',
        'crr' => 'karolin algonkin',
        'crs' => 'kreol (Seyshel)',
        'cs' => 'chex',
        'csw' => 'botqoq kri',
        'cu' => 'slavyan (cherkov)',
        'cv' => 'chuvash',
        'cy' => 'valliy',
        'da' => 'dan',
        'dak' => 'dakota',
        'dar' => 'dargva',
        'dav' => 'taita',
        'de' => 'nemischa',
        'dgr' => 'dogrib',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'quyi sorb',
        'dua' => 'duala',
        'dv' => 'divexi',
        'dyo' => 'diola-fogni',
        'dz' => 'dzongka',
        'dzg' => 'dazag',
        'ebu' => 'embu',
        'ee' => 'eve',
        'efi' => 'efik',
        'eka' => 'ekajuk',
        'el' => 'grek',
        'en' => 'inglizcha',
        'eo' => 'esperanto',
        'es' => 'ispancha',
        'et' => 'estoncha',
        'eu' => 'bask',
        'ewo' => 'evondo',
        'fa' => 'fors',
        'ff' => 'fula',
        'fi' => 'fincha',
        'fil' => 'filipincha',
        'fj' => 'fiji',
        'fo' => 'farercha',
        'fon' => 'fon',
        'fr' => 'fransuzcha',
        'frc' => 'kajun fransuz',
        'frr' => 'shimoliy friz',
        'fur' => 'friul',
        'fy' => 'g‘arbiy friz',
        'ga' => 'irland',
        'gaa' => 'ga',
        'gag' => 'gagauz',
        'gan' => 'gan',
        'gd' => 'shotland-gel',
        'gez' => 'geez',
        'gil' => 'gilbert',
        'gl' => 'galisiy',
        'gn' => 'guarani',
        'gor' => 'gorontalo',
        'gsw' => 'nemis (Shveytsariya)',
        'gu' => 'gujarot',
        'guz' => 'gusii',
        'gv' => 'men',
        'gwi' => 'gvichin',
        'ha' => 'xausa',
        'hai' => 'hayda',
        'haw' => 'gavaycha',
        'hax' => 'janubiy hayda',
        'he' => 'ivrit',
        'hi' => 'hind',
        'hil' => 'hiligaynon',
        'hmn' => 'xmong',
        'hr' => 'xorvat',
        'hsb' => 'yuqori sorb',
        'ht' => 'gaityan',
        'hu' => 'venger',
        'hup' => 'xupa',
        'hur' => 'halkomelem',
        'hy' => 'arman',
        'hz' => 'gerero',
        'ia' => 'interlingva',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonez',
        'ie' => 'interlingve',
        'ig' => 'igbo',
        'ii' => 'sichuan',
        'ikt' => 'sharqiy-kanada inuktitut',
        'ilo' => 'iloko',
        'inh' => 'ingush',
        'io' => 'ido',
        'is' => 'island',
        'it' => 'italyan',
        'iu' => 'inuktitut',
        'ja' => 'yapon',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jv' => 'yavan',
        'ka' => 'gruzincha',
        'kab' => 'kabil',
        'kac' => 'kachin',
        'kaj' => 'kaji',
        'kam' => 'kamba',
        'kbd' => 'kabardin',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'kabuverdianu',
        'kfo' => 'koro',
        'kgp' => 'kaingang',
        'kha' => 'kxasi',
        'khq' => 'koyra-chiini',
        'ki' => 'kikuyu',
        'kj' => 'kvanyama',
        'kk' => 'qozoqcha',
        'kkj' => 'kako',
        'kl' => 'grenland',
        'kln' => 'kalenjin',
        'km' => 'xmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'koreyscha',
        'koi' => 'komi-permyak',
        'kok' => 'konkan',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'qorachoy-bolqor',
        'krl' => 'karel',
        'kru' => 'kurux',
        'ks' => 'kashmircha',
        'ksb' => 'shambala',
        'ksf' => 'bafiya',
        'ksh' => 'kyoln',
        'ku' => 'kurdcha',
        'kum' => 'qo‘miq',
        'kv' => 'komi',
        'kw' => 'korn',
        'kwk' => 'kvakvala',
        'kxv' => 'kuvi',
        'ky' => 'qirgʻizcha',
        'la' => 'lotincha',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lb' => 'lyuksemburgcha',
        'lez' => 'lezgin',
        'lg' => 'ganda',
        'li' => 'limburg',
        'lij' => 'liguryan',
        'lil' => 'lilluet',
        'lkt' => 'lakota',
        'lmo' => 'lombard',
        'ln' => 'lingala',
        'lo' => 'laos',
        'lou' => 'luiziana kreol',
        'loz' => 'lozi',
        'lrc' => 'shimoliy luri',
        'lsm' => 'saamia',
        'lt' => 'litva',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lun' => 'lunda',
        'lus' => 'lushay',
        'luy' => 'luhya',
        'lv' => 'latishcha',
        'mad' => 'madur',
        'mag' => 'magahi',
        'mai' => 'maythili',
        'mak' => 'makasar',
        'mas' => 'masay',
        'mdf' => 'moksha',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisyen',
        'mg' => 'malagasiy',
        'mgh' => 'maxuva-mitto',
        'mgo' => 'meta',
        'mh' => 'marshall',
        'mi' => 'maori',
        'mic' => 'mikmak',
        'min' => 'minangkabau',
        'mk' => 'makedon',
        'ml' => 'malayalam',
        'mn' => 'mongol',
        'mni' => 'manipur',
        'moe' => 'innu-aymun',
        'moh' => 'mohauk',
        'mos' => 'mossi',
        'mr' => 'maratxi',
        'ms' => 'malay',
        'mt' => 'maltiy',
        'mua' => 'mundang',
        'mus' => 'krik',
        'mwl' => 'miranda',
        'my' => 'birman',
        'myv' => 'erzya',
        'mzn' => 'mozandaron',
        'na' => 'nauru',
        'nap' => 'neapolitan',
        'naq' => 'nama',
        'nb' => 'norveg-bokmal',
        'nd' => 'shimoliy ndebele',
        'nds' => 'quyi nemis',
        'ne' => 'nepal',
        'new' => 'nevar',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niue',
        'nl' => 'niderland',
        'nmg' => 'kvasio',
        'nn' => 'norveg-nyunorsk',
        'nnh' => 'ngiyembun',
        'no' => 'norveg',
        'nog' => 'no‘g‘ay',
        'nqo' => 'nko',
        'nr' => 'janubiy ndebel',
        'nso' => 'shimoliy soto',
        'nus' => 'nuer',
        'nv' => 'navaxo',
        'ny' => 'cheva',
        'nyn' => 'nyankole',
        'oc' => 'oksitan',
        'ojb' => 'shimoli-gʻarbiy ojibva',
        'ojc' => 'markaziy ijibve',
        'ojs' => 'oji-kri',
        'ojw' => 'gʻarbiy ojibva',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'oriya',
        'os' => 'osetin',
        'pa' => 'panjobcha',
        'pag' => 'pangasinan',
        'pam' => 'pampanga',
        'pap' => 'papiyamento',
        'pau' => 'palau',
        'pcm' => 'kreol (Nigeriya)',
        'pis' => 'pijin',
        'pl' => 'polyakcha',
        'pqm' => 'maliset-passamakvoddi',
        'prg' => 'pruss',
        'ps' => 'pushtu',
        'pt' => 'portugalcha',
        'qu' => 'kechua',
        'quc' => 'kiche',
        'raj' => 'rajastani',
        'rap' => 'rapanui',
        'rar' => 'rarotongan',
        'rhg' => 'rohinja',
        'rm' => 'romansh',
        'rn' => 'rundi',
        'ro' => 'rumincha',
        'rof' => 'rombo',
        'ru' => 'ruscha',
        'rup' => 'arumin',
        'rw' => 'kinyaruanda',
        'rwk' => 'ruanda',
        'sa' => 'sanskrit',
        'sad' => 'sandave',
        'sah' => 'saxa',
        'saq' => 'samburu',
        'sat' => 'santali',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardin',
        'scn' => 'sitsiliya',
        'sco' => 'shotland',
        'sd' => 'sindhi',
        'sdh' => 'janubiy kurd',
        'se' => 'shimoliy saam',
        'seh' => 'sena',
        'ses' => 'koyraboro-senni',
        'sg' => 'sango',
        'shi' => 'tashelxit',
        'shn' => 'shan',
        'si' => 'singal',
        'sk' => 'slovakcha',
        'sl' => 'slovencha',
        'slh' => 'janubiy lushutsid',
        'sm' => 'samoa',
        'sma' => 'janubiy saam',
        'smj' => 'lule-saam',
        'smn' => 'inari-saam',
        'sms' => 'skolt-saam',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somalicha',
        'sq' => 'alban',
        'sr' => 'serbcha',
        'srn' => 'sranan-tongo',
        'ss' => 'svati',
        'ssy' => 'saho',
        'st' => 'janubiy soto',
        'str' => 'streyts salish',
        'su' => 'sundan',
        'suk' => 'sukuma',
        'sv' => 'shved',
        'sw' => 'suaxili',
        'swb' => 'qamar',
        'syr' => 'suryoniy',
        'szl' => 'silez',
        'ta' => 'tamil',
        'tce' => 'janubiy tutchone',
        'te' => 'telugu',
        'tem' => 'timne',
        'teo' => 'teso',
        'tet' => 'tetum',
        'tg' => 'tojik',
        'tgx' => 'tagish',
        'th' => 'tay',
        'tht' => 'taltan',
        'ti' => 'tigrinya',
        'tig' => 'tigre',
        'tk' => 'turkman',
        'tlh' => 'klingon',
        'tli' => 'tlingit',
        'tn' => 'tsvana',
        'to' => 'tongan',
        'tok' => 'tokipona',
        'tpi' => 'tok-piksin',
        'tr' => 'turk',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tt' => 'tatar',
        'ttm' => 'shimoliy tutchone',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'twq' => 'tasavak',
        'ty' => 'taiti',
        'tyv' => 'tuva',
        'tzm' => 'markaziy atlas tamazigxt',
        'udm' => 'udmurt',
        'ug' => 'uyg‘ur',
        'uk' => 'ukrain',
        'umb' => 'umbundu',
        'ur' => 'urdu',
        'uz' => 'o‘zbek',
        've' => 'venda',
        'vec' => 'venet',
        'vi' => 'vyetnam',
        'vmw' => 'makua',
        'vo' => 'volapyuk',
        'vun' => 'vunjo',
        'wa' => 'vallon',
        'wae' => 'valis',
        'wal' => 'volamo',
        'war' => 'varay',
        'wbp' => 'valbiri',
        'wo' => 'volof',
        'wuu' => 'vu xitoy',
        'xal' => 'qalmoq',
        'xh' => 'kxosa',
        'xnr' => 'kangri',
        'xog' => 'soga',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'idish',
        'yo' => 'yoruba',
        'yrl' => 'nyengatu',
        'yue' => 'kanton',
        'za' => 'Chjuan',
        'zgh' => 'tamazigxt',
        'zh' => 'xitoy',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'standart arab',
        'de_AT' => 'nemis (Avstriya)',
        'de_CH' => 'yuqori nemis (Shveytsariya)',
        'en_AU' => 'ingliz (Avstraliya)',
        'en_CA' => 'ingliz (Kanada)',
        'en_GB' => 'ingliz (Britaniya)',
        'en_US' => 'ingliz (Amerika)',
        'es_419' => 'ispan (Lotin Amerikasi)',
        'es_ES' => 'ispan (Yevropa)',
        'es_MX' => 'ispan (Meksika)',
        'fa_AF' => 'dari',
        'fr_CA' => 'fransuz (Kanada)',
        'fr_CH' => 'fransuz (Shveytsariya)',
        'nds_NL' => 'quyi sakson',
        'nl_BE' => 'flamand',
        'pt_BR' => 'portugal (Braziliya)',
        'pt_PT' => 'portugal (Yevropa)',
        'ro_MD' => 'moldovan',
        'sw_CD' => 'suaxili (Kongo)',
        'zh_Hant' => 'xitoy (an’anaviy)',
    ],
];
