<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abkhazeg',
        'ace' => 'achineg',
        'ach' => 'acoli',
        'ada' => 'adangme',
        'ady' => 'adygeieg',
        'ae' => 'avesteg',
        'aeb' => 'arabeg Tunizia',
        'af' => 'afrikaaneg',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainoueg',
        'ak' => 'akaneg',
        'akk' => 'akadeg',
        'akz' => 'alabamaeg',
        'ale' => 'aleouteg',
        'aln' => 'gegeg',
        'alt' => 'altaieg ar Su',
        'am' => 'amhareg',
        'an' => 'aragoneg',
        'ang' => 'hensaozneg',
        'ann' => 'obolo',
        'anp' => 'angika',
        'ar' => 'arabeg',
        'arc' => 'arameeg',
        'arn' => 'araoukaneg',
        'aro' => 'araona',
        'arp' => 'arapaho',
        'arq' => 'arabeg Aljeria',
        'ars' => 'arabeg nadjiek',
        'arw' => 'arawakeg',
        'ary' => 'arabeg Maroko',
        'arz' => 'arabeg Egipt',
        'as' => 'asameg',
        'asa' => 'asu',
        'ase' => 'yezh sinoù Amerika',
        'ast' => 'asturianeg',
        'atj' => 'atikamekweg',
        'av' => 'avar',
        'awa' => 'awadhi',
        'ay' => 'aymara',
        'az' => 'azerbaidjaneg',
        'ba' => 'bachkir',
        'bal' => 'baloutcheg',
        'ban' => 'balineg',
        'bar' => 'bavarieg',
        'bas' => 'basaa',
        'be' => 'belaruseg',
        'bej' => 'bedawieg',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'bulgareg',
        'bgn' => 'baloutchi ar Cʼhornôg',
        'bho' => 'bhojpureg',
        'bi' => 'bislama',
        'bik' => 'bikol',
        'bin' => 'bini',
        'bla' => 'siksika',
        'blo' => 'aniieg',
        'bm' => 'bambara',
        'bn' => 'bengaleg',
        'bo' => 'tibetaneg',
        'br' => 'brezhoneg',
        'bra' => 'braj',
        'brh' => 'brahweg',
        'brx' => 'bodo',
        'bs' => 'bosneg',
        'bss' => 'akoose',
        'bua' => 'bouriat',
        'bug' => 'bugi',
        'byn' => 'blin',
        'ca' => 'katalaneg',
        'cad' => 'caddo',
        'car' => 'karibeg',
        'cay' => 'kayougeg',
        'cch' => 'atsam',
        'ccp' => 'chakmaeg',
        'ce' => 'tchetcheneg',
        'ceb' => 'cebuanoeg',
        'cgg' => 'chigaeg',
        'ch' => 'chamorru',
        'chb' => 'chibcha',
        'chk' => 'chuuk',
        'chm' => 'marieg',
        'cho' => 'choktaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokieg',
        'chy' => 'cheyenne',
        'ckb' => 'kurdeg sorani',
        'clc' => 'chilkotineg',
        'co' => 'korseg',
        'cop' => 'kopteg',
        'cr' => 'kri',
        'crg' => 'michifeg',
        'crh' => 'turkeg Krimea',
        'crj' => 'krieg ar Gevred',
        'crk' => 'krieg ar cʼhompezennoù',
        'crl' => 'krieg ar Biz',
        'crm' => 'krieg ar cʼhornôg',
        'crr' => 'algonkeg Carolina',
        'crs' => 'kreoleg Sechelez',
        'cs' => 'tchekeg',
        'csb' => 'kachoubeg',
        'csw' => 'krieg ar gwernioù',
        'cu' => 'slavoneg iliz',
        'cv' => 'tchouvatcheg',
        'cy' => 'kembraeg',
        'da' => 'daneg',
        'dak' => 'dakota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'alamaneg',
        'del' => 'delaware',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'izelsorabeg',
        'dua' => 'douala',
        'dum' => 'nederlandeg krenn',
        'dv' => 'divehi',
        'dyo' => 'diola',
        'dyu' => 'dyula',
        'dz' => 'dzongkha',
        'dzg' => 'dazagaeg',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'egy' => 'henegipteg',
        'eka' => 'ekajuk',
        'el' => 'gresianeg',
        'elx' => 'elameg',
        'en' => 'saozneg',
        'enm' => 'krennsaozneg',
        'eo' => 'esperanteg',
        'es' => 'spagnoleg',
        'et' => 'estoneg',
        'eu' => 'euskareg',
        'ewo' => 'ewondo',
        'fa' => 'perseg',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'fulaeg',
        'fi' => 'finneg',
        'fil' => 'filipineg',
        'fit' => 'finneg traoñienn an Torne',
        'fj' => 'fidjieg',
        'fo' => 'faeroeg',
        'fon' => 'fon',
        'fr' => 'galleg',
        'frc' => 'galleg cajun',
        'frm' => 'krenncʼhalleg',
        'fro' => 'hencʼhalleg',
        'frp' => 'arpitaneg',
        'frr' => 'frizeg an Norzh',
        'frs' => 'frizeg ar Reter',
        'fur' => 'frioulaneg',
        'fy' => 'frizeg ar Cʼhornôg',
        'ga' => 'iwerzhoneg',
        'gaa' => 'gaeg',
        'gag' => 'gagaouzeg',
        'gan' => 'sinaeg Gan',
        'gay' => 'gayo',
        'gba' => 'gbaya',
        'gd' => 'skoseg',
        'gez' => 'gezeg',
        'gil' => 'gilberteg',
        'gl' => 'galizeg',
        'gmh' => 'krennalamaneg uhel',
        'gn' => 'guarani',
        'goh' => 'henalamaneg uhel',
        'gor' => 'gorontalo',
        'got' => 'goteg',
        'grb' => 'grebo',
        'grc' => 'hencʼhresianeg',
        'gsw' => 'alamaneg Suis',
        'gu' => 'gujarateg',
        'guz' => 'gusiieg',
        'gv' => 'manaveg',
        'gwi' => 'gwich’in',
        'ha' => 'haousaeg',
        'hai' => 'haideg',
        'hak' => 'sinaeg Hakka',
        'haw' => 'hawaieg',
        'hax' => 'haideg ar Su',
        'he' => 'hebraeg',
        'hi' => 'hindieg',
        'hil' => 'hiligaynon',
        'hmn' => 'hmong',
        'ho' => 'hiri motu',
        'hr' => 'kroateg',
        'hsb' => 'uhelsorabeg',
        'hsn' => 'sinaeg Xian',
        'ht' => 'haitieg',
        'hu' => 'hungareg',
        'hup' => 'hupa',
        'hur' => 'halkomelemeg',
        'hy' => 'armenianeg',
        'hz' => 'herero',
        'ia' => 'interlinguaeg',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonezeg',
        'ie' => 'interlingue',
        'ig' => 'igboeg',
        'ii' => 'yieg Sichuan',
        'ik' => 'inupiaq',
        'ikt' => 'inuktitut Kanada ar Cʼhornôg',
        'ilo' => 'ilokanoeg',
        'inh' => 'ingoucheg',
        'io' => 'ido',
        'is' => 'islandeg',
        'it' => 'italianeg',
        'iu' => 'inuktitut',
        'ja' => 'japaneg',
        'jam' => 'kreoleg Jamaika',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jpr' => 'yuzev-perseg',
        'jrb' => 'yuzev-arabeg',
        'jv' => 'javaneg',
        'ka' => 'jorjianeg',
        'kaa' => 'karakalpak',
        'kab' => 'kabileg',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kbd' => 'kabardeg',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'kabuverdianu',
        'kfo' => 'koroeg',
        'kg' => 'kongo',
        'kgp' => 'kaingangeg',
        'kha' => 'khasi',
        'kho' => 'khotaneg',
        'khq' => 'koyra chiini',
        'ki' => 'kikuyu',
        'kj' => 'kwanyama',
        'kk' => 'kazakeg',
        'kkj' => 'kakoeg',
        'kl' => 'greunlandeg',
        'kln' => 'kalendjineg',
        'km' => 'khmereg',
        'kmb' => 'kimbundu',
        'kn' => 'kanareg',
        'ko' => 'koreaneg',
        'kok' => 'konkani',
        'kos' => 'kosrae',
        'kpe' => 'kpelle',
        'kr' => 'kanouri',
        'krc' => 'karatchay-balkar',
        'kri' => 'krio',
        'krl' => 'karelieg',
        'kru' => 'kurukh',
        'ks' => 'kashmireg',
        'ksb' => 'shambala',
        'ksf' => 'bafiaeg',
        'ksh' => 'koluneg',
        'ku' => 'kurdeg',
        'kum' => 'koumikeg',
        'kut' => 'kutenai',
        'kv' => 'komieg',
        'kw' => 'kerneveureg',
        'kwk' => 'kwakwaleg',
        'ky' => 'kirgizeg',
        'la' => 'latin',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lam' => 'lamba',
        'lb' => 'luksembourgeg',
        'lez' => 'lezgi',
        'lfn' => 'lingua franca nova',
        'lg' => 'ganda',
        'li' => 'limbourgeg',
        'lij' => 'ligurieg',
        'lil' => 'lillooet',
        'lkt' => 'lakota',
        'ln' => 'lingala',
        'lo' => 'laoseg',
        'lol' => 'mongo',
        'lou' => 'kreoleg Louiziana',
        'loz' => 'lozi',
        'lrc' => 'loureg an Norzh',
        'lt' => 'lituaneg',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lui' => 'luiseno',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'lushai',
        'luy' => 'luyia',
        'lv' => 'latvieg',
        'lzh' => 'sinaeg lennegel',
        'mad' => 'madoureg',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makasar',
        'mas' => 'masai',
        'mdf' => 'moksha',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'moriseg',
        'mg' => 'malgacheg',
        'mga' => 'krenniwerzhoneg',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'metaʼ',
        'mh' => 'marshall',
        'mi' => 'maori',
        'mic' => 'mikmakeg',
        'min' => 'minangkabau',
        'mk' => 'makedoneg',
        'ml' => 'malayalameg',
        'mn' => 'mongoleg',
        'mnc' => 'manchou',
        'mni' => 'manipuri',
        'moe' => 'montagneg',
        'moh' => 'mohawk',
        'mos' => 'more',
        'mr' => 'maratheg',
        'mrj' => 'marieg ar Cʼhornôg',
        'ms' => 'malayseg',
        'mt' => 'malteg',
        'mua' => 'moundangeg',
        'mus' => 'muskogi',
        'mwl' => 'mirandeg',
        'my' => 'birmaneg',
        'myv' => 'erza',
        'mzn' => 'mazanderaneg',
        'na' => 'naurueg',
        'nan' => 'sinaeg Min Nan',
        'nap' => 'napolitaneg',
        'naq' => 'nama',
        'nb' => 'norvegeg bokmål',
        'nd' => 'ndebele an Norzh',
        'nds' => 'alamaneg izel',
        'ne' => 'nepaleg',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niue',
        'njo' => 'aoeg',
        'nl' => 'nederlandeg',
        'nmg' => 'ngoumbeg',
        'nn' => 'norvegeg nynorsk',
        'nnh' => 'ngiemboon',
        'no' => 'norvegeg',
        'nog' => 'nogay',
        'non' => 'hennorseg',
        'nov' => 'novial',
        'nqo' => 'nkoeg',
        'nr' => 'ndebele ar Su',
        'nso' => 'sothoeg an Norzh',
        'nus' => 'nouereg',
        'nv' => 'navacʼho',
        'nwc' => 'newari klasel',
        'ny' => 'nyanja',
        'nym' => 'nyamwezi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoro',
        'oc' => 'okitaneg',
        'oj' => 'ojibweg',
        'ojb' => 'ojibweg ar Gwalarn',
        'ojc' => 'ojibweg ar cʼhreiz',
        'ojs' => 'ojibweg Severn',
        'ojw' => 'ojibweg ar Cʼhornôg',
        'oka' => 'okanaganeg',
        'om' => 'oromoeg',
        'or' => 'oriyaeg',
        'os' => 'oseteg',
        'osa' => 'osage',
        'ota' => 'turkeg otoman',
        'pa' => 'punjabeg',
        'pag' => 'pangasinan',
        'pal' => 'pahlavi',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palau',
        'pcd' => 'pikardeg',
        'pcm' => 'pidjin Nigeria',
        'pdc' => 'alamaneg Pennsylvania',
        'peo' => 'henberseg',
        'phn' => 'fenikianeg',
        'pi' => 'pali',
        'pis' => 'pidjin',
        'pl' => 'poloneg',
        'pms' => 'piemonteg',
        'pnt' => 'ponteg',
        'pon' => 'pohnpei',
        'pqm' => 'malisiteg-pasamawkodieg',
        'prg' => 'henbruseg',
        'pro' => 'henbrovañseg',
        'ps' => 'pachtoeg',
        'pt' => 'portugaleg',
        'qu' => 'kechuaeg',
        'quc' => 'kʼicheʼ',
        'qug' => 'kichuaeg Chimborazo',
        'raj' => 'rajasthaneg',
        'rap' => 'rapanui',
        'rar' => 'rarotonga',
        'rgn' => 'romagnoleg',
        'rhg' => 'rohingya',
        'rm' => 'romañcheg',
        'rn' => 'rundi',
        'ro' => 'roumaneg',
        'rof' => 'rombo',
        'rom' => 'romanieg',
        'ru' => 'rusianeg',
        'rup' => 'aroumaneg',
        'rw' => 'kinyarwanda',
        'rwk' => 'rwa',
        'sa' => 'sanskriteg',
        'sad' => 'sandawe',
        'sah' => 'yakouteg',
        'sam' => 'arameeg ar Samaritaned',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santali',
        'sba' => 'ngambayeg',
        'sbp' => 'sangu',
        'sc' => 'sardeg',
        'scn' => 'sikilieg',
        'sco' => 'skoteg',
        'sd' => 'sindhi',
        'sdc' => 'sasareseg',
        'se' => 'sámi an Norzh',
        'seh' => 'sena',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sga' => 'heniwerzhoneg',
        'sh' => 'serb-kroateg',
        'shi' => 'tacheliteg',
        'shn' => 'shan',
        'shu' => 'arabeg Tchad',
        'si' => 'singhaleg',
        'sid' => 'sidamo',
        'sk' => 'slovakeg',
        'sl' => 'sloveneg',
        'slh' => 'luchoutsideg ar Su',
        'sm' => 'samoan',
        'sma' => 'sámi ar Su',
        'smj' => 'sámi Luleå',
        'smn' => 'sámi Inari',
        'sms' => 'sámi Skolt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somalieg',
        'sog' => 'sogdieg',
        'sq' => 'albaneg',
        'sr' => 'serbeg',
        'srn' => 'sranan tongo',
        'srr' => 'serer',
        'ss' => 'swati',
        'ssy' => 'sahoeg',
        'st' => 'sothoeg ar Su',
        'su' => 'sundaneg',
        'suk' => 'sukuma',
        'sux' => 'sumereg',
        'sv' => 'svedeg',
        'sw' => 'swahilieg',
        'swb' => 'komoreg',
        'syc' => 'sirieg klasel',
        'syr' => 'sirieg',
        'szl' => 'silezieg',
        'ta' => 'tamileg',
        'tce' => 'tutchoneg ar Su',
        'tcy' => 'touloueg',
        'te' => 'telougou',
        'tem' => 'temne',
        'teo' => 'tesoeg',
        'ter' => 'tereno',
        'tet' => 'tetum',
        'tg' => 'tadjikeg',
        'th' => 'thaieg',
        'ti' => 'tigrignaeg',
        'tig' => 'tigreaneg',
        'tiv' => 'tiv',
        'tk' => 'turkmeneg',
        'tkl' => 'tokelau',
        'tl' => 'tagalog',
        'tlh' => 'klingon',
        'tli' => 'tinglit',
        'tmh' => 'tamacheg',
        'tn' => 'tswanaeg',
        'to' => 'tongaeg',
        'tog' => 'nyasa tonga',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turkeg',
        'tru' => 'turoyoeg',
        'trv' => 'taroko',
        'ts' => 'tsonga',
        'tsi' => 'tsimshian',
        'tt' => 'tatareg',
        'ttm' => 'tutchoneg an Norzh',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'tw' => 'twi',
        'twq' => 'tasawakeg',
        'ty' => 'tahitianeg',
        'tyv' => 'touva',
        'tzm' => 'tamazigteg Kreizatlas',
        'udm' => 'oudmourteg',
        'ug' => 'ouigoureg',
        'uga' => 'ougariteg',
        'uk' => 'ukraineg',
        'umb' => 'umbundu',
        'ur' => 'ourdoueg',
        'uz' => 'ouzbekeg',
        'vai' => 'vai',
        've' => 'venda',
        'vec' => 'venezieg',
        'vep' => 'vepseg',
        'vi' => 'vietnameg',
        'vls' => 'flandrezeg ar c’hornôg',
        'vo' => 'volapük',
        'vot' => 'votyakeg',
        'vro' => 'voroeg',
        'vun' => 'vunjo',
        'wa' => 'walloneg',
        'wae' => 'walser',
        'wal' => 'walamo',
        'war' => 'waray',
        'was' => 'washo',
        'wo' => 'wolofeg',
        'wuu' => 'sinaeg Wu',
        'xal' => 'kalmouk',
        'xh' => 'xhosaeg',
        'xmf' => 'megreleg',
        'xog' => 'sogaeg',
        'yao' => 'yao',
        'yap' => 'yapeg',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'yiddish',
        'yo' => 'yoroubaeg',
        'yrl' => 'nengatoueg',
        'yue' => 'kantoneg',
        'za' => 'zhuang',
        'zap' => 'zapoteg',
        'zbl' => 'arouezioù Bliss',
        'zea' => 'zelandeg',
        'zen' => 'zenaga',
        'zgh' => 'tamacheg Maroko standart',
        'zh' => 'sinaeg',
        'zu' => 'zouloueg',
        'zun' => 'zuni',
        'zza' => 'zazakeg',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabeg modern',
        'de_AT' => 'alamaneg Aostria',
        'de_CH' => 'alamaneg uhel Suis',
        'en_AU' => 'saozneg Aostralia',
        'en_CA' => 'saozneg Kanada',
        'en_GB' => 'saozneg Breizh-Veur',
        'en_US' => 'saozneg Amerika',
        'es_419' => 'spagnoleg Amerika latin',
        'es_ES' => 'spagnoleg Europa',
        'es_MX' => 'spagnoleg Mecʼhiko',
        'fa_AF' => 'dareg',
        'fr_CA' => 'galleg Kanada',
        'fr_CH' => 'galleg Suis',
        'hi_Latn' => 'hindieg (latin)',
        'nds_NL' => 'saksoneg izel',
        'nl_BE' => 'flandrezeg',
        'pt_BR' => 'portugaleg Brazil',
        'pt_PT' => 'portugaleg Europa',
        'ro_MD' => 'moldoveg',
        'sw_CD' => 'swahili Kongo',
        'zh_Hans' => 'sinaeg eeunaet',
        'zh_Hant' => 'sinaeg hengounel',
    ],
];
