<?php

return [
    'Names' => [
        'CRC' => [
            'CRC',
            'کوسٹا ریکا کولون',
        ],
        'CUC' => [
            'CUC',
            'قابل منتقلی کیوبائی پیسو',
        ],
        'CUP' => [
            'CUP',
            'کیوبائی پیسو',
        ],
        'CVE' => [
            'CVE',
            'کیپ ورڈی اسکیوڈو',
        ],
        'GBP' => [
            '£',
            'برطانوی پاونڈ سٹرلنگ',
        ],
        'GHS' => [
            'GHS',
            'گھانی سیڈی',
        ],
        'PKR' => [
            'PKR',
            'پاکستانی روپیہ',
        ],
        'WST' => [
            'WST',
            'ساموآئی ٹالا',
        ],
    ],
];
