<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich Mean Time (Abidjan)',
        'Africa/Accra' => 'Greenwich Mean Time (Accra)',
        'Africa/Bamako' => 'Greenwich Mean Time (Bamako)',
        'Africa/Banjul' => 'Greenwich Mean Time (Banjul)',
        'Africa/Bissau' => 'Greenwich Mean Time (Bissau)',
        'Africa/Conakry' => 'Greenwich Mean Time (Conakry)',
        'Africa/Dakar' => 'Greenwich Mean Time (Dakar)',
        'Africa/Freetown' => 'Greenwich Mean Time (Freetown)',
        'Africa/Kigali' => 'U Rwanda (Kigali)',
        'Africa/Lome' => 'Greenwich Mean Time (Lomé)',
        'Africa/Monrovia' => 'Greenwich Mean Time (Monrovia)',
        'Africa/Nouakchott' => 'Greenwich Mean Time (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich Mean Time (Ouagadougou)',
        'Africa/Sao_Tome' => 'Greenwich Mean Time (São Tomé)',
        'America/Danmarkshavn' => 'Greenwich Mean Time (Danmarkshavn)',
        'Antarctica/Troll' => 'Greenwich Mean Time (Troll)',
        'Atlantic/Reykjavik' => 'Greenwich Mean Time (Reykjavik)',
        'Atlantic/St_Helena' => 'Greenwich Mean Time (St. Helena)',
        'Etc/GMT' => 'Greenwich Mean Time',
        'Europe/Dublin' => 'Greenwich Mean Time (Dublin)',
        'Europe/Guernsey' => 'Greenwich Mean Time (Guernsey)',
        'Europe/Isle_of_Man' => 'Greenwich Mean Time (Isle of Man)',
        'Europe/Jersey' => 'Greenwich Mean Time (Jersey)',
        'Europe/London' => 'Greenwich Mean Time (London)',
        'Europe/Skopje' => 'Masedoniya y’Amajyaruguru (Skopje)',
        'Pacific/Tongatapu' => 'Tonga (Tongatapu)',
    ],
    'Meta' => [],
];
