<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'témpore medial de Greenwich (Abidjan)',
        'Africa/Accra' => 'témpore medial de Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'témpor de Etiopia (Addis Ababa)',
        'Africa/Asmera' => 'témpor de Eritrea (Asmara)',
        'Africa/Asmara' => 'témpor de Eritrea (Asmara)',
        'Africa/Bamako' => 'témpore medial de Greenwich (Bamako)',
        'Africa/Banjul' => 'témpore medial de Greenwich (Banjul)',
        'Africa/Bissau' => 'témpore medial de Greenwich (Bissau)',
        'Africa/Ceuta' => 'témpor de Hispania (Ceuta)',
        'Africa/Conakry' => 'témpore medial de Greenwich (Conakry)',
        'Africa/Dakar' => 'témpore medial de Greenwich (Dakar)',
        'Africa/Freetown' => 'témpore medial de Greenwich (Freetown)',
        'Africa/Lome' => 'témpore medial de Greenwich (Lomé)',
        'Africa/Monrovia' => 'témpore medial de Greenwich (Monrovia)',
        'Africa/Ndjamena' => 'témpor de Tchad (N’Djamena)',
        'Africa/Nouakchott' => 'témpore medial de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'témpore medial de Greenwich (Ouagadougou)',
        'Africa/Sao_Tome' => 'témpore medial de Greenwich (São Tomé)',
        'America/Danmarkshavn' => 'témpore medial de Greenwich (Danmarkshavn)',
        'America/Grand_Turk' => 'témpor de Turks e Caicos (Grand Turk)',
        'America/Guyana' => 'témpor de Guyana (Guyana)',
        'America/Lima' => 'témpor de Perú (Lima)',
        'America/Lower_Princes' => 'témpor de Sint-Maarten (Lower Prince’s Quarter)',
        'America/Martinique' => 'témpor de Martinica (Martinique)',
        'America/Port_of_Spain' => 'témpor de Trinidad e Tobago (Port of Spain)',
        'America/Puerto_Rico' => 'témpor de Porto-Rico (Puerto Rico)',
        'Antarctica/Casey' => 'témpor de Antarctica (Casey)',
        'Antarctica/Davis' => 'témpor de Antarctica (Davis)',
        'Antarctica/DumontDUrville' => 'témpor de Antarctica (Dumont-d’Urville)',
        'Antarctica/Mawson' => 'témpor de Antarctica (Mawson)',
        'Antarctica/McMurdo' => 'témpor de Antarctica (McMurdo)',
        'Antarctica/Palmer' => 'témpor de Antarctica (Palmer)',
        'Antarctica/Rothera' => 'témpor de Antarctica (Rothera)',
        'Antarctica/Syowa' => 'témpor de Antarctica (Showa)',
        'Antarctica/Troll' => 'témpore medial de Greenwich (Troll)',
        'Antarctica/Vostok' => 'témpor de Antarctica (Vostok)',
        'Arctic/Longyearbyen' => 'témpor de Svalbard e Jan Mayen (Longyearbyen)',
        'Asia/Anadyr' => 'témpor de Russia (Anadyr)',
        'Asia/Barnaul' => 'témpor de Russia (Barnaul)',
        'Asia/Calcutta' => 'témpor de India (Kolkata)',
        'Asia/Kolkata' => 'témpor de India (Kolkata)',
        'Asia/Chita' => 'témpor de Russia (Chita)',
        'Asia/Colombo' => 'témpor de Sri-Lanka (Colombo)',
        'Asia/Dili' => 'témpor de Ost-Timor (Dili)',
        'Asia/Irkutsk' => 'témpor de Russia (Irkutsk)',
        'Asia/Jakarta' => 'témpor de Indonesia (Jakarta)',
        'Asia/Jayapura' => 'témpor de Indonesia (Jayapura)',
        'Asia/Kamchatka' => 'témpor de Russia (Kamchatka)',
        'Asia/Karachi' => 'témpor de Pakistan (Karachi)',
        'Asia/Khandyga' => 'témpor de Russia (Khandyga)',
        'Asia/Krasnoyarsk' => 'témpor de Russia (Krasnoyarsk)',
        'Asia/Magadan' => 'témpor de Russia (Magadan)',
        'Asia/Makassar' => 'témpor de Indonesia (Makassar)',
        'Asia/Manila' => 'témpor de Filipines (Manila)',
        'Asia/Novokuznetsk' => 'témpor de Russia (Novokuznetsk)',
        'Asia/Novosibirsk' => 'témpor de Russia (Novosibirsk)',
        'Asia/Omsk' => 'témpor de Russia (Omsk)',
        'Asia/Phnom_Penh' => 'témpor de Cambodja (Phnom Penh)',
        'Asia/Pontianak' => 'témpor de Indonesia (Pontianak)',
        'Asia/Sakhalin' => 'témpor de Russia (Sakhalin)',
        'Asia/Srednekolymsk' => 'témpor de Russia (Srednekolymsk)',
        'Asia/Tehran' => 'témpor de Iran (Tehran)',
        'Asia/Tomsk' => 'témpor de Russia (Tomsk)',
        'Asia/Ust-Nera' => 'témpor de Russia (Ust-Nera)',
        'Asia/Vladivostok' => 'témpor de Russia (Vladivostok)',
        'Asia/Yakutsk' => 'témpor de Russia (Yakutsk)',
        'Asia/Yekaterinburg' => 'témpor de Russia (Yekaterinburg)',
        'Atlantic/Azores' => 'témpor de Portugal (Azores)',
        'Atlantic/Canary' => 'témpor de Hispania (Canarias)',
        'Atlantic/Madeira' => 'témpor de Portugal (Madeira)',
        'Atlantic/Reykjavik' => 'témpore medial de Greenwich (Reykjavik)',
        'Atlantic/St_Helena' => 'témpore medial de Greenwich (St. Helena)',
        'Etc/GMT' => 'témpore medial de Greenwich',
        'Europe/Amsterdam' => 'témpor de Nederland (Amsterdam)',
        'Europe/Andorra' => 'témpor de Andorra (Andorra)',
        'Europe/Astrakhan' => 'témpor de Russia (Astrakhan)',
        'Europe/Athens' => 'témpor de Grecia (Athens)',
        'Europe/Belgrade' => 'témpor de Serbia (Belgrade)',
        'Europe/Berlin' => 'témpor de Germania (Berlin)',
        'Europe/Bratislava' => 'témpor de Slovakia (Bratislava)',
        'Europe/Brussels' => 'témpor de Belgia (Brussels)',
        'Europe/Bucharest' => 'témpor de Rumania (Bucharest)',
        'Europe/Budapest' => 'témpor de Hungaria (Budapest)',
        'Europe/Busingen' => 'témpor de Germania (Büsingen)',
        'Europe/Chisinau' => 'témpor de Moldova (Chișinău)',
        'Europe/Copenhagen' => 'témpor de Dania (Copenhagen)',
        'Europe/Dublin' => 'témpore medial de Greenwich (Dublin)',
        'Europe/Gibraltar' => 'témpor de Gibraltar (Gibraltar)',
        'Europe/Guernsey' => 'témpore medial de Greenwich (Guernsey)',
        'Europe/Helsinki' => 'témpor de Finland (Helsinki)',
        'Europe/Isle_of_Man' => 'témpore medial de Greenwich (Insul de Man)',
        'Europe/Jersey' => 'témpore medial de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'témpor de Russia (Kaliningrad)',
        'Europe/Kiev' => 'témpor de Ukraina (Kyiv)',
        'Europe/Kyiv' => 'témpor de Ukraina (Kyiv)',
        'Europe/Kirov' => 'témpor de Russia (Kirov)',
        'Europe/Lisbon' => 'témpor de Portugal (Lisbon)',
        'Europe/Ljubljana' => 'témpor de Slovenia (Ljubljana)',
        'Europe/London' => 'témpore medial de Greenwich (London)',
        'Europe/Luxembourg' => 'témpor de Luxemburg (Luxembourg)',
        'Europe/Madrid' => 'témpor de Hispania (Madrid)',
        'Europe/Malta' => 'témpor de Malta (Malta)',
        'Europe/Mariehamn' => 'témpor de Insules Åland (Mariehamn)',
        'Europe/Minsk' => 'témpor de Bielorussia (Minsk)',
        'Europe/Monaco' => 'témpor de Mónaco (Monaco)',
        'Europe/Moscow' => 'témpor de Russia (Moscow)',
        'Europe/Oslo' => 'témpor de Norvegia (Oslo)',
        'Europe/Paris' => 'témpor de Francia (Paris)',
        'Europe/Podgorica' => 'témpor de Montenegro (Podgorica)',
        'Europe/Prague' => 'témpor de Tchekia (Prague)',
        'Europe/Riga' => 'témpor de Lettonia (Riga)',
        'Europe/Rome' => 'témpor de Italia (Rome)',
        'Europe/Samara' => 'témpor de Russia (Samara)',
        'Europe/San_Marino' => 'témpor de San-Marino (San Marino)',
        'Europe/Sarajevo' => 'témpor de Bosnia e Herzegovina (Sarajevo)',
        'Europe/Saratov' => 'témpor de Russia (Saratov)',
        'Europe/Simferopol' => 'témpor de Ukraina (Simferopol)',
        'Europe/Skopje' => 'témpor de Nord-Macedonia (Skopje)',
        'Europe/Sofia' => 'témpor de Bulgaria (Sofia)',
        'Europe/Stockholm' => 'témpor de Svedia (Stockholm)',
        'Europe/Tallinn' => 'témpor de Estonia (Tallinn)',
        'Europe/Tirane' => 'témpor de Albania (Tirana)',
        'Europe/Ulyanovsk' => 'témpor de Russia (Ulyanovsk)',
        'Europe/Vaduz' => 'témpor de Liechtenstein (Vaduz)',
        'Europe/Vatican' => 'témpor de Cité de Vatican (Vatican)',
        'Europe/Vienna' => 'témpor de Austria (Vienna)',
        'Europe/Vilnius' => 'témpor de Lituania (Vilnius)',
        'Europe/Volgograd' => 'témpor de Russia (Volgograd)',
        'Europe/Warsaw' => 'témpor de Polonia (Warsaw)',
        'Europe/Zagreb' => 'témpor de Croatia (Zagreb)',
        'Europe/Zurich' => 'témpor de Svissia (Zurich)',
        'Indian/Maldives' => 'témpor de Maldivas (Maldives)',
        'Indian/Mauritius' => 'témpor de Mauricio (Mauritius)',
        'Pacific/Apia' => 'témpor de Samoa (Apia)',
        'Pacific/Auckland' => 'témpor de Nov-Zeland (Auckland)',
        'Pacific/Chatham' => 'témpor de Nov-Zeland (Chatham)',
        'Pacific/Efate' => 'témpor de Vanuatu (Efate)',
        'Pacific/Fakaofo' => 'témpor de Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'témpor de Fidji (Fiji)',
        'Pacific/Funafuti' => 'témpor de Tuvalu (Funafuti)',
        'Pacific/Nauru' => 'témpor de Nauru (Nauru)',
        'Pacific/Norfolk' => 'témpor de Insul Norfolk (Norfolk)',
        'Pacific/Palau' => 'témpor de Palau (Palau)',
        'Pacific/Rarotonga' => 'témpor del Insules Cook (Rarotonga)',
    ],
    'Meta' => [
        'GmtFormat' => 'TMG%s',
    ],
];
