<?php

return [
    'UserAssignedNames' => [],
    'Names' => [
        'AD' => 'Andora',
        'AE' => 'United Arab Emirates',
        'AF' => 'Afghanistan',
        'AG' => 'Antigua le Barbuda',
        'AI' => 'Anguilla',
        'AL' => 'Albania',
        'AM' => 'Armenia',
        'AO' => 'Angola',
        'AR' => 'Ajentina',
        'AS' => 'Samoa ye Amelika',
        'AT' => 'Austria',
        'AU' => 'Australia',
        'AW' => 'Arubha',
        'AZ' => 'Azerbaijan',
        'BA' => 'Bhosnia le Herzegovina',
        'BB' => 'Bhabhadosi',
        'BD' => 'Bhangiladeshi',
        'BE' => 'Bhelgium',
        'BF' => 'Bhukina Faso',
        'BG' => 'Bhulgariya',
        'BH' => 'Bhahareni',
        'BI' => 'Bhurundi',
        'BJ' => 'Bhenini',
        'BM' => 'Bhemuda',
        'BN' => 'Brunei',
        'BO' => 'Bholiviya',
        'BR' => 'Brazili',
        'BS' => 'Bhahamas',
        'BT' => 'Bhutani',
        'BW' => 'Botswana',
        'BY' => 'Bhelarusi',
        'BZ' => 'Bhelize',
        'CA' => 'Khanada',
        'CD' => 'Democratic Republic of the Congo',
        'CF' => 'Central African Republic',
        'CG' => 'Khongo',
        'CH' => 'Switzerland',
        'CI' => 'Ivory Coast',
        'CK' => 'Cook Islands',
        'CL' => 'Chile',
        'CM' => 'Khameruni',
        'CN' => 'China',
        'CO' => 'Kholombiya',
        'CR' => 'Khosta Rikha',
        'CU' => 'Cuba',
        'CV' => 'Cape Verde Islands',
        'CY' => 'Cyprus',
        'CZ' => 'Czech Republic',
        'DE' => 'Germany',
        'DJ' => 'Djibouti',
        'DK' => 'Denmakhi',
        'DM' => 'Dominikha',
        'DO' => 'Dominican Republic',
        'DZ' => 'Aljeriya',
        'EC' => 'Ecuador',
        'EE' => 'Estonia',
        'EG' => 'Egypt',
        'ER' => 'Eritrea',
        'ES' => 'Spain',
        'ET' => 'Ethiopia',
        'FI' => 'Finland',
        'FJ' => 'Fiji',
        'FK' => 'Falkland Islands',
        'FM' => 'Micronesia',
        'FR' => 'Furansi',
        'GA' => 'Gabhoni',
        'GB' => 'United Kingdom',
        'GD' => 'Grenada',
        'GE' => 'Georgia',
        'GF' => 'Gwiyana ye Furansi',
        'GH' => 'Ghana',
        'GI' => 'Gibraltar',
        'GL' => 'Greenland',
        'GM' => 'Gambiya',
        'GN' => 'Guinea',
        'GP' => 'Guadeloupe',
        'GQ' => 'Equatorial Guinea',
        'GR' => 'Greece',
        'GT' => 'Guatemala',
        'GU' => 'Guam',
        'GW' => 'Guinea-Bissau',
        'GY' => 'Guyana',
        'HN' => 'Honduras',
        'HR' => 'Croatia',
        'HT' => 'Hayiti',
        'HU' => 'Hungary',
        'ID' => 'Indonesiya',
        'IE' => 'Ireland',
        'IL' => 'Isuraeli',
        'IN' => 'Indiya',
        'IQ' => 'Iraki',
        'IR' => 'Iran',
        'IS' => 'Iceland',
        'IT' => 'Itali',
        'JM' => 'Jamaica',
        'JO' => 'Jodani',
        'JP' => 'Japan',
        'KE' => 'Khenya',
        'KG' => 'Kyrgyzstan',
        'KH' => 'Cambodia',
        'KI' => 'Khiribati',
        'KM' => 'Khomoro',
        'KN' => 'Saint Kitts and Nevis',
        'KP' => 'North Korea',
        'KR' => 'South Korea',
        'KW' => 'Khuweiti',
        'KY' => 'Cayman Islands',
        'KZ' => 'Kazakhstan',
        'LA' => 'Laos',
        'LB' => 'Lebhanoni',
        'LC' => 'Saint Lucia',
        'LI' => 'Liechtenstein',
        'LK' => 'Sri Lanka',
        'LR' => 'Libheriya',
        'LS' => 'Lesotho',
        'LT' => 'Lithuania',
        'LU' => 'Luxembourg',
        'LV' => 'Latvia',
        'LY' => 'Libhiya',
        'MA' => 'Morokho',
        'MC' => 'Monakho',
        'MD' => 'Moldova',
        'MG' => 'Madagaska',
        'MH' => 'Marshall Islands',
        'ML' => 'Mali',
        'MM' => 'Myanmar',
        'MN' => 'Mongolia',
        'MP' => 'Northern Mariana Islands',
        'MQ' => 'Martinique',
        'MR' => 'Mauritania',
        'MS' => 'Montserrat',
        'MT' => 'Malta',
        'MU' => 'Mauritius',
        'MV' => 'Maldives',
        'MW' => 'Malawi',
        'MX' => 'Meksikho',
        'MY' => 'Malezhiya',
        'MZ' => 'Mozambique',
        'NA' => 'Namibhiya',
        'NC' => 'New Caledonia',
        'NE' => 'Niger',
        'NF' => 'Norfolk Island',
        'NG' => 'Nigeriya',
        'NI' => 'Nicaragua',
        'NL' => 'Netherlands',
        'NO' => 'Noweyi',
        'NP' => 'Nephali',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'New Zealand',
        'OM' => 'Omani',
        'PA' => 'Panama',
        'PE' => 'Pheru',
        'PF' => 'Pholinesiya ye Fulansi',
        'PG' => 'Papua New Guinea',
        'PH' => 'Philippines',
        'PK' => 'Phakistani',
        'PL' => 'Pholandi',
        'PM' => 'Saint Pierre and Miquelon',
        'PN' => 'Pitcairn',
        'PR' => 'Puerto Rico',
        'PS' => 'Palestinian West Bank and Gaza',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'PY' => 'Paraguay',
        'QA' => 'Kathari',
        'RE' => 'Réunion',
        'RO' => 'Romania',
        'RU' => 'Rashiya',
        'RW' => 'Ruwanda',
        'SA' => 'Saudi Arabia',
        'SB' => 'Solomon Islands',
        'SC' => 'Seychelles',
        'SD' => 'Sudani',
        'SE' => 'Sweden',
        'SG' => 'Singapore',
        'SH' => 'Saint Helena',
        'SI' => 'Slovenia',
        'SK' => 'Slovakia',
        'SL' => 'Sierra Leone',
        'SM' => 'San Marino',
        'SN' => 'Senegali',
        'SO' => 'Somaliya',
        'SR' => 'Suriname',
        'ST' => 'São Tomé and Príncipe',
        'SV' => 'El Salvador',
        'SY' => 'Syria',
        'SZ' => 'Swaziland',
        'TC' => 'Turks and Caicos Islands',
        'TD' => 'Chadi',
        'TG' => 'Thogo',
        'TH' => 'Thayilandi',
        'TJ' => 'Tajikistan',
        'TK' => 'Thokelawu',
        'TL' => 'East Timor',
        'TM' => 'Turkmenistan',
        'TN' => 'Tunisiya',
        'TO' => 'Thonga',
        'TR' => 'Thekhi',
        'TT' => 'Trinidad le Tobago',
        'TV' => 'Thuvalu',
        'TW' => 'Thayiwani',
        'TZ' => 'Tanzaniya',
        'UA' => 'Yukreini',
        'UG' => 'Uganda',
        'US' => 'Amelika',
        'UY' => 'Yurugwai',
        'UZ' => 'Uzbekistan',
        'VA' => 'Vatican State',
        'VC' => 'Saint Vincent and the Grenadines',
        'VE' => 'Venezuela',
        'VG' => 'British Virgin Islands',
        'VI' => 'U.S. Virgin Islands',
        'VN' => 'Vietnam',
        'VU' => 'Vhanuatu',
        'WF' => 'Wallis and Futuna',
        'WS' => 'Samowa',
        'YE' => 'Yemeni',
        'YT' => 'Mayotte',
        'ZA' => 'Mzansi ye Afrika',
        'ZM' => 'Zambiya',
        'ZW' => 'Zimbabwe',
    ],
];
