<?php

return [
    'Names' => [
        'af' => 'افريكاانس ءتىلى',
        'af_NA' => 'افريكاانس ءتىلى (ناميبيا)',
        'af_ZA' => 'افريكاانس ءتىلى (وڭتۇستىك افريكا)',
        'ak' => 'اكان ءتىلى',
        'ak_GH' => 'اكان ءتىلى (گانا)',
        'am' => 'امحار ءتىلى',
        'am_ET' => 'امحار ءتىلى (ەفيوپيا)',
        'ar' => 'اراب ءتىلى',
        'ar_001' => 'اراب ءتىلى (الەم)',
        'ar_AE' => 'اراب ءتىلى (بىرىككەن اراب امىرلىكتەرى)',
        'ar_BH' => 'اراب ءتىلى (باحرەين)',
        'ar_DJ' => 'اراب ءتىلى (دجيبۋتي)',
        'ar_DZ' => 'اراب ءتىلى (الجىر)',
        'ar_EG' => 'اراب ءتىلى (مىسىر)',
        'ar_EH' => 'اراب ءتىلى (باتىس ساحارا)',
        'ar_ER' => 'اراب ءتىلى (ەريترەيا)',
        'ar_IL' => 'اراب ءتىلى (يزرايل)',
        'ar_IQ' => 'اراب ءتىلى (يراك)',
        'ar_JO' => 'اراب ءتىلى (يوردانيا)',
        'ar_KM' => 'اراب ءتىلى (كومور ارالدارى)',
        'ar_KW' => 'اراب ءتىلى (كۋۆەيت)',
        'ar_LB' => 'اراب ءتىلى (ليۆان)',
        'ar_LY' => 'اراب ءتىلى (ليۆيا)',
        'ar_MA' => 'اراب ءتىلى (ماروككو)',
        'ar_MR' => 'اراب ءتىلى (ماۆريتانيا)',
        'ar_OM' => 'اراب ءتىلى (ومان)',
        'ar_PS' => 'اراب ءتىلى (پالەستينا ايماقتارى)',
        'ar_QA' => 'اراب ءتىلى (كاتار)',
        'ar_SA' => 'اراب ءتىلى (ساۋد ارابياسى)',
        'ar_SD' => 'اراب ءتىلى (سۋدان)',
        'ar_SO' => 'اراب ءتىلى (سومالي)',
        'ar_SS' => 'اراب ءتىلى (وڭتۇستىك سۋدان)',
        'ar_SY' => 'اراب ءتىلى (سيريا)',
        'ar_TD' => 'اراب ءتىلى (چاد)',
        'ar_TN' => 'اراب ءتىلى (تۋنيس)',
        'ar_YE' => 'اراب ءتىلى (يەمەن)',
        'as' => 'اسسام ءتىلى',
        'as_IN' => 'اسسام ءتىلى (ءۇندىستان)',
        'az' => 'ءازىربايجان ءتىلى',
        'az_AZ' => 'ءازىربايجان ءتىلى (ءازىربايجان)',
        'az_Cyrl' => 'ءازىربايجان ءتىلى (كيريل جازۋى)',
        'az_Cyrl_AZ' => 'ءازىربايجان ءتىلى (كيريل جازۋى، ءازىربايجان)',
        'az_Latn' => 'ءازىربايجان ءتىلى (لاتىن جازۋى)',
        'az_Latn_AZ' => 'ءازىربايجان ءتىلى (لاتىن جازۋى، ءازىربايجان)',
        'ba' => 'باشقۇرت ءتىلى',
        'ba_RU' => 'باشقۇرت ءتىلى (حەسەي)',
        'be' => 'بەلارۋس ءتىلى',
        'be_BY' => 'بەلارۋس ءتىلى (بەلارۋس)',
        'bg' => 'بولگار ءتىلى',
        'bg_BG' => 'بولگار ءتىلى (بولگاريا)',
        'bm' => 'بامبارا ءتىلى',
        'bm_ML' => 'بامبارا ءتىلى (مالي)',
        'bn' => 'بەنگال ءتىلى',
        'bn_BD' => 'بەنگال ءتىلى (بانگلادەش)',
        'bn_IN' => 'بەنگال ءتىلى (ءۇندىستان)',
        'bo' => 'تيبەت ءتىلى',
        'bo_CN' => 'تيبەت ءتىلى (قىتاي)',
        'bo_IN' => 'تيبەت ءتىلى (ءۇندىستان)',
        'br' => 'برەتون ءتىلى',
        'br_FR' => 'برەتون ءتىلى (فرانسيا)',
        'bs' => 'بوسنيا ءتىلى',
        'bs_BA' => 'بوسنيا ءتىلى (بوسنيا جانە گەرتسەگوۆينا)',
        'bs_Cyrl' => 'بوسنيا ءتىلى (كيريل جازۋى)',
        'bs_Cyrl_BA' => 'بوسنيا ءتىلى (كيريل جازۋى، بوسنيا جانە گەرتسەگوۆينا)',
        'bs_Latn' => 'بوسنيا ءتىلى (لاتىن جازۋى)',
        'bs_Latn_BA' => 'بوسنيا ءتىلى (لاتىن جازۋى، بوسنيا جانە گەرتسەگوۆينا)',
        'ca' => 'كاتالان ءتىلى',
        'ca_AD' => 'كاتالان ءتىلى (اندوررا)',
        'ca_ES' => 'كاتالان ءتىلى (يسپانيا)',
        'ca_FR' => 'كاتالان ءتىلى (فرانسيا)',
        'ca_IT' => 'كاتالان ءتىلى (يتاليا)',
        'ce' => 'شەشەن ءتىلى',
        'ce_RU' => 'شەشەن ءتىلى (حەسەي)',
        'cs' => 'چەح ءتىلى',
        'cs_CZ' => 'چەح ءتىلى (چەحيا)',
        'cv' => 'چۋۆاش ءتىلى',
        'cv_RU' => 'چۋۆاش ءتىلى (حەسەي)',
        'cy' => 'ۆاللي ءتىلى',
        'cy_GB' => 'ۆاللي ءتىلى (ۇلىبريتانيا)',
        'da' => 'دات ءتىلى',
        'da_DK' => 'دات ءتىلى (دانيا)',
        'da_GL' => 'دات ءتىلى (گرەنلانديا)',
        'de' => 'نەمىس ءتىلى',
        'de_AT' => 'نەمىس ءتىلى (اۋستريا)',
        'de_BE' => 'نەمىس ءتىلى (بەلگيا)',
        'de_CH' => 'نەمىس ءتىلى (شۆەيساريا)',
        'de_DE' => 'نەمىس ءتىلى (گەرمانيا)',
        'de_IT' => 'نەمىس ءتىلى (يتاليا)',
        'de_LI' => 'نەمىس ءتىلى (ليحتەنشتەين)',
        'de_LU' => 'نەمىس ءتىلى (ليۋكسەمبۋرگ)',
        'dz' => 'جوڭكا ءتىلى',
        'dz_BT' => 'جوڭكا ءتىلى (بۋتان)',
        'ee' => 'ەۆە ءتىلى',
        'ee_GH' => 'ەۆە ءتىلى (گانا)',
        'ee_TG' => 'ەۆە ءتىلى (توگو)',
        'el' => 'گرەك ءتىلى',
        'el_CY' => 'گرەك ءتىلى (كيپر)',
        'el_GR' => 'گرەك ءتىلى (گرەكيا)',
        'en' => 'اعىلشىن ءتىلى',
        'en_001' => 'اعىلشىن ءتىلى (الەم)',
        'en_150' => 'اعىلشىن ءتىلى (ەۋروپا)',
        'en_AE' => 'اعىلشىن ءتىلى (بىرىككەن اراب امىرلىكتەرى)',
        'en_AG' => 'اعىلشىن ءتىلى (انتيگۋا جانە باربۋدا)',
        'en_AI' => 'اعىلشىن ءتىلى (انگيليا)',
        'en_AS' => 'اعىلشىن ءتىلى (امەريكالىق ساموا)',
        'en_AT' => 'اعىلشىن ءتىلى (اۋستريا)',
        'en_AU' => 'اعىلشىن ءتىلى (اۋستراليا)',
        'en_BB' => 'اعىلشىن ءتىلى (باربادوس)',
        'en_BE' => 'اعىلشىن ءتىلى (بەلگيا)',
        'en_BI' => 'اعىلشىن ءتىلى (بۋرۋندي)',
        'en_BM' => 'اعىلشىن ءتىلى (بەرمۋد ارالدارى)',
        'en_BS' => 'اعىلشىن ءتىلى (باگام ارالدارى)',
        'en_BW' => 'اعىلشىن ءتىلى (بوتسۆانا)',
        'en_BZ' => 'اعىلشىن ءتىلى (بەليز)',
        'en_CA' => 'اعىلشىن ءتىلى (كانادا)',
        'en_CC' => 'اعىلشىن ءتىلى (كوكوس [كيليڭ] ارالدارى)',
        'en_CH' => 'اعىلشىن ءتىلى (شۆەيساريا)',
        'en_CK' => 'اعىلشىن ءتىلى (كۋك ارالدارى)',
        'en_CM' => 'اعىلشىن ءتىلى (كامەرۋن)',
        'en_CX' => 'اعىلشىن ءتىلى (حريستماس ارالى)',
        'en_CY' => 'اعىلشىن ءتىلى (كيپر)',
        'en_CZ' => 'اعىلشىن ءتىلى (چەحيا)',
        'en_DE' => 'اعىلشىن ءتىلى (گەرمانيا)',
        'en_DK' => 'اعىلشىن ءتىلى (دانيا)',
        'en_DM' => 'اعىلشىن ءتىلى (دومينيكا)',
        'en_EE' => 'اعىلشىن ءتىلى (ەستونيا)',
        'en_ER' => 'اعىلشىن ءتىلى (ەريترەيا)',
        'en_ES' => 'اعىلشىن ءتىلى (يسپانيا)',
        'en_FI' => 'اعىلشىن ءتىلى (فينليانديا)',
        'en_FJ' => 'اعىلشىن ءتىلى (فيجي)',
        'en_FK' => 'اعىلشىن ءتىلى (فولكلەند ارالدارى)',
        'en_FM' => 'اعىلشىن ءتىلى (ميكرونەزيا)',
        'en_FR' => 'اعىلشىن ءتىلى (فرانسيا)',
        'en_GB' => 'اعىلشىن ءتىلى (ۇلىبريتانيا)',
        'en_GD' => 'اعىلشىن ءتىلى (گرەنادا)',
        'en_GE' => 'اعىلشىن ءتىلى (گرۋزيا)',
        'en_GG' => 'اعىلشىن ءتىلى (گەرنسي)',
        'en_GH' => 'اعىلشىن ءتىلى (گانا)',
        'en_GI' => 'اعىلشىن ءتىلى (گيبرالتار)',
        'en_GM' => 'اعىلشىن ءتىلى (گامبيا)',
        'en_GS' => 'اعىلشىن ءتىلى (وڭتۇستىك گەورگيا جانە وڭتۇستىك ساندۆيچ ارالدارى)',
        'en_GU' => 'اعىلشىن ءتىلى (گۋان)',
        'en_GY' => 'اعىلشىن ءتىلى (گايانا)',
        'en_HK' => 'اعىلشىن ءتىلى (حوڭكوڭ)',
        'en_HU' => 'اعىلشىن ءتىلى (ماجارستان)',
        'en_ID' => 'اعىلشىن ءتىلى (يندونەزيا)',
        'en_IE' => 'اعىلشىن ءتىلى (يرلانديا)',
        'en_IL' => 'اعىلشىن ءتىلى (يزرايل)',
        'en_IM' => 'اعىلشىن ءتىلى (مەن ارالى)',
        'en_IN' => 'اعىلشىن ءتىلى (ءۇندىستان)',
        'en_IO' => 'اعىلشىن ءتىلى (ءۇندى مۇحيتىنداعى بريتان ايماعى)',
        'en_IT' => 'اعىلشىن ءتىلى (يتاليا)',
        'en_JE' => 'اعىلشىن ءتىلى (جەرسي)',
        'en_JM' => 'اعىلشىن ءتىلى (يامايكا)',
        'en_JP' => 'اعىلشىن ءتىلى (جاپونيا)',
        'en_KE' => 'اعىلشىن ءتىلى (كەنيا)',
        'en_KI' => 'اعىلشىن ءتىلى (كيريباتي)',
        'en_KN' => 'اعىلشىن ءتىلى (سەنت-كيتس جانە نەۆيس)',
        'en_KY' => 'اعىلشىن ءتىلى (كايمان ارالدارى)',
        'en_LC' => 'اعىلشىن ءتىلى (سەنت-ليۋسيا)',
        'en_LR' => 'اعىلشىن ءتىلى (ليبەريا)',
        'en_LS' => 'اعىلشىن ءتىلى (لەسوتو)',
        'en_LT' => 'اعىلشىن ءتىلى (ليتۆا)',
        'en_LV' => 'اعىلشىن ءتىلى (لاتۆيا)',
        'en_MG' => 'اعىلشىن ءتىلى (ماداگاسكار)',
        'en_MH' => 'اعىلشىن ءتىلى (مارشال ارالدارى)',
        'en_MO' => 'اعىلشىن ءتىلى (ماكاو)',
        'en_MP' => 'اعىلشىن ءتىلى (سولتۇستىك ماريانا ارالدارى)',
        'en_MS' => 'اعىلشىن ءتىلى (مونتسەررات)',
        'en_MT' => 'اعىلشىن ءتىلى (مالتا)',
        'en_MU' => 'اعىلشىن ءتىلى (ماۆريكي)',
        'en_MV' => 'اعىلشىن ءتىلى (مالديۆ ارالدارى)',
        'en_MW' => 'اعىلشىن ءتىلى (مالاۆي)',
        'en_MY' => 'اعىلشىن ءتىلى (مالايزيا)',
        'en_NA' => 'اعىلشىن ءتىلى (ناميبيا)',
        'en_NF' => 'اعىلشىن ءتىلى (نورفولك ارالى)',
        'en_NG' => 'اعىلشىن ءتىلى (نيگەريا)',
        'en_NL' => 'اعىلشىن ءتىلى (نيدەرلاند)',
        'en_NO' => 'اعىلشىن ءتىلى (نورۆەگيا)',
        'en_NR' => 'اعىلشىن ءتىلى (ناۋرۋ)',
        'en_NU' => 'اعىلشىن ءتىلى (نيۋە)',
        'en_NZ' => 'اعىلشىن ءتىلى (جاڭا زەلانديا)',
        'en_PG' => 'اعىلشىن ءتىلى (پاپۋا — جاڭا گۆينەيا)',
        'en_PH' => 'اعىلشىن ءتىلى (فيليپين ارالدارى)',
        'en_PK' => 'اعىلشىن ءتىلى (پاكىستان)',
        'en_PL' => 'اعىلشىن ءتىلى (پولشا)',
        'en_PN' => 'اعىلشىن ءتىلى (پيتكەرن ارالدارى)',
        'en_PR' => 'اعىلشىن ءتىلى (پۋەرتو-ريكو)',
        'en_PT' => 'اعىلشىن ءتىلى (پورتۋگاليا)',
        'en_PW' => 'اعىلشىن ءتىلى (پالاۋ)',
        'en_RO' => 'اعىلشىن ءتىلى (رۋمىنيا)',
        'en_RW' => 'اعىلشىن ءتىلى (رۋاندا)',
        'en_SB' => 'اعىلشىن ءتىلى (سولومون ارالدارى)',
        'en_SC' => 'اعىلشىن ءتىلى (سەيشەل ارالدارى)',
        'en_SD' => 'اعىلشىن ءتىلى (سۋدان)',
        'en_SE' => 'اعىلشىن ءتىلى (شۆەسيا)',
        'en_SG' => 'اعىلشىن ءتىلى (سينگاپۋر)',
        'en_SH' => 'اعىلشىن ءتىلى (اۋليە ەلەنا ارالى)',
        'en_SI' => 'اعىلشىن ءتىلى (سلوۆەنيا)',
        'en_SK' => 'اعىلشىن ءتىلى (سلوۆاكيا)',
        'en_SL' => 'اعىلشىن ءتىلى (سەررا-لەونە)',
        'en_SS' => 'اعىلشىن ءتىلى (وڭتۇستىك سۋدان)',
        'en_SX' => 'اعىلشىن ءتىلى (سينت-مارتەن)',
        'en_SZ' => 'اعىلشىن ءتىلى (ەسۆاتيني)',
        'en_TC' => 'اعىلشىن ءتىلى (تەركس جانە كايكوس ارالدارى)',
        'en_TK' => 'اعىلشىن ءتىلى (توكەلاۋ)',
        'en_TO' => 'اعىلشىن ءتىلى (تونگا)',
        'en_TT' => 'اعىلشىن ءتىلى (ترينيداد جانە توباگو)',
        'en_TV' => 'اعىلشىن ءتىلى (تۋۆالۋ)',
        'en_TZ' => 'اعىلشىن ءتىلى (تانزانيا)',
        'en_UA' => 'اعىلشىن ءتىلى (ۋكراينا)',
        'en_UG' => 'اعىلشىن ءتىلى (ۋگاندا)',
        'en_UM' => 'اعىلشىن ءتىلى (ا ق ش-تىڭ سىرتقى كىشى ارالدارى)',
        'en_US' => 'اعىلشىن ءتىلى (امەريكا قۇراما شتاتتارى)',
        'en_VC' => 'اعىلشىن ءتىلى (سەنت-ۆينسەنت جانە گرەنادين ارالدارى)',
        'en_VG' => 'اعىلشىن ءتىلى (بريتاندىق ۆيرگين ارالدارى)',
        'en_VI' => 'اعىلشىن ءتىلى (ا ق ش-تىڭ ۆيرگين ارالدارى)',
        'en_VU' => 'اعىلشىن ءتىلى (ۆانۋاتۋ)',
        'en_WS' => 'اعىلشىن ءتىلى (ساموا)',
        'en_ZA' => 'اعىلشىن ءتىلى (وڭتۇستىك افريكا)',
        'en_ZM' => 'اعىلشىن ءتىلى (زامبيا)',
        'en_ZW' => 'اعىلشىن ءتىلى (زيمبابۆە)',
        'eo' => 'ەسپەرانتو ءتىلى',
        'eo_001' => 'ەسپەرانتو ءتىلى (الەم)',
        'es' => 'يسپان ءتىلى',
        'es_419' => 'يسپان ءتىلى (لاتىن امەريكا)',
        'es_AR' => 'يسپان ءتىلى (ارگەنتينا)',
        'es_BO' => 'يسپان ءتىلى (بوليۆيا)',
        'es_BR' => 'يسپان ءتىلى (برازيليا)',
        'es_BZ' => 'يسپان ءتىلى (بەليز)',
        'es_CL' => 'يسپان ءتىلى (چيلي)',
        'es_CO' => 'يسپان ءتىلى (كولۋمبيا)',
        'es_CR' => 'يسپان ءتىلى (كوستا-ريكا)',
        'es_CU' => 'يسپان ءتىلى (كۋبا)',
        'es_DO' => 'يسپان ءتىلى (دومينيكان رەسپۋبليكاسى)',
        'es_EC' => 'يسپان ءتىلى (ەكۆادور)',
        'es_ES' => 'يسپان ءتىلى (يسپانيا)',
        'es_GQ' => 'يسپان ءتىلى (ەكۆاتورلىق گۆينەيا)',
        'es_GT' => 'يسپان ءتىلى (گۆاتەمالا)',
        'es_HN' => 'يسپان ءتىلى (گوندۋراس)',
        'es_MX' => 'يسپان ءتىلى (مەكسيكا)',
        'es_NI' => 'يسپان ءتىلى (نيكاراگۋا)',
        'es_PA' => 'يسپان ءتىلى (پاناما)',
        'es_PE' => 'يسپان ءتىلى (پەرۋ)',
        'es_PH' => 'يسپان ءتىلى (فيليپين ارالدارى)',
        'es_PR' => 'يسپان ءتىلى (پۋەرتو-ريكو)',
        'es_PY' => 'يسپان ءتىلى (پاراگۆاي)',
        'es_SV' => 'يسپان ءتىلى (سالۆادور)',
        'es_US' => 'يسپان ءتىلى (امەريكا قۇراما شتاتتارى)',
        'es_UY' => 'يسپان ءتىلى (ۋرۋگۆاي)',
        'es_VE' => 'يسپان ءتىلى (ۆەنەسۋەلا)',
        'et' => 'ەستون ءتىلى',
        'et_EE' => 'ەستون ءتىلى (ەستونيا)',
        'eu' => 'باسك ءتىلى',
        'eu_ES' => 'باسك ءتىلى (يسپانيا)',
        'fa' => 'پارسى ءتىلى',
        'fa_AF' => 'پارسى ءتىلى (اۋعانستان)',
        'fa_IR' => 'پارسى ءتىلى (يران)',
        'ff' => 'فۋلا ءتىلى',
        'ff_Adlm' => 'فۋلا ءتىلى (ادلام جازۋى)',
        'ff_Adlm_BF' => 'فۋلا ءتىلى (ادلام جازۋى، بۋركينا-فاسو)',
        'ff_Adlm_CM' => 'فۋلا ءتىلى (ادلام جازۋى، كامەرۋن)',
        'ff_Adlm_GH' => 'فۋلا ءتىلى (ادلام جازۋى، گانا)',
        'ff_Adlm_GM' => 'فۋلا ءتىلى (ادلام جازۋى، گامبيا)',
        'ff_Adlm_GN' => 'فۋلا ءتىلى (ادلام جازۋى، گۆەنيا)',
        'ff_Adlm_GW' => 'فۋلا ءتىلى (ادلام جازۋى، گۆەنيا-بيساۋ)',
        'ff_Adlm_LR' => 'فۋلا ءتىلى (ادلام جازۋى، ليبەريا)',
        'ff_Adlm_MR' => 'فۋلا ءتىلى (ادلام جازۋى، ماۆريتانيا)',
        'ff_Adlm_NE' => 'فۋلا ءتىلى (ادلام جازۋى، نيگەر)',
        'ff_Adlm_NG' => 'فۋلا ءتىلى (ادلام جازۋى، نيگەريا)',
        'ff_Adlm_SL' => 'فۋلا ءتىلى (ادلام جازۋى، سەررا-لەونە)',
        'ff_Adlm_SN' => 'فۋلا ءتىلى (ادلام جازۋى، سەنەگال)',
        'ff_CM' => 'فۋلا ءتىلى (كامەرۋن)',
        'ff_GN' => 'فۋلا ءتىلى (گۆەنيا)',
        'ff_Latn' => 'فۋلا ءتىلى (لاتىن جازۋى)',
        'ff_Latn_BF' => 'فۋلا ءتىلى (لاتىن جازۋى، بۋركينا-فاسو)',
        'ff_Latn_CM' => 'فۋلا ءتىلى (لاتىن جازۋى، كامەرۋن)',
        'ff_Latn_GH' => 'فۋلا ءتىلى (لاتىن جازۋى، گانا)',
        'ff_Latn_GM' => 'فۋلا ءتىلى (لاتىن جازۋى، گامبيا)',
        'ff_Latn_GN' => 'فۋلا ءتىلى (لاتىن جازۋى، گۆەنيا)',
        'ff_Latn_GW' => 'فۋلا ءتىلى (لاتىن جازۋى، گۆەنيا-بيساۋ)',
        'ff_Latn_LR' => 'فۋلا ءتىلى (لاتىن جازۋى، ليبەريا)',
        'ff_Latn_MR' => 'فۋلا ءتىلى (لاتىن جازۋى، ماۆريتانيا)',
        'ff_Latn_NE' => 'فۋلا ءتىلى (لاتىن جازۋى، نيگەر)',
        'ff_Latn_NG' => 'فۋلا ءتىلى (لاتىن جازۋى، نيگەريا)',
        'ff_Latn_SL' => 'فۋلا ءتىلى (لاتىن جازۋى، سەررا-لەونە)',
        'ff_Latn_SN' => 'فۋلا ءتىلى (لاتىن جازۋى، سەنەگال)',
        'ff_MR' => 'فۋلا ءتىلى (ماۆريتانيا)',
        'ff_SN' => 'فۋلا ءتىلى (سەنەگال)',
        'fi' => 'فين ءتىلى',
        'fi_FI' => 'فين ءتىلى (فينليانديا)',
        'fo' => 'فارەر ءتىلى',
        'fo_DK' => 'فارەر ءتىلى (دانيا)',
        'fo_FO' => 'فارەر ءتىلى (فارەر ارالدارى)',
        'fr' => 'فرانسۋز ءتىلى',
        'fr_BE' => 'فرانسۋز ءتىلى (بەلگيا)',
        'fr_BF' => 'فرانسۋز ءتىلى (بۋركينا-فاسو)',
        'fr_BI' => 'فرانسۋز ءتىلى (بۋرۋندي)',
        'fr_BJ' => 'فرانسۋز ءتىلى (بەنين)',
        'fr_BL' => 'فرانسۋز ءتىلى (سان-بارتەمەلي)',
        'fr_CA' => 'فرانسۋز ءتىلى (كانادا)',
        'fr_CD' => 'فرانسۋز ءتىلى (كونگو)',
        'fr_CF' => 'فرانسۋز ءتىلى (ورتالىق افريكا رەسپۋبليكاسى)',
        'fr_CG' => 'فرانسۋز ءتىلى (كونگو-براززاۆيل رەسپۋبليكاسى)',
        'fr_CH' => 'فرانسۋز ءتىلى (شۆەيساريا)',
        'fr_CI' => 'فرانسۋز ءتىلى (كوت-ديۆۋار)',
        'fr_CM' => 'فرانسۋز ءتىلى (كامەرۋن)',
        'fr_DJ' => 'فرانسۋز ءتىلى (دجيبۋتي)',
        'fr_DZ' => 'فرانسۋز ءتىلى (الجىر)',
        'fr_FR' => 'فرانسۋز ءتىلى (فرانسيا)',
        'fr_GA' => 'فرانسۋز ءتىلى (گابون)',
        'fr_GF' => 'فرانسۋز ءتىلى (فرانسۋز گۆياناسى)',
        'fr_GN' => 'فرانسۋز ءتىلى (گۆەنيا)',
        'fr_GP' => 'فرانسۋز ءتىلى (گۆادەلۋپا)',
        'fr_GQ' => 'فرانسۋز ءتىلى (ەكۆاتورلىق گۆينەيا)',
        'fr_HT' => 'فرانسۋز ءتىلى (گايتي)',
        'fr_KM' => 'فرانسۋز ءتىلى (كومور ارالدارى)',
        'fr_LU' => 'فرانسۋز ءتىلى (ليۋكسەمبۋرگ)',
        'fr_MA' => 'فرانسۋز ءتىلى (ماروككو)',
        'fr_MC' => 'فرانسۋز ءتىلى (موناكو)',
        'fr_MF' => 'فرانسۋز ءتىلى (سەن-مارتەن)',
        'fr_MG' => 'فرانسۋز ءتىلى (ماداگاسكار)',
        'fr_ML' => 'فرانسۋز ءتىلى (مالي)',
        'fr_MQ' => 'فرانسۋز ءتىلى (مارتينيكا)',
        'fr_MR' => 'فرانسۋز ءتىلى (ماۆريتانيا)',
        'fr_MU' => 'فرانسۋز ءتىلى (ماۆريكي)',
        'fr_NC' => 'فرانسۋز ءتىلى (جاڭا كالەدونيا)',
        'fr_NE' => 'فرانسۋز ءتىلى (نيگەر)',
        'fr_PF' => 'فرانسۋز ءتىلى (فرانتسۋز پولينەزياسى)',
        'fr_PM' => 'فرانسۋز ءتىلى (سەن-پەر جانە ميكەلون)',
        'fr_RE' => 'فرانسۋز ءتىلى (رەيۋنيون)',
        'fr_RW' => 'فرانسۋز ءتىلى (رۋاندا)',
        'fr_SC' => 'فرانسۋز ءتىلى (سەيشەل ارالدارى)',
        'fr_SN' => 'فرانسۋز ءتىلى (سەنەگال)',
        'fr_SY' => 'فرانسۋز ءتىلى (سيريا)',
        'fr_TD' => 'فرانسۋز ءتىلى (چاد)',
        'fr_TG' => 'فرانسۋز ءتىلى (توگو)',
        'fr_TN' => 'فرانسۋز ءتىلى (تۋنيس)',
        'fr_VU' => 'فرانسۋز ءتىلى (ۆانۋاتۋ)',
        'fr_WF' => 'فرانسۋز ءتىلى (ۋولليس جانە فۋتۋنا)',
        'fr_YT' => 'فرانسۋز ءتىلى (مايوتتا)',
        'fy' => 'باتىس فريز ءتىلى',
        'fy_NL' => 'باتىس فريز ءتىلى (نيدەرلاند)',
        'ga' => 'يرلاند ءتىلى',
        'ga_GB' => 'يرلاند ءتىلى (ۇلىبريتانيا)',
        'ga_IE' => 'يرلاند ءتىلى (يرلانديا)',
        'gd' => 'شوتلانديالىق گەل ءتىلى',
        'gd_GB' => 'شوتلانديالىق گەل ءتىلى (ۇلىبريتانيا)',
        'gl' => 'گاليسيا ءتىلى',
        'gl_ES' => 'گاليسيا ءتىلى (يسپانيا)',
        'gu' => 'گۋجاراتي ءتىلى',
        'gu_IN' => 'گۋجاراتي ءتىلى (ءۇندىستان)',
        'gv' => 'مەن ءتىلى',
        'gv_IM' => 'مەن ءتىلى (مەن ارالى)',
        'ha' => 'حاۋسا ءتىلى',
        'ha_GH' => 'حاۋسا ءتىلى (گانا)',
        'ha_NE' => 'حاۋسا ءتىلى (نيگەر)',
        'ha_NG' => 'حاۋسا ءتىلى (نيگەريا)',
        'he' => 'يۆريت ءتىلى',
        'he_IL' => 'يۆريت ءتىلى (يزرايل)',
        'hi' => 'حيندي ءتىلى',
        'hi_IN' => 'حيندي ءتىلى (ءۇندىستان)',
        'hi_Latn' => 'حيندي ءتىلى (لاتىن جازۋى)',
        'hi_Latn_IN' => 'حيندي ءتىلى (لاتىن جازۋى، ءۇندىستان)',
        'hr' => 'حورۆات ءتىلى',
        'hr_BA' => 'حورۆات ءتىلى (بوسنيا جانە گەرتسەگوۆينا)',
        'hr_HR' => 'حورۆات ءتىلى (حورۆاتيا)',
        'hu' => 'ماجار ءتىلى',
        'hu_HU' => 'ماجار ءتىلى (ماجارستان)',
        'hy' => 'ارميان ءتىلى',
        'hy_AM' => 'ارميان ءتىلى (ارمەنيا)',
        'ia' => 'ينتەرلينگۆا ءتىلى',
        'ia_001' => 'ينتەرلينگۆا ءتىلى (الەم)',
        'id' => 'يندونەزيا ءتىلى',
        'id_ID' => 'يندونەزيا ءتىلى (يندونەزيا)',
        'ie' => 'ينتەرلينگۆە ءتىلى',
        'ie_EE' => 'ينتەرلينگۆە ءتىلى (ەستونيا)',
        'ig' => 'يگبو ءتىلى',
        'ig_NG' => 'يگبو ءتىلى (نيگەريا)',
        'ii' => 'سىچۋان ي ءتىلى',
        'ii_CN' => 'سىچۋان ي ءتىلى (قىتاي)',
        'is' => 'يسلاند ءتىلى',
        'is_IS' => 'يسلاند ءتىلى (يسلانديا)',
        'it' => 'يتاليان ءتىلى',
        'it_CH' => 'يتاليان ءتىلى (شۆەيساريا)',
        'it_IT' => 'يتاليان ءتىلى (يتاليا)',
        'it_SM' => 'يتاليان ءتىلى (سان-مارينو)',
        'it_VA' => 'يتاليان ءتىلى (ۆاتيكان)',
        'ja' => 'جاپون ءتىلى',
        'ja_JP' => 'جاپون ءتىلى (جاپونيا)',
        'jv' => 'ياۆا ءتىلى',
        'jv_ID' => 'ياۆا ءتىلى (يندونەزيا)',
        'ka' => 'گرۋزين ءتىلى',
        'ka_GE' => 'گرۋزين ءتىلى (گرۋزيا)',
        'ki' => 'كيكۋيۋ ءتىلى',
        'ki_KE' => 'كيكۋيۋ ءتىلى (كەنيا)',
        'kk' => 'قازاق ءتىلى',
        'kk_Arab' => 'قازاق ءتىلى (اراب جازۋى)',
        'kk_Arab_CN' => 'قازاق ءتىلى (اراب جازۋى، قىتاي)',
        'kk_Cyrl' => 'قازاق ءتىلى (كيريل جازۋى)',
        'kk_Cyrl_KZ' => 'قازاق ءتىلى (كيريل جازۋى، قازاق ەلى)',
        'kk_KZ' => 'قازاق ءتىلى (قازاق ەلى)',
        'kl' => 'كالاليسۋت ءتىلى',
        'kl_GL' => 'كالاليسۋت ءتىلى (گرەنلانديا)',
        'km' => 'كحمەر ءتىلى',
        'km_KH' => 'كحمەر ءتىلى (كامباجا)',
        'kn' => 'كاننادا ءتىلى',
        'kn_IN' => 'كاننادا ءتىلى (ءۇندىستان)',
        'ko' => 'كورەي ءتىلى',
        'ko_CN' => 'كورەي ءتىلى (قىتاي)',
        'ko_KP' => 'كورەي ءتىلى (سولتۇستىك كورەيا)',
        'ko_KR' => 'كورەي ءتىلى (وڭتۇستىك كورەيا)',
        'ks' => 'كاشمير ءتىلى',
        'ks_Arab' => 'كاشمير ءتىلى (اراب جازۋى)',
        'ks_Arab_IN' => 'كاشمير ءتىلى (اراب جازۋى، ءۇندىستان)',
        'ks_Deva' => 'كاشمير ءتىلى (دەۆاناگاري جازۋى)',
        'ks_Deva_IN' => 'كاشمير ءتىلى (دەۆاناگاري جازۋى، ءۇندىستان)',
        'ks_IN' => 'كاشمير ءتىلى (ءۇندىستان)',
        'ku' => 'كۇرد ءتىلى',
        'ku_Latn' => 'كۇرد ءتىلى (لاتىن جازۋى)',
        'ku_Latn_IQ' => 'كۇرد ءتىلى (لاتىن جازۋى، يراك)',
        'ku_Latn_SY' => 'كۇرد ءتىلى (لاتىن جازۋى، سيريا)',
        'ku_Latn_TR' => 'كۇرد ءتىلى (لاتىن جازۋى، تۇركيا)',
        'ku_SY' => 'كۇرد ءتىلى (سيريا)',
        'ku_TR' => 'كۇرد ءتىلى (تۇركيا)',
        'kw' => 'كورن ءتىلى',
        'kw_GB' => 'كورن ءتىلى (ۇلىبريتانيا)',
        'ky' => 'قىرعىز ءتىلى',
        'ky_KG' => 'قىرعىز ءتىلى (قىرعىزستان)',
        'lb' => 'ليۋكسەمبۋرگ ءتىلى',
        'lb_LU' => 'ليۋكسەمبۋرگ ءتىلى (ليۋكسەمبۋرگ)',
        'lg' => 'گاندا ءتىلى',
        'lg_UG' => 'گاندا ءتىلى (ۋگاندا)',
        'ln' => 'لينگالا ءتىلى',
        'ln_AO' => 'لينگالا ءتىلى (انگولا)',
        'ln_CD' => 'لينگالا ءتىلى (كونگو)',
        'ln_CF' => 'لينگالا ءتىلى (ورتالىق افريكا رەسپۋبليكاسى)',
        'ln_CG' => 'لينگالا ءتىلى (كونگو-براززاۆيل رەسپۋبليكاسى)',
        'lo' => 'لاوس ءتىلى',
        'lo_LA' => 'لاوس ءتىلى (لاوس)',
        'lt' => 'ليتۆا ءتىلى',
        'lt_LT' => 'ليتۆا ءتىلى (ليتۆا)',
        'lu' => 'لۋبا-كاتاڭا ءتىلى',
        'lu_CD' => 'لۋبا-كاتاڭا ءتىلى (كونگو)',
        'lv' => 'لاتىش ءتىلى',
        'lv_LV' => 'لاتىش ءتىلى (لاتۆيا)',
        'mg' => 'مالاگاسي ءتىلى',
        'mg_MG' => 'مالاگاسي ءتىلى (ماداگاسكار)',
        'mi' => 'ماوري ءتىلى',
        'mi_NZ' => 'ماوري ءتىلى (جاڭا زەلانديا)',
        'mk' => 'ماكەدون ءتىلى',
        'mk_MK' => 'ماكەدون ءتىلى (سولتۇستىك ماكەدونيا)',
        'ml' => 'مالايالام ءتىلى',
        'ml_IN' => 'مالايالام ءتىلى (ءۇندىستان)',
        'mn' => 'موڭعول ءتىلى',
        'mn_MN' => 'موڭعول ءتىلى (موڭعوليا)',
        'mr' => 'ماراتحي ءتىلى',
        'mr_IN' => 'ماراتحي ءتىلى (ءۇندىستان)',
        'ms' => 'مالاي ءتىلى',
        'ms_BN' => 'مالاي ءتىلى (برۋنەي)',
        'ms_ID' => 'مالاي ءتىلى (يندونەزيا)',
        'ms_MY' => 'مالاي ءتىلى (مالايزيا)',
        'ms_SG' => 'مالاي ءتىلى (سينگاپۋر)',
        'mt' => 'مالتا ءتىلى',
        'mt_MT' => 'مالتا ءتىلى (مالتا)',
        'my' => 'بيرما ءتىلى',
        'my_MM' => 'بيرما ءتىلى (ميانما [بيرما])',
        'nb' => 'نورۆەگيالىق بۋكمول ءتىلى',
        'nb_NO' => 'نورۆەگيالىق بۋكمول ءتىلى (نورۆەگيا)',
        'nb_SJ' => 'نورۆەگيالىق بۋكمول ءتىلى (شپيتسبەرگەن جانە يان-مايەن)',
        'nd' => 'سولتۇستىك ندەبەلە ءتىلى',
        'nd_ZW' => 'سولتۇستىك ندەبەلە ءتىلى (زيمبابۆە)',
        'ne' => 'نەپال ءتىلى',
        'ne_IN' => 'نەپال ءتىلى (ءۇندىستان)',
        'ne_NP' => 'نەپال ءتىلى (نەپال)',
        'nl' => 'نيدەرلاند ءتىلى',
        'nl_AW' => 'نيدەرلاند ءتىلى (ارۋبا)',
        'nl_BE' => 'نيدەرلاند ءتىلى (بەلگيا)',
        'nl_BQ' => 'نيدەرلاند ءتىلى (بونەير، سينت-ەستاتيۋس جانە سابا)',
        'nl_CW' => 'نيدەرلاند ءتىلى (كيۋراساو)',
        'nl_NL' => 'نيدەرلاند ءتىلى (نيدەرلاند)',
        'nl_SR' => 'نيدەرلاند ءتىلى (سۋرينام)',
        'nl_SX' => 'نيدەرلاند ءتىلى (سينت-مارتەن)',
        'nn' => 'نورۆەگيالىق نيۋنورسك ءتىلى',
        'nn_NO' => 'نورۆەگيالىق نيۋنورسك ءتىلى (نورۆەگيا)',
        'no' => 'نورۆەگ ءتىلى',
        'no_NO' => 'نورۆەگ ءتىلى (نورۆەگيا)',
        'oc' => 'وكسيتان ءتىلى',
        'oc_ES' => 'وكسيتان ءتىلى (يسپانيا)',
        'oc_FR' => 'وكسيتان ءتىلى (فرانسيا)',
        'om' => 'ورومو ءتىلى',
        'om_ET' => 'ورومو ءتىلى (ەفيوپيا)',
        'om_KE' => 'ورومو ءتىلى (كەنيا)',
        'or' => 'وريا ءتىلى',
        'or_IN' => 'وريا ءتىلى (ءۇندىستان)',
        'os' => 'وسەتين ءتىلى',
        'os_GE' => 'وسەتين ءتىلى (گرۋزيا)',
        'os_RU' => 'وسەتين ءتىلى (حەسەي)',
        'pa' => 'پەنجاب ءتىلى',
        'pa_Arab' => 'پەنجاب ءتىلى (اراب جازۋى)',
        'pa_Arab_PK' => 'پەنجاب ءتىلى (اراب جازۋى، پاكىستان)',
        'pa_Guru' => 'پەنجاب ءتىلى (گۋرمۋكحي جازۋى)',
        'pa_Guru_IN' => 'پەنجاب ءتىلى (گۋرمۋكحي جازۋى، ءۇندىستان)',
        'pa_IN' => 'پەنجاب ءتىلى (ءۇندىستان)',
        'pa_PK' => 'پەنجاب ءتىلى (پاكىستان)',
        'pl' => 'پولياك ءتىلى',
        'pl_PL' => 'پولياك ءتىلى (پولشا)',
        'ps' => 'پۋشتۋ ءتىلى',
        'ps_AF' => 'پۋشتۋ ءتىلى (اۋعانستان)',
        'ps_PK' => 'پۋشتۋ ءتىلى (پاكىستان)',
        'pt' => 'پورتۋگال ءتىلى',
        'pt_AO' => 'پورتۋگال ءتىلى (انگولا)',
        'pt_BR' => 'پورتۋگال ءتىلى (برازيليا)',
        'pt_CH' => 'پورتۋگال ءتىلى (شۆەيساريا)',
        'pt_CV' => 'پورتۋگال ءتىلى (كابو-ۆەردە)',
        'pt_GQ' => 'پورتۋگال ءتىلى (ەكۆاتورلىق گۆينەيا)',
        'pt_GW' => 'پورتۋگال ءتىلى (گۆەنيا-بيساۋ)',
        'pt_LU' => 'پورتۋگال ءتىلى (ليۋكسەمبۋرگ)',
        'pt_MO' => 'پورتۋگال ءتىلى (ماكاو)',
        'pt_MZ' => 'پورتۋگال ءتىلى (موزامبيك)',
        'pt_PT' => 'پورتۋگال ءتىلى (پورتۋگاليا)',
        'pt_ST' => 'پورتۋگال ءتىلى (سان-تومە جانە پرينسيپي)',
        'pt_TL' => 'پورتۋگال ءتىلى (تيمور-لەستە)',
        'qu' => 'كەچۋا ءتىلى',
        'qu_BO' => 'كەچۋا ءتىلى (بوليۆيا)',
        'qu_EC' => 'كەچۋا ءتىلى (ەكۆادور)',
        'qu_PE' => 'كەچۋا ءتىلى (پەرۋ)',
        'rm' => 'رومانش ءتىلى',
        'rm_CH' => 'رومانش ءتىلى (شۆەيساريا)',
        'rn' => 'رۋندي ءتىلى',
        'rn_BI' => 'رۋندي ءتىلى (بۋرۋندي)',
        'ro' => 'رۋمىن ءتىلى',
        'ro_MD' => 'رۋمىن ءتىلى (مولدوۆا)',
        'ro_RO' => 'رۋمىن ءتىلى (رۋمىنيا)',
        'ru' => 'ورىس ءتىلى',
        'ru_BY' => 'ورىس ءتىلى (بەلارۋس)',
        'ru_KG' => 'ورىس ءتىلى (قىرعىزستان)',
        'ru_KZ' => 'ورىس ءتىلى (قازاق ەلى)',
        'ru_MD' => 'ورىس ءتىلى (مولدوۆا)',
        'ru_RU' => 'ورىس ءتىلى (حەسەي)',
        'ru_UA' => 'ورىس ءتىلى (ۋكراينا)',
        'rw' => 'كينيارۋاندا ءتىلى',
        'rw_RW' => 'كينيارۋاندا ءتىلى (رۋاندا)',
        'sa' => 'سانسكريت ءتىلى',
        'sa_IN' => 'سانسكريت ءتىلى (ءۇندىستان)',
        'sc' => 'ساردين ءتىلى',
        'sc_IT' => 'ساردين ءتىلى (يتاليا)',
        'sd' => 'سيندحي ءتىلى',
        'sd_Arab' => 'سيندحي ءتىلى (اراب جازۋى)',
        'sd_Arab_PK' => 'سيندحي ءتىلى (اراب جازۋى، پاكىستان)',
        'sd_Deva' => 'سيندحي ءتىلى (دەۆاناگاري جازۋى)',
        'sd_Deva_IN' => 'سيندحي ءتىلى (دەۆاناگاري جازۋى، ءۇندىستان)',
        'sd_IN' => 'سيندحي ءتىلى (ءۇندىستان)',
        'sd_PK' => 'سيندحي ءتىلى (پاكىستان)',
        'se' => 'سولتۇستىك سامي ءتىلى',
        'se_FI' => 'سولتۇستىك سامي ءتىلى (فينليانديا)',
        'se_NO' => 'سولتۇستىك سامي ءتىلى (نورۆەگيا)',
        'se_SE' => 'سولتۇستىك سامي ءتىلى (شۆەسيا)',
        'sg' => 'ساڭو ءتىلى',
        'sg_CF' => 'ساڭو ءتىلى (ورتالىق افريكا رەسپۋبليكاسى)',
        'sh_BA' => 'серб-хорват тілі (بوسنيا جانە گەرتسەگوۆينا)',
        'si' => 'سينگال ءتىلى',
        'si_LK' => 'سينگال ءتىلى (شري-لانكا)',
        'sk' => 'سلوۆاك ءتىلى',
        'sk_SK' => 'سلوۆاك ءتىلى (سلوۆاكيا)',
        'sl' => 'سلوۆەن ءتىلى',
        'sl_SI' => 'سلوۆەن ءتىلى (سلوۆەنيا)',
        'sn' => 'شونا ءتىلى',
        'sn_ZW' => 'شونا ءتىلى (زيمبابۆە)',
        'so' => 'سومالي ءتىلى',
        'so_DJ' => 'سومالي ءتىلى (دجيبۋتي)',
        'so_ET' => 'سومالي ءتىلى (ەفيوپيا)',
        'so_KE' => 'سومالي ءتىلى (كەنيا)',
        'so_SO' => 'سومالي ءتىلى (سومالي)',
        'sq' => 'البان ءتىلى',
        'sq_AL' => 'البان ءتىلى (البانيا)',
        'sq_MK' => 'البان ءتىلى (سولتۇستىك ماكەدونيا)',
        'sr' => 'سەرب ءتىلى',
        'sr_BA' => 'سەرب ءتىلى (بوسنيا جانە گەرتسەگوۆينا)',
        'sr_Cyrl' => 'سەرب ءتىلى (كيريل جازۋى)',
        'sr_Cyrl_BA' => 'سەرب ءتىلى (كيريل جازۋى، بوسنيا جانە گەرتسەگوۆينا)',
        'sr_Cyrl_ME' => 'سەرب ءتىلى (كيريل جازۋى، چەرنوگوريا)',
        'sr_Cyrl_RS' => 'سەرب ءتىلى (كيريل جازۋى، سەربيا)',
        'sr_Latn' => 'سەرب ءتىلى (لاتىن جازۋى)',
        'sr_Latn_BA' => 'سەرب ءتىلى (لاتىن جازۋى، بوسنيا جانە گەرتسەگوۆينا)',
        'sr_Latn_ME' => 'سەرب ءتىلى (لاتىن جازۋى، چەرنوگوريا)',
        'sr_Latn_RS' => 'سەرب ءتىلى (لاتىن جازۋى، سەربيا)',
        'sr_ME' => 'سەرب ءتىلى (چەرنوگوريا)',
        'sr_RS' => 'سەرب ءتىلى (سەربيا)',
        'st' => 'وڭتۇستىك سوتو ءتىلى',
        'st_LS' => 'وڭتۇستىك سوتو ءتىلى (لەسوتو)',
        'st_ZA' => 'وڭتۇستىك سوتو ءتىلى (وڭتۇستىك افريكا)',
        'su' => 'سۋدان ءتىلى',
        'su_ID' => 'سۋدان ءتىلى (يندونەزيا)',
        'su_Latn' => 'سۋدان ءتىلى (لاتىن جازۋى)',
        'su_Latn_ID' => 'سۋدان ءتىلى (لاتىن جازۋى، يندونەزيا)',
        'sv' => 'شۆەد ءتىلى',
        'sv_AX' => 'شۆەد ءتىلى (الاند ارالدارى)',
        'sv_FI' => 'شۆەد ءتىلى (فينليانديا)',
        'sv_SE' => 'شۆەد ءتىلى (شۆەسيا)',
        'sw' => 'سۋاحيلي ءتىلى',
        'sw_CD' => 'سۋاحيلي ءتىلى (كونگو)',
        'sw_KE' => 'سۋاحيلي ءتىلى (كەنيا)',
        'sw_TZ' => 'سۋاحيلي ءتىلى (تانزانيا)',
        'sw_UG' => 'سۋاحيلي ءتىلى (ۋگاندا)',
        'ta' => 'تاميل ءتىلى',
        'ta_IN' => 'تاميل ءتىلى (ءۇندىستان)',
        'ta_LK' => 'تاميل ءتىلى (شري-لانكا)',
        'ta_MY' => 'تاميل ءتىلى (مالايزيا)',
        'ta_SG' => 'تاميل ءتىلى (سينگاپۋر)',
        'te' => 'تەلۋگۋ ءتىلى',
        'te_IN' => 'تەلۋگۋ ءتىلى (ءۇندىستان)',
        'tg' => 'تاجىك ءتىلى',
        'tg_TJ' => 'تاجىك ءتىلى (تاجىكستان)',
        'th' => 'تاي ءتىلى',
        'th_TH' => 'تاي ءتىلى (تايلاند)',
        'ti' => 'تيگرينيا ءتىلى',
        'ti_ER' => 'تيگرينيا ءتىلى (ەريترەيا)',
        'ti_ET' => 'تيگرينيا ءتىلى (ەفيوپيا)',
        'tk' => 'تۇرىكمەن ءتىلى',
        'tk_TM' => 'تۇرىكمەن ءتىلى (تۇرىكمەنستان)',
        'tn' => 'سۋانا ءتىلى',
        'tn_BW' => 'سۋانا ءتىلى (بوتسۆانا)',
        'tn_ZA' => 'سۋانا ءتىلى (وڭتۇستىك افريكا)',
        'to' => 'تونگان ءتىلى',
        'to_TO' => 'تونگان ءتىلى (تونگا)',
        'tr' => 'تۇرىك ءتىلى',
        'tr_CY' => 'تۇرىك ءتىلى (كيپر)',
        'tr_TR' => 'تۇرىك ءتىلى (تۇركيا)',
        'tt' => 'تاتار ءتىلى',
        'tt_RU' => 'تاتار ءتىلى (حەسەي)',
        'ug' => 'ۇيعىر ءتىلى',
        'ug_CN' => 'ۇيعىر ءتىلى (قىتاي)',
        'uk' => 'ۋكراين ءتىلى',
        'uk_UA' => 'ۋكراين ءتىلى (ۋكراينا)',
        'ur' => 'ۋردۋ ءتىلى',
        'ur_IN' => 'ۋردۋ ءتىلى (ءۇندىستان)',
        'ur_PK' => 'ۋردۋ ءتىلى (پاكىستان)',
        'uz' => 'وزبەك ءتىلى',
        'uz_AF' => 'وزبەك ءتىلى (اۋعانستان)',
        'uz_Arab' => 'وزبەك ءتىلى (اراب جازۋى)',
        'uz_Arab_AF' => 'وزبەك ءتىلى (اراب جازۋى، اۋعانستان)',
        'uz_Cyrl' => 'وزبەك ءتىلى (كيريل جازۋى)',
        'uz_Cyrl_UZ' => 'وزبەك ءتىلى (كيريل جازۋى، وزبەكستان)',
        'uz_Latn' => 'وزبەك ءتىلى (لاتىن جازۋى)',
        'uz_Latn_UZ' => 'وزبەك ءتىلى (لاتىن جازۋى، وزبەكستان)',
        'uz_UZ' => 'وزبەك ءتىلى (وزبەكستان)',
        'vi' => 'ۆيەتنام ءتىلى',
        'vi_VN' => 'ۆيەتنام ءتىلى (ۆيەتنام)',
        'wo' => 'ۆولوف ءتىلى',
        'wo_SN' => 'ۆولوف ءتىلى (سەنەگال)',
        'xh' => 'كحوسا ءتىلى',
        'xh_ZA' => 'كحوسا ءتىلى (وڭتۇستىك افريكا)',
        'yi' => 'يديش ءتىلى',
        'yi_UA' => 'يديش ءتىلى (ۋكراينا)',
        'yo' => 'يورۋبا ءتىلى',
        'yo_BJ' => 'يورۋبا ءتىلى (بەنين)',
        'yo_NG' => 'يورۋبا ءتىلى (نيگەريا)',
        'za' => 'جۋاڭ ءتىلى',
        'za_CN' => 'جۋاڭ ءتىلى (قىتاي)',
        'zh' => 'قىتاي ءتىلى',
        'zh_CN' => 'قىتاي ءتىلى (قىتاي)',
        'zh_HK' => 'قىتاي ءتىلى (حوڭكوڭ)',
        'zh_Hans' => 'قىتاي ءتىلى (جەڭىلدەتىلگەن جازۋ)',
        'zh_Hans_CN' => 'قىتاي ءتىلى (جەڭىلدەتىلگەن جازۋ، قىتاي)',
        'zh_Hans_HK' => 'قىتاي ءتىلى (جەڭىلدەتىلگەن جازۋ، حوڭكوڭ)',
        'zh_Hans_MO' => 'قىتاي ءتىلى (جەڭىلدەتىلگەن جازۋ، ماكاو)',
        'zh_Hans_MY' => 'قىتاي ءتىلى (جەڭىلدەتىلگەن جازۋ، مالايزيا)',
        'zh_Hans_SG' => 'قىتاي ءتىلى (جەڭىلدەتىلگەن جازۋ، سينگاپۋر)',
        'zh_Hant' => 'قىتاي ءتىلى (ءداستۇرلى جازۋ)',
        'zh_Hant_HK' => 'قىتاي ءتىلى (ءداستۇرلى جازۋ، حوڭكوڭ)',
        'zh_Hant_MO' => 'قىتاي ءتىلى (ءداستۇرلى جازۋ، ماكاو)',
        'zh_Hant_MY' => 'قىتاي ءتىلى (ءداستۇرلى جازۋ، مالايزيا)',
        'zh_Hant_TW' => 'قىتاي ءتىلى (ءداستۇرلى جازۋ، تايۋان)',
        'zh_MO' => 'قىتاي ءتىلى (ماكاو)',
        'zh_SG' => 'قىتاي ءتىلى (سينگاپۋر)',
        'zh_TW' => 'قىتاي ءتىلى (تايۋان)',
        'zu' => 'زۋلۋ ءتىلى',
        'zu_ZA' => 'زۋلۋ ءتىلى (وڭتۇستىك افريكا)',
    ],
];
