<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Hora del meridià de Greenwich (Abidjan)',
        'Africa/Accra' => 'Hora del meridià de Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'Hora de l’Àfrica oriental (Addis Abeba)',
        'Africa/Algiers' => 'Hora d’Europa central (Alger)',
        'Africa/Asmera' => 'Hora de l’Àfrica oriental (Asmara)',
        'Africa/Asmara' => 'Hora de l’Àfrica oriental (Asmara)',
        'Africa/Bamako' => 'Hora del meridià de Greenwich (Bamako)',
        'Africa/Bangui' => 'Hora de l’Àfrica occidental (Bangui)',
        'Africa/Banjul' => 'Hora del meridià de Greenwich (Banjul)',
        'Africa/Bissau' => 'Hora del meridià de Greenwich (Bissau)',
        'Africa/Blantyre' => 'Hora de l’Àfrica central (Blantyre)',
        'Africa/Brazzaville' => 'Hora de l’Àfrica occidental (Brazzaville)',
        'Africa/Bujumbura' => 'Hora de l’Àfrica central (Bujumbura)',
        'Africa/Cairo' => 'Hora d’Europa oriental (Caire, el)',
        'Africa/Casablanca' => 'Hora d’Europa occidental (Casablanca)',
        'Africa/Ceuta' => 'Hora d’Europa central (Ceuta)',
        'Africa/Conakry' => 'Hora del meridià de Greenwich (Conakry)',
        'Africa/Dakar' => 'Hora del meridià de Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Hora de l’Àfrica oriental (Dar es Salaam)',
        'Africa/Djibouti' => 'Hora de l’Àfrica oriental (Djibouti)',
        'Africa/Douala' => 'Hora de l’Àfrica occidental (Douala)',
        'Africa/El_Aaiun' => 'Hora d’Europa occidental (al-Aaiun)',
        'Africa/Freetown' => 'Hora del meridià de Greenwich (Freetown)',
        'Africa/Gaborone' => 'Hora de l’Àfrica central (Gaborone)',
        'Africa/Harare' => 'Hora de l’Àfrica central (Harare)',
        'Africa/Johannesburg' => 'Hora estàndard de l’Àfrica meridional (Johannesburg)',
        'Africa/Juba' => 'Hora de l’Àfrica central (Juba)',
        'Africa/Kampala' => 'Hora de l’Àfrica oriental (Kampala)',
        'Africa/Khartoum' => 'Hora de l’Àfrica central (Khartum)',
        'Africa/Kigali' => 'Hora de l’Àfrica central (Kigali)',
        'Africa/Kinshasa' => 'Hora de l’Àfrica occidental (Kinshasa)',
        'Africa/Lagos' => 'Hora de l’Àfrica occidental (Lagos)',
        'Africa/Libreville' => 'Hora de l’Àfrica occidental (Libreville)',
        'Africa/Lome' => 'Hora del meridià de Greenwich (Lomé)',
        'Africa/Luanda' => 'Hora de l’Àfrica occidental (Luanda)',
        'Africa/Lubumbashi' => 'Hora de l’Àfrica central (Lubumbashi)',
        'Africa/Lusaka' => 'Hora de l’Àfrica central (Lusaka)',
        'Africa/Malabo' => 'Hora de l’Àfrica occidental (Malabo)',
        'Africa/Maputo' => 'Hora de l’Àfrica central (Maputo)',
        'Africa/Maseru' => 'Hora estàndard de l’Àfrica meridional (Maseru)',
        'Africa/Mbabane' => 'Hora estàndard de l’Àfrica meridional (Mbabane)',
        'Africa/Mogadishu' => 'Hora de l’Àfrica oriental (Mogadiscio)',
        'Africa/Monrovia' => 'Hora del meridià de Greenwich (Monròvia)',
        'Africa/Nairobi' => 'Hora de l’Àfrica oriental (Nairobi)',
        'Africa/Ndjamena' => 'Hora de l’Àfrica occidental (N’Djamena)',
        'Africa/Niamey' => 'Hora de l’Àfrica occidental (Niamey)',
        'Africa/Nouakchott' => 'Hora del meridià de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Hora del meridià de Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Hora de l’Àfrica occidental (Porto-Novo)',
        'Africa/Sao_Tome' => 'Hora del meridià de Greenwich (São Tomé)',
        'Africa/Tripoli' => 'Hora d’Europa oriental (Trípoli)',
        'Africa/Tunis' => 'Hora d’Europa central (Tunis)',
        'Africa/Windhoek' => 'Hora de l’Àfrica central (Windhoek)',
        'America/Adak' => 'Hora de Hawaii-Aleutianes (Adak)',
        'America/Anchorage' => 'Hora d’Alaska (Anchorage)',
        'America/Anguilla' => 'Hora de l’Atlàntic (Anguilla)',
        'America/Antigua' => 'Hora de l’Atlàntic (Antigua)',
        'America/Araguaina' => 'Hora de Brasília (Araguaína)',
        'America/Argentina/La_Rioja' => 'Hora de l’Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Hora de l’Argentina (Río Gallegos)',
        'America/Argentina/Salta' => 'Hora de l’Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Hora de l’Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Hora de l’Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Hora de l’Argentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'Hora de l’Argentina (Ushuaia)',
        'America/Aruba' => 'Hora de l’Atlàntic (Aruba)',
        'America/Asuncion' => 'Hora del Paraguai (Asunción)',
        'America/Bahia' => 'Hora de Brasília (Bahia)',
        'America/Bahia_Banderas' => 'Hora central d’Amèrica del Nord (Bahía de Banderas)',
        'America/Barbados' => 'Hora de l’Atlàntic (Barbados)',
        'America/Belem' => 'Hora de Brasília (Belém)',
        'America/Belize' => 'Hora central d’Amèrica del Nord (Belize)',
        'America/Blanc-Sablon' => 'Hora de l’Atlàntic (Blanc Sablon)',
        'America/Boa_Vista' => 'Hora de l’Amazones (Boa Vista)',
        'America/Bogota' => 'Hora de Colòmbia (Bogotà)',
        'America/Boise' => 'Hora de muntanya d’Amèrica del Nord (Boise)',
        'America/Buenos_Aires' => 'Hora de l’Argentina (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Hora de l’Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Hora de muntanya d’Amèrica del Nord (Cambridge Bay)',
        'America/Campo_Grande' => 'Hora de l’Amazones (Campo Grande)',
        'America/Cancun' => 'Hora oriental d’Amèrica del Nord (Cancun)',
        'America/Caracas' => 'Hora de Veneçuela (Caracas)',
        'America/Catamarca' => 'Hora de l’Argentina (Catamarca)',
        'America/Argentina/Catamarca' => 'Hora de l’Argentina (Catamarca)',
        'America/Cayenne' => 'Hora de la Guaiana Francesa (Caiena)',
        'America/Cayman' => 'Hora oriental d’Amèrica del Nord (Caiman)',
        'America/Chicago' => 'Hora central d’Amèrica del Nord (Chicago)',
        'America/Chihuahua' => 'Hora central d’Amèrica del Nord (Chihuahua)',
        'America/Ciudad_Juarez' => 'Hora de muntanya d’Amèrica del Nord (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Hora oriental d’Amèrica del Nord (Atikokan)',
        'America/Atikokan' => 'Hora oriental d’Amèrica del Nord (Atikokan)',
        'America/Cordoba' => 'Hora de l’Argentina (Córdoba)',
        'America/Argentina/Cordoba' => 'Hora de l’Argentina (Córdoba)',
        'America/Costa_Rica' => 'Hora central d’Amèrica del Nord (Costa Rica)',
        'America/Coyhaique' => 'Hora de Xile (Coyhaique)',
        'America/Creston' => 'Hora de muntanya d’Amèrica del Nord (Creston)',
        'America/Cuiaba' => 'Hora de l’Amazones (Cuiabá)',
        'America/Curacao' => 'Hora de l’Atlàntic (Curaçao)',
        'America/Danmarkshavn' => 'Hora del meridià de Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Hora de Yukon (Dawson)',
        'America/Dawson_Creek' => 'Hora de muntanya d’Amèrica del Nord (Dawson Creek)',
        'America/Denver' => 'Hora de muntanya d’Amèrica del Nord (Denver)',
        'America/Detroit' => 'Hora oriental d’Amèrica del Nord (Detroit)',
        'America/Dominica' => 'Hora de l’Atlàntic (Dominica)',
        'America/Edmonton' => 'Hora de muntanya d’Amèrica del Nord (Edmonton)',
        'America/Eirunepe' => 'Hora de: Brasil (Eirunepé)',
        'America/El_Salvador' => 'Hora central d’Amèrica del Nord (El Salvador)',
        'America/Fort_Nelson' => 'Hora de muntanya d’Amèrica del Nord (Fort Nelson)',
        'America/Fortaleza' => 'Hora de Brasília (Fortaleza)',
        'America/Glace_Bay' => 'Hora de l’Atlàntic (Glace Bay)',
        'America/Godthab' => 'Hora de: Groenlàndia (Nuuk)',
        'America/Nuuk' => 'Hora de: Groenlàndia (Nuuk)',
        'America/Goose_Bay' => 'Hora de l’Atlàntic (Goose Bay)',
        'America/Grand_Turk' => 'Hora oriental d’Amèrica del Nord (Grand Turk)',
        'America/Grenada' => 'Hora de l’Atlàntic (Grenada)',
        'America/Guadeloupe' => 'Hora de l’Atlàntic (Guadeloupe)',
        'America/Guatemala' => 'Hora central d’Amèrica del Nord (Guatemala)',
        'America/Guayaquil' => 'Hora de l’Equador (Guayaquil)',
        'America/Guyana' => 'Hora de Guyana',
        'America/Halifax' => 'Hora de l’Atlàntic (Halifax)',
        'America/Havana' => 'Hora de Cuba (Havana)',
        'America/Hermosillo' => 'Hora del Pacífic de Mèxic (Hermosillo)',
        'America/Indiana/Knox' => 'Hora central d’Amèrica del Nord (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Hora oriental d’Amèrica del Nord (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Hora oriental d’Amèrica del Nord (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Hora central d’Amèrica del Nord (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Hora oriental d’Amèrica del Nord (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Hora oriental d’Amèrica del Nord (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Hora oriental d’Amèrica del Nord (Winamac, Indiana)',
        'America/Indianapolis' => 'Hora oriental d’Amèrica del Nord (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Hora oriental d’Amèrica del Nord (Indianapolis)',
        'America/Inuvik' => 'Hora de muntanya d’Amèrica del Nord (Inuvik)',
        'America/Iqaluit' => 'Hora oriental d’Amèrica del Nord (Iqaluit)',
        'America/Jamaica' => 'Hora oriental d’Amèrica del Nord (Jamaica)',
        'America/Jujuy' => 'Hora de l’Argentina (Jujuy)',
        'America/Argentina/Jujuy' => 'Hora de l’Argentina (Jujuy)',
        'America/Juneau' => 'Hora d’Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Hora oriental d’Amèrica del Nord (Monticello, Kentucky)',
        'America/Kralendijk' => 'Hora de l’Atlàntic (Kralendijk)',
        'America/La_Paz' => 'Hora de Bolívia (La Paz)',
        'America/Lima' => 'Hora del Perú (Lima)',
        'America/Los_Angeles' => 'Hora del Pacífic d’Amèrica del Nord (Los Angeles)',
        'America/Louisville' => 'Hora oriental d’Amèrica del Nord (Louisville)',
        'America/Kentucky/Louisville' => 'Hora oriental d’Amèrica del Nord (Louisville)',
        'America/Lower_Princes' => 'Hora de l’Atlàntic (Lower Prince’s Quarter)',
        'America/Maceio' => 'Hora de Brasília (Maceió)',
        'America/Managua' => 'Hora central d’Amèrica del Nord (Managua)',
        'America/Manaus' => 'Hora de l’Amazones (Manaus)',
        'America/Marigot' => 'Hora de l’Atlàntic (Marigot)',
        'America/Martinique' => 'Hora de l’Atlàntic (Martinica)',
        'America/Matamoros' => 'Hora central d’Amèrica del Nord (Matamoros)',
        'America/Mazatlan' => 'Hora del Pacífic de Mèxic (Mazatlán)',
        'America/Mendoza' => 'Hora de l’Argentina (Mendoza)',
        'America/Argentina/Mendoza' => 'Hora de l’Argentina (Mendoza)',
        'America/Menominee' => 'Hora central d’Amèrica del Nord (Menominee)',
        'America/Merida' => 'Hora central d’Amèrica del Nord (Mérida)',
        'America/Metlakatla' => 'Hora d’Alaska (Metlakatla)',
        'America/Mexico_City' => 'Hora central d’Amèrica del Nord (Ciutat de Mèxic)',
        'America/Miquelon' => 'Hora de Saint-Pierre-et-Miquelon',
        'America/Moncton' => 'Hora de l’Atlàntic (Moncton)',
        'America/Monterrey' => 'Hora central d’Amèrica del Nord (Monterrey)',
        'America/Montevideo' => 'Hora de l’Uruguai (Montevideo)',
        'America/Montserrat' => 'Hora de l’Atlàntic (Montserrat)',
        'America/Nassau' => 'Hora oriental d’Amèrica del Nord (Nassau)',
        'America/New_York' => 'Hora oriental d’Amèrica del Nord (Nova York)',
        'America/Nome' => 'Hora d’Alaska (Nome)',
        'America/Noronha' => 'Hora de Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Hora central d’Amèrica del Nord (Beulah, Dakota del Nord)',
        'America/North_Dakota/Center' => 'Hora central d’Amèrica del Nord (Center, Dakota del Nord)',
        'America/North_Dakota/New_Salem' => 'Hora central d’Amèrica del Nord (New Salem, Dakota del Nord)',
        'America/Ojinaga' => 'Hora central d’Amèrica del Nord (Ojinaga)',
        'America/Panama' => 'Hora oriental d’Amèrica del Nord (Panamà)',
        'America/Paramaribo' => 'Hora de Surinam (Paramaribo)',
        'America/Phoenix' => 'Hora de muntanya d’Amèrica del Nord (Phoenix)',
        'America/Port-au-Prince' => 'Hora oriental d’Amèrica del Nord (Port-au-Prince)',
        'America/Port_of_Spain' => 'Hora de l’Atlàntic (Port of Spain)',
        'America/Porto_Velho' => 'Hora de l’Amazones (Porto Velho)',
        'America/Puerto_Rico' => 'Hora de l’Atlàntic (Puerto Rico)',
        'America/Punta_Arenas' => 'Hora de Xile (Punta Arenas)',
        'America/Rankin_Inlet' => 'Hora central d’Amèrica del Nord (Rankin Inlet)',
        'America/Recife' => 'Hora de Brasília (Recife)',
        'America/Regina' => 'Hora central d’Amèrica del Nord (Regina)',
        'America/Resolute' => 'Hora central d’Amèrica del Nord (Resolute)',
        'America/Rio_Branco' => 'Hora de: Brasil (Rio Branco)',
        'America/Santarem' => 'Hora de Brasília (Santarém)',
        'America/Santiago' => 'Hora de Xile (Santiago)',
        'America/Santo_Domingo' => 'Hora de l’Atlàntic (Santo Domingo)',
        'America/Sao_Paulo' => 'Hora de Brasília (São Paulo)',
        'America/Scoresbysund' => 'Hora de: Groenlàndia (Scoresbysund)',
        'America/Sitka' => 'Hora d’Alaska (Sitka)',
        'America/St_Barthelemy' => 'Hora de l’Atlàntic (Saint Barthélemy)',
        'America/St_Johns' => 'Hora de Terranova (Saint John’s)',
        'America/St_Kitts' => 'Hora de l’Atlàntic (Saint Kitts)',
        'America/St_Lucia' => 'Hora de l’Atlàntic (Saint Lucia)',
        'America/St_Thomas' => 'Hora de l’Atlàntic (Saint Thomas)',
        'America/St_Vincent' => 'Hora de l’Atlàntic (Saint Vincent)',
        'America/Swift_Current' => 'Hora central d’Amèrica del Nord (Swift Current)',
        'America/Tegucigalpa' => 'Hora central d’Amèrica del Nord (Tegucigalpa)',
        'America/Thule' => 'Hora de l’Atlàntic (Thule)',
        'America/Tijuana' => 'Hora del Pacífic d’Amèrica del Nord (Tijuana)',
        'America/Toronto' => 'Hora oriental d’Amèrica del Nord (Toronto)',
        'America/Tortola' => 'Hora de l’Atlàntic (Tortola)',
        'America/Vancouver' => 'Hora del Pacífic d’Amèrica del Nord (Vancouver)',
        'America/Whitehorse' => 'Hora de Yukon (Whitehorse)',
        'America/Winnipeg' => 'Hora central d’Amèrica del Nord (Winnipeg)',
        'America/Yakutat' => 'Hora d’Alaska (Yakutat)',
        'Antarctica/Casey' => 'Hora d’Austràlia occidental (Casey)',
        'Antarctica/Davis' => 'Hora de Davis',
        'Antarctica/DumontDUrville' => 'Hora de Dumont d’Urville',
        'Antarctica/Macquarie' => 'Hora d’Austràlia oriental (Macquarie)',
        'Antarctica/Mawson' => 'Hora de Mawson',
        'Antarctica/McMurdo' => 'Hora de Nova Zelanda (McMurdo)',
        'Antarctica/Palmer' => 'Hora de Xile (Palmer)',
        'Antarctica/Rothera' => 'Hora de Rothera',
        'Antarctica/Syowa' => 'Hora de Syowa (Showa)',
        'Antarctica/Troll' => 'Hora del meridià de Greenwich (Troll)',
        'Antarctica/Vostok' => 'Hora de Vostok',
        'Arctic/Longyearbyen' => 'Hora d’Europa central (Longyearbyen)',
        'Asia/Aden' => 'Hora àrab (Aden)',
        'Asia/Almaty' => 'Hora del Kazakhstan (Almaty)',
        'Asia/Amman' => 'Hora d’Europa oriental (Amman)',
        'Asia/Anadyr' => 'Hora de Kamtxatka (Anàdir)',
        'Asia/Aqtau' => 'Hora del Kazakhstan (Aqtaý)',
        'Asia/Aqtobe' => 'Hora del Kazakhstan (Aqtóbe)',
        'Asia/Ashgabat' => 'Hora del Turkmenistan (Aşgabat)',
        'Asia/Atyrau' => 'Hora del Kazakhstan (Atyraý)',
        'Asia/Baghdad' => 'Hora àrab (Bagdad)',
        'Asia/Bahrain' => 'Hora àrab (Bahrain)',
        'Asia/Baku' => 'Hora de l’Azerbaidjan (Bakú)',
        'Asia/Bangkok' => 'Hora de l’Indoxina (Bangkok)',
        'Asia/Barnaul' => 'Hora de Krasnoiarsk (Barnaül)',
        'Asia/Beirut' => 'Hora d’Europa oriental (Beirut)',
        'Asia/Bishkek' => 'Hora del Kirguizstan (Bishkek)',
        'Asia/Brunei' => 'Hora de Brunei Darussalam',
        'Asia/Calcutta' => 'Hora de l’Índia (Calcuta)',
        'Asia/Kolkata' => 'Hora de l’Índia (Calcuta)',
        'Asia/Chita' => 'Hora de Iakutsk (Txità)',
        'Asia/Colombo' => 'Hora de l’Índia (Colombo)',
        'Asia/Damascus' => 'Hora d’Europa oriental (Damasc)',
        'Asia/Dhaka' => 'Hora de Bangladesh (Dhaka)',
        'Asia/Dili' => 'Hora de Timor Oriental (Dili)',
        'Asia/Dubai' => 'Hora estàndard del Golf (Dubai)',
        'Asia/Dushanbe' => 'Hora del Tadjikistan (Duixanbé)',
        'Asia/Famagusta' => 'Hora d’Europa oriental (Famagusta)',
        'Asia/Gaza' => 'Hora d’Europa oriental (Gaza)',
        'Asia/Hebron' => 'Hora d’Europa oriental (Hebron)',
        'Asia/Hong_Kong' => 'Hora de Hong Kong',
        'Asia/Hovd' => 'Hora de Khovd',
        'Asia/Irkutsk' => 'Hora d’Irkutsk',
        'Asia/Jakarta' => 'Hora de l’oest d’Indonèsia (Jakarta)',
        'Asia/Jayapura' => 'Hora de l’est d’Indonèsia (Jaipur)',
        'Asia/Jerusalem' => 'Hora d’Israel (Jerusalem)',
        'Asia/Kabul' => 'Hora de l’Afganistan (Kabul)',
        'Asia/Kamchatka' => 'Hora de Kamtxatka',
        'Asia/Karachi' => 'Hora del Pakistan (Karachi)',
        'Asia/Katmandu' => 'Hora del Nepal (Katmandú)',
        'Asia/Kathmandu' => 'Hora del Nepal (Katmandú)',
        'Asia/Khandyga' => 'Hora de Iakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Hora de Krasnoiarsk',
        'Asia/Kuala_Lumpur' => 'Hora de Malàisia (Kuala Lumpur)',
        'Asia/Kuching' => 'Hora de Malàisia (Kuching)',
        'Asia/Kuwait' => 'Hora àrab (Kuwait)',
        'Asia/Macau' => 'Hora de la Xina (Macau)',
        'Asia/Magadan' => 'Hora de Magadan',
        'Asia/Makassar' => 'Hora central d’Indonèsia (Makassar)',
        'Asia/Manila' => 'Hora de les Filipines (Manila)',
        'Asia/Muscat' => 'Hora estàndard del Golf (Masqat)',
        'Asia/Nicosia' => 'Hora d’Europa oriental (Nicòsia)',
        'Asia/Novokuznetsk' => 'Hora de Krasnoiarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Hora de Krasnoiarsk (Novossibirsk)',
        'Asia/Omsk' => 'Hora d’Omsk',
        'Asia/Oral' => 'Hora del Kazakhstan (Oral)',
        'Asia/Phnom_Penh' => 'Hora de l’Indoxina (Phnom Penh)',
        'Asia/Pontianak' => 'Hora de l’oest d’Indonèsia (Pontianak)',
        'Asia/Pyongyang' => 'Hora de Corea (Pyongyang)',
        'Asia/Qatar' => 'Hora àrab (Qatar)',
        'Asia/Qostanay' => 'Hora del Kazakhstan (Qostanai)',
        'Asia/Qyzylorda' => 'Hora del Kazakhstan (Qyzylorda)',
        'Asia/Rangoon' => 'Hora de Myanmar (Yangon)',
        'Asia/Yangon' => 'Hora de Myanmar (Yangon)',
        'Asia/Riyadh' => 'Hora àrab (Riad)',
        'Asia/Saigon' => 'Hora de l’Indoxina (Hồ Chí Minh)',
        'Asia/Ho_Chi_Minh' => 'Hora de l’Indoxina (Hồ Chí Minh)',
        'Asia/Sakhalin' => 'Hora de Magadan (Sakhalín)',
        'Asia/Samarkand' => 'Hora de l’Uzbekistan (Samarcanda)',
        'Asia/Seoul' => 'Hora de Corea (Seül)',
        'Asia/Shanghai' => 'Hora de la Xina (Shanghai)',
        'Asia/Singapore' => 'Hora de Singapur',
        'Asia/Srednekolymsk' => 'Hora de Magadan (Srednekolimsk)',
        'Asia/Taipei' => 'Hora de Taipei',
        'Asia/Tashkent' => 'Hora de l’Uzbekistan (Taixkent)',
        'Asia/Tbilisi' => 'Hora de Geòrgia (Tbilisi)',
        'Asia/Tehran' => 'Hora de l’Iran (Teheran)',
        'Asia/Thimphu' => 'Hora de Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Hora del Japó (Tòquio)',
        'Asia/Tomsk' => 'Hora de Krasnoiarsk (Tomsk)',
        'Asia/Ulaanbaatar' => 'Hora d’Ulaanbaatar',
        'Asia/Urumqi' => 'Hora de: Xina (Ürümchi)',
        'Asia/Ust-Nera' => 'Hora de Vladivostok (Ust’-Nera)',
        'Asia/Vientiane' => 'Hora de l’Indoxina (Vientiane)',
        'Asia/Vladivostok' => 'Hora de Vladivostok',
        'Asia/Yakutsk' => 'Hora de Iakutsk',
        'Asia/Yekaterinburg' => 'Hora de Iekaterinburg',
        'Asia/Yerevan' => 'Hora d’Armènia (Yerevan)',
        'Atlantic/Azores' => 'Hora de les Açores',
        'Atlantic/Bermuda' => 'Hora de l’Atlàntic (Bermudes)',
        'Atlantic/Canary' => 'Hora d’Europa occidental (Illes Canàries)',
        'Atlantic/Cape_Verde' => 'Hora de Cap Verd',
        'Atlantic/Faeroe' => 'Hora d’Europa occidental (Illes Fèroe)',
        'Atlantic/Faroe' => 'Hora d’Europa occidental (Illes Fèroe)',
        'Atlantic/Madeira' => 'Hora d’Europa occidental (Madeira)',
        'Atlantic/Reykjavik' => 'Hora del meridià de Greenwich (Reykjavík)',
        'Atlantic/South_Georgia' => 'Hora de Geòrgia del Sud',
        'Atlantic/St_Helena' => 'Hora del meridià de Greenwich (Saint Helena)',
        'Atlantic/Stanley' => 'Hora de les illes Falkland (Stanley)',
        'Australia/Adelaide' => 'Hora d’Austràlia central (Adelaide)',
        'Australia/Brisbane' => 'Hora d’Austràlia oriental (Brisbane)',
        'Australia/Broken_Hill' => 'Hora d’Austràlia central (Broken Hill)',
        'Australia/Darwin' => 'Hora d’Austràlia central (Darwin)',
        'Australia/Eucla' => 'Hora d’Austràlia centre-occidental (Eucla)',
        'Australia/Hobart' => 'Hora d’Austràlia oriental (Hobart)',
        'Australia/Lindeman' => 'Hora d’Austràlia oriental (Lindeman)',
        'Australia/Lord_Howe' => 'Hora de Lord Howe',
        'Australia/Melbourne' => 'Hora d’Austràlia oriental (Melbourne)',
        'Australia/Perth' => 'Hora d’Austràlia occidental (Perth)',
        'Australia/Sydney' => 'Hora d’Austràlia oriental (Sydney)',
        'Etc/GMT' => 'Hora del meridià de Greenwich',
        'Etc/UTC' => 'Temps universal coordinat',
        'Europe/Amsterdam' => 'Hora d’Europa central (Amsterdam)',
        'Europe/Andorra' => 'Hora d’Europa central (Andorra)',
        'Europe/Astrakhan' => 'Hora de Samara (Astracan)',
        'Europe/Athens' => 'Hora d’Europa oriental (Atenes)',
        'Europe/Belgrade' => 'Hora d’Europa central (Belgrad)',
        'Europe/Berlin' => 'Hora d’Europa central (Berlín)',
        'Europe/Bratislava' => 'Hora d’Europa central (Bratislava)',
        'Europe/Brussels' => 'Hora d’Europa central (Brussel·les)',
        'Europe/Bucharest' => 'Hora d’Europa oriental (Bucarest)',
        'Europe/Budapest' => 'Hora d’Europa central (Budapest)',
        'Europe/Busingen' => 'Hora d’Europa central (Büsingen)',
        'Europe/Chisinau' => 'Hora d’Europa oriental (Chișinău)',
        'Europe/Copenhagen' => 'Hora d’Europa central (Copenhaguen)',
        'Europe/Dublin' => 'Hora del meridià de Greenwich (Dublín)',
        'Europe/Gibraltar' => 'Hora d’Europa central (Gibraltar)',
        'Europe/Guernsey' => 'Hora del meridià de Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Hora d’Europa oriental (Hèlsinki)',
        'Europe/Isle_of_Man' => 'Hora del meridià de Greenwich (Man)',
        'Europe/Istanbul' => 'Hora de Turquia (Istanbul)',
        'Europe/Jersey' => 'Hora del meridià de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Hora d’Europa oriental (Kaliningrad)',
        'Europe/Kiev' => 'Hora d’Europa oriental (Kíiv)',
        'Europe/Kyiv' => 'Hora d’Europa oriental (Kíiv)',
        'Europe/Kirov' => 'Hora de Moscou (Kírov)',
        'Europe/Lisbon' => 'Hora d’Europa occidental (Lisboa)',
        'Europe/Ljubljana' => 'Hora d’Europa central (Ljubljana)',
        'Europe/London' => 'Hora del meridià de Greenwich (Londres)',
        'Europe/Luxembourg' => 'Hora d’Europa central (Luxemburg)',
        'Europe/Madrid' => 'Hora d’Europa central (Madrid)',
        'Europe/Malta' => 'Hora d’Europa central (Malta)',
        'Europe/Mariehamn' => 'Hora d’Europa oriental (Mariehamn)',
        'Europe/Minsk' => 'Hora de Moscou (Minsk)',
        'Europe/Monaco' => 'Hora d’Europa central (Mònaco)',
        'Europe/Moscow' => 'Hora de Moscou',
        'Europe/Oslo' => 'Hora d’Europa central (Oslo)',
        'Europe/Paris' => 'Hora d’Europa central (París)',
        'Europe/Podgorica' => 'Hora d’Europa central (Podgorica)',
        'Europe/Prague' => 'Hora d’Europa central (Praga)',
        'Europe/Riga' => 'Hora d’Europa oriental (Riga)',
        'Europe/Rome' => 'Hora d’Europa central (Roma)',
        'Europe/Samara' => 'Hora de Samara',
        'Europe/San_Marino' => 'Hora d’Europa central (San Marino)',
        'Europe/Sarajevo' => 'Hora d’Europa central (Sarajevo)',
        'Europe/Saratov' => 'Hora de Samara (Saràtov)',
        'Europe/Simferopol' => 'Hora de Moscou (Simferòpol)',
        'Europe/Skopje' => 'Hora d’Europa central (Skopje)',
        'Europe/Sofia' => 'Hora d’Europa oriental (Sofia)',
        'Europe/Stockholm' => 'Hora d’Europa central (Estocolm)',
        'Europe/Tallinn' => 'Hora d’Europa oriental (Tallinn)',
        'Europe/Tirane' => 'Hora d’Europa central (Tirana)',
        'Europe/Ulyanovsk' => 'Hora de Samara (Uliànovsk)',
        'Europe/Vaduz' => 'Hora d’Europa central (Vaduz)',
        'Europe/Vatican' => 'Hora d’Europa central (Vaticà)',
        'Europe/Vienna' => 'Hora d’Europa central (Viena)',
        'Europe/Vilnius' => 'Hora d’Europa oriental (Vílnius)',
        'Europe/Volgograd' => 'Hora de Moscou (Volgograd)',
        'Europe/Warsaw' => 'Hora d’Europa central (Varsòvia)',
        'Europe/Zagreb' => 'Hora d’Europa central (Zagreb)',
        'Europe/Zurich' => 'Hora d’Europa central (Zúric)',
        'Indian/Antananarivo' => 'Hora de l’Àfrica oriental (Antananarivo)',
        'Indian/Chagos' => 'Hora de l’oceà Índic (Chagos)',
        'Indian/Christmas' => 'Hora de Kiritimati (Christmas)',
        'Indian/Cocos' => 'Hora de les illes Cocos',
        'Indian/Comoro' => 'Hora de l’Àfrica oriental (Comores)',
        'Indian/Kerguelen' => 'Hora d’Antàrtida i de les Terres Australs Antàrtiques Franceses (Kerguelen)',
        'Indian/Mahe' => 'Hora de les Seychelles (Mahé)',
        'Indian/Maldives' => 'Hora de les Maldives',
        'Indian/Mauritius' => 'Hora de Maurici',
        'Indian/Mayotte' => 'Hora de l’Àfrica oriental (Mayotte)',
        'Indian/Reunion' => 'Hora de Reunió',
        'Pacific/Apia' => 'Hora d’Apia',
        'Pacific/Auckland' => 'Hora de Nova Zelanda (Auckland)',
        'Pacific/Bougainville' => 'Hora de Papua Nova Guinea (Bougainville)',
        'Pacific/Chatham' => 'Hora de Chatham',
        'Pacific/Easter' => 'Hora de l’illa de Pasqua',
        'Pacific/Efate' => 'Hora de Vanatu (Efate)',
        'Pacific/Enderbury' => 'Hora de les illes Phoenix (Canton)',
        'Pacific/Kanton' => 'Hora de les illes Phoenix (Canton)',
        'Pacific/Fakaofo' => 'Hora de Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Hora de Fiji',
        'Pacific/Funafuti' => 'Hora de Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Hora de Galápagos',
        'Pacific/Gambier' => 'Hora de Gambier',
        'Pacific/Guadalcanal' => 'Hora de les illes Salomó (Guadalcanal)',
        'Pacific/Guam' => 'Hora estàndard de Chamorro (Guam)',
        'Pacific/Honolulu' => 'Hora estàndard de Hawaii-Aleutianes (Honolulu)',
        'Pacific/Kiritimati' => 'Hora de les illes Line (Kiritimati)',
        'Pacific/Kosrae' => 'Hora de Kosrae',
        'Pacific/Kwajalein' => 'Hora de les illes Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Hora de les illes Marshall (Majuro)',
        'Pacific/Marquesas' => 'Hora de les Marqueses',
        'Pacific/Midway' => 'Hora de Samoa (Midway)',
        'Pacific/Nauru' => 'Hora de Nauru',
        'Pacific/Niue' => 'Hora de Niue',
        'Pacific/Norfolk' => 'Hora de l’illa Norfolk',
        'Pacific/Noumea' => 'Hora de Nova Caledònia (Nouméa)',
        'Pacific/Pago_Pago' => 'Hora de Samoa (Pago Pago)',
        'Pacific/Palau' => 'Hora de Palau',
        'Pacific/Pitcairn' => 'Hora de Pitcairn',
        'Pacific/Ponape' => 'Hora de Ponape (Pohnpei)',
        'Pacific/Pohnpei' => 'Hora de Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Hora de Papua Nova Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Hora de les illes Cook (Rarotonga)',
        'Pacific/Saipan' => 'Hora estàndard de Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Hora de Tahití',
        'Pacific/Tarawa' => 'Hora de les illes Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Hora de Tonga (Tongatapu)',
        'Pacific/Truk' => 'Hora de Chuuk',
        'Pacific/Chuuk' => 'Hora de Chuuk',
        'Pacific/Wake' => 'Hora de les illes Wake',
        'Pacific/Wallis' => 'Hora de Wallis i Futuna (Wallis & Futuna)',
    ],
    'Meta' => [],
];
