<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich gaƒoƒo (Abidjan)',
        'Africa/Accra' => 'Greenwich gaƒoƒo (Accra)',
        'Africa/Addis_Ababa' => 'East Africa gaƒoƒo me (Addis Ababa)',
        'Africa/Algiers' => 'Central Europe gaƒoƒo me (Algiers)',
        'Africa/Asmera' => 'East Africa gaƒoƒo me (Asmara)',
        'Africa/Asmara' => 'East Africa gaƒoƒo me (Asmara)',
        'Africa/Bamako' => 'Greenwich gaƒoƒo (Bamako)',
        'Africa/Bangui' => 'West Africa game (Bangui)',
        'Africa/Banjul' => 'Greenwich gaƒoƒo (Banjul)',
        'Africa/Bissau' => 'Greenwich gaƒoƒo (Bissau)',
        'Africa/Blantyre' => 'Central Africa gaƒoƒo me (Blantyre)',
        'Africa/Brazzaville' => 'West Africa game (Brazzaville)',
        'Africa/Bujumbura' => 'Central Africa gaƒoƒo me (Bujumbura)',
        'Africa/Cairo' => 'Ɣedzeƒe Europe gaƒoƒome (Cairo)',
        'Africa/Casablanca' => 'Western Europe gaƒoƒo me (Casablanca)',
        'Africa/Ceuta' => 'Central Europe gaƒoƒo me (Ceuta)',
        'Africa/Conakry' => 'Greenwich gaƒoƒo (Conakry)',
        'Africa/Dakar' => 'Greenwich gaƒoƒo (Dakar)',
        'Africa/Dar_es_Salaam' => 'East Africa gaƒoƒo me (Dar es Salaam)',
        'Africa/Djibouti' => 'East Africa gaƒoƒo me (Djibouti)',
        'Africa/Douala' => 'West Africa game (Douala)',
        'Africa/El_Aaiun' => 'Western Europe gaƒoƒo me (El Aaiún)',
        'Africa/Freetown' => 'Greenwich gaƒoƒo (Freetown)',
        'Africa/Gaborone' => 'Central Africa gaƒoƒo me (Gaborone)',
        'Africa/Harare' => 'Central Africa gaƒoƒo me (Harare)',
        'Africa/Johannesburg' => 'South Africa nutome gaƒoƒo me (Johannesburg)',
        'Africa/Juba' => 'Central Africa gaƒoƒo me (Juba)',
        'Africa/Kampala' => 'East Africa gaƒoƒo me (Kampala)',
        'Africa/Khartoum' => 'Central Africa gaƒoƒo me (Khartoum)',
        'Africa/Kigali' => 'Central Africa gaƒoƒo me (Kigali)',
        'Africa/Kinshasa' => 'West Africa game (Kinshasa)',
        'Africa/Lagos' => 'West Africa game (Lagos)',
        'Africa/Libreville' => 'West Africa game (Libreville)',
        'Africa/Lome' => 'Greenwich gaƒoƒo (Lomé)',
        'Africa/Luanda' => 'West Africa game (Luanda)',
        'Africa/Lubumbashi' => 'Central Africa gaƒoƒo me (Lubumbashi)',
        'Africa/Lusaka' => 'Central Africa gaƒoƒo me (Lusaka)',
        'Africa/Malabo' => 'West Africa game (Malabo)',
        'Africa/Maputo' => 'Central Africa gaƒoƒo me (Maputo)',
        'Africa/Maseru' => 'South Africa nutome gaƒoƒo me (Maseru)',
        'Africa/Mbabane' => 'South Africa nutome gaƒoƒo me (Mbabane)',
        'Africa/Mogadishu' => 'East Africa gaƒoƒo me (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich gaƒoƒo (Monrovia)',
        'Africa/Nairobi' => 'East Africa gaƒoƒo me (Nairobi)',
        'Africa/Ndjamena' => 'West Africa game (N’Djamena)',
        'Africa/Niamey' => 'West Africa game (Niamey)',
        'Africa/Nouakchott' => 'Greenwich gaƒoƒo (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich gaƒoƒo (Ouagadougou)',
        'Africa/Porto-Novo' => 'West Africa game (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich gaƒoƒo (São Tomé)',
        'Africa/Tripoli' => 'Ɣedzeƒe Europe gaƒoƒome (Tripoli)',
        'Africa/Tunis' => 'Central Europe gaƒoƒo me (Tunis)',
        'Africa/Windhoek' => 'Central Africa gaƒoƒo me (Windhoek)',
        'America/Adak' => 'Hawaii-Aleutia gaƒoƒo me (Adak)',
        'America/Anchorage' => 'Alaska gaƒoƒome (Anchorage)',
        'America/Anguilla' => 'Atlantic gaƒoƒome (Anguilla)',
        'America/Antigua' => 'Atlantic gaƒoƒome (Antigua)',
        'America/Araguaina' => 'Brasilia gaƒoƒo me (Araguaína)',
        'America/Argentina/La_Rioja' => 'Argentina gaƒoƒo me (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentina gaƒoƒo me (Río Gallegos)',
        'America/Argentina/Salta' => 'Argentina gaƒoƒo me (Salta)',
        'America/Argentina/San_Juan' => 'Argentina gaƒoƒo me (San Juan)',
        'America/Argentina/San_Luis' => 'Argentina gaƒoƒo me (San Luis)',
        'America/Argentina/Tucuman' => 'Argentina gaƒoƒo me (Tucumán)',
        'America/Argentina/Ushuaia' => 'Argentina gaƒoƒo me (Ushuaia)',
        'America/Aruba' => 'Atlantic gaƒoƒome (Aruba)',
        'America/Asuncion' => 'Paraguay gaƒoƒo me (Asunción)',
        'America/Bahia' => 'Brasilia gaƒoƒo me (Bahia)',
        'America/Bahia_Banderas' => 'Titina America gaƒoƒome (Bahia Banderas)',
        'America/Barbados' => 'Atlantic gaƒoƒome (Barbados)',
        'America/Belem' => 'Brasilia gaƒoƒo me (Belém)',
        'America/Belize' => 'Titina America gaƒoƒome (Belize)',
        'America/Blanc-Sablon' => 'Atlantic gaƒoƒome (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazon gaƒoƒome (Boa Vista)',
        'America/Bogota' => 'Colombia gaƒoƒo me (Bogotá)',
        'America/Boise' => 'Mountain gaƒoƒo me (Boise)',
        'America/Buenos_Aires' => 'Argentina gaƒoƒo me (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Argentina gaƒoƒo me (Buenos Aires)',
        'America/Cambridge_Bay' => 'Mountain gaƒoƒo me (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazon gaƒoƒome (Campo Grande)',
        'America/Cancun' => 'Eastern America gaƒoƒo me (Cancun)',
        'America/Caracas' => 'Venezuela gaƒoƒo me (Caracas)',
        'America/Catamarca' => 'Argentina gaƒoƒo me (Catamarca)',
        'America/Argentina/Catamarca' => 'Argentina gaƒoƒo me (Catamarca)',
        'America/Cayenne' => 'French Guiana gaƒoƒo me (Cayenne)',
        'America/Cayman' => 'Eastern America gaƒoƒo me (Cayman)',
        'America/Chicago' => 'Titina America gaƒoƒome (Chicago)',
        'America/Chihuahua' => 'Titina America gaƒoƒome (Chihuahua)',
        'America/Ciudad_Juarez' => 'Mountain gaƒoƒo me (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Eastern America gaƒoƒo me (Atikokan)',
        'America/Atikokan' => 'Eastern America gaƒoƒo me (Atikokan)',
        'America/Cordoba' => 'Argentina gaƒoƒo me (Córdoba)',
        'America/Argentina/Cordoba' => 'Argentina gaƒoƒo me (Córdoba)',
        'America/Costa_Rica' => 'Titina America gaƒoƒome (Costa Rica)',
        'America/Coyhaique' => 'Chile gaƒoƒo me (Coyhaique)',
        'America/Creston' => 'Mountain gaƒoƒo me (Creston)',
        'America/Cuiaba' => 'Amazon gaƒoƒome (Cuiabá)',
        'America/Curacao' => 'Atlantic gaƒoƒome (Curaçao)',
        'America/Danmarkshavn' => 'Greenwich gaƒoƒo (Danmarkshavn)',
        'America/Dawson' => 'Canada nutome game (Dawson)',
        'America/Dawson_Creek' => 'Mountain gaƒoƒo me (Dawson Creek)',
        'America/Denver' => 'Mountain gaƒoƒo me (Denver)',
        'America/Detroit' => 'Eastern America gaƒoƒo me (Detroit)',
        'America/Dominica' => 'Atlantic gaƒoƒome (Dominica)',
        'America/Edmonton' => 'Mountain gaƒoƒo me (Edmonton)',
        'America/Eirunepe' => 'Brazil nutome game (Eirunepé)',
        'America/El_Salvador' => 'Titina America gaƒoƒome (El Salvador)',
        'America/Fort_Nelson' => 'Mountain gaƒoƒo me (Fort Nelson)',
        'America/Fortaleza' => 'Brasilia gaƒoƒo me (Fortaleza)',
        'America/Glace_Bay' => 'Atlantic gaƒoƒome (Glace Bay)',
        'America/Godthab' => 'Grinland nutome game (Nuuk)',
        'America/Nuuk' => 'Grinland nutome game (Nuuk)',
        'America/Goose_Bay' => 'Atlantic gaƒoƒome (Goose Bay)',
        'America/Grand_Turk' => 'Eastern America gaƒoƒo me (Grand Turk)',
        'America/Grenada' => 'Atlantic gaƒoƒome (Grenada)',
        'America/Guadeloupe' => 'Atlantic gaƒoƒome (Guadeloupe)',
        'America/Guatemala' => 'Titina America gaƒoƒome (Guatemala)',
        'America/Guayaquil' => 'Ecuador gaƒoƒo me (Guayaquil)',
        'America/Guyana' => 'Guyana gaƒoƒo me',
        'America/Halifax' => 'Atlantic gaƒoƒome (Halifax)',
        'America/Havana' => 'Cuba gaƒoƒome (Havana)',
        'America/Hermosillo' => 'Mexican Pacific gaƒoƒo me (Hermosillo)',
        'America/Indiana/Knox' => 'Titina America gaƒoƒome (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Eastern America gaƒoƒo me (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Eastern America gaƒoƒo me (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Titina America gaƒoƒome (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Eastern America gaƒoƒo me (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Eastern America gaƒoƒo me (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Eastern America gaƒoƒo me (Winamac, Indiana)',
        'America/Indianapolis' => 'Eastern America gaƒoƒo me (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Eastern America gaƒoƒo me (Indianapolis)',
        'America/Inuvik' => 'Mountain gaƒoƒo me (Inuvik)',
        'America/Iqaluit' => 'Eastern America gaƒoƒo me (Iqaluit)',
        'America/Jamaica' => 'Eastern America gaƒoƒo me (Jamaica)',
        'America/Jujuy' => 'Argentina gaƒoƒo me (Jujuy)',
        'America/Argentina/Jujuy' => 'Argentina gaƒoƒo me (Jujuy)',
        'America/Juneau' => 'Alaska gaƒoƒome (Juneau)',
        'America/Kentucky/Monticello' => 'Eastern America gaƒoƒo me (Monticello, Kentucky)',
        'America/Kralendijk' => 'Atlantic gaƒoƒome (Kralendijk)',
        'America/La_Paz' => 'Bolivia gaƒoƒo me (La Paz)',
        'America/Lima' => 'Peru gaƒoƒo me (Lima)',
        'America/Los_Angeles' => 'Pacific gaƒoƒome (Los Angeles)',
        'America/Louisville' => 'Eastern America gaƒoƒo me (Louisville)',
        'America/Kentucky/Louisville' => 'Eastern America gaƒoƒo me (Louisville)',
        'America/Lower_Princes' => 'Atlantic gaƒoƒome (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasilia gaƒoƒo me (Maceió)',
        'America/Managua' => 'Titina America gaƒoƒome (Managua)',
        'America/Manaus' => 'Amazon gaƒoƒome (Manaus)',
        'America/Marigot' => 'Atlantic gaƒoƒome (Marigot)',
        'America/Martinique' => 'Atlantic gaƒoƒome (Martinique)',
        'America/Matamoros' => 'Titina America gaƒoƒome (Matamoros)',
        'America/Mazatlan' => 'Mexican Pacific gaƒoƒo me (Mazatlán)',
        'America/Mendoza' => 'Argentina gaƒoƒo me (Mendoza)',
        'America/Argentina/Mendoza' => 'Argentina gaƒoƒo me (Mendoza)',
        'America/Menominee' => 'Titina America gaƒoƒome (Menominee)',
        'America/Merida' => 'Titina America gaƒoƒome (Merida)',
        'America/Metlakatla' => 'Alaska gaƒoƒome (Metlakatla)',
        'America/Mexico_City' => 'Titina America gaƒoƒome (Ciudad de México)',
        'America/Miquelon' => 'St. Pierre & Miquelon gaƒoƒome (Saint-Pierre)',
        'America/Moncton' => 'Atlantic gaƒoƒome (Moncton)',
        'America/Monterrey' => 'Titina America gaƒoƒome (Monterrey)',
        'America/Montevideo' => 'Uruguay gaƒoƒo me (Montevideo)',
        'America/Montserrat' => 'Atlantic gaƒoƒome (Montserrat)',
        'America/Nassau' => 'Eastern America gaƒoƒo me (Nassau)',
        'America/New_York' => 'Eastern America gaƒoƒo me (New York)',
        'America/Nome' => 'Alaska gaƒoƒome (Nome)',
        'America/Noronha' => 'Fernando de Noronha gaƒoƒo me',
        'America/North_Dakota/Beulah' => 'Titina America gaƒoƒome (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Titina America gaƒoƒome (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Titina America gaƒoƒome (New Salem, North Dakota)',
        'America/Ojinaga' => 'Titina America gaƒoƒome (Ojinaga)',
        'America/Panama' => 'Eastern America gaƒoƒo me (Panama)',
        'America/Paramaribo' => 'Suriname gaƒoƒome (Paramaribo)',
        'America/Phoenix' => 'Mountain gaƒoƒo me (Phoenix)',
        'America/Port-au-Prince' => 'Eastern America gaƒoƒo me (Port-au-Prince)',
        'America/Port_of_Spain' => 'Atlantic gaƒoƒome (Port of Spain)',
        'America/Porto_Velho' => 'Amazon gaƒoƒome (Porto Velho)',
        'America/Puerto_Rico' => 'Atlantic gaƒoƒome (Puerto Rico)',
        'America/Punta_Arenas' => 'Chile gaƒoƒo me (Punta Arenas)',
        'America/Rankin_Inlet' => 'Titina America gaƒoƒome (Rankin Inlet)',
        'America/Recife' => 'Brasilia gaƒoƒo me (Recife)',
        'America/Regina' => 'Titina America gaƒoƒome (Regina)',
        'America/Resolute' => 'Titina America gaƒoƒome (Resolute)',
        'America/Rio_Branco' => 'Brazil nutome game (Rio Branco)',
        'America/Santarem' => 'Brasilia gaƒoƒo me (Santarém)',
        'America/Santiago' => 'Chile gaƒoƒo me (Santiago)',
        'America/Santo_Domingo' => 'Atlantic gaƒoƒome (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasilia gaƒoƒo me (São Paulo)',
        'America/Scoresbysund' => 'Grinland nutome game (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaska gaƒoƒome (Sitka)',
        'America/St_Barthelemy' => 'Atlantic gaƒoƒome (St. Barthélemy)',
        'America/St_Johns' => 'Newfoundland gaƒoƒome (St. John’s)',
        'America/St_Kitts' => 'Atlantic gaƒoƒome (St. Kitts)',
        'America/St_Lucia' => 'Atlantic gaƒoƒome (St. Lucia)',
        'America/St_Thomas' => 'Atlantic gaƒoƒome (St. Thomas)',
        'America/St_Vincent' => 'Atlantic gaƒoƒome (St. Vincent)',
        'America/Swift_Current' => 'Titina America gaƒoƒome (Swift Current)',
        'America/Tegucigalpa' => 'Titina America gaƒoƒome (Tegucigalpa)',
        'America/Thule' => 'Atlantic gaƒoƒome (Thule)',
        'America/Tijuana' => 'Pacific gaƒoƒome (Tijuana)',
        'America/Toronto' => 'Eastern America gaƒoƒo me (Toronto)',
        'America/Tortola' => 'Atlantic gaƒoƒome (Tortola)',
        'America/Vancouver' => 'Pacific gaƒoƒome (Vancouver)',
        'America/Whitehorse' => 'Canada nutome game (Whitehorse)',
        'America/Winnipeg' => 'Titina America gaƒoƒome (Winnipeg)',
        'America/Yakutat' => 'Alaska gaƒoƒome (Yakutat)',
        'Antarctica/Casey' => 'Western Australia gaƒoƒo me (Casey)',
        'Antarctica/Davis' => 'Davis gaƒoƒo me',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urville gaƒoƒo me',
        'Antarctica/Macquarie' => 'Eastern Australia gaƒoƒo me (Macquarie)',
        'Antarctica/Mawson' => 'Mawson gaƒoƒo me',
        'Antarctica/McMurdo' => 'New Zealand gaƒoƒo me (McMurdo)',
        'Antarctica/Palmer' => 'Chile gaƒoƒo me (Palmer)',
        'Antarctica/Rothera' => 'Rothera gaƒoƒo me',
        'Antarctica/Syowa' => 'Syowa gaƒoƒo me (Showa)',
        'Antarctica/Troll' => 'Greenwich gaƒoƒo (Troll)',
        'Antarctica/Vostok' => 'Vostok gaƒoƒo me',
        'Arctic/Longyearbyen' => 'Central Europe gaƒoƒo me (Longyearbyen)',
        'Asia/Aden' => 'Arabia gaƒoƒo me (Aden)',
        'Asia/Almaty' => 'Kazakstan nutome game (Almaty)',
        'Asia/Amman' => 'Ɣedzeƒe Europe gaƒoƒome (Amman)',
        'Asia/Anadyr' => 'Russia nutome game (Anadyr)',
        'Asia/Aqtau' => 'Kazakstan nutome game (Aqtau)',
        'Asia/Aqtobe' => 'Kazakstan nutome game (Aqtobe)',
        'Asia/Ashgabat' => 'Turkmenistan gaƒoƒo me (Ashgabat)',
        'Asia/Atyrau' => 'Kazakstan nutome game (Atyrau)',
        'Asia/Baghdad' => 'Arabia gaƒoƒo me (Baghdad)',
        'Asia/Bahrain' => 'Arabia gaƒoƒo me (Bahrain)',
        'Asia/Baku' => 'Azerbaijan gaƒoƒo me (Baku)',
        'Asia/Bangkok' => 'Indonesia gaƒoƒo me (Bangkok)',
        'Asia/Barnaul' => 'Krasnoyarsk gaƒoƒo me (Barnaul)',
        'Asia/Beirut' => 'Ɣedzeƒe Europe gaƒoƒome (Beirut)',
        'Asia/Bishkek' => 'Kyrgystan gaƒoƒo me (Bishkek)',
        'Asia/Brunei' => 'Brunei Darussalam gaƒoƒo me',
        'Asia/Calcutta' => 'India gaƒoƒo me (Kolkata)',
        'Asia/Kolkata' => 'India gaƒoƒo me (Kolkata)',
        'Asia/Chita' => 'Yakutsk gaƒoƒo me (Chita)',
        'Asia/Colombo' => 'India gaƒoƒo me (Colombo)',
        'Asia/Damascus' => 'Ɣedzeƒe Europe gaƒoƒome (Damascus)',
        'Asia/Dhaka' => 'Bangladesh gaƒoƒo me (Dhaka)',
        'Asia/Dili' => 'East Timor gaƒoƒo me (Dili)',
        'Asia/Dubai' => 'Gulf nutome gaƒoƒo me (Dubai)',
        'Asia/Dushanbe' => 'Tajikistan gaƒoƒo me (Dushanbe)',
        'Asia/Famagusta' => 'Ɣedzeƒe Europe gaƒoƒome (Famagusta)',
        'Asia/Gaza' => 'Ɣedzeƒe Europe gaƒoƒome (Gaza)',
        'Asia/Hebron' => 'Ɣedzeƒe Europe gaƒoƒome (Hebron)',
        'Asia/Hong_Kong' => 'Hong Kong gaƒoƒo me',
        'Asia/Hovd' => 'Hovd gaƒoƒo me (Khovd)',
        'Asia/Irkutsk' => 'Irkutsk gaƒoƒo me',
        'Asia/Jakarta' => 'Western Indonesia gaƒoƒo me (Jakarta)',
        'Asia/Jayapura' => 'Eastern Indonesia gaƒoƒo me (Jayapura)',
        'Asia/Jerusalem' => 'Israel gaƒoƒo me (Jerusalem)',
        'Asia/Kabul' => 'Afghanistan gaƒoƒo me (Kabul)',
        'Asia/Kamchatka' => 'Russia nutome game (Kamchatka)',
        'Asia/Karachi' => 'Pakistan gaƒoƒo me (Karachi)',
        'Asia/Katmandu' => 'Nepal gaƒoƒo me (Kathmandu nutomegaƒoƒome)',
        'Asia/Kathmandu' => 'Nepal gaƒoƒo me (Kathmandu nutomegaƒoƒome)',
        'Asia/Khandyga' => 'Yakutsk gaƒoƒo me (Khandyga)',
        'Asia/Krasnoyarsk' => 'Krasnoyarsk gaƒoƒo me',
        'Asia/Kuala_Lumpur' => 'Malaysia gaƒoƒo me (Kuala Lumpur)',
        'Asia/Kuching' => 'Malaysia gaƒoƒo me (Kuching)',
        'Asia/Kuwait' => 'Arabia gaƒoƒo me (Kuwait)',
        'Asia/Macau' => 'China gaƒoƒo me (Macau)',
        'Asia/Magadan' => 'Magadan gaƒoƒo me',
        'Asia/Makassar' => 'Central Indonesia gaƒoƒo me (Makassar)',
        'Asia/Manila' => 'Philippine gaƒoƒo me (Manila)',
        'Asia/Muscat' => 'Gulf nutome gaƒoƒo me (Muscat)',
        'Asia/Nicosia' => 'Ɣedzeƒe Europe gaƒoƒome (Nicosia)',
        'Asia/Novokuznetsk' => 'Krasnoyarsk gaƒoƒo me (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Krasnoyarsk gaƒoƒo me (Novosibirsk)',
        'Asia/Omsk' => 'Omsk gaƒoƒo me',
        'Asia/Oral' => 'Kazakstan nutome game (Oral)',
        'Asia/Phnom_Penh' => 'Indonesia gaƒoƒo me (Phnom Penh)',
        'Asia/Pontianak' => 'Western Indonesia gaƒoƒo me (Pontianak)',
        'Asia/Pyongyang' => 'Korea gaƒoƒo me (Pyongyang)',
        'Asia/Qatar' => 'Arabia gaƒoƒo me (Qatar)',
        'Asia/Qostanay' => 'Kazakstan nutome game (Qostanay)',
        'Asia/Qyzylorda' => 'Kazakstan nutome game (Qyzylorda)',
        'Asia/Rangoon' => 'Myanmar gaƒoƒo me (Yangon)',
        'Asia/Yangon' => 'Myanmar gaƒoƒo me (Yangon)',
        'Asia/Riyadh' => 'Arabia gaƒoƒo me (Riyadh)',
        'Asia/Saigon' => 'Indonesia gaƒoƒo me (Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'Indonesia gaƒoƒo me (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Magadan gaƒoƒo me (Sakhalin)',
        'Asia/Samarkand' => 'Uzbekistan gaƒoƒo me (Samarkand)',
        'Asia/Seoul' => 'Korea gaƒoƒo me (Seoul)',
        'Asia/Shanghai' => 'China gaƒoƒo me (Shanghai)',
        'Asia/Singapore' => 'Singapore nutome gaƒoƒo me',
        'Asia/Srednekolymsk' => 'Magadan gaƒoƒo me (Srednekolymsk)',
        'Asia/Taipei' => 'Taipei gaƒoƒo me',
        'Asia/Tashkent' => 'Uzbekistan gaƒoƒo me (Tashkent)',
        'Asia/Tbilisi' => 'Georgia gaƒoƒo me (Tbilisi)',
        'Asia/Tehran' => 'Iran gaƒoƒo me (Tehran)',
        'Asia/Thimphu' => 'Bhutan gaƒoƒo me (Thimphu)',
        'Asia/Tokyo' => 'Japan gaƒoƒo me (Tokyo)',
        'Asia/Tomsk' => 'Krasnoyarsk gaƒoƒo me (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulan Bator gaƒoƒo me (Ulaanbaatar)',
        'Asia/Urumqi' => 'Tsaina nutome game (Ürümqi)',
        'Asia/Ust-Nera' => 'Vladivostok gaƒoƒo me (Ust-Nera)',
        'Asia/Vientiane' => 'Indonesia gaƒoƒo me (Vientiane)',
        'Asia/Vladivostok' => 'Vladivostok gaƒoƒo me',
        'Asia/Yakutsk' => 'Yakutsk gaƒoƒo me',
        'Asia/Yekaterinburg' => 'Yekaterinburg gaƒoƒo me',
        'Asia/Yerevan' => 'Armenia gaƒoƒo me (Yerevan)',
        'Atlantic/Azores' => 'Azores gaƒoƒo me',
        'Atlantic/Bermuda' => 'Atlantic gaƒoƒome (Bermuda)',
        'Atlantic/Canary' => 'Western Europe gaƒoƒo me (Canarias)',
        'Atlantic/Cape_Verde' => 'Cape Verde gaƒoƒo me',
        'Atlantic/Faeroe' => 'Western Europe gaƒoƒo me (Faroe)',
        'Atlantic/Faroe' => 'Western Europe gaƒoƒo me (Faroe)',
        'Atlantic/Madeira' => 'Western Europe gaƒoƒo me (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich gaƒoƒo (Reykjavik)',
        'Atlantic/South_Georgia' => 'South Georgia gaƒoƒo me',
        'Atlantic/St_Helena' => 'Greenwich gaƒoƒo (St. Helena)',
        'Atlantic/Stanley' => 'Falkland Islands gaƒoƒo me (Stanley)',
        'Australia/Adelaide' => 'Central Australia gaƒoƒo me (Adelaide)',
        'Australia/Brisbane' => 'Eastern Australia gaƒoƒo me (Brisbane)',
        'Australia/Broken_Hill' => 'Central Australia gaƒoƒo me (Broken Hill)',
        'Australia/Darwin' => 'Central Australia gaƒoƒo me (Darwin)',
        'Australia/Eucla' => 'Australian Central Australia ɣetoɖofe gaƒoƒo me (Eucla)',
        'Australia/Hobart' => 'Eastern Australia gaƒoƒo me (Hobart)',
        'Australia/Lindeman' => 'Eastern Australia gaƒoƒo me (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howe gaƒoƒo me',
        'Australia/Melbourne' => 'Eastern Australia gaƒoƒo me (Melbourne)',
        'Australia/Perth' => 'Western Australia gaƒoƒo me (Perth)',
        'Australia/Sydney' => 'Eastern Australia gaƒoƒo me (Sydney)',
        'Etc/GMT' => 'Greenwich gaƒoƒo',
        'Etc/UTC' => 'Xexeme gaƒoƒoɖoanyi me',
        'Europe/Amsterdam' => 'Central Europe gaƒoƒo me (Amsterdam)',
        'Europe/Andorra' => 'Central Europe gaƒoƒo me (Andorra)',
        'Europe/Astrakhan' => 'Russia nutome game (Astrakhan)',
        'Europe/Athens' => 'Ɣedzeƒe Europe gaƒoƒome (Athens)',
        'Europe/Belgrade' => 'Central Europe gaƒoƒo me (Belgrade)',
        'Europe/Berlin' => 'Central Europe gaƒoƒo me (Berlin)',
        'Europe/Bratislava' => 'Central Europe gaƒoƒo me (Bratislava)',
        'Europe/Brussels' => 'Central Europe gaƒoƒo me (Brussels)',
        'Europe/Bucharest' => 'Ɣedzeƒe Europe gaƒoƒome (Bucharest)',
        'Europe/Budapest' => 'Central Europe gaƒoƒo me (Budapest)',
        'Europe/Busingen' => 'Central Europe gaƒoƒo me (Büsingen)',
        'Europe/Chisinau' => 'Ɣedzeƒe Europe gaƒoƒome (Chișinău)',
        'Europe/Copenhagen' => 'Central Europe gaƒoƒo me (Copenhagen)',
        'Europe/Dublin' => 'Greenwich gaƒoƒo (Dublin)',
        'Europe/Gibraltar' => 'Central Europe gaƒoƒo me (Gibraltar)',
        'Europe/Guernsey' => 'Greenwich gaƒoƒo (Guernsey)',
        'Europe/Helsinki' => 'Ɣedzeƒe Europe gaƒoƒome (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwich gaƒoƒo (Isle of Man)',
        'Europe/Istanbul' => 'Tɛki nutome game (Istanbul)',
        'Europe/Jersey' => 'Greenwich gaƒoƒo (Jersey)',
        'Europe/Kaliningrad' => 'Ɣedzeƒe Europe gaƒoƒome (Kaliningrad)',
        'Europe/Kiev' => 'Ɣedzeƒe Europe gaƒoƒome (Kiev)',
        'Europe/Kyiv' => 'Ɣedzeƒe Europe gaƒoƒome (Kiev)',
        'Europe/Kirov' => 'Moscow gaƒoƒo me (Kirov)',
        'Europe/Lisbon' => 'Western Europe gaƒoƒo me (Lisbon)',
        'Europe/Ljubljana' => 'Central Europe gaƒoƒo me (Ljubljana)',
        'Europe/London' => 'Greenwich gaƒoƒo (London)',
        'Europe/Luxembourg' => 'Central Europe gaƒoƒo me (Luxembourg)',
        'Europe/Madrid' => 'Central Europe gaƒoƒo me (Madrid)',
        'Europe/Malta' => 'Central Europe gaƒoƒo me (Malta)',
        'Europe/Mariehamn' => 'Ɣedzeƒe Europe gaƒoƒome (Mariehamn)',
        'Europe/Minsk' => 'Moscow gaƒoƒo me (Minsk)',
        'Europe/Monaco' => 'Central Europe gaƒoƒo me (Monaco)',
        'Europe/Moscow' => 'Moscow gaƒoƒo me',
        'Europe/Oslo' => 'Central Europe gaƒoƒo me (Oslo)',
        'Europe/Paris' => 'Central Europe gaƒoƒo me (Paris)',
        'Europe/Podgorica' => 'Central Europe gaƒoƒo me (Podgorica)',
        'Europe/Prague' => 'Central Europe gaƒoƒo me (Prague)',
        'Europe/Riga' => 'Ɣedzeƒe Europe gaƒoƒome (Riga)',
        'Europe/Rome' => 'Central Europe gaƒoƒo me (Rome)',
        'Europe/Samara' => 'Russia nutome game (Samara)',
        'Europe/San_Marino' => 'Central Europe gaƒoƒo me (San Marino)',
        'Europe/Sarajevo' => 'Central Europe gaƒoƒo me (Sarajevo)',
        'Europe/Saratov' => 'Russia nutome game (Saratov)',
        'Europe/Simferopol' => 'Moscow gaƒoƒo me (Simferopol)',
        'Europe/Skopje' => 'Central Europe gaƒoƒo me (Skopje)',
        'Europe/Sofia' => 'Ɣedzeƒe Europe gaƒoƒome (Sofia)',
        'Europe/Stockholm' => 'Central Europe gaƒoƒo me (Stockholm)',
        'Europe/Tallinn' => 'Ɣedzeƒe Europe gaƒoƒome (Tallinn)',
        'Europe/Tirane' => 'Central Europe gaƒoƒo me (Tirana)',
        'Europe/Ulyanovsk' => 'Russia nutome game (Ulyanovsk)',
        'Europe/Vaduz' => 'Central Europe gaƒoƒo me (Vaduz)',
        'Europe/Vatican' => 'Central Europe gaƒoƒo me (Vatican)',
        'Europe/Vienna' => 'Central Europe gaƒoƒo me (Vienna)',
        'Europe/Vilnius' => 'Ɣedzeƒe Europe gaƒoƒome (Vilnius)',
        'Europe/Volgograd' => 'Moscow gaƒoƒo me (Volgograd)',
        'Europe/Warsaw' => 'Central Europe gaƒoƒo me (Warsaw)',
        'Europe/Zagreb' => 'Central Europe gaƒoƒo me (Zagreb)',
        'Europe/Zurich' => 'Central Europe gaƒoƒo me (Zurich)',
        'Indian/Antananarivo' => 'East Africa gaƒoƒo me (Antananarivo)',
        'Indian/Chagos' => 'Indian Ocean gaƒoƒo me (Chagos)',
        'Indian/Christmas' => 'Christmas Island gaƒoƒo me',
        'Indian/Cocos' => 'Cocos Islands gaƒoƒo me',
        'Indian/Comoro' => 'East Africa gaƒoƒo me (Comores)',
        'Indian/Kerguelen' => 'French Southern & Antarctic gaƒoƒo me (Kerguelen)',
        'Indian/Mahe' => 'Seychelles gaƒoƒo me (Mahé)',
        'Indian/Maldives' => 'Maldives gaƒoƒo me',
        'Indian/Mauritius' => 'Mauritius gaƒoƒo me',
        'Indian/Mayotte' => 'East Africa gaƒoƒo me (Mayotte)',
        'Indian/Reunion' => 'Reunion gaƒoƒo me (Réunion)',
        'Pacific/Apia' => 'Apia gaƒoƒo me',
        'Pacific/Auckland' => 'New Zealand gaƒoƒo me (Auckland)',
        'Pacific/Bougainville' => 'Papua New Guinea gaƒoƒo me (Bougainville)',
        'Pacific/Chatham' => 'Chatham gaƒoƒo me',
        'Pacific/Easter' => 'Easter Island gaƒoƒo me',
        'Pacific/Efate' => 'Vanuatu gaƒoƒo me (Efate)',
        'Pacific/Enderbury' => 'Phoenix Islands gaƒoƒo me (Canton)',
        'Pacific/Kanton' => 'Phoenix Islands gaƒoƒo me (Canton)',
        'Pacific/Fakaofo' => 'Tokelau gaƒoƒo me (Fakaofo)',
        'Pacific/Fiji' => 'Fiji gaƒoƒo me',
        'Pacific/Funafuti' => 'Tuvalu gaƒoƒo me (Funafuti)',
        'Pacific/Galapagos' => 'Galapagos gaƒoƒo me (Galápagos)',
        'Pacific/Gambier' => 'Gambier gaƒoƒo me',
        'Pacific/Guadalcanal' => 'Solomon Islands gaƒoƒo me (Guadalcanal)',
        'Pacific/Guam' => 'Chamorro gaƒoƒo me (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleutia nutome gaƒoƒo me (Honolulu)',
        'Pacific/Kiritimati' => 'Line Islands gaƒoƒo me (Kiritimati)',
        'Pacific/Kosrae' => 'Kosrae gaƒoƒo me',
        'Pacific/Kwajalein' => 'Marshall Islands gaƒoƒo me (Kwajalein)',
        'Pacific/Majuro' => 'Marshall Islands gaƒoƒo me (Majuro)',
        'Pacific/Marquesas' => 'Marquesas gaƒoƒo me',
        'Pacific/Midway' => 'Samoa gaƒoƒo me (Midway)',
        'Pacific/Nauru' => 'Nauru gaƒoƒo me',
        'Pacific/Niue' => 'Niue gaƒoƒo me',
        'Pacific/Norfolk' => 'Norfolk Island gaƒoƒo me',
        'Pacific/Noumea' => 'New Caledonia gaƒoƒo me (Nouméa)',
        'Pacific/Pago_Pago' => 'Samoa gaƒoƒo me (Pago Pago)',
        'Pacific/Palau' => 'Palau gaƒoƒo me',
        'Pacific/Pitcairn' => 'Pitcairn gaƒoƒo me',
        'Pacific/Ponape' => 'Ponape gaƒoƒo me (Pohnpei)',
        'Pacific/Pohnpei' => 'Ponape gaƒoƒo me (Pohnpei)',
        'Pacific/Port_Moresby' => 'Papua New Guinea gaƒoƒo me (Port Moresby)',
        'Pacific/Rarotonga' => 'Cook Islands gaƒoƒo me (Rarotonga)',
        'Pacific/Saipan' => 'Chamorro gaƒoƒo me (Saipan)',
        'Pacific/Tahiti' => 'Tahiti gaƒoƒo me',
        'Pacific/Tarawa' => 'Gilbert Islands gaƒoƒo me (Tarawa)',
        'Pacific/Tongatapu' => 'Tonga gaƒoƒo me (Tongatapu)',
        'Pacific/Truk' => 'Chuuk gaƒoƒo me',
        'Pacific/Chuuk' => 'Chuuk gaƒoƒo me',
        'Pacific/Wake' => 'Wake Island gaƒoƒo me',
        'Pacific/Wallis' => 'Wallis & Futuna gaƒoƒo me',
    ],
    'Meta' => [
        'GmtFormat' => '%s GMT',
    ],
];
