<?php

declare(strict_types=1);

namespace SAML2\Exception;

/**
 * This exception may be raised when a violation of the SAML2 is detected
 *
 * @package simplesamlphp/saml2
 */
class ProtocolViolationException extends RuntimeException
{
}
