<?php

return [
    'Names' => [
        'Afak' => 'ئافاكا',
        'Arab' => 'ئەرەب',
        'Armi' => 'خان جەمەتى ئارامۇ',
        'Armn' => 'ئەرمەن',
        'Avst' => 'ئاۋېستا',
        'Bali' => 'بالى',
        'Bamu' => 'بامۇم',
        'Bass' => 'باسسا',
        'Batk' => 'باتاك',
        'Beng' => 'بېنگال',
        'Blis' => 'بىلىس بەلگىلىرى',
        'Bopo' => 'خەنچە پىنيىن',
        'Brah' => 'براخمى',
        'Brai' => 'برائىل ئەمالار يېزىقى',
        'Bugi' => 'بۇگى',
        'Buhd' => 'بۇخىت',
        'Cakm' => 'چاكما',
        'Cans' => 'بىرلىككە كەلگەن كانادا يەرلىك بوغۇم جەدۋىلى',
        'Cari' => 'كارىيا',
        'Cham' => 'چام',
        'Cher' => 'چېروكى',
        'Cirt' => 'كىرسچە',
        'Copt' => 'كوپتىك',
        'Cprt' => 'سىپرۇس',
        'Cyrl' => 'كىرىل',
        'Cyrs' => 'قەدىمكى چىركاۋ سىلاۋيانچە كىرىل',
        'Deva' => 'دېۋاناگارى',
        'Dsrt' => 'دېزېرېت',
        'Dupl' => 'دۇپلويان تېز خاتىرىلەش',
        'Egyd' => 'دېموتىكچە مىسىر',
        'Egyh' => 'خىيەراتىكچە مىسىر',
        'Egyp' => 'تەسۋىرىي يېزىق مىسىر',
        'Ethi' => 'ئېفىيوپىيەچە',
        'Geok' => 'خۇتسۇرى گىرۇزىنچە',
        'Geor' => 'گىرۇزىنچە',
        'Glag' => 'گىلاگوتچە',
        'Goth' => 'گوتچە',
        'Gran' => 'گىرانتاچە',
        'Grek' => 'گىرېكچە',
        'Gujr' => 'گۇجاراتچە',
        'Guru' => 'گۇرمۇكىچە',
        'Hani' => 'خەنچە',
        'Hano' => 'خانۇنۇچە',
        'Hans' => 'ئاددىي خەنچە',
        'Hant' => 'مۇرەككەپ خەنچە',
        'Hebr' => 'ئىبرانىچە',
        'Hira' => 'خىراگانا',
        'Hluw' => 'ئاناتولىيە تەسۋىرىي يېزىق',
        'Hmng' => 'مۆڭچە',
        'Hrkt' => 'ياپونچە خىراگانا ياكى كاتاكانا',
        'Hung' => 'قەدىمكى ماجارچە',
        'Inds' => 'ئىندۇسچە',
        'Ital' => 'قەدىمكى ئىتاليانچە',
        'Java' => 'ياۋاچە',
        'Jpan' => 'ياپونچە',
        'Jurc' => 'جۇرچېنچە',
        'Kali' => 'كاياھچە',
        'Kana' => 'كاتاكانا',
        'Khar' => 'كاروشتىچە',
        'Khmr' => 'كېخمېرچە',
        'Khoj' => 'خوجكىچە',
        'Knda' => 'كانناداچە',
        'Kore' => 'كورېيەچە',
        'Kpel' => 'كپېللېچە',
        'Kthi' => 'كاياتىچە',
        'Lana' => 'لانناچە',
        'Laoo' => 'لائوسچە',
        'Latf' => 'فىراكتۇر لاتىنچە',
        'Latg' => 'سىكوت لاتىنچە',
        'Latn' => 'لاتىنچە',
        'Lepc' => 'لەپچاچە',
        'Limb' => 'لىمبۇچە',
        'Lina' => 'سىزىقلىق A',
        'Linb' => 'سىزىقلىق B',
        'Lisu' => 'فراسېرچە',
        'Loma' => 'لوماچە',
        'Lyci' => 'لىسىيانچە',
        'Lydi' => 'لىدىيەچە',
        'Mand' => 'ماندائىكچە',
        'Mani' => 'مانەكېزەمچە',
        'Maya' => 'ماياچە تەسۋىرىي يېزىق',
        'Mend' => 'مېندېچە',
        'Merc' => 'مېتروئىت يازمىچە',
        'Mero' => 'مېتروئىت',
        'Mlym' => 'مالايامچە',
        'Mong' => 'موڭغۇلچە',
        'Moon' => 'كورىيە',
        'Mroo' => 'مروچە',
        'Mtei' => 'مانىپۇرىچە',
        'Mymr' => 'بىرماچە',
        'Narb' => 'قەدىمكى شىمالىي ئەرەبچە',
        'Nbat' => 'ئانباتچە',
        'Nkgb' => 'ناشىچە',
        'Nkoo' => 'نىكوچە',
        'Nshu' => 'نۈشۇچە',
        'Ogam' => 'ئوگەمچە',
        'Olck' => 'ئول-چىكىچە',
        'Orkh' => 'ئورخۇنچە',
        'Orya' => 'ئورىياچە',
        'Osma' => 'ئوسمانيە',
        'Palm' => 'پالمىراچە',
        'Perm' => 'قەدىمكى پېرمىكچە',
        'Phag' => 'پاسپاچە',
        'Phli' => 'پەھلىۋىچە ئويما خەت',
        'Phlp' => 'پەھلىۋىچە شېئىرىي تىل',
        'Phlv' => 'پەھلىۋىچە كىتابى تىل',
        'Phnx' => 'فىنىكچە',
        'Plrd' => 'پوللارد تاۋۇشلىرى',
        'Prti' => 'پارتىئانچە ئويما خەت',
        'Rjng' => 'رېجاڭچە',
        'Roro' => 'روڭگوروڭگو',
        'Runr' => 'رۇنىكچە',
        'Samr' => 'سامارىچە',
        'Sara' => 'ساراتىچە',
        'Sarb' => 'قەدىمكى جەنۇبى ئەرەبچە',
        'Saur' => 'سائۇراشتىراچە',
        'Sgnw' => 'ئىشارەت تىلى',
        'Shaw' => 'شاۋىيانچە',
        'Shrd' => 'شاراداچە',
        'Sind' => 'كۇداۋادچە',
        'Sinh' => 'سىنخالاچە',
        'Sora' => 'سورا سامپىڭ',
        'Sund' => 'سۇنداچە',
        'Sylo' => 'سىيولوتى-ناگرىچە',
        'Syrc' => 'سۈرىيەچە',
        'Syre' => 'سۈرىيەچە ئەبجەت',
        'Syrj' => 'غەربىي سۈرىيەچە',
        'Syrn' => 'شەرقىي سۈرىيەچە',
        'Tagb' => 'تاگبانۋاچە',
        'Takr' => 'تاكرىچە',
        'Tale' => 'تاي-لەچە',
        'Talu' => 'يېڭى تاي-لەچە',
        'Taml' => 'تامىلچە',
        'Tang' => 'تاڭغۇتچە',
        'Tavt' => 'تايلاندچە-ۋىيېتنامچە',
        'Telu' => 'تېلۇگۇچە',
        'Teng' => 'تېڭۋارچە',
        'Tfng' => 'تىفىناغچە',
        'Tglg' => 'تاگالوگچە',
        'Thaa' => 'تاناچە',
        'Thai' => 'تايلاندچە',
        'Tibt' => 'تىبەتچە',
        'Tirh' => 'تىرخۇتاچە',
        'Ugar' => 'ئۇگارىتىكچە',
        'Vaii' => 'ۋايچە',
        'Visp' => 'كۆرۈنۈشچان تاۋۇش',
        'Wara' => 'ۋاراڭ كىشىتى',
        'Wole' => 'ۋولىئاي',
        'Xpeo' => 'قەدىمكى پارىسچە',
        'Xsux' => 'سۇمېر-ئاككادىيان مىخ خەت',
        'Yiii' => 'يىچە',
        'Zinh' => 'ئىرسىيەت ئاتالغۇ',
        'Zmth' => 'ماتېماتىكىلىق بەلگە',
        'Zsym' => 'بەلگە',
        'Zxxx' => 'يېزىلمىغان',
        'Zyyy' => 'ئورتاق',
    ],
];
