<?php

return [
    'Names' => [
        'Adlm' => 'ايڊلام',
        'Arab' => 'عربي',
        'Aran' => 'نستعلیق',
        'Armn' => 'عرماني',
        'Beng' => 'بنگلا',
        'Bopo' => 'بوپوموفو',
        'Brai' => 'بريل',
        'Cakm' => 'چڪما',
        'Cans' => 'يونيفائيڊ ڪينيڊيئن ابارجيني سليبڪس',
        'Cher' => 'چيروڪي',
        'Cyrl' => 'سيريلي',
        'Deva' => 'ديوناگري',
        'Ethi' => 'ايٿوپيائي',
        'Geor' => 'جيورجيائي',
        'Grek' => 'يوناني',
        'Gujr' => 'گجراتي',
        'Guru' => 'گرمکي',
        'Hanb' => 'بوپوموفو سان هين',
        'Hang' => 'هنگول',
        'Hani' => 'هين',
        'Hans' => 'سادي',
        'Hant' => 'روايتي',
        'Hebr' => 'عبراني',
        'Hira' => 'هراگنا',
        'Hrkt' => 'جاپاني لکت',
        'Ital' => 'قديم اطالوي',
        'Jamo' => 'جامو',
        'Java' => 'جاوانيز',
        'Jpan' => 'جاپاني',
        'Kana' => 'ڪٽاڪانا',
        'Khmr' => 'خمر',
        'Knda' => 'ڪناڊا',
        'Kore' => 'ڪوريائي',
        'Laoo' => 'لائو',
        'Latn' => 'لاطيني',
        'Mlym' => 'ملايالم',
        'Mong' => 'منگولي',
        'Mtei' => 'ميئيٽي مائيڪ',
        'Mult' => 'ملتاني',
        'Mymr' => 'ميانمر',
        'Nkoo' => 'نڪو',
        'Olck' => 'اول چڪي',
        'Orya' => 'اوڊيا',
        'Rohg' => 'ھنيفي',
        'Sarb' => 'قديم ڏاکڻي عربي',
        'Sinh' => 'سنهالا',
        'Sund' => 'سوڊاني',
        'Syrc' => 'شامي',
        'Taml' => 'تامل',
        'Telu' => 'تلگو',
        'Tfng' => 'ٽفيناگ',
        'Thaa' => 'ٿانا',
        'Thai' => 'ٿائي',
        'Tibt' => 'تبيتن',
        'Vaii' => 'وائي',
        'Xpeo' => 'قديم فارسي',
        'Yiii' => 'يي',
        'Zmth' => 'رياضي جون نشانيون',
        'Zsye' => 'ايموجي',
        'Zsym' => 'نشانيون',
        'Zxxx' => 'اڻ لکيل',
        'Zyyy' => 'ڪامن',
    ],
];
