<?php

return [
    '😀' => 'ܦܐܬܐ ܚܕܝܬܐ',
    '😃' => 'ܦܐܬܐ ܚܕܝܬܐ ܘܥܝܢ̈ܐ ܪ̈ܒܐ',
    '😄' => 'ܦܐܬܐ ܚܕܝܬܐ ܘܥܝܢ̈ܐ ܚܕܝ̈ܐ',
    '😁' => 'ܦܐܬܐ ܒܣܝܡܬܐ ܘܥܝܢ̈ܐ ܚܕܝ̈ܐ',
    '😆' => 'ܦܐܬܐ ܚܕܝܬܐ ܘܥܝܢ̈ܐ ܐܟܝܡ̈ܐ',
    '😅' => 'ܦܐܬܐ ܚܕܝܬܐ ܘܕܘܥܬܐ',
    '🤣' => 'ܡܓܘܪܚܠܐ ܥܠ ܐܪܥܐ ܒܓܘܚܟܐ',
    '😂' => 'ܦܐܬܐ ܘܕܡܥ̈ܐ ܕܓܘܚܟܐ',
    '🙂' => 'ܦܐܬܐ ܘܒܪܣܘܡܬܐ ܦܫܝܛܬܐ',
    '🙃' => 'ܦܐܬܐ ܗܦܟܝܬܐ',
    '🫠' => 'ܦܐܬܐ ܦܫܝܪܬܐ',
    '😉' => 'ܦܐܬܐ ܪܡܝܙܬܐ',
    '😊' => 'ܦܐܬܐ ܡܒܘܪܣܡܬܐ ܘܥܝܢ̈ܐ ܚܕܝ̈ܐ',
    '😇' => 'ܦܐܬܐ ܡܒܘܪܣܡܬܐ ܘܚܘܓܬܐ',
    '🥰' => 'ܦܐܬܐ ܡܒܘܪܣܡܬܐ ܥܡ ܠܒܘ̈ܬܐ',
    '❤' => 'ܠܒܐ ܣܡܘܩܐ',
];
