<?php

return [
    'UserAssignedNames' => [
        'XK' => 'كوسوۆو',
    ],
    'Names' => [
        'AD' => 'اندوررا',
        'AE' => 'بىرىككەن اراب امىرلىكتەرى',
        'AF' => 'اۋعانستان',
        'AG' => 'انتيگۋا جانە باربۋدا',
        'AI' => 'انگيليا',
        'AL' => 'البانيا',
        'AM' => 'ارمەنيا',
        'AO' => 'انگولا',
        'AQ' => 'انتاركتيدا',
        'AR' => 'ارگەنتينا',
        'AS' => 'امەريكالىق ساموا',
        'AT' => 'اۋستريا',
        'AU' => 'اۋستراليا',
        'AW' => 'ارۋبا',
        'AX' => 'الاند ارالدارى',
        'AZ' => 'ءازىربايجان',
        'BA' => 'بوسنيا جانە گەرتسەگوۆينا',
        'BB' => 'باربادوس',
        'BD' => 'بانگلادەش',
        'BE' => 'بەلگيا',
        'BF' => 'بۋركينا-فاسو',
        'BG' => 'بولگاريا',
        'BH' => 'باحرەين',
        'BI' => 'بۋرۋندي',
        'BJ' => 'بەنين',
        'BL' => 'سان-بارتەمەلي',
        'BM' => 'بەرمۋد ارالدارى',
        'BN' => 'برۋنەي',
        'BO' => 'بوليۆيا',
        'BQ' => 'بونەير، سينت-ەستاتيۋس جانە سابا',
        'BR' => 'برازيليا',
        'BS' => 'باگام ارالدارى',
        'BT' => 'بۋتان',
        'BV' => 'بۋۆە ارالى',
        'BW' => 'بوتسۆانا',
        'BY' => 'بەلارۋس',
        'BZ' => 'بەليز',
        'CA' => 'كانادا',
        'CC' => 'كوكوس (كيليڭ) ارالدارى',
        'CD' => 'كونگو',
        'CF' => 'ورتالىق افريكا رەسپۋبليكاسى',
        'CG' => 'كونگو-براززاۆيل رەسپۋبليكاسى',
        'CH' => 'شۆەيساريا',
        'CI' => 'كوت-ديۆۋار',
        'CK' => 'كۋك ارالدارى',
        'CL' => 'چيلي',
        'CM' => 'كامەرۋن',
        'CN' => 'قىتاي',
        'CO' => 'كولۋمبيا',
        'CR' => 'كوستا-ريكا',
        'CU' => 'كۋبا',
        'CV' => 'كابو-ۆەردە',
        'CW' => 'كيۋراساو',
        'CX' => 'حريستماس ارالى',
        'CY' => 'كيپر',
        'CZ' => 'چەحيا',
        'DE' => 'گەرمانيا',
        'DJ' => 'دجيبۋتي',
        'DK' => 'دانيا',
        'DM' => 'دومينيكا',
        'DO' => 'دومينيكان رەسپۋبليكاسى',
        'DZ' => 'الجىر',
        'EC' => 'ەكۆادور',
        'EE' => 'ەستونيا',
        'EG' => 'مىسىر',
        'EH' => 'باتىس ساحارا',
        'ER' => 'ەريترەيا',
        'ES' => 'يسپانيا',
        'ET' => 'ەفيوپيا',
        'FI' => 'فينليانديا',
        'FJ' => 'فيجي',
        'FK' => 'فولكلەند ارالدارى',
        'FM' => 'ميكرونەزيا',
        'FO' => 'فارەر ارالدارى',
        'FR' => 'فرانسيا',
        'GA' => 'گابون',
        'GB' => 'ۇلىبريتانيا',
        'GD' => 'گرەنادا',
        'GE' => 'گرۋزيا',
        'GF' => 'فرانسۋز گۆياناسى',
        'GG' => 'گەرنسي',
        'GH' => 'گانا',
        'GI' => 'گيبرالتار',
        'GL' => 'گرەنلانديا',
        'GM' => 'گامبيا',
        'GN' => 'گۆەنيا',
        'GP' => 'گۆادەلۋپا',
        'GQ' => 'ەكۆاتورلىق گۆينەيا',
        'GR' => 'گرەكيا',
        'GS' => 'وڭتۇستىك گەورگيا جانە وڭتۇستىك ساندۆيچ ارالدارى',
        'GT' => 'گۆاتەمالا',
        'GU' => 'گۋان',
        'GW' => 'گۆەنيا-بيساۋ',
        'GY' => 'گايانا',
        'HK' => 'حوڭكوڭ',
        'HM' => 'حەرد ارالى جانە ماكدونالد ارالدارى',
        'HN' => 'گوندۋراس',
        'HR' => 'حورۆاتيا',
        'HT' => 'گايتي',
        'HU' => 'ماجارستان',
        'ID' => 'يندونەزيا',
        'IE' => 'يرلانديا',
        'IL' => 'يزرايل',
        'IM' => 'مەن ارالى',
        'IN' => 'ءۇندىستان',
        'IO' => 'ءۇندى مۇحيتىنداعى بريتان ايماعى',
        'IQ' => 'يراك',
        'IR' => 'يران',
        'IS' => 'يسلانديا',
        'IT' => 'يتاليا',
        'JE' => 'جەرسي',
        'JM' => 'يامايكا',
        'JO' => 'يوردانيا',
        'JP' => 'جاپونيا',
        'KE' => 'كەنيا',
        'KG' => 'قىرعىزستان',
        'KH' => 'كامباجا',
        'KI' => 'كيريباتي',
        'KM' => 'كومور ارالدارى',
        'KN' => 'سەنت-كيتس جانە نەۆيس',
        'KP' => 'سولتۇستىك كورەيا',
        'KR' => 'وڭتۇستىك كورەيا',
        'KW' => 'كۋۆەيت',
        'KY' => 'كايمان ارالدارى',
        'KZ' => 'قازاق ەلى',
        'LA' => 'لاوس',
        'LB' => 'ليۆان',
        'LC' => 'سەنت-ليۋسيا',
        'LI' => 'ليحتەنشتەين',
        'LK' => 'شري-لانكا',
        'LR' => 'ليبەريا',
        'LS' => 'لەسوتو',
        'LT' => 'ليتۆا',
        'LU' => 'ليۋكسەمبۋرگ',
        'LV' => 'لاتۆيا',
        'LY' => 'ليۆيا',
        'MA' => 'ماروككو',
        'MC' => 'موناكو',
        'MD' => 'مولدوۆا',
        'ME' => 'چەرنوگوريا',
        'MF' => 'سەن-مارتەن',
        'MG' => 'ماداگاسكار',
        'MH' => 'مارشال ارالدارى',
        'MK' => 'سولتۇستىك ماكەدونيا',
        'ML' => 'مالي',
        'MM' => 'ميانما (بيرما)',
        'MN' => 'موڭعوليا',
        'MO' => 'ماكاو',
        'MP' => 'سولتۇستىك ماريانا ارالدارى',
        'MQ' => 'مارتينيكا',
        'MR' => 'ماۆريتانيا',
        'MS' => 'مونتسەررات',
        'MT' => 'مالتا',
        'MU' => 'ماۆريكي',
        'MV' => 'مالديۆ ارالدارى',
        'MW' => 'مالاۆي',
        'MX' => 'مەكسيكا',
        'MY' => 'مالايزيا',
        'MZ' => 'موزامبيك',
        'NA' => 'ناميبيا',
        'NC' => 'جاڭا كالەدونيا',
        'NE' => 'نيگەر',
        'NF' => 'نورفولك ارالى',
        'NG' => 'نيگەريا',
        'NI' => 'نيكاراگۋا',
        'NL' => 'نيدەرلاند',
        'NO' => 'نورۆەگيا',
        'NP' => 'نەپال',
        'NR' => 'ناۋرۋ',
        'NU' => 'نيۋە',
        'NZ' => 'جاڭا زەلانديا',
        'OM' => 'ومان',
        'PA' => 'پاناما',
        'PE' => 'پەرۋ',
        'PF' => 'فرانتسۋز پولينەزياسى',
        'PG' => 'پاپۋا — جاڭا گۆينەيا',
        'PH' => 'فيليپين ارالدارى',
        'PK' => 'پاكىستان',
        'PL' => 'پولشا',
        'PM' => 'سەن-پەر جانە ميكەلون',
        'PN' => 'پيتكەرن ارالدارى',
        'PR' => 'پۋەرتو-ريكو',
        'PS' => 'پالەستينا ايماقتارى',
        'PT' => 'پورتۋگاليا',
        'PW' => 'پالاۋ',
        'PY' => 'پاراگۆاي',
        'QA' => 'كاتار',
        'RE' => 'رەيۋنيون',
        'RO' => 'رۋمىنيا',
        'RS' => 'سەربيا',
        'RU' => 'حەسەي',
        'RW' => 'رۋاندا',
        'SA' => 'ساۋد ارابياسى',
        'SB' => 'سولومون ارالدارى',
        'SC' => 'سەيشەل ارالدارى',
        'SD' => 'سۋدان',
        'SE' => 'شۆەسيا',
        'SG' => 'سينگاپۋر',
        'SH' => 'اۋليە ەلەنا ارالى',
        'SI' => 'سلوۆەنيا',
        'SJ' => 'شپيتسبەرگەن جانە يان-مايەن',
        'SK' => 'سلوۆاكيا',
        'SL' => 'سەررا-لەونە',
        'SM' => 'سان-مارينو',
        'SN' => 'سەنەگال',
        'SO' => 'سومالي',
        'SR' => 'سۋرينام',
        'SS' => 'وڭتۇستىك سۋدان',
        'ST' => 'سان-تومە جانە پرينسيپي',
        'SV' => 'سالۆادور',
        'SX' => 'سينت-مارتەن',
        'SY' => 'سيريا',
        'SZ' => 'ەسۆاتيني',
        'TC' => 'تەركس جانە كايكوس ارالدارى',
        'TD' => 'چاد',
        'TF' => 'فرانتسيانىڭ وڭتۇستىك ايماقتارى',
        'TG' => 'توگو',
        'TH' => 'تايلاند',
        'TJ' => 'تاجىكستان',
        'TK' => 'توكەلاۋ',
        'TL' => 'تيمور-لەستە',
        'TM' => 'تۇرىكمەنستان',
        'TN' => 'تۋنيس',
        'TO' => 'تونگا',
        'TR' => 'تۇركيا',
        'TT' => 'ترينيداد جانە توباگو',
        'TV' => 'تۋۆالۋ',
        'TW' => 'تايۋان',
        'TZ' => 'تانزانيا',
        'UA' => 'ۋكراينا',
        'UG' => 'ۋگاندا',
        'UM' => 'ا ق ش-تىڭ سىرتقى كىشى ارالدارى',
        'US' => 'امەريكا قۇراما شتاتتارى',
        'UY' => 'ۋرۋگۆاي',
        'UZ' => 'وزبەكستان',
        'VA' => 'ۆاتيكان',
        'VC' => 'سەنت-ۆينسەنت جانە گرەنادين ارالدارى',
        'VE' => 'ۆەنەسۋەلا',
        'VG' => 'بريتاندىق ۆيرگين ارالدارى',
        'VI' => 'ا ق ش-تىڭ ۆيرگين ارالدارى',
        'VN' => 'ۆيەتنام',
        'VU' => 'ۆانۋاتۋ',
        'WF' => 'ۋولليس جانە فۋتۋنا',
        'WS' => 'ساموا',
        'YE' => 'يەمەن',
        'YT' => 'مايوتتا',
        'ZA' => 'وڭتۇستىك افريكا',
        'ZM' => 'زامبيا',
        'ZW' => 'زيمبابۆە',
    ],
];
