<?php

return [
    'Names' => [
        'af' => 'afrîkansî',
        'af_NA' => 'afrîkansî (Namîbya)',
        'af_ZA' => 'afrîkansî (Afrîkaya Başûr)',
        'ak' => 'akanî',
        'ak_GH' => 'akanî (Gana)',
        'am' => 'amharî',
        'am_ET' => 'amharî (Etîyopya)',
        'ar' => 'erebî',
        'ar_001' => 'erebî (dinya)',
        'ar_AE' => 'erebî (Mîrgehên Erebî yên Yekbûyî)',
        'ar_BH' => 'erebî (Behreyn)',
        'ar_DJ' => 'erebî (Cîbûtî)',
        'ar_DZ' => 'erebî (Cezayîr)',
        'ar_EG' => 'erebî (Misir)',
        'ar_EH' => 'erebî (Sahraya Rojava)',
        'ar_ER' => 'erebî (Erître)',
        'ar_IL' => 'erebî (Îsraîl)',
        'ar_IQ' => 'erebî (Îraq)',
        'ar_JO' => 'erebî (Urdun)',
        'ar_KM' => 'erebî (Komor)',
        'ar_KW' => 'erebî (Kuweyt)',
        'ar_LB' => 'erebî (Libnan)',
        'ar_LY' => 'erebî (Lîbya)',
        'ar_MA' => 'erebî (Fas)',
        'ar_MR' => 'erebî (Morîtanya)',
        'ar_OM' => 'erebî (Uman)',
        'ar_PS' => 'erebî (Herêmên Filistînî)',
        'ar_QA' => 'erebî (Qeter)',
        'ar_SA' => 'erebî (Erebistana Siûdî)',
        'ar_SD' => 'erebî (Sûdan)',
        'ar_SO' => 'erebî (Somalya)',
        'ar_SS' => 'erebî (Sûdana Başûr)',
        'ar_SY' => 'erebî (Sûrîye)',
        'ar_TD' => 'erebî (Çad)',
        'ar_TN' => 'erebî (Tûnis)',
        'ar_YE' => 'erebî (Yemen)',
        'as' => 'asamî',
        'as_IN' => 'asamî (Hindistan)',
        'az' => 'azerbaycanî',
        'az_AZ' => 'azerbaycanî (Azerbeycan)',
        'az_Cyrl' => 'azerbaycanî (kirîlî)',
        'az_Cyrl_AZ' => 'azerbaycanî (kirîlî, Azerbeycan)',
        'az_Latn' => 'azerbaycanî (latînî)',
        'az_Latn_AZ' => 'azerbaycanî (latînî, Azerbeycan)',
        'ba' => 'başkîrî',
        'ba_RU' => 'başkîrî (Rûsya)',
        'be' => 'belarûsî',
        'be_BY' => 'belarûsî (Belarûs)',
        'bg' => 'bulgarî',
        'bg_BG' => 'bulgarî (Bulgaristan)',
        'bm' => 'bambarayî',
        'bm_ML' => 'bambarayî (Malî)',
        'bn' => 'bengalî',
        'bn_BD' => 'bengalî (Bengladeş)',
        'bn_IN' => 'bengalî (Hindistan)',
        'bo' => 'tîbetî',
        'bo_CN' => 'tîbetî (Çîn)',
        'bo_IN' => 'tîbetî (Hindistan)',
        'br' => 'bretonî',
        'br_FR' => 'bretonî (Fransa)',
        'bs' => 'bosnî',
        'bs_BA' => 'bosnî (Bosna û Hersek)',
        'bs_Cyrl' => 'bosnî (kirîlî)',
        'bs_Cyrl_BA' => 'bosnî (kirîlî, Bosna û Hersek)',
        'bs_Latn' => 'bosnî (latînî)',
        'bs_Latn_BA' => 'bosnî (latînî, Bosna û Hersek)',
        'ca' => 'katalanî',
        'ca_AD' => 'katalanî (Andorra)',
        'ca_ES' => 'katalanî (Spanya)',
        'ca_FR' => 'katalanî (Fransa)',
        'ca_IT' => 'katalanî (Îtalya)',
        'ce' => 'çeçenî',
        'ce_RU' => 'çeçenî (Rûsya)',
        'cs' => 'çekî',
        'cs_CZ' => 'çekî (Çekya)',
        'cv' => 'çuvaşî',
        'cv_RU' => 'çuvaşî (Rûsya)',
        'cy' => 'weylsî',
        'cy_GB' => 'weylsî (Qiralîyeta Yekbûyî)',
        'da' => 'danîmarkî',
        'da_DK' => 'danîmarkî (Danîmarka)',
        'da_GL' => 'danîmarkî (Grînlanda)',
        'de' => 'almanî',
        'de_AT' => 'almanî (Awistirya)',
        'de_BE' => 'almanî (Belçîka)',
        'de_CH' => 'almanî (Swîsre)',
        'de_DE' => 'almanî (Almanya)',
        'de_IT' => 'almanî (Îtalya)',
        'de_LI' => 'almanî (Liechtenstein)',
        'de_LU' => 'almanî (Luksembûrg)',
        'dz' => 'conxayî',
        'dz_BT' => 'conxayî (Bûtan)',
        'ee' => 'eweyî',
        'ee_GH' => 'eweyî (Gana)',
        'ee_TG' => 'eweyî (Togo)',
        'el' => 'yûnanî',
        'el_CY' => 'yûnanî (Qibris)',
        'el_GR' => 'yûnanî (Yûnanistan)',
        'en' => 'îngilîzî',
        'en_001' => 'îngilîzî (dinya)',
        'en_150' => 'îngilîzî (Ewropa)',
        'en_AE' => 'îngilîzî (Mîrgehên Erebî yên Yekbûyî)',
        'en_AG' => 'îngilîzî (Antîgua û Berbûda)',
        'en_AI' => 'îngilîzî (Anguîla)',
        'en_AS' => 'îngilîzî (Samoaya Amerîkanî)',
        'en_AT' => 'îngilîzî (Awistirya)',
        'en_AU' => 'îngilîzî (Awistralya)',
        'en_BB' => 'îngilîzî (Barbados)',
        'en_BE' => 'îngilîzî (Belçîka)',
        'en_BI' => 'îngilîzî (Bûrûndî)',
        'en_BM' => 'îngilîzî (Bermûda)',
        'en_BS' => 'îngilîzî (Bahama)',
        'en_BW' => 'îngilîzî (Botswana)',
        'en_BZ' => 'îngilîzî (Belîze)',
        'en_CA' => 'îngilîzî (Kanada)',
        'en_CC' => 'îngilîzî (Giravên Kokosê [Keeling])',
        'en_CH' => 'îngilîzî (Swîsre)',
        'en_CK' => 'îngilîzî (Giravên Cookê)',
        'en_CM' => 'îngilîzî (Kamerûn)',
        'en_CX' => 'îngilîzî (Girava Christmasê)',
        'en_CY' => 'îngilîzî (Qibris)',
        'en_CZ' => 'îngilîzî (Çekya)',
        'en_DE' => 'îngilîzî (Almanya)',
        'en_DK' => 'îngilîzî (Danîmarka)',
        'en_DM' => 'îngilîzî (Domînîka)',
        'en_EE' => 'îngilîzî (Estonya)',
        'en_ER' => 'îngilîzî (Erître)',
        'en_ES' => 'îngilîzî (Spanya)',
        'en_FI' => 'îngilîzî (Fînlenda)',
        'en_FJ' => 'îngilîzî (Fîjî)',
        'en_FK' => 'îngilîzî (Giravên Falklandê)',
        'en_FM' => 'îngilîzî (Mîkronezya)',
        'en_FR' => 'îngilîzî (Fransa)',
        'en_GB' => 'îngilîzî (Qiralîyeta Yekbûyî)',
        'en_GD' => 'îngilîzî (Grenada)',
        'en_GE' => 'îngilîzî (Gurcistan)',
        'en_GG' => 'îngilîzî (Guernsey)',
        'en_GH' => 'îngilîzî (Gana)',
        'en_GI' => 'îngilîzî (Cebelîtariq)',
        'en_GM' => 'îngilîzî (Gambîya)',
        'en_GS' => 'îngilîzî (Giravên Georgîyaya Başûr û Sandwicha Başûr)',
        'en_GU' => 'îngilîzî (Guam)',
        'en_GY' => 'îngilîzî (Guyana)',
        'en_HK' => 'îngilîzî (Hong Konga HîT ya Çînê)',
        'en_HU' => 'îngilîzî (Macaristan)',
        'en_ID' => 'îngilîzî (Endonezya)',
        'en_IE' => 'îngilîzî (Îrlanda)',
        'en_IL' => 'îngilîzî (Îsraîl)',
        'en_IM' => 'îngilîzî (Girava Manê)',
        'en_IN' => 'îngilîzî (Hindistan)',
        'en_IO' => 'îngilîzî (Herêma Okyanûsa Hindî ya Brîtanyayê)',
        'en_IT' => 'îngilîzî (Îtalya)',
        'en_JE' => 'îngilîzî (Jersey)',
        'en_JM' => 'îngilîzî (Jamaîka)',
        'en_JP' => 'îngilîzî (Japonya)',
        'en_KE' => 'îngilîzî (Kenya)',
        'en_KI' => 'îngilîzî (Kirîbatî)',
        'en_KN' => 'îngilîzî (Saint Kitts û Nevîs)',
        'en_KY' => 'îngilîzî (Giravên Kaymanê)',
        'en_LC' => 'îngilîzî (Saint Lucia)',
        'en_LR' => 'îngilîzî (Lîberya)',
        'en_LS' => 'îngilîzî (Lesoto)',
        'en_LT' => 'îngilîzî (Lîtvanya)',
        'en_LV' => 'îngilîzî (Letonya)',
        'en_MG' => 'îngilîzî (Madagaskar)',
        'en_MH' => 'îngilîzî (Giravên Marşalê)',
        'en_MO' => 'îngilîzî (Makaoya Hît ya Çînê)',
        'en_MP' => 'îngilîzî (Giravên Bakurê Marianan)',
        'en_MS' => 'îngilîzî (Montserat)',
        'en_MT' => 'îngilîzî (Malta)',
        'en_MU' => 'îngilîzî (Mauritius)',
        'en_MV' => 'îngilîzî (Maldîv)',
        'en_MW' => 'îngilîzî (Malawî)',
        'en_MY' => 'îngilîzî (Malezya)',
        'en_NA' => 'îngilîzî (Namîbya)',
        'en_NF' => 'îngilîzî (Girava Norfolkê)',
        'en_NG' => 'îngilîzî (Nîjerya)',
        'en_NL' => 'îngilîzî (Holanda)',
        'en_NO' => 'îngilîzî (Norwec)',
        'en_NR' => 'îngilîzî (Naûrû)',
        'en_NU' => 'îngilîzî (Niûe)',
        'en_NZ' => 'îngilîzî (Zelandaya Nû)',
        'en_PG' => 'îngilîzî (Papua Gîneya Nû)',
        'en_PH' => 'îngilîzî (Fîlîpîn)',
        'en_PK' => 'îngilîzî (Pakistan)',
        'en_PL' => 'îngilîzî (Polonya)',
        'en_PN' => 'îngilîzî (Giravên Pitcairnê)',
        'en_PR' => 'îngilîzî (Porto Rîko)',
        'en_PT' => 'îngilîzî (Portugal)',
        'en_PW' => 'îngilîzî (Palau)',
        'en_RO' => 'îngilîzî (Romanya)',
        'en_RW' => 'îngilîzî (Rwanda)',
        'en_SB' => 'îngilîzî (Giravên Solomonê)',
        'en_SC' => 'îngilîzî (Seyşel)',
        'en_SD' => 'îngilîzî (Sûdan)',
        'en_SE' => 'îngilîzî (Swêd)',
        'en_SG' => 'îngilîzî (Sîngapûr)',
        'en_SH' => 'îngilîzî (Saint Helena)',
        'en_SI' => 'îngilîzî (Slovenya)',
        'en_SK' => 'îngilîzî (Slovakya)',
        'en_SL' => 'îngilîzî (Sierra Leone)',
        'en_SS' => 'îngilîzî (Sûdana Başûr)',
        'en_SX' => 'îngilîzî (Sint Marteen)',
        'en_SZ' => 'îngilîzî (Eswatînî)',
        'en_TC' => 'îngilîzî (Giravên Turks û Kaîkosê)',
        'en_TK' => 'îngilîzî (Tokelau)',
        'en_TO' => 'îngilîzî (Tonga)',
        'en_TT' => 'îngilîzî (Trînîdad û Tobago)',
        'en_TV' => 'îngilîzî (Tûvalû)',
        'en_TZ' => 'îngilîzî (Tanzanya)',
        'en_UA' => 'îngilîzî (Ûkrayna)',
        'en_UG' => 'îngilîzî (Ûganda)',
        'en_UM' => 'îngilîzî (Giravên Biçûk ên Derveyî DAYê)',
        'en_US' => 'îngilîzî (Dewletên Amerîkayê yên Yekbûyî)',
        'en_VC' => 'îngilîzî (Saint Vincent û Giravên Grenadînê)',
        'en_VG' => 'îngilîzî (Giravên Vîrjînê yên Brîtanyayê)',
        'en_VI' => 'îngilîzî (Giravên Vîrjînê yên Amerîkayê)',
        'en_VU' => 'îngilîzî (Vanûatû)',
        'en_WS' => 'îngilîzî (Samoa)',
        'en_ZA' => 'îngilîzî (Afrîkaya Başûr)',
        'en_ZM' => 'îngilîzî (Zambîya)',
        'en_ZW' => 'îngilîzî (Zîmbabwe)',
        'eo' => 'esperantoyî',
        'eo_001' => 'esperantoyî (dinya)',
        'es' => 'spanî',
        'es_419' => 'spanî (Amerîkaya Latîn)',
        'es_AR' => 'spanî (Arjantîn)',
        'es_BO' => 'spanî (Bolîvya)',
        'es_BR' => 'spanî (Brezîlya)',
        'es_BZ' => 'spanî (Belîze)',
        'es_CL' => 'spanî (Şîlî)',
        'es_CO' => 'spanî (Kolombîya)',
        'es_CR' => 'spanî (Kosta Rîka)',
        'es_CU' => 'spanî (Kuba)',
        'es_DO' => 'spanî (Cimhûrîyeta Domînîkê)',
        'es_EC' => 'spanî (Ekwador)',
        'es_ES' => 'spanî (Spanya)',
        'es_GQ' => 'spanî (Gîneya Ekwadorê)',
        'es_GT' => 'spanî (Guatemala)',
        'es_HN' => 'spanî (Hondûras)',
        'es_MX' => 'spanî (Meksîka)',
        'es_NI' => 'spanî (Nîkaragua)',
        'es_PA' => 'spanî (Panama)',
        'es_PE' => 'spanî (Perû)',
        'es_PH' => 'spanî (Fîlîpîn)',
        'es_PR' => 'spanî (Porto Rîko)',
        'es_PY' => 'spanî (Paragûay)',
        'es_SV' => 'spanî (El Salvador)',
        'es_US' => 'spanî (Dewletên Amerîkayê yên Yekbûyî)',
        'es_UY' => 'spanî (Ûrûguay)',
        'es_VE' => 'spanî (Venezuela)',
        'et' => 'estonî',
        'et_EE' => 'estonî (Estonya)',
        'eu' => 'baskî',
        'eu_ES' => 'baskî (Spanya)',
        'fa' => 'farisî',
        'fa_AF' => 'farisî (Efxanistan)',
        'fa_IR' => 'farisî (Îran)',
        'ff' => 'fulahî',
        'ff_Adlm' => 'fulahî (adlamî)',
        'ff_Adlm_BF' => 'fulahî (adlamî, Burkîna Faso)',
        'ff_Adlm_CM' => 'fulahî (adlamî, Kamerûn)',
        'ff_Adlm_GH' => 'fulahî (adlamî, Gana)',
        'ff_Adlm_GM' => 'fulahî (adlamî, Gambîya)',
        'ff_Adlm_GN' => 'fulahî (adlamî, Gîne)',
        'ff_Adlm_GW' => 'fulahî (adlamî, Gîne-Bissau)',
        'ff_Adlm_LR' => 'fulahî (adlamî, Lîberya)',
        'ff_Adlm_MR' => 'fulahî (adlamî, Morîtanya)',
        'ff_Adlm_NE' => 'fulahî (adlamî, Nîjer)',
        'ff_Adlm_NG' => 'fulahî (adlamî, Nîjerya)',
        'ff_Adlm_SL' => 'fulahî (adlamî, Sierra Leone)',
        'ff_Adlm_SN' => 'fulahî (adlamî, Senegal)',
        'ff_CM' => 'fulahî (Kamerûn)',
        'ff_GN' => 'fulahî (Gîne)',
        'ff_Latn' => 'fulahî (latînî)',
        'ff_Latn_BF' => 'fulahî (latînî, Burkîna Faso)',
        'ff_Latn_CM' => 'fulahî (latînî, Kamerûn)',
        'ff_Latn_GH' => 'fulahî (latînî, Gana)',
        'ff_Latn_GM' => 'fulahî (latînî, Gambîya)',
        'ff_Latn_GN' => 'fulahî (latînî, Gîne)',
        'ff_Latn_GW' => 'fulahî (latînî, Gîne-Bissau)',
        'ff_Latn_LR' => 'fulahî (latînî, Lîberya)',
        'ff_Latn_MR' => 'fulahî (latînî, Morîtanya)',
        'ff_Latn_NE' => 'fulahî (latînî, Nîjer)',
        'ff_Latn_NG' => 'fulahî (latînî, Nîjerya)',
        'ff_Latn_SL' => 'fulahî (latînî, Sierra Leone)',
        'ff_Latn_SN' => 'fulahî (latînî, Senegal)',
        'ff_MR' => 'fulahî (Morîtanya)',
        'ff_SN' => 'fulahî (Senegal)',
        'fi' => 'fînî',
        'fi_FI' => 'fînî (Fînlenda)',
        'fo' => 'ferî',
        'fo_DK' => 'ferî (Danîmarka)',
        'fo_FO' => 'ferî (Giravên Faroeyê)',
        'fr' => 'fransizî',
        'fr_BE' => 'fransizî (Belçîka)',
        'fr_BF' => 'fransizî (Burkîna Faso)',
        'fr_BI' => 'fransizî (Bûrûndî)',
        'fr_BJ' => 'fransizî (Bênîn)',
        'fr_BL' => 'fransizî (Saint Barthelemy)',
        'fr_CA' => 'fransizî (Kanada)',
        'fr_CD' => 'fransizî (Kongo - Kînşasa)',
        'fr_CF' => 'fransizî (Cimhûrîyeta Afrîkaya Navîn)',
        'fr_CG' => 'fransizî (Kongo - Brazzaville)',
        'fr_CH' => 'fransizî (Swîsre)',
        'fr_CI' => 'fransizî (Côte d’Ivoire)',
        'fr_CM' => 'fransizî (Kamerûn)',
        'fr_DJ' => 'fransizî (Cîbûtî)',
        'fr_DZ' => 'fransizî (Cezayîr)',
        'fr_FR' => 'fransizî (Fransa)',
        'fr_GA' => 'fransizî (Gabon)',
        'fr_GF' => 'fransizî (Guyanaya Fransî)',
        'fr_GN' => 'fransizî (Gîne)',
        'fr_GP' => 'fransizî (Guadeloupe)',
        'fr_GQ' => 'fransizî (Gîneya Ekwadorê)',
        'fr_HT' => 'fransizî (Haîtî)',
        'fr_KM' => 'fransizî (Komor)',
        'fr_LU' => 'fransizî (Luksembûrg)',
        'fr_MA' => 'fransizî (Fas)',
        'fr_MC' => 'fransizî (Monako)',
        'fr_MF' => 'fransizî (Saint Martin)',
        'fr_MG' => 'fransizî (Madagaskar)',
        'fr_ML' => 'fransizî (Malî)',
        'fr_MQ' => 'fransizî (Martînîk)',
        'fr_MR' => 'fransizî (Morîtanya)',
        'fr_MU' => 'fransizî (Mauritius)',
        'fr_NC' => 'fransizî (Kaledonyaya Nû)',
        'fr_NE' => 'fransizî (Nîjer)',
        'fr_PF' => 'fransizî (Polînezyaya Fransizî)',
        'fr_PM' => 'fransizî (Saint-Pierre û Miquelon)',
        'fr_RE' => 'fransizî (Réunion)',
        'fr_RW' => 'fransizî (Rwanda)',
        'fr_SC' => 'fransizî (Seyşel)',
        'fr_SN' => 'fransizî (Senegal)',
        'fr_SY' => 'fransizî (Sûrîye)',
        'fr_TD' => 'fransizî (Çad)',
        'fr_TG' => 'fransizî (Togo)',
        'fr_TN' => 'fransizî (Tûnis)',
        'fr_VU' => 'fransizî (Vanûatû)',
        'fr_WF' => 'fransizî (Wallis û Futuna)',
        'fr_YT' => 'fransizî (Mayotte)',
        'fy' => 'frîsîya rojavayî',
        'fy_NL' => 'frîsîya rojavayî (Holanda)',
        'ga' => 'îrlendî',
        'ga_GB' => 'îrlendî (Qiralîyeta Yekbûyî)',
        'ga_IE' => 'îrlendî (Îrlanda)',
        'gd' => 'gaelîka skotî',
        'gd_GB' => 'gaelîka skotî (Qiralîyeta Yekbûyî)',
        'gl' => 'galîsî',
        'gl_ES' => 'galîsî (Spanya)',
        'gu' => 'gujaratî',
        'gu_IN' => 'gujaratî (Hindistan)',
        'gv' => 'manksî',
        'gv_IM' => 'manksî (Girava Manê)',
        'ha' => 'hawsayî',
        'ha_GH' => 'hawsayî (Gana)',
        'ha_NE' => 'hawsayî (Nîjer)',
        'ha_NG' => 'hawsayî (Nîjerya)',
        'he' => 'îbranî',
        'he_IL' => 'îbranî (Îsraîl)',
        'hi' => 'hindî',
        'hi_IN' => 'hindî (Hindistan)',
        'hi_Latn' => 'hindî (latînî)',
        'hi_Latn_IN' => 'hindî (latînî, Hindistan)',
        'hr' => 'xirwatî',
        'hr_BA' => 'xirwatî (Bosna û Hersek)',
        'hr_HR' => 'xirwatî (Xirwatistan)',
        'hu' => 'macarî',
        'hu_HU' => 'macarî (Macaristan)',
        'hy' => 'ermenî',
        'hy_AM' => 'ermenî (Ermenistan)',
        'ia' => 'înterlîngua',
        'ia_001' => 'înterlîngua (dinya)',
        'id' => 'endonezyayî',
        'id_ID' => 'endonezyayî (Endonezya)',
        'ie' => 'înterlîngue',
        'ie_EE' => 'înterlîngue (Estonya)',
        'ig' => 'îgboyî',
        'ig_NG' => 'îgboyî (Nîjerya)',
        'ii' => 'yîyîya siçuwayî',
        'ii_CN' => 'yîyîya siçuwayî (Çîn)',
        'is' => 'îzlendî',
        'is_IS' => 'îzlendî (Îslanda)',
        'it' => 'îtalî',
        'it_CH' => 'îtalî (Swîsre)',
        'it_IT' => 'îtalî (Îtalya)',
        'it_SM' => 'îtalî (San Marîno)',
        'it_VA' => 'îtalî (Vatîkan)',
        'ja' => 'japonî',
        'ja_JP' => 'japonî (Japonya)',
        'jv' => 'javayî',
        'jv_ID' => 'javayî (Endonezya)',
        'ka' => 'gurcî',
        'ka_GE' => 'gurcî (Gurcistan)',
        'ki' => 'kîkûyûyî',
        'ki_KE' => 'kîkûyûyî (Kenya)',
        'kk' => 'qazaxî',
        'kk_Arab' => 'qazaxî (erebî)',
        'kk_Arab_CN' => 'qazaxî (erebî, Çîn)',
        'kk_Cyrl' => 'qazaxî (kirîlî)',
        'kk_Cyrl_KZ' => 'qazaxî (kirîlî, Qazaxistan)',
        'kk_KZ' => 'qazaxî (Qazaxistan)',
        'kl' => 'kalalîsûtî',
        'kl_GL' => 'kalalîsûtî (Grînlanda)',
        'km' => 'khmerî',
        'km_KH' => 'khmerî (Kamboçya)',
        'kn' => 'kannadayî',
        'kn_IN' => 'kannadayî (Hindistan)',
        'ko' => 'koreyî',
        'ko_CN' => 'koreyî (Çîn)',
        'ko_KP' => 'koreyî (Koreya Bakur)',
        'ko_KR' => 'koreyî (Koreya Başûr)',
        'ks' => 'keşmîrî',
        'ks_Arab' => 'keşmîrî (erebî)',
        'ks_Arab_IN' => 'keşmîrî (erebî, Hindistan)',
        'ks_Deva' => 'keşmîrî (devanagarî)',
        'ks_Deva_IN' => 'keşmîrî (devanagarî, Hindistan)',
        'ks_IN' => 'keşmîrî (Hindistan)',
        'ku' => 'kurdî [kurmancî]',
        'ku_Latn' => 'kurdî [kurmancî] (latînî)',
        'ku_Latn_IQ' => 'kurdî [kurmancî] (latînî, Îraq)',
        'ku_Latn_SY' => 'kurdî [kurmancî] (latînî, Sûrîye)',
        'ku_Latn_TR' => 'kurdî [kurmancî] (latînî, Türkiye)',
        'ku_SY' => 'kurdî [kurmancî] (Sûrîye)',
        'ku_TR' => 'kurdî [kurmancî] (Türkiye)',
        'kw' => 'kornî',
        'kw_GB' => 'kornî (Qiralîyeta Yekbûyî)',
        'ky' => 'qirgizî',
        'ky_KG' => 'qirgizî (Qirgizistan)',
        'lb' => 'luksembûrgî',
        'lb_LU' => 'luksembûrgî (Luksembûrg)',
        'lg' => 'lugandayî',
        'lg_UG' => 'lugandayî (Ûganda)',
        'ln' => 'lingalayî',
        'ln_AO' => 'lingalayî (Angola)',
        'ln_CD' => 'lingalayî (Kongo - Kînşasa)',
        'ln_CF' => 'lingalayî (Cimhûrîyeta Afrîkaya Navîn)',
        'ln_CG' => 'lingalayî (Kongo - Brazzaville)',
        'lo' => 'lao',
        'lo_LA' => 'lao (Laos)',
        'lt' => 'lîtwanî',
        'lt_LT' => 'lîtwanî (Lîtvanya)',
        'lu' => 'luba-katangayî',
        'lu_CD' => 'luba-katangayî (Kongo - Kînşasa)',
        'lv' => 'latvîyayî',
        'lv_LV' => 'latvîyayî (Letonya)',
        'mg' => 'malagasî',
        'mg_MG' => 'malagasî (Madagaskar)',
        'mi' => 'maorî',
        'mi_NZ' => 'maorî (Zelandaya Nû)',
        'mk' => 'makedonî',
        'mk_MK' => 'makedonî (Makedonyaya Bakur)',
        'ml' => 'malayalamî',
        'ml_IN' => 'malayalamî (Hindistan)',
        'mn' => 'moxolî',
        'mn_MN' => 'moxolî (Moxolistan)',
        'mr' => 'maratî',
        'mr_IN' => 'maratî (Hindistan)',
        'ms' => 'malezî',
        'ms_BN' => 'malezî (Brûney)',
        'ms_ID' => 'malezî (Endonezya)',
        'ms_MY' => 'malezî (Malezya)',
        'ms_SG' => 'malezî (Sîngapûr)',
        'mt' => 'maltayî',
        'mt_MT' => 'maltayî (Malta)',
        'my' => 'burmayî',
        'my_MM' => 'burmayî (Myanmar [Bûrma])',
        'nb' => 'norwecî [bokmål]',
        'nb_NO' => 'norwecî [bokmål] (Norwec)',
        'nb_SJ' => 'norwecî [bokmål] (Svalbard û Jan Mayen)',
        'nd' => 'ndebelîya bakurî',
        'nd_ZW' => 'ndebelîya bakurî (Zîmbabwe)',
        'ne' => 'nepalî',
        'ne_IN' => 'nepalî (Hindistan)',
        'ne_NP' => 'nepalî (Nepal)',
        'nl' => 'holendî',
        'nl_AW' => 'holendî (Arûba)',
        'nl_BE' => 'holendî (Belçîka)',
        'nl_BQ' => 'holendî (Holendaya Karayîbê)',
        'nl_CW' => 'holendî (Curaçao)',
        'nl_NL' => 'holendî (Holanda)',
        'nl_SR' => 'holendî (Surînam)',
        'nl_SX' => 'holendî (Sint Marteen)',
        'nn' => 'norwecî [nynorsk]',
        'nn_NO' => 'norwecî [nynorsk] (Norwec)',
        'no' => 'norwecî',
        'no_NO' => 'norwecî (Norwec)',
        'oc' => 'oksîtanî',
        'oc_ES' => 'oksîtanî (Spanya)',
        'oc_FR' => 'oksîtanî (Fransa)',
        'om' => 'oromoyî',
        'om_ET' => 'oromoyî (Etîyopya)',
        'om_KE' => 'oromoyî (Kenya)',
        'or' => 'oriyayî',
        'or_IN' => 'oriyayî (Hindistan)',
        'os' => 'osetî',
        'os_GE' => 'osetî (Gurcistan)',
        'os_RU' => 'osetî (Rûsya)',
        'pa' => 'puncabî',
        'pa_Arab' => 'puncabî (erebî)',
        'pa_Arab_PK' => 'puncabî (erebî, Pakistan)',
        'pa_Guru' => 'puncabî (gurmuxî)',
        'pa_Guru_IN' => 'puncabî (gurmuxî, Hindistan)',
        'pa_IN' => 'puncabî (Hindistan)',
        'pa_PK' => 'puncabî (Pakistan)',
        'pl' => 'polonî',
        'pl_PL' => 'polonî (Polonya)',
        'ps' => 'peştûyî',
        'ps_AF' => 'peştûyî (Efxanistan)',
        'ps_PK' => 'peştûyî (Pakistan)',
        'pt' => 'portugalî',
        'pt_AO' => 'portugalî (Angola)',
        'pt_BR' => 'portugalî (Brezîlya)',
        'pt_CH' => 'portugalî (Swîsre)',
        'pt_CV' => 'portugalî (Kap Verde)',
        'pt_GQ' => 'portugalî (Gîneya Ekwadorê)',
        'pt_GW' => 'portugalî (Gîne-Bissau)',
        'pt_LU' => 'portugalî (Luksembûrg)',
        'pt_MO' => 'portugalî (Makaoya Hît ya Çînê)',
        'pt_MZ' => 'portugalî (Mozambîk)',
        'pt_PT' => 'portugalî (Portugal)',
        'pt_ST' => 'portugalî (Sao Tome û Prînsîpe)',
        'pt_TL' => 'portugalî (Tîmor-Leste)',
        'qu' => 'keçwayî',
        'qu_BO' => 'keçwayî (Bolîvya)',
        'qu_EC' => 'keçwayî (Ekwador)',
        'qu_PE' => 'keçwayî (Perû)',
        'rm' => 'romancî',
        'rm_CH' => 'romancî (Swîsre)',
        'rn' => 'rundî',
        'rn_BI' => 'rundî (Bûrûndî)',
        'ro' => 'romanî',
        'ro_MD' => 'romanî (Moldova)',
        'ro_RO' => 'romanî (Romanya)',
        'ru' => 'rûsî',
        'ru_BY' => 'rûsî (Belarûs)',
        'ru_KG' => 'rûsî (Qirgizistan)',
        'ru_KZ' => 'rûsî (Qazaxistan)',
        'ru_MD' => 'rûsî (Moldova)',
        'ru_RU' => 'rûsî (Rûsya)',
        'ru_UA' => 'rûsî (Ûkrayna)',
        'rw' => 'kînyariwandayî',
        'rw_RW' => 'kînyariwandayî (Rwanda)',
        'sa' => 'sanskrîtî',
        'sa_IN' => 'sanskrîtî (Hindistan)',
        'sc' => 'sardînî',
        'sc_IT' => 'sardînî (Îtalya)',
        'sd' => 'sindhî',
        'sd_Arab' => 'sindhî (erebî)',
        'sd_Arab_PK' => 'sindhî (erebî, Pakistan)',
        'sd_Deva' => 'sindhî (devanagarî)',
        'sd_Deva_IN' => 'sindhî (devanagarî, Hindistan)',
        'sd_IN' => 'sindhî (Hindistan)',
        'sd_PK' => 'sindhî (Pakistan)',
        'se' => 'samîya bakur',
        'se_FI' => 'samîya bakur (Fînlenda)',
        'se_NO' => 'samîya bakur (Norwec)',
        'se_SE' => 'samîya bakur (Swêd)',
        'sg' => 'sangoyî',
        'sg_CF' => 'sangoyî (Cimhûrîyeta Afrîkaya Navîn)',
        'si' => 'kîngalî',
        'si_LK' => 'kîngalî (Srî Lanka)',
        'sk' => 'slovakî',
        'sk_SK' => 'slovakî (Slovakya)',
        'sl' => 'slovenî',
        'sl_SI' => 'slovenî (Slovenya)',
        'sn' => 'şonayî',
        'sn_ZW' => 'şonayî (Zîmbabwe)',
        'so' => 'somalî',
        'so_DJ' => 'somalî (Cîbûtî)',
        'so_ET' => 'somalî (Etîyopya)',
        'so_KE' => 'somalî (Kenya)',
        'so_SO' => 'somalî (Somalya)',
        'sq' => 'arnawidî',
        'sq_AL' => 'arnawidî (Albanya)',
        'sq_MK' => 'arnawidî (Makedonyaya Bakur)',
        'sr' => 'sirbî',
        'sr_BA' => 'sirbî (Bosna û Hersek)',
        'sr_Cyrl' => 'sirbî (kirîlî)',
        'sr_Cyrl_BA' => 'sirbî (kirîlî, Bosna û Hersek)',
        'sr_Cyrl_ME' => 'sirbî (kirîlî, Qeredax)',
        'sr_Cyrl_RS' => 'sirbî (kirîlî, Sirbistan)',
        'sr_Latn' => 'sirbî (latînî)',
        'sr_Latn_BA' => 'sirbî (latînî, Bosna û Hersek)',
        'sr_Latn_ME' => 'sirbî (latînî, Qeredax)',
        'sr_Latn_RS' => 'sirbî (latînî, Sirbistan)',
        'sr_ME' => 'sirbî (Qeredax)',
        'sr_RS' => 'sirbî (Sirbistan)',
        'st' => 'sotoyîya başûr',
        'st_LS' => 'sotoyîya başûr (Lesoto)',
        'st_ZA' => 'sotoyîya başûr (Afrîkaya Başûr)',
        'su' => 'sundanî',
        'su_ID' => 'sundanî (Endonezya)',
        'su_Latn' => 'sundanî (latînî)',
        'su_Latn_ID' => 'sundanî (latînî, Endonezya)',
        'sv' => 'swêdî',
        'sv_AX' => 'swêdî (Giravên Alandê)',
        'sv_FI' => 'swêdî (Fînlenda)',
        'sv_SE' => 'swêdî (Swêd)',
        'sw' => 'swahîlî',
        'sw_CD' => 'swahîlî (Kongo - Kînşasa)',
        'sw_KE' => 'swahîlî (Kenya)',
        'sw_TZ' => 'swahîlî (Tanzanya)',
        'sw_UG' => 'swahîlî (Ûganda)',
        'ta' => 'tamîlî',
        'ta_IN' => 'tamîlî (Hindistan)',
        'ta_LK' => 'tamîlî (Srî Lanka)',
        'ta_MY' => 'tamîlî (Malezya)',
        'ta_SG' => 'tamîlî (Sîngapûr)',
        'te' => 'telûgûyî',
        'te_IN' => 'telûgûyî (Hindistan)',
        'tg' => 'tacikî',
        'tg_TJ' => 'tacikî (Tacikistan)',
        'th' => 'tayî',
        'th_TH' => 'tayî (Tayland)',
        'ti' => 'tigrînî',
        'ti_ER' => 'tigrînî (Erître)',
        'ti_ET' => 'tigrînî (Etîyopya)',
        'tk' => 'tirkmenî',
        'tk_TM' => 'tirkmenî (Tirkmenistan)',
        'tn' => 'tswanayî',
        'tn_BW' => 'tswanayî (Botswana)',
        'tn_ZA' => 'tswanayî (Afrîkaya Başûr)',
        'to' => 'tongî',
        'to_TO' => 'tongî (Tonga)',
        'tr' => 'tirkî',
        'tr_CY' => 'tirkî (Qibris)',
        'tr_TR' => 'tirkî (Türkiye)',
        'tt' => 'teterî',
        'tt_RU' => 'teterî (Rûsya)',
        'ug' => 'uyxurî',
        'ug_CN' => 'uyxurî (Çîn)',
        'uk' => 'ukraynî',
        'uk_UA' => 'ukraynî (Ûkrayna)',
        'ur' => 'urdûyî',
        'ur_IN' => 'urdûyî (Hindistan)',
        'ur_PK' => 'urdûyî (Pakistan)',
        'uz' => 'ozbekî',
        'uz_AF' => 'ozbekî (Efxanistan)',
        'uz_Arab' => 'ozbekî (erebî)',
        'uz_Arab_AF' => 'ozbekî (erebî, Efxanistan)',
        'uz_Cyrl' => 'ozbekî (kirîlî)',
        'uz_Cyrl_UZ' => 'ozbekî (kirîlî, Ozbekistan)',
        'uz_Latn' => 'ozbekî (latînî)',
        'uz_Latn_UZ' => 'ozbekî (latînî, Ozbekistan)',
        'uz_UZ' => 'ozbekî (Ozbekistan)',
        'vi' => 'vîetnamî',
        'vi_VN' => 'vîetnamî (Vîetnam)',
        'wo' => 'wolofî',
        'wo_SN' => 'wolofî (Senegal)',
        'xh' => 'xosayî',
        'xh_ZA' => 'xosayî (Afrîkaya Başûr)',
        'yi' => 'yidîşî',
        'yi_UA' => 'yidîşî (Ûkrayna)',
        'yo' => 'yorubayî',
        'yo_BJ' => 'yorubayî (Bênîn)',
        'yo_NG' => 'yorubayî (Nîjerya)',
        'za' => 'zhuangî',
        'za_CN' => 'zhuangî (Çîn)',
        'zh' => 'çînî',
        'zh_CN' => 'çînî (Çîn)',
        'zh_HK' => 'çînî (Hong Konga HîT ya Çînê)',
        'zh_Hans' => 'çînî (sadekirî)',
        'zh_Hans_CN' => 'çînî (sadekirî, Çîn)',
        'zh_Hans_HK' => 'çînî (sadekirî, Hong Konga HîT ya Çînê)',
        'zh_Hans_MO' => 'çînî (sadekirî, Makaoya Hît ya Çînê)',
        'zh_Hans_MY' => 'çînî (sadekirî, Malezya)',
        'zh_Hans_SG' => 'çînî (sadekirî, Sîngapûr)',
        'zh_Hant' => 'çînî (edetî)',
        'zh_Hant_HK' => 'çînî (edetî, Hong Konga HîT ya Çînê)',
        'zh_Hant_MO' => 'çînî (edetî, Makaoya Hît ya Çînê)',
        'zh_Hant_MY' => 'çînî (edetî, Malezya)',
        'zh_Hant_TW' => 'çînî (edetî, Taywan)',
        'zh_MO' => 'çînî (Makaoya Hît ya Çînê)',
        'zh_SG' => 'çînî (Sîngapûr)',
        'zh_TW' => 'çînî (Taywan)',
        'zu' => 'zuluyî',
        'zu_ZA' => 'zuluyî (Afrîkaya Başûr)',
    ],
];
