<?php

return [
    'Names' => [
        'Adlm' => 'Kiadlamu',
        'Arab' => 'Kiarabu',
        'Aran' => 'Kinastaliki',
        'Armn' => 'Kiarmenia',
        'Beng' => 'Kibengali',
        'Bopo' => 'Kibopomofo',
        'Brai' => 'Nukta nundu',
        'Cakm' => 'Kichakma',
        'Cans' => 'Silabi Zilizounganishwa za Wakazi Asili wa Kanada',
        'Cher' => 'Kicherokee',
        'Cyrl' => 'Kisiriliki',
        'Deva' => 'Kidevanagari',
        'Ethi' => 'Kiethiopia',
        'Geor' => 'Kijojia',
        'Grek' => 'Kigiriki',
        'Gujr' => 'Kigujarati',
        'Guru' => 'Kigurmukhi',
        'Hanb' => 'Kihan chenye Bopomofo',
        'Hang' => 'Kihangul',
        'Hani' => 'Kihan',
        'Hans' => 'Rahisi',
        'Hant' => 'Cha jadi',
        'Hebr' => 'Kiebrania',
        'Hira' => 'Hiragana',
        'Hrkt' => 'Hati za Kijapani',
        'Jpan' => 'Kijapani',
        'Kana' => 'Kikatakana',
        'Khmr' => 'Kikambodia',
        'Knda' => 'Kikannada',
        'Kore' => 'Kikorea',
        'Laoo' => 'Kilaosi',
        'Latn' => 'Kilatini',
        'Mlym' => 'Kimalayalam',
        'Mong' => 'Kimongolia',
        'Mtei' => 'Meitei Mayek',
        'Mymr' => 'Myama',
        'Nkoo' => 'N’Ko',
        'Olck' => 'Kiol Chiki',
        'Orya' => 'Kioriya',
        'Rohg' => 'Kihanifi',
        'Sinh' => 'Kisinhala',
        'Sund' => 'Kisunda',
        'Syrc' => 'Kisiriaki',
        'Taml' => 'Kitamil',
        'Telu' => 'Kitelugu',
        'Tfng' => 'Kitifinagh',
        'Thaa' => 'Kithaana',
        'Thai' => 'Kithai',
        'Tibt' => 'Kitibeti',
        'Vaii' => 'Kivai',
        'Yiii' => 'Kiyii',
        'Zmth' => 'Hati za kihisabati',
        'Zsye' => 'Emoji',
        'Zsym' => 'Alama',
        'Zxxx' => 'Haijaandikwa',
        'Zyyy' => 'Kawaida',
    ],
];
