<?php

return [
    'Names' => [
        'Arab' => 'Arabesch',
        'Armn' => 'Armenesch',
        'Avst' => 'Avestesch',
        'Bali' => 'Balinesesch',
        'Batk' => 'Battakesch',
        'Beng' => 'Bengalesch',
        'Blis' => 'Bliss-Symboler',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brahmi',
        'Brai' => 'Blanneschrëft',
        'Bugi' => 'Buginesesch',
        'Buhd' => 'Buhid',
        'Cans' => 'UCAS',
        'Cari' => 'Karesch',
        'Cher' => 'Cherokee',
        'Cirt' => 'Cirth',
        'Copt' => 'Koptesch',
        'Cprt' => 'Zypriotesch',
        'Cyrl' => 'Kyrillesch',
        'Cyrs' => 'Alkiercheslawesch',
        'Deva' => 'Devanagari',
        'Dsrt' => 'Deseret',
        'Egyd' => 'Egyptesch-Demotesch',
        'Egyh' => 'Egyptesch-Hieratesch',
        'Egyp' => 'Egyptesch Hieroglyphen',
        'Ethi' => 'Ethiopesch',
        'Geok' => 'Khutsuri',
        'Geor' => 'Georgesch',
        'Glag' => 'Glagolitesch',
        'Goth' => 'Gotesch',
        'Grek' => 'Griichesch',
        'Gujr' => 'Gujarati',
        'Guru' => 'Gurmukhi',
        'Hang' => 'Hangul',
        'Hani' => 'Chinesesch',
        'Hano' => 'Hanunoo',
        'Hans' => 'Vereinfacht',
        'Hant' => 'Traditionell',
        'Hebr' => 'Hebräesch',
        'Hira' => 'Hiragana',
        'Hmng' => 'Pahawh Hmong',
        'Hrkt' => 'Katakana oder Hiragana',
        'Hung' => 'Alungaresch',
        'Inds' => 'Indus-Schrëft',
        'Ital' => 'Alitalesch',
        'Java' => 'Javanesesch',
        'Jpan' => 'Japanesch',
        'Kali' => 'Kayah Li',
        'Kana' => 'Katakana',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Khmer',
        'Knda' => 'Kannada',
        'Kore' => 'Koreanesch',
        'Lana' => 'Lanna',
        'Laoo' => 'Laotesch',
        'Latf' => 'Laténgesch-Fraktur-Variant',
        'Latg' => 'Laténgesch-Gällesch Variant',
        'Latn' => 'Laténgesch',
        'Lepc' => 'Lepcha',
        'Limb' => 'Limbu',
        'Lina' => 'Linear A',
        'Linb' => 'Linear B',
        'Lyci' => 'Lykesch',
        'Lydi' => 'Lydesch',
        'Mand' => 'Mandäesch',
        'Mani' => 'Manichäesch',
        'Maya' => 'Maya-Hieroglyphen',
        'Mero' => 'Meroitesch',
        'Mlym' => 'Malaysesch',
        'Mong' => 'Mongolesch',
        'Moon' => 'Moon',
        'Mtei' => 'Meitei Mayek',
        'Mymr' => 'Birmanesch',
        'Nkoo' => 'N’Ko',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Orkh' => 'Orchon-Runen',
        'Orya' => 'Oriya',
        'Osma' => 'Osmanesch',
        'Perm' => 'Alpermesch',
        'Phag' => 'Phags-pa',
        'Phlv' => 'Pahlavi',
        'Phnx' => 'Phönizesch',
        'Plrd' => 'Pollard Phonetesch',
        'Rjng' => 'Rejang',
        'Roro' => 'Rongorongo',
        'Runr' => 'Runeschrëft',
        'Samr' => 'Samaritanesch',
        'Sara' => 'Sarati',
        'Saur' => 'Saurashtra',
        'Sgnw' => 'Zeechesprooch',
        'Shaw' => 'Shaw-Alphabet',
        'Sinh' => 'Singhalesesch',
        'Sund' => 'Sundanesesch',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Syresch',
        'Syre' => 'Syresch-Estrangelo-Variant',
        'Syrj' => 'Westsyresch',
        'Syrn' => 'Ostsyresch',
        'Tale' => 'Tai Le',
        'Talu' => 'Tai Lue',
        'Taml' => 'Tamilesch',
        'Telu' => 'Telugu',
        'Teng' => 'Tengwar',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Dagalog',
        'Thaa' => 'Thaana',
        'Thai' => 'Thai',
        'Tibt' => 'Tibetesch',
        'Ugar' => 'Ugaritesch',
        'Vaii' => 'Vai',
        'Visp' => 'Siichtbar Sprooch',
        'Xpeo' => 'Alpersesch',
        'Xsux' => 'Sumeresch-akkadesch Keilschrëft',
        'Yiii' => 'Yi',
        'Zinh' => 'Geierfte Schrëftwäert',
        'Zsym' => 'Symboler',
        'Zxxx' => 'Ouni Schrëft',
        'Zyyy' => 'Onbestëmmt',
    ],
];
