<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Lokacin Greenwich a Ingila (Abidjan)',
        'Africa/Accra' => 'Lokacin Greenwich a Ingila (Accra)',
        'Africa/Addis_Ababa' => 'Lokacin Gabashin Afirka (Addis Ababa)',
        'Africa/Algiers' => 'Tsakiyar a lokaci turai (Algiers)',
        'Africa/Asmera' => 'Lokacin Gabashin Afirka (Asmara)',
        'Africa/Asmara' => 'Lokacin Gabashin Afirka (Asmara)',
        'Africa/Bamako' => 'Lokacin Greenwich a Ingila (Bamako)',
        'Africa/Bangui' => 'Lokacin Afirka ta Yamma (Bangui)',
        'Africa/Banjul' => 'Lokacin Greenwich a Ingila (Banjul)',
        'Africa/Bissau' => 'Lokacin Greenwich a Ingila (Bissau)',
        'Africa/Blantyre' => 'Lokacin Afirka ta Tsakiya (Blantyre)',
        'Africa/Brazzaville' => 'Lokacin Afirka ta Yamma (Brazzaville)',
        'Africa/Bujumbura' => 'Lokacin Afirka ta Tsakiya (Bujumbura)',
        'Africa/Cairo' => 'Lokaci a turai gabas (Cairo)',
        'Africa/Casablanca' => 'Lokaci ta yammacin turai (Casablanca)',
        'Africa/Ceuta' => 'Tsakiyar a lokaci turai (Ceuta)',
        'Africa/Conakry' => 'Lokacin Greenwich a Ingila (Conakry)',
        'Africa/Dakar' => 'Lokacin Greenwich a Ingila (Dakar)',
        'Africa/Dar_es_Salaam' => 'Lokacin Gabashin Afirka (Dar es Salaam)',
        'Africa/Djibouti' => 'Lokacin Gabashin Afirka (Djibouti)',
        'Africa/Douala' => 'Lokacin Afirka ta Yamma (Douala)',
        'Africa/El_Aaiun' => 'Lokaci ta yammacin turai (El Aaiún)',
        'Africa/Freetown' => 'Lokacin Greenwich a Ingila (Freetown)',
        'Africa/Gaborone' => 'Lokacin Afirka ta Tsakiya (Gaborone)',
        'Africa/Harare' => 'Lokacin Afirka ta Tsakiya (Harare)',
        'Africa/Johannesburg' => 'Tsayayyen Lokacin Afirka ta Kudu (Johannesburg)',
        'Africa/Juba' => 'Lokacin Afirka ta Tsakiya (Juba)',
        'Africa/Kampala' => 'Lokacin Gabashin Afirka (Kampala)',
        'Africa/Khartoum' => 'Lokacin Afirka ta Tsakiya (Khartoum)',
        'Africa/Kigali' => 'Lokacin Afirka ta Tsakiya (Kigali)',
        'Africa/Kinshasa' => 'Lokacin Afirka ta Yamma (Kinshasa)',
        'Africa/Lagos' => 'Lokacin Afirka ta Yamma (Lagos)',
        'Africa/Libreville' => 'Lokacin Afirka ta Yamma (Libreville)',
        'Africa/Lome' => 'Lokacin Greenwich a Ingila (Lomé)',
        'Africa/Luanda' => 'Lokacin Afirka ta Yamma (Luanda)',
        'Africa/Lubumbashi' => 'Lokacin Afirka ta Tsakiya (Lubumbashi)',
        'Africa/Lusaka' => 'Lokacin Afirka ta Tsakiya (Lusaka)',
        'Africa/Malabo' => 'Lokacin Afirka ta Yamma (Malabo)',
        'Africa/Maputo' => 'Lokacin Afirka ta Tsakiya (Maputo)',
        'Africa/Maseru' => 'Tsayayyen Lokacin Afirka ta Kudu (Maseru)',
        'Africa/Mbabane' => 'Tsayayyen Lokacin Afirka ta Kudu (Mbabane)',
        'Africa/Mogadishu' => 'Lokacin Gabashin Afirka (Mogadishu)',
        'Africa/Monrovia' => 'Lokacin Greenwich a Ingila (Monrovia)',
        'Africa/Nairobi' => 'Lokacin Gabashin Afirka (Nairobi)',
        'Africa/Ndjamena' => 'Lokacin Afirka ta Yamma (N’Djamena)',
        'Africa/Niamey' => 'Lokacin Afirka ta Yamma (Niamey)',
        'Africa/Nouakchott' => 'Lokacin Greenwich a Ingila (Nouakchott)',
        'Africa/Ouagadougou' => 'Lokacin Greenwich a Ingila (Ouagadougou)',
        'Africa/Porto-Novo' => 'Lokacin Afirka ta Yamma (Porto-Novo)',
        'Africa/Sao_Tome' => 'Lokacin Greenwich a Ingila (São Tomé)',
        'Africa/Tripoli' => 'Lokaci a turai gabas (Tripoli)',
        'Africa/Tunis' => 'Tsakiyar a lokaci turai (Tunis)',
        'Africa/Windhoek' => 'Lokacin Afirka ta Tsakiya (Windhoek)',
        'America/Adak' => 'Lokaci na Hawaii-Aleutian (Adak)',
        'America/Anchorage' => 'Lokacin Alaska (Anchorage)',
        'America/Anguilla' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Anguilla)',
        'America/Antigua' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Antigua)',
        'America/Araguaina' => 'Lokacin Brasillia (Araguaína)',
        'America/Argentina/La_Rioja' => 'Lokacin Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Lokacin Argentina (Río Gallegos)',
        'America/Argentina/Salta' => 'Lokacin Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Lokacin Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Lokacin Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Lokacin Argentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'Lokacin Argentina (Ushuaia)',
        'America/Aruba' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Aruba)',
        'America/Asuncion' => 'Lokacin Paraguay (Asunción)',
        'America/Bahia' => 'Lokacin Brasillia (Bahia)',
        'America/Bahia_Banderas' => 'Lokaci dake Amurika arewa ta tsakiyar (Bahía de Banderas)',
        'America/Barbados' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Barbados)',
        'America/Belem' => 'Lokacin Brasillia (Belém)',
        'America/Belize' => 'Lokaci dake Amurika arewa ta tsakiyar (Belize)',
        'America/Blanc-Sablon' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Blanc-Sablon)',
        'America/Boa_Vista' => 'Lokacin Amazon (Boa Vista)',
        'America/Bogota' => 'Lokacin Colombia (Bogotá)',
        'America/Boise' => 'Lokacin Tsauni na Arewacin Amurka (Boise)',
        'America/Buenos_Aires' => 'Lokacin Argentina (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Lokacin Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Lokacin Tsauni na Arewacin Amurka (Cambridge Bay)',
        'America/Campo_Grande' => 'Lokacin Amazon (Campo Grande)',
        'America/Cancun' => 'Lokacin Gabas dake Arewacin Amurikaa (Cancún)',
        'America/Caracas' => 'Lokacin Venezuela (Caracas)',
        'America/Catamarca' => 'Lokacin Argentina (Catamarca)',
        'America/Argentina/Catamarca' => 'Lokacin Argentina (Catamarca)',
        'America/Cayenne' => 'Lokacin French Guiana (Cayenne)',
        'America/Cayman' => 'Lokacin Gabas dake Arewacin Amurikaa (Cayman)',
        'America/Chicago' => 'Lokaci dake Amurika arewa ta tsakiyar (Chicago)',
        'America/Chihuahua' => 'Lokaci dake Amurika arewa ta tsakiyar (Chihuahua)',
        'America/Ciudad_Juarez' => 'Lokacin Tsauni na Arewacin Amurka (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Lokacin Gabas dake Arewacin Amurikaa (Atikokan)',
        'America/Atikokan' => 'Lokacin Gabas dake Arewacin Amurikaa (Atikokan)',
        'America/Cordoba' => 'Lokacin Argentina (Córdoba)',
        'America/Argentina/Cordoba' => 'Lokacin Argentina (Córdoba)',
        'America/Costa_Rica' => 'Lokaci dake Amurika arewa ta tsakiyar (Costa Rica)',
        'America/Coyhaique' => 'Lokacin Chile (Coyhaique)',
        'America/Creston' => 'Lokacin Tsauni na Arewacin Amurka (Creston)',
        'America/Cuiaba' => 'Lokacin Amazon (Cuiabá)',
        'America/Curacao' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Curaçao)',
        'America/Danmarkshavn' => 'Lokacin Greenwich a Ingila (Danmarkshavn)',
        'America/Dawson' => 'Lokacin Yukon (Dawson)',
        'America/Dawson_Creek' => 'Lokacin Tsauni na Arewacin Amurka (Dawson Creek)',
        'America/Denver' => 'Lokacin Tsauni na Arewacin Amurka (Denver)',
        'America/Detroit' => 'Lokacin Gabas dake Arewacin Amurikaa (Detroit)',
        'America/Dominica' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Dominica)',
        'America/Edmonton' => 'Lokacin Tsauni na Arewacin Amurka (Edmonton)',
        'America/Eirunepe' => 'Birazil Lokaci (Eirunepé)',
        'America/El_Salvador' => 'Lokaci dake Amurika arewa ta tsakiyar (El Salvador)',
        'America/Fort_Nelson' => 'Lokacin Tsauni na Arewacin Amurka (Fort Nelson)',
        'America/Fortaleza' => 'Lokacin Brasillia (Fortaleza)',
        'America/Glace_Bay' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Glace Bay)',
        'America/Godthab' => 'Grinlan Lokaci (Nuuk)',
        'America/Nuuk' => 'Grinlan Lokaci (Nuuk)',
        'America/Goose_Bay' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Goose Bay)',
        'America/Grand_Turk' => 'Lokacin Gabas dake Arewacin Amurikaa (Grand Turk)',
        'America/Grenada' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Grenada)',
        'America/Guadeloupe' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Guadeloupe)',
        'America/Guatemala' => 'Lokaci dake Amurika arewa ta tsakiyar (Guatemala)',
        'America/Guayaquil' => 'Lokacin Ecuador (Guayaquil)',
        'America/Guyana' => 'Lokacin Guyana',
        'America/Halifax' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Halifax)',
        'America/Havana' => 'Lokaci na Kuba (Havana)',
        'America/Hermosillo' => 'Lokacin Mekziko Pacific (Hermosillo)',
        'America/Indiana/Knox' => 'Lokaci dake Amurika arewa ta tsakiyar (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Lokacin Gabas dake Arewacin Amurikaa (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Lokacin Gabas dake Arewacin Amurikaa (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Lokaci dake Amurika arewa ta tsakiyar (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Lokacin Gabas dake Arewacin Amurikaa (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Lokacin Gabas dake Arewacin Amurikaa (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Lokacin Gabas dake Arewacin Amurikaa (Winamac, Indiana)',
        'America/Indianapolis' => 'Lokacin Gabas dake Arewacin Amurikaa (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Lokacin Gabas dake Arewacin Amurikaa (Indianapolis)',
        'America/Inuvik' => 'Lokacin Tsauni na Arewacin Amurka (Inuvik)',
        'America/Iqaluit' => 'Lokacin Gabas dake Arewacin Amurikaa (Iqaluit)',
        'America/Jamaica' => 'Lokacin Gabas dake Arewacin Amurikaa (Jamaica)',
        'America/Jujuy' => 'Lokacin Argentina (Jujuy)',
        'America/Argentina/Jujuy' => 'Lokacin Argentina (Jujuy)',
        'America/Juneau' => 'Lokacin Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Lokacin Gabas dake Arewacin Amurikaa (Monticello, Kentucky)',
        'America/Kralendijk' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Kralendijk)',
        'America/La_Paz' => 'Lokacin Bolivia (La Paz)',
        'America/Lima' => 'Lokacin Peru (Lima)',
        'America/Los_Angeles' => 'Lokacin Arewacin Amurika (Los Angeles)',
        'America/Louisville' => 'Lokacin Gabas dake Arewacin Amurikaa (Louisville)',
        'America/Kentucky/Louisville' => 'Lokacin Gabas dake Arewacin Amurikaa (Louisville)',
        'America/Lower_Princes' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Lower Prince’s Quarter)',
        'America/Maceio' => 'Lokacin Brasillia (Maceió)',
        'America/Managua' => 'Lokaci dake Amurika arewa ta tsakiyar (Managua)',
        'America/Manaus' => 'Lokacin Amazon (Manaus)',
        'America/Marigot' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Marigot)',
        'America/Martinique' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Martinique)',
        'America/Matamoros' => 'Lokaci dake Amurika arewa ta tsakiyar (Matamoros)',
        'America/Mazatlan' => 'Lokacin Mekziko Pacific (Mazatlán)',
        'America/Mendoza' => 'Lokacin Argentina (Mendoza)',
        'America/Argentina/Mendoza' => 'Lokacin Argentina (Mendoza)',
        'America/Menominee' => 'Lokaci dake Amurika arewa ta tsakiyar (Menominee)',
        'America/Merida' => 'Lokaci dake Amurika arewa ta tsakiyar (Mérida)',
        'America/Metlakatla' => 'Lokacin Alaska (Metlakatla)',
        'America/Mexico_City' => 'Lokaci dake Amurika arewa ta tsakiyar (Ciudad de México)',
        'America/Miquelon' => 'Lokacin St. Pierre da Miquelon (Saint-Pierre)',
        'America/Moncton' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Moncton)',
        'America/Monterrey' => 'Lokaci dake Amurika arewa ta tsakiyar (Monterrey)',
        'America/Montevideo' => 'Lokacin Uruguay (Montevideo)',
        'America/Montserrat' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Montserrat)',
        'America/Nassau' => 'Lokacin Gabas dake Arewacin Amurikaa (Nassau)',
        'America/New_York' => 'Lokacin Gabas dake Arewacin Amurikaa (New York)',
        'America/Nome' => 'Lokacin Alaska (Nome)',
        'America/Noronha' => 'Lokacin Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Lokaci dake Amurika arewa ta tsakiyar (Beulah, Arewacin Dakota)',
        'America/North_Dakota/Center' => 'Lokaci dake Amurika arewa ta tsakiyar (Center, Arewacin Dakota)',
        'America/North_Dakota/New_Salem' => 'Lokaci dake Amurika arewa ta tsakiyar (New Salem, Arewacin Dakota)',
        'America/Ojinaga' => 'Lokaci dake Amurika arewa ta tsakiyar (Ojinaga)',
        'America/Panama' => 'Lokacin Gabas dake Arewacin Amurikaa (Panama)',
        'America/Paramaribo' => 'Lokacin Suriname (Paramaribo)',
        'America/Phoenix' => 'Lokacin Tsauni na Arewacin Amurka (Phoenix)',
        'America/Port-au-Prince' => 'Lokacin Gabas dake Arewacin Amurikaa (Port-au-Prince)',
        'America/Port_of_Spain' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Port of Spain)',
        'America/Porto_Velho' => 'Lokacin Amazon (Porto Velho)',
        'America/Puerto_Rico' => 'Lokacin Kanada, Puerto Rico da Virgin Islands',
        'America/Punta_Arenas' => 'Lokacin Chile (Punta Arenas)',
        'America/Rankin_Inlet' => 'Lokaci dake Amurika arewa ta tsakiyar (Rankin Inlet)',
        'America/Recife' => 'Lokacin Brasillia (Recife)',
        'America/Regina' => 'Lokaci dake Amurika arewa ta tsakiyar (Regina)',
        'America/Resolute' => 'Lokaci dake Amurika arewa ta tsakiyar (Resolute)',
        'America/Rio_Branco' => 'Birazil Lokaci (Rio Branco)',
        'America/Santarem' => 'Lokacin Brasillia (Santarém)',
        'America/Santiago' => 'Lokacin Chile (Santiago)',
        'America/Santo_Domingo' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Santo Domingo)',
        'America/Sao_Paulo' => 'Lokacin Brasillia (São Paulo)',
        'America/Scoresbysund' => 'Grinlan Lokaci (Ittoqqortoormiit)',
        'America/Sitka' => 'Lokacin Alaska (Sitka)',
        'America/St_Barthelemy' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (St. Barthélemy)',
        'America/St_Johns' => 'Lokacin Newfoundland (St. John’s)',
        'America/St_Kitts' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (St. Kitts)',
        'America/St_Lucia' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (St. Lucia)',
        'America/St_Thomas' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (St. Thomas)',
        'America/St_Vincent' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (St. Vincent)',
        'America/Swift_Current' => 'Lokaci dake Amurika arewa ta tsakiyar (Swift Current)',
        'America/Tegucigalpa' => 'Lokaci dake Amurika arewa ta tsakiyar (Tegucigalpa)',
        'America/Thule' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Thule)',
        'America/Tijuana' => 'Lokacin Arewacin Amurika (Tijuana)',
        'America/Toronto' => 'Lokacin Gabas dake Arewacin Amurikaa (Toronto)',
        'America/Tortola' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Tortola)',
        'America/Vancouver' => 'Lokacin Arewacin Amurika (Vancouver)',
        'America/Whitehorse' => 'Lokacin Yukon (Whitehorse)',
        'America/Winnipeg' => 'Lokaci dake Amurika arewa ta tsakiyar (Winnipeg)',
        'America/Yakutat' => 'Lokacin Alaska (Yakutat)',
        'Antarctica/Casey' => 'Lokacin Yammacin Austiralia (Casey)',
        'Antarctica/Davis' => 'Lokacin Davis',
        'Antarctica/DumontDUrville' => 'Lokacin Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Lokacin Gabashin Austiraliya (Macquarie)',
        'Antarctica/Mawson' => 'Lokacin Mawson',
        'Antarctica/McMurdo' => 'Lokacin New Zealand (McMurdo)',
        'Antarctica/Palmer' => 'Lokacin Chile (Palmer)',
        'Antarctica/Rothera' => 'Lokacin Rothera',
        'Antarctica/Syowa' => 'Lokacin Syowa (Showa)',
        'Antarctica/Troll' => 'Lokacin Greenwich a Ingila (Troll)',
        'Antarctica/Vostok' => 'Lokacin Vostok',
        'Arctic/Longyearbyen' => 'Tsakiyar a lokaci turai (Longyearbyen)',
        'Asia/Aden' => 'Lokacin Arebiya (Aden)',
        'Asia/Almaty' => 'Lokacin Kazakhstan (Almaty)',
        'Asia/Amman' => 'Lokaci a turai gabas (Amman)',
        'Asia/Anadyr' => 'Rasha Lokaci (Anadyr)',
        'Asia/Aqtau' => 'Lokacin Kazakhstan (Aqtau)',
        'Asia/Aqtobe' => 'Lokacin Kazakhstan (Aqtobe)',
        'Asia/Ashgabat' => 'Lokacin Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'Lokacin Kazakhstan (Atyrau)',
        'Asia/Baghdad' => 'Lokacin Arebiya (Baghdad)',
        'Asia/Bahrain' => 'Lokacin Arebiya (Bahrain)',
        'Asia/Baku' => 'Lokacin Azerbaijan (Baku)',
        'Asia/Bangkok' => 'Lokacin Indochina (Bangkok)',
        'Asia/Barnaul' => 'Lokacin Krasnoyarsk (Barnaul)',
        'Asia/Beirut' => 'Lokaci a turai gabas (Beirut)',
        'Asia/Bishkek' => 'Lokacin Kyrgyzstan (Bishkek)',
        'Asia/Brunei' => 'Lokacin Brunei Darussalam',
        'Asia/Calcutta' => 'Tsayayyen lokacin Indiya (Kolkata)',
        'Asia/Kolkata' => 'Tsayayyen lokacin Indiya (Kolkata)',
        'Asia/Chita' => 'Lokacin Yakutsk (Chita)',
        'Asia/Colombo' => 'Tsayayyen lokacin Indiya (Colombo)',
        'Asia/Damascus' => 'Lokaci a turai gabas (Damascus)',
        'Asia/Dhaka' => 'Lokacin Bangladesh (Dhaka)',
        'Asia/Dili' => 'Lokacin East Timor (Dili)',
        'Asia/Dubai' => 'Tsayayyen lokacin Gulf (Dubai)',
        'Asia/Dushanbe' => 'Lokacin Tajikistan (Dushanbe)',
        'Asia/Famagusta' => 'Lokaci a turai gabas (Famagusta)',
        'Asia/Gaza' => 'Lokaci a turai gabas (Gaza)',
        'Asia/Hebron' => 'Lokaci a turai gabas (Hebron)',
        'Asia/Hong_Kong' => 'Lokacin Hong Kong',
        'Asia/Hovd' => 'Lokacin Hovd (Khovd)',
        'Asia/Irkutsk' => 'Lokacin Irkutsk',
        'Asia/Jakarta' => 'Lokacin Yammacin Indonesia (Jakarta)',
        'Asia/Jayapura' => 'Lokacin Gabashin Indonesia (Jayapura)',
        'Asia/Jerusalem' => 'Lokacin Israʼila (Jerusalem)',
        'Asia/Kabul' => 'Lokacin Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'Rasha Lokaci (Kamchatka)',
        'Asia/Karachi' => 'Lokacin Pakistan (Karachi)',
        'Asia/Katmandu' => 'Lokacin Nepal (Kathmandu)',
        'Asia/Kathmandu' => 'Lokacin Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Lokacin Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Lokacin Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Lokacin Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'Lokacin Malaysia (Kuching)',
        'Asia/Kuwait' => 'Lokacin Arebiya (Kuwait)',
        'Asia/Macau' => 'Lokacin Sin (Macao)',
        'Asia/Magadan' => 'Lokacin Magadan',
        'Asia/Makassar' => 'Lokacin Indonesia ta Tsakiya (Makassar)',
        'Asia/Manila' => 'Lokacin Philippine (Manila)',
        'Asia/Muscat' => 'Tsayayyen lokacin Gulf (Muscat)',
        'Asia/Nicosia' => 'Lokaci a turai gabas (Nicosia)',
        'Asia/Novokuznetsk' => 'Lokacin Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Lokacin Krasnoyarsk (Novosibirsk)',
        'Asia/Omsk' => 'Lokacin Omsk',
        'Asia/Oral' => 'Lokacin Kazakhstan (Oral)',
        'Asia/Phnom_Penh' => 'Lokacin Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'Lokacin Yammacin Indonesia (Pontianak)',
        'Asia/Pyongyang' => 'Lokacin Koriya (Pyongyang)',
        'Asia/Qatar' => 'Lokacin Arebiya (Qatar)',
        'Asia/Qostanay' => 'Lokacin Kazakhstan (Qostanay)',
        'Asia/Qyzylorda' => 'Lokacin Kazakhstan (Qyzylorda)',
        'Asia/Rangoon' => 'Lokacin Myanmar (Yangon)',
        'Asia/Yangon' => 'Lokacin Myanmar (Yangon)',
        'Asia/Riyadh' => 'Lokacin Arebiya (Riyadh)',
        'Asia/Saigon' => 'Lokacin Indochina (Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'Lokacin Indochina (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Lokacin Magadan (Sakhalin)',
        'Asia/Samarkand' => 'Lokacin Uzbekistan (Samarkand)',
        'Asia/Seoul' => 'Lokacin Koriya (Seoul)',
        'Asia/Shanghai' => 'Lokacin Sin (Shanghai)',
        'Asia/Singapore' => 'Tsayayyen Lokacin Singapore',
        'Asia/Srednekolymsk' => 'Lokacin Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Lokacin Taipei',
        'Asia/Tashkent' => 'Lokacin Uzbekistan (Tashkent)',
        'Asia/Tbilisi' => 'Lokacin Georgia (Tbilisi)',
        'Asia/Tehran' => 'Lokacin Iran (Tehran)',
        'Asia/Thimphu' => 'Lokacin Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Lokacin Japan (Tokyo)',
        'Asia/Tomsk' => 'Lokacin Krasnoyarsk (Tomsk)',
        'Asia/Ulaanbaatar' => 'Lokacin Ulaanbaatar',
        'Asia/Urumqi' => 'Sin Lokaci (Ürümqi)',
        'Asia/Ust-Nera' => 'Lokacin Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Lokacin Indochina (Vientiane)',
        'Asia/Vladivostok' => 'Lokacin Vladivostok',
        'Asia/Yakutsk' => 'Lokacin Yakutsk',
        'Asia/Yekaterinburg' => 'Lokacin Yekaterinburg',
        'Asia/Yerevan' => 'Lokacin Armenia (Yerevan)',
        'Atlantic/Azores' => 'Lokacin Azores',
        'Atlantic/Bermuda' => 'Lokacin Kanada, Puerto Rico da Virgin Islands (Bermuda)',
        'Atlantic/Canary' => 'Lokaci ta yammacin turai (Canarias)',
        'Atlantic/Cape_Verde' => 'Lokacin Cape Verde',
        'Atlantic/Faeroe' => 'Lokaci ta yammacin turai (Faroe)',
        'Atlantic/Faroe' => 'Lokaci ta yammacin turai (Faroe)',
        'Atlantic/Madeira' => 'Lokaci ta yammacin turai (Madeira)',
        'Atlantic/Reykjavik' => 'Lokacin Greenwich a Ingila (Reykjavik)',
        'Atlantic/South_Georgia' => 'Lokacin Kudancin Georgia (South Georgia)',
        'Atlantic/St_Helena' => 'Lokacin Greenwich a Ingila (St. Helena)',
        'Atlantic/Stanley' => 'Lokacin Falkland Islands (Stanley)',
        'Australia/Adelaide' => 'Lokacin Tsakiyar Australiya (Adelaide)',
        'Australia/Brisbane' => 'Lokacin Gabashin Austiraliya (Brisbane)',
        'Australia/Broken_Hill' => 'Lokacin Tsakiyar Australiya (Broken Hill)',
        'Australia/Darwin' => 'Lokacin Tsakiyar Australiya (Darwin)',
        'Australia/Eucla' => 'Lokacin Yammacin Tsakiyar Austiraliya (Eucla)',
        'Australia/Hobart' => 'Lokacin Gabashin Austiraliya (Hobart)',
        'Australia/Lindeman' => 'Lokacin Gabashin Austiraliya (Lindeman)',
        'Australia/Lord_Howe' => 'Lokacin Lord Howe',
        'Australia/Melbourne' => 'Lokacin Gabashin Austiraliya (Melbourne)',
        'Australia/Perth' => 'Lokacin Yammacin Austiralia (Perth)',
        'Australia/Sydney' => 'Lokacin Gabashin Austiraliya (Sydney)',
        'Etc/GMT' => 'Lokacin Greenwich a Ingila',
        'Etc/UTC' => 'Hadewa Lokaci na Duniya',
        'Europe/Amsterdam' => 'Tsakiyar a lokaci turai (Amsterdam)',
        'Europe/Andorra' => 'Tsakiyar a lokaci turai (Andorra)',
        'Europe/Astrakhan' => 'Rasha Lokaci (Astrakhan)',
        'Europe/Athens' => 'Lokaci a turai gabas (Athens)',
        'Europe/Belgrade' => 'Tsakiyar a lokaci turai (Belgrade)',
        'Europe/Berlin' => 'Tsakiyar a lokaci turai (Berlin)',
        'Europe/Bratislava' => 'Tsakiyar a lokaci turai (Bratislava)',
        'Europe/Brussels' => 'Tsakiyar a lokaci turai (Brussels)',
        'Europe/Bucharest' => 'Lokaci a turai gabas (Bucharest)',
        'Europe/Budapest' => 'Tsakiyar a lokaci turai (Budapest)',
        'Europe/Busingen' => 'Tsakiyar a lokaci turai (Büsingen)',
        'Europe/Chisinau' => 'Lokaci a turai gabas (Chișinău)',
        'Europe/Copenhagen' => 'Tsakiyar a lokaci turai (Copenhagen)',
        'Europe/Dublin' => 'Lokacin Greenwich a Ingila (Dublin)',
        'Europe/Gibraltar' => 'Tsakiyar a lokaci turai (Gibraltar)',
        'Europe/Guernsey' => 'Lokacin Greenwich a Ingila (Guernsey)',
        'Europe/Helsinki' => 'Lokaci a turai gabas (Helsinki)',
        'Europe/Isle_of_Man' => 'Lokacin Greenwich a Ingila (Isle of Man)',
        'Europe/Istanbul' => 'Turkiyya Lokaci (Istanbul)',
        'Europe/Jersey' => 'Lokacin Greenwich a Ingila (Jersey)',
        'Europe/Kaliningrad' => 'Lokaci a turai gabas (Kaliningrad)',
        'Europe/Kiev' => 'Lokaci a turai gabas (Kyiv)',
        'Europe/Kyiv' => 'Lokaci a turai gabas (Kyiv)',
        'Europe/Kirov' => 'Lokacin Moscow (Kirov)',
        'Europe/Lisbon' => 'Lokaci ta yammacin turai (Lisbon)',
        'Europe/Ljubljana' => 'Tsakiyar a lokaci turai (Ljubljana)',
        'Europe/London' => 'Lokacin Greenwich a Ingila (London)',
        'Europe/Luxembourg' => 'Tsakiyar a lokaci turai (Luxembourg)',
        'Europe/Madrid' => 'Tsakiyar a lokaci turai (Madrid)',
        'Europe/Malta' => 'Tsakiyar a lokaci turai (Malta)',
        'Europe/Mariehamn' => 'Lokaci a turai gabas (Mariehamn)',
        'Europe/Minsk' => 'Lokacin Moscow (Minsk)',
        'Europe/Monaco' => 'Tsakiyar a lokaci turai (Monaco)',
        'Europe/Moscow' => 'Lokacin Moscow',
        'Europe/Oslo' => 'Tsakiyar a lokaci turai (Oslo)',
        'Europe/Paris' => 'Tsakiyar a lokaci turai (Paris)',
        'Europe/Podgorica' => 'Tsakiyar a lokaci turai (Podgorica)',
        'Europe/Prague' => 'Tsakiyar a lokaci turai (Prague)',
        'Europe/Riga' => 'Lokaci a turai gabas (Riga)',
        'Europe/Rome' => 'Tsakiyar a lokaci turai (Rome)',
        'Europe/Samara' => 'Rasha Lokaci (Samara)',
        'Europe/San_Marino' => 'Tsakiyar a lokaci turai (San Marino)',
        'Europe/Sarajevo' => 'Tsakiyar a lokaci turai (Sarajevo)',
        'Europe/Saratov' => 'Rasha Lokaci (Saratov)',
        'Europe/Simferopol' => 'Lokacin Moscow (Simferopol)',
        'Europe/Skopje' => 'Tsakiyar a lokaci turai (Skopje)',
        'Europe/Sofia' => 'Lokaci a turai gabas (Sofia)',
        'Europe/Stockholm' => 'Tsakiyar a lokaci turai (Stockholm)',
        'Europe/Tallinn' => 'Lokaci a turai gabas (Tallinn)',
        'Europe/Tirane' => 'Tsakiyar a lokaci turai (Tirana)',
        'Europe/Ulyanovsk' => 'Rasha Lokaci (Ulyanovsk)',
        'Europe/Vaduz' => 'Tsakiyar a lokaci turai (Vaduz)',
        'Europe/Vatican' => 'Tsakiyar a lokaci turai (Vatican)',
        'Europe/Vienna' => 'Tsakiyar a lokaci turai (Vienna)',
        'Europe/Vilnius' => 'Lokaci a turai gabas (Vilnius)',
        'Europe/Volgograd' => 'Lokacin Moscow (Volgograd)',
        'Europe/Warsaw' => 'Tsakiyar a lokaci turai (Warsaw)',
        'Europe/Zagreb' => 'Tsakiyar a lokaci turai (Zagreb)',
        'Europe/Zurich' => 'Tsakiyar a lokaci turai (Zurich)',
        'Indian/Antananarivo' => 'Lokacin Gabashin Afirka (Antananarivo)',
        'Indian/Chagos' => 'Lokacin Tekun Indiya (Chagos)',
        'Indian/Christmas' => 'Lokacin Christmas Island',
        'Indian/Cocos' => 'Lokacin Cocos Islands',
        'Indian/Comoro' => 'Lokacin Gabashin Afirka (Comores)',
        'Indian/Kerguelen' => 'Lokacin Kudancin Faransa da Antarctic (Kerguelen)',
        'Indian/Mahe' => 'Lokacin Seychelles (Mahé)',
        'Indian/Maldives' => 'Lokacin Maldives',
        'Indian/Mauritius' => 'Lokacin Mauritius',
        'Indian/Mayotte' => 'Lokacin Gabashin Afirka (Mayotte)',
        'Indian/Reunion' => 'Lokacin Réunion',
        'Pacific/Apia' => 'Lokacin Apia',
        'Pacific/Auckland' => 'Lokacin New Zealand (Auckland)',
        'Pacific/Bougainville' => 'Lokacin Papua New Guinea (Bougainville)',
        'Pacific/Chatham' => 'Lokacin Chatham',
        'Pacific/Easter' => 'Lokacin Easter Island',
        'Pacific/Efate' => 'Lokacin Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Lokacin Phoenix Islands (Tsibirin Canton)',
        'Pacific/Kanton' => 'Lokacin Phoenix Islands (Tsibirin Canton)',
        'Pacific/Fakaofo' => 'Lokacin Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Lokacin Fiji',
        'Pacific/Funafuti' => 'Lokacin Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Lokacin Galapagos (Galápagos)',
        'Pacific/Gambier' => 'Lokacin Gambier',
        'Pacific/Guadalcanal' => 'Lokacin Rana na Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Tsayayyen Lokacin Chamorro (Guam)',
        'Pacific/Honolulu' => 'Tsayayyen Lokacin Hawaii-Aleutian (Honolulu)',
        'Pacific/Kiritimati' => 'Lokacin Line Islands (Kiritimati)',
        'Pacific/Kosrae' => 'Lokacin Kosrae',
        'Pacific/Kwajalein' => 'Lokacin Marshall Islands (Kwajalein)',
        'Pacific/Majuro' => 'Lokacin Marshall Islands (Majuro)',
        'Pacific/Marquesas' => 'Lokacin Marquesas',
        'Pacific/Midway' => 'Lokacin Samoa (Midway)',
        'Pacific/Nauru' => 'Lokacin Nauru',
        'Pacific/Niue' => 'Lokacin Niue',
        'Pacific/Norfolk' => 'Lokacin Norfolk Island',
        'Pacific/Noumea' => 'Lokacin New Caledonia (Nouméa)',
        'Pacific/Pago_Pago' => 'Lokacin Samoa (Pago Pago)',
        'Pacific/Palau' => 'Lokacin Palau',
        'Pacific/Pitcairn' => 'Lokacin Pitcairn',
        'Pacific/Ponape' => 'Lokacin Ponape (Pohnpei)',
        'Pacific/Pohnpei' => 'Lokacin Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Lokacin Papua New Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Lokacin Cook Islands (Rarotonga)',
        'Pacific/Saipan' => 'Tsayayyen Lokacin Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Lokacin Tahiti',
        'Pacific/Tarawa' => 'Lokacin Gilbert Islands (Tarawa)',
        'Pacific/Tongatapu' => 'Lokacin Tonga (Tongatapu)',
        'Pacific/Truk' => 'Lokacin Chuuk',
        'Pacific/Chuuk' => 'Lokacin Chuuk',
        'Pacific/Wake' => 'Lokacin Wake Island',
        'Pacific/Wallis' => 'Lokacin Wallis da Futuna (Wallis & Futuna)',
    ],
    'Meta' => [],
];
