<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich Mean Time (Abidjan)',
        'Africa/Accra' => 'Greenwich Mean Time (Accra)',
        'Africa/Addis_Ababa' => 'East-Afrikaanske tiid (Addis Abeba)',
        'Africa/Algiers' => 'Midden-Europeeske tiid (Algiers)',
        'Africa/Asmera' => 'East-Afrikaanske tiid (Asmara)',
        'Africa/Asmara' => 'East-Afrikaanske tiid (Asmara)',
        'Africa/Bamako' => 'Greenwich Mean Time (Bamako)',
        'Africa/Bangui' => 'West-Afrikaanske tiid (Bangui)',
        'Africa/Banjul' => 'Greenwich Mean Time (Banjul)',
        'Africa/Bissau' => 'Greenwich Mean Time (Bissau)',
        'Africa/Blantyre' => 'Sintraal-Afrikaanske tiid (Blantyre)',
        'Africa/Brazzaville' => 'West-Afrikaanske tiid (Brazzaville)',
        'Africa/Bujumbura' => 'Sintraal-Afrikaanske tiid (Bujumbura)',
        'Africa/Cairo' => 'East-Europeeske tiid (Caïro)',
        'Africa/Casablanca' => 'West-Europeeske tiid (Casablanca)',
        'Africa/Ceuta' => 'Midden-Europeeske tiid (Ceuta)',
        'Africa/Conakry' => 'Greenwich Mean Time (Conakry)',
        'Africa/Dakar' => 'Greenwich Mean Time (Dakar)',
        'Africa/Dar_es_Salaam' => 'East-Afrikaanske tiid (Dar es Salaam)',
        'Africa/Djibouti' => 'East-Afrikaanske tiid (Djibouti)',
        'Africa/Douala' => 'West-Afrikaanske tiid (Douala)',
        'Africa/El_Aaiun' => 'West-Europeeske tiid (El Aaiún)',
        'Africa/Freetown' => 'Greenwich Mean Time (Freetown)',
        'Africa/Gaborone' => 'Sintraal-Afrikaanske tiid (Gaborone)',
        'Africa/Harare' => 'Sintraal-Afrikaanske tiid (Harare)',
        'Africa/Johannesburg' => 'Sûd-Afrikaanske tiid (Johannesburg)',
        'Africa/Juba' => 'Sintraal-Afrikaanske tiid (Juba)',
        'Africa/Kampala' => 'East-Afrikaanske tiid (Kampala)',
        'Africa/Khartoum' => 'Sintraal-Afrikaanske tiid (Khartoem)',
        'Africa/Kigali' => 'Sintraal-Afrikaanske tiid (Kigali)',
        'Africa/Kinshasa' => 'West-Afrikaanske tiid (Kinshasa)',
        'Africa/Lagos' => 'West-Afrikaanske tiid (Lagos)',
        'Africa/Libreville' => 'West-Afrikaanske tiid (Libreville)',
        'Africa/Lome' => 'Greenwich Mean Time (Lomé)',
        'Africa/Luanda' => 'West-Afrikaanske tiid (Luanda)',
        'Africa/Lubumbashi' => 'Sintraal-Afrikaanske tiid (Lubumbashi)',
        'Africa/Lusaka' => 'Sintraal-Afrikaanske tiid (Lusaka)',
        'Africa/Malabo' => 'West-Afrikaanske tiid (Malabo)',
        'Africa/Maputo' => 'Sintraal-Afrikaanske tiid (Maputo)',
        'Africa/Maseru' => 'Sûd-Afrikaanske tiid (Maseru)',
        'Africa/Mbabane' => 'Sûd-Afrikaanske tiid (Mbabane)',
        'Africa/Mogadishu' => 'East-Afrikaanske tiid (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich Mean Time (Monrovia)',
        'Africa/Nairobi' => 'East-Afrikaanske tiid (Nairobi)',
        'Africa/Ndjamena' => 'West-Afrikaanske tiid (N’Djamena)',
        'Africa/Niamey' => 'West-Afrikaanske tiid (Niamey)',
        'Africa/Nouakchott' => 'Greenwich Mean Time (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich Mean Time (Ouagadougou)',
        'Africa/Porto-Novo' => 'West-Afrikaanske tiid (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich Mean Time (Sao Tomé)',
        'Africa/Tripoli' => 'East-Europeeske tiid (Tripoli)',
        'Africa/Tunis' => 'Midden-Europeeske tiid (Tunis)',
        'Africa/Windhoek' => 'Sintraal-Afrikaanske tiid (Windhoek)',
        'America/Adak' => 'Hawaii-Aleoetyske tiid (Adak)',
        'America/Anchorage' => 'Alaska-tiid (Anchorage)',
        'America/Anguilla' => 'Atlantic-tiid (Anguilla)',
        'America/Antigua' => 'Atlantic-tiid (Antigua)',
        'America/Araguaina' => 'Brazyljaanske tiid (Araguaína)',
        'America/Argentina/La_Rioja' => 'Argentynske tiid (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentynske tiid (Río Gallegos)',
        'America/Argentina/Salta' => 'Argentynske tiid (Salta)',
        'America/Argentina/San_Juan' => 'Argentynske tiid (San Juan)',
        'America/Argentina/San_Luis' => 'Argentynske tiid (San Luis)',
        'America/Argentina/Tucuman' => 'Argentynske tiid (Tucumán)',
        'America/Argentina/Ushuaia' => 'Argentynske tiid (Ushuaia)',
        'America/Aruba' => 'Atlantic-tiid (Aruba)',
        'America/Asuncion' => 'Paraguayaanske tiid (Asunción)',
        'America/Bahia' => 'Brazyljaanske tiid (Bahia)',
        'America/Bahia_Banderas' => 'Central-tiid (Bahía de Banderas)',
        'America/Barbados' => 'Atlantic-tiid (Barbados)',
        'America/Belem' => 'Brazyljaanske tiid (Belém)',
        'America/Belize' => 'Central-tiid (Belize)',
        'America/Blanc-Sablon' => 'Atlantic-tiid (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazone-tiid (Boa Vista)',
        'America/Bogota' => 'Kolombiaanske tiid (Bogotá)',
        'America/Boise' => 'Mountain-tiid (Boise)',
        'America/Buenos_Aires' => 'Argentynske tiid (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Argentynske tiid (Buenos Aires)',
        'America/Cambridge_Bay' => 'Mountain-tiid (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazone-tiid (Campo Grande)',
        'America/Cancun' => 'Eastern-tiid (Cancún)',
        'America/Caracas' => 'Fenezolaanske tiid (Caracas)',
        'America/Catamarca' => 'Argentynske tiid (Catamarca)',
        'America/Argentina/Catamarca' => 'Argentynske tiid (Catamarca)',
        'America/Cayenne' => 'Frâns-Guyaanske tiid (Cayenne)',
        'America/Cayman' => 'Eastern-tiid (Cayman)',
        'America/Chicago' => 'Central-tiid (Chicago)',
        'America/Chihuahua' => 'Central-tiid (Chihuahua)',
        'America/Ciudad_Juarez' => 'Mountain-tiid (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Eastern-tiid (Atikokan)',
        'America/Atikokan' => 'Eastern-tiid (Atikokan)',
        'America/Cordoba' => 'Argentynske tiid (Córdoba)',
        'America/Argentina/Cordoba' => 'Argentynske tiid (Córdoba)',
        'America/Costa_Rica' => 'Central-tiid (Costa Rica)',
        'America/Coyhaique' => 'Sileenske tiid (Coyhaique)',
        'America/Creston' => 'Mountain-tiid (Creston)',
        'America/Cuiaba' => 'Amazone-tiid (Cuiabá)',
        'America/Curacao' => 'Atlantic-tiid (Curaçao)',
        'America/Danmarkshavn' => 'Greenwich Mean Time (Danmarkshavn)',
        'America/Dawson' => 'Canada-tiid (Dawson)',
        'America/Dawson_Creek' => 'Mountain-tiid (Dawson Creek)',
        'America/Denver' => 'Mountain-tiid (Denver)',
        'America/Detroit' => 'Eastern-tiid (Detroit)',
        'America/Dominica' => 'Atlantic-tiid (Dominica)',
        'America/Edmonton' => 'Mountain-tiid (Edmonton)',
        'America/Eirunepe' => 'Acre-tiid (Eirunepé)',
        'America/El_Salvador' => 'Central-tiid (Salvador)',
        'America/Fort_Nelson' => 'Mountain-tiid (Fort Nelson)',
        'America/Fortaleza' => 'Brazyljaanske tiid (Fortaleza)',
        'America/Glace_Bay' => 'Atlantic-tiid (Glace Bay)',
        'America/Godthab' => 'Grienlân-tiid (Nuuk)',
        'America/Nuuk' => 'Grienlân-tiid (Nuuk)',
        'America/Goose_Bay' => 'Atlantic-tiid (Goose Bay)',
        'America/Grand_Turk' => 'Eastern-tiid (Grand Turk)',
        'America/Grenada' => 'Atlantic-tiid (Grenada)',
        'America/Guadeloupe' => 'Atlantic-tiid (Guadeloupe)',
        'America/Guatemala' => 'Central-tiid (Guatemala)',
        'America/Guayaquil' => 'Ecuadoraanske tiid (Guayaquil)',
        'America/Guyana' => 'Guyaanske tiid (Guyana)',
        'America/Halifax' => 'Atlantic-tiid (Halifax)',
        'America/Havana' => 'Kubaanske tiid (Havana)',
        'America/Hermosillo' => 'Mexico-tiid (Hermosillo)',
        'America/Indiana/Knox' => 'Central-tiid (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Eastern-tiid (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Eastern-tiid (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Central-tiid (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Eastern-tiid (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Eastern-tiid (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Eastern-tiid (Winamac, Indiana)',
        'America/Indianapolis' => 'Eastern-tiid (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Eastern-tiid (Indianapolis)',
        'America/Inuvik' => 'Mountain-tiid (Inuvik)',
        'America/Iqaluit' => 'Eastern-tiid (Iqaluit)',
        'America/Jamaica' => 'Eastern-tiid (Jamaica)',
        'America/Jujuy' => 'Argentynske tiid (Jujuy)',
        'America/Argentina/Jujuy' => 'Argentynske tiid (Jujuy)',
        'America/Juneau' => 'Alaska-tiid (Juneau)',
        'America/Kentucky/Monticello' => 'Eastern-tiid (Monticello, Kentucky)',
        'America/Kralendijk' => 'Atlantic-tiid (Kralendijk)',
        'America/La_Paz' => 'Boliviaanske tiid (La Paz)',
        'America/Lima' => 'Peruaanske tiid (Lima)',
        'America/Los_Angeles' => 'Pasifik-tiid (Los Angeles)',
        'America/Louisville' => 'Eastern-tiid (Louisville)',
        'America/Kentucky/Louisville' => 'Eastern-tiid (Louisville)',
        'America/Lower_Princes' => 'Atlantic-tiid (Beneden Prinsen Kwartier)',
        'America/Maceio' => 'Brazyljaanske tiid (Maceió)',
        'America/Managua' => 'Central-tiid (Managua)',
        'America/Manaus' => 'Amazone-tiid (Manaus)',
        'America/Marigot' => 'Atlantic-tiid (Marigot)',
        'America/Martinique' => 'Atlantic-tiid (Martinique)',
        'America/Matamoros' => 'Central-tiid (Matamoros)',
        'America/Mazatlan' => 'Mexico-tiid (Mazatlán)',
        'America/Mendoza' => 'Argentynske tiid (Mendoza)',
        'America/Argentina/Mendoza' => 'Argentynske tiid (Mendoza)',
        'America/Menominee' => 'Central-tiid (Menominee)',
        'America/Merida' => 'Central-tiid (Mérida)',
        'America/Metlakatla' => 'Alaska-tiid (Metlakatla)',
        'America/Mexico_City' => 'Central-tiid (Mexico-stad)',
        'America/Miquelon' => 'Saint Pierre en Miquelon-tiid',
        'America/Moncton' => 'Atlantic-tiid (Moncton)',
        'America/Monterrey' => 'Central-tiid (Monterrey)',
        'America/Montevideo' => 'Uruguayaanske tiid (Montevideo)',
        'America/Montserrat' => 'Atlantic-tiid (Montserrat)',
        'America/Nassau' => 'Eastern-tiid (Nassau)',
        'America/New_York' => 'Eastern-tiid (New York)',
        'America/Nome' => 'Alaska-tiid (Nome)',
        'America/Noronha' => 'Fernando de Noronha-tiid',
        'America/North_Dakota/Beulah' => 'Central-tiid (Beulah, Noard-Dakota)',
        'America/North_Dakota/Center' => 'Central-tiid (Center, Noard-Dakota)',
        'America/North_Dakota/New_Salem' => 'Central-tiid (New Salem, Noard-Dakota)',
        'America/Ojinaga' => 'Central-tiid (Ojinaga)',
        'America/Panama' => 'Eastern-tiid (Panama)',
        'America/Paramaribo' => 'Surinaamske tiid (Paramaribo)',
        'America/Phoenix' => 'Mountain-tiid (Phoenix)',
        'America/Port-au-Prince' => 'Eastern-tiid (Port-au-Prince)',
        'America/Port_of_Spain' => 'Atlantic-tiid (Port of Spain)',
        'America/Porto_Velho' => 'Amazone-tiid (Pôrto Velho)',
        'America/Puerto_Rico' => 'Atlantic-tiid (Puerto Rico)',
        'America/Punta_Arenas' => 'Sileenske tiid (Punta Arenas)',
        'America/Rankin_Inlet' => 'Central-tiid (Rankin Inlet)',
        'America/Recife' => 'Brazyljaanske tiid (Recife)',
        'America/Regina' => 'Central-tiid (Regina)',
        'America/Resolute' => 'Central-tiid (Resolute)',
        'America/Rio_Branco' => 'Acre-tiid (Rio Branco)',
        'America/Santarem' => 'Brazyljaanske tiid (Santarém)',
        'America/Santiago' => 'Sileenske tiid (Santiago)',
        'America/Santo_Domingo' => 'Atlantic-tiid (Santo Domingo)',
        'America/Sao_Paulo' => 'Brazyljaanske tiid (São Paulo)',
        'America/Scoresbysund' => 'Grienlân-tiid (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaska-tiid (Sitka)',
        'America/St_Barthelemy' => 'Atlantic-tiid (Saint-Barthélemy)',
        'America/St_Johns' => 'Newfoundlânske-tiid (St. John’s)',
        'America/St_Kitts' => 'Atlantic-tiid (St. Kitts)',
        'America/St_Lucia' => 'Atlantic-tiid (St. Lucia)',
        'America/St_Thomas' => 'Atlantic-tiid (St. Thomas)',
        'America/St_Vincent' => 'Atlantic-tiid (St. Vincent)',
        'America/Swift_Current' => 'Central-tiid (Swift Current)',
        'America/Tegucigalpa' => 'Central-tiid (Tegucigalpa)',
        'America/Thule' => 'Atlantic-tiid (Thule)',
        'America/Tijuana' => 'Pasifik-tiid (Tijuana)',
        'America/Toronto' => 'Eastern-tiid (Toronto)',
        'America/Tortola' => 'Atlantic-tiid (Tortola)',
        'America/Vancouver' => 'Pasifik-tiid (Vancouver)',
        'America/Whitehorse' => 'Canada-tiid (Whitehorse)',
        'America/Winnipeg' => 'Central-tiid (Winnipeg)',
        'America/Yakutat' => 'Alaska-tiid (Yakutat)',
        'Antarctica/Casey' => 'West-Australyske tiid (Casey)',
        'Antarctica/Davis' => 'Davis tiid',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urville tiid',
        'Antarctica/Macquarie' => 'East-Australyske tiid (Macquarie)',
        'Antarctica/Mawson' => 'Mawson tiid',
        'Antarctica/McMurdo' => 'Nij-Seelânske tiid (McMurdo)',
        'Antarctica/Palmer' => 'Sileenske tiid (Palmer)',
        'Antarctica/Rothera' => 'Rothera tiid',
        'Antarctica/Syowa' => 'Syowa tiid (Showa)',
        'Antarctica/Troll' => 'Greenwich Mean Time (Troll)',
        'Antarctica/Vostok' => 'Vostok tiid',
        'Arctic/Longyearbyen' => 'Midden-Europeeske tiid (Longyearbyen)',
        'Asia/Aden' => 'Arabyske tiid (Aden)',
        'Asia/Almaty' => 'Kazachstan-tiid (Alma-Ata)',
        'Asia/Amman' => 'East-Europeeske tiid (Amman)',
        'Asia/Anadyr' => 'Petropavlovsk-Kamtsjatski-tiid (Anadyr)',
        'Asia/Aqtau' => 'Kazachstan-tiid (Aqtau)',
        'Asia/Aqtobe' => 'Kazachstan-tiid (Aqtöbe)',
        'Asia/Ashgabat' => 'Turkmeense tiid (Asjchabad)',
        'Asia/Atyrau' => 'Kazachstan-tiid (Atyrau)',
        'Asia/Baghdad' => 'Arabyske tiid (Bagdad)',
        'Asia/Bahrain' => 'Arabyske tiid (Bahrein)',
        'Asia/Baku' => 'Azerbeidzjaanske tiid (Bakoe)',
        'Asia/Bangkok' => 'Yndochinese tiid (Bangkok)',
        'Asia/Barnaul' => 'Krasnojarsk-tiid (Barnaul)',
        'Asia/Beirut' => 'East-Europeeske tiid (Beiroet)',
        'Asia/Bishkek' => 'Kirgizyske tiid (Bisjkek)',
        'Asia/Brunei' => 'Bruneise tiid',
        'Asia/Calcutta' => 'Yndiaaske tiid (Calcutta)',
        'Asia/Kolkata' => 'Yndiaaske tiid (Calcutta)',
        'Asia/Chita' => 'Jakoetsk-tiid (Chita)',
        'Asia/Colombo' => 'Yndiaaske tiid (Colombo)',
        'Asia/Damascus' => 'East-Europeeske tiid (Damascus)',
        'Asia/Dhaka' => 'Bengalese tiid (Dhaka)',
        'Asia/Dili' => 'East-Timorese tiid (Dili)',
        'Asia/Dubai' => 'Golf standerttiid (Dubai)',
        'Asia/Dushanbe' => 'Tadzjiekse tiid (Dusjanbe)',
        'Asia/Famagusta' => 'East-Europeeske tiid (Famagusta)',
        'Asia/Gaza' => 'East-Europeeske tiid (Gaza)',
        'Asia/Hebron' => 'East-Europeeske tiid (Hebron)',
        'Asia/Hong_Kong' => 'Hongkongse tiid',
        'Asia/Hovd' => 'Hovd tiid (Khovd)',
        'Asia/Irkutsk' => 'Irkoetsk-tiid',
        'Asia/Jakarta' => 'West-Yndonezyske tiid (Jakarta)',
        'Asia/Jayapura' => 'East-Yndonezyske tiid (Jayapura)',
        'Asia/Jerusalem' => 'Israëlyske tiid (Jeruzalem)',
        'Asia/Kabul' => 'Afghaanske tiid (Kabul)',
        'Asia/Kamchatka' => 'Petropavlovsk-Kamtsjatski-tiid (Kamtsjatka)',
        'Asia/Karachi' => 'Pakistaanske tiid (Karachi)',
        'Asia/Katmandu' => 'Nepalese tiid (Kathmandu)',
        'Asia/Kathmandu' => 'Nepalese tiid (Kathmandu)',
        'Asia/Khandyga' => 'Jakoetsk-tiid (Khandyga)',
        'Asia/Krasnoyarsk' => 'Krasnojarsk-tiid',
        'Asia/Kuala_Lumpur' => 'Maleisyske tiid (Kuala Lumpur)',
        'Asia/Kuching' => 'Maleisyske tiid (Kuching)',
        'Asia/Kuwait' => 'Arabyske tiid (Koeweit)',
        'Asia/Macau' => 'Sineeske tiid (Macao)',
        'Asia/Magadan' => 'Magadan-tiid',
        'Asia/Makassar' => 'Sintraal-Yndonezyske tiid (Makassar)',
        'Asia/Manila' => 'Filipijnse tiid (Manilla)',
        'Asia/Muscat' => 'Golf standerttiid (Muscat)',
        'Asia/Nicosia' => 'East-Europeeske tiid (Nicosia)',
        'Asia/Novokuznetsk' => 'Krasnojarsk-tiid (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Krasnojarsk-tiid (Novosibirsk)',
        'Asia/Omsk' => 'Omsk-tiid',
        'Asia/Oral' => 'Kazachstan-tiid (Oral)',
        'Asia/Phnom_Penh' => 'Yndochinese tiid (Phnom-Penh)',
        'Asia/Pontianak' => 'West-Yndonezyske tiid (Pontianak)',
        'Asia/Pyongyang' => 'Koreaanske tiid (Pyongyang)',
        'Asia/Qatar' => 'Arabyske tiid (Qatar)',
        'Asia/Qostanay' => 'Kazachstan-tiid (Qostanay)',
        'Asia/Qyzylorda' => 'Kazachstan-tiid (Qyzylorda)',
        'Asia/Rangoon' => 'Myanmarese tiid (Yangon)',
        'Asia/Yangon' => 'Myanmarese tiid (Yangon)',
        'Asia/Riyadh' => 'Arabyske tiid (Riyad)',
        'Asia/Saigon' => 'Yndochinese tiid (Ho Chi Minhstad)',
        'Asia/Ho_Chi_Minh' => 'Yndochinese tiid (Ho Chi Minhstad)',
        'Asia/Sakhalin' => 'Magadan-tiid (Sachalin)',
        'Asia/Samarkand' => 'Oezbeekse tiid (Samarkand)',
        'Asia/Seoul' => 'Koreaanske tiid (Seoul)',
        'Asia/Shanghai' => 'Sineeske tiid (Sjanghai)',
        'Asia/Singapore' => 'Singaporese standerttiid',
        'Asia/Srednekolymsk' => 'Magadan-tiid (Srednekolymsk)',
        'Asia/Taipei' => 'Taipei tiid',
        'Asia/Tashkent' => 'Oezbeekse tiid (Tasjkent)',
        'Asia/Tbilisi' => 'Georgyske tiid (Tbilisi)',
        'Asia/Tehran' => 'Iraanske tiid (Teheran)',
        'Asia/Thimphu' => 'Bhutaanske tiid (Thimphu)',
        'Asia/Tokyo' => 'Japanske tiid (Tokio)',
        'Asia/Tomsk' => 'Krasnojarsk-tiid (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulaanbaatar tiid',
        'Asia/Urumqi' => 'Sina-tiid (Ürümqi)',
        'Asia/Ust-Nera' => 'Vladivostok-tiid (Ust-Nera)',
        'Asia/Vientiane' => 'Yndochinese tiid (Vientiane)',
        'Asia/Vladivostok' => 'Vladivostok-tiid',
        'Asia/Yakutsk' => 'Jakoetsk-tiid',
        'Asia/Yekaterinburg' => 'Jekaterinenburg-tiid',
        'Asia/Yerevan' => 'Armeense tiid (Jerevan)',
        'Atlantic/Azores' => 'Azoren-tiid',
        'Atlantic/Bermuda' => 'Atlantic-tiid (Bermuda)',
        'Atlantic/Canary' => 'West-Europeeske tiid (Kanaryske Eilannen)',
        'Atlantic/Cape_Verde' => 'Kaapverdyske tiid (Kaapverdië)',
        'Atlantic/Faeroe' => 'West-Europeeske tiid (Faeröer)',
        'Atlantic/Faroe' => 'West-Europeeske tiid (Faeröer)',
        'Atlantic/Madeira' => 'West-Europeeske tiid (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich Mean Time (Reykjavik)',
        'Atlantic/South_Georgia' => 'Sûd-Georgyske tiid (Sûd-Georgia)',
        'Atlantic/St_Helena' => 'Greenwich Mean Time (Sint-Helena)',
        'Atlantic/Stanley' => 'Falklâneilânske tiid (Stanley)',
        'Australia/Adelaide' => 'Midden-Australyske tiid (Adelaide)',
        'Australia/Brisbane' => 'East-Australyske tiid (Brisbane)',
        'Australia/Broken_Hill' => 'Midden-Australyske tiid (Broken Hill)',
        'Australia/Darwin' => 'Midden-Australyske tiid (Darwin)',
        'Australia/Eucla' => 'Midden-Australyske westelijke tiid (Eucla)',
        'Australia/Hobart' => 'East-Australyske tiid (Hobart)',
        'Australia/Lindeman' => 'East-Australyske tiid (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howe-eilânske tiid',
        'Australia/Melbourne' => 'East-Australyske tiid (Melbourne)',
        'Australia/Perth' => 'West-Australyske tiid (Perth)',
        'Australia/Sydney' => 'East-Australyske tiid (Sydney)',
        'Etc/GMT' => 'Greenwich Mean Time',
        'Europe/Amsterdam' => 'Midden-Europeeske tiid (Amsterdam)',
        'Europe/Andorra' => 'Midden-Europeeske tiid (Andorra)',
        'Europe/Astrakhan' => 'Samara-tiid (Astrakhan)',
        'Europe/Athens' => 'East-Europeeske tiid (Athene)',
        'Europe/Belgrade' => 'Midden-Europeeske tiid (Belgrado)',
        'Europe/Berlin' => 'Midden-Europeeske tiid (Berlyn)',
        'Europe/Bratislava' => 'Midden-Europeeske tiid (Bratislava)',
        'Europe/Brussels' => 'Midden-Europeeske tiid (Brussel)',
        'Europe/Bucharest' => 'East-Europeeske tiid (Boekarest)',
        'Europe/Budapest' => 'Midden-Europeeske tiid (Boedapest)',
        'Europe/Busingen' => 'Midden-Europeeske tiid (Büsingen)',
        'Europe/Chisinau' => 'East-Europeeske tiid (Chișinău)',
        'Europe/Copenhagen' => 'Midden-Europeeske tiid (Kopenhagen)',
        'Europe/Dublin' => 'Greenwich Mean Time (Dublin)',
        'Europe/Gibraltar' => 'Midden-Europeeske tiid (Gibraltar)',
        'Europe/Guernsey' => 'Greenwich Mean Time (Guernsey)',
        'Europe/Helsinki' => 'East-Europeeske tiid (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwich Mean Time (Isle of Man)',
        'Europe/Istanbul' => 'Turkije-tiid (Istanboel)',
        'Europe/Jersey' => 'Greenwich Mean Time (Jersey)',
        'Europe/Kaliningrad' => 'East-Europeeske tiid (Kaliningrad)',
        'Europe/Kiev' => 'East-Europeeske tiid (Kyiv)',
        'Europe/Kyiv' => 'East-Europeeske tiid (Kyiv)',
        'Europe/Kirov' => 'Moskou-tiid (Kirov)',
        'Europe/Lisbon' => 'West-Europeeske tiid (Lissabon)',
        'Europe/Ljubljana' => 'Midden-Europeeske tiid (Ljubljana)',
        'Europe/London' => 'Greenwich Mean Time (Londen)',
        'Europe/Luxembourg' => 'Midden-Europeeske tiid (Luxemburg)',
        'Europe/Madrid' => 'Midden-Europeeske tiid (Madrid)',
        'Europe/Malta' => 'Midden-Europeeske tiid (Malta)',
        'Europe/Mariehamn' => 'East-Europeeske tiid (Mariehamn)',
        'Europe/Minsk' => 'Moskou-tiid (Minsk)',
        'Europe/Monaco' => 'Midden-Europeeske tiid (Monaco)',
        'Europe/Moscow' => 'Moskou-tiid',
        'Europe/Oslo' => 'Midden-Europeeske tiid (Oslo)',
        'Europe/Paris' => 'Midden-Europeeske tiid (Parys)',
        'Europe/Podgorica' => 'Midden-Europeeske tiid (Podgorica)',
        'Europe/Prague' => 'Midden-Europeeske tiid (Praach)',
        'Europe/Riga' => 'East-Europeeske tiid (Riga)',
        'Europe/Rome' => 'Midden-Europeeske tiid (Rome)',
        'Europe/Samara' => 'Samara-tiid',
        'Europe/San_Marino' => 'Midden-Europeeske tiid (San Marino)',
        'Europe/Sarajevo' => 'Midden-Europeeske tiid (Sarajevo)',
        'Europe/Saratov' => 'Samara-tiid (Saratov)',
        'Europe/Simferopol' => 'Moskou-tiid (Simferopol)',
        'Europe/Skopje' => 'Midden-Europeeske tiid (Skopje)',
        'Europe/Sofia' => 'East-Europeeske tiid (Sofia)',
        'Europe/Stockholm' => 'Midden-Europeeske tiid (Stockholm)',
        'Europe/Tallinn' => 'East-Europeeske tiid (Tallinn)',
        'Europe/Tirane' => 'Midden-Europeeske tiid (Tirana)',
        'Europe/Ulyanovsk' => 'Samara-tiid (Ulyanovsk)',
        'Europe/Vaduz' => 'Midden-Europeeske tiid (Vaduz)',
        'Europe/Vatican' => 'Midden-Europeeske tiid (Fatikaanstêd)',
        'Europe/Vienna' => 'Midden-Europeeske tiid (Wenen)',
        'Europe/Vilnius' => 'East-Europeeske tiid (Vilnius)',
        'Europe/Volgograd' => 'Moskou-tiid (Wolgograd)',
        'Europe/Warsaw' => 'Midden-Europeeske tiid (Warschau)',
        'Europe/Zagreb' => 'Midden-Europeeske tiid (Zagreb)',
        'Europe/Zurich' => 'Midden-Europeeske tiid (Zürich)',
        'Indian/Antananarivo' => 'East-Afrikaanske tiid (Antananarivo)',
        'Indian/Chagos' => 'Yndyske Oceaan-tiid (Chagosarchipel)',
        'Indian/Christmas' => 'Krysteilânske tiid',
        'Indian/Cocos' => 'Kokoseilânske tiid (Cocoseilannen)',
        'Indian/Comoro' => 'East-Afrikaanske tiid (Comores)',
        'Indian/Kerguelen' => 'Frânske Súdlike en Antarctyske tiid (Kerguelen)',
        'Indian/Mahe' => 'Seychelse tiid (Mahé)',
        'Indian/Maldives' => 'Maldivyske tiid (Maldiven)',
        'Indian/Mauritius' => 'Mauritiaanske tiid (Mauritius)',
        'Indian/Mayotte' => 'East-Afrikaanske tiid (Mayotte)',
        'Indian/Reunion' => 'Réunionse tiid',
        'Pacific/Apia' => 'Samoa-tiid (Apia)',
        'Pacific/Auckland' => 'Nij-Seelânske tiid (Auckland)',
        'Pacific/Bougainville' => 'Papoea-Nij-Guineeske tiid (Bougainville)',
        'Pacific/Chatham' => 'Chatham tiid',
        'Pacific/Easter' => 'Peaskeeilânske tiid',
        'Pacific/Efate' => 'Vanuatuaanske tiid (Efate)',
        'Pacific/Enderbury' => 'Phoenixeilânske tiid (Enderbury-eilân)',
        'Pacific/Kanton' => 'Phoenixeilânske tiid (Enderbury-eilân)',
        'Pacific/Fakaofo' => 'Tokelau-eilânske tiid (Fakaofo)',
        'Pacific/Fiji' => 'Fijyske tiid (Fiji)',
        'Pacific/Funafuti' => 'Tuvaluaanske tiid (Funafuti)',
        'Pacific/Galapagos' => 'Galapagoseilânske tiid (Galápagos)',
        'Pacific/Gambier' => 'Gambiereilânske tiid (Gambiereilannen)',
        'Pacific/Guadalcanal' => 'Salomonseilânske tiid (Guadalcanal)',
        'Pacific/Guam' => 'Chamorro-tiid (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleoetyske standerttiid (Honolulu)',
        'Pacific/Kiritimati' => 'Line-eilânske tiid (Kiritimati)',
        'Pacific/Kosrae' => 'Kosraese tiid',
        'Pacific/Kwajalein' => 'Marshalleilânske tiid (Kwajalein)',
        'Pacific/Majuro' => 'Marshalleilânske tiid (Majuro)',
        'Pacific/Marquesas' => 'Marquesaseilânske tiid (Marquesaseilannen)',
        'Pacific/Midway' => 'Samoaanske tiid (Midway)',
        'Pacific/Nauru' => 'Nauruaanske tiid',
        'Pacific/Niue' => 'Niuese tiid',
        'Pacific/Norfolk' => 'Norfolkeilânske tiid',
        'Pacific/Noumea' => 'Nij-Kaledonyske tiid (Nouméa)',
        'Pacific/Pago_Pago' => 'Samoaanske tiid (Pago Pago)',
        'Pacific/Palau' => 'Belause tiid (Palau)',
        'Pacific/Pitcairn' => 'Pitcairneillânske tiid',
        'Pacific/Ponape' => 'Pohnpei tiid',
        'Pacific/Pohnpei' => 'Pohnpei tiid',
        'Pacific/Port_Moresby' => 'Papoea-Nij-Guineeske tiid (Port Moresby)',
        'Pacific/Rarotonga' => 'Cookeilânse tiid (Rarotonga)',
        'Pacific/Saipan' => 'Chamorro-tiid (Saipan)',
        'Pacific/Tahiti' => 'Tahitiaanske tiid',
        'Pacific/Tarawa' => 'Gilberteilânske tiid (Tarawa)',
        'Pacific/Tongatapu' => 'Tongaanske tiid (Tongatapu)',
        'Pacific/Truk' => 'Chuukse tiid',
        'Pacific/Chuuk' => 'Chuukse tiid',
        'Pacific/Wake' => 'Wake-eilânske tiid',
        'Pacific/Wallis' => 'Wallis en Futunase tiid (Wallis & Futuna)',
    ],
    'Meta' => [],
];
