<?php

return [
    'Names' => [
        'Arab' => 'гарәп',
        'Cyrl' => 'кирилл',
        'Hans' => 'гадиләштерелгән',
        'Hant' => 'традицион',
        'Jpan' => 'япон',
        'Kore' => 'корея',
        'Latn' => 'латин',
        'Zxxx' => 'язусыз',
    ],
];
