<?php

return [
    'Names' => [
        'aa' => 'афар',
        'ab' => 'абхаз',
        'af' => 'африкаанс',
        'agq' => 'агем',
        'ak' => 'акан',
        'am' => 'амхар',
        'an' => 'арагон',
        'ann' => 'оболо',
        'apc' => 'левант ғәрәп',
        'ar' => 'ғәрәп',
        'arn' => 'мапуче',
        'as' => 'ассам',
        'asa' => 'асу',
        'ast' => 'астурий',
        'az' => 'әзербайжан',
        'ba' => 'башҡорт',
        'bal' => 'балудж',
        'bas' => 'басаа',
        'be' => 'белорус',
        'bem' => 'бемба',
        'bew' => 'бетави',
        'bez' => 'бена',
        'bg' => 'болгар',
        'bgc' => 'харьянви',
        'bgn' => 'көнбайыш белудж',
        'bho' => 'бходжпури',
        'blo' => 'ании',
        'blt' => 'тай дам',
        'bm' => 'бамбара',
        'bn' => 'бенгал',
        'bo' => 'тибет',
        'bqi' => 'бәхтиәр',
        'br' => 'бретон',
        'brx' => 'бодо',
        'bs' => 'босний',
        'bss' => 'акоосе',
        'bua' => 'бүрәт',
        'byn' => 'блин',
        'ca' => 'каталан',
        'cad' => 'каддо',
        'cch' => 'атсам',
        'ccp' => 'чакма',
        'ce' => 'чечен',
        'ceb' => 'себуано',
        'cgg' => 'чига',
        'cho' => 'чоктав',
        'chr' => 'чероки',
        'cic' => 'чикасо',
        'ckb' => 'үҙәк курд',
        'co' => 'корсика',
        'cop' => 'копт',
        'cs' => 'чех',
        'csw' => 'һаҙлыҡлы кри',
        'cu' => 'сиркәү славян',
        'cv' => 'сыуаш',
        'cy' => 'валлий',
        'da' => 'дат',
        'dav' => 'таита',
        'de' => 'немец',
        'dje' => 'зарма',
        'doi' => 'догри',
        'dsb' => 'түбәнге лужиц',
        'dua' => 'дуала',
        'dv' => 'дивехи',
        'dyo' => 'джола фоньи',
        'dz' => 'дзонг-кэ',
        'ebu' => 'эмбу',
        'ee' => 'эве',
        'el' => 'грек',
        'en' => 'инглиз',
        'eo' => 'эсперанто',
        'es' => 'испан',
        'et' => 'эстон',
        'eu' => 'баск',
        'ewo' => 'эвондо',
        'fa' => 'фарсы',
        'ff' => 'фула',
        'fi' => 'фин',
        'fil' => 'филиппин',
        'fo' => 'фарер',
        'fr' => 'француз',
        'frc' => 'каджун француз',
        'frr' => 'төньяҡ фриз',
        'fur' => 'фриул',
        'fy' => 'көнбайыш фриз',
        'ga' => 'ирланд',
        'gaa' => 'га',
        'gd' => 'шотланд гэл',
        'gez' => 'геэз',
        'gl' => 'галисий',
        'gn' => 'гуарани',
        'gsw' => 'швейцария немец',
        'gu' => 'гуджарати',
        'guz' => 'гусии',
        'gv' => 'мэн',
        'ha' => 'хауса',
        'haw' => 'гавай',
        'he' => 'иврит',
        'hi' => 'һинди',
        'hnj' => 'хмонг нджуа',
        'hr' => 'хорват',
        'hsb' => 'үрге лужи',
        'ht' => 'гаити креол',
        'hu' => 'венгр',
        'hy' => 'әрмән',
        'ia' => 'интерлингва',
        'id' => 'индонез',
        'ie' => 'интерлингве',
        'ig' => 'игбо',
        'ii' => 'сычуань и',
        'io' => 'идо',
        'is' => 'исланд',
        'it' => 'итальян',
        'iu' => 'инуктитут',
        'ja' => 'япон',
        'jbo' => 'ложбан',
        'jgo' => 'нгомба',
        'jmc' => 'мачаме',
        'jv' => 'ява',
        'ka' => 'грузин',
        'kaa' => 'ҡарағалпаҡ',
        'kab' => 'кабил',
        'kaj' => 'джу',
        'kam' => 'камба',
        'kcg' => 'тьяп',
        'kde' => 'маконде',
        'kea' => 'кабувердьяну',
        'kek' => 'кекчи',
        'ken' => 'кеньянг',
        'kgp' => 'каинганг',
        'khq' => 'койра Чиини',
        'ki' => 'кикуйю',
        'kk' => 'ҡаҙаҡ',
        'kkj' => 'како',
        'kl' => 'калааллисут',
        'kln' => 'календжин',
        'km' => 'кхмер',
        'kn' => 'каннада',
        'ko' => 'корей',
        'kok' => 'конкани',
        'kpe' => 'кпелле',
        'ks' => 'кашмири',
        'ksb' => 'шамбала',
        'ksf' => 'бафия',
        'ksh' => 'кёльн',
        'ku' => 'курд',
        'kw' => 'корн',
        'kxv' => 'куви',
        'ky' => 'ҡырғыҙ',
        'la' => 'латин',
        'lag' => 'ланги',
        'lb' => 'люксембург',
        'lg' => 'ганда',
        'lij' => 'лигур',
        'lkt' => 'лакота',
        'lld' => 'ладин',
        'lmo' => 'ломбард',
        'ln' => 'лингала',
        'lo' => 'лаос',
        'lou' => 'луизиана креол',
        'lrc' => 'төньяҡ лури',
        'lt' => 'литва',
        'ltg' => 'латгал',
        'lu' => 'луба-катанга',
        'luo' => 'луо',
        'luy' => 'лухья',
        'lv' => 'латыш',
        'lzz' => 'лаз',
        'mai' => 'майтхили',
        'mas' => 'масаи',
        'mdf' => 'мокша',
        'mer' => 'меру',
        'mfe' => 'морисьен',
        'mg' => 'малагаси',
        'mgh' => 'макуа-меетто',
        'mgo' => 'мета',
        'mhn' => 'мокено',
        'mi' => 'маори',
        'mic' => 'микмау',
        'mk' => 'македон',
        'ml' => 'малаялам',
        'mn' => 'монгол',
        'mni' => 'манипури',
        'moh' => 'мохаук',
        'mr' => 'маратхи',
        'ms' => 'малай',
        'mt' => 'мальта',
        'mua' => 'мунданг',
        'mus' => 'мускоги',
        'mww' => 'хмонг дав',
        'my' => 'бирма',
        'myv' => 'эрзә',
        'mzn' => 'мазандеран',
        'nan' => 'мин нан ҡытай',
        'naq' => 'нама',
        'nb' => 'норвег букмол',
        'nd' => 'төньяҡ ндебеле',
        'nds' => 'түбәнге немец',
        'ne' => 'непал',
        'nl' => 'нидерланд',
        'nmg' => 'квасио',
        'nn' => 'норвег нюнорск',
        'nnh' => 'нгиембун',
        'no' => 'норвег',
        'nqo' => 'н’ко',
        'nr' => 'көньяҡ ндебеле',
        'nso' => 'төньяҡ сото',
        'nus' => 'нуэр',
        'nv' => 'навахо',
        'ny' => 'ньянджа',
        'nyn' => 'ньянколе',
        'oc' => 'окситан',
        'oka' => 'оканаган',
        'om' => 'оромо',
        'or' => 'одия',
        'os' => 'осетин',
        'osa' => 'осейдж',
        'pa' => 'панджаби',
        'pap' => 'папьяменто',
        'pcm' => 'нигерия пиджины',
        'pi' => 'пали',
        'pis' => 'пиджин',
        'pl' => 'поляк',
        'pms' => 'пьемонт',
        'prg' => 'прус',
        'ps' => 'пушту',
        'pt' => 'португал',
        'qu' => 'кечуа',
        'quc' => 'киче',
        'raj' => 'раджастхани',
        'rhg' => 'рохинджа',
        'rif' => 'риф',
        'rm' => 'романш',
        'rn' => 'рунди',
        'ro' => 'румын',
        'rof' => 'ромбо',
        'ru' => 'урыҫ',
        'rw' => 'киньяруанда',
        'rwk' => 'руа',
        'sa' => 'санскрит',
        'sah' => 'саха',
        'saq' => 'самбуру',
        'sat' => 'сантали',
        'sbp' => 'сангу',
        'sc' => 'сардин',
        'scn' => 'сицилия',
        'sd' => 'синдхи',
        'sdh' => 'көньяҡ курд',
        'se' => 'төньяҡ саам',
        'seh' => 'сена',
        'ses' => 'койраборо Сенни',
        'sg' => 'санго',
        'sgs' => 'самогит',
        'shi' => 'ташельхит',
        'shn' => 'шан',
        'si' => 'сингал',
        'sid' => 'сидамо',
        'sk' => 'словак',
        'skr' => 'сараиики',
        'sl' => 'словен',
        'sma' => 'көньяҡ саам',
        'smj' => 'луле саам',
        'smn' => 'инари саам',
        'sms' => 'сколт саам',
        'sn' => 'шона',
        'so' => 'сомали',
        'sq' => 'албан',
        'sr' => 'серб',
        'ss' => 'свати',
        'ssy' => 'сахо',
        'st' => 'көньяҡ сото',
        'su' => 'сундан',
        'suz' => 'сунвар',
        'sv' => 'швед',
        'sw' => 'суахили',
        'syr' => 'сүриә',
        'szl' => 'силез',
        'ta' => 'тамил',
        'te' => 'телугу',
        'teo' => 'тесо',
        'tg' => 'тажик',
        'th' => 'тай',
        'ti' => 'тигринья',
        'tig' => 'тигре',
        'tk' => 'төркмән',
        'tn' => 'тсвана',
        'to' => 'тонга',
        'tok' => 'токи пона',
        'tpi' => 'ток писин',
        'tr' => 'төрөк',
        'trv' => 'тароко',
        'trw' => 'торвали',
        'ts' => 'тсонга',
        'tt' => 'татар',
        'twq' => 'тасавак',
        'tyv' => 'тува',
        'tzm' => 'үҙәк атлас тамазигхт',
        'ug' => 'уйғыр',
        'uk' => 'украин',
        'ur' => 'урду',
        'uz' => 'үзбәк',
        'vai' => 'ваи',
        've' => 'венда',
        'vec' => 'венет',
        'vi' => 'вьетнам',
        'vmw' => 'макуа',
        'vo' => 'волапюк',
        'vun' => 'вунджо',
        'wa' => 'валлон',
        'wae' => 'вальзер',
        'wal' => 'волайтта',
        'wbp' => 'вальпири',
        'wo' => 'волоф',
        'xh' => 'коса',
        'xnr' => 'кангри',
        'xog' => 'сога',
        'yav' => 'янгбен',
        'yi' => 'идиш',
        'yo' => 'йоруба',
        'yrl' => 'ньенгату',
        'yue' => 'кантональ',
        'za' => 'чжуан',
        'zgh' => 'стандарт марокко тамазигхт',
        'zh' => 'ҡытай',
        'zu' => 'зулу',
    ],
    'LocalizedNames' => [
        'ar_001' => 'әҙәби ғәрәп',
        'de_AT' => 'немец (Австрия)',
        'de_CH' => 'немец (Швейцария)',
        'en_AU' => 'инглиз (Австралия)',
        'en_CA' => 'инглиз (Канада)',
        'en_GB' => 'инглиз (Британия)',
        'en_US' => 'инглиз (АҠШ)',
        'es_419' => 'испан (Латин Америкаһы)',
        'es_ES' => 'испан (Европа)',
        'es_MX' => 'испан (Мексика)',
        'fa_AF' => 'дари',
        'fr_CA' => 'француз (Канада)',
        'fr_CH' => 'француз (Швейцария)',
        'hi_Latn' => 'һинди (латиница)',
        'nds_NL' => 'түбәнге саксон',
        'nl_BE' => 'фламанд',
        'pt_BR' => 'португал (Бразилия)',
        'pt_PT' => 'португал (Европа)',
        'ro_MD' => 'молдов',
        'sw_CD' => 'конго суахили',
        'zh_Hans' => 'ҡытай (ябайлаштырылған)',
        'zh_Hant' => 'ҡытай (традицион)',
    ],
];
