<?php

return [
    'Names' => [
        'aa' => 'აფარი',
        'ab' => 'აფხაზური',
        'ace' => 'აჩეხური',
        'ach' => 'აჩოლი',
        'ada' => 'ადანგმე',
        'ady' => 'ადიღეური',
        'ae' => 'ავესტური',
        'af' => 'აფრიკაანსი',
        'agq' => 'აღემი',
        'ain' => 'აინუური',
        'ak' => 'აკანი',
        'akk' => 'აქადური',
        'ale' => 'ალეუტური',
        'alt' => 'სამხრეთ ალთაური',
        'am' => 'ამჰარული',
        'an' => 'არაგონული',
        'ang' => 'ძველი ინგლისური',
        'ann' => 'ობოლო',
        'anp' => 'ანგიკა',
        'ar' => 'არაბული',
        'arc' => 'არამეული',
        'arn' => 'მაპუდუნგუნი',
        'arp' => 'არაპაჰო',
        'ars' => 'ნაჯის არაბული',
        'arw' => 'არავაკი',
        'as' => 'ასამური',
        'asa' => 'ასუ',
        'ast' => 'ასტურიული',
        'atj' => 'ატიკამეკი',
        'av' => 'ხუნძური',
        'awa' => 'ავადი',
        'ay' => 'აიმარა',
        'az' => 'აზერბაიჯანული',
        'ba' => 'ბაშკირული',
        'bal' => 'ბელუჯი',
        'ban' => 'ბალინური',
        'bas' => 'ბასა',
        'bax' => 'ბამუნი',
        'be' => 'ბელარუსული',
        'bej' => 'ბეჯა',
        'bem' => 'ბემბა',
        'bez' => 'ბენა',
        'bg' => 'ბულგარული',
        'bgc' => 'ჰარიანვი',
        'bgn' => 'დასავლეთ ბელუჯი',
        'bho' => 'ბოჯპური',
        'bi' => 'ბისლამა',
        'bin' => 'ბინი',
        'bla' => 'სიკსიკა',
        'blo' => 'ანიი',
        'bm' => 'ბამბარა',
        'bn' => 'ბენგალური',
        'bo' => 'ტიბეტური',
        'br' => 'ბრეტონული',
        'bra' => 'ბრაჯი',
        'brx' => 'ბოდო',
        'bs' => 'ბოსნიური',
        'bua' => 'ბურიატული',
        'bug' => 'ბუგინური',
        'byn' => 'ბილინი',
        'ca' => 'კატალანური',
        'cay' => 'კაიუგა',
        'ccp' => 'ჩაკმა',
        'ce' => 'ჩეჩნური',
        'ceb' => 'სებუანო',
        'cgg' => 'ჩიგა',
        'ch' => 'ჩამორო',
        'chb' => 'ჩიბჩა',
        'chk' => 'ჩუკოტკური',
        'chm' => 'მარიული',
        'chn' => 'ჩინუკის ჟარგონი',
        'cho' => 'ჩოკტო',
        'chp' => 'ჩიპევიანი',
        'chr' => 'ჩეროკი',
        'chy' => 'ჩეიენი',
        'ckb' => 'ცენტრალური ქურთული',
        'clc' => 'ჩილკოტინი',
        'co' => 'კორსიკული',
        'cop' => 'კოპტური',
        'cr' => 'კრი',
        'crg' => 'მიჩიფი',
        'crh' => 'ყირიმულ-თურქული',
        'crj' => 'სამხრეთ-აღმოსავლეთის კრი',
        'crk' => 'დაბლობის კრი',
        'crl' => 'ჩრდილო-აღმოსავლეთის კრი',
        'crm' => 'მუსური კრი',
        'crr' => 'კაროლინური ალგონკინი',
        'crs' => 'სესელვა-კრეოლური ფრანგული',
        'cs' => 'ჩეხური',
        'csb' => 'კაშუბური',
        'csw' => 'ჭაობის კრი',
        'cu' => 'საეკლესიო სლავური',
        'cv' => 'ჩუვაშური',
        'cy' => 'უელსური',
        'da' => 'დანიური',
        'dak' => 'დაკოტური',
        'dar' => 'დარგუული',
        'dav' => 'ტაიტა',
        'de' => 'გერმანული',
        'del' => 'დელავერული',
        'den' => 'სლეივი',
        'dgr' => 'დოგრიბი',
        'din' => 'დინკა',
        'dje' => 'ზარმა',
        'doi' => 'დოგრი',
        'dsb' => 'ქვემოსორბული',
        'dua' => 'დუალა',
        'dum' => 'საშუალო ჰოლანდიური',
        'dv' => 'დივეჰი',
        'dyo' => 'დიოლა',
        'dyu' => 'დიულა',
        'dz' => 'ძონგკხა',
        'dzg' => 'დაზაგა',
        'ebu' => 'ემბუ',
        'ee' => 'ევე',
        'efi' => 'ეფიკი',
        'egy' => 'ძველეგვიპტური',
        'eka' => 'ეკაჯუკი',
        'el' => 'ბერძნული',
        'en' => 'ინგლისური',
        'enm' => 'საშუალო ინგლისური',
        'eo' => 'ესპერანტო',
        'es' => 'ესპანური',
        'et' => 'ესტონური',
        'eu' => 'ბასკური',
        'ewo' => 'ევონდო',
        'fa' => 'სპარსული',
        'ff' => 'ფულა',
        'fi' => 'ფინური',
        'fil' => 'ფილიპინური',
        'fj' => 'ფიჯი',
        'fo' => 'ფარერული',
        'fon' => 'ფონი',
        'fr' => 'ფრანგული',
        'frc' => 'კაჟუნური ფრანგული',
        'frm' => 'საშუალო ფრანგული',
        'fro' => 'ძველი ფრანგული',
        'frr' => 'ჩრდილოფრიზიული',
        'frs' => 'აღმოსავლეთფრიზიული',
        'fur' => 'ფრიულური',
        'fy' => 'დასავლეთფრიზიული',
        'ga' => 'ირლანდიური',
        'gaa' => 'გა',
        'gag' => 'გაგაუზური',
        'gba' => 'გბაია',
        'gd' => 'შოტლანდიური გელური',
        'gez' => 'გეეზი',
        'gil' => 'გილბერტული',
        'gl' => 'გალისიური',
        'gmh' => 'საშუალო ზემოგერმანული',
        'gn' => 'გუარანი',
        'goh' => 'ძველი ზემოგერმანული',
        'gon' => 'გონდი',
        'gor' => 'გორონტალო',
        'got' => 'გოთური',
        'grc' => 'ძველი ბერძნული',
        'gsw' => 'შვეიცარიული გერმანული',
        'gu' => 'გუჯარათი',
        'guz' => 'გუსიი',
        'gv' => 'მენური',
        'gwi' => 'გვიჩინი',
        'ha' => 'ჰაუსა',
        'hai' => 'ჰაიდა',
        'haw' => 'ჰავაიური',
        'hax' => 'სამხრეთული ჰაიდა',
        'he' => 'ებრაული',
        'hi' => 'ჰინდი',
        'hil' => 'ჰილიგაინონი',
        'hit' => 'ხეთური',
        'hmn' => 'ჰმონგი',
        'hr' => 'ხორვატული',
        'hsb' => 'ზემოსორბული',
        'ht' => 'ჰაიტიური კრეოლი',
        'hu' => 'უნგრული',
        'hup' => 'ჰუპა',
        'hur' => 'ჰალკომელემი',
        'hy' => 'სომხური',
        'hz' => 'ჰერერო',
        'ia' => 'ინტერლინგუალური',
        'iba' => 'იბანი',
        'ibb' => 'იბიბიო',
        'id' => 'ინდონეზიური',
        'ie' => 'ინტერლინგი',
        'ig' => 'იგბო',
        'ii' => 'სიჩუანის ი',
        'ikt' => 'დასავლეთ-კანადური ინუკტიტუტი',
        'ilo' => 'ილოკო',
        'inh' => 'ინგუშური',
        'io' => 'იდო',
        'is' => 'ისლანდიური',
        'it' => 'იტალიური',
        'iu' => 'ინუკტიტუტი',
        'ja' => 'იაპონური',
        'jbo' => 'ლოჟბანი',
        'jgo' => 'ნგომბა',
        'jmc' => 'კიმაშამი',
        'jpr' => 'იუდეო-სპარსული',
        'jrb' => 'იუდეო-არაბული',
        'jv' => 'იავური',
        'ka' => 'ქართული',
        'kaa' => 'ყარაყალფახური',
        'kab' => 'კაბილური',
        'kac' => 'კაჩინი',
        'kaj' => 'კაჯი',
        'kam' => 'კამბა',
        'kbd' => 'ყაბარდოული',
        'kcg' => 'ტიაპი',
        'kde' => 'მაკონდე',
        'kea' => 'კაბუვერდიანუ',
        'kfo' => 'კორო',
        'kg' => 'კონგო',
        'kgp' => 'კაინგანგი',
        'kha' => 'ხასი',
        'khq' => 'კოირა-ჩიინი',
        'ki' => 'კიკუიუ',
        'kj' => 'კუნამა',
        'kk' => 'ყაზახური',
        'kkj' => 'კაკო',
        'kl' => 'დასავლეთ გრენლანდიური',
        'kln' => 'კალენჯინი',
        'km' => 'ქმერული',
        'kmb' => 'კიმბუნდუ',
        'kn' => 'კანადა',
        'ko' => 'კორეული',
        'koi' => 'კომი-პერმიაკული',
        'kok' => 'კონკანი',
        'kos' => 'კუსაიე',
        'kpe' => 'კპელე',
        'kr' => 'კანური',
        'krc' => 'ყარაჩაულ-ბალყარული',
        'krl' => 'კარელიური',
        'kru' => 'კურუქი',
        'ks' => 'ქაშმირული',
        'ksb' => 'შამბალა',
        'ksf' => 'ბაფია',
        'ksh' => 'კიოლში',
        'ku' => 'ქურთული',
        'kum' => 'ყუმუხური',
        'kut' => 'კუტენაი',
        'kv' => 'კომი',
        'kw' => 'კორნული',
        'kwk' => 'კვაკვალა',
        'kxv' => 'კუვი',
        'ky' => 'ყირგიზული',
        'la' => 'ლათინური',
        'lad' => 'ლადინო',
        'lag' => 'ლანგი',
        'lah' => 'ლანდა',
        'lam' => 'ლამბა',
        'lb' => 'ლუქსემბურგული',
        'lez' => 'ლეზგიური',
        'lg' => 'განდა',
        'li' => 'ლიმბურგული',
        'lij' => 'ლიგურიული',
        'lil' => 'ლილიეტი',
        'lkt' => 'ლაკოტა',
        'lmo' => 'ლომბარდიული',
        'ln' => 'ლინგალა',
        'lo' => 'ლაოსური',
        'lol' => 'მონგო',
        'lou' => 'ლუიზიანას კრეოლური',
        'loz' => 'ლოზი',
        'lrc' => 'ჩრდილოეთ ლური',
        'lsm' => 'სამია',
        'lt' => 'ლიეტუვური',
        'lu' => 'ლუბა-კატანგა',
        'lua' => 'ლუბა-ლულუა',
        'lui' => 'ლუისენიო',
        'lun' => 'ლუნდა',
        'luo' => 'ლუო',
        'lus' => 'მიზო',
        'luy' => 'ლუჰია',
        'lv' => 'ლატვიური',
        'mad' => 'მადურული',
        'maf' => 'მაფა',
        'mag' => 'მაგაჰი',
        'mai' => 'მაითილი',
        'mak' => 'მაკასარი',
        'mas' => 'მასაი',
        'mde' => 'მაბა',
        'mdf' => 'მოქშა',
        'men' => 'მენდე',
        'mer' => 'მერუ',
        'mfe' => 'მორისიენი',
        'mg' => 'მალაგასიური',
        'mga' => 'საშუალო ირლანდიური',
        'mgh' => 'მაქუვა-მეეტო',
        'mgo' => 'მეტა-ენა',
        'mh' => 'მარშალური',
        'mi' => 'მაორი',
        'mic' => 'მიკმაკი',
        'min' => 'მინანგკაბაუ',
        'mk' => 'მაკედონური',
        'ml' => 'მალაიალამური',
        'mn' => 'მონღოლური',
        'mnc' => 'მანჯურიული',
        'mni' => 'მანიპური',
        'moe' => 'ინუ-აიმუნი',
        'moh' => 'მოჰაუკური',
        'mos' => 'მოსი',
        'mr' => 'მარათჰი',
        'ms' => 'მალაიური',
        'mt' => 'მალტური',
        'mua' => 'მუნდანგი',
        'mus' => 'კრიკი',
        'mwl' => 'მირანდული',
        'mwr' => 'მარვარი',
        'my' => 'ბირმული',
        'mye' => 'მიენე',
        'myv' => 'ერზია',
        'mzn' => 'მაზანდერანული',
        'na' => 'ნაურუ',
        'nap' => 'ნეაპოლიტანური',
        'naq' => 'ნამა',
        'nb' => 'ნორვეგიული ბუკმოლი',
        'nd' => 'ჩრდილოეთ ნდებელე',
        'nds' => 'ქვემოგერმანული',
        'ne' => 'ნეპალური',
        'new' => 'ნევარი',
        'ng' => 'ნდონგა',
        'nia' => 'ნიასი',
        'niu' => 'ნიუე',
        'nl' => 'ნიდერლანდური',
        'nmg' => 'კვასიო',
        'nn' => 'ნორვეგიული ნიუნორსკი',
        'nnh' => 'ნგიმბუნი',
        'no' => 'ნორვეგიული',
        'nog' => 'ნოღაური',
        'non' => 'ძველსკანდინავიური',
        'nqo' => 'ნკო',
        'nr' => 'სამხრეთ ნდებელური',
        'nso' => 'ჩრდილოეთ სოთო',
        'nus' => 'ნუერი',
        'nv' => 'ნავახო',
        'nwc' => 'კლასიკური ნევარული',
        'ny' => 'ნიანჯა',
        'nym' => 'ნიამვეზი',
        'nyn' => 'ნიანკოლე',
        'nyo' => 'ნიორო',
        'nzi' => 'ნზიმა',
        'oc' => 'ოქსიტანური',
        'oj' => 'ოჯიბვე',
        'ojb' => 'ჩრდილო-დასავლეთის ოჯიბვა',
        'ojc' => 'ცენტრალური ოჯიბვე',
        'ojs' => 'ოჯი-კრი',
        'ojw' => 'დასავლეთის ოჯიბვა',
        'oka' => 'ოკანაგანი',
        'om' => 'ორომო',
        'or' => 'ორია',
        'os' => 'ოსური',
        'pa' => 'პენჯაბური',
        'pag' => 'პანგასინანი',
        'pal' => 'ფალაური',
        'pam' => 'პამპანგა',
        'pap' => 'პაპიამენტო',
        'pau' => 'ფალაუანი',
        'pcm' => 'ნიგერიული კრეოლური',
        'peo' => 'ძველი სპარსული',
        'phn' => 'ფინიკიური',
        'pi' => 'პალი',
        'pis' => 'პიჯინი',
        'pl' => 'პოლონური',
        'pqm' => 'მალისეტ-პასამაკვოდი',
        'prg' => 'პრუსიული',
        'pro' => 'ძველი პროვანსული',
        'ps' => 'პუშტუ',
        'pt' => 'პორტუგალიური',
        'qu' => 'კეჩუა',
        'quc' => 'კიჩე',
        'raj' => 'რაჯასთანი',
        'rap' => 'რაპანუი',
        'rar' => 'რაროტონგული',
        'rhg' => 'როჰინგა',
        'rm' => 'რეტორომანული',
        'rn' => 'რუნდი',
        'ro' => 'რუმინული',
        'rof' => 'რომბო',
        'rom' => 'ბოშური',
        'ru' => 'რუსული',
        'rup' => 'არომანული',
        'rw' => 'კინიარუანდა',
        'rwk' => 'რუა',
        'sa' => 'სანსკრიტი',
        'sad' => 'სანდავე',
        'sah' => 'იაკუტური',
        'sam' => 'სამარიულ-არამეული',
        'saq' => 'სამბურუ',
        'sat' => 'სანტალი',
        'sba' => 'ნგამბაი',
        'sbp' => 'სანგუ',
        'sc' => 'სარდინიული',
        'scn' => 'სიცილიური',
        'sco' => 'შოტლანდიური',
        'sd' => 'სინდჰური',
        'sdh' => 'სამხრეთქურთული',
        'se' => 'ჩრდილოეთ საამური',
        'see' => 'სენეკა',
        'seh' => 'სენა',
        'sel' => 'სელკუპური',
        'ses' => 'კოირაბორო-სენი',
        'sg' => 'სანგო',
        'sga' => 'ძველი ირლანდიური',
        'sh' => 'სერბულ-ხორვატული',
        'shi' => 'შილჰა',
        'shn' => 'შანი',
        'shu' => 'ჩადური არაბული',
        'si' => 'სინჰალური',
        'sk' => 'სლოვაკური',
        'sl' => 'სლოვენური',
        'slh' => 'სამხრეთული ლუშუციდი',
        'sm' => 'სამოა',
        'sma' => 'სამხრეთსამური',
        'smj' => 'ლულე-საამური',
        'smn' => 'ინარი-საამური',
        'sms' => 'სკოლტ-საამური',
        'sn' => 'შონა',
        'snk' => 'სონინკე',
        'so' => 'სომალიური',
        'sq' => 'ალბანური',
        'sr' => 'სერბული',
        'srn' => 'სრანან ტონგო',
        'ss' => 'სუატი',
        'ssy' => 'საჰო',
        'st' => 'სამხრეთ სოთოს ენა',
        'str' => 'სტრეიტს სალიში',
        'su' => 'სუნდური',
        'suk' => 'სუკუმა',
        'sux' => 'შუმერული',
        'sv' => 'შვედური',
        'sw' => 'სუაჰილი',
        'swb' => 'კომორული',
        'syc' => 'კლასიკური სირიული',
        'syr' => 'სირიული',
        'szl' => 'სილესიური',
        'ta' => 'ტამილური',
        'tce' => 'სამხრეთ ტუჩონი',
        'te' => 'ტელუგუ',
        'tem' => 'ტინმე',
        'teo' => 'ტესო',
        'tet' => 'ტეტუმი',
        'tg' => 'ტაჯიკური',
        'tgx' => 'ტაგიში',
        'th' => 'ტაილანდური',
        'tht' => 'ტალტანი',
        'ti' => 'ტიგრინია',
        'tig' => 'თიგრე',
        'tk' => 'თურქმენული',
        'tlh' => 'კლინგონი',
        'tli' => 'ტლინგიტი',
        'tn' => 'ტსვანა',
        'to' => 'ტონგანური',
        'tok' => 'ტოკი-პონა',
        'tpi' => 'ტოკ-პისინი',
        'tr' => 'თურქული',
        'trv' => 'ტაროკო',
        'ts' => 'ტსონგა',
        'tt' => 'თათრული',
        'ttm' => 'ჩრდილოეთ ტუჩონი',
        'tum' => 'ტუმბუკა',
        'tvl' => 'ტუვალუ',
        'tw' => 'თუი',
        'twq' => 'ტასავაქი',
        'ty' => 'ტაიტური',
        'tyv' => 'ტუვა',
        'tzm' => 'ცენტრალური მოროკოს ტამაზიგხტი',
        'udm' => 'უდმურტული',
        'ug' => 'უიღურული',
        'uga' => 'უგარითული',
        'uk' => 'უკრაინული',
        'umb' => 'უმბუნდუ',
        'ur' => 'ურდუ',
        'uz' => 'უზბეკური',
        'vai' => 'ვაი',
        've' => 'ვენდა',
        'vec' => 'ვენეციური',
        'vi' => 'ვიეტნამური',
        'vmw' => 'მაკჰუვა',
        'vo' => 'ვოლაპუკი',
        'vun' => 'ვუნჯო',
        'wa' => 'ვალონური',
        'wae' => 'ვალსერი',
        'wal' => 'ველაითა',
        'war' => 'ვარაი',
        'wbp' => 'ვალპირი',
        'wo' => 'ვოლოფური',
        'wuu' => 'ვუ',
        'xal' => 'ყალმუხური',
        'xh' => 'ქჰოსა',
        'xnr' => 'კანგრი',
        'xog' => 'სოგა',
        'yav' => 'იანგბენი',
        'ybb' => 'იემბა',
        'yi' => 'იდიში',
        'yo' => 'იორუბა',
        'yrl' => 'ნენგატუ',
        'yue' => 'კანტონური',
        'za' => 'ზჰუანგი',
        'zbl' => 'ბლისსიმბოლოები',
        'zen' => 'ზენაგა',
        'zgh' => 'სტანდარტული მაროკოული ტამაზიგხტი',
        'zh' => 'ჩინური',
        'zu' => 'ზულუ',
        'zun' => 'ზუნი',
        'zza' => 'ზაზაკი',
    ],
    'LocalizedNames' => [
        'ar_001' => 'თანამედროვე სტანდარტული არაბული',
        'de_AT' => 'ავსტრიული გერმანული',
        'de_CH' => 'შვეიცარიული ზემოგერმანული',
        'en_AU' => 'ავსტრალიური ინგლისური',
        'en_CA' => 'კანადური ინგლისური',
        'en_GB' => 'ბრიტანული ინგლისური',
        'en_US' => 'ამერიკული ინგლისური',
        'es_419' => 'ლათინურ ამერიკული ესპანური',
        'es_ES' => 'ევროპული ესპანური',
        'es_MX' => 'მექსიკური ესპანური',
        'fa_AF' => 'დარი',
        'fr_CA' => 'კანადური ფრანგული',
        'fr_CH' => 'შვეიცარიული ფრანგული',
        'nds_NL' => 'ქვემოსაქსონური',
        'nl_BE' => 'ფლამანდიური',
        'pt_BR' => 'ბრაზილიური პორტუგალიური',
        'pt_PT' => 'ევროპული პორტუგალიური',
        'ro_MD' => 'მოლდავური',
        'sw_CD' => 'კონგოს სუაჰილი',
        'zh_Hans' => 'გამარტივებული ჩინური',
        'zh_Hant' => 'ტრადიციული ჩინური',
    ],
];
