<?php

return [
    'Names' => [
        'af' => 'africâner',
        'af_NA' => 'africâner (Namíbia)',
        'af_ZA' => 'africâner (África do Sul)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Gana)',
        'am' => 'amárico',
        'am_ET' => 'amárico (Etiópia)',
        'ar' => 'árabe',
        'ar_001' => 'árabe (Mundo)',
        'ar_AE' => 'árabe (Emirados Árabes Unidos)',
        'ar_BH' => 'árabe (Barein)',
        'ar_DJ' => 'árabe (Djibuti)',
        'ar_DZ' => 'árabe (Argélia)',
        'ar_EG' => 'árabe (Egito)',
        'ar_EH' => 'árabe (Saara Ocidental)',
        'ar_ER' => 'árabe (Eritreia)',
        'ar_IL' => 'árabe (Israel)',
        'ar_IQ' => 'árabe (Iraque)',
        'ar_JO' => 'árabe (Jordânia)',
        'ar_KM' => 'árabe (Comores)',
        'ar_KW' => 'árabe (Kuwait)',
        'ar_LB' => 'árabe (Líbano)',
        'ar_LY' => 'árabe (Líbia)',
        'ar_MA' => 'árabe (Marrocos)',
        'ar_MR' => 'árabe (Mauritânia)',
        'ar_OM' => 'árabe (Omã)',
        'ar_PS' => 'árabe (Territórios palestinos)',
        'ar_QA' => 'árabe (Catar)',
        'ar_SA' => 'árabe (Arábia Saudita)',
        'ar_SD' => 'árabe (Sudão)',
        'ar_SO' => 'árabe (Somália)',
        'ar_SS' => 'árabe (Sudão do Sul)',
        'ar_SY' => 'árabe (Síria)',
        'ar_TD' => 'árabe (Chade)',
        'ar_TN' => 'árabe (Tunísia)',
        'ar_YE' => 'árabe (Iêmen)',
        'as' => 'assamês',
        'as_IN' => 'assamês (Índia)',
        'az' => 'azerbaijano',
        'az_AZ' => 'azerbaijano (Azerbaijão)',
        'az_Cyrl' => 'azerbaijano (cirílico)',
        'az_Cyrl_AZ' => 'azerbaijano (cirílico, Azerbaijão)',
        'az_Latn' => 'azerbaijano (latim)',
        'az_Latn_AZ' => 'azerbaijano (latim, Azerbaijão)',
        'ba' => 'bashkir',
        'ba_RU' => 'bashkir (Rússia)',
        'be' => 'bielorrusso',
        'be_BY' => 'bielorrusso (Bielorrússia)',
        'bg' => 'búlgaro',
        'bg_BG' => 'búlgaro (Bulgária)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengali',
        'bn_BD' => 'bengali (Bangladesh)',
        'bn_IN' => 'bengali (Índia)',
        'bo' => 'tibetano',
        'bo_CN' => 'tibetano (China)',
        'bo_IN' => 'tibetano (Índia)',
        'br' => 'bretão',
        'br_FR' => 'bretão (França)',
        'bs' => 'bósnio',
        'bs_BA' => 'bósnio (Bósnia e Herzegovina)',
        'bs_Cyrl' => 'bósnio (cirílico)',
        'bs_Cyrl_BA' => 'bósnio (cirílico, Bósnia e Herzegovina)',
        'bs_Latn' => 'bósnio (latim)',
        'bs_Latn_BA' => 'bósnio (latim, Bósnia e Herzegovina)',
        'ca' => 'catalão',
        'ca_AD' => 'catalão (Andorra)',
        'ca_ES' => 'catalão (Espanha)',
        'ca_FR' => 'catalão (França)',
        'ca_IT' => 'catalão (Itália)',
        'ce' => 'checheno',
        'ce_RU' => 'checheno (Rússia)',
        'cs' => 'tcheco',
        'cs_CZ' => 'tcheco (Tchéquia)',
        'cv' => 'tchuvache',
        'cv_RU' => 'tchuvache (Rússia)',
        'cy' => 'galês',
        'cy_GB' => 'galês (Reino Unido)',
        'da' => 'dinamarquês',
        'da_DK' => 'dinamarquês (Dinamarca)',
        'da_GL' => 'dinamarquês (Groenlândia)',
        'de' => 'alemão',
        'de_AT' => 'alemão (Áustria)',
        'de_BE' => 'alemão (Bélgica)',
        'de_CH' => 'alemão (Suíça)',
        'de_DE' => 'alemão (Alemanha)',
        'de_IT' => 'alemão (Itália)',
        'de_LI' => 'alemão (Liechtenstein)',
        'de_LU' => 'alemão (Luxemburgo)',
        'dz' => 'dzonga',
        'dz_BT' => 'dzonga (Butão)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Gana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'grego',
        'el_CY' => 'grego (Chipre)',
        'el_GR' => 'grego (Grécia)',
        'en' => 'inglês',
        'en_001' => 'inglês (Mundo)',
        'en_150' => 'inglês (Europa)',
        'en_AE' => 'inglês (Emirados Árabes Unidos)',
        'en_AG' => 'inglês (Antígua e Barbuda)',
        'en_AI' => 'inglês (Anguila)',
        'en_AS' => 'inglês (Samoa Americana)',
        'en_AT' => 'inglês (Áustria)',
        'en_AU' => 'inglês (Austrália)',
        'en_BB' => 'inglês (Barbados)',
        'en_BE' => 'inglês (Bélgica)',
        'en_BI' => 'inglês (Burundi)',
        'en_BM' => 'inglês (Bermudas)',
        'en_BS' => 'inglês (Bahamas)',
        'en_BW' => 'inglês (Botsuana)',
        'en_BZ' => 'inglês (Belize)',
        'en_CA' => 'inglês (Canadá)',
        'en_CC' => 'inglês (Ilhas Cocos [Keeling])',
        'en_CH' => 'inglês (Suíça)',
        'en_CK' => 'inglês (Ilhas Cook)',
        'en_CM' => 'inglês (Camarões)',
        'en_CX' => 'inglês (Ilha Christmas)',
        'en_CY' => 'inglês (Chipre)',
        'en_CZ' => 'inglês (Tchéquia)',
        'en_DE' => 'inglês (Alemanha)',
        'en_DK' => 'inglês (Dinamarca)',
        'en_DM' => 'inglês (Dominica)',
        'en_EE' => 'inglês (Estônia)',
        'en_ER' => 'inglês (Eritreia)',
        'en_ES' => 'inglês (Espanha)',
        'en_FI' => 'inglês (Finlândia)',
        'en_FJ' => 'inglês (Fiji)',
        'en_FK' => 'inglês (Ilhas Malvinas)',
        'en_FM' => 'inglês (Micronésia)',
        'en_FR' => 'inglês (França)',
        'en_GB' => 'inglês (Reino Unido)',
        'en_GD' => 'inglês (Granada)',
        'en_GE' => 'inglês (Geórgia)',
        'en_GG' => 'inglês (Guernsey)',
        'en_GH' => 'inglês (Gana)',
        'en_GI' => 'inglês (Gibraltar)',
        'en_GM' => 'inglês (Gâmbia)',
        'en_GS' => 'inglês (Ilhas Geórgia do Sul e Sandwich do Sul)',
        'en_GU' => 'inglês (Guam)',
        'en_GY' => 'inglês (Guiana)',
        'en_HK' => 'inglês (Hong Kong, RAE da China)',
        'en_HU' => 'inglês (Hungria)',
        'en_ID' => 'inglês (Indonésia)',
        'en_IE' => 'inglês (Irlanda)',
        'en_IL' => 'inglês (Israel)',
        'en_IM' => 'inglês (Ilha de Man)',
        'en_IN' => 'inglês (Índia)',
        'en_IO' => 'inglês (Território Britânico do Oceano Índico)',
        'en_IT' => 'inglês (Itália)',
        'en_JE' => 'inglês (Jersey)',
        'en_JM' => 'inglês (Jamaica)',
        'en_JP' => 'inglês (Japão)',
        'en_KE' => 'inglês (Quênia)',
        'en_KI' => 'inglês (Quiribati)',
        'en_KN' => 'inglês (São Cristóvão e Névis)',
        'en_KY' => 'inglês (Ilhas Cayman)',
        'en_LC' => 'inglês (Santa Lúcia)',
        'en_LR' => 'inglês (Libéria)',
        'en_LS' => 'inglês (Lesoto)',
        'en_LT' => 'inglês (Lituânia)',
        'en_LV' => 'inglês (Letônia)',
        'en_MG' => 'inglês (Madagascar)',
        'en_MH' => 'inglês (Ilhas Marshall)',
        'en_MO' => 'inglês (Macau, RAE da China)',
        'en_MP' => 'inglês (Ilhas Marianas do Norte)',
        'en_MS' => 'inglês (Montserrat)',
        'en_MT' => 'inglês (Malta)',
        'en_MU' => 'inglês (Maurício)',
        'en_MV' => 'inglês (Maldivas)',
        'en_MW' => 'inglês (Malaui)',
        'en_MY' => 'inglês (Malásia)',
        'en_NA' => 'inglês (Namíbia)',
        'en_NF' => 'inglês (Ilha Norfolk)',
        'en_NG' => 'inglês (Nigéria)',
        'en_NL' => 'inglês (Países Baixos)',
        'en_NO' => 'inglês (Noruega)',
        'en_NR' => 'inglês (Nauru)',
        'en_NU' => 'inglês (Niue)',
        'en_NZ' => 'inglês (Nova Zelândia)',
        'en_PG' => 'inglês (Papua-Nova Guiné)',
        'en_PH' => 'inglês (Filipinas)',
        'en_PK' => 'inglês (Paquistão)',
        'en_PL' => 'inglês (Polônia)',
        'en_PN' => 'inglês (Ilhas Pitcairn)',
        'en_PR' => 'inglês (Porto Rico)',
        'en_PT' => 'inglês (Portugal)',
        'en_PW' => 'inglês (Palau)',
        'en_RO' => 'inglês (Romênia)',
        'en_RW' => 'inglês (Ruanda)',
        'en_SB' => 'inglês (Ilhas Salomão)',
        'en_SC' => 'inglês (Seicheles)',
        'en_SD' => 'inglês (Sudão)',
        'en_SE' => 'inglês (Suécia)',
        'en_SG' => 'inglês (Singapura)',
        'en_SH' => 'inglês (Santa Helena)',
        'en_SI' => 'inglês (Eslovênia)',
        'en_SK' => 'inglês (Eslováquia)',
        'en_SL' => 'inglês (Serra Leoa)',
        'en_SS' => 'inglês (Sudão do Sul)',
        'en_SX' => 'inglês (Sint Maarten)',
        'en_SZ' => 'inglês (Essuatíni)',
        'en_TC' => 'inglês (Ilhas Turcas e Caicos)',
        'en_TK' => 'inglês (Tokelau)',
        'en_TO' => 'inglês (Tonga)',
        'en_TT' => 'inglês (Trinidad e Tobago)',
        'en_TV' => 'inglês (Tuvalu)',
        'en_TZ' => 'inglês (Tanzânia)',
        'en_UA' => 'inglês (Ucrânia)',
        'en_UG' => 'inglês (Uganda)',
        'en_UM' => 'inglês (Ilhas Menores Distantes dos EUA)',
        'en_US' => 'inglês (Estados Unidos)',
        'en_VC' => 'inglês (São Vicente e Granadinas)',
        'en_VG' => 'inglês (Ilhas Virgens Britânicas)',
        'en_VI' => 'inglês (Ilhas Virgens Americanas)',
        'en_VU' => 'inglês (Vanuatu)',
        'en_WS' => 'inglês (Samoa)',
        'en_ZA' => 'inglês (África do Sul)',
        'en_ZM' => 'inglês (Zâmbia)',
        'en_ZW' => 'inglês (Zimbábue)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Mundo)',
        'es' => 'espanhol',
        'es_419' => 'espanhol (América Latina)',
        'es_AR' => 'espanhol (Argentina)',
        'es_BO' => 'espanhol (Bolívia)',
        'es_BR' => 'espanhol (Brasil)',
        'es_BZ' => 'espanhol (Belize)',
        'es_CL' => 'espanhol (Chile)',
        'es_CO' => 'espanhol (Colômbia)',
        'es_CR' => 'espanhol (Costa Rica)',
        'es_CU' => 'espanhol (Cuba)',
        'es_DO' => 'espanhol (República Dominicana)',
        'es_EC' => 'espanhol (Equador)',
        'es_ES' => 'espanhol (Espanha)',
        'es_GQ' => 'espanhol (Guiné Equatorial)',
        'es_GT' => 'espanhol (Guatemala)',
        'es_HN' => 'espanhol (Honduras)',
        'es_MX' => 'espanhol (México)',
        'es_NI' => 'espanhol (Nicarágua)',
        'es_PA' => 'espanhol (Panamá)',
        'es_PE' => 'espanhol (Peru)',
        'es_PH' => 'espanhol (Filipinas)',
        'es_PR' => 'espanhol (Porto Rico)',
        'es_PY' => 'espanhol (Paraguai)',
        'es_SV' => 'espanhol (El Salvador)',
        'es_US' => 'espanhol (Estados Unidos)',
        'es_UY' => 'espanhol (Uruguai)',
        'es_VE' => 'espanhol (Venezuela)',
        'et' => 'estoniano',
        'et_EE' => 'estoniano (Estônia)',
        'eu' => 'basco',
        'eu_ES' => 'basco (Espanha)',
        'fa' => 'persa',
        'fa_AF' => 'persa (Afeganistão)',
        'fa_IR' => 'persa (Irã)',
        'ff' => 'fula',
        'ff_Adlm' => 'fula (adlam)',
        'ff_Adlm_BF' => 'fula (adlam, Burquina Faso)',
        'ff_Adlm_CM' => 'fula (adlam, Camarões)',
        'ff_Adlm_GH' => 'fula (adlam, Gana)',
        'ff_Adlm_GM' => 'fula (adlam, Gâmbia)',
        'ff_Adlm_GN' => 'fula (adlam, Guiné)',
        'ff_Adlm_GW' => 'fula (adlam, Guiné-Bissau)',
        'ff_Adlm_LR' => 'fula (adlam, Libéria)',
        'ff_Adlm_MR' => 'fula (adlam, Mauritânia)',
        'ff_Adlm_NE' => 'fula (adlam, Níger)',
        'ff_Adlm_NG' => 'fula (adlam, Nigéria)',
        'ff_Adlm_SL' => 'fula (adlam, Serra Leoa)',
        'ff_Adlm_SN' => 'fula (adlam, Senegal)',
        'ff_CM' => 'fula (Camarões)',
        'ff_GN' => 'fula (Guiné)',
        'ff_Latn' => 'fula (latim)',
        'ff_Latn_BF' => 'fula (latim, Burquina Faso)',
        'ff_Latn_CM' => 'fula (latim, Camarões)',
        'ff_Latn_GH' => 'fula (latim, Gana)',
        'ff_Latn_GM' => 'fula (latim, Gâmbia)',
        'ff_Latn_GN' => 'fula (latim, Guiné)',
        'ff_Latn_GW' => 'fula (latim, Guiné-Bissau)',
        'ff_Latn_LR' => 'fula (latim, Libéria)',
        'ff_Latn_MR' => 'fula (latim, Mauritânia)',
        'ff_Latn_NE' => 'fula (latim, Níger)',
        'ff_Latn_NG' => 'fula (latim, Nigéria)',
        'ff_Latn_SL' => 'fula (latim, Serra Leoa)',
        'ff_Latn_SN' => 'fula (latim, Senegal)',
        'ff_MR' => 'fula (Mauritânia)',
        'ff_SN' => 'fula (Senegal)',
        'fi' => 'finlandês',
        'fi_FI' => 'finlandês (Finlândia)',
        'fo' => 'feroês',
        'fo_DK' => 'feroês (Dinamarca)',
        'fo_FO' => 'feroês (Ilhas Faroé)',
        'fr' => 'francês',
        'fr_BE' => 'francês (Bélgica)',
        'fr_BF' => 'francês (Burquina Faso)',
        'fr_BI' => 'francês (Burundi)',
        'fr_BJ' => 'francês (Benin)',
        'fr_BL' => 'francês (São Bartolomeu)',
        'fr_CA' => 'francês (Canadá)',
        'fr_CD' => 'francês (Congo - Kinshasa)',
        'fr_CF' => 'francês (República Centro-Africana)',
        'fr_CG' => 'francês (República do Congo)',
        'fr_CH' => 'francês (Suíça)',
        'fr_CI' => 'francês (Costa do Marfim)',
        'fr_CM' => 'francês (Camarões)',
        'fr_DJ' => 'francês (Djibuti)',
        'fr_DZ' => 'francês (Argélia)',
        'fr_FR' => 'francês (França)',
        'fr_GA' => 'francês (Gabão)',
        'fr_GF' => 'francês (Guiana Francesa)',
        'fr_GN' => 'francês (Guiné)',
        'fr_GP' => 'francês (Guadalupe)',
        'fr_GQ' => 'francês (Guiné Equatorial)',
        'fr_HT' => 'francês (Haiti)',
        'fr_KM' => 'francês (Comores)',
        'fr_LU' => 'francês (Luxemburgo)',
        'fr_MA' => 'francês (Marrocos)',
        'fr_MC' => 'francês (Mônaco)',
        'fr_MF' => 'francês (São Martinho)',
        'fr_MG' => 'francês (Madagascar)',
        'fr_ML' => 'francês (Mali)',
        'fr_MQ' => 'francês (Martinica)',
        'fr_MR' => 'francês (Mauritânia)',
        'fr_MU' => 'francês (Maurício)',
        'fr_NC' => 'francês (Nova Caledônia)',
        'fr_NE' => 'francês (Níger)',
        'fr_PF' => 'francês (Polinésia Francesa)',
        'fr_PM' => 'francês (São Pedro e Miquelão)',
        'fr_RE' => 'francês (Reunião)',
        'fr_RW' => 'francês (Ruanda)',
        'fr_SC' => 'francês (Seicheles)',
        'fr_SN' => 'francês (Senegal)',
        'fr_SY' => 'francês (Síria)',
        'fr_TD' => 'francês (Chade)',
        'fr_TG' => 'francês (Togo)',
        'fr_TN' => 'francês (Tunísia)',
        'fr_VU' => 'francês (Vanuatu)',
        'fr_WF' => 'francês (Wallis e Futuna)',
        'fr_YT' => 'francês (Mayotte)',
        'fy' => 'frísio ocidental',
        'fy_NL' => 'frísio ocidental (Países Baixos)',
        'ga' => 'irlandês',
        'ga_GB' => 'irlandês (Reino Unido)',
        'ga_IE' => 'irlandês (Irlanda)',
        'gd' => 'gaélico escocês',
        'gd_GB' => 'gaélico escocês (Reino Unido)',
        'gl' => 'galego',
        'gl_ES' => 'galego (Espanha)',
        'gu' => 'guzerate',
        'gu_IN' => 'guzerate (Índia)',
        'gv' => 'manx',
        'gv_IM' => 'manx (Ilha de Man)',
        'ha' => 'hauçá',
        'ha_GH' => 'hauçá (Gana)',
        'ha_NE' => 'hauçá (Níger)',
        'ha_NG' => 'hauçá (Nigéria)',
        'he' => 'hebraico',
        'he_IL' => 'hebraico (Israel)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (Índia)',
        'hi_Latn' => 'hindi (latim)',
        'hi_Latn_IN' => 'hindi (latim, Índia)',
        'hr' => 'croata',
        'hr_BA' => 'croata (Bósnia e Herzegovina)',
        'hr_HR' => 'croata (Croácia)',
        'hu' => 'húngaro',
        'hu_HU' => 'húngaro (Hungria)',
        'hy' => 'armênio',
        'hy_AM' => 'armênio (Armênia)',
        'ia' => 'interlíngua',
        'ia_001' => 'interlíngua (Mundo)',
        'id' => 'indonésio',
        'id_ID' => 'indonésio (Indonésia)',
        'ie' => 'interlingue',
        'ie_EE' => 'interlingue (Estônia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigéria)',
        'ii' => 'sichuan yi',
        'ii_CN' => 'sichuan yi (China)',
        'is' => 'islandês',
        'is_IS' => 'islandês (Islândia)',
        'it' => 'italiano',
        'it_CH' => 'italiano (Suíça)',
        'it_IT' => 'italiano (Itália)',
        'it_SM' => 'italiano (San Marino)',
        'it_VA' => 'italiano (Cidade do Vaticano)',
        'ja' => 'japonês',
        'ja_JP' => 'japonês (Japão)',
        'jv' => 'javanês',
        'jv_ID' => 'javanês (Indonésia)',
        'ka' => 'georgiano',
        'ka_GE' => 'georgiano (Geórgia)',
        'ki' => 'quicuio',
        'ki_KE' => 'quicuio (Quênia)',
        'kk' => 'cazaque',
        'kk_Arab' => 'cazaque (árabe)',
        'kk_Arab_CN' => 'cazaque (árabe, China)',
        'kk_Cyrl' => 'cazaque (cirílico)',
        'kk_Cyrl_KZ' => 'cazaque (cirílico, Cazaquistão)',
        'kk_KZ' => 'cazaque (Cazaquistão)',
        'kl' => 'groenlandês',
        'kl_GL' => 'groenlandês (Groenlândia)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Camboja)',
        'kn' => 'canarim',
        'kn_IN' => 'canarim (Índia)',
        'ko' => 'coreano',
        'ko_CN' => 'coreano (China)',
        'ko_KP' => 'coreano (Coreia do Norte)',
        'ko_KR' => 'coreano (Coreia do Sul)',
        'ks' => 'caxemira',
        'ks_Arab' => 'caxemira (árabe)',
        'ks_Arab_IN' => 'caxemira (árabe, Índia)',
        'ks_Deva' => 'caxemira (devanágari)',
        'ks_Deva_IN' => 'caxemira (devanágari, Índia)',
        'ks_IN' => 'caxemira (Índia)',
        'ku' => 'curdo',
        'ku_Latn' => 'curdo (latim)',
        'ku_Latn_IQ' => 'curdo (latim, Iraque)',
        'ku_Latn_SY' => 'curdo (latim, Síria)',
        'ku_Latn_TR' => 'curdo (latim, Turquia)',
        'ku_SY' => 'curdo (Síria)',
        'ku_TR' => 'curdo (Turquia)',
        'kw' => 'córnico',
        'kw_GB' => 'córnico (Reino Unido)',
        'ky' => 'quirguiz',
        'ky_KG' => 'quirguiz (Quirguistão)',
        'lb' => 'luxemburguês',
        'lb_LU' => 'luxemburguês (Luxemburgo)',
        'lg' => 'luganda',
        'lg_UG' => 'luganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Congo - Kinshasa)',
        'ln_CF' => 'lingala (República Centro-Africana)',
        'ln_CG' => 'lingala (República do Congo)',
        'lo' => 'laosiano',
        'lo_LA' => 'laosiano (Laos)',
        'lt' => 'lituano',
        'lt_LT' => 'lituano (Lituânia)',
        'lu' => 'luba-catanga',
        'lu_CD' => 'luba-catanga (Congo - Kinshasa)',
        'lv' => 'letão',
        'lv_LV' => 'letão (Letônia)',
        'mg' => 'malgaxe',
        'mg_MG' => 'malgaxe (Madagascar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Nova Zelândia)',
        'mk' => 'macedônio',
        'mk_MK' => 'macedônio (Macedônia do Norte)',
        'ml' => 'malaiala',
        'ml_IN' => 'malaiala (Índia)',
        'mn' => 'mongol',
        'mn_MN' => 'mongol (Mongólia)',
        'mr' => 'marati',
        'mr_IN' => 'marati (Índia)',
        'ms' => 'malaio',
        'ms_BN' => 'malaio (Brunei)',
        'ms_ID' => 'malaio (Indonésia)',
        'ms_MY' => 'malaio (Malásia)',
        'ms_SG' => 'malaio (Singapura)',
        'mt' => 'maltês',
        'mt_MT' => 'maltês (Malta)',
        'my' => 'birmanês',
        'my_MM' => 'birmanês (Mianmar [Birmânia])',
        'nb' => 'bokmål norueguês',
        'nb_NO' => 'bokmål norueguês (Noruega)',
        'nb_SJ' => 'bokmål norueguês (Svalbard e Jan Mayen)',
        'nd' => 'ndebele do norte',
        'nd_ZW' => 'ndebele do norte (Zimbábue)',
        'ne' => 'nepalês',
        'ne_IN' => 'nepalês (Índia)',
        'ne_NP' => 'nepalês (Nepal)',
        'nl' => 'holandês',
        'nl_AW' => 'holandês (Aruba)',
        'nl_BE' => 'holandês (Bélgica)',
        'nl_BQ' => 'holandês (Países Baixos Caribenhos)',
        'nl_CW' => 'holandês (Curaçao)',
        'nl_NL' => 'holandês (Países Baixos)',
        'nl_SR' => 'holandês (Suriname)',
        'nl_SX' => 'holandês (Sint Maarten)',
        'nn' => 'nynorsk norueguês',
        'nn_NO' => 'nynorsk norueguês (Noruega)',
        'no' => 'norueguês',
        'no_NO' => 'norueguês (Noruega)',
        'oc' => 'occitânico',
        'oc_ES' => 'occitânico (Espanha)',
        'oc_FR' => 'occitânico (França)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiópia)',
        'om_KE' => 'oromo (Quênia)',
        'or' => 'oriá',
        'or_IN' => 'oriá (Índia)',
        'os' => 'osseto',
        'os_GE' => 'osseto (Geórgia)',
        'os_RU' => 'osseto (Rússia)',
        'pa' => 'panjabi',
        'pa_Arab' => 'panjabi (árabe)',
        'pa_Arab_PK' => 'panjabi (árabe, Paquistão)',
        'pa_Guru' => 'panjabi (gurmuqui)',
        'pa_Guru_IN' => 'panjabi (gurmuqui, Índia)',
        'pa_IN' => 'panjabi (Índia)',
        'pa_PK' => 'panjabi (Paquistão)',
        'pl' => 'polonês',
        'pl_PL' => 'polonês (Polônia)',
        'ps' => 'pashto',
        'ps_AF' => 'pashto (Afeganistão)',
        'ps_PK' => 'pashto (Paquistão)',
        'pt' => 'português',
        'pt_AO' => 'português (Angola)',
        'pt_BR' => 'português (Brasil)',
        'pt_CH' => 'português (Suíça)',
        'pt_CV' => 'português (Cabo Verde)',
        'pt_GQ' => 'português (Guiné Equatorial)',
        'pt_GW' => 'português (Guiné-Bissau)',
        'pt_LU' => 'português (Luxemburgo)',
        'pt_MO' => 'português (Macau, RAE da China)',
        'pt_MZ' => 'português (Moçambique)',
        'pt_PT' => 'português (Portugal)',
        'pt_ST' => 'português (São Tomé e Príncipe)',
        'pt_TL' => 'português (Timor-Leste)',
        'qu' => 'quíchua',
        'qu_BO' => 'quíchua (Bolívia)',
        'qu_EC' => 'quíchua (Equador)',
        'qu_PE' => 'quíchua (Peru)',
        'rm' => 'romanche',
        'rm_CH' => 'romanche (Suíça)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'romeno',
        'ro_MD' => 'romeno (Moldávia)',
        'ro_RO' => 'romeno (Romênia)',
        'ru' => 'russo',
        'ru_BY' => 'russo (Bielorrússia)',
        'ru_KG' => 'russo (Quirguistão)',
        'ru_KZ' => 'russo (Cazaquistão)',
        'ru_MD' => 'russo (Moldávia)',
        'ru_RU' => 'russo (Rússia)',
        'ru_UA' => 'russo (Ucrânia)',
        'rw' => 'quiniaruanda',
        'rw_RW' => 'quiniaruanda (Ruanda)',
        'sa' => 'sânscrito',
        'sa_IN' => 'sânscrito (Índia)',
        'sc' => 'sardo',
        'sc_IT' => 'sardo (Itália)',
        'sd' => 'sindi',
        'sd_Arab' => 'sindi (árabe)',
        'sd_Arab_PK' => 'sindi (árabe, Paquistão)',
        'sd_Deva' => 'sindi (devanágari)',
        'sd_Deva_IN' => 'sindi (devanágari, Índia)',
        'sd_IN' => 'sindi (Índia)',
        'sd_PK' => 'sindi (Paquistão)',
        'se' => 'sami setentrional',
        'se_FI' => 'sami setentrional (Finlândia)',
        'se_NO' => 'sami setentrional (Noruega)',
        'se_SE' => 'sami setentrional (Suécia)',
        'sg' => 'sango',
        'sg_CF' => 'sango (República Centro-Africana)',
        'sh' => 'servo-croata',
        'sh_BA' => 'servo-croata (Bósnia e Herzegovina)',
        'si' => 'cingalês',
        'si_LK' => 'cingalês (Sri Lanka)',
        'sk' => 'eslovaco',
        'sk_SK' => 'eslovaco (Eslováquia)',
        'sl' => 'esloveno',
        'sl_SI' => 'esloveno (Eslovênia)',
        'sn' => 'xona',
        'sn_ZW' => 'xona (Zimbábue)',
        'so' => 'somali',
        'so_DJ' => 'somali (Djibuti)',
        'so_ET' => 'somali (Etiópia)',
        'so_KE' => 'somali (Quênia)',
        'so_SO' => 'somali (Somália)',
        'sq' => 'albanês',
        'sq_AL' => 'albanês (Albânia)',
        'sq_MK' => 'albanês (Macedônia do Norte)',
        'sr' => 'sérvio',
        'sr_BA' => 'sérvio (Bósnia e Herzegovina)',
        'sr_Cyrl' => 'sérvio (cirílico)',
        'sr_Cyrl_BA' => 'sérvio (cirílico, Bósnia e Herzegovina)',
        'sr_Cyrl_ME' => 'sérvio (cirílico, Montenegro)',
        'sr_Cyrl_RS' => 'sérvio (cirílico, Sérvia)',
        'sr_Latn' => 'sérvio (latim)',
        'sr_Latn_BA' => 'sérvio (latim, Bósnia e Herzegovina)',
        'sr_Latn_ME' => 'sérvio (latim, Montenegro)',
        'sr_Latn_RS' => 'sérvio (latim, Sérvia)',
        'sr_ME' => 'sérvio (Montenegro)',
        'sr_RS' => 'sérvio (Sérvia)',
        'st' => 'soto do sul',
        'st_LS' => 'soto do sul (Lesoto)',
        'st_ZA' => 'soto do sul (África do Sul)',
        'su' => 'sundanês',
        'su_ID' => 'sundanês (Indonésia)',
        'su_Latn' => 'sundanês (latim)',
        'su_Latn_ID' => 'sundanês (latim, Indonésia)',
        'sv' => 'sueco',
        'sv_AX' => 'sueco (Ilhas Aland)',
        'sv_FI' => 'sueco (Finlândia)',
        'sv_SE' => 'sueco (Suécia)',
        'sw' => 'suaíli',
        'sw_CD' => 'suaíli (Congo - Kinshasa)',
        'sw_KE' => 'suaíli (Quênia)',
        'sw_TZ' => 'suaíli (Tanzânia)',
        'sw_UG' => 'suaíli (Uganda)',
        'ta' => 'tâmil',
        'ta_IN' => 'tâmil (Índia)',
        'ta_LK' => 'tâmil (Sri Lanka)',
        'ta_MY' => 'tâmil (Malásia)',
        'ta_SG' => 'tâmil (Singapura)',
        'te' => 'télugo',
        'te_IN' => 'télugo (Índia)',
        'tg' => 'tadjique',
        'tg_TJ' => 'tadjique (Tadjiquistão)',
        'th' => 'tailandês',
        'th_TH' => 'tailandês (Tailândia)',
        'ti' => 'tigrínia',
        'ti_ER' => 'tigrínia (Eritreia)',
        'ti_ET' => 'tigrínia (Etiópia)',
        'tk' => 'turcomeno',
        'tk_TM' => 'turcomeno (Turcomenistão)',
        'tl' => 'tagalo',
        'tl_PH' => 'tagalo (Filipinas)',
        'tn' => 'tswana',
        'tn_BW' => 'tswana (Botsuana)',
        'tn_ZA' => 'tswana (África do Sul)',
        'to' => 'tonganês',
        'to_TO' => 'tonganês (Tonga)',
        'tr' => 'turco',
        'tr_CY' => 'turco (Chipre)',
        'tr_TR' => 'turco (Turquia)',
        'tt' => 'tártaro',
        'tt_RU' => 'tártaro (Rússia)',
        'ug' => 'uigur',
        'ug_CN' => 'uigur (China)',
        'uk' => 'ucraniano',
        'uk_UA' => 'ucraniano (Ucrânia)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (Índia)',
        'ur_PK' => 'urdu (Paquistão)',
        'uz' => 'uzbeque',
        'uz_AF' => 'uzbeque (Afeganistão)',
        'uz_Arab' => 'uzbeque (árabe)',
        'uz_Arab_AF' => 'uzbeque (árabe, Afeganistão)',
        'uz_Cyrl' => 'uzbeque (cirílico)',
        'uz_Cyrl_UZ' => 'uzbeque (cirílico, Uzbequistão)',
        'uz_Latn' => 'uzbeque (latim)',
        'uz_Latn_UZ' => 'uzbeque (latim, Uzbequistão)',
        'uz_UZ' => 'uzbeque (Uzbequistão)',
        'vi' => 'vietnamita',
        'vi_VN' => 'vietnamita (Vietnã)',
        'wo' => 'uolofe',
        'wo_SN' => 'uolofe (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (África do Sul)',
        'yi' => 'iídiche',
        'yi_UA' => 'iídiche (Ucrânia)',
        'yo' => 'iorubá',
        'yo_BJ' => 'iorubá (Benin)',
        'yo_NG' => 'iorubá (Nigéria)',
        'za' => 'zhuang',
        'za_CN' => 'zhuang (China)',
        'zh' => 'chinês',
        'zh_CN' => 'chinês (China)',
        'zh_HK' => 'chinês (Hong Kong, RAE da China)',
        'zh_Hans' => 'chinês (simplificado)',
        'zh_Hans_CN' => 'chinês (simplificado, China)',
        'zh_Hans_HK' => 'chinês (simplificado, Hong Kong, RAE da China)',
        'zh_Hans_MO' => 'chinês (simplificado, Macau, RAE da China)',
        'zh_Hans_MY' => 'chinês (simplificado, Malásia)',
        'zh_Hans_SG' => 'chinês (simplificado, Singapura)',
        'zh_Hant' => 'chinês (tradicional)',
        'zh_Hant_HK' => 'chinês (tradicional, Hong Kong, RAE da China)',
        'zh_Hant_MO' => 'chinês (tradicional, Macau, RAE da China)',
        'zh_Hant_MY' => 'chinês (tradicional, Malásia)',
        'zh_Hant_TW' => 'chinês (tradicional, Taiwan)',
        'zh_MO' => 'chinês (Macau, RAE da China)',
        'zh_SG' => 'chinês (Singapura)',
        'zh_TW' => 'chinês (Taiwan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (África do Sul)',
    ],
];
