<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abhaasi',
        'ace' => 'atšeh',
        'ach' => 'atšoli',
        'ada' => 'adangme',
        'ady' => 'adyge',
        'ae' => 'avesta',
        'aeb' => 'tunisianarabia',
        'af' => 'afrikaans',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'akk' => 'akkadi',
        'akz' => 'alabama',
        'ale' => 'aleutti',
        'aln' => 'gegi',
        'alt' => 'altai',
        'am' => 'amhara',
        'an' => 'aragonia',
        'ang' => 'muinaisenglanti',
        'ann' => 'obolo',
        'anp' => 'angika',
        'apc' => 'urduni',
        'ar' => 'arabia',
        'arc' => 'valtakunnanaramea',
        'arn' => 'mapudungun',
        'aro' => 'araona',
        'arp' => 'arapaho',
        'arq' => 'algerianarabia',
        'ars' => 'arabia – najd',
        'arw' => 'arawak',
        'ary' => 'marokonarabia',
        'arz' => 'egyptinarabia',
        'as' => 'assami',
        'asa' => 'asu',
        'ase' => 'amerikkalainen viittomakieli',
        'ast' => 'asturia',
        'atj' => 'atikamekw',
        'av' => 'avaari',
        'avk' => 'kotava',
        'awa' => 'awadhi',
        'ay' => 'aimara',
        'az' => 'azeri',
        'ba' => 'baškiiri',
        'bal' => 'belutši',
        'ban' => 'bali',
        'bar' => 'baijeri',
        'bas' => 'basaa',
        'bax' => 'bamum',
        'bbc' => 'batak-toba',
        'bbj' => 'ghomala',
        'be' => 'valkovenäjä',
        'bej' => 'bedža',
        'bem' => 'bemba',
        'bew' => 'betawi',
        'bez' => 'bena',
        'bfd' => 'fut',
        'bfq' => 'badaga',
        'bg' => 'bulgaria',
        'bgc' => 'haryanvi',
        'bgn' => 'länsibelutši',
        'bho' => 'bhodžpuri',
        'bi' => 'bislama',
        'bik' => 'bikol',
        'bin' => 'bini',
        'bjn' => 'banjar',
        'bkm' => 'kom',
        'bla' => 'siksika',
        'blo' => 'anii',
        'blt' => 'tai dam',
        'bm' => 'bambara',
        'bn' => 'bengali',
        'bo' => 'tiibet',
        'bpy' => 'bišnupria',
        'bqi' => 'bahtiari',
        'br' => 'bretoni',
        'bra' => 'bradž',
        'brh' => 'brahui',
        'brx' => 'bodo',
        'bs' => 'bosnia',
        'bss' => 'koose',
        'bua' => 'burjaatti',
        'bug' => 'bugi',
        'bum' => 'bulu',
        'byn' => 'bilin',
        'byv' => 'medumba',
        'ca' => 'katalaani',
        'cad' => 'caddo',
        'car' => 'karibi',
        'cay' => 'cayuga',
        'cch' => 'atsam',
        'ccp' => 'chakma',
        'ce' => 'tšetšeeni',
        'ceb' => 'cebuano',
        'cgg' => 'kiga',
        'ch' => 'tšamorro',
        'chb' => 'tšibtša',
        'chg' => 'tšagatai',
        'chk' => 'chuuk',
        'chm' => 'mari',
        'chn' => 'chinook-jargon',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'cic' => 'chickasaw',
        'ckb' => 'soranî',
        'clc' => 'chilcotin',
        'co' => 'korsika',
        'cop' => 'kopti',
        'cps' => 'capiznon',
        'cr' => 'cree',
        'crg' => 'michif',
        'crh' => 'krimintataari',
        'crj' => 'east cree (eteläinen)',
        'crk' => 'plains cree',
        'crl' => 'east cree (pohjoinen)',
        'crm' => 'moose cree',
        'crr' => 'pamlico',
        'crs' => 'seychellienkreoli',
        'cs' => 'tšekki',
        'csb' => 'kašubi',
        'csw' => 'swampy cree',
        'cu' => 'kirkkoslaavi',
        'cv' => 'tšuvassi',
        'cy' => 'kymri',
        'da' => 'tanska',
        'dak' => 'dakota',
        'dar' => 'dargi',
        'dav' => 'taita',
        'de' => 'saksa',
        'del' => 'delaware',
        'den' => 'slevi',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'djerma',
        'doi' => 'dogri',
        'dsb' => 'alasorbi',
        'dtp' => 'dusun',
        'dua' => 'duala',
        'dum' => 'keskihollanti',
        'dv' => 'divehi',
        'dyo' => 'jola-fonyi',
        'dyu' => 'djula',
        'dz' => 'dzongkha',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'egl' => 'emilia',
        'egy' => 'muinaisegypti',
        'eka' => 'ekajuk',
        'el' => 'kreikka',
        'elx' => 'elami',
        'en' => 'englanti',
        'enm' => 'keskienglanti',
        'eo' => 'esperanto',
        'es' => 'espanja',
        'esu' => 'alaskanjupik',
        'et' => 'viro',
        'eu' => 'baski',
        'ewo' => 'ewondo',
        'ext' => 'extremadura',
        'fa' => 'persia',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'fulani',
        'fi' => 'suomi',
        'fil' => 'filipino',
        'fit' => 'meänkieli',
        'fj' => 'fidži',
        'fo' => 'fääri',
        'fon' => 'fon',
        'fr' => 'ranska',
        'frc' => 'cajunranska',
        'frm' => 'keskiranska',
        'fro' => 'muinaisranska',
        'frp' => 'arpitaani',
        'frr' => 'pohjoisfriisi',
        'frs' => 'itäfriisi',
        'fur' => 'friuli',
        'fy' => 'länsifriisi',
        'ga' => 'iiri',
        'gaa' => 'ga',
        'gag' => 'gagauzi',
        'gan' => 'gan-kiina',
        'gay' => 'gajo',
        'gba' => 'gbaja',
        'gbz' => 'zoroastrialaisdari',
        'gd' => 'gaeli',
        'gez' => 'ge’ez',
        'gil' => 'kiribati',
        'gl' => 'galicia',
        'glk' => 'gilaki',
        'gmh' => 'keskiyläsaksa',
        'gn' => 'guarani',
        'goh' => 'muinaisyläsaksa',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gootti',
        'grb' => 'grebo',
        'grc' => 'muinaiskreikka',
        'gsw' => 'sveitsinsaksa',
        'gu' => 'gudžarati',
        'guc' => 'wayuu',
        'gur' => 'frafra',
        'guz' => 'gusii',
        'gv' => 'manksi',
        'gwi' => 'gwitšin',
        'ha' => 'hausa',
        'hai' => 'haida',
        'hak' => 'hakka-kiina',
        'haw' => 'havaiji',
        'hax' => 'haida (eteläinen)',
        'he' => 'heprea',
        'hi' => 'hindi',
        'hif' => 'fidžinhindi',
        'hil' => 'hiligaino',
        'hit' => 'heetti',
        'hmn' => 'hmong',
        'hnj' => 'hmong njua',
        'ho' => 'hiri-motu',
        'hr' => 'kroatia',
        'hsb' => 'yläsorbi',
        'hsn' => 'xiang-kiina',
        'ht' => 'haiti',
        'hu' => 'unkari',
        'hup' => 'hupa',
        'hur' => 'halkomelem',
        'hy' => 'armenia',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'ibb' => 'ibibio',
        'id' => 'indonesia',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'sichuanin-yi',
        'ik' => 'inupiaq',
        'ikt' => 'Länsi-Kanadan inuktitut',
        'ilo' => 'iloko',
        'inh' => 'inguuši',
        'io' => 'ido',
        'is' => 'islanti',
        'it' => 'italia',
        'iu' => 'inuktitut',
        'izh' => 'inkeroinen',
        'ja' => 'japani',
        'jam' => 'jamaikankreolienglanti',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jpr' => 'juutalaispersia',
        'jrb' => 'juutalaisarabia',
        'jut' => 'juutti',
        'jv' => 'jaava',
        'ka' => 'georgia',
        'kaa' => 'karakalpakki',
        'kab' => 'kabyyli',
        'kac' => 'katšin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kavi',
        'kbd' => 'kabardi',
        'kbl' => 'kanembu',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'kapverdenkreoli',
        'kek' => 'qʼeqchiʼ',
        'ken' => 'kenyang',
        'kfo' => 'norsunluurannikonkoro',
        'kg' => 'kongo',
        'kgp' => 'kaingang',
        'kha' => 'khasi',
        'kho' => 'khotani',
        'khq' => 'koyra chiini',
        'khw' => 'khowar',
        'ki' => 'kikuju',
        'kiu' => 'kirmanjki',
        'kj' => 'kuanjama',
        'kk' => 'kazakki',
        'kkj' => 'kako',
        'kl' => 'kalaallisut',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'korea',
        'koi' => 'komipermjakki',
        'kok' => 'konkani',
        'kos' => 'kosrae',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karatšai-balkaari',
        'kri' => 'krio',
        'krj' => 'kinaray-a',
        'krl' => 'karjala',
        'kru' => 'kurukh',
        'ks' => 'kašmiri',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'kölsch',
        'ku' => 'kurdi',
        'kum' => 'kumykki',
        'kut' => 'kutenai',
        'kv' => 'komi',
        'kw' => 'korni',
        'kwk' => 'kwakʼwala',
        'kxv' => 'kuvi',
        'ky' => 'kirgiisi',
        'la' => 'latina',
        'lad' => 'ladino',
        'lag' => 'lango',
        'lah' => 'lahnda',
        'lam' => 'lamba',
        'lb' => 'luxemburg',
        'lez' => 'lezgi',
        'lfn' => 'lingua franca nova',
        'lg' => 'ganda',
        'li' => 'limburg',
        'lij' => 'liguuri',
        'lil' => 'lillooet',
        'liv' => 'liivi',
        'lkt' => 'lakota',
        'lld' => 'ladin',
        'lmo' => 'lombardi',
        'ln' => 'lingala',
        'lo' => 'lao',
        'lol' => 'mongo',
        'lou' => 'louisianankreoli',
        'loz' => 'lozi',
        'lrc' => 'pohjoisluri',
        'lsm' => 'samia',
        'lt' => 'liettua',
        'ltg' => 'latgalli',
        'lu' => 'katanganluba',
        'lua' => 'luluanluba',
        'lui' => 'luiseño',
        'lun' => 'lunda',
        'lus' => 'lusai',
        'luy' => 'luhya',
        'lv' => 'latvia',
        'lzh' => 'klassinen kiina',
        'lzz' => 'lazi',
        'mad' => 'madura',
        'maf' => 'mafa',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makassar',
        'man' => 'mandingo',
        'mas' => 'maasai',
        'mde' => 'maba',
        'mdf' => 'mokša',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisyen',
        'mg' => 'malagassi',
        'mga' => 'keski-iiri',
        'mgh' => 'makua-meetto',
        'mgo' => 'meta’',
        'mh' => 'marshall',
        'mhn' => 'mócheno',
        'mi' => 'maori',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'makedonia',
        'ml' => 'malajalam',
        'mn' => 'mongoli',
        'mnc' => 'mantšu',
        'mni' => 'manipuri',
        'moe' => 'innu-aimun',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'mrj' => 'vuorimari',
        'ms' => 'malaiji',
        'mt' => 'malta',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandeesi',
        'mwr' => 'marwari',
        'mwv' => 'mentawai',
        'my' => 'burma',
        'mye' => 'myene',
        'myv' => 'ersä',
        'mzn' => 'mazandarani',
        'na' => 'nauru',
        'nan' => 'min nan -kiina',
        'nap' => 'napoli',
        'naq' => 'nama',
        'nb' => 'norjan bokmål',
        'nd' => 'pohjois-ndebele',
        'nds' => 'alasaksa',
        'ne' => 'nepali',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niue',
        'njo' => 'ao naga',
        'nl' => 'hollanti',
        'nmg' => 'kwasio',
        'nn' => 'norjan nynorsk',
        'nnh' => 'ngiemboon',
        'no' => 'norja',
        'nog' => 'nogai',
        'non' => 'muinaisnorja',
        'nov' => 'novial',
        'nqo' => 'n’ko',
        'nr' => 'etelä-ndebele',
        'nso' => 'pohjoissotho',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'nwc' => 'klassinen newari',
        'ny' => 'njandža',
        'nym' => 'nyamwezi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoro',
        'nzi' => 'nzima',
        'oc' => 'oksitaani',
        'oj' => 'odžibwa',
        'ojb' => 'luoteis-odžibwa',
        'ojc' => 'keskiojibwa',
        'ojs' => 'oji-cree',
        'ojw' => 'länsi-odžibwa',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'orija',
        'os' => 'osseetti',
        'osa' => 'osage',
        'ota' => 'osmani',
        'pa' => 'pandžabi',
        'pag' => 'pangasinan',
        'pal' => 'pahlavi',
        'pam' => 'pampanga',
        'pap' => 'papiamentu',
        'pau' => 'palau',
        'pcd' => 'picardi',
        'pcm' => 'nigerianpidgin',
        'pdc' => 'pennsylvaniansaksa',
        'pdt' => 'plautdietsch',
        'peo' => 'muinaispersia',
        'pfl' => 'pfaltsi',
        'phn' => 'foinikia',
        'pi' => 'paali',
        'pis' => 'pijin',
        'pl' => 'puola',
        'pms' => 'piemonte',
        'pnt' => 'pontoksenkreikka',
        'pon' => 'pohnpei',
        'pqm' => 'maliseet-passamaquoddy',
        'prg' => 'muinaispreussi',
        'pro' => 'muinaisprovensaali',
        'ps' => 'paštu',
        'pt' => 'portugali',
        'qu' => 'ketšua',
        'quc' => 'kʼicheʼ',
        'qug' => 'chimborazonylänköketšua',
        'raj' => 'radžastani',
        'rap' => 'rapanui',
        'rar' => 'rarotonga',
        'rgn' => 'romagnoli',
        'rhg' => 'rohinga',
        'rif' => 'tarifit',
        'rm' => 'retoromaani',
        'rn' => 'rundi',
        'ro' => 'romania',
        'rof' => 'rombo',
        'rom' => 'romani',
        'rtm' => 'rotuma',
        'ru' => 'venäjä',
        'rue' => 'ruteeni',
        'rug' => 'roviana',
        'rup' => 'aromania',
        'rw' => 'ruanda',
        'rwk' => 'rwa',
        'sa' => 'sanskrit',
        'sad' => 'sandawe',
        'sah' => 'jakuutti',
        'sam' => 'samarianaramea',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santali',
        'saz' => 'sauraštri',
        'sba' => 'ngambay',
        'sbp' => 'sangu',
        'sc' => 'sardi',
        'scn' => 'sisilia',
        'sco' => 'skotti',
        'sd' => 'sindhi',
        'sdc' => 'sassarinsardi',
        'sdh' => 'eteläkurdi',
        'se' => 'pohjoissaame',
        'see' => 'seneca',
        'seh' => 'sena',
        'sei' => 'seri',
        'sel' => 'selkuppi',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sga' => 'muinaisiiri',
        'sgs' => 'samogiitti',
        'sh' => 'serbokroaatti',
        'shi' => 'tašelhit',
        'shn' => 'shan',
        'shu' => 'tšadinarabia',
        'si' => 'sinhala',
        'sid' => 'sidamo',
        'sk' => 'slovakki',
        'skr' => 'saraiki',
        'sl' => 'sloveeni',
        'slh' => 'lushootseed (eteläinen)',
        'sli' => 'sleesiansaksa',
        'sly' => 'selayar',
        'sm' => 'samoa',
        'sma' => 'eteläsaame',
        'smj' => 'luulajansaame',
        'smn' => 'inarinsaame',
        'sms' => 'koltansaame',
        'sn' => 'šona',
        'snk' => 'soninke',
        'so' => 'somali',
        'sog' => 'sogdi',
        'sq' => 'albania',
        'sr' => 'serbia',
        'srn' => 'sranan',
        'srr' => 'serer',
        'ss' => 'swazi',
        'ssy' => 'saho',
        'st' => 'eteläsotho',
        'stq' => 'saterlandinfriisi',
        'str' => 'straits-salish',
        'su' => 'sunda',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumeri',
        'suz' => 'sunwar',
        'sv' => 'ruotsi',
        'sw' => 'swahili',
        'swb' => 'komori',
        'syc' => 'muinaissyyria',
        'syr' => 'syyria',
        'szl' => 'sleesia',
        'ta' => 'tamili',
        'tce' => 'etelätutchone',
        'tcy' => 'tulu',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tetum',
        'tg' => 'tadžikki',
        'tgx' => 'tagish',
        'th' => 'thai',
        'tht' => 'tahlta',
        'ti' => 'tigrinja',
        'tig' => 'tigre',
        'tiv' => 'tiv',
        'tk' => 'turkmeeni',
        'tkl' => 'tokelau',
        'tkr' => 'tsahuri',
        'tl' => 'tagalog',
        'tlh' => 'klingon',
        'tli' => 'tlingit',
        'tly' => 'tališi',
        'tmh' => 'tamašek',
        'tn' => 'tswana',
        'to' => 'tonga',
        'tog' => 'malawintonga',
        'tok' => 'toki pona',
        'tpi' => 'tok-pisin',
        'tr' => 'turkki',
        'tru' => 'turojo',
        'trv' => 'taroko',
        'trw' => 'torwali',
        'ts' => 'tsonga',
        'tsd' => 'tsakonia',
        'tsi' => 'tsimši',
        'tt' => 'tataari',
        'ttm' => 'pohjoinen tutchone',
        'ttt' => 'tati',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahiti',
        'tyv' => 'tuva',
        'tzm' => 'keskiatlaksentamazight',
        'udm' => 'udmurtti',
        'ug' => 'uiguuri',
        'uga' => 'ugarit',
        'uk' => 'ukraina',
        'umb' => 'mbundu',
        'ur' => 'urdu',
        'uz' => 'uzbekki',
        've' => 'venda',
        'vec' => 'venetsia',
        'vep' => 'vepsä',
        'vi' => 'vietnam',
        'vls' => 'länsiflaami',
        'vmf' => 'maininfrankki',
        'vmw' => 'makhuwa',
        'vo' => 'volapük',
        'vot' => 'vatja',
        'vro' => 'võro',
        'vun' => 'vunjo',
        'wa' => 'valloni',
        'wae' => 'walser',
        'wal' => 'wolaitta',
        'war' => 'waray',
        'was' => 'washo',
        'wbp' => 'warlpiri',
        'wo' => 'wolof',
        'wuu' => 'wu-kiina',
        'xal' => 'kalmukki',
        'xh' => 'xhosa',
        'xmf' => 'mingreli',
        'xnr' => 'kangri',
        'xog' => 'soga',
        'yao' => 'jao',
        'yap' => 'japi',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'jiddiš',
        'yo' => 'joruba',
        'yrl' => 'ñeengatú',
        'yue' => 'kantoninkiina',
        'za' => 'zhuang',
        'zap' => 'zapoteekki',
        'zbl' => 'blisskieli',
        'zea' => 'seelanti',
        'zen' => 'zenaga',
        'zgh' => 'vakioitu tamazight',
        'zh' => 'kiina',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'yleisarabia',
        'de_AT' => 'itävallansaksa',
        'de_CH' => 'sveitsinyläsaksa',
        'en_AU' => 'australianenglanti',
        'en_CA' => 'kanadanenglanti',
        'en_GB' => 'britannianenglanti',
        'en_US' => 'amerikanenglanti',
        'es_419' => 'amerikanespanja',
        'es_ES' => 'euroopanespanja',
        'es_MX' => 'meksikonespanja',
        'fa_AF' => 'dari',
        'fr_CA' => 'kanadanranska',
        'fr_CH' => 'sveitsinranska',
        'nds_NL' => 'alankomaidenalasaksa',
        'nl_BE' => 'flaami',
        'pt_BR' => 'brasilianportugali',
        'pt_PT' => 'euroopanportugali',
        'ro_MD' => 'moldova',
        'sw_CD' => 'kongonswahili',
    ],
];
