<?php

return [
    'Names' => [
        'ak' => 'Akaan',
        'am' => 'Amarik',
        'ar' => 'Aarabeere',
        'be' => 'Belaruuse',
        'bg' => 'Bulgariire',
        'bn' => 'Bengali',
        'cs' => 'Cekkere',
        'de' => 'Docceere',
        'el' => 'Gerke',
        'en' => 'Engeleere',
        'es' => 'Español',
        'fa' => 'Perseere',
        'ff' => 'Pulaar',
        'fr' => 'Farayseere',
        'ha' => 'Hawsaŋkoore',
        'hi' => 'Hinndi',
        'hu' => 'Hongariire',
        'id' => 'Endonesiire',
        'ig' => 'Igiboore',
        'it' => 'Italiyeere',
        'ja' => 'Saponeere',
        'jv' => 'Sawaneere',
        'km' => 'Kemeere',
        'ko' => 'Koreere',
        'ms' => 'Malayeere',
        'my' => 'Burmeese',
        'ne' => 'Nepaaleere',
        'nl' => 'Dacceere',
        'pa' => 'Punjabeere',
        'pl' => 'Poloneere',
        'pt' => 'Purtugeere',
        'ro' => 'Romaneere',
        'ru' => 'Riis',
        'rw' => 'Ruwaanndeere',
        'so' => 'Somalii',
        'sv' => 'Sweedeere',
        'ta' => 'Tamil',
        'th' => 'Taay',
        'tr' => 'Turkeere',
        'uk' => 'Ukereneere',
        'ur' => 'Urdu',
        'vi' => 'Wiyetnameere',
        'yo' => 'Yorrubaa',
        'zh' => 'Sinuwaare',
        'zu' => 'Suluŋkoore',
    ],
    'LocalizedNames' => [],
];
