<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ອາບິດແຈນ)',
        'Africa/Accra' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ອັກຄຣາ)',
        'Africa/Addis_Ababa' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ແອດດິສ ອະບາບາ)',
        'Africa/Algiers' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ແອວເຈຍ)',
        'Africa/Asmera' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ອັສມາຣາ)',
        'Africa/Asmara' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ອັສມາຣາ)',
        'Africa/Bamako' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ບາມາໂກ)',
        'Africa/Bangui' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ບັງກຸຍ)',
        'Africa/Banjul' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ບານຈູ)',
        'Africa/Bissau' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ບິສເຊົາ)',
        'Africa/Blantyre' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ແບລນໄທຣ໌)',
        'Africa/Brazzaville' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ບຣາຊາວິວ)',
        'Africa/Bujumbura' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ບູຈູມບູຣາ)',
        'Africa/Cairo' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ໄຄໂຣ)',
        'Africa/Casablanca' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ຕົກ (ຄາຊາບລັງກາ)',
        'Africa/Ceuta' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ຊີວຕາ)',
        'Africa/Conakry' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ໂຄນາຄຣີ)',
        'Africa/Dakar' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ດາກາ)',
        'Africa/Dar_es_Salaam' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ດາເອສສະລາມ)',
        'Africa/Djibouti' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ຈີບູຕິ)',
        'Africa/Douala' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ດູອາລາ)',
        'Africa/El_Aaiun' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ຕົກ (ເອວ ອາຢູນ)',
        'Africa/Freetown' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ຟຣີທາວ)',
        'Africa/Gaborone' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ກາບໍໂຣນ)',
        'Africa/Harare' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ຮາຣາເຣ)',
        'Africa/Johannesburg' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ໃຕ້ (ໂຈຮັນເນດສເບີກ)',
        'Africa/Juba' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ຈູບາ)',
        'Africa/Kampala' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ຄຳປາລາ)',
        'Africa/Khartoum' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ຄາທູມ)',
        'Africa/Kigali' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ຄີກາລີ)',
        'Africa/Kinshasa' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ກິນຊາຊາ)',
        'Africa/Lagos' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ລາໂກສ)',
        'Africa/Libreville' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ລິເບຼີວິວ)',
        'Africa/Lome' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ໂລເມ)',
        'Africa/Luanda' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ລວນດາ)',
        'Africa/Lubumbashi' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ລູບຳບາຊິ)',
        'Africa/Lusaka' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ລູຊາກາ)',
        'Africa/Malabo' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ມາລາໂບ)',
        'Africa/Maputo' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ມາປູໂຕ)',
        'Africa/Maseru' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ໃຕ້ (ມາເຊຣູ)',
        'Africa/Mbabane' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ໃຕ້ (ອຳບາບາເນ)',
        'Africa/Mogadishu' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ໂມກາດີຊູ)',
        'Africa/Monrovia' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ມອນໂຣເວຍ)',
        'Africa/Nairobi' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ໄນໂຣບີ)',
        'Africa/Ndjamena' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ເອນຈາເມນ່າ)',
        'Africa/Niamey' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ນີອາເມ)',
        'Africa/Nouakchott' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ນູແອກຊອດ)',
        'Africa/Ouagadougou' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ອູກາດູກູ)',
        'Africa/Porto-Novo' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ຕົກ (ປໍໂຕ-ໂນໂວ)',
        'Africa/Sao_Tome' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ຊາວໂຕເມ)',
        'Africa/Tripoli' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ທຣິໂພລິ)',
        'Africa/Tunis' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ຕູນິສ)',
        'Africa/Windhoek' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ກາງ (ວີນຮູດ)',
        'America/Adak' => 'ເວລາຮາວາຍ-ເອລູທຽນ (ອາແດກ)',
        'America/Anchorage' => 'ເວລາອະລັສກາ (ແອນເຄີເຣກ)',
        'America/Anguilla' => 'ເວລາຂອງອາແລນຕິກ (ແອນກິນລາ)',
        'America/Antigua' => 'ເວລາຂອງອາແລນຕິກ (ແອນທິກົວ)',
        'America/Araguaina' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ອາຣາກົວນາ)',
        'America/Argentina/La_Rioja' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ລາ ຣິໂອຈາ)',
        'America/Argentina/Rio_Gallegos' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຣິໂກ ແກວເລກອສ)',
        'America/Argentina/Salta' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຊານຕາ)',
        'America/Argentina/San_Juan' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ແຊນຮວນ)',
        'America/Argentina/San_Luis' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ແຊນລຸຍສ໌)',
        'America/Argentina/Tucuman' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຕູຄູແມນ)',
        'America/Argentina/Ushuaia' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ອູຊູເອຍ)',
        'America/Aruba' => 'ເວລາຂອງອາແລນຕິກ (ອາຣູບາ)',
        'America/Asuncion' => 'ເວ​ລາ​ປາ​ຣາ​ກວຍ (ອະຊຸນຊິອອງ)',
        'America/Bahia' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ບາເຢຍ)',
        'America/Bahia_Banderas' => 'ເວລາກາງ (ບາເຮຍ ແບນເດີຣາສ)',
        'America/Barbados' => 'ເວລາຂອງອາແລນຕິກ (ບາເບດອສ)',
        'America/Belem' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ບີເລມ)',
        'America/Belize' => 'ເວລາກາງ (ເບລີຊ)',
        'America/Blanc-Sablon' => 'ເວລາຂອງອາແລນຕິກ (ບລານ-ຊາບລອນ)',
        'America/Boa_Vista' => 'ເວລາຕາມເຂດອາເມຊອນ (ບົວ ວິສຕາ)',
        'America/Bogota' => 'ເວລາໂຄລໍາເບຍ (ໂບໂກຕາ)',
        'America/Boise' => 'ເວລາແຖບພູເຂົາ (ບອຍຊ໌)',
        'America/Buenos_Aires' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ບົວໂນສ ໄອເຣສ)',
        'America/Argentina/Buenos_Aires' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ບົວໂນສ ໄອເຣສ)',
        'America/Cambridge_Bay' => 'ເວລາແຖບພູເຂົາ (ແຄມບຣິດ ເບ)',
        'America/Campo_Grande' => 'ເວລາຕາມເຂດອາເມຊອນ (ກັງປູຣັງຈີ)',
        'America/Cancun' => 'ເວລາຕາເວັນອອກ (ແຄນກຸນ)',
        'America/Caracas' => 'ເວ​ລາ​ເວ​ເນ​ຊູ​ເອ​ລາ (ຄາຣາກັສ)',
        'America/Catamarca' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຄາຕາມາກາ)',
        'America/Argentina/Catamarca' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຄາຕາມາກາ)',
        'America/Cayenne' => 'ເວ​ລາ​ເຟ​ຣນ​ຊ໌​ເກຍ​ນາ (ຄາເຢນ)',
        'America/Cayman' => 'ເວລາຕາເວັນອອກ (ເຄແມນ)',
        'America/Chicago' => 'ເວລາກາງ (ຊິຄາໂກ)',
        'America/Chihuahua' => 'ເວລາກາງ (ຊິວາວາ)',
        'America/Ciudad_Juarez' => 'ເວລາແຖບພູເຂົາ (ຊີອູດັດ ຄົວເຣຊ)',
        'America/Coral_Harbour' => 'ເວລາຕາເວັນອອກ (ອາທິໂຄຄານ)',
        'America/Atikokan' => 'ເວລາຕາເວັນອອກ (ອາທິໂຄຄານ)',
        'America/Cordoba' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຄໍໂດບາ)',
        'America/Argentina/Cordoba' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຄໍໂດບາ)',
        'America/Costa_Rica' => 'ເວລາກາງ (ຄອສຕາຣິກາ)',
        'America/Coyhaique' => 'ເວ​ລາ​ຊິ​ລີ (Coyhaique)',
        'America/Creston' => 'ເວລາແຖບພູເຂົາ (ເຄຣສຕັນ)',
        'America/Cuiaba' => 'ເວລາຕາມເຂດອາເມຊອນ (ກຸຢາບາ)',
        'America/Curacao' => 'ເວລາຂອງອາແລນຕິກ (ກືຣາເຊົາ)',
        'America/Danmarkshavn' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ເດນມາກແຊນ)',
        'America/Dawson' => 'ເວລາຢູຄອນ (ດໍສັນ)',
        'America/Dawson_Creek' => 'ເວລາແຖບພູເຂົາ (ດໍສັນ ຄຣີກ)',
        'America/Denver' => 'ເວລາແຖບພູເຂົາ (ເດັນເວີ)',
        'America/Detroit' => 'ເວລາຕາເວັນອອກ (ດີທຣອຍ)',
        'America/Dominica' => 'ເວລາຂອງອາແລນຕິກ (ໂດມິນິກາ)',
        'America/Edmonton' => 'ເວລາແຖບພູເຂົາ (ເອດມອນຕອນ)',
        'America/Eirunepe' => 'ເວລາຂອງອາເກຣ (ເອຣຸເນປີ)',
        'America/El_Salvador' => 'ເວລາກາງ (ເອວ ຊາວາດໍ)',
        'America/Fort_Nelson' => 'ເວລາແຖບພູເຂົາ (ຟອດ ເນວສັນ)',
        'America/Fortaleza' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ຟໍຕາເລຊາ)',
        'America/Glace_Bay' => 'ເວລາຂອງອາແລນຕິກ (ເກລດເບ)',
        'America/Godthab' => 'ເວລາ ກຣີນແລນ (ນູກ)',
        'America/Nuuk' => 'ເວລາ ກຣີນແລນ (ນູກ)',
        'America/Goose_Bay' => 'ເວລາຂອງອາແລນຕິກ (ກູສເບ)',
        'America/Grand_Turk' => 'ເວລາຕາເວັນອອກ (ແກຣນ ເທີກ)',
        'America/Grenada' => 'ເວລາຂອງອາແລນຕິກ (ເກຣນາດາ)',
        'America/Guadeloupe' => 'ເວລາຂອງອາແລນຕິກ (ກາວເດລູບ)',
        'America/Guatemala' => 'ເວລາກາງ (ກົວເຕມາລາ)',
        'America/Guayaquil' => 'ເວ​ລາ​ເອ​ກົວ​ດໍ (ກົວຢາກິລ)',
        'America/Guyana' => 'ເວລາກາຍອານາ (ກູຢານາ)',
        'America/Halifax' => 'ເວລາຂອງອາແລນຕິກ (ຮາລິແຟັກ)',
        'America/Havana' => 'ເວລາຄິວບາ (ຮາວານາ)',
        'America/Hermosillo' => 'ເວລາແປຊິຟິກເມັກຊິກັນ (ເອໂມຊິໂຢ)',
        'America/Indiana/Knox' => 'ເວລາກາງ (ນ໋ອກ, ອິນເດຍນາ)',
        'America/Indiana/Marengo' => 'ເວລາຕາເວັນອອກ (ມາເຣນໂກ, ອິນເດຍນາ)',
        'America/Indiana/Petersburg' => 'ເວລາຕາເວັນອອກ (ປີເຕີສເປີກ, ອິນເດຍນາ)',
        'America/Indiana/Tell_City' => 'ເວລາກາງ (ເທວ ຊິຕີ, ອິນເດຍນາ)',
        'America/Indiana/Vevay' => 'ເວລາຕາເວັນອອກ (ວີເວ, ອິນເດຍນາ)',
        'America/Indiana/Vincennes' => 'ເວລາຕາເວັນອອກ (ວິນເຊນເນສ, ອິນເດຍນາ)',
        'America/Indiana/Winamac' => 'ເວລາຕາເວັນອອກ (ວິນາແມັກ, ອິນເດຍນາ)',
        'America/Indianapolis' => 'ເວລາຕາເວັນອອກ (ອິນດີເອນາໂພລິສ)',
        'America/Indiana/Indianapolis' => 'ເວລາຕາເວັນອອກ (ອິນດີເອນາໂພລິສ)',
        'America/Inuvik' => 'ເວລາແຖບພູເຂົາ (ອີນູວິກ)',
        'America/Iqaluit' => 'ເວລາຕາເວັນອອກ (ອີກົວລິດ)',
        'America/Jamaica' => 'ເວລາຕາເວັນອອກ (ຈາໄມກາ)',
        'America/Jujuy' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຈູຈຸຍ)',
        'America/Argentina/Jujuy' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ຈູຈຸຍ)',
        'America/Juneau' => 'ເວລາອະລັສກາ (ຈູໂນ)',
        'America/Kentucky/Monticello' => 'ເວລາຕາເວັນອອກ (ມອນຕີເຊວໂລ, ເຄນທັກກີ)',
        'America/Kralendijk' => 'ເວລາຂອງອາແລນຕິກ (ຄຣາເລນດິກ)',
        'America/La_Paz' => 'ເວ​ລາ​ໂບ​ລິ​ເວຍ (ລາປາສ)',
        'America/Lima' => 'ເວ​ລາ​ເປ​ຣູ (ລີມາ)',
        'America/Los_Angeles' => 'ເວລາແປຊິຟິກ (ລອສແອນເຈລີສ)',
        'America/Louisville' => 'ເວລາຕາເວັນອອກ (ຫລຸຍວິວ)',
        'America/Kentucky/Louisville' => 'ເວລາຕາເວັນອອກ (ຫລຸຍວິວ)',
        'America/Lower_Princes' => 'ເວລາຂອງອາແລນຕິກ (ໂລເວີ ພຣິນຊ໌ ຄວດເຕີ)',
        'America/Maceio' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ມາເຊໂອ)',
        'America/Managua' => 'ເວລາກາງ (ມານາກົວ)',
        'America/Manaus' => 'ເວລາຕາມເຂດອາເມຊອນ (ມາເນົາສ໌)',
        'America/Marigot' => 'ເວລາຂອງອາແລນຕິກ (ມາຣີໂກດ)',
        'America/Martinique' => 'ເວລາຂອງອາແລນຕິກ (ມາທີນິກ)',
        'America/Matamoros' => 'ເວລາກາງ (ມາຕາໂມຣອສ)',
        'America/Mazatlan' => 'ເວລາແປຊິຟິກເມັກຊິກັນ (ມາຊາດລານ)',
        'America/Mendoza' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ເມັນໂດຊ່າ)',
        'America/Argentina/Mendoza' => 'ເວ​ລາ​ອາ​ເຈ​ທິ​ນາ (ເມັນໂດຊ່າ)',
        'America/Menominee' => 'ເວລາກາງ (ເມໂນມິນີ)',
        'America/Merida' => 'ເວລາກາງ (ເມີຣິດາ)',
        'America/Metlakatla' => 'ເວລາອະລັສກາ (ເມັດລາກັດລາ)',
        'America/Mexico_City' => 'ເວລາກາງ (ເມັກຊິໂກ ຊິຕີ)',
        'America/Miquelon' => '​ເວ​ລາເຊນ​ປີ​ແອ ແລະ​ມິ​ກົວ​ລອນ (ມິກົວລອນ)',
        'America/Moncton' => 'ເວລາຂອງອາແລນຕິກ (ມອນຕັນ)',
        'America/Monterrey' => 'ເວລາກາງ (ມອນເຕີເຣຍ)',
        'America/Montevideo' => '​ເວ​ລາ​ອູ​ຣູ​ກວຍ (ມອນເຕວິເດໂອ)',
        'America/Montserrat' => 'ເວລາຂອງອາແລນຕິກ (ມອນເຊີຣັດ)',
        'America/Nassau' => 'ເວລາຕາເວັນອອກ (ແນສຊໍ)',
        'America/New_York' => 'ເວລາຕາເວັນອອກ (ນິວຢອກ)',
        'America/Nome' => 'ເວລາອະລັສກາ (ນອມ)',
        'America/Noronha' => 'ເວລາເຟນັນໂດເດໂນຮອນຮາ (ນໍຣອນຮາ)',
        'America/North_Dakota/Beulah' => 'ເວລາກາງ (ເບີລາ, ນອດ ດາໂກຕາ)',
        'America/North_Dakota/Center' => 'ເວລາກາງ (ເຊັນເຈີ, ນອດ ດາໂກຕາ)',
        'America/North_Dakota/New_Salem' => 'ເວລາກາງ (ນິວ ຊາເລມ, ນອດ ດາໂກຕາ)',
        'America/Ojinaga' => 'ເວລາກາງ (ໂອຈິນາກາ)',
        'America/Panama' => 'ເວລາຕາເວັນອອກ (ພານາມາ)',
        'America/Paramaribo' => 'ເວ​ລາ​ຊຸ​ຣິ​ນາມ (ພາຣາມາຣິໂບ)',
        'America/Phoenix' => 'ເວລາແຖບພູເຂົາ (ຟິນິກ)',
        'America/Port-au-Prince' => 'ເວລາຕາເວັນອອກ (ປໍໂຕແປຣງ)',
        'America/Port_of_Spain' => 'ເວລາຂອງອາແລນຕິກ (ພອດອອບສະເປນ)',
        'America/Porto_Velho' => 'ເວລາຕາມເຂດອາເມຊອນ (ປໍຕູ ເວວຢູ)',
        'America/Puerto_Rico' => 'ເວລາຂອງອາແລນຕິກ (ເປີໂທຣິໂກ)',
        'America/Punta_Arenas' => 'ເວ​ລາ​ຊິ​ລີ (ພຸນທາ ອະຣີນາສ໌)',
        'America/Rankin_Inlet' => 'ເວລາກາງ (ແຣນກິນ ອິນເລັດ)',
        'America/Recife' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ເຣຊິເຟ)',
        'America/Regina' => 'ເວລາກາງ (ເຣຈິນາ)',
        'America/Resolute' => 'ເວລາກາງ (ເຣໂຊລຸດ)',
        'America/Rio_Branco' => 'ເວລາຂອງອາເກຣ (ຣິໂອ ບຣັນໂກ)',
        'America/Santarem' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ຊັນຕາເຣມ)',
        'America/Santiago' => 'ເວ​ລາ​ຊິ​ລີ (ຊັນຕີອາໂກ)',
        'America/Santo_Domingo' => 'ເວລາຂອງອາແລນຕິກ (ຊານໂຕໂດມິນໂກ)',
        'America/Sao_Paulo' => 'ເວລາຕາມເຂດບຣາຊິເລຍ (ເຊົາ ເປົາໂລ)',
        'America/Scoresbysund' => 'ເວລາ ກຣີນແລນ (ອິໂຕຄໍທົວມິດ)',
        'America/Sitka' => 'ເວລາອະລັສກາ (ຊິດກາ)',
        'America/St_Barthelemy' => 'ເວລາຂອງອາແລນຕິກ (ເຊນບາເທເລມີ)',
        'America/St_Johns' => 'ເວ​ລາ​ນິວ​ຟາວ​ແລນ (ເຊນ ຈອນ)',
        'America/St_Kitts' => 'ເວລາຂອງອາແລນຕິກ (ເຊນ ຄິດສ໌)',
        'America/St_Lucia' => 'ເວລາຂອງອາແລນຕິກ (ເຊນ ລູເຊຍ)',
        'America/St_Thomas' => 'ເວລາຂອງອາແລນຕິກ (ເຊນ ໂທມັສ)',
        'America/St_Vincent' => 'ເວລາຂອງອາແລນຕິກ (ເຊນ ວິນເຊນ)',
        'America/Swift_Current' => 'ເວລາກາງ (ສະວິຟ ເຄີເຣນ)',
        'America/Tegucigalpa' => 'ເວລາກາງ (ເຕກູຊີການປາ)',
        'America/Thule' => 'ເວລາຂອງອາແລນຕິກ (ທູເລ)',
        'America/Tijuana' => 'ເວລາແປຊິຟິກ (ທີຈົວນາ)',
        'America/Toronto' => 'ເວລາຕາເວັນອອກ (ໂທຣອນໂຕ)',
        'America/Tortola' => 'ເວລາຂອງອາແລນຕິກ (ທໍໂຕລາ)',
        'America/Vancouver' => 'ເວລາແປຊິຟິກ (ແວນຄູເວີ)',
        'America/Whitehorse' => 'ເວລາຢູຄອນ (ໄວທ໌ຮອສ)',
        'America/Winnipeg' => 'ເວລາກາງ (ວິນນີເພກ)',
        'America/Yakutat' => 'ເວລາອະລັສກາ (ຢາຄູຕັດ)',
        'Antarctica/Casey' => 'ເວ​ລາ​ອອສ​ເຕຣ​ເລຍ​ຕາ​ເວັນ​ຕົກ (ເຄຊີ)',
        'Antarctica/Davis' => 'ເວລາເດວິດ (ດາວີສ)',
        'Antarctica/DumontDUrville' => 'ເວລາດູມອງດູວິລ (ດູມອນດີຍູວີວສ໌)',
        'Antarctica/Macquarie' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ແມັກຄົວຣີ)',
        'Antarctica/Mawson' => 'ເວລາມໍສັນ (ເມົາຊັນ)',
        'Antarctica/McMurdo' => 'ເວ​ລາ​ນິວ​ຊີ​ແລນ (ແມັກມົວໂດ)',
        'Antarctica/Palmer' => 'ເວ​ລາ​ຊິ​ລີ (ພາມເມີ)',
        'Antarctica/Rothera' => 'ເວລາ ໂຣທີຕາ (ໂຣເທຣາ)',
        'Antarctica/Syowa' => 'ເວລາ ໂຊວາ (ເຊຍວາ)',
        'Antarctica/Troll' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ໂທຣລ໌)',
        'Antarctica/Vostok' => 'ເວລາ ວອສໂຕກ (ວໍສະຕອກ)',
        'Arctic/Longyearbyen' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ລອງເຢຍບຽນ)',
        'Asia/Aden' => 'ເວ​ລາ​ອາ​ຣາ​ບຽນ (ເອເດັນ)',
        'Asia/Almaty' => 'ເວລາຄາຊັກສຖານ (ອໍມາຕີ)',
        'Asia/Amman' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ອຳມານ)',
        'Asia/Anadyr' => 'ເວລາ ຣັດເຊຍ (ອານາດີ)',
        'Asia/Aqtau' => 'ເວລາຄາຊັກສຖານ (ອັດຕາອູ)',
        'Asia/Aqtobe' => 'ເວລາຄາຊັກສຖານ (ອັດໂທບີ)',
        'Asia/Ashgabat' => 'ເວລາຕວກເມນິສຖານ (ອາດຊ໌ກາບັດ)',
        'Asia/Atyrau' => 'ເວລາຄາຊັກສຖານ (ອັດທີເຣົາ)',
        'Asia/Baghdad' => 'ເວ​ລາ​ອາ​ຣາ​ບຽນ (ແບກແດດ)',
        'Asia/Bahrain' => 'ເວ​ລາ​ອາ​ຣາ​ບຽນ (ບາເຣນ)',
        'Asia/Baku' => 'ເວລາອັສເຊີໄບຈັນ (ບາກູ)',
        'Asia/Bangkok' => 'ເວລາອິນດູຈີນ (ບາງກອກ)',
        'Asia/Barnaul' => 'ເວ​ລາ​ຄຣັສ​ໂນ​ຢາ​ສ​ຄ໌ (ບານົວ)',
        'Asia/Beirut' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ເບຣຸດ)',
        'Asia/Bishkek' => 'ເວລາເຄຍກິສຖານ (ບິດຊ໌ເຄກ)',
        'Asia/Brunei' => '​ເວ​ລາບຣູ​ໄນດາ​ຣຸສ​ຊາ​ລາມ (ບຣູໄນ)',
        'Asia/Calcutta' => 'ເວລາ ອິນເດຍ (ໂກລກາຕາ)',
        'Asia/Kolkata' => 'ເວລາ ອິນເດຍ (ໂກລກາຕາ)',
        'Asia/Chita' => 'ເວລາຢາກູດສ (ຊີຕ່າ)',
        'Asia/Colombo' => 'ເວລາ ອິນເດຍ (ໂຄລຳໂບ)',
        'Asia/Damascus' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ດາມາສຄັສ)',
        'Asia/Dhaka' => 'ເວລາ ບັງກະລາເທດ (ດາຫ໌ກາ)',
        'Asia/Dili' => 'ເວລາຕີມໍຕາເວັນອອກ (ດີລີ)',
        'Asia/Dubai' => 'ເວ​ລາ​ກູ​ລ​໌ຟ (ດູໄບ)',
        'Asia/Dushanbe' => 'ເວລາທາຈິກິສຖານ (ດູຊານເບ)',
        'Asia/Famagusta' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ຟາມາກັສທາ)',
        'Asia/Gaza' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ກາຊາ)',
        'Asia/Hebron' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ເຮບຣອນ)',
        'Asia/Hong_Kong' => 'ເວ​ລາ​ຮອງ​ກົງ (ຮ່ອງກົງ)',
        'Asia/Hovd' => 'ເວ​ລາ​ຮອບ​ດ໌',
        'Asia/Irkutsk' => 'ເວ​ລ​າອີ​ຄຸດ​ສ​ຄ໌ (ອີຄຸສຄ໌)',
        'Asia/Jakarta' => 'ເວ​ລາ​ອິນ​ໂດ​ເນ​ເຊຍ​ຕາ​ເວັນ​ຕົກ (ຈາກາຕາ)',
        'Asia/Jayapura' => 'ເວ​ລາ​ອິນ​ໂດ​ເນ​ເຊຍ​ຕາ​ເວັນ​ອອກ (ຈາຢາປູຣະ)',
        'Asia/Jerusalem' => 'ເວ​ລາ​ອິ​ສ​ຣາ​ເອວ (ເຢຣູຊາເລມ)',
        'Asia/Kabul' => 'ເວລາ ອັຟການິສຖານ (ຄາບູ)',
        'Asia/Kamchatka' => 'ເວລາ ຣັດເຊຍ (ຄາມຊາດກາ)',
        'Asia/Karachi' => 'ເວ​ລາ​ປາ​ກີສຖານ (ກາຣາຈີ)',
        'Asia/Katmandu' => '​ເວ​ລາ​ເນ​ປານ (ຄັດມັນດູ)',
        'Asia/Kathmandu' => '​ເວ​ລາ​ເນ​ປານ (ຄັດມັນດູ)',
        'Asia/Khandyga' => 'ເວລາຢາກູດສ (ແຄນດີກາ)',
        'Asia/Krasnoyarsk' => 'ເວ​ລາ​ຄຣັສ​ໂນ​ຢາ​ສ​ຄ໌ (ຄຣັສໂນຢາສຄ໌)',
        'Asia/Kuala_Lumpur' => 'ເວ​ລາ​ມາ​ເລ​ເຊຍ (ກົວລາລຳເປີ)',
        'Asia/Kuching' => 'ເວ​ລາ​ມາ​ເລ​ເຊຍ (ກູຊີງ)',
        'Asia/Kuwait' => 'ເວ​ລາ​ອາ​ຣາ​ບຽນ (ຄູເວດ)',
        'Asia/Macau' => 'ເວ​ລາ​ຈີນ (ມາເກົາ)',
        'Asia/Magadan' => 'ເວລາເມັກກາເດນ (ມາກາແດນ)',
        'Asia/Makassar' => 'ເວ​ລາ​ອິນ​ໂດ​ເນ​ເຊຍ​ກາງ (ມາກາສຊາ)',
        'Asia/Manila' => '​ເວ​ລາ​ຟິ​ລິບ​ປິນ (ມານີລາ)',
        'Asia/Muscat' => 'ເວ​ລາ​ກູ​ລ​໌ຟ (ມາສຄັດ)',
        'Asia/Nicosia' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ນິໂຄເຊຍ)',
        'Asia/Novokuznetsk' => 'ເວ​ລາ​ຄຣັສ​ໂນ​ຢາ​ສ​ຄ໌ (ໂນໂວຄຸສເນັດ)',
        'Asia/Novosibirsk' => 'ເວ​ລາ​ຄຣັສ​ໂນ​ຢາ​ສ​ຄ໌ (ໂນໂວຊີບີສຄ໌)',
        'Asia/Omsk' => '​ເວ​ລາອອມ​ສ​ຄ໌ (ອອມສຄ໌)',
        'Asia/Oral' => 'ເວລາຄາຊັກສຖານ (ອໍຣໍ)',
        'Asia/Phnom_Penh' => 'ເວລາອິນດູຈີນ (ພະນົມເປັນ)',
        'Asia/Pontianak' => 'ເວ​ລາ​ອິນ​ໂດ​ເນ​ເຊຍ​ຕາ​ເວັນ​ຕົກ (ພອນເທຍນັກ)',
        'Asia/Pyongyang' => 'ເວລາເກົາຫຼີ (ປຽງຢາງ)',
        'Asia/Qatar' => 'ເວ​ລາ​ອາ​ຣາ​ບຽນ (ກາຕາຣ໌)',
        'Asia/Qostanay' => 'ເວລາຄາຊັກສຖານ (ຄອສຕາເນ)',
        'Asia/Qyzylorda' => 'ເວລາຄາຊັກສຖານ (ໄຄຊີລໍດາ)',
        'Asia/Rangoon' => 'ເວລາມຽນມາ (ຢາງກອນ)',
        'Asia/Yangon' => 'ເວລາມຽນມາ (ຢາງກອນ)',
        'Asia/Riyadh' => 'ເວ​ລາ​ອາ​ຣາ​ບຽນ (ຣີຢາດ)',
        'Asia/Saigon' => 'ເວລາອິນດູຈີນ (ໂຮຈິມິນ)',
        'Asia/Ho_Chi_Minh' => 'ເວລາອິນດູຈີນ (ໂຮຈິມິນ)',
        'Asia/Sakhalin' => 'ເວລາເມັກກາເດນ (ຊາຄາລິນ)',
        'Asia/Samarkand' => 'ເວລາອຸສເບກິດສະຖານ (ຊາມາແຄນ)',
        'Asia/Seoul' => 'ເວລາເກົາຫຼີ (ໂຊລ໌)',
        'Asia/Shanghai' => 'ເວ​ລາ​ຈີນ (ຊ່ຽງໄຮ້)',
        'Asia/Singapore' => 'ເວ​ລາ​ສິງ​ກະ​ໂປ (ສິງກະໂປ)',
        'Asia/Srednekolymsk' => 'ເວລາເມັກກາເດນ (ສຣິລເນັກໂກລີດ)',
        'Asia/Taipei' => 'ເວ​ລາ​ໄທ​ເປ (ໄທເປ)',
        'Asia/Tashkent' => 'ເວລາອຸສເບກິດສະຖານ (ທາດສ໌ເຄນ)',
        'Asia/Tbilisi' => 'ເວລາຈໍເຈຍ (ທິບີລີຊີ)',
        'Asia/Tehran' => 'ເວ​ລາ​ອີ​ຣານ (ເຕຣານ)',
        'Asia/Thimphu' => 'ເວ​ລາ​ພູ​ຖານ (ທິມພູ)',
        'Asia/Tokyo' => 'ເວ​ລາ​ຍີ່​ປຸ່ນ (ໂຕກຽວ)',
        'Asia/Tomsk' => 'ເວ​ລາ​ຄຣັສ​ໂນ​ຢາ​ສ​ຄ໌ (ທອມສກ໌)',
        'Asia/Ulaanbaatar' => 'ເວລາ ອູລານບາເຕີ (ອູລານບາຕາຣ໌)',
        'Asia/Urumqi' => 'ເວລາ ຈີນ (ອູຣຸມຊີ)',
        'Asia/Ust-Nera' => 'ເວລາລາດີໂວສຕົກ (ອຸສ ເນຣາ)',
        'Asia/Vientiane' => 'ເວລາອິນດູຈີນ (ວຽງຈັນ)',
        'Asia/Vladivostok' => 'ເວລາລາດີໂວສຕົກ (ວີລາດິໂວສຕອກ)',
        'Asia/Yakutsk' => 'ເວລາຢາກູດສ (ຢາຄຸທຊ໌)',
        'Asia/Yekaterinburg' => 'ເວລາເຢກາເຕລິນເບີກ (ເຢຄາເຕີຣິນເບີກ)',
        'Asia/Yerevan' => 'ເວລາອາເມເນຍ (ເຍເຣວານ)',
        'Atlantic/Azores' => 'ເວ​ລາ​ອາ​ໂຊ​ເຣ​ສ',
        'Atlantic/Bermuda' => 'ເວລາຂອງອາແລນຕິກ (ເບີມິວດາ)',
        'Atlantic/Canary' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ຕົກ (ຄານາຣີ)',
        'Atlantic/Cape_Verde' => 'ເວ​ລາ​ເຄບ​ເວີດ (ເຄບເວີດ)',
        'Atlantic/Faeroe' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ຕົກ (ແຟໂຣ)',
        'Atlantic/Faroe' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ຕົກ (ແຟໂຣ)',
        'Atlantic/Madeira' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ຕົກ (ມາເດຣາ)',
        'Atlantic/Reykjavik' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ເຣກຢາວິກ)',
        'Atlantic/South_Georgia' => 'ເວລາຈໍເຈຍໃຕ້ (ເຊົາຈໍເຈຍ)',
        'Atlantic/St_Helena' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ເຊນ ເຮເລນາ)',
        'Atlantic/Stanley' => '​ເວ​ລາ​ໝູ່​ເກາະ​ຟອ​ລ໌ກ​ແລນ (ສະແຕນເລ)',
        'Australia/Adelaide' => 'ເວ​ລາອອ​ສ​ເຕຣ​ເລຍ​ກາງ (ເອດີແລດ)',
        'Australia/Brisbane' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ບຣິສເບນ)',
        'Australia/Broken_Hill' => 'ເວ​ລາອອ​ສ​ເຕຣ​ເລຍ​ກາງ (ໂບຣກເຄນ ຮິວ)',
        'Australia/Darwin' => 'ເວ​ລາອອ​ສ​ເຕຣ​ເລຍ​ກາງ (ດາວິນ)',
        'Australia/Eucla' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ກາງ​ຕາ​ເວັນ​ຕົກ (ຢູຄລາ)',
        'Australia/Hobart' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ໂຮບາດ)',
        'Australia/Lindeman' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ລິນດີແມນ)',
        'Australia/Lord_Howe' => 'ເວ​ລາ​ລອດ​ເຮົາ (ໂລດໂຮວີ)',
        'Australia/Melbourne' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ເມວເບິນ)',
        'Australia/Perth' => 'ເວ​ລາ​ອອສ​ເຕຣ​ເລຍ​ຕາ​ເວັນ​ຕົກ (ເພີດ)',
        'Australia/Sydney' => 'ເວ​ລາອອສ​ເຕຣ​ລຽນ​ຕາ​ເວັນ​ອອກ (ຊິດນີ)',
        'Etc/GMT' => 'ເວ​ລາກຣີນ​ວິ​ຊ',
        'Etc/UTC' => 'ເວລາສາກົນເຊີງພິກັດ',
        'Europe/Amsterdam' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ອາມສເຕີດຳ)',
        'Europe/Andorra' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ອິນດໍຣາ)',
        'Europe/Astrakhan' => 'ເວລາ ຣັດເຊຍ (ອາສຕຣາຄານ)',
        'Europe/Athens' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ເອເທນສ໌)',
        'Europe/Belgrade' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ເບວເກຣດ)',
        'Europe/Berlin' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ເບີລິນ)',
        'Europe/Bratislava' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ບຣາທິສລາວາ)',
        'Europe/Brussels' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ບຣັສເຊວ)',
        'Europe/Bucharest' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ບູຄາເຣສຕ໌)',
        'Europe/Budapest' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ບູດາເປສຕ໌)',
        'Europe/Busingen' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ບັດຊິນເກນ)',
        'Europe/Chisinau' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ຄີຊີເນົາ)',
        'Europe/Copenhagen' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ໂຄເປນເຮເກນ)',
        'Europe/Dublin' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ດັບບລິນ)',
        'Europe/Gibraltar' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ກິບຣອລທາ)',
        'Europe/Guernsey' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ເກີນຊີ)',
        'Europe/Helsinki' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ເຮວຊິນກິ)',
        'Europe/Isle_of_Man' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ເກາະແມນ)',
        'Europe/Istanbul' => 'ເວລາ ເທີຄີ (ອິສຕັນບູລ໌)',
        'Europe/Jersey' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ເຈີຊີ)',
        'Europe/Kaliningrad' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ຄາລິນິນກຣາດ)',
        'Europe/Kiev' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ຂຽບ)',
        'Europe/Kyiv' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ຂຽບ)',
        'Europe/Kirov' => 'ເວ​ລາ​ມອ​ສ​ໂຄ (ກິໂຣບ)',
        'Europe/Lisbon' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ຕົກ (ລິສບອນ)',
        'Europe/Ljubljana' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ລູບລີຍານາ)',
        'Europe/London' => 'ເວ​ລາກຣີນ​ວິ​ຊ (ລອນດອນ)',
        'Europe/Luxembourg' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ລັກເຊັມເບີກ)',
        'Europe/Madrid' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ມາດຣິດ)',
        'Europe/Malta' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ມອລຕາ)',
        'Europe/Mariehamn' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ມາຣີແຮມນ໌)',
        'Europe/Minsk' => 'ເວ​ລາ​ມອ​ສ​ໂຄ (ມິນສກ໌)',
        'Europe/Monaco' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ໂມນາໂຄ)',
        'Europe/Moscow' => 'ເວ​ລາ​ມອ​ສ​ໂຄ (ມອສໂຄ)',
        'Europe/Oslo' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ອອສໂລ)',
        'Europe/Paris' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ປາຣີສ)',
        'Europe/Podgorica' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ພອດກໍຣີກາ)',
        'Europe/Prague' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ປຣາກ)',
        'Europe/Riga' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ຣິກາ)',
        'Europe/Rome' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ໂຣມ)',
        'Europe/Samara' => 'ເວລາ ຣັດເຊຍ (ຊາມາຣາ)',
        'Europe/San_Marino' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ຊານມາຣີໂນ)',
        'Europe/Sarajevo' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ຊາຣາເຢໂວ)',
        'Europe/Saratov' => 'ເວລາ ຣັດເຊຍ (ຊາຣາທອບ)',
        'Europe/Simferopol' => 'ເວ​ລາ​ມອ​ສ​ໂຄ (ຊີມເຟໂລໂປ)',
        'Europe/Skopje' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ສະໂກເປຍ)',
        'Europe/Sofia' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ໂຊເຟຍ)',
        'Europe/Stockholm' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ສະຕອກໂຮມ)',
        'Europe/Tallinn' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ທາລລິນນ໌)',
        'Europe/Tirane' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ທິຣານ)',
        'Europe/Ulyanovsk' => 'ເວລາ ຣັດເຊຍ (ອູລີອານອບສຄ໌)',
        'Europe/Vaduz' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ວາດາຊ)',
        'Europe/Vatican' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ວາຕິກັນ)',
        'Europe/Vienna' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ວຽນນາ)',
        'Europe/Vilnius' => 'ເວ​ລາ​ຢູ​ໂຣບ​ຕາ​ເວັນ​ອອກ (ວິລນິອຸສ)',
        'Europe/Volgograd' => 'ເວ​ລາ​ມອ​ສ​ໂຄ (ວອລໂກກຣາດ)',
        'Europe/Warsaw' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ວໍຊໍ)',
        'Europe/Zagreb' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ຊາເກຣບ)',
        'Europe/Zurich' => 'ເວ​ລາ​ຢູ​ໂຣບ​ກາງ (ຊູຣິກ)',
        'Indian/Antananarivo' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ອັນຕານານາຣິໂວ)',
        'Indian/Chagos' => 'ເວລາມະຫາສະຫມຸດອິນເດຍ (ຊາໂກສ)',
        'Indian/Christmas' => 'ເວ​ລາ​ເກາະ​ຄ​ຣິສ​ມາສ (ຄຣິດສະມາດ)',
        'Indian/Cocos' => 'ເວລາຫມູ່ເກາະໂກໂກສ (ໂຄໂຄສ)',
        'Indian/Comoro' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ໂຄໂມໂຣ)',
        'Indian/Kerguelen' => 'ເວລາຝຣັ່ງຕອນໃຕ້ ແລະ ແອນຕາກຕິກ (ແກເກີເລນ)',
        'Indian/Mahe' => 'ເວ​ລາ​ເຊ​ເຊ​ລ​ສ໌ (ມາເຮ)',
        'Indian/Maldives' => 'ເວລາມັລດີຟ',
        'Indian/Mauritius' => 'ເວ​ລາ​ມົວຣິ​ຊຽ​ສ (ເມົາຣິທຽສ)',
        'Indian/Mayotte' => 'ເວ​ລາ​ອາ​ຟຣິ​ກາ​ຕາ​ເວັນ​ອອກ (ມາຢັອດເຕ)',
        'Indian/Reunion' => 'ເວ​ລາ​ເຣ​ອູ​ນິ​ຢົງ (ເຣອູນິຢົງ)',
        'Pacific/Apia' => 'ເວລາເອເພຍ (ເອປີອາ)',
        'Pacific/Auckland' => 'ເວ​ລາ​ນິວ​ຊີ​ແລນ (ອັກແລນ)',
        'Pacific/Bougainville' => 'ເວລາປາປົວກິນີ (ເວລາຕາມເຂດບູນກຽນວິວ)',
        'Pacific/Chatham' => 'ເວ​ລາ​ຊາ​ທາມ (ແຊແທມ)',
        'Pacific/Easter' => 'ເວ​ລາ​ເກາະ​ອີ​ສ​ເຕີ (ເອສເຕີ)',
        'Pacific/Efate' => 'ເວລາວານູອາຕູ (ເອຟາເຕ)',
        'Pacific/Enderbury' => 'ເວລາຫມູ່ເກາະຟີນິກ (ແຄນຕອນ)',
        'Pacific/Kanton' => 'ເວລາຫມູ່ເກາະຟີນິກ (ແຄນຕອນ)',
        'Pacific/Fakaofo' => 'ເວລາໂຕເກເລົາ (ຟາກາວໂຟ)',
        'Pacific/Fiji' => 'ເວລາຟິຈິ (ຟູຈິ)',
        'Pacific/Funafuti' => 'ເວລາຕູວາລູ (ຟູນະຟູຕິ)',
        'Pacific/Galapagos' => 'ເວ​ລາ​ກາ​ລາ​ປາ​ກອ​ສ (ກາລາປາກອສ)',
        'Pacific/Gambier' => 'ເວລາແກມເບຍ',
        'Pacific/Guadalcanal' => 'ເວລາຫມູ່ເກາະໂຊໂລມອນ (ກົວດັລຄະແນລ)',
        'Pacific/Guam' => 'ເວ​ລາ​ຈາ​ໂມ​ໂຣ (ກວມ)',
        'Pacific/Honolulu' => 'ເວລາມາດຕະຖານຮາວາຍ-ເອລູທຽນ (ໂຮໂນລູລູ)',
        'Pacific/Kiritimati' => 'ເວ​ລາ​ໝູ່​ເກາະ​ລາຍ (ຄີຣິທີມາຕີ)',
        'Pacific/Kosrae' => 'ເວລາຄອສແຣ (ຄໍສແຣ)',
        'Pacific/Kwajalein' => 'ເວ​ລາ​ໝູ່​ເກາະ​ມາ​ແຊວ (ຄວາຈາເລນ)',
        'Pacific/Majuro' => 'ເວ​ລາ​ໝູ່​ເກາະ​ມາ​ແຊວ (ມາຈູໂຣ)',
        'Pacific/Marquesas' => 'ເວລາມາເຄີຊັສ (ມາຄິວຊາສ)',
        'Pacific/Midway' => 'ເວລາຊາມົວ (ມິດເວ)',
        'Pacific/Nauru' => 'ເວ​ລາ​ນາ​ອູ​ຣຸ (ນາອູຣູ)',
        'Pacific/Niue' => 'ເວລານິອູເອ (ນີອູເອ)',
        'Pacific/Norfolk' => 'ເວ​ລາ​ເກາະ​ນໍ​ຟອ​ລ໌ກ (ນໍຟອລ໌ກ)',
        'Pacific/Noumea' => 'ເວລານິວແຄລິໂດເນຍ (ນູເມອາ)',
        'Pacific/Pago_Pago' => 'ເວລາຊາມົວ (ປາໂກປາໂກ)',
        'Pacific/Palau' => 'ເວລາປາເລົາ',
        'Pacific/Pitcairn' => 'ເວລາພິດແຄຣ໌ນ (ພິດແຄນ)',
        'Pacific/Ponape' => 'ເວລາໂປເນບ (ປົນເປີຍ)',
        'Pacific/Pohnpei' => 'ເວລາໂປເນບ (ປົນເປີຍ)',
        'Pacific/Port_Moresby' => 'ເວລາປາປົວກິນີ (ພອດ ມໍເຣສບີ)',
        'Pacific/Rarotonga' => 'ເວລາຫມູ່ເກາະຄຸກ (ຣາໂຣຕອງກາ)',
        'Pacific/Saipan' => 'ເວ​ລາ​ຈາ​ໂມ​ໂຣ (ໄຊປານ)',
        'Pacific/Tahiti' => 'ເວລາທາຮິຕິ (ທາຮີຕິ)',
        'Pacific/Tarawa' => 'ເວລາຫມູ່ເກາະກິລເບີດ (ຕາຣາວາ)',
        'Pacific/Tongatapu' => 'ເວລາຕອງກາ (ຕອງກາຕາປູ)',
        'Pacific/Truk' => 'ເວລາຊຸກ (ຈັກ)',
        'Pacific/Chuuk' => 'ເວລາຊຸກ (ຈັກ)',
        'Pacific/Wake' => 'ເວລາເກາະເວກ',
        'Pacific/Wallis' => 'ເວລາວາລລິສ ແລະ ຟູຕູນາ (ວາລິດ)',
    ],
    'Meta' => [],
];
