<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'გრინვიჩის საშუალო დრო (აბიჯანი)',
        'Africa/Accra' => 'გრინვიჩის საშუალო დრო (აკრა)',
        'Africa/Addis_Ababa' => 'აღმოსავლეთ აფრიკის დრო (ადის-აბება)',
        'Africa/Algiers' => 'ცენტრალური ევროპის დრო (ალჟირი)',
        'Africa/Asmera' => 'აღმოსავლეთ აფრიკის დრო (ასმარა)',
        'Africa/Asmara' => 'აღმოსავლეთ აფრიკის დრო (ასმარა)',
        'Africa/Bamako' => 'გრინვიჩის საშუალო დრო (ბამაკო)',
        'Africa/Bangui' => 'დასავლეთ აფრიკის დრო (ბანგი)',
        'Africa/Banjul' => 'გრინვიჩის საშუალო დრო (ბანჯული)',
        'Africa/Bissau' => 'გრინვიჩის საშუალო დრო (ბისაუ)',
        'Africa/Blantyre' => 'ცენტრალური აფრიკის დრო (ბლანტირი)',
        'Africa/Brazzaville' => 'დასავლეთ აფრიკის დრო (ბრაზავილი)',
        'Africa/Bujumbura' => 'ცენტრალური აფრიკის დრო (ბუჯუმბურა)',
        'Africa/Cairo' => 'აღმოსავლეთ ევროპის დრო (კაირო)',
        'Africa/Casablanca' => 'დასავლეთ ევროპის დრო (კასაბლანკა)',
        'Africa/Ceuta' => 'ცენტრალური ევროპის დრო (სეუტა)',
        'Africa/Conakry' => 'გრინვიჩის საშუალო დრო (კონაკრი)',
        'Africa/Dakar' => 'გრინვიჩის საშუალო დრო (დაკარი)',
        'Africa/Dar_es_Salaam' => 'აღმოსავლეთ აფრიკის დრო (დარ-ეს-სალამი)',
        'Africa/Djibouti' => 'აღმოსავლეთ აფრიკის დრო (ჯიბუტი)',
        'Africa/Douala' => 'დასავლეთ აფრიკის დრო (დუალა)',
        'Africa/El_Aaiun' => 'დასავლეთ ევროპის დრო (ელ-ააიუნი)',
        'Africa/Freetown' => 'გრინვიჩის საშუალო დრო (ფრიტაუნი)',
        'Africa/Gaborone' => 'ცენტრალური აფრიკის დრო (გაბორონე)',
        'Africa/Harare' => 'ცენტრალური აფრიკის დრო (ჰარარე)',
        'Africa/Johannesburg' => 'სამხრეთ აფრიკის დრო (იოჰანესბურგი)',
        'Africa/Juba' => 'ცენტრალური აფრიკის დრო (ჯუბა)',
        'Africa/Kampala' => 'აღმოსავლეთ აფრიკის დრო (კამპალა)',
        'Africa/Khartoum' => 'ცენტრალური აფრიკის დრო (ხარტუმი)',
        'Africa/Kigali' => 'ცენტრალური აფრიკის დრო (კიგალი)',
        'Africa/Kinshasa' => 'დასავლეთ აფრიკის დრო (კინშასა)',
        'Africa/Lagos' => 'დასავლეთ აფრიკის დრო (ლაგოსი)',
        'Africa/Libreville' => 'დასავლეთ აფრიკის დრო (ლიბრევილი)',
        'Africa/Lome' => 'გრინვიჩის საშუალო დრო (ლომე)',
        'Africa/Luanda' => 'დასავლეთ აფრიკის დრო (ლუანდა)',
        'Africa/Lubumbashi' => 'ცენტრალური აფრიკის დრო (ლუბუმბაში)',
        'Africa/Lusaka' => 'ცენტრალური აფრიკის დრო (ლუსაკა)',
        'Africa/Malabo' => 'დასავლეთ აფრიკის დრო (მალაბო)',
        'Africa/Maputo' => 'ცენტრალური აფრიკის დრო (მაპუტო)',
        'Africa/Maseru' => 'სამხრეთ აფრიკის დრო (მასერუ)',
        'Africa/Mbabane' => 'სამხრეთ აფრიკის დრო (მბაბანე)',
        'Africa/Mogadishu' => 'აღმოსავლეთ აფრიკის დრო (მოგადიშუ)',
        'Africa/Monrovia' => 'გრინვიჩის საშუალო დრო (მონროვია)',
        'Africa/Nairobi' => 'აღმოსავლეთ აფრიკის დრო (ნაირობი)',
        'Africa/Ndjamena' => 'დასავლეთ აფრიკის დრო (ნჯამენა)',
        'Africa/Niamey' => 'დასავლეთ აფრიკის დრო (ნიამეი)',
        'Africa/Nouakchott' => 'გრინვიჩის საშუალო დრო (ნუაკშოტი)',
        'Africa/Ouagadougou' => 'გრინვიჩის საშუალო დრო (უაგადუგუ)',
        'Africa/Porto-Novo' => 'დასავლეთ აფრიკის დრო (პორტო-ნოვო)',
        'Africa/Sao_Tome' => 'გრინვიჩის საშუალო დრო (სენ-ტომე)',
        'Africa/Tripoli' => 'აღმოსავლეთ ევროპის დრო (ტრიპოლი)',
        'Africa/Tunis' => 'ცენტრალური ევროპის დრო (ტუნისი)',
        'Africa/Windhoek' => 'ცენტრალური აფრიკის დრო (ვინდხუკი)',
        'America/Adak' => 'ჰავაისა და ალეუტის დრო (ადაკი)',
        'America/Anchorage' => 'ალასკის დრო (ენქორაჯი)',
        'America/Anguilla' => 'ატლანტიკის ოკეანის დრო (ანგილია)',
        'America/Antigua' => 'ატლანტიკის ოკეანის დრო (ანტიგუა)',
        'America/Araguaina' => 'ბრაზილიის დრო (არაგუაინა)',
        'America/Argentina/La_Rioja' => 'არგენტინის დრო (ლა რიოხა)',
        'America/Argentina/Rio_Gallegos' => 'არგენტინის დრო (რიო გალეგოსი)',
        'America/Argentina/Salta' => 'არგენტინის დრო (სალტა)',
        'America/Argentina/San_Juan' => 'არგენტინის დრო (სან ხუანი)',
        'America/Argentina/San_Luis' => 'არგენტინის დრო (სან-ლუისი)',
        'America/Argentina/Tucuman' => 'არგენტინის დრო (ტუკუმანი)',
        'America/Argentina/Ushuaia' => 'არგენტინის დრო (უშუაია)',
        'America/Aruba' => 'ატლანტიკის ოკეანის დრო (არუბა)',
        'America/Asuncion' => 'პარაგვაის დრო (ასუნსიონი)',
        'America/Bahia' => 'ბრაზილიის დრო (ბაია)',
        'America/Bahia_Banderas' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ბაჰია ბანდერასი)',
        'America/Barbados' => 'ატლანტიკის ოკეანის დრო (ბარბადოსი)',
        'America/Belem' => 'ბრაზილიის დრო (ბელემი)',
        'America/Belize' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ბელიზი)',
        'America/Blanc-Sablon' => 'ატლანტიკის ოკეანის დრო (ბლან-საბლონი)',
        'America/Boa_Vista' => 'ამაზონიის დრო (ბოა ვისტა)',
        'America/Bogota' => 'კოლუმბიის დრო (ბოგოტა)',
        'America/Boise' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (ბუასი)',
        'America/Buenos_Aires' => 'არგენტინის დრო (ბუენოს-აირესი)',
        'America/Argentina/Buenos_Aires' => 'არგენტინის დრო (ბუენოს-აირესი)',
        'America/Cambridge_Bay' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (კემბრიჯ ბეი)',
        'America/Campo_Grande' => 'ამაზონიის დრო (კამპო გრანდე)',
        'America/Cancun' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (კანკუნი)',
        'America/Caracas' => 'ვენესუელის დრო (კარაკასი)',
        'America/Catamarca' => 'არგენტინის დრო (კატამარკა)',
        'America/Argentina/Catamarca' => 'არგენტინის დრო (კატამარკა)',
        'America/Cayenne' => 'საფრანგეთის გვიანის დრო (კაიენა)',
        'America/Cayman' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (კაიმანი)',
        'America/Chicago' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ჩიკაგო)',
        'America/Chihuahua' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ჩიჰუაჰუა)',
        'America/Ciudad_Juarez' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (სიუდად-ხუარესი)',
        'America/Coral_Harbour' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ატიკოკანი)',
        'America/Atikokan' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ატიკოკანი)',
        'America/Cordoba' => 'არგენტინის დრო (კორდობა)',
        'America/Argentina/Cordoba' => 'არგენტინის დრო (კორდობა)',
        'America/Costa_Rica' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (კოსტა-რიკა)',
        'America/Coyhaique' => 'ჩილეს დრო (კოიჰაიკე)',
        'America/Creston' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (კრესტონი)',
        'America/Cuiaba' => 'ამაზონიის დრო (კუიაბა)',
        'America/Curacao' => 'ატლანტიკის ოკეანის დრო (კიურასაო)',
        'America/Danmarkshavn' => 'გრინვიჩის საშუალო დრო (დენმარკშავნი)',
        'America/Dawson' => 'იუკონის დრო (დოუსონი)',
        'America/Dawson_Creek' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (დოუსონ ქრიკი)',
        'America/Denver' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (დენვერი)',
        'America/Detroit' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (დეტროიტი)',
        'America/Dominica' => 'ატლანტიკის ოკეანის დრო (დომინიკა)',
        'America/Edmonton' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (ედმონტონი)',
        'America/Eirunepe' => 'დრო: ბრაზილია (ეირუნეპე)',
        'America/El_Salvador' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (სალვადორი)',
        'America/Fort_Nelson' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (ფორტ-ნელსონი)',
        'America/Fortaleza' => 'ბრაზილიის დრო (ფორტალეზა)',
        'America/Glace_Bay' => 'ატლანტიკის ოკეანის დრო (გლეის ბეი)',
        'America/Godthab' => 'დრო: გრენლანდია (გოდთები)',
        'America/Nuuk' => 'დრო: გრენლანდია (გოდთები)',
        'America/Goose_Bay' => 'ატლანტიკის ოკეანის დრო (გუზ ბეი)',
        'America/Grand_Turk' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (გრანდ-ტურკი)',
        'America/Grenada' => 'ატლანტიკის ოკეანის დრო (გრენადა)',
        'America/Guadeloupe' => 'ატლანტიკის ოკეანის დრო (გვადელუპა)',
        'America/Guatemala' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (გვატემალა)',
        'America/Guayaquil' => 'ეკვადორის დრო (გუაიაკილი)',
        'America/Guyana' => 'გაიანის დრო (გაიანა)',
        'America/Halifax' => 'ატლანტიკის ოკეანის დრო (ჰალიფაქსი)',
        'America/Havana' => 'კუბის დრო (ჰავანა)',
        'America/Hermosillo' => 'მექსიკის წყნარი ოკეანის დრო (ჰერმოსილო)',
        'America/Indiana/Knox' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ნოქსი, ინდიანა)',
        'America/Indiana/Marengo' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (მარენგო, ინდიანა)',
        'America/Indiana/Petersburg' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (პიტერსბურგი, ინდიანა)',
        'America/Indiana/Tell_City' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (თელ სითი, ინდიანა)',
        'America/Indiana/Vevay' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ვივეი, ინდიანა)',
        'America/Indiana/Vincennes' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ვინსენი, ინდიანა)',
        'America/Indiana/Winamac' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (უინემაკი, ინდიანა)',
        'America/Indianapolis' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ინდიანაპოლისი)',
        'America/Indiana/Indianapolis' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ინდიანაპოლისი)',
        'America/Inuvik' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (ინუვიკი)',
        'America/Iqaluit' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (იქალუიტი)',
        'America/Jamaica' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (იამაიკა)',
        'America/Jujuy' => 'არგენტინის დრო (ჯუჯუი)',
        'America/Argentina/Jujuy' => 'არგენტინის დრო (ჯუჯუი)',
        'America/Juneau' => 'ალასკის დრო (ჯუნო)',
        'America/Kentucky/Monticello' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (მონტიჩელო, კენტუკი)',
        'America/Kralendijk' => 'ატლანტიკის ოკეანის დრო (კრალენდიიკი)',
        'America/La_Paz' => 'ბოლივიის დრო (ლა-პაზი)',
        'America/Lima' => 'პერუს დრო (ლიმა)',
        'America/Los_Angeles' => 'ჩრდილოეთ ამერიკის წყნარი ოკეანის დრო (ლოს-ანჯელესი)',
        'America/Louisville' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ლუისვილი)',
        'America/Kentucky/Louisville' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ლუისვილი)',
        'America/Lower_Princes' => 'ატლანტიკის ოკეანის დრო (ლოერ პრინც კვორტერი)',
        'America/Maceio' => 'ბრაზილიის დრო (მასეიო)',
        'America/Managua' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (მანაგუა)',
        'America/Manaus' => 'ამაზონიის დრო (მანაუსი)',
        'America/Marigot' => 'ატლანტიკის ოკეანის დრო (მარიგო)',
        'America/Martinique' => 'ატლანტიკის ოკეანის დრო (მარტინიკი)',
        'America/Matamoros' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (მატამოროსი)',
        'America/Mazatlan' => 'მექსიკის წყნარი ოკეანის დრო (მაზატლანი)',
        'America/Mendoza' => 'არგენტინის დრო (მენდოზა)',
        'America/Argentina/Mendoza' => 'არგენტინის დრო (მენდოზა)',
        'America/Menominee' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (მენომინი)',
        'America/Merida' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (მერიდა)',
        'America/Metlakatla' => 'ალასკის დრო (მეტლაკატლა)',
        'America/Mexico_City' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (მეხიკო)',
        'America/Miquelon' => 'სენ-პიერის და მიკელონის დრო',
        'America/Moncton' => 'ატლანტიკის ოკეანის დრო (მონქტონი)',
        'America/Monterrey' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (მონტერეი)',
        'America/Montevideo' => 'ურუგვაის დრო (მონტევიდეო)',
        'America/Montserrat' => 'ატლანტიკის ოკეანის დრო (მონსერატი)',
        'America/Nassau' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ნასაუ)',
        'America/New_York' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ნიუ-იორკი)',
        'America/Nome' => 'ალასკის დრო (ნომი)',
        'America/Noronha' => 'ფერნანდო-დე-ნორონიას დრო',
        'America/North_Dakota/Beulah' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ბიულა, ჩრდილოეთი დაკოტა)',
        'America/North_Dakota/Center' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ცენტრი, ჩრდილოეთი დაკოტა)',
        'America/North_Dakota/New_Salem' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ნიუ-სალემი, ჩრდილოეთი დაკოტა)',
        'America/Ojinaga' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ოხინაგა)',
        'America/Panama' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (პანამა)',
        'America/Paramaribo' => 'სურინამის დრო (პარამარიბო)',
        'America/Phoenix' => 'ჩრდილოეთ ამერიკის მაუნთინის დრო (ფენიქსი)',
        'America/Port-au-Prince' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (პორტ-ა-პრინსი)',
        'America/Port_of_Spain' => 'ატლანტიკის ოკეანის დრო (პორტ-ოვ-სპეინი)',
        'America/Porto_Velho' => 'ამაზონიის დრო (პორტუ-ველიო)',
        'America/Puerto_Rico' => 'ატლანტიკის ოკეანის დრო (პუერტო-რიკო)',
        'America/Punta_Arenas' => 'ჩილეს დრო (პუნტა-არენასი)',
        'America/Rankin_Inlet' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (რენკინ ინლეტი)',
        'America/Recife' => 'ბრაზილიის დრო (რეციფე)',
        'America/Regina' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (რეჯინა)',
        'America/Resolute' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (რეზოლუტე)',
        'America/Rio_Branco' => 'დრო: ბრაზილია (რიო ბრანკო)',
        'America/Santarem' => 'ბრაზილიის დრო (სანტარემი)',
        'America/Santiago' => 'ჩილეს დრო (სანტიაგო)',
        'America/Santo_Domingo' => 'ატლანტიკის ოკეანის დრო (სანტო-დომინგო)',
        'America/Sao_Paulo' => 'ბრაზილიის დრო (სან-პაულუ)',
        'America/Scoresbysund' => 'დრო: გრენლანდია (სკორსბისუნდი)',
        'America/Sitka' => 'ალასკის დრო (სიტკა)',
        'America/St_Barthelemy' => 'ატლანტიკის ოკეანის დრო (სენ-ბართელემი)',
        'America/St_Johns' => 'ნიუფაუნდლენდის დრო (სენტ-ჯონსი)',
        'America/St_Kitts' => 'ატლანტიკის ოკეანის დრო (სენტ-კიტსი)',
        'America/St_Lucia' => 'ატლანტიკის ოკეანის დრო (სენტ-ლუსია)',
        'America/St_Thomas' => 'ატლანტიკის ოკეანის დრო (სენ-ტომასი)',
        'America/St_Vincent' => 'ატლანტიკის ოკეანის დრო (სენ-ვინსენტი)',
        'America/Swift_Current' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (სვიფტ კარენტი)',
        'America/Tegucigalpa' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (ტეგუჩიგალპა)',
        'America/Thule' => 'ატლანტიკის ოკეანის დრო (თულე)',
        'America/Tijuana' => 'ჩრდილოეთ ამერიკის წყნარი ოკეანის დრო (ტიხუანა)',
        'America/Toronto' => 'ჩრდილოეთ ამერიკის აღმოსავლეთის დრო (ტორონტო)',
        'America/Tortola' => 'ატლანტიკის ოკეანის დრო (ტორტოლა)',
        'America/Vancouver' => 'ჩრდილოეთ ამერიკის წყნარი ოკეანის დრო (ვანკუვერი)',
        'America/Whitehorse' => 'იუკონის დრო (უაითჰორსი)',
        'America/Winnipeg' => 'ჩრდილოეთ ამერიკის ცენტრალური დრო (უინიპეგი)',
        'America/Yakutat' => 'ალასკის დრო (იაკუტატი)',
        'Antarctica/Casey' => 'დასავლეთ ავსტრალიის დრო (კეისი)',
        'Antarctica/Davis' => 'დევისის დრო',
        'Antarctica/DumontDUrville' => 'დუმონ-დურვილის დრო (დიუმონ დ’ურვილი)',
        'Antarctica/Macquarie' => 'აღმოსავლეთ ავსტრალიის დრო (მექვორი)',
        'Antarctica/Mawson' => 'მოუსონის დრო',
        'Antarctica/McMurdo' => 'ახალი ზელანდიის დრო (მაკმურდო)',
        'Antarctica/Palmer' => 'ჩილეს დრო (პალმერი)',
        'Antarctica/Rothera' => 'როთერის დრო (როთერა)',
        'Antarctica/Syowa' => 'სიოვას დრო (სიოუა)',
        'Antarctica/Troll' => 'გრინვიჩის საშუალო დრო (ტროლი)',
        'Antarctica/Vostok' => 'ვოსტოკის დრო',
        'Arctic/Longyearbyen' => 'ცენტრალური ევროპის დრო (ლონგირბიენი)',
        'Asia/Aden' => 'არაბეთის დრო (ადენი)',
        'Asia/Almaty' => 'ყაზახეთის დრო (ალმატი)',
        'Asia/Amman' => 'აღმოსავლეთ ევროპის დრო (ამანი)',
        'Asia/Anadyr' => 'დრო: რუსეთი (ანადირი)',
        'Asia/Aqtau' => 'ყაზახეთის დრო (აქტაუ)',
        'Asia/Aqtobe' => 'ყაზახეთის დრო (აქტობე)',
        'Asia/Ashgabat' => 'თურქმენეთის დრო (აშხაბადი)',
        'Asia/Atyrau' => 'ყაზახეთის დრო (ატირაუ)',
        'Asia/Baghdad' => 'არაბეთის დრო (ბაღდადი)',
        'Asia/Bahrain' => 'არაბეთის დრო (ბაჰრეინი)',
        'Asia/Baku' => 'აზერბაიჯანის დრო (ბაქო)',
        'Asia/Bangkok' => 'ინდოჩინეთის დრო (ბანგკოკი)',
        'Asia/Barnaul' => 'კრასნოიარსკის დრო (ბარნაული)',
        'Asia/Beirut' => 'აღმოსავლეთ ევროპის დრო (ბეირუთი)',
        'Asia/Bishkek' => 'ყირგიზეთის დრო (ბიშკეკი)',
        'Asia/Brunei' => 'ბრუნეი-დარუსალამის დრო',
        'Asia/Calcutta' => 'ინდოეთის დრო (კალკუტა)',
        'Asia/Kolkata' => 'ინდოეთის დრო (კალკუტა)',
        'Asia/Chita' => 'იაკუტსკის დრო (ჩიტა)',
        'Asia/Colombo' => 'ინდოეთის დრო (კოლომბო)',
        'Asia/Damascus' => 'აღმოსავლეთ ევროპის დრო (დამასკი)',
        'Asia/Dhaka' => 'ბანგლადეშის დრო (დაკა)',
        'Asia/Dili' => 'აღმოსავლეთ ტიმორის დრო (დილი)',
        'Asia/Dubai' => 'სპარსეთის ყურის სტანდარტული დრო (დუბაი)',
        'Asia/Dushanbe' => 'ტაჯიკეთის დრო (დუშანბე)',
        'Asia/Famagusta' => 'აღმოსავლეთ ევროპის დრო (ფამაგუსტა)',
        'Asia/Gaza' => 'აღმოსავლეთ ევროპის დრო (გაზა)',
        'Asia/Hebron' => 'აღმოსავლეთ ევროპის დრო (ჰებრონი)',
        'Asia/Hong_Kong' => 'ჰონკონგის დრო',
        'Asia/Hovd' => 'ჰოვდის დრო',
        'Asia/Irkutsk' => 'ირკუტსკის დრო',
        'Asia/Jakarta' => 'დასავლეთ ინდონეზიის დრო (ჯაკარტა)',
        'Asia/Jayapura' => 'აღმოსავლეთ ინდონეზიის დრო (ჯაიაპურა)',
        'Asia/Jerusalem' => 'ისრაელის დრო (იერუსალიმი)',
        'Asia/Kabul' => 'ავღანეთის დრო (ქაბული)',
        'Asia/Kamchatka' => 'დრო: რუსეთი (კამჩატკა)',
        'Asia/Karachi' => 'პაკისტანის დრო (კარაჩი)',
        'Asia/Katmandu' => 'ნეპალის დრო (კატმანდუ)',
        'Asia/Kathmandu' => 'ნეპალის დრო (კატმანდუ)',
        'Asia/Khandyga' => 'იაკუტსკის დრო (ხანდიგა)',
        'Asia/Krasnoyarsk' => 'კრასნოიარსკის დრო',
        'Asia/Kuala_Lumpur' => 'მალაიზიის დრო (კუალა-ლუმპური)',
        'Asia/Kuching' => 'მალაიზიის დრო (კუჩინგი)',
        'Asia/Kuwait' => 'არაბეთის დრო (ქუვეითი)',
        'Asia/Macau' => 'ჩინეთის დრო (მაკაო)',
        'Asia/Magadan' => 'მაგადანის დრო',
        'Asia/Makassar' => 'ცენტრალური ინდონეზიის დრო (მაკასარი)',
        'Asia/Manila' => 'ფილიპინების დრო (მანილა)',
        'Asia/Muscat' => 'სპარსეთის ყურის სტანდარტული დრო (მუსკატი)',
        'Asia/Nicosia' => 'აღმოსავლეთ ევროპის დრო (ნიკოსია)',
        'Asia/Novokuznetsk' => 'კრასნოიარსკის დრო (ნოვოკუზნეცკი)',
        'Asia/Novosibirsk' => 'კრასნოიარსკის დრო (ნოვოსიბირსკი)',
        'Asia/Omsk' => 'ომსკის დრო',
        'Asia/Oral' => 'ყაზახეთის დრო (ორალი)',
        'Asia/Phnom_Penh' => 'ინდოჩინეთის დრო (პნომპენი)',
        'Asia/Pontianak' => 'დასავლეთ ინდონეზიის დრო (პონტიანაკი)',
        'Asia/Pyongyang' => 'კორეის დრო (ფხენიანი)',
        'Asia/Qatar' => 'არაბეთის დრო (კატარი)',
        'Asia/Qostanay' => 'ყაზახეთის დრო (კოსტანაი)',
        'Asia/Qyzylorda' => 'ყაზახეთის დრო (ყიზილორდა)',
        'Asia/Rangoon' => 'მიანმარის დრო (რანგუნი)',
        'Asia/Yangon' => 'მიანმარის დრო (რანგუნი)',
        'Asia/Riyadh' => 'არაბეთის დრო (ერ-რიადი)',
        'Asia/Saigon' => 'ინდოჩინეთის დრო (ჰოჩიმინი)',
        'Asia/Ho_Chi_Minh' => 'ინდოჩინეთის დრო (ჰოჩიმინი)',
        'Asia/Sakhalin' => 'მაგადანის დრო (სახალინი)',
        'Asia/Samarkand' => 'უზბეკეთის დრო (სამარყანდი)',
        'Asia/Seoul' => 'კორეის დრო (სეული)',
        'Asia/Shanghai' => 'ჩინეთის დრო (შანხაი)',
        'Asia/Singapore' => 'სინგაპურის დრო',
        'Asia/Srednekolymsk' => 'მაგადანის დრო (სრედნეკოლიმსკი)',
        'Asia/Taipei' => 'ტაიბეის დრო (ტაიპეი)',
        'Asia/Tashkent' => 'უზბეკეთის დრო (ტაშკენტი)',
        'Asia/Tbilisi' => 'საქართველოს დრო (თბილისი)',
        'Asia/Tehran' => 'ირანის დრო (თეირანი)',
        'Asia/Thimphu' => 'ბუტანის დრო (თხიმფხუ)',
        'Asia/Tokyo' => 'იაპონიის დრო (ტოკიო)',
        'Asia/Tomsk' => 'კრასნოიარსკის დრო (ტომსკი)',
        'Asia/Ulaanbaatar' => 'ულან-ბატორის დრო (ულანბატარი)',
        'Asia/Urumqi' => 'დრო: ჩინეთი (ურუმქი)',
        'Asia/Ust-Nera' => 'ვლადივოსტოკის დრო (უსტ-ნერა)',
        'Asia/Vientiane' => 'ინდოჩინეთის დრო (ვიენტიანი)',
        'Asia/Vladivostok' => 'ვლადივოსტოკის დრო',
        'Asia/Yakutsk' => 'იაკუტსკის დრო',
        'Asia/Yekaterinburg' => 'ეკატერინბურგის დრო',
        'Asia/Yerevan' => 'სომხეთის დრო (ერევანი)',
        'Atlantic/Azores' => 'აზორის კუნძულების დრო',
        'Atlantic/Bermuda' => 'ატლანტიკის ოკეანის დრო (ბერმუდა)',
        'Atlantic/Canary' => 'დასავლეთ ევროპის დრო (კანარი)',
        'Atlantic/Cape_Verde' => 'კაბო-ვერდეს დრო',
        'Atlantic/Faeroe' => 'დასავლეთ ევროპის დრო (ფარერის კუნძულები)',
        'Atlantic/Faroe' => 'დასავლეთ ევროპის დრო (ფარერის კუნძულები)',
        'Atlantic/Madeira' => 'დასავლეთ ევროპის დრო (მადეირა)',
        'Atlantic/Reykjavik' => 'გრინვიჩის საშუალო დრო (რეიკიავიკი)',
        'Atlantic/South_Georgia' => 'სამხრეთ გეორგიის დრო (სამხრეთ ჯორჯია)',
        'Atlantic/St_Helena' => 'გრინვიჩის საშუალო დრო (წმ. ელენეს კუნძული)',
        'Atlantic/Stanley' => 'ფოლკლენდის კუნძულების დრო (სტენლი)',
        'Australia/Adelaide' => 'ცენტრალური ავსტრალიის დრო (ადელაიდა)',
        'Australia/Brisbane' => 'აღმოსავლეთ ავსტრალიის დრო (ბრისბეინი)',
        'Australia/Broken_Hill' => 'ცენტრალური ავსტრალიის დრო (ბროუკენ ჰილი)',
        'Australia/Darwin' => 'ცენტრალური ავსტრალიის დრო (დარვინი)',
        'Australia/Eucla' => 'ცენტრალური და დასავლეთ ავსტრალიის დრო (ეუკლა)',
        'Australia/Hobart' => 'აღმოსავლეთ ავსტრალიის დრო (ჰობარტი)',
        'Australia/Lindeman' => 'აღმოსავლეთ ავსტრალიის დრო (ლინდმანი)',
        'Australia/Lord_Howe' => 'ლორდ-ჰაუს დრო (ლორდ ჰოუი)',
        'Australia/Melbourne' => 'აღმოსავლეთ ავსტრალიის დრო (მელბურნი)',
        'Australia/Perth' => 'დასავლეთ ავსტრალიის დრო (პერთი)',
        'Australia/Sydney' => 'აღმოსავლეთ ავსტრალიის დრო (სიდნეი)',
        'Etc/GMT' => 'გრინვიჩის საშუალო დრო',
        'Etc/UTC' => 'მსოფლიო კოორდინირებული დრო',
        'Europe/Amsterdam' => 'ცენტრალური ევროპის დრო (ამსტერდამი)',
        'Europe/Andorra' => 'ცენტრალური ევროპის დრო (ანდორა)',
        'Europe/Astrakhan' => 'დრო: რუსეთი (ასტრახანი)',
        'Europe/Athens' => 'აღმოსავლეთ ევროპის დრო (ათენი)',
        'Europe/Belgrade' => 'ცენტრალური ევროპის დრო (ბელგრადი)',
        'Europe/Berlin' => 'ცენტრალური ევროპის დრო (ბერლინი)',
        'Europe/Bratislava' => 'ცენტრალური ევროპის დრო (ბრატისლავა)',
        'Europe/Brussels' => 'ცენტრალური ევროპის დრო (ბრიუსელი)',
        'Europe/Bucharest' => 'აღმოსავლეთ ევროპის დრო (ბუქარესტი)',
        'Europe/Budapest' => 'ცენტრალური ევროპის დრო (ბუდაპეშტი)',
        'Europe/Busingen' => 'ცენტრალური ევროპის დრო (ბუსინგენი)',
        'Europe/Chisinau' => 'აღმოსავლეთ ევროპის დრო (კიშინიოვი)',
        'Europe/Copenhagen' => 'ცენტრალური ევროპის დრო (კოპენჰაგენი)',
        'Europe/Dublin' => 'გრინვიჩის საშუალო დრო (დუბლინი)',
        'Europe/Gibraltar' => 'ცენტრალური ევროპის დრო (გიბრალტარი)',
        'Europe/Guernsey' => 'გრინვიჩის საშუალო დრო (გერნსი)',
        'Europe/Helsinki' => 'აღმოსავლეთ ევროპის დრო (ჰელსინკი)',
        'Europe/Isle_of_Man' => 'გრინვიჩის საშუალო დრო (მენის კუნძული)',
        'Europe/Istanbul' => 'დრო: თურქეთი (სტამბოლი)',
        'Europe/Jersey' => 'გრინვიჩის საშუალო დრო (ჯერსი)',
        'Europe/Kaliningrad' => 'აღმოსავლეთ ევროპის დრო (კალინინგრადი)',
        'Europe/Kiev' => 'აღმოსავლეთ ევროპის დრო (კიევი)',
        'Europe/Kyiv' => 'აღმოსავლეთ ევროპის დრო (კიევი)',
        'Europe/Kirov' => 'მოსკოვის დრო (კიროვი)',
        'Europe/Lisbon' => 'დასავლეთ ევროპის დრო (ლისაბონი)',
        'Europe/Ljubljana' => 'ცენტრალური ევროპის დრო (ლიუბლიანა)',
        'Europe/London' => 'გრინვიჩის საშუალო დრო (ლონდონი)',
        'Europe/Luxembourg' => 'ცენტრალური ევროპის დრო (ლუქსემბურგი)',
        'Europe/Madrid' => 'ცენტრალური ევროპის დრო (მადრიდი)',
        'Europe/Malta' => 'ცენტრალური ევროპის დრო (მალტა)',
        'Europe/Mariehamn' => 'აღმოსავლეთ ევროპის დრო (მარიჰამნი)',
        'Europe/Minsk' => 'მოსკოვის დრო (მინსკი)',
        'Europe/Monaco' => 'ცენტრალური ევროპის დრო (მონაკო)',
        'Europe/Moscow' => 'მოსკოვის დრო',
        'Europe/Oslo' => 'ცენტრალური ევროპის დრო (ოსლო)',
        'Europe/Paris' => 'ცენტრალური ევროპის დრო (პარიზი)',
        'Europe/Podgorica' => 'ცენტრალური ევროპის დრო (პოდგორიცა)',
        'Europe/Prague' => 'ცენტრალური ევროპის დრო (პრაღა)',
        'Europe/Riga' => 'აღმოსავლეთ ევროპის დრო (რიგა)',
        'Europe/Rome' => 'ცენტრალური ევროპის დრო (რომი)',
        'Europe/Samara' => 'დრო: რუსეთი (სამარა)',
        'Europe/San_Marino' => 'ცენტრალური ევროპის დრო (სან-მარინო)',
        'Europe/Sarajevo' => 'ცენტრალური ევროპის დრო (სარაევო)',
        'Europe/Saratov' => 'დრო: რუსეთი (სარატოვი)',
        'Europe/Simferopol' => 'მოსკოვის დრო (სიმფეროპოლი)',
        'Europe/Skopje' => 'ცენტრალური ევროპის დრო (სკოპიე)',
        'Europe/Sofia' => 'აღმოსავლეთ ევროპის დრო (სოფია)',
        'Europe/Stockholm' => 'ცენტრალური ევროპის დრო (სტოკჰოლმი)',
        'Europe/Tallinn' => 'აღმოსავლეთ ევროპის დრო (ტალინი)',
        'Europe/Tirane' => 'ცენტრალური ევროპის დრო (ტირანა)',
        'Europe/Ulyanovsk' => 'დრო: რუსეთი (ულიანოვსკი)',
        'Europe/Vaduz' => 'ცენტრალური ევროპის დრო (ვადუცი)',
        'Europe/Vatican' => 'ცენტრალური ევროპის დრო (ვატიკანი)',
        'Europe/Vienna' => 'ცენტრალური ევროპის დრო (ვენა)',
        'Europe/Vilnius' => 'აღმოსავლეთ ევროპის დრო (ვილნიუსი)',
        'Europe/Volgograd' => 'მოსკოვის დრო (ვოლგოგრადი)',
        'Europe/Warsaw' => 'ცენტრალური ევროპის დრო (ვარშავა)',
        'Europe/Zagreb' => 'ცენტრალური ევროპის დრო (ზაგრები)',
        'Europe/Zurich' => 'ცენტრალური ევროპის დრო (ციურიხი)',
        'Indian/Antananarivo' => 'აღმოსავლეთ აფრიკის დრო (ანტანანარივუ)',
        'Indian/Chagos' => 'ინდოეთის ოკეანის კუნძულების დრო (ჩაგოსი)',
        'Indian/Christmas' => 'შობის კუნძულის დრო',
        'Indian/Cocos' => 'ქოქოსის კუნძულების დრო',
        'Indian/Comoro' => 'აღმოსავლეთ აფრიკის დრო (კომორო)',
        'Indian/Kerguelen' => 'ფრანგული სამხრეთის და ანტარქტიკის დრო (კერგელენი)',
        'Indian/Mahe' => 'სეიშელის კუნძულების დრო (მაჰე)',
        'Indian/Maldives' => 'მალდივების დრო',
        'Indian/Mauritius' => 'მავრიკის დრო',
        'Indian/Mayotte' => 'აღმოსავლეთ აფრიკის დრო (მაიოტი)',
        'Indian/Reunion' => 'რეიუნიონის დრო',
        'Pacific/Apia' => 'აპიას დრო',
        'Pacific/Auckland' => 'ახალი ზელანდიის დრო (ოკლენდი)',
        'Pacific/Bougainville' => 'პაპუა-ახალი გვინეის დრო (ბუგენვილი)',
        'Pacific/Chatham' => 'ჩატემის დრო (ჩათამი)',
        'Pacific/Easter' => 'აღდგომის კუნძულის დრო (ისთერი)',
        'Pacific/Efate' => 'ვანუატუს დრო (ეფატე)',
        'Pacific/Enderbury' => 'ფენიქსის კუნძულების დრო (კანტონი)',
        'Pacific/Kanton' => 'ფენიქსის კუნძულების დრო (კანტონი)',
        'Pacific/Fakaofo' => 'ტოკელაუს დრო (ფაკაოფო)',
        'Pacific/Fiji' => 'ფიჯის დრო',
        'Pacific/Funafuti' => 'ტუვალუს დრო (ფუნაფუტი)',
        'Pacific/Galapagos' => 'გალაპაგოსის დრო',
        'Pacific/Gambier' => 'გამბიერის დრო',
        'Pacific/Guadalcanal' => 'სოლომონის კუნძულების დრო (გვადალკანალი)',
        'Pacific/Guam' => 'ჩამოროს დრო (გუამი)',
        'Pacific/Honolulu' => 'ჰავაისა და ალეუტის სტანდარტული დრო (ჰონოლულუ)',
        'Pacific/Kiritimati' => 'ლაინის კუნძულების დრო (კირიტიმატი)',
        'Pacific/Kosrae' => 'კოსრეს დრო (კოსრაე)',
        'Pacific/Kwajalein' => 'მარშალის კუნძულების დრო (კვაჯალეინი)',
        'Pacific/Majuro' => 'მარშალის კუნძულების დრო (მახურო)',
        'Pacific/Marquesas' => 'მარკიზის კუნძულების დრო (მარკეზასი)',
        'Pacific/Midway' => 'სამოას დრო (მიდუეი)',
        'Pacific/Nauru' => 'ნაურუს დრო',
        'Pacific/Niue' => 'ნიუეს დრო',
        'Pacific/Norfolk' => 'ნორფოლკის კუნძულის დრო',
        'Pacific/Noumea' => 'ახალი კალედონიის დრო (ნუმეა)',
        'Pacific/Pago_Pago' => 'სამოას დრო (პაგო-პაგო)',
        'Pacific/Palau' => 'პალაუს დრო',
        'Pacific/Pitcairn' => 'პიტკერნის დრო',
        'Pacific/Ponape' => 'პონაპეს დრო (პონპეი)',
        'Pacific/Pohnpei' => 'პონაპეს დრო (პონპეი)',
        'Pacific/Port_Moresby' => 'პაპუა-ახალი გვინეის დრო (პორტ მორსბი)',
        'Pacific/Rarotonga' => 'კუკის კუნძულების დრო (რაროტონგა)',
        'Pacific/Saipan' => 'ჩამოროს დრო (საიპანი)',
        'Pacific/Tahiti' => 'ტაიტის დრო',
        'Pacific/Tarawa' => 'გილბერტის კუნძულების დრო (ტარაუა)',
        'Pacific/Tongatapu' => 'ტონგის დრო (ტონგატაპუ)',
        'Pacific/Truk' => 'ჩუუკის დრო',
        'Pacific/Chuuk' => 'ჩუუკის დრო',
        'Pacific/Wake' => 'ვეიკის კუნძულის დრო (უეიკი)',
        'Pacific/Wallis' => 'ვოლისი და ფუტუნას დრო (ვალისი)',
    ],
    'Meta' => [],
];
