<?php

return [
    'Names' => [
        'af' => 'afrikaaneg',
        'af_NA' => 'afrikaaneg (Namibia)',
        'af_ZA' => 'afrikaaneg (Suafrika)',
        'ak' => 'akaneg',
        'ak_GH' => 'akaneg (Ghana)',
        'am' => 'amhareg',
        'am_ET' => 'amhareg (Etiopia)',
        'ar' => 'arabeg',
        'ar_001' => 'arabeg (bed)',
        'ar_AE' => 'arabeg (Emirelezhioù-Arab-Unanet)',
        'ar_BH' => 'arabeg (Bahrein)',
        'ar_DJ' => 'arabeg (Djibouti)',
        'ar_DZ' => 'arabeg (Aljeria)',
        'ar_EG' => 'arabeg (Egipt)',
        'ar_EH' => 'arabeg (Sahara ar Cʼhornôg)',
        'ar_ER' => 'arabeg (Eritrea)',
        'ar_IL' => 'arabeg (Israel)',
        'ar_IQ' => 'arabeg (Iraq)',
        'ar_JO' => 'arabeg (Jordania)',
        'ar_KM' => 'arabeg (Komorez)',
        'ar_KW' => 'arabeg (Koweit)',
        'ar_LB' => 'arabeg (Liban)',
        'ar_LY' => 'arabeg (Libia)',
        'ar_MA' => 'arabeg (Maroko)',
        'ar_MR' => 'arabeg (Maouritania)',
        'ar_OM' => 'arabeg (Oman)',
        'ar_PS' => 'arabeg (Tiriadoù Palestina)',
        'ar_QA' => 'arabeg (Qatar)',
        'ar_SA' => 'arabeg (Arabia Saoudat)',
        'ar_SD' => 'arabeg (Soudan)',
        'ar_SO' => 'arabeg (Somalia)',
        'ar_SS' => 'arabeg (Soudan ar Su)',
        'ar_SY' => 'arabeg (Siria)',
        'ar_TD' => 'arabeg (Tchad)',
        'ar_TN' => 'arabeg (Tunizia)',
        'ar_YE' => 'arabeg (Yemen)',
        'as' => 'asameg',
        'as_IN' => 'asameg (India)',
        'az' => 'azerbaidjaneg',
        'az_AZ' => 'azerbaidjaneg (Azerbaidjan)',
        'az_Cyrl' => 'azerbaidjaneg (kirillek)',
        'az_Cyrl_AZ' => 'azerbaidjaneg (kirillek, Azerbaidjan)',
        'az_Latn' => 'azerbaidjaneg (latin)',
        'az_Latn_AZ' => 'azerbaidjaneg (latin, Azerbaidjan)',
        'ba' => 'bachkir',
        'ba_RU' => 'bachkir (Rusia)',
        'be' => 'belaruseg',
        'be_BY' => 'belaruseg (Belarus)',
        'bg' => 'bulgareg',
        'bg_BG' => 'bulgareg (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengaleg',
        'bn_BD' => 'bengaleg (Bangladesh)',
        'bn_IN' => 'bengaleg (India)',
        'bo' => 'tibetaneg',
        'bo_CN' => 'tibetaneg (Sina)',
        'bo_IN' => 'tibetaneg (India)',
        'br' => 'brezhoneg',
        'br_FR' => 'brezhoneg (Frañs)',
        'bs' => 'bosneg',
        'bs_BA' => 'bosneg (Bosnia-ha-Herzegovina)',
        'bs_Cyrl' => 'bosneg (kirillek)',
        'bs_Cyrl_BA' => 'bosneg (kirillek, Bosnia-ha-Herzegovina)',
        'bs_Latn' => 'bosneg (latin)',
        'bs_Latn_BA' => 'bosneg (latin, Bosnia-ha-Herzegovina)',
        'ca' => 'katalaneg',
        'ca_AD' => 'katalaneg (Andorra)',
        'ca_ES' => 'katalaneg (Spagn)',
        'ca_FR' => 'katalaneg (Frañs)',
        'ca_IT' => 'katalaneg (Italia)',
        'ce' => 'tchetcheneg',
        'ce_RU' => 'tchetcheneg (Rusia)',
        'cs' => 'tchekeg',
        'cs_CZ' => 'tchekeg (Tchekia)',
        'cv' => 'tchouvatcheg',
        'cv_RU' => 'tchouvatcheg (Rusia)',
        'cy' => 'kembraeg',
        'cy_GB' => 'kembraeg (Rouantelezh-Unanet)',
        'da' => 'daneg',
        'da_DK' => 'daneg (Danmark)',
        'da_GL' => 'daneg (Greunland)',
        'de' => 'alamaneg',
        'de_AT' => 'alamaneg (Aostria)',
        'de_BE' => 'alamaneg (Belgia)',
        'de_CH' => 'alamaneg (Suis)',
        'de_DE' => 'alamaneg (Alamagn)',
        'de_IT' => 'alamaneg (Italia)',
        'de_LI' => 'alamaneg (Liechtenstein)',
        'de_LU' => 'alamaneg (Luksembourg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhoutan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'gresianeg',
        'el_CY' => 'gresianeg (Kiprenez)',
        'el_GR' => 'gresianeg (Gres)',
        'en' => 'saozneg',
        'en_001' => 'saozneg (bed)',
        'en_150' => 'saozneg (Europa)',
        'en_AE' => 'saozneg (Emirelezhioù-Arab-Unanet)',
        'en_AG' => 'saozneg (Antigua-ha-Barbuda)',
        'en_AI' => 'saozneg (Anguilla)',
        'en_AS' => 'saozneg (Samoa Amerikan)',
        'en_AT' => 'saozneg (Aostria)',
        'en_AU' => 'saozneg (Aostralia)',
        'en_BB' => 'saozneg (Barbados)',
        'en_BE' => 'saozneg (Belgia)',
        'en_BI' => 'saozneg (Burundi)',
        'en_BM' => 'saozneg (Bermudez)',
        'en_BS' => 'saozneg (Bahamas)',
        'en_BW' => 'saozneg (Botswana)',
        'en_BZ' => 'saozneg (Belize)',
        'en_CA' => 'saozneg (Kanada)',
        'en_CC' => 'saozneg (Inizi Kokoz)',
        'en_CH' => 'saozneg (Suis)',
        'en_CK' => 'saozneg (Inizi Cook)',
        'en_CM' => 'saozneg (Kameroun)',
        'en_CX' => 'saozneg (Enez Christmas)',
        'en_CY' => 'saozneg (Kiprenez)',
        'en_CZ' => 'saozneg (Tchekia)',
        'en_DE' => 'saozneg (Alamagn)',
        'en_DK' => 'saozneg (Danmark)',
        'en_DM' => 'saozneg (Dominica)',
        'en_EE' => 'saozneg (Estonia)',
        'en_ER' => 'saozneg (Eritrea)',
        'en_ES' => 'saozneg (Spagn)',
        'en_FI' => 'saozneg (Finland)',
        'en_FJ' => 'saozneg (Fidji)',
        'en_FK' => 'saozneg (Inizi Falkland)',
        'en_FM' => 'saozneg (Mikronezia)',
        'en_FR' => 'saozneg (Frañs)',
        'en_GB' => 'saozneg (Rouantelezh-Unanet)',
        'en_GD' => 'saozneg (Grenada)',
        'en_GE' => 'saozneg (Jorjia)',
        'en_GG' => 'saozneg (Gwernenez)',
        'en_GH' => 'saozneg (Ghana)',
        'en_GI' => 'saozneg (Jibraltar)',
        'en_GM' => 'saozneg (Gambia)',
        'en_GS' => 'saozneg (Inizi Georgia ar Su hag Inizi Sandwich ar Su)',
        'en_GU' => 'saozneg (Guam)',
        'en_GY' => 'saozneg (Guyana)',
        'en_HK' => 'saozneg (Hong Kong RMD Sina)',
        'en_HU' => 'saozneg (Hungaria)',
        'en_ID' => 'saozneg (Indonezia)',
        'en_IE' => 'saozneg (Iwerzhon)',
        'en_IL' => 'saozneg (Israel)',
        'en_IM' => 'saozneg (Enez-Vanav)',
        'en_IN' => 'saozneg (India)',
        'en_IO' => 'saozneg (Tiriad breizhveurat Meurvor Indez)',
        'en_IT' => 'saozneg (Italia)',
        'en_JE' => 'saozneg (Jerzenez)',
        'en_JM' => 'saozneg (Jamaika)',
        'en_JP' => 'saozneg (Japan)',
        'en_KE' => 'saozneg (Kenya)',
        'en_KI' => 'saozneg (Kiribati)',
        'en_KN' => 'saozneg (Saint Kitts-ha-Nevis)',
        'en_KY' => 'saozneg (Inizi Cayman)',
        'en_LC' => 'saozneg (Saint Lucia)',
        'en_LR' => 'saozneg (Liberia)',
        'en_LS' => 'saozneg (Lesotho)',
        'en_LT' => 'saozneg (Lituania)',
        'en_LV' => 'saozneg (Latvia)',
        'en_MG' => 'saozneg (Madagaskar)',
        'en_MH' => 'saozneg (Inizi Marshall)',
        'en_MO' => 'saozneg (Makao RMD Sina)',
        'en_MP' => 'saozneg (Inizi Mariana an Norzh)',
        'en_MS' => 'saozneg (Montserrat)',
        'en_MT' => 'saozneg (Malta)',
        'en_MU' => 'saozneg (Moris)',
        'en_MV' => 'saozneg (Maldivez)',
        'en_MW' => 'saozneg (Malawi)',
        'en_MY' => 'saozneg (Malaysia)',
        'en_NA' => 'saozneg (Namibia)',
        'en_NF' => 'saozneg (Enez Norfolk)',
        'en_NG' => 'saozneg (Nigeria)',
        'en_NL' => 'saozneg (Izelvroioù)',
        'en_NO' => 'saozneg (Norvegia)',
        'en_NR' => 'saozneg (Nauru)',
        'en_NU' => 'saozneg (Niue)',
        'en_NZ' => 'saozneg (Zeland-Nevez)',
        'en_PG' => 'saozneg (Papoua Ginea-Nevez)',
        'en_PH' => 'saozneg (Filipinez)',
        'en_PK' => 'saozneg (Pakistan)',
        'en_PL' => 'saozneg (Polonia)',
        'en_PN' => 'saozneg (Enez Pitcairn)',
        'en_PR' => 'saozneg (Puerto Rico)',
        'en_PT' => 'saozneg (Portugal)',
        'en_PW' => 'saozneg (Palau)',
        'en_RO' => 'saozneg (Roumania)',
        'en_RW' => 'saozneg (Rwanda)',
        'en_SB' => 'saozneg (Inizi Salomon)',
        'en_SC' => 'saozneg (Sechelez)',
        'en_SD' => 'saozneg (Soudan)',
        'en_SE' => 'saozneg (Sveden)',
        'en_SG' => 'saozneg (Singapoura)',
        'en_SH' => 'saozneg (Saint-Helena)',
        'en_SI' => 'saozneg (Slovenia)',
        'en_SK' => 'saozneg (Slovakia)',
        'en_SL' => 'saozneg (Sierra Leone)',
        'en_SS' => 'saozneg (Soudan ar Su)',
        'en_SX' => 'saozneg (Sint Maarten)',
        'en_SZ' => 'saozneg (Eswatini)',
        'en_TC' => 'saozneg (Inizi Turks-ha-Caicos)',
        'en_TK' => 'saozneg (Tokelau)',
        'en_TO' => 'saozneg (Tonga)',
        'en_TT' => 'saozneg (Trinidad-ha-Tobago)',
        'en_TV' => 'saozneg (Tuvalu)',
        'en_TZ' => 'saozneg (Tanzania)',
        'en_UA' => 'saozneg (Ukraina)',
        'en_UG' => 'saozneg (Ouganda)',
        'en_UM' => 'saozneg (Inizi diabell ar Stadoù-Unanet)',
        'en_US' => 'saozneg (Stadoù-Unanet)',
        'en_VC' => 'saozneg (Sant-Visant hag ar Grenadinez)',
        'en_VG' => 'saozneg (Inizi Gwercʼh Breizh-Veur)',
        'en_VI' => 'saozneg (Inizi Gwercʼh ar Stadoù-Unanet)',
        'en_VU' => 'saozneg (Vanuatu)',
        'en_WS' => 'saozneg (Samoa)',
        'en_ZA' => 'saozneg (Suafrika)',
        'en_ZM' => 'saozneg (Zambia)',
        'en_ZW' => 'saozneg (Zimbabwe)',
        'eo' => 'esperanteg',
        'eo_001' => 'esperanteg (bed)',
        'es' => 'spagnoleg',
        'es_419' => 'spagnoleg (Amerika Latin)',
        'es_AR' => 'spagnoleg (Arcʼhantina)',
        'es_BO' => 'spagnoleg (Bolivia)',
        'es_BR' => 'spagnoleg (Brazil)',
        'es_BZ' => 'spagnoleg (Belize)',
        'es_CL' => 'spagnoleg (Chile)',
        'es_CO' => 'spagnoleg (Kolombia)',
        'es_CR' => 'spagnoleg (Costa Rica)',
        'es_CU' => 'spagnoleg (Kuba)',
        'es_DO' => 'spagnoleg (Republik Dominikan)',
        'es_EC' => 'spagnoleg (Ecuador)',
        'es_ES' => 'spagnoleg (Spagn)',
        'es_GQ' => 'spagnoleg (Ginea-ar-Cʼheheder)',
        'es_GT' => 'spagnoleg (Guatemala)',
        'es_HN' => 'spagnoleg (Honduras)',
        'es_MX' => 'spagnoleg (Mecʼhiko)',
        'es_NI' => 'spagnoleg (Nicaragua)',
        'es_PA' => 'spagnoleg (Panamá)',
        'es_PE' => 'spagnoleg (Perou)',
        'es_PH' => 'spagnoleg (Filipinez)',
        'es_PR' => 'spagnoleg (Puerto Rico)',
        'es_PY' => 'spagnoleg (Paraguay)',
        'es_SV' => 'spagnoleg (Salvador)',
        'es_US' => 'spagnoleg (Stadoù-Unanet)',
        'es_UY' => 'spagnoleg (Uruguay)',
        'es_VE' => 'spagnoleg (Venezuela)',
        'et' => 'estoneg',
        'et_EE' => 'estoneg (Estonia)',
        'eu' => 'euskareg',
        'eu_ES' => 'euskareg (Spagn)',
        'fa' => 'perseg',
        'fa_AF' => 'perseg (Afghanistan)',
        'fa_IR' => 'perseg (Iran)',
        'ff' => 'fulaeg',
        'ff_Adlm' => 'fulaeg (adlam)',
        'ff_Adlm_BF' => 'fulaeg (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulaeg (adlam, Kameroun)',
        'ff_Adlm_GH' => 'fulaeg (adlam, Ghana)',
        'ff_Adlm_GM' => 'fulaeg (adlam, Gambia)',
        'ff_Adlm_GN' => 'fulaeg (adlam, Ginea)',
        'ff_Adlm_GW' => 'fulaeg (adlam, Ginea-Bissau)',
        'ff_Adlm_LR' => 'fulaeg (adlam, Liberia)',
        'ff_Adlm_MR' => 'fulaeg (adlam, Maouritania)',
        'ff_Adlm_NE' => 'fulaeg (adlam, Niger)',
        'ff_Adlm_NG' => 'fulaeg (adlam, Nigeria)',
        'ff_Adlm_SL' => 'fulaeg (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'fulaeg (adlam, Senegal)',
        'ff_CM' => 'fulaeg (Kameroun)',
        'ff_GN' => 'fulaeg (Ginea)',
        'ff_Latn' => 'fulaeg (latin)',
        'ff_Latn_BF' => 'fulaeg (latin, Burkina Faso)',
        'ff_Latn_CM' => 'fulaeg (latin, Kameroun)',
        'ff_Latn_GH' => 'fulaeg (latin, Ghana)',
        'ff_Latn_GM' => 'fulaeg (latin, Gambia)',
        'ff_Latn_GN' => 'fulaeg (latin, Ginea)',
        'ff_Latn_GW' => 'fulaeg (latin, Ginea-Bissau)',
        'ff_Latn_LR' => 'fulaeg (latin, Liberia)',
        'ff_Latn_MR' => 'fulaeg (latin, Maouritania)',
        'ff_Latn_NE' => 'fulaeg (latin, Niger)',
        'ff_Latn_NG' => 'fulaeg (latin, Nigeria)',
        'ff_Latn_SL' => 'fulaeg (latin, Sierra Leone)',
        'ff_Latn_SN' => 'fulaeg (latin, Senegal)',
        'ff_MR' => 'fulaeg (Maouritania)',
        'ff_SN' => 'fulaeg (Senegal)',
        'fi' => 'finneg',
        'fi_FI' => 'finneg (Finland)',
        'fo' => 'faeroeg',
        'fo_DK' => 'faeroeg (Danmark)',
        'fo_FO' => 'faeroeg (Inizi Faero)',
        'fr' => 'galleg',
        'fr_BE' => 'galleg (Belgia)',
        'fr_BF' => 'galleg (Burkina Faso)',
        'fr_BI' => 'galleg (Burundi)',
        'fr_BJ' => 'galleg (Benin)',
        'fr_BL' => 'galleg (Sant-Bertele)',
        'fr_CA' => 'galleg (Kanada)',
        'fr_CD' => 'galleg (Kongo - Kinshasa)',
        'fr_CF' => 'galleg (Republik Kreizafrikan)',
        'fr_CG' => 'galleg (Kongo - Brazzaville)',
        'fr_CH' => 'galleg (Suis)',
        'fr_CI' => 'galleg (Aod-an-Olifant)',
        'fr_CM' => 'galleg (Kameroun)',
        'fr_DJ' => 'galleg (Djibouti)',
        'fr_DZ' => 'galleg (Aljeria)',
        'fr_FR' => 'galleg (Frañs)',
        'fr_GA' => 'galleg (Gabon)',
        'fr_GF' => 'galleg (Gwiana cʼhall)',
        'fr_GN' => 'galleg (Ginea)',
        'fr_GP' => 'galleg (Gwadeloup)',
        'fr_GQ' => 'galleg (Ginea-ar-Cʼheheder)',
        'fr_HT' => 'galleg (Haiti)',
        'fr_KM' => 'galleg (Komorez)',
        'fr_LU' => 'galleg (Luksembourg)',
        'fr_MA' => 'galleg (Maroko)',
        'fr_MC' => 'galleg (Monaco)',
        'fr_MF' => 'galleg (Sant-Martin)',
        'fr_MG' => 'galleg (Madagaskar)',
        'fr_ML' => 'galleg (Mali)',
        'fr_MQ' => 'galleg (Martinik)',
        'fr_MR' => 'galleg (Maouritania)',
        'fr_MU' => 'galleg (Moris)',
        'fr_NC' => 'galleg (Kaledonia-Nevez)',
        'fr_NE' => 'galleg (Niger)',
        'fr_PF' => 'galleg (Polinezia Cʼhall)',
        'fr_PM' => 'galleg (Sant-Pêr-ha-Mikelon)',
        'fr_RE' => 'galleg (Ar Reünion)',
        'fr_RW' => 'galleg (Rwanda)',
        'fr_SC' => 'galleg (Sechelez)',
        'fr_SN' => 'galleg (Senegal)',
        'fr_SY' => 'galleg (Siria)',
        'fr_TD' => 'galleg (Tchad)',
        'fr_TG' => 'galleg (Togo)',
        'fr_TN' => 'galleg (Tunizia)',
        'fr_VU' => 'galleg (Vanuatu)',
        'fr_WF' => 'galleg (Wallis-ha-Futuna)',
        'fr_YT' => 'galleg (Mayotte)',
        'fy' => 'frizeg ar Cʼhornôg',
        'fy_NL' => 'frizeg ar Cʼhornôg (Izelvroioù)',
        'ga' => 'iwerzhoneg',
        'ga_GB' => 'iwerzhoneg (Rouantelezh-Unanet)',
        'ga_IE' => 'iwerzhoneg (Iwerzhon)',
        'gd' => 'skoseg',
        'gd_GB' => 'skoseg (Rouantelezh-Unanet)',
        'gl' => 'galizeg',
        'gl_ES' => 'galizeg (Spagn)',
        'gu' => 'gujarateg',
        'gu_IN' => 'gujarateg (India)',
        'gv' => 'manaveg',
        'gv_IM' => 'manaveg (Enez-Vanav)',
        'ha' => 'haousaeg',
        'ha_GH' => 'haousaeg (Ghana)',
        'ha_NE' => 'haousaeg (Niger)',
        'ha_NG' => 'haousaeg (Nigeria)',
        'he' => 'hebraeg',
        'he_IL' => 'hebraeg (Israel)',
        'hi' => 'hindieg',
        'hi_IN' => 'hindieg (India)',
        'hi_Latn' => 'hindieg (latin)',
        'hi_Latn_IN' => 'hindieg (latin, India)',
        'hr' => 'kroateg',
        'hr_BA' => 'kroateg (Bosnia-ha-Herzegovina)',
        'hr_HR' => 'kroateg (Kroatia)',
        'hu' => 'hungareg',
        'hu_HU' => 'hungareg (Hungaria)',
        'hy' => 'armenianeg',
        'hy_AM' => 'armenianeg (Armenia)',
        'ia' => 'interlinguaeg',
        'ia_001' => 'interlinguaeg (bed)',
        'id' => 'indonezeg',
        'id_ID' => 'indonezeg (Indonezia)',
        'ie' => 'interlingue',
        'ie_EE' => 'interlingue (Estonia)',
        'ig' => 'igboeg',
        'ig_NG' => 'igboeg (Nigeria)',
        'ii' => 'yieg Sichuan',
        'ii_CN' => 'yieg Sichuan (Sina)',
        'is' => 'islandeg',
        'is_IS' => 'islandeg (Island)',
        'it' => 'italianeg',
        'it_CH' => 'italianeg (Suis)',
        'it_IT' => 'italianeg (Italia)',
        'it_SM' => 'italianeg (San Marino)',
        'it_VA' => 'italianeg (Vatikan)',
        'ja' => 'japaneg',
        'ja_JP' => 'japaneg (Japan)',
        'jv' => 'javaneg',
        'jv_ID' => 'javaneg (Indonezia)',
        'ka' => 'jorjianeg',
        'ka_GE' => 'jorjianeg (Jorjia)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenya)',
        'kk' => 'kazakeg',
        'kk_Arab' => 'kazakeg (arabek)',
        'kk_Arab_CN' => 'kazakeg (arabek, Sina)',
        'kk_Cyrl' => 'kazakeg (kirillek)',
        'kk_Cyrl_KZ' => 'kazakeg (kirillek, Kazakstan)',
        'kk_KZ' => 'kazakeg (Kazakstan)',
        'kl' => 'greunlandeg',
        'kl_GL' => 'greunlandeg (Greunland)',
        'km' => 'khmereg',
        'km_KH' => 'khmereg (Kambodja)',
        'kn' => 'kanareg',
        'kn_IN' => 'kanareg (India)',
        'ko' => 'koreaneg',
        'ko_CN' => 'koreaneg (Sina)',
        'ko_KP' => 'koreaneg (Norzhkorea)',
        'ko_KR' => 'koreaneg (Sukorea)',
        'ks' => 'kashmireg',
        'ks_Arab' => 'kashmireg (arabek)',
        'ks_Arab_IN' => 'kashmireg (arabek, India)',
        'ks_Deva' => 'kashmireg (devanagari)',
        'ks_Deva_IN' => 'kashmireg (devanagari, India)',
        'ks_IN' => 'kashmireg (India)',
        'ku' => 'kurdeg',
        'ku_Latn' => 'kurdeg (latin)',
        'ku_Latn_IQ' => 'kurdeg (latin, Iraq)',
        'ku_Latn_SY' => 'kurdeg (latin, Siria)',
        'ku_Latn_TR' => 'kurdeg (latin, Turkia)',
        'ku_SY' => 'kurdeg (Siria)',
        'ku_TR' => 'kurdeg (Turkia)',
        'kw' => 'kerneveureg',
        'kw_GB' => 'kerneveureg (Rouantelezh-Unanet)',
        'ky' => 'kirgizeg',
        'ky_KG' => 'kirgizeg (Kyrgyzstan)',
        'lb' => 'luksembourgeg',
        'lb_LU' => 'luksembourgeg (Luksembourg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Ouganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongo - Kinshasa)',
        'ln_CF' => 'lingala (Republik Kreizafrikan)',
        'ln_CG' => 'lingala (Kongo - Brazzaville)',
        'lo' => 'laoseg',
        'lo_LA' => 'laoseg (Laos)',
        'lt' => 'lituaneg',
        'lt_LT' => 'lituaneg (Lituania)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Kongo - Kinshasa)',
        'lv' => 'latvieg',
        'lv_LV' => 'latvieg (Latvia)',
        'mg' => 'malgacheg',
        'mg_MG' => 'malgacheg (Madagaskar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Zeland-Nevez)',
        'mk' => 'makedoneg',
        'mk_MK' => 'makedoneg (Makedonia an Norzh)',
        'ml' => 'malayalameg',
        'ml_IN' => 'malayalameg (India)',
        'mn' => 'mongoleg',
        'mn_MN' => 'mongoleg (Mongolia)',
        'mr' => 'maratheg',
        'mr_IN' => 'maratheg (India)',
        'ms' => 'malayseg',
        'ms_BN' => 'malayseg (Brunei)',
        'ms_ID' => 'malayseg (Indonezia)',
        'ms_MY' => 'malayseg (Malaysia)',
        'ms_SG' => 'malayseg (Singapoura)',
        'mt' => 'malteg',
        'mt_MT' => 'malteg (Malta)',
        'my' => 'birmaneg',
        'my_MM' => 'birmaneg (Myanmar [Birmania])',
        'nb' => 'norvegeg bokmål',
        'nb_NO' => 'norvegeg bokmål (Norvegia)',
        'nb_SJ' => 'norvegeg bokmål (Svalbard)',
        'nd' => 'ndebele an Norzh',
        'nd_ZW' => 'ndebele an Norzh (Zimbabwe)',
        'ne' => 'nepaleg',
        'ne_IN' => 'nepaleg (India)',
        'ne_NP' => 'nepaleg (Nepal)',
        'nl' => 'nederlandeg',
        'nl_AW' => 'nederlandeg (Aruba)',
        'nl_BE' => 'nederlandeg (Belgia)',
        'nl_BQ' => 'nederlandeg (Karib Nederlandat)',
        'nl_CW' => 'nederlandeg (Curaçao)',
        'nl_NL' => 'nederlandeg (Izelvroioù)',
        'nl_SR' => 'nederlandeg (Surinam)',
        'nl_SX' => 'nederlandeg (Sint Maarten)',
        'nn' => 'norvegeg nynorsk',
        'nn_NO' => 'norvegeg nynorsk (Norvegia)',
        'no' => 'norvegeg',
        'no_NO' => 'norvegeg (Norvegia)',
        'oc' => 'okitaneg',
        'oc_ES' => 'okitaneg (Spagn)',
        'oc_FR' => 'okitaneg (Frañs)',
        'om' => 'oromoeg',
        'om_ET' => 'oromoeg (Etiopia)',
        'om_KE' => 'oromoeg (Kenya)',
        'or' => 'oriyaeg',
        'or_IN' => 'oriyaeg (India)',
        'os' => 'oseteg',
        'os_GE' => 'oseteg (Jorjia)',
        'os_RU' => 'oseteg (Rusia)',
        'pa' => 'punjabeg',
        'pa_Arab' => 'punjabeg (arabek)',
        'pa_Arab_PK' => 'punjabeg (arabek, Pakistan)',
        'pa_Guru' => 'punjabeg (gurmukhi)',
        'pa_Guru_IN' => 'punjabeg (gurmukhi, India)',
        'pa_IN' => 'punjabeg (India)',
        'pa_PK' => 'punjabeg (Pakistan)',
        'pl' => 'poloneg',
        'pl_PL' => 'poloneg (Polonia)',
        'ps' => 'pachtoeg',
        'ps_AF' => 'pachtoeg (Afghanistan)',
        'ps_PK' => 'pachtoeg (Pakistan)',
        'pt' => 'portugaleg',
        'pt_AO' => 'portugaleg (Angola)',
        'pt_BR' => 'portugaleg (Brazil)',
        'pt_CH' => 'portugaleg (Suis)',
        'pt_CV' => 'portugaleg (Kab-Glas)',
        'pt_GQ' => 'portugaleg (Ginea-ar-Cʼheheder)',
        'pt_GW' => 'portugaleg (Ginea-Bissau)',
        'pt_LU' => 'portugaleg (Luksembourg)',
        'pt_MO' => 'portugaleg (Makao RMD Sina)',
        'pt_MZ' => 'portugaleg (Mozambik)',
        'pt_PT' => 'portugaleg (Portugal)',
        'pt_ST' => 'portugaleg (São-Tomé-ha-Príncipe)',
        'pt_TL' => 'portugaleg (Timor-Leste)',
        'qu' => 'kechuaeg',
        'qu_BO' => 'kechuaeg (Bolivia)',
        'qu_EC' => 'kechuaeg (Ecuador)',
        'qu_PE' => 'kechuaeg (Perou)',
        'rm' => 'romañcheg',
        'rm_CH' => 'romañcheg (Suis)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'roumaneg',
        'ro_MD' => 'roumaneg (Moldova)',
        'ro_RO' => 'roumaneg (Roumania)',
        'ru' => 'rusianeg',
        'ru_BY' => 'rusianeg (Belarus)',
        'ru_KG' => 'rusianeg (Kyrgyzstan)',
        'ru_KZ' => 'rusianeg (Kazakstan)',
        'ru_MD' => 'rusianeg (Moldova)',
        'ru_RU' => 'rusianeg (Rusia)',
        'ru_UA' => 'rusianeg (Ukraina)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Rwanda)',
        'sa' => 'sanskriteg',
        'sa_IN' => 'sanskriteg (India)',
        'sc' => 'sardeg',
        'sc_IT' => 'sardeg (Italia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arabek)',
        'sd_Arab_PK' => 'sindhi (arabek, Pakistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, India)',
        'sd_IN' => 'sindhi (India)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'sámi an Norzh',
        'se_FI' => 'sámi an Norzh (Finland)',
        'se_NO' => 'sámi an Norzh (Norvegia)',
        'se_SE' => 'sámi an Norzh (Sveden)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Republik Kreizafrikan)',
        'sh' => 'serb-kroateg',
        'sh_BA' => 'serb-kroateg (Bosnia-ha-Herzegovina)',
        'si' => 'singhaleg',
        'si_LK' => 'singhaleg (Sri Lanka)',
        'sk' => 'slovakeg',
        'sk_SK' => 'slovakeg (Slovakia)',
        'sl' => 'sloveneg',
        'sl_SI' => 'sloveneg (Slovenia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabwe)',
        'so' => 'somalieg',
        'so_DJ' => 'somalieg (Djibouti)',
        'so_ET' => 'somalieg (Etiopia)',
        'so_KE' => 'somalieg (Kenya)',
        'so_SO' => 'somalieg (Somalia)',
        'sq' => 'albaneg',
        'sq_AL' => 'albaneg (Albania)',
        'sq_MK' => 'albaneg (Makedonia an Norzh)',
        'sr' => 'serbeg',
        'sr_BA' => 'serbeg (Bosnia-ha-Herzegovina)',
        'sr_Cyrl' => 'serbeg (kirillek)',
        'sr_Cyrl_BA' => 'serbeg (kirillek, Bosnia-ha-Herzegovina)',
        'sr_Cyrl_ME' => 'serbeg (kirillek, Montenegro)',
        'sr_Cyrl_RS' => 'serbeg (kirillek, Serbia)',
        'sr_Latn' => 'serbeg (latin)',
        'sr_Latn_BA' => 'serbeg (latin, Bosnia-ha-Herzegovina)',
        'sr_Latn_ME' => 'serbeg (latin, Montenegro)',
        'sr_Latn_RS' => 'serbeg (latin, Serbia)',
        'sr_ME' => 'serbeg (Montenegro)',
        'sr_RS' => 'serbeg (Serbia)',
        'st' => 'sothoeg ar Su',
        'st_LS' => 'sothoeg ar Su (Lesotho)',
        'st_ZA' => 'sothoeg ar Su (Suafrika)',
        'su' => 'sundaneg',
        'su_ID' => 'sundaneg (Indonezia)',
        'su_Latn' => 'sundaneg (latin)',
        'su_Latn_ID' => 'sundaneg (latin, Indonezia)',
        'sv' => 'svedeg',
        'sv_AX' => 'svedeg (Inizi Åland)',
        'sv_FI' => 'svedeg (Finland)',
        'sv_SE' => 'svedeg (Sveden)',
        'sw' => 'swahilieg',
        'sw_CD' => 'swahilieg (Kongo - Kinshasa)',
        'sw_KE' => 'swahilieg (Kenya)',
        'sw_TZ' => 'swahilieg (Tanzania)',
        'sw_UG' => 'swahilieg (Ouganda)',
        'ta' => 'tamileg',
        'ta_IN' => 'tamileg (India)',
        'ta_LK' => 'tamileg (Sri Lanka)',
        'ta_MY' => 'tamileg (Malaysia)',
        'ta_SG' => 'tamileg (Singapoura)',
        'te' => 'telougou',
        'te_IN' => 'telougou (India)',
        'tg' => 'tadjikeg',
        'tg_TJ' => 'tadjikeg (Tadjikistan)',
        'th' => 'thaieg',
        'th_TH' => 'thaieg (Thailand)',
        'ti' => 'tigrignaeg',
        'ti_ER' => 'tigrignaeg (Eritrea)',
        'ti_ET' => 'tigrignaeg (Etiopia)',
        'tk' => 'turkmeneg',
        'tk_TM' => 'turkmeneg (Turkmenistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filipinez)',
        'tn' => 'tswanaeg',
        'tn_BW' => 'tswanaeg (Botswana)',
        'tn_ZA' => 'tswanaeg (Suafrika)',
        'to' => 'tongaeg',
        'to_TO' => 'tongaeg (Tonga)',
        'tr' => 'turkeg',
        'tr_CY' => 'turkeg (Kiprenez)',
        'tr_TR' => 'turkeg (Turkia)',
        'tt' => 'tatareg',
        'tt_RU' => 'tatareg (Rusia)',
        'ug' => 'ouigoureg',
        'ug_CN' => 'ouigoureg (Sina)',
        'uk' => 'ukraineg',
        'uk_UA' => 'ukraineg (Ukraina)',
        'ur' => 'ourdoueg',
        'ur_IN' => 'ourdoueg (India)',
        'ur_PK' => 'ourdoueg (Pakistan)',
        'uz' => 'ouzbekeg',
        'uz_AF' => 'ouzbekeg (Afghanistan)',
        'uz_Arab' => 'ouzbekeg (arabek)',
        'uz_Arab_AF' => 'ouzbekeg (arabek, Afghanistan)',
        'uz_Cyrl' => 'ouzbekeg (kirillek)',
        'uz_Cyrl_UZ' => 'ouzbekeg (kirillek, Ouzbekistan)',
        'uz_Latn' => 'ouzbekeg (latin)',
        'uz_Latn_UZ' => 'ouzbekeg (latin, Ouzbekistan)',
        'uz_UZ' => 'ouzbekeg (Ouzbekistan)',
        'vi' => 'vietnameg',
        'vi_VN' => 'vietnameg (Viêt Nam)',
        'wo' => 'wolofeg',
        'wo_SN' => 'wolofeg (Senegal)',
        'xh' => 'xhosaeg',
        'xh_ZA' => 'xhosaeg (Suafrika)',
        'yi' => 'yiddish',
        'yi_UA' => 'yiddish (Ukraina)',
        'yo' => 'yoroubaeg',
        'yo_BJ' => 'yoroubaeg (Benin)',
        'yo_NG' => 'yoroubaeg (Nigeria)',
        'za' => 'zhuang',
        'za_CN' => 'zhuang (Sina)',
        'zh' => 'sinaeg',
        'zh_CN' => 'sinaeg (Sina)',
        'zh_HK' => 'sinaeg (Hong Kong RMD Sina)',
        'zh_Hans' => 'sinaeg (eeunaet)',
        'zh_Hans_CN' => 'sinaeg (eeunaet, Sina)',
        'zh_Hans_HK' => 'sinaeg (eeunaet, Hong Kong RMD Sina)',
        'zh_Hans_MO' => 'sinaeg (eeunaet, Makao RMD Sina)',
        'zh_Hans_MY' => 'sinaeg (eeunaet, Malaysia)',
        'zh_Hans_SG' => 'sinaeg (eeunaet, Singapoura)',
        'zh_Hant' => 'sinaeg (hengounel)',
        'zh_Hant_HK' => 'sinaeg (hengounel, Hong Kong RMD Sina)',
        'zh_Hant_MO' => 'sinaeg (hengounel, Makao RMD Sina)',
        'zh_Hant_MY' => 'sinaeg (hengounel, Malaysia)',
        'zh_Hant_TW' => 'sinaeg (hengounel, Taiwan)',
        'zh_MO' => 'sinaeg (Makao RMD Sina)',
        'zh_SG' => 'sinaeg (Singapoura)',
        'zh_TW' => 'sinaeg (Taiwan)',
        'zu' => 'zouloueg',
        'zu_ZA' => 'zouloueg (Suafrika)',
    ],
];
