<?php

return [
    'UserAssignedNames' => [
        'XK' => 'โคโซโว',
    ],
    'Names' => [
        'AD' => 'อันดอร์รา',
        'AE' => 'สหรัฐอาหรับเอมิเรตส์',
        'AF' => 'อัฟกานิสถาน',
        'AG' => 'แอนติกาและบาร์บูดา',
        'AI' => 'แองกวิลลา',
        'AL' => 'แอลเบเนีย',
        'AM' => 'อาร์เมเนีย',
        'AO' => 'แองโกลา',
        'AQ' => 'แอนตาร์กติกา',
        'AR' => 'อาร์เจนตินา',
        'AS' => 'อเมริกันซามัว',
        'AT' => 'ออสเตรีย',
        'AU' => 'ออสเตรเลีย',
        'AW' => 'อารูบา',
        'AX' => 'หมู่เกาะโอลันด์',
        'AZ' => 'อาเซอร์ไบจาน',
        'BA' => 'บอสเนียและเฮอร์เซโกวีนา',
        'BB' => 'บาร์เบโดส',
        'BD' => 'บังกลาเทศ',
        'BE' => 'เบลเยียม',
        'BF' => 'บูร์กินาฟาโซ',
        'BG' => 'บัลแกเรีย',
        'BH' => 'บาห์เรน',
        'BI' => 'บุรุนดี',
        'BJ' => 'เบนิน',
        'BL' => 'เซนต์บาร์เธเลมี',
        'BM' => 'เบอร์มิวดา',
        'BN' => 'บรูไน',
        'BO' => 'โบลิเวีย',
        'BQ' => 'เนเธอร์แลนด์แคริบเบียน',
        'BR' => 'บราซิล',
        'BS' => 'บาฮามาส',
        'BT' => 'ภูฏาน',
        'BV' => 'เกาะบูเว',
        'BW' => 'บอตสวานา',
        'BY' => 'เบลารุส',
        'BZ' => 'เบลีซ',
        'CA' => 'แคนาดา',
        'CC' => 'หมู่เกาะโคโคส (คีลิง)',
        'CD' => 'คองโก - กินชาซา',
        'CF' => 'สาธารณรัฐแอฟริกากลาง',
        'CG' => 'คองโก - บราซซาวิล',
        'CH' => 'สวิตเซอร์แลนด์',
        'CI' => 'โกตดิวัวร์',
        'CK' => 'หมู่เกาะคุก',
        'CL' => 'ชิลี',
        'CM' => 'แคเมอรูน',
        'CN' => 'จีน',
        'CO' => 'โคลอมเบีย',
        'CR' => 'คอสตาริกา',
        'CU' => 'คิวบา',
        'CV' => 'เคปเวิร์ด',
        'CW' => 'คูราเซา',
        'CX' => 'เกาะคริสต์มาส',
        'CY' => 'ไซปรัส',
        'CZ' => 'เช็ก',
        'DE' => 'เยอรมนี',
        'DJ' => 'จิบูตี',
        'DK' => 'เดนมาร์ก',
        'DM' => 'โดมินิกา',
        'DO' => 'สาธารณรัฐโดมินิกัน',
        'DZ' => 'แอลจีเรีย',
        'EC' => 'เอกวาดอร์',
        'EE' => 'เอสโตเนีย',
        'EG' => 'อียิปต์',
        'EH' => 'ซาฮาราตะวันตก',
        'ER' => 'เอริเทรีย',
        'ES' => 'สเปน',
        'ET' => 'เอธิโอเปีย',
        'FI' => 'ฟินแลนด์',
        'FJ' => 'ฟิจิ',
        'FK' => 'หมู่เกาะฟอล์กแลนด์',
        'FM' => 'ไมโครนีเซีย',
        'FO' => 'หมู่เกาะแฟโร',
        'FR' => 'ฝรั่งเศส',
        'GA' => 'กาบอง',
        'GB' => 'สหราชอาณาจักร',
        'GD' => 'เกรเนดา',
        'GE' => 'จอร์เจีย',
        'GF' => 'เฟรนช์เกียนา',
        'GG' => 'เกิร์นซีย์',
        'GH' => 'กานา',
        'GI' => 'ยิบรอลตาร์',
        'GL' => 'กรีนแลนด์',
        'GM' => 'แกมเบีย',
        'GN' => 'กินี',
        'GP' => 'กวาเดอลูป',
        'GQ' => 'อิเควทอเรียลกินี',
        'GR' => 'กรีซ',
        'GS' => 'เกาะเซาท์จอร์เจียและหมู่เกาะเซาท์แซนด์วิช',
        'GT' => 'กัวเตมาลา',
        'GU' => 'กวม',
        'GW' => 'กินี-บิสเซา',
        'GY' => 'กายอานา',
        'HK' => 'เขตปกครองพิเศษฮ่องกงแห่งสาธารณรัฐประชาชนจีน',
        'HM' => 'เกาะเฮิร์ดและหมู่เกาะแมกดอนัลด์',
        'HN' => 'ฮอนดูรัส',
        'HR' => 'โครเอเชีย',
        'HT' => 'เฮติ',
        'HU' => 'ฮังการี',
        'ID' => 'อินโดนีเซีย',
        'IE' => 'ไอร์แลนด์',
        'IL' => 'อิสราเอล',
        'IM' => 'เกาะแมน',
        'IN' => 'อินเดีย',
        'IO' => 'บริติชอินเดียนโอเชียนเทร์ริทอรี',
        'IQ' => 'อิรัก',
        'IR' => 'อิหร่าน',
        'IS' => 'ไอซ์แลนด์',
        'IT' => 'อิตาลี',
        'JE' => 'เจอร์ซีย์',
        'JM' => 'จาเมกา',
        'JO' => 'จอร์แดน',
        'JP' => 'ญี่ปุ่น',
        'KE' => 'เคนยา',
        'KG' => 'คีร์กีซสถาน',
        'KH' => 'กัมพูชา',
        'KI' => 'คิริบาส',
        'KM' => 'คอโมโรส',
        'KN' => 'เซนต์คิตส์และเนวิส',
        'KP' => 'เกาหลีเหนือ',
        'KR' => 'เกาหลีใต้',
        'KW' => 'คูเวต',
        'KY' => 'หมู่เกาะเคย์แมน',
        'KZ' => 'คาซัคสถาน',
        'LA' => 'ลาว',
        'LB' => 'เลบานอน',
        'LC' => 'เซนต์ลูเซีย',
        'LI' => 'ลิกเตนสไตน์',
        'LK' => 'ศรีลังกา',
        'LR' => 'ไลบีเรีย',
        'LS' => 'เลโซโท',
        'LT' => 'ลิทัวเนีย',
        'LU' => 'ลักเซมเบิร์ก',
        'LV' => 'ลัตเวีย',
        'LY' => 'ลิเบีย',
        'MA' => 'โมร็อกโก',
        'MC' => 'โมนาโก',
        'MD' => 'มอลโดวา',
        'ME' => 'มอนเตเนโกร',
        'MF' => 'เซนต์มาร์ติน',
        'MG' => 'มาดากัสการ์',
        'MH' => 'หมู่เกาะมาร์แชลล์',
        'MK' => 'มาซิโดเนียเหนือ',
        'ML' => 'มาลี',
        'MM' => 'เมียนมา (พม่า)',
        'MN' => 'มองโกเลีย',
        'MO' => 'เขตปกครองพิเศษมาเก๊าแห่งสาธารณรัฐประชาชนจีน',
        'MP' => 'หมู่เกาะนอร์เทิร์นมาเรียนา',
        'MQ' => 'มาร์ตินีก',
        'MR' => 'มอริเตเนีย',
        'MS' => 'มอนต์เซอร์รัต',
        'MT' => 'มอลตา',
        'MU' => 'มอริเชียส',
        'MV' => 'มัลดีฟส์',
        'MW' => 'มาลาวี',
        'MX' => 'เม็กซิโก',
        'MY' => 'มาเลเซีย',
        'MZ' => 'โมซัมบิก',
        'NA' => 'นามิเบีย',
        'NC' => 'นิวแคลิโดเนีย',
        'NE' => 'ไนเจอร์',
        'NF' => 'เกาะนอร์ฟอล์ก',
        'NG' => 'ไนจีเรีย',
        'NI' => 'นิการากัว',
        'NL' => 'เนเธอร์แลนด์',
        'NO' => 'นอร์เวย์',
        'NP' => 'เนปาล',
        'NR' => 'นาอูรู',
        'NU' => 'นีอูเอ',
        'NZ' => 'นิวซีแลนด์',
        'OM' => 'โอมาน',
        'PA' => 'ปานามา',
        'PE' => 'เปรู',
        'PF' => 'เฟรนช์โปลินีเซีย',
        'PG' => 'ปาปัวนิวกินี',
        'PH' => 'ฟิลิปปินส์',
        'PK' => 'ปากีสถาน',
        'PL' => 'โปแลนด์',
        'PM' => 'แซงปีแยร์และมีเกอลง',
        'PN' => 'หมู่เกาะพิตแคร์น',
        'PR' => 'เปอร์โตริโก',
        'PS' => 'ดินแดนปาเลสไตน์',
        'PT' => 'โปรตุเกส',
        'PW' => 'ปาเลา',
        'PY' => 'ปารากวัย',
        'QA' => 'กาตาร์',
        'RE' => 'เรอูนียง',
        'RO' => 'โรมาเนีย',
        'RS' => 'เซอร์เบีย',
        'RU' => 'รัสเซีย',
        'RW' => 'รวันดา',
        'SA' => 'ซาอุดีอาระเบีย',
        'SB' => 'หมู่เกาะโซโลมอน',
        'SC' => 'เซเชลส์',
        'SD' => 'ซูดาน',
        'SE' => 'สวีเดน',
        'SG' => 'สิงคโปร์',
        'SH' => 'เซนต์เฮเลนา',
        'SI' => 'สโลวีเนีย',
        'SJ' => 'สฟาลบาร์และยานไมเอน',
        'SK' => 'สโลวะเกีย',
        'SL' => 'เซียร์ราลีโอน',
        'SM' => 'ซานมาริโน',
        'SN' => 'เซเนกัล',
        'SO' => 'โซมาเลีย',
        'SR' => 'ซูรินาเม',
        'SS' => 'ซูดานใต้',
        'ST' => 'เซาตูเมและปรินซิปี',
        'SV' => 'เอลซัลวาดอร์',
        'SX' => 'ซินต์มาร์เทน',
        'SY' => 'ซีเรีย',
        'SZ' => 'เอสวาตีนี',
        'TC' => 'หมู่เกาะเติกส์และหมู่เกาะเคคอส',
        'TD' => 'ชาด',
        'TF' => 'เฟรนช์เซาเทิร์นเทร์ริทอรีส์',
        'TG' => 'โตโก',
        'TH' => 'ไทย',
        'TJ' => 'ทาจิกิสถาน',
        'TK' => 'โตเกเลา',
        'TL' => 'ติมอร์-เลสเต',
        'TM' => 'เติร์กเมนิสถาน',
        'TN' => 'ตูนิเซีย',
        'TO' => 'ตองกา',
        'TR' => 'ตุรกี',
        'TT' => 'ตรินิแดดและโตเบโก',
        'TV' => 'ตูวาลู',
        'TW' => 'ไต้หวัน',
        'TZ' => 'แทนซาเนีย',
        'UA' => 'ยูเครน',
        'UG' => 'ยูกันดา',
        'UM' => 'หมู่เกาะรอบนอกของสหรัฐอเมริกา',
        'US' => 'สหรัฐอเมริกา',
        'UY' => 'อุรุกวัย',
        'UZ' => 'อุซเบกิสถาน',
        'VA' => 'นครวาติกัน',
        'VC' => 'เซนต์วินเซนต์และเกรนาดีนส์',
        'VE' => 'เวเนซุเอลา',
        'VG' => 'หมู่เกาะบริติชเวอร์จิน',
        'VI' => 'หมู่เกาะเวอร์จินของสหรัฐอเมริกา',
        'VN' => 'เวียดนาม',
        'VU' => 'วานูอาตู',
        'WF' => 'วาลลิสและฟุตูนา',
        'WS' => 'ซามัว',
        'YE' => 'เยเมน',
        'YT' => 'มายอต',
        'ZA' => 'แอฟริกาใต้',
        'ZM' => 'แซมเบีย',
        'ZW' => 'ซิมบับเว',
    ],
];
