<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'GMT (waxtu Greenwich) (Abidjan)',
        'Africa/Accra' => 'GMT (waxtu Greenwich) (Accra)',
        'Africa/Addis_Ababa' => 'Waxtu Afrique sowwu jant (Addis Ababa)',
        'Africa/Algiers' => 'CTE (waxtu ëroop sàntaraal) (Algiers)',
        'Africa/Asmera' => 'Waxtu Afrique sowwu jant (Asmara)',
        'Africa/Asmara' => 'Waxtu Afrique sowwu jant (Asmara)',
        'Africa/Bamako' => 'GMT (waxtu Greenwich) (Bamako)',
        'Africa/Bangui' => 'Waxtu sowwu Afrique (Bangui)',
        'Africa/Banjul' => 'GMT (waxtu Greenwich) (Banjul)',
        'Africa/Bissau' => 'GMT (waxtu Greenwich) (Bissau)',
        'Africa/Blantyre' => 'Waxtu Afrique Centrale (Blantyre)',
        'Africa/Brazzaville' => 'Waxtu sowwu Afrique (Brazzaville)',
        'Africa/Bujumbura' => 'Waxtu Afrique Centrale (Bujumbura)',
        'Africa/Cairo' => 'EET (waxtu ëroop u penku) (Cairo)',
        'Africa/Casablanca' => 'WET (waxtu ëroop u sowwu-jant (Casablanca)',
        'Africa/Ceuta' => 'CTE (waxtu ëroop sàntaraal) (Ceuta)',
        'Africa/Conakry' => 'GMT (waxtu Greenwich) (Conakry)',
        'Africa/Dakar' => 'GMT (waxtu Greenwich) (Dakar)',
        'Africa/Dar_es_Salaam' => 'Waxtu Afrique sowwu jant (Dar es Salaam)',
        'Africa/Djibouti' => 'Waxtu Afrique sowwu jant (Djibouti)',
        'Africa/Douala' => 'Waxtu sowwu Afrique (Douala)',
        'Africa/El_Aaiun' => 'WET (waxtu ëroop u sowwu-jant (El Aaiún)',
        'Africa/Freetown' => 'GMT (waxtu Greenwich) (Freetown)',
        'Africa/Gaborone' => 'Waxtu Afrique Centrale (Gaborone)',
        'Africa/Harare' => 'Waxtu Afrique Centrale (Harare)',
        'Africa/Johannesburg' => 'Afrique du Sud (Johannesburg)',
        'Africa/Juba' => 'Waxtu Afrique Centrale (Juba)',
        'Africa/Kampala' => 'Waxtu Afrique sowwu jant (Kampala)',
        'Africa/Khartoum' => 'Waxtu Afrique Centrale (Khartoum)',
        'Africa/Kigali' => 'Waxtu Afrique Centrale (Kigali)',
        'Africa/Kinshasa' => 'Waxtu sowwu Afrique (Kinshasa)',
        'Africa/Lagos' => 'Waxtu sowwu Afrique (Lagos)',
        'Africa/Libreville' => 'Waxtu sowwu Afrique (Libreville)',
        'Africa/Lome' => 'GMT (waxtu Greenwich) (Lomé)',
        'Africa/Luanda' => 'Waxtu sowwu Afrique (Luanda)',
        'Africa/Lubumbashi' => 'Waxtu Afrique Centrale (Lubumbashi)',
        'Africa/Lusaka' => 'Waxtu Afrique Centrale (Lusaka)',
        'Africa/Malabo' => 'Waxtu sowwu Afrique (Malabo)',
        'Africa/Maputo' => 'Waxtu Afrique Centrale (Maputo)',
        'Africa/Maseru' => 'Afrique du Sud (Maseru)',
        'Africa/Mbabane' => 'Afrique du Sud (Mbabane)',
        'Africa/Mogadishu' => 'Waxtu Afrique sowwu jant (Mogadishu)',
        'Africa/Monrovia' => 'GMT (waxtu Greenwich) (Monrovia)',
        'Africa/Nairobi' => 'Waxtu Afrique sowwu jant (Nairobi)',
        'Africa/Ndjamena' => 'Waxtu sowwu Afrique (N’Djamena)',
        'Africa/Niamey' => 'Waxtu sowwu Afrique (Niamey)',
        'Africa/Nouakchott' => 'GMT (waxtu Greenwich) (Nouakchott)',
        'Africa/Ouagadougou' => 'GMT (waxtu Greenwich) (Ouagadougou)',
        'Africa/Porto-Novo' => 'Waxtu sowwu Afrique (Porto-Novo)',
        'Africa/Sao_Tome' => 'GMT (waxtu Greenwich) (São Tomé)',
        'Africa/Tripoli' => 'EET (waxtu ëroop u penku) (Tripoli)',
        'Africa/Tunis' => 'CTE (waxtu ëroop sàntaraal) (Tunis)',
        'Africa/Windhoek' => 'Waxtu Afrique Centrale (Windhoek)',
        'America/Adak' => 'Waxtu Hawaii-Aleutian (Adak)',
        'America/Anchorage' => 'Waxtu Alaska (Anchorage)',
        'America/Anguilla' => 'AT (waxtu atlàntik) (Anguilla)',
        'America/Antigua' => 'AT (waxtu atlàntik) (Antigua)',
        'America/Araguaina' => 'Waxtu Bresil (Araguaína)',
        'America/Argentina/La_Rioja' => 'Waxtu Arsantiin (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Waxtu Arsantiin (Río Gallegos)',
        'America/Argentina/Salta' => 'Waxtu Arsantiin (Salta)',
        'America/Argentina/San_Juan' => 'Waxtu Arsantiin (San Juan)',
        'America/Argentina/San_Luis' => 'Waxtu Arsantiin (San Luis)',
        'America/Argentina/Tucuman' => 'Waxtu Arsantiin (Tucumán)',
        'America/Argentina/Ushuaia' => 'Waxtu Arsantiin (Ushuaia)',
        'America/Aruba' => 'AT (waxtu atlàntik) (Aruba)',
        'America/Asuncion' => 'Waxtu Paraguay (Asunción)',
        'America/Bahia' => 'Waxtu Bresil (Bahia)',
        'America/Bahia_Banderas' => 'CT (waxtu sàntaral) (Bahía de Banderas)',
        'America/Barbados' => 'AT (waxtu atlàntik) (Barbados)',
        'America/Belem' => 'Waxtu Bresil (Belém)',
        'America/Belize' => 'CT (waxtu sàntaral) (Belize)',
        'America/Blanc-Sablon' => 'AT (waxtu atlàntik) (Blanc-Sablon)',
        'America/Boa_Vista' => 'Waxtu Amazon (Boa Vista)',
        'America/Bogota' => 'Waxtu Kolombi (Bogotá)',
        'America/Boise' => 'MT (waxtu tundu) (Boise)',
        'America/Buenos_Aires' => 'Waxtu Arsantiin (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Waxtu Arsantiin (Buenos Aires)',
        'America/Cambridge_Bay' => 'MT (waxtu tundu) (Cambridge Bay)',
        'America/Campo_Grande' => 'Waxtu Amazon (Campo Grande)',
        'America/Cancun' => 'ET waxtu penku (Cancún)',
        'America/Caracas' => 'Waxtu Venezuela (Caracas)',
        'America/Catamarca' => 'Waxtu Arsantiin (Catamarca)',
        'America/Argentina/Catamarca' => 'Waxtu Arsantiin (Catamarca)',
        'America/Cayenne' => 'Guyane française (Cayenne)',
        'America/Cayman' => 'ET waxtu penku (Cayman)',
        'America/Chicago' => 'CT (waxtu sàntaral) (Chicago)',
        'America/Chihuahua' => 'CT (waxtu sàntaral) (Chihuahua)',
        'America/Ciudad_Juarez' => 'MT (waxtu tundu) (Ciudad Juárez)',
        'America/Coral_Harbour' => 'ET waxtu penku (Atikokan)',
        'America/Atikokan' => 'ET waxtu penku (Atikokan)',
        'America/Cordoba' => 'Waxtu Arsantiin (Córdoba)',
        'America/Argentina/Cordoba' => 'Waxtu Arsantiin (Córdoba)',
        'America/Costa_Rica' => 'CT (waxtu sàntaral) (Costa Rica)',
        'America/Coyhaique' => 'Waxtu Sili (Coyhaique)',
        'America/Creston' => 'MT (waxtu tundu) (Creston)',
        'America/Cuiaba' => 'Waxtu Amazon (Cuiabá)',
        'America/Curacao' => 'AT (waxtu atlàntik) (Curaçao)',
        'America/Danmarkshavn' => 'GMT (waxtu Greenwich) (Danmarkshavn)',
        'America/Dawson' => 'Waxtu Yukon (Dawson)',
        'America/Dawson_Creek' => 'MT (waxtu tundu) (Dawson Creek)',
        'America/Denver' => 'MT (waxtu tundu) (Denver)',
        'America/Detroit' => 'ET waxtu penku (Detroit)',
        'America/Dominica' => 'AT (waxtu atlàntik) (Dominica)',
        'America/Edmonton' => 'MT (waxtu tundu) (Edmonton)',
        'America/Eirunepe' => 'Beresil (Eirunepé)',
        'America/El_Salvador' => 'CT (waxtu sàntaral) (El Salvador)',
        'America/Fort_Nelson' => 'MT (waxtu tundu) (Fort Nelson)',
        'America/Fortaleza' => 'Waxtu Bresil (Fortaleza)',
        'America/Glace_Bay' => 'AT (waxtu atlàntik) (Glace Bay)',
        'America/Godthab' => 'Girinlànd (Nuuk)',
        'America/Nuuk' => 'Girinlànd (Nuuk)',
        'America/Goose_Bay' => 'AT (waxtu atlàntik) (Goose Bay)',
        'America/Grand_Turk' => 'ET waxtu penku (Grand Turk)',
        'America/Grenada' => 'AT (waxtu atlàntik) (Grenada)',
        'America/Guadeloupe' => 'AT (waxtu atlàntik) (Guadeloupe)',
        'America/Guatemala' => 'CT (waxtu sàntaral) (Guatemala)',
        'America/Guayaquil' => 'waxtu Ecuador (Guayaquil)',
        'America/Guyana' => 'Waxtu Guyana',
        'America/Halifax' => 'AT (waxtu atlàntik) (Halifax)',
        'America/Havana' => 'Waxtu Cuba (Havana)',
        'America/Hermosillo' => 'waxtu pasifik bu Mexik (Hermosillo)',
        'America/Indiana/Knox' => 'CT (waxtu sàntaral) (Knox, Indiana)',
        'America/Indiana/Marengo' => 'ET waxtu penku (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'ET waxtu penku (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'CT (waxtu sàntaral) (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'ET waxtu penku (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'ET waxtu penku (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'ET waxtu penku (Winamac, Indiana)',
        'America/Indianapolis' => 'ET waxtu penku (Indianapolis)',
        'America/Indiana/Indianapolis' => 'ET waxtu penku (Indianapolis)',
        'America/Inuvik' => 'MT (waxtu tundu) (Inuvik)',
        'America/Iqaluit' => 'ET waxtu penku (Iqaluit)',
        'America/Jamaica' => 'ET waxtu penku (Jamaica)',
        'America/Jujuy' => 'Waxtu Arsantiin (Jujuy)',
        'America/Argentina/Jujuy' => 'Waxtu Arsantiin (Jujuy)',
        'America/Juneau' => 'Waxtu Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'ET waxtu penku (Monticello, Kentucky)',
        'America/Kralendijk' => 'AT (waxtu atlàntik) (Kralendijk)',
        'America/La_Paz' => 'Waxtu Bolivie (La Paz)',
        'America/Lima' => 'Peru waxtu (Lima)',
        'America/Los_Angeles' => 'PT (waxtu pasifik) (Los Angeles)',
        'America/Louisville' => 'ET waxtu penku (Louisville)',
        'America/Kentucky/Louisville' => 'ET waxtu penku (Louisville)',
        'America/Lower_Princes' => 'AT (waxtu atlàntik) (Lower Prince’s Quarter)',
        'America/Maceio' => 'Waxtu Bresil (Maceió)',
        'America/Managua' => 'CT (waxtu sàntaral) (Managua)',
        'America/Manaus' => 'Waxtu Amazon (Manaus)',
        'America/Marigot' => 'AT (waxtu atlàntik) (Marigot)',
        'America/Martinique' => 'AT (waxtu atlàntik) (Martinique)',
        'America/Matamoros' => 'CT (waxtu sàntaral) (Matamoros)',
        'America/Mazatlan' => 'waxtu pasifik bu Mexik (Mazatlán)',
        'America/Mendoza' => 'Waxtu Arsantiin (Mendoza)',
        'America/Argentina/Mendoza' => 'Waxtu Arsantiin (Mendoza)',
        'America/Menominee' => 'CT (waxtu sàntaral) (Menominee)',
        'America/Merida' => 'CT (waxtu sàntaral) (Mérida)',
        'America/Metlakatla' => 'Waxtu Alaska (Metlakatla)',
        'America/Mexico_City' => 'CT (waxtu sàntaral) (Ciudad de México)',
        'America/Miquelon' => 'Saint Pierre ak Miquelon',
        'America/Moncton' => 'AT (waxtu atlàntik) (Moncton)',
        'America/Monterrey' => 'CT (waxtu sàntaral) (Monterrey)',
        'America/Montevideo' => 'Waxtu Urugway (Montevideo)',
        'America/Montserrat' => 'AT (waxtu atlàntik) (Montserrat)',
        'America/Nassau' => 'ET waxtu penku (Nassau)',
        'America/New_York' => 'ET waxtu penku (New York)',
        'America/Nome' => 'Waxtu Alaska (Nome)',
        'America/Noronha' => 'Fernando de noronha',
        'America/North_Dakota/Beulah' => 'CT (waxtu sàntaral) (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'CT (waxtu sàntaral) (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'CT (waxtu sàntaral) (New Salem, North Dakota)',
        'America/Ojinaga' => 'CT (waxtu sàntaral) (Ojinaga)',
        'America/Panama' => 'ET waxtu penku (Panama)',
        'America/Paramaribo' => 'Waxtu Surinam (Paramaribo)',
        'America/Phoenix' => 'MT (waxtu tundu) (Phoenix)',
        'America/Port-au-Prince' => 'ET waxtu penku (Port-au-Prince)',
        'America/Port_of_Spain' => 'AT (waxtu atlàntik) (Port of Spain)',
        'America/Porto_Velho' => 'Waxtu Amazon (Porto Velho)',
        'America/Puerto_Rico' => 'AT (waxtu atlàntik) (Puerto Rico)',
        'America/Punta_Arenas' => 'Waxtu Sili (Punta Arenas)',
        'America/Rankin_Inlet' => 'CT (waxtu sàntaral) (Rankin Inlet)',
        'America/Recife' => 'Waxtu Bresil (Recife)',
        'America/Regina' => 'CT (waxtu sàntaral) (Regina)',
        'America/Resolute' => 'CT (waxtu sàntaral) (Resolute)',
        'America/Rio_Branco' => 'Beresil (Rio Branco)',
        'America/Santarem' => 'Waxtu Bresil (Santarém)',
        'America/Santiago' => 'Waxtu Sili (Santiago)',
        'America/Santo_Domingo' => 'AT (waxtu atlàntik) (Santo Domingo)',
        'America/Sao_Paulo' => 'Waxtu Bresil (São Paulo)',
        'America/Scoresbysund' => 'Girinlànd (Ittoqqortoormiit)',
        'America/Sitka' => 'Waxtu Alaska (Sitka)',
        'America/St_Barthelemy' => 'AT (waxtu atlàntik) (St. Barthélemy)',
        'America/St_Johns' => 'waxtu Terre-Neuve (St. John’s)',
        'America/St_Kitts' => 'AT (waxtu atlàntik) (St. Kitts)',
        'America/St_Lucia' => 'AT (waxtu atlàntik) (St. Lucia)',
        'America/St_Thomas' => 'AT (waxtu atlàntik) (St. Thomas)',
        'America/St_Vincent' => 'AT (waxtu atlàntik) (St. Vincent)',
        'America/Swift_Current' => 'CT (waxtu sàntaral) (Swift Current)',
        'America/Tegucigalpa' => 'CT (waxtu sàntaral) (Tegucigalpa)',
        'America/Thule' => 'AT (waxtu atlàntik) (Thule)',
        'America/Tijuana' => 'PT (waxtu pasifik) (Tijuana)',
        'America/Toronto' => 'ET waxtu penku (Toronto)',
        'America/Tortola' => 'AT (waxtu atlàntik) (Tortola)',
        'America/Vancouver' => 'PT (waxtu pasifik) (Vancouver)',
        'America/Whitehorse' => 'Waxtu Yukon (Whitehorse)',
        'America/Winnipeg' => 'CT (waxtu sàntaral) (Winnipeg)',
        'America/Yakutat' => 'Waxtu Alaska (Yakutat)',
        'Antarctica/Casey' => 'waxtu Australie bu bëtu Soow (Casey)',
        'Antarctica/Davis' => 'Waxtu Davis',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urville',
        'Antarctica/Macquarie' => 'waxtu penku Australie (Macquarie)',
        'Antarctica/Mawson' => 'waxtu Mawson',
        'Antarctica/McMurdo' => 'Waxtu Nouvelle-Zélande (McMurdo)',
        'Antarctica/Palmer' => 'Waxtu Sili (Palmer)',
        'Antarctica/Rothera' => 'Waxtu Rotera (Rothera)',
        'Antarctica/Syowa' => 'waxtu syowa (Showa)',
        'Antarctica/Troll' => 'GMT (waxtu Greenwich) (Troll)',
        'Antarctica/Vostok' => 'Waxtu Vostok',
        'Arctic/Longyearbyen' => 'CTE (waxtu ëroop sàntaraal) (Longyearbyen)',
        'Asia/Aden' => 'Waxtu araab yi (Aden)',
        'Asia/Almaty' => 'Waxtu Kazakhstaan (Almaty)',
        'Asia/Amman' => 'EET (waxtu ëroop u penku) (Amman)',
        'Asia/Anadyr' => 'Risi (Anadyr)',
        'Asia/Aqtau' => 'Waxtu Kazakhstaan (Aqtau)',
        'Asia/Aqtobe' => 'Waxtu Kazakhstaan (Aqtobe)',
        'Asia/Ashgabat' => 'Waxtu Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'Waxtu Kazakhstaan (Atyrau)',
        'Asia/Baghdad' => 'Waxtu araab yi (Baghdad)',
        'Asia/Bahrain' => 'Waxtu araab yi (Bahrain)',
        'Asia/Baku' => 'Azerbaïdjan Waxtu (Baku)',
        'Asia/Bangkok' => 'waxtu Indochine (Bangkok)',
        'Asia/Barnaul' => 'Waxtu Krasnoyarsk (Barnaul)',
        'Asia/Beirut' => 'EET (waxtu ëroop u penku) (Beirut)',
        'Asia/Bishkek' => 'Waxtu Kirgistan (Bishkek)',
        'Asia/Brunei' => 'Brunei Darussalam',
        'Asia/Calcutta' => 'Waxtu Inde (Kolkata)',
        'Asia/Kolkata' => 'Waxtu Inde (Kolkata)',
        'Asia/Chita' => 'Yakutsk Waxtu (Chita)',
        'Asia/Colombo' => 'Waxtu Inde (Colombo)',
        'Asia/Damascus' => 'EET (waxtu ëroop u penku) (Damascus)',
        'Asia/Dhaka' => 'Waxtu Bangladesh (Dhaka)',
        'Asia/Dili' => 'Timor oriental (Dili)',
        'Asia/Dubai' => 'Waxtu Golf (Dubai)',
        'Asia/Dushanbe' => 'Waxtu Tajikistaan (Dushanbe)',
        'Asia/Famagusta' => 'EET (waxtu ëroop u penku) (Famagusta)',
        'Asia/Gaza' => 'EET (waxtu ëroop u penku) (Gaza)',
        'Asia/Hebron' => 'EET (waxtu ëroop u penku) (Hebron)',
        'Asia/Hong_Kong' => 'waxtu Hong Kong',
        'Asia/Hovd' => 'Hovd waxtu (Khovd)',
        'Asia/Irkutsk' => 'Waxtu rkutsk (Irkutsk)',
        'Asia/Jakarta' => 'waxtu sowwu Enndonesi (Jakarta)',
        'Asia/Jayapura' => 'waxtu penku Enndonesi (Jayapura)',
        'Asia/Jerusalem' => 'Waxtu Israel (Jerusalem)',
        'Asia/Kabul' => 'waxtu Afganistan (Kabul)',
        'Asia/Kamchatka' => 'Risi (Kamchatka)',
        'Asia/Karachi' => 'Waxtu Pakistan (Karachi)',
        'Asia/Katmandu' => 'waxtu Nepal (Kathmandu)',
        'Asia/Kathmandu' => 'waxtu Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Yakutsk Waxtu (Khandyga)',
        'Asia/Krasnoyarsk' => 'Waxtu Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Malaysie (Kuala Lumpur)',
        'Asia/Kuching' => 'Malaysie (Kuching)',
        'Asia/Kuwait' => 'Waxtu araab yi (Kuwait)',
        'Asia/Macau' => 'Waxtu Chine (Macao)',
        'Asia/Magadan' => 'Waxtu Magadaan (Magadan)',
        'Asia/Makassar' => 'Waxtu Enndonesi bu diggi bi (Makassar)',
        'Asia/Manila' => 'filippines waxtu (Manila)',
        'Asia/Muscat' => 'Waxtu Golf (Muscat)',
        'Asia/Nicosia' => 'EET (waxtu ëroop u penku) (Nicosia)',
        'Asia/Novokuznetsk' => 'Waxtu Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Waxtu Krasnoyarsk (Novosibirsk)',
        'Asia/Omsk' => 'Waxtu Omsk',
        'Asia/Oral' => 'Waxtu Kazakhstaan (Oral)',
        'Asia/Phnom_Penh' => 'waxtu Indochine (Phnom Penh)',
        'Asia/Pontianak' => 'waxtu sowwu Enndonesi (Pontianak)',
        'Asia/Pyongyang' => 'waxtu Kore (Pyongyang)',
        'Asia/Qatar' => 'Waxtu araab yi (Qatar)',
        'Asia/Qostanay' => 'Waxtu Kazakhstaan (Qostanay)',
        'Asia/Qyzylorda' => 'Waxtu Kazakhstaan (Qyzylorda)',
        'Asia/Rangoon' => 'waxtu Myanmar (Yangon)',
        'Asia/Yangon' => 'waxtu Myanmar (Yangon)',
        'Asia/Riyadh' => 'Waxtu araab yi (Riyadh)',
        'Asia/Saigon' => 'waxtu Indochine (Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'waxtu Indochine (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Waxtu Magadaan (Sakhalin)',
        'Asia/Samarkand' => 'Waxtu Ouzbékistan (Samarkand)',
        'Asia/Seoul' => 'waxtu Kore (Seoul)',
        'Asia/Shanghai' => 'Waxtu Chine (Shanghai)',
        'Asia/Singapore' => 'waxtu buñ miin ci Singapuur (Singapore)',
        'Asia/Srednekolymsk' => 'Waxtu Magadaan (Srednekolymsk)',
        'Asia/Taipei' => 'Waxtu Taipei',
        'Asia/Tashkent' => 'Waxtu Ouzbékistan (Tashkent)',
        'Asia/Tbilisi' => 'Waxtu Georgie (Tbilisi)',
        'Asia/Tehran' => 'Waxtu Iran (Tehran)',
        'Asia/Thimphu' => 'waxtu Bhoutan (Thimphu)',
        'Asia/Tokyo' => 'Japon (Tokyo)',
        'Asia/Tomsk' => 'Waxtu Krasnoyarsk (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulaan Baatar (Ulaanbaatar)',
        'Asia/Urumqi' => 'Siin (Ürümqi)',
        'Asia/Ust-Nera' => 'Waxtu Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'waxtu Indochine (Vientiane)',
        'Asia/Vladivostok' => 'Waxtu Vladivostok',
        'Asia/Yakutsk' => 'Yakutsk Waxtu',
        'Asia/Yekaterinburg' => 'Waxtu Yekaterinburg',
        'Asia/Yerevan' => 'Waxtu Armeni (Yerevan)',
        'Atlantic/Azores' => 'Waxtu Azores',
        'Atlantic/Bermuda' => 'AT (waxtu atlàntik) (Bermuda)',
        'Atlantic/Canary' => 'WET (waxtu ëroop u sowwu-jant (Canarias)',
        'Atlantic/Cape_Verde' => 'Cape Verde',
        'Atlantic/Faeroe' => 'WET (waxtu ëroop u sowwu-jant (Faroe)',
        'Atlantic/Faroe' => 'WET (waxtu ëroop u sowwu-jant (Faroe)',
        'Atlantic/Madeira' => 'WET (waxtu ëroop u sowwu-jant (Madeira)',
        'Atlantic/Reykjavik' => 'GMT (waxtu Greenwich) (Reykjavik)',
        'Atlantic/South_Georgia' => 'Georgie du Sud (South Georgia)',
        'Atlantic/St_Helena' => 'GMT (waxtu Greenwich) (St. Helena)',
        'Atlantic/Stanley' => 'Falkland time (Stanley)',
        'Australia/Adelaide' => 'Waxtu Australie bu diggi bi (Adelaide)',
        'Australia/Brisbane' => 'waxtu penku Australie (Brisbane)',
        'Australia/Broken_Hill' => 'Waxtu Australie bu diggi bi (Broken Hill)',
        'Australia/Darwin' => 'Waxtu Australie bu diggi bi (Darwin)',
        'Australia/Eucla' => 'Waxtu sowwu Australie (Eucla)',
        'Australia/Hobart' => 'waxtu penku Australie (Hobart)',
        'Australia/Lindeman' => 'waxtu penku Australie (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howe Time',
        'Australia/Melbourne' => 'waxtu penku Australie (Melbourne)',
        'Australia/Perth' => 'waxtu Australie bu bëtu Soow (Perth)',
        'Australia/Sydney' => 'waxtu penku Australie (Sydney)',
        'Etc/GMT' => 'GMT (waxtu Greenwich)',
        'Etc/UTC' => 'CUT (waxtu iniwelsel yuñ boole)',
        'Europe/Amsterdam' => 'CTE (waxtu ëroop sàntaraal) (Amsterdam)',
        'Europe/Andorra' => 'CTE (waxtu ëroop sàntaraal) (Andorra)',
        'Europe/Astrakhan' => 'Risi (Astrakhan)',
        'Europe/Athens' => 'EET (waxtu ëroop u penku) (Athens)',
        'Europe/Belgrade' => 'CTE (waxtu ëroop sàntaraal) (Belgrade)',
        'Europe/Berlin' => 'CTE (waxtu ëroop sàntaraal) (Berlin)',
        'Europe/Bratislava' => 'CTE (waxtu ëroop sàntaraal) (Bratislava)',
        'Europe/Brussels' => 'CTE (waxtu ëroop sàntaraal) (Brussels)',
        'Europe/Bucharest' => 'EET (waxtu ëroop u penku) (Bucharest)',
        'Europe/Budapest' => 'CTE (waxtu ëroop sàntaraal) (Budapest)',
        'Europe/Busingen' => 'CTE (waxtu ëroop sàntaraal) (Büsingen)',
        'Europe/Chisinau' => 'EET (waxtu ëroop u penku) (Chișinău)',
        'Europe/Copenhagen' => 'CTE (waxtu ëroop sàntaraal) (Copenhagen)',
        'Europe/Dublin' => 'GMT (waxtu Greenwich) (Dublin)',
        'Europe/Gibraltar' => 'CTE (waxtu ëroop sàntaraal) (Gibraltar)',
        'Europe/Guernsey' => 'GMT (waxtu Greenwich) (Guernsey)',
        'Europe/Helsinki' => 'EET (waxtu ëroop u penku) (Helsinki)',
        'Europe/Isle_of_Man' => 'GMT (waxtu Greenwich) (Isle of Man)',
        'Europe/Istanbul' => 'Tirki (Istanbul)',
        'Europe/Jersey' => 'GMT (waxtu Greenwich) (Jersey)',
        'Europe/Kaliningrad' => 'EET (waxtu ëroop u penku) (Kaliningrad)',
        'Europe/Kiev' => 'EET (waxtu ëroop u penku) (Kyiv)',
        'Europe/Kyiv' => 'EET (waxtu ëroop u penku) (Kyiv)',
        'Europe/Kirov' => 'Waxtu Moscow (Kirov)',
        'Europe/Lisbon' => 'WET (waxtu ëroop u sowwu-jant (Lisbon)',
        'Europe/Ljubljana' => 'CTE (waxtu ëroop sàntaraal) (Ljubljana)',
        'Europe/London' => 'GMT (waxtu Greenwich) (London)',
        'Europe/Luxembourg' => 'CTE (waxtu ëroop sàntaraal) (Luxembourg)',
        'Europe/Madrid' => 'CTE (waxtu ëroop sàntaraal) (Madrid)',
        'Europe/Malta' => 'CTE (waxtu ëroop sàntaraal) (Malta)',
        'Europe/Mariehamn' => 'EET (waxtu ëroop u penku) (Mariehamn)',
        'Europe/Minsk' => 'Waxtu Moscow (Minsk)',
        'Europe/Monaco' => 'CTE (waxtu ëroop sàntaraal) (Monaco)',
        'Europe/Moscow' => 'Waxtu Moscow',
        'Europe/Oslo' => 'CTE (waxtu ëroop sàntaraal) (Oslo)',
        'Europe/Paris' => 'CTE (waxtu ëroop sàntaraal) (Paris)',
        'Europe/Podgorica' => 'CTE (waxtu ëroop sàntaraal) (Podgorica)',
        'Europe/Prague' => 'CTE (waxtu ëroop sàntaraal) (Prague)',
        'Europe/Riga' => 'EET (waxtu ëroop u penku) (Riga)',
        'Europe/Rome' => 'CTE (waxtu ëroop sàntaraal) (Rome)',
        'Europe/Samara' => 'Risi (Samara)',
        'Europe/San_Marino' => 'CTE (waxtu ëroop sàntaraal) (San Marino)',
        'Europe/Sarajevo' => 'CTE (waxtu ëroop sàntaraal) (Sarajevo)',
        'Europe/Saratov' => 'Risi (Saratov)',
        'Europe/Simferopol' => 'Waxtu Moscow (Simferopol)',
        'Europe/Skopje' => 'CTE (waxtu ëroop sàntaraal) (Skopje)',
        'Europe/Sofia' => 'EET (waxtu ëroop u penku) (Sofia)',
        'Europe/Stockholm' => 'CTE (waxtu ëroop sàntaraal) (Stockholm)',
        'Europe/Tallinn' => 'EET (waxtu ëroop u penku) (Tallinn)',
        'Europe/Tirane' => 'CTE (waxtu ëroop sàntaraal) (Tirana)',
        'Europe/Ulyanovsk' => 'Risi (Ulyanovsk)',
        'Europe/Vaduz' => 'CTE (waxtu ëroop sàntaraal) (Vaduz)',
        'Europe/Vatican' => 'CTE (waxtu ëroop sàntaraal) (Vatican)',
        'Europe/Vienna' => 'CTE (waxtu ëroop sàntaraal) (Vienna)',
        'Europe/Vilnius' => 'EET (waxtu ëroop u penku) (Vilnius)',
        'Europe/Volgograd' => 'Waxtu Moscow (Volgograd)',
        'Europe/Warsaw' => 'CTE (waxtu ëroop sàntaraal) (Warsaw)',
        'Europe/Zagreb' => 'CTE (waxtu ëroop sàntaraal) (Zagreb)',
        'Europe/Zurich' => 'CTE (waxtu ëroop sàntaraal) (Zurich)',
        'Indian/Antananarivo' => 'Waxtu Afrique sowwu jant (Antananarivo)',
        'Indian/Chagos' => 'Waxtu géeju Inde (Chagos)',
        'Indian/Christmas' => 'waxtu ile bu noel (Christmas)',
        'Indian/Cocos' => 'Waxtu ile Cocos',
        'Indian/Comoro' => 'Waxtu Afrique sowwu jant (Comores)',
        'Indian/Kerguelen' => 'Waxtu Sud ak Antarctique bu Français (Kerguelen)',
        'Indian/Mahe' => 'Waxtu Seychelles (Mahé)',
        'Indian/Maldives' => 'Waxtu Maldives',
        'Indian/Mauritius' => 'waxtu Maurice (Mauritius)',
        'Indian/Mayotte' => 'Waxtu Afrique sowwu jant (Mayotte)',
        'Indian/Reunion' => 'waxtu ndaje (Réunion)',
        'Pacific/Apia' => 'Waxtu Apia',
        'Pacific/Auckland' => 'Waxtu Nouvelle-Zélande (Auckland)',
        'Pacific/Bougainville' => 'Papouasie-Nouvelle-Guiné (Bougainville)',
        'Pacific/Chatham' => 'waxtu Chatham',
        'Pacific/Easter' => 'Waxtu ile bu Pâques (Easter)',
        'Pacific/Efate' => 'Waxtu Vanuatu (Efate)',
        'Pacific/Enderbury' => 'waxtu ile Phoenix (Canton)',
        'Pacific/Kanton' => 'waxtu ile Phoenix (Canton)',
        'Pacific/Fakaofo' => 'Tokelau time (Fakaofo)',
        'Pacific/Fiji' => 'waxtu Fidji (Fiji)',
        'Pacific/Funafuti' => 'Waxtu Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'waxtu galapagos (Galápagos)',
        'Pacific/Gambier' => 'Waxtu Gambier',
        'Pacific/Guadalcanal' => 'Waxtu Ile Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Chamorro Standard Time (Guam)',
        'Pacific/Honolulu' => 'Waxtu buñ jagleel Hawaii-Aleutian (Honolulu)',
        'Pacific/Kiritimati' => 'Waxtu Ile Line (Kiritimati)',
        'Pacific/Kosrae' => 'Waxtu Kosrae',
        'Pacific/Kwajalein' => 'Waxtu Ile Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Waxtu Ile Marshall (Majuro)',
        'Pacific/Marquesas' => 'Waxtu Marquesas',
        'Pacific/Midway' => 'waxtu Samoa (Midway)',
        'Pacific/Nauru' => 'waxtu Nauru',
        'Pacific/Niue' => 'Waxtu Niue',
        'Pacific/Norfolk' => 'waxtu ile Norfolk',
        'Pacific/Noumea' => 'Waxtu New Caledonie (Nouméa)',
        'Pacific/Pago_Pago' => 'waxtu Samoa (Pago Pago)',
        'Pacific/Palau' => 'waxtu Palau',
        'Pacific/Pitcairn' => 'Waxtu Pitcairn',
        'Pacific/Ponape' => 'Waxtu Ponape (Pohnpei)',
        'Pacific/Pohnpei' => 'Waxtu Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Papouasie-Nouvelle-Guiné (Port Moresby)',
        'Pacific/Rarotonga' => 'Waxtu Ile Cook (Rarotonga)',
        'Pacific/Saipan' => 'Chamorro Standard Time (Saipan)',
        'Pacific/Tahiti' => 'waxtu Tahiti',
        'Pacific/Tarawa' => 'waxtu ile Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Waxtu Tonga (Tongatapu)',
        'Pacific/Truk' => 'Waxtu Chuuk',
        'Pacific/Chuuk' => 'Waxtu Chuuk',
        'Pacific/Wake' => 'Waxtu Ile Wake',
        'Pacific/Wallis' => 'Wallis & Futuna Time',
    ],
    'Meta' => [],
];
