<?php

return [
    'Names' => [
        'aa' => 'афарски',
        'ab' => 'абказијски',
        'ace' => 'ачинески',
        'ach' => 'аколи',
        'ada' => 'адангмејски',
        'ady' => 'адигејски',
        'ae' => 'авестански',
        'af' => 'африканс',
        'afh' => 'африхили',
        'agq' => 'ахемски',
        'ain' => 'аину',
        'ak' => 'акан',
        'akk' => 'акадијски',
        'ale' => 'аљут',
        'alt' => 'јужни алтаи',
        'am' => 'амхарски',
        'an' => 'арагонежански',
        'ang' => 'староенглески',
        'ann' => 'оболо',
        'anp' => 'ангика',
        'ar' => 'арапски',
        'arc' => 'армајски',
        'arn' => 'ароканијски',
        'arp' => 'арапахо',
        'ars' => 'најди арапски',
        'arw' => 'аравак',
        'as' => 'асемијски',
        'asa' => 'асу',
        'ast' => 'астуријски',
        'atj' => 'атикамекв',
        'av' => 'аварски',
        'awa' => 'авадхи',
        'ay' => 'ајмара',
        'az' => 'азербејџански',
        'ba' => 'башкир',
        'bal' => 'балучи',
        'ban' => 'балинезијски',
        'bas' => 'баса',
        'be' => 'бјелоруски',
        'bej' => 'беја',
        'bem' => 'бемба',
        'bez' => 'бена',
        'bg' => 'бугарски',
        'bho' => 'бојпури',
        'bi' => 'бислама',
        'bik' => 'бикол',
        'bin' => 'бини',
        'bla' => 'сисика',
        'bm' => 'бамбара',
        'bn' => 'бенгалски',
        'bo' => 'тибетански',
        'br' => 'бретонски',
        'bra' => 'брај',
        'brx' => 'бодо',
        'bs' => 'босански',
        'bua' => 'буриат',
        'bug' => 'бугинежански',
        'byn' => 'блин',
        'ca' => 'каталонски',
        'cad' => 'кадо',
        'car' => 'карипски',
        'cay' => 'Кајуга',
        'cch' => 'атсамски',
        'ccp' => 'чакма',
        'ce' => 'чеченски',
        'ceb' => 'цебуано',
        'cgg' => 'чига',
        'ch' => 'чаморо',
        'chb' => 'чибча',
        'chg' => 'чагатаи',
        'chk' => 'чукески',
        'chm' => 'мари',
        'chn' => 'чинукски',
        'cho' => 'чоктавски',
        'chp' => 'чипвијански',
        'chr' => 'чероки',
        'chy' => 'чејенски',
        'ckb' => 'централнокурдски',
        'clc' => 'Чилкотин',
        'co' => 'корзикански',
        'cop' => 'коптски',
        'cr' => 'кри',
        'crg' => 'мичиф',
        'crh' => 'кримеански турски',
        'crj' => 'јужноисточни кре',
        'crk' => 'равничарски кре',
        'crl' => 'сјеверно источни кре',
        'crm' => 'мосе кре',
        'crr' => 'алгонкуански за Каролину',
        'cs' => 'чешки',
        'csb' => 'кашубијански',
        'csw' => 'свампи кре',
        'cu' => 'старославенски',
        'cv' => 'чувашки',
        'cy' => 'велшки',
        'da' => 'дански',
        'dak' => 'дакота',
        'dar' => 'даргва',
        'dav' => 'таита',
        'de' => 'њемачки',
        'del' => 'делавер',
        'den' => 'славски',
        'dgr' => 'догриб',
        'din' => 'динка',
        'dje' => 'зарма',
        'doi' => 'догри',
        'dsb' => 'доњолужичкосрпски',
        'dua' => 'дуала',
        'dum' => 'средњи холандски',
        'dv' => 'дивехијски',
        'dyo' => 'јола-фоњи',
        'dyu' => 'ђула',
        'dz' => 'џонга',
        'dzg' => 'дазага',
        'ebu' => 'ембу',
        'ee' => 'еве',
        'efi' => 'ефикски',
        'egy' => 'староегипатски',
        'eka' => 'екајук',
        'el' => 'грчки',
        'elx' => 'еламитски',
        'en' => 'енглески',
        'enm' => 'средњи енглески',
        'eo' => 'есперанто',
        'es' => 'шпански',
        'et' => 'естонски',
        'eu' => 'баскијски',
        'ewo' => 'евондо',
        'fa' => 'персијски',
        'fan' => 'фанг',
        'fat' => 'фанти',
        'ff' => 'фулах',
        'fi' => 'фински',
        'fil' => 'филипински',
        'fj' => 'фиджијски',
        'fo' => 'фарски',
        'fon' => 'фон',
        'fr' => 'француски',
        'frc' => 'кајунски француски',
        'frm' => 'средњи француски',
        'fro' => 'старофранцуски',
        'frr' => 'северно-фризијски',
        'frs' => 'источни фризијски',
        'fur' => 'фриулијски',
        'fy' => 'западни фризијски',
        'ga' => 'ирски',
        'gaa' => 'га',
        'gay' => 'гајо',
        'gba' => 'гбаја',
        'gd' => 'шкотски галски',
        'gez' => 'џиз',
        'gil' => 'гилбертшки',
        'gl' => 'галски',
        'gmh' => 'средњи високи немачки',
        'gn' => 'гварани',
        'goh' => 'старонемачки',
        'gon' => 'гонди',
        'gor' => 'горонтало',
        'got' => 'готски',
        'grb' => 'гребо',
        'grc' => 'старогрчки',
        'gsw' => 'њемачки (Швицарска)',
        'gu' => 'гуџарати',
        'guz' => 'гуси',
        'gv' => 'манкс',
        'gwi' => 'гвич’ин',
        'ha' => 'хауса',
        'hai' => 'хаида',
        'haw' => 'хавајски',
        'hax' => 'јужни хаида',
        'he' => 'хебрејски',
        'hi' => 'хинди',
        'hil' => 'хилигајнон',
        'hit' => 'хитите',
        'hmn' => 'хмонг',
        'ho' => 'хири моту',
        'hr' => 'хрватски',
        'hsb' => 'горњолужичкосрпски',
        'ht' => 'хаићански креолски',
        'hu' => 'мађарски',
        'hup' => 'хупа',
        'hur' => 'халкомелем',
        'hy' => 'јерменски',
        'hz' => 'хереро',
        'ia' => 'интерлингва',
        'iba' => 'ибан',
        'ibb' => 'ибибио',
        'id' => 'индонежански',
        'ie' => 'међујезички',
        'ig' => 'игбо',
        'ii' => 'сечуан ји',
        'ik' => 'унупиак',
        'ikt' => 'западно канадски инуктитут',
        'ilo' => 'илоко',
        'inh' => 'ингвишки',
        'io' => 'идо',
        'is' => 'исландски',
        'it' => 'италијански',
        'iu' => 'инуктитут',
        'ja' => 'јапански',
        'jbo' => 'лојбан',
        'jgo' => 'нгомба',
        'jmc' => 'мачаме',
        'jpr' => 'јудео-персијски',
        'jrb' => 'јудео-арапски',
        'jv' => 'јавански',
        'ka' => 'грузијски',
        'kaa' => 'кара-калпашки',
        'kab' => 'кабиле',
        'kac' => 'качин',
        'kaj' => 'ђу',
        'kam' => 'камба',
        'kaw' => 'кави',
        'kbd' => 'кабардијски',
        'kcg' => 'тјап',
        'kde' => 'маконде',
        'kea' => 'кабовердијански креолски',
        'kfo' => 'коро',
        'kg' => 'конго',
        'kgp' => 'каинганг',
        'kha' => 'каси',
        'kho' => 'котанешки',
        'khq' => 'којра чини',
        'ki' => 'кикују',
        'kj' => 'куањама',
        'kk' => 'казашки',
        'kkj' => 'како',
        'kl' => 'калалисут',
        'kln' => 'калењин',
        'km' => 'кмерски',
        'kmb' => 'кимбунду',
        'kn' => 'канада',
        'ko' => 'корејски',
        'kok' => 'конкани',
        'kos' => 'косреански',
        'kpe' => 'кпеле',
        'kr' => 'канури',
        'krc' => 'карачај-балкар',
        'krl' => 'карелијски',
        'kru' => 'курукх',
        'ks' => 'кашмирски',
        'ksb' => 'шамбала',
        'ksf' => 'бафија',
        'ksh' => 'келнски',
        'ku' => 'курдски',
        'kum' => 'кумик',
        'kut' => 'кутенаи',
        'kv' => 'коми',
        'kw' => 'корнишки',
        'kwk' => 'кваквала',
        'ky' => 'киргиски',
        'la' => 'латински',
        'lad' => 'ладино',
        'lag' => 'ланги',
        'lah' => 'ланда',
        'lam' => 'ламба',
        'lb' => 'луксембуршки',
        'lez' => 'лезгиан',
        'lg' => 'ганда',
        'li' => 'лимбургиш',
        'lij' => 'линуриан',
        'lil' => 'лилоет',
        'lkt' => 'лакота',
        'ln' => 'лингала',
        'lo' => 'лаоски',
        'lol' => 'монго',
        'lou' => 'луизиански креолски',
        'loz' => 'лози',
        'lrc' => 'сјеверни лури',
        'lsm' => 'самиа',
        'lt' => 'литвански',
        'lu' => 'луба-катанга',
        'lua' => 'луба-лулуа',
        'lui' => 'луисено',
        'lun' => 'лунда',
        'luo' => 'луо',
        'lus' => 'лушаи',
        'luy' => 'луја',
        'lv' => 'латвијски',
        'mad' => 'мадурешки',
        'mag' => 'магахи',
        'mai' => 'маитили',
        'mak' => 'макасар',
        'man' => 'мандинго',
        'mas' => 'масаи',
        'mdf' => 'мокша',
        'mdr' => 'мандар',
        'men' => 'менде',
        'mer' => 'меру',
        'mfe' => 'мауритански',
        'mg' => 'малагасијски',
        'mga' => 'средњи ирски',
        'mgh' => 'макуа-мето',
        'mgo' => 'мета',
        'mh' => 'маршалски',
        'mi' => 'маорски',
        'mic' => 'микмак',
        'min' => 'минангкабау',
        'mk' => 'македонски',
        'ml' => 'малајалам',
        'mn' => 'монголски',
        'mnc' => 'манчу',
        'mni' => 'манипури',
        'moe' => 'иму-аимун',
        'moh' => 'махавски',
        'mos' => 'моси',
        'mr' => 'марати',
        'ms' => 'малајски',
        'mt' => 'малтешки',
        'mua' => 'мунданг',
        'mus' => 'кришки',
        'mwl' => 'мирандешки',
        'mwr' => 'марвари',
        'my' => 'бурмански',
        'myv' => 'ерзија',
        'mzn' => 'мазандерани',
        'na' => 'науру',
        'nap' => 'неаполитански',
        'naq' => 'нама',
        'nb' => 'норвешки бокмал',
        'nd' => 'сјеверни ндебеле',
        'nds' => 'ниски њемачки',
        'ne' => 'непалски',
        'new' => 'невари',
        'ng' => 'ндонга',
        'nia' => 'ниас',
        'niu' => 'ниуеан',
        'nl' => 'холандски',
        'nmg' => 'квасио',
        'nn' => 'норвешки нинорск',
        'nnh' => 'нгиембун',
        'no' => 'норвешки',
        'nog' => 'ногаи',
        'non' => 'стари норски',
        'nqo' => 'н’ко',
        'nr' => 'јужни ндебеле',
        'nso' => 'сјеверни сото',
        'nus' => 'нуер',
        'nv' => 'навахо',
        'nwc' => 'класични невари',
        'ny' => 'њања',
        'nym' => 'њамвези',
        'nyn' => 'њанколе',
        'nyo' => 'њоро',
        'nzi' => 'нзима',
        'oc' => 'провансалски',
        'oj' => 'ојибва',
        'ojb' => 'сјеверозападни ојибва',
        'ojc' => 'Централни обијва',
        'ojs' => 'оји-кре',
        'ojw' => 'западни ојибва',
        'oka' => 'оканаган',
        'om' => 'оромо',
        'or' => 'одија',
        'os' => 'осетски',
        'osa' => 'осаге',
        'ota' => 'отомански турски',
        'pa' => 'пенџапски',
        'pag' => 'пангасински',
        'pal' => 'пахлави',
        'pam' => 'пампанга',
        'pap' => 'папиаменто',
        'pau' => 'палауански',
        'pcm' => 'нигеријски пидгин',
        'peo' => 'староперсијски',
        'phn' => 'феничански',
        'pi' => 'пали',
        'pis' => 'пијин',
        'pl' => 'пољски',
        'pon' => 'понпејски',
        'pqm' => 'малисет-шасамкуоди',
        'prg' => 'пруски',
        'pro' => 'старопровансалски',
        'ps' => 'паштунски',
        'pt' => 'португалски',
        'qu' => 'квенча',
        'raj' => 'рађастани',
        'rap' => 'рапануи',
        'rar' => 'раротонган',
        'rhg' => 'рохимгја',
        'rm' => 'рето-романски',
        'rn' => 'рунди',
        'ro' => 'румунски',
        'rof' => 'ромбо',
        'rom' => 'романи',
        'ru' => 'руски',
        'rup' => 'ароманијски',
        'rw' => 'кинјаруанда',
        'rwk' => 'рва',
        'sa' => 'санскрит',
        'sad' => 'сандаве',
        'sah' => 'јакутски',
        'sam' => 'самаритански арамејски',
        'saq' => 'самбуру',
        'sas' => 'сасак',
        'sat' => 'сантали',
        'sba' => 'нгамбеј',
        'sbp' => 'сангу',
        'sc' => 'сардињаски',
        'scn' => 'сицилијански',
        'sco' => 'шкотски',
        'sd' => 'синди',
        'se' => 'сјеверни сами',
        'seh' => 'сена',
        'sel' => 'селкап',
        'ses' => 'којраборо сени',
        'sg' => 'санго',
        'sga' => 'староирски',
        'sh' => 'српскохрватски',
        'shi' => 'ташелхит',
        'shn' => 'шан',
        'si' => 'синхалски',
        'sid' => 'сидамо',
        'sk' => 'словачки',
        'sl' => 'словенски',
        'slh' => 'јужни лушотсед',
        'sm' => 'самоански',
        'sma' => 'јужни сами',
        'smj' => 'луле сами',
        'smn' => 'инари сами',
        'sms' => 'сколтски језик',
        'sn' => 'шона',
        'snk' => 'сонинке',
        'so' => 'сомалски',
        'sog' => 'соџијенски',
        'sq' => 'албански',
        'sr' => 'српски',
        'srn' => 'сранански тонго',
        'srr' => 'серер',
        'ss' => 'свати',
        'st' => 'сесото',
        'str' => 'страитс салиш',
        'su' => 'сундански',
        'suk' => 'сукума',
        'sus' => 'сусу',
        'sux' => 'сумерски',
        'sv' => 'шведски',
        'sw' => 'свахили',
        'swb' => 'коморски',
        'syc' => 'класични сиријски',
        'syr' => 'сиријски',
        'ta' => 'тамилски',
        'tce' => 'јужни тутчоне',
        'te' => 'телугу',
        'tem' => 'тимне',
        'teo' => 'тесо',
        'ter' => 'терено',
        'tet' => 'тетум',
        'tg' => 'таџички',
        'tgx' => 'тагиш',
        'th' => 'тајландски',
        'tht' => 'талтан',
        'ti' => 'тигриња',
        'tig' => 'тигре',
        'tiv' => 'тив',
        'tk' => 'туркменски',
        'tkl' => 'токелау',
        'tl' => 'тагалски',
        'tlh' => 'клингонски',
        'tli' => 'тлингит',
        'tmh' => 'тамашек',
        'tn' => 'тсвана',
        'to' => 'тонга',
        'tog' => 'њаса тонга',
        'tok' => 'токи пона',
        'tpi' => 'ток писин',
        'tr' => 'турски',
        'trv' => 'тароко',
        'ts' => 'тсонга',
        'tsi' => 'тсимшиан',
        'tt' => 'татарски',
        'ttm' => 'сјеверни тутчоне',
        'tum' => 'тумбука',
        'tvl' => 'тувалу',
        'tw' => 'тви',
        'twq' => 'тасавак',
        'ty' => 'тахићански',
        'tyv' => 'тувинијски',
        'tzm' => 'централноатласки тамазихт',
        'udm' => 'удмурт',
        'ug' => 'ујгурски',
        'uga' => 'угаритски',
        'uk' => 'украјински',
        'umb' => 'умбунду',
        'ur' => 'урду',
        'uz' => 'узбечки',
        'vai' => 'ваи',
        've' => 'венда',
        'vec' => 'венецијански',
        'vi' => 'вијетнамски',
        'vo' => 'волапук',
        'vot' => 'вотски',
        'vun' => 'вунјо',
        'wa' => 'валун',
        'wae' => 'валсерски',
        'wal' => 'валамо',
        'war' => 'варај',
        'was' => 'вашо',
        'wo' => 'волоф',
        'wuu' => 'ву кинески',
        'xal' => 'калмик',
        'xh' => 'коса',
        'xog' => 'сога',
        'yao' => 'јао',
        'yap' => 'јапешки',
        'yav' => 'јангбен',
        'ybb' => 'јемба',
        'yi' => 'јидиш',
        'yo' => 'јоруба',
        'yrl' => 'ненгату',
        'yue' => 'кантонски',
        'za' => 'жуанг',
        'zap' => 'запотечки',
        'zbl' => 'блисимболи',
        'zen' => 'зенага',
        'zgh' => 'стандардни марокански тамазихт',
        'zh' => 'кинески',
        'zu' => 'зулу',
        'zun' => 'зуни',
        'zza' => 'заза',
    ],
    'LocalizedNames' => [
        'ar_001' => 'арапски (стандардни)',
        'de_CH' => 'високи њемачки (Швицарска)',
        'nl_BE' => 'фламански',
        'ro_MD' => 'молдавски',
        'zh_Hans' => 'кинески (поједностављен)',
    ],
];
