<?php

return [
    'Names' => [
        'af' => 'Afrikaanka',
        'af_NA' => 'Afrikaanka (Namiibiya)',
        'af_ZA' => 'Afrikaanka (Koonfur Afrika)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Gaana)',
        'am' => 'Axmaar',
        'am_ET' => 'Axmaar (Itoobiya)',
        'ar' => 'Carabi',
        'ar_001' => 'Carabi (dunida)',
        'ar_AE' => 'Carabi (Midawga Imaaraatka Carabta)',
        'ar_BH' => 'Carabi (Baxreyn)',
        'ar_DJ' => 'Carabi (Jabuuti)',
        'ar_DZ' => 'Carabi (Aljeeriya)',
        'ar_EG' => 'Carabi (Masar)',
        'ar_EH' => 'Carabi (Saxaraha Galbeed)',
        'ar_ER' => 'Carabi (Eritreeya)',
        'ar_IL' => 'Carabi (Israaʼiil)',
        'ar_IQ' => 'Carabi (Ciraaq)',
        'ar_JO' => 'Carabi (Urdun)',
        'ar_KM' => 'Carabi (Komooros)',
        'ar_KW' => 'Carabi (Kuwayt)',
        'ar_LB' => 'Carabi (Lubnaan)',
        'ar_LY' => 'Carabi (Liibya)',
        'ar_MA' => 'Carabi (Morooko)',
        'ar_MR' => 'Carabi (Muritaaniya)',
        'ar_OM' => 'Carabi (Cumaan)',
        'ar_PS' => 'Carabi (Dhulka Falastiiniyiinta daanta galbeed iyo marinka qasa)',
        'ar_QA' => 'Carabi (Qadar)',
        'ar_SA' => 'Carabi (Sacuudi Carabiya)',
        'ar_SD' => 'Carabi (Suudaan)',
        'ar_SO' => 'Carabi (Soomaaliya)',
        'ar_SS' => 'Carabi (Koonfur Suudaan)',
        'ar_SY' => 'Carabi (Suuriya)',
        'ar_TD' => 'Carabi (Jaad)',
        'ar_TN' => 'Carabi (Tuniisiya)',
        'ar_YE' => 'Carabi (Yaman)',
        'as' => 'Asaamiis',
        'as_IN' => 'Asaamiis (Hindiya)',
        'az' => 'Asarbayjan',
        'az_AZ' => 'Asarbayjan (Asarbajan)',
        'az_Cyrl' => 'Asarbayjan (Siriylik)',
        'az_Cyrl_AZ' => 'Asarbayjan (Siriylik, Asarbajan)',
        'az_Latn' => 'Asarbayjan (Laatiin)',
        'az_Latn_AZ' => 'Asarbayjan (Laatiin, Asarbajan)',
        'ba' => 'Bashkir',
        'ba_RU' => 'Bashkir (Ruush)',
        'be' => 'Beleruusiyaan',
        'be_BY' => 'Beleruusiyaan (Belarus)',
        'bg' => 'Bulgeeriyaan',
        'bg_BG' => 'Bulgeeriyaan (Bulgaariya)',
        'bm' => 'Bambaara',
        'bm_ML' => 'Bambaara (Maali)',
        'bn' => 'Bangladesh',
        'bn_BD' => 'Bangladesh (Bangaladhesh)',
        'bn_IN' => 'Bangladesh (Hindiya)',
        'bo' => 'Tibeetaan',
        'bo_CN' => 'Tibeetaan (Shiinaha)',
        'bo_IN' => 'Tibeetaan (Hindiya)',
        'br' => 'Biriton',
        'br_FR' => 'Biriton (Faransiis)',
        'bs' => 'Bosniyaan',
        'bs_BA' => 'Bosniyaan (Boosniya & Harsegofina)',
        'bs_Cyrl' => 'Bosniyaan (Siriylik)',
        'bs_Cyrl_BA' => 'Bosniyaan (Siriylik, Boosniya & Harsegofina)',
        'bs_Latn' => 'Bosniyaan (Laatiin)',
        'bs_Latn_BA' => 'Bosniyaan (Laatiin, Boosniya & Harsegofina)',
        'ca' => 'Katalaan',
        'ca_AD' => 'Katalaan (Andora)',
        'ca_ES' => 'Katalaan (Isbeyn)',
        'ca_FR' => 'Katalaan (Faransiis)',
        'ca_IT' => 'Katalaan (Talyaani)',
        'ce' => 'Jejen',
        'ce_RU' => 'Jejen (Ruush)',
        'cs' => 'Jeeg',
        'cs_CZ' => 'Jeeg (Jekiya)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (Ruush)',
        'cy' => 'Welsh',
        'cy_GB' => 'Welsh (Boqortooyada Midowday)',
        'da' => 'Dhaanish',
        'da_DK' => 'Dhaanish (Denmark)',
        'da_GL' => 'Dhaanish (Greenland)',
        'de' => 'Jarmal',
        'de_AT' => 'Jarmal (Awsteriya)',
        'de_BE' => 'Jarmal (Biljam)',
        'de_CH' => 'Jarmal (Swiiserlaand)',
        'de_DE' => 'Jarmal (Jarmal)',
        'de_IT' => 'Jarmal (Talyaani)',
        'de_LI' => 'Jarmal (Liyjtensteyn)',
        'de_LU' => 'Jarmal (Luksemboorg)',
        'dz' => 'D’zongqa',
        'dz_BT' => 'D’zongqa (Buutan)',
        'ee' => 'Eewe',
        'ee_GH' => 'Eewe (Gaana)',
        'ee_TG' => 'Eewe (Toogo)',
        'el' => 'Giriik',
        'el_CY' => 'Giriik (Qubrus)',
        'el_GR' => 'Giriik (Giriig)',
        'en' => 'Ingiriisi',
        'en_001' => 'Ingiriisi (dunida)',
        'en_150' => 'Ingiriisi (Yurub)',
        'en_AE' => 'Ingiriisi (Midawga Imaaraatka Carabta)',
        'en_AG' => 'Ingiriisi (Antigua & Barbuuda)',
        'en_AI' => 'Ingiriisi (Anguula)',
        'en_AS' => 'Ingiriisi (Samowa Ameerika)',
        'en_AT' => 'Ingiriisi (Awsteriya)',
        'en_AU' => 'Ingiriisi (Awstaraaliya)',
        'en_BB' => 'Ingiriisi (Baarbadoos)',
        'en_BE' => 'Ingiriisi (Biljam)',
        'en_BI' => 'Ingiriisi (Burundi)',
        'en_BM' => 'Ingiriisi (Barmuuda)',
        'en_BS' => 'Ingiriisi (Bahaamas)',
        'en_BW' => 'Ingiriisi (Botuswaana)',
        'en_BZ' => 'Ingiriisi (Beliis)',
        'en_CA' => 'Ingiriisi (Kanada)',
        'en_CC' => 'Ingiriisi (Jasiiradda Kookoos)',
        'en_CH' => 'Ingiriisi (Swiiserlaand)',
        'en_CK' => 'Ingiriisi (Jasiiradda Kook)',
        'en_CM' => 'Ingiriisi (Kaameruun)',
        'en_CX' => 'Ingiriisi (Jasiiradda Kirismas)',
        'en_CY' => 'Ingiriisi (Qubrus)',
        'en_CZ' => 'Ingiriisi (Jekiya)',
        'en_DE' => 'Ingiriisi (Jarmal)',
        'en_DK' => 'Ingiriisi (Denmark)',
        'en_DM' => 'Ingiriisi (Dominika)',
        'en_EE' => 'Ingiriisi (Estooniya)',
        'en_ER' => 'Ingiriisi (Eritreeya)',
        'en_ES' => 'Ingiriisi (Isbeyn)',
        'en_FI' => 'Ingiriisi (Finland)',
        'en_FJ' => 'Ingiriisi (Fiji)',
        'en_FK' => 'Ingiriisi (Jaziiradaha Fooklaan)',
        'en_FM' => 'Ingiriisi (Mikroneesiya)',
        'en_FR' => 'Ingiriisi (Faransiis)',
        'en_GB' => 'Ingiriisi (Boqortooyada Midowday)',
        'en_GD' => 'Ingiriisi (Giriinaada)',
        'en_GE' => 'Ingiriisi (Joorjiya)',
        'en_GG' => 'Ingiriisi (Guurnsey)',
        'en_GH' => 'Ingiriisi (Gaana)',
        'en_GI' => 'Ingiriisi (Gibraltar)',
        'en_GM' => 'Ingiriisi (Gambiya)',
        'en_GS' => 'Ingiriisi (Jasiiradda Joorjiyada Koonfureed & Sandwij)',
        'en_GU' => 'Ingiriisi (Guaam)',
        'en_GY' => 'Ingiriisi (Guyana)',
        'en_HK' => 'Ingiriisi (Hong Kong)',
        'en_HU' => 'Ingiriisi (Hangari)',
        'en_ID' => 'Ingiriisi (Indoneesiya)',
        'en_IE' => 'Ingiriisi (Ayrlaand)',
        'en_IL' => 'Ingiriisi (Israaʼiil)',
        'en_IM' => 'Ingiriisi (Jasiiradda Isle of Man)',
        'en_IN' => 'Ingiriisi (Hindiya)',
        'en_IO' => 'Ingiriisi (Dhul xadeedka Badweynta Hindiya ee Ingiriiska)',
        'en_IT' => 'Ingiriisi (Talyaani)',
        'en_JE' => 'Ingiriisi (Jaarsey)',
        'en_JM' => 'Ingiriisi (Jamaaika)',
        'en_JP' => 'Ingiriisi (Jabaan)',
        'en_KE' => 'Ingiriisi (Kenya)',
        'en_KI' => 'Ingiriisi (Kiribati)',
        'en_KN' => 'Ingiriisi (St. Kitts iyo Nevis)',
        'en_KY' => 'Ingiriisi (Cayman Islands)',
        'en_LC' => 'Ingiriisi (St. Lusia)',
        'en_LR' => 'Ingiriisi (Laybeeriya)',
        'en_LS' => 'Ingiriisi (Losooto)',
        'en_LT' => 'Ingiriisi (Lituweeniya)',
        'en_LV' => 'Ingiriisi (Latfiya)',
        'en_MG' => 'Ingiriisi (Madagaskar)',
        'en_MH' => 'Ingiriisi (Jasiiradda Maarshal)',
        'en_MO' => 'Ingiriisi (Makaaw)',
        'en_MP' => 'Ingiriisi (Jasiiradda Waqooyiga Mariaana)',
        'en_MS' => 'Ingiriisi (Montserrat)',
        'en_MT' => 'Ingiriisi (Maalta)',
        'en_MU' => 'Ingiriisi (Mawrishiyaas)',
        'en_MV' => 'Ingiriisi (Maaldiifis)',
        'en_MW' => 'Ingiriisi (Malaawi)',
        'en_MY' => 'Ingiriisi (Malaysiya)',
        'en_NA' => 'Ingiriisi (Namiibiya)',
        'en_NF' => 'Ingiriisi (Jasiiradda Noorfolk)',
        'en_NG' => 'Ingiriisi (Nayjeeriya)',
        'en_NL' => 'Ingiriisi (Nederlaands)',
        'en_NO' => 'Ingiriisi (Noorweey)',
        'en_NR' => 'Ingiriisi (Nauru)',
        'en_NU' => 'Ingiriisi (Niue)',
        'en_NZ' => 'Ingiriisi (Niyuusiilaand)',
        'en_PG' => 'Ingiriisi (Babwa Niyuu Gini)',
        'en_PH' => 'Ingiriisi (Filibiin)',
        'en_PK' => 'Ingiriisi (Bakistaan)',
        'en_PL' => 'Ingiriisi (Booland)',
        'en_PN' => 'Ingiriisi (Bitkairn)',
        'en_PR' => 'Ingiriisi (Bueerto Riiko)',
        'en_PT' => 'Ingiriisi (Bortugaal)',
        'en_PW' => 'Ingiriisi (Balaaw)',
        'en_RO' => 'Ingiriisi (Rumaaniya)',
        'en_RW' => 'Ingiriisi (Ruwanda)',
        'en_SB' => 'Ingiriisi (Jasiiradda Solomon)',
        'en_SC' => 'Ingiriisi (Sishelis)',
        'en_SD' => 'Ingiriisi (Suudaan)',
        'en_SE' => 'Ingiriisi (Iswidhan)',
        'en_SG' => 'Ingiriisi (Singaboor)',
        'en_SH' => 'Ingiriisi (Saynt Helena)',
        'en_SI' => 'Ingiriisi (Islofeeniya)',
        'en_SK' => 'Ingiriisi (Islofaakiya)',
        'en_SL' => 'Ingiriisi (Siraaliyoon)',
        'en_SS' => 'Ingiriisi (Koonfur Suudaan)',
        'en_SX' => 'Ingiriisi (Siint Maarteen)',
        'en_SZ' => 'Ingiriisi (Eswaatiini)',
        'en_TC' => 'Ingiriisi (Turks & Kaikos Island)',
        'en_TK' => 'Ingiriisi (Tokelaaw)',
        'en_TO' => 'Ingiriisi (Tonga)',
        'en_TT' => 'Ingiriisi (Tirinidaad & Tobago)',
        'en_TV' => 'Ingiriisi (Tufaalu)',
        'en_TZ' => 'Ingiriisi (Tansaaniya)',
        'en_UA' => 'Ingiriisi (Yukrayn)',
        'en_UG' => 'Ingiriisi (Ugaanda)',
        'en_UM' => 'Ingiriisi (Jasiiradaha ka baxsan Maraykanka)',
        'en_US' => 'Ingiriisi (Maraykanka)',
        'en_VC' => 'Ingiriisi (St. Finsent & Girenadiins)',
        'en_VG' => 'Ingiriisi (Biritish Farjin Island)',
        'en_VI' => 'Ingiriisi (U.S Fargin Island)',
        'en_VU' => 'Ingiriisi (Fanuaatu)',
        'en_WS' => 'Ingiriisi (Samoowa)',
        'en_ZA' => 'Ingiriisi (Koonfur Afrika)',
        'en_ZM' => 'Ingiriisi (Saambiya)',
        'en_ZW' => 'Ingiriisi (Simbaabwe)',
        'eo' => 'Isberaanto',
        'eo_001' => 'Isberaanto (dunida)',
        'es' => 'Isbaanish',
        'es_419' => 'Isbaanish (Laatiin Ameerika)',
        'es_AR' => 'Isbaanish (Arjentiina)',
        'es_BO' => 'Isbaanish (Boliifiya)',
        'es_BR' => 'Isbaanish (Baraasiil)',
        'es_BZ' => 'Isbaanish (Beliis)',
        'es_CL' => 'Isbaanish (Jili)',
        'es_CO' => 'Isbaanish (Koloombiya)',
        'es_CR' => 'Isbaanish (Costa Rica)',
        'es_CU' => 'Isbaanish (Kuuba)',
        'es_DO' => 'Isbaanish (Jamhuuriyaddda Dominika)',
        'es_EC' => 'Isbaanish (Ikuwadoor)',
        'es_ES' => 'Isbaanish (Isbeyn)',
        'es_GQ' => 'Isbaanish (Ekuwatooriyal Gini)',
        'es_GT' => 'Isbaanish (Guwaatamaala)',
        'es_HN' => 'Isbaanish (Honduras)',
        'es_MX' => 'Isbaanish (Meksiko)',
        'es_NI' => 'Isbaanish (Nikaraaguwa)',
        'es_PA' => 'Isbaanish (Baanama)',
        'es_PE' => 'Isbaanish (Beeru)',
        'es_PH' => 'Isbaanish (Filibiin)',
        'es_PR' => 'Isbaanish (Bueerto Riiko)',
        'es_PY' => 'Isbaanish (Baraguaay)',
        'es_SV' => 'Isbaanish (El Salfadoor)',
        'es_US' => 'Isbaanish (Maraykanka)',
        'es_UY' => 'Isbaanish (Uruguwaay)',
        'es_VE' => 'Isbaanish (Fenisuweela)',
        'et' => 'Istooniyaan',
        'et_EE' => 'Istooniyaan (Estooniya)',
        'eu' => 'Basquu',
        'eu_ES' => 'Basquu (Isbeyn)',
        'fa' => 'Faarisi',
        'fa_AF' => 'Faarisi (Afgaanistaan)',
        'fa_IR' => 'Faarisi (Iiraan)',
        'ff' => 'Fuulah',
        'ff_Adlm' => 'Fuulah (Adlam)',
        'ff_Adlm_BF' => 'Fuulah (Adlam, Burkiina Faaso)',
        'ff_Adlm_CM' => 'Fuulah (Adlam, Kaameruun)',
        'ff_Adlm_GH' => 'Fuulah (Adlam, Gaana)',
        'ff_Adlm_GM' => 'Fuulah (Adlam, Gambiya)',
        'ff_Adlm_GN' => 'Fuulah (Adlam, Gini)',
        'ff_Adlm_GW' => 'Fuulah (Adlam, Gini-Bisaaw)',
        'ff_Adlm_LR' => 'Fuulah (Adlam, Laybeeriya)',
        'ff_Adlm_MR' => 'Fuulah (Adlam, Muritaaniya)',
        'ff_Adlm_NE' => 'Fuulah (Adlam, Nayjer)',
        'ff_Adlm_NG' => 'Fuulah (Adlam, Nayjeeriya)',
        'ff_Adlm_SL' => 'Fuulah (Adlam, Siraaliyoon)',
        'ff_Adlm_SN' => 'Fuulah (Adlam, Sinigaal)',
        'ff_CM' => 'Fuulah (Kaameruun)',
        'ff_GN' => 'Fuulah (Gini)',
        'ff_Latn' => 'Fuulah (Laatiin)',
        'ff_Latn_BF' => 'Fuulah (Laatiin, Burkiina Faaso)',
        'ff_Latn_CM' => 'Fuulah (Laatiin, Kaameruun)',
        'ff_Latn_GH' => 'Fuulah (Laatiin, Gaana)',
        'ff_Latn_GM' => 'Fuulah (Laatiin, Gambiya)',
        'ff_Latn_GN' => 'Fuulah (Laatiin, Gini)',
        'ff_Latn_GW' => 'Fuulah (Laatiin, Gini-Bisaaw)',
        'ff_Latn_LR' => 'Fuulah (Laatiin, Laybeeriya)',
        'ff_Latn_MR' => 'Fuulah (Laatiin, Muritaaniya)',
        'ff_Latn_NE' => 'Fuulah (Laatiin, Nayjer)',
        'ff_Latn_NG' => 'Fuulah (Laatiin, Nayjeeriya)',
        'ff_Latn_SL' => 'Fuulah (Laatiin, Siraaliyoon)',
        'ff_Latn_SN' => 'Fuulah (Laatiin, Sinigaal)',
        'ff_MR' => 'Fuulah (Muritaaniya)',
        'ff_SN' => 'Fuulah (Sinigaal)',
        'fi' => 'Finishka',
        'fi_FI' => 'Finishka (Finland)',
        'fo' => 'Farowsi',
        'fo_DK' => 'Farowsi (Denmark)',
        'fo_FO' => 'Farowsi (Jasiiradda Faroo)',
        'fr' => 'Faransiis',
        'fr_BE' => 'Faransiis (Biljam)',
        'fr_BF' => 'Faransiis (Burkiina Faaso)',
        'fr_BI' => 'Faransiis (Burundi)',
        'fr_BJ' => 'Faransiis (Biniin)',
        'fr_BL' => 'Faransiis (St. Baathelemiy)',
        'fr_CA' => 'Faransiis (Kanada)',
        'fr_CD' => 'Faransiis (Jamhuuriyadda Dimuquraadiga Kongo)',
        'fr_CF' => 'Faransiis (Jamhuuriyadda Afrikada Dhexe)',
        'fr_CG' => 'Faransiis (Kongo)',
        'fr_CH' => 'Faransiis (Swiiserlaand)',
        'fr_CI' => 'Faransiis (Ayfori Koost)',
        'fr_CM' => 'Faransiis (Kaameruun)',
        'fr_DJ' => 'Faransiis (Jabuuti)',
        'fr_DZ' => 'Faransiis (Aljeeriya)',
        'fr_FR' => 'Faransiis (Faransiis)',
        'fr_GA' => 'Faransiis (Gaaboon)',
        'fr_GF' => 'Faransiis (Faransiis Gini)',
        'fr_GN' => 'Faransiis (Gini)',
        'fr_GP' => 'Faransiis (Guadeluub)',
        'fr_GQ' => 'Faransiis (Ekuwatooriyal Gini)',
        'fr_HT' => 'Faransiis (Haiti)',
        'fr_KM' => 'Faransiis (Komooros)',
        'fr_LU' => 'Faransiis (Luksemboorg)',
        'fr_MA' => 'Faransiis (Morooko)',
        'fr_MC' => 'Faransiis (Moonako)',
        'fr_MF' => 'Faransiis (St. Maartin)',
        'fr_MG' => 'Faransiis (Madagaskar)',
        'fr_ML' => 'Faransiis (Maali)',
        'fr_MQ' => 'Faransiis (Maartinik)',
        'fr_MR' => 'Faransiis (Muritaaniya)',
        'fr_MU' => 'Faransiis (Mawrishiyaas)',
        'fr_NC' => 'Faransiis (Jasiiradda Niyuu Kaledooniya)',
        'fr_NE' => 'Faransiis (Nayjer)',
        'fr_PF' => 'Faransiis (Booliyneesiya Faransiiska)',
        'fr_PM' => 'Faransiis (St. Pierre iyo Miquelon)',
        'fr_RE' => 'Faransiis (Riyuuniyon)',
        'fr_RW' => 'Faransiis (Ruwanda)',
        'fr_SC' => 'Faransiis (Sishelis)',
        'fr_SN' => 'Faransiis (Sinigaal)',
        'fr_SY' => 'Faransiis (Suuriya)',
        'fr_TD' => 'Faransiis (Jaad)',
        'fr_TG' => 'Faransiis (Toogo)',
        'fr_TN' => 'Faransiis (Tuniisiya)',
        'fr_VU' => 'Faransiis (Fanuaatu)',
        'fr_WF' => 'Faransiis (Walis & Futuna)',
        'fr_YT' => 'Faransiis (Mayotte)',
        'fy' => 'Firiisiyan Galbeed',
        'fy_NL' => 'Firiisiyan Galbeed (Nederlaands)',
        'ga' => 'Ayrish',
        'ga_GB' => 'Ayrish (Boqortooyada Midowday)',
        'ga_IE' => 'Ayrish (Ayrlaand)',
        'gd' => 'Iskot Giilik',
        'gd_GB' => 'Iskot Giilik (Boqortooyada Midowday)',
        'gl' => 'Galiisiyaan',
        'gl_ES' => 'Galiisiyaan (Isbeyn)',
        'gu' => 'Gujaraati',
        'gu_IN' => 'Gujaraati (Hindiya)',
        'gv' => 'Mankis',
        'gv_IM' => 'Mankis (Jasiiradda Isle of Man)',
        'ha' => 'Hawsa',
        'ha_GH' => 'Hawsa (Gaana)',
        'ha_NE' => 'Hawsa (Nayjer)',
        'ha_NG' => 'Hawsa (Nayjeeriya)',
        'he' => 'Cibraani',
        'he_IL' => 'Cibraani (Israaʼiil)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (Hindiya)',
        'hi_Latn' => 'Hindi (Laatiin)',
        'hi_Latn_IN' => 'Hindi (Laatiin, Hindiya)',
        'hr' => 'Koro’eeshiyaan',
        'hr_BA' => 'Koro’eeshiyaan (Boosniya & Harsegofina)',
        'hr_HR' => 'Koro’eeshiyaan (Korweeshiya)',
        'hu' => 'Hangariyaan',
        'hu_HU' => 'Hangariyaan (Hangari)',
        'hy' => 'Armeeniyaan',
        'hy_AM' => 'Armeeniyaan (Armeeniya)',
        'ia' => 'Interlinguwa',
        'ia_001' => 'Interlinguwa (dunida)',
        'id' => 'Indunusiyaan',
        'id_ID' => 'Indunusiyaan (Indoneesiya)',
        'ie' => 'Interlingue',
        'ie_EE' => 'Interlingue (Estooniya)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nayjeeriya)',
        'ii' => 'Sijuwan Yi',
        'ii_CN' => 'Sijuwan Yi (Shiinaha)',
        'is' => 'Ayslandays',
        'is_IS' => 'Ayslandays (Ayslaand)',
        'it' => 'Talyaani',
        'it_CH' => 'Talyaani (Swiiserlaand)',
        'it_IT' => 'Talyaani (Talyaani)',
        'it_SM' => 'Talyaani (San Marino)',
        'it_VA' => 'Talyaani (Magaalada Faatikaan)',
        'ja' => 'Jabaaniis',
        'ja_JP' => 'Jabaaniis (Jabaan)',
        'jv' => 'Jafaaniis',
        'jv_ID' => 'Jafaaniis (Indoneesiya)',
        'ka' => 'Joorijiyaan',
        'ka_GE' => 'Joorijiyaan (Joorjiya)',
        'ki' => 'Kikuuyu',
        'ki_KE' => 'Kikuuyu (Kenya)',
        'kk' => 'Kasaaq',
        'kk_Arab' => 'Kasaaq (Carabi)',
        'kk_Arab_CN' => 'Kasaaq (Carabi, Shiinaha)',
        'kk_Cyrl' => 'Kasaaq (Siriylik)',
        'kk_Cyrl_KZ' => 'Kasaaq (Siriylik, Kasaakhistaan)',
        'kk_KZ' => 'Kasaaq (Kasaakhistaan)',
        'kl' => 'Kalaallisuut',
        'kl_GL' => 'Kalaallisuut (Greenland)',
        'km' => 'Kamboodhian',
        'km_KH' => 'Kamboodhian (Kamboodiya)',
        'kn' => 'Kannadays',
        'kn_IN' => 'Kannadays (Hindiya)',
        'ko' => 'Kuuriyaan',
        'ko_CN' => 'Kuuriyaan (Shiinaha)',
        'ko_KP' => 'Kuuriyaan (Kuuriyada Waqooyi)',
        'ko_KR' => 'Kuuriyaan (Kuuriyada Koonfureed)',
        'ks' => 'Kaashmiir',
        'ks_Arab' => 'Kaashmiir (Carabi)',
        'ks_Arab_IN' => 'Kaashmiir (Carabi, Hindiya)',
        'ks_Deva' => 'Kaashmiir (Dhefangaari)',
        'ks_Deva_IN' => 'Kaashmiir (Dhefangaari, Hindiya)',
        'ks_IN' => 'Kaashmiir (Hindiya)',
        'ku' => 'Kurdishka',
        'ku_Latn' => 'Kurdishka (Laatiin)',
        'ku_Latn_IQ' => 'Kurdishka (Laatiin, Ciraaq)',
        'ku_Latn_SY' => 'Kurdishka (Laatiin, Suuriya)',
        'ku_Latn_TR' => 'Kurdishka (Laatiin, Turki)',
        'ku_SY' => 'Kurdishka (Suuriya)',
        'ku_TR' => 'Kurdishka (Turki)',
        'kw' => 'Kornish',
        'kw_GB' => 'Kornish (Boqortooyada Midowday)',
        'ky' => 'Kirgiis',
        'ky_KG' => 'Kirgiis (Kirgistaan)',
        'lb' => 'Luksaamboorgish',
        'lb_LU' => 'Luksaamboorgish (Luksemboorg)',
        'lg' => 'Gandha',
        'lg_UG' => 'Gandha (Ugaanda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angoola)',
        'ln_CD' => 'Lingala (Jamhuuriyadda Dimuquraadiga Kongo)',
        'ln_CF' => 'Lingala (Jamhuuriyadda Afrikada Dhexe)',
        'ln_CG' => 'Lingala (Kongo)',
        'lo' => 'Lao',
        'lo_LA' => 'Lao (Laos)',
        'lt' => 'Lituwaanays',
        'lt_LT' => 'Lituwaanays (Lituweeniya)',
        'lu' => 'Luuba-kataanga',
        'lu_CD' => 'Luuba-kataanga (Jamhuuriyadda Dimuquraadiga Kongo)',
        'lv' => 'Laatfiyaan',
        'lv_LV' => 'Laatfiyaan (Latfiya)',
        'mg' => 'Malagaasi',
        'mg_MG' => 'Malagaasi (Madagaskar)',
        'mi' => 'Maaoori',
        'mi_NZ' => 'Maaoori (Niyuusiilaand)',
        'mk' => 'Masadooniyaan',
        'mk_MK' => 'Masadooniyaan (Masedooniya Waqooyi)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (Hindiya)',
        'mn' => 'Mangooli',
        'mn_MN' => 'Mangooli (Mongooliya)',
        'mr' => 'Maarati',
        'mr_IN' => 'Maarati (Hindiya)',
        'ms' => 'Malaay',
        'ms_BN' => 'Malaay (Buruneey)',
        'ms_ID' => 'Malaay (Indoneesiya)',
        'ms_MY' => 'Malaay (Malaysiya)',
        'ms_SG' => 'Malaay (Singaboor)',
        'mt' => 'Maltiis',
        'mt_MT' => 'Maltiis (Maalta)',
        'my' => 'Burmese',
        'my_MM' => 'Burmese (Mayanmar)',
        'nb' => 'Nawrijii Bokmål',
        'nb_NO' => 'Nawrijii Bokmål (Noorweey)',
        'nb_SJ' => 'Nawrijii Bokmål (Jasiiradda Sfaldbaad & Jaan Mayen)',
        'nd' => 'Indhebeele Waqooyi',
        'nd_ZW' => 'Indhebeele Waqooyi (Simbaabwe)',
        'ne' => 'Nebaali',
        'ne_IN' => 'Nebaali (Hindiya)',
        'ne_NP' => 'Nebaali (Nebaal)',
        'nl' => 'Holandays',
        'nl_AW' => 'Holandays (Aruba)',
        'nl_BE' => 'Holandays (Biljam)',
        'nl_BQ' => 'Holandays (Karibiyaan Nadarlands)',
        'nl_CW' => 'Holandays (Kurakaaw)',
        'nl_NL' => 'Holandays (Nederlaands)',
        'nl_SR' => 'Holandays (Surineym)',
        'nl_SX' => 'Holandays (Siint Maarteen)',
        'nn' => 'Nawriijiga Nynorsk',
        'nn_NO' => 'Nawriijiga Nynorsk (Noorweey)',
        'no' => 'Nawriiji',
        'no_NO' => 'Nawriiji (Noorweey)',
        'oc' => 'Occitan',
        'oc_ES' => 'Occitan (Isbeyn)',
        'oc_FR' => 'Occitan (Faransiis)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Itoobiya)',
        'om_KE' => 'Oromo (Kenya)',
        'or' => 'Oodhiya',
        'or_IN' => 'Oodhiya (Hindiya)',
        'os' => 'Oseetic',
        'os_GE' => 'Oseetic (Joorjiya)',
        'os_RU' => 'Oseetic (Ruush)',
        'pa' => 'Bunjaabi',
        'pa_Arab' => 'Bunjaabi (Carabi)',
        'pa_Arab_PK' => 'Bunjaabi (Carabi, Bakistaan)',
        'pa_Guru' => 'Bunjaabi (Luuqada gujarati)',
        'pa_Guru_IN' => 'Bunjaabi (Luuqada gujarati, Hindiya)',
        'pa_IN' => 'Bunjaabi (Hindiya)',
        'pa_PK' => 'Bunjaabi (Bakistaan)',
        'pl' => 'Boolish',
        'pl_PL' => 'Boolish (Booland)',
        'ps' => 'Bashtuu',
        'ps_AF' => 'Bashtuu (Afgaanistaan)',
        'ps_PK' => 'Bashtuu (Bakistaan)',
        'pt' => 'Boortaqiis',
        'pt_AO' => 'Boortaqiis (Angoola)',
        'pt_BR' => 'Boortaqiis (Baraasiil)',
        'pt_CH' => 'Boortaqiis (Swiiserlaand)',
        'pt_CV' => 'Boortaqiis (Jasiiradda Kayb Faarde)',
        'pt_GQ' => 'Boortaqiis (Ekuwatooriyal Gini)',
        'pt_GW' => 'Boortaqiis (Gini-Bisaaw)',
        'pt_LU' => 'Boortaqiis (Luksemboorg)',
        'pt_MO' => 'Boortaqiis (Makaaw)',
        'pt_MZ' => 'Boortaqiis (Musambiik)',
        'pt_PT' => 'Boortaqiis (Bortugaal)',
        'pt_ST' => 'Boortaqiis (Sao Tome & Birincibal)',
        'pt_TL' => 'Boortaqiis (Timor-Leste)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Boliifiya)',
        'qu_EC' => 'Quechua (Ikuwadoor)',
        'qu_PE' => 'Quechua (Beeru)',
        'rm' => 'Romaanis',
        'rm_CH' => 'Romaanis (Swiiserlaand)',
        'rn' => 'Rundhi',
        'rn_BI' => 'Rundhi (Burundi)',
        'ro' => 'Romanka',
        'ro_MD' => 'Romanka (Moldofa)',
        'ro_RO' => 'Romanka (Rumaaniya)',
        'ru' => 'Ruush',
        'ru_BY' => 'Ruush (Belarus)',
        'ru_KG' => 'Ruush (Kirgistaan)',
        'ru_KZ' => 'Ruush (Kasaakhistaan)',
        'ru_MD' => 'Ruush (Moldofa)',
        'ru_RU' => 'Ruush (Ruush)',
        'ru_UA' => 'Ruush (Yukrayn)',
        'rw' => 'Ruwaandha',
        'rw_RW' => 'Ruwaandha (Ruwanda)',
        'sa' => 'Sanskrit',
        'sa_IN' => 'Sanskrit (Hindiya)',
        'sc' => 'Sardinian',
        'sc_IT' => 'Sardinian (Talyaani)',
        'sd' => 'Siindhi',
        'sd_Arab' => 'Siindhi (Carabi)',
        'sd_Arab_PK' => 'Siindhi (Carabi, Bakistaan)',
        'sd_Deva' => 'Siindhi (Dhefangaari)',
        'sd_Deva_IN' => 'Siindhi (Dhefangaari, Hindiya)',
        'sd_IN' => 'Siindhi (Hindiya)',
        'sd_PK' => 'Siindhi (Bakistaan)',
        'se' => 'Sami Waqooyi',
        'se_FI' => 'Sami Waqooyi (Finland)',
        'se_NO' => 'Sami Waqooyi (Noorweey)',
        'se_SE' => 'Sami Waqooyi (Iswidhan)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Jamhuuriyadda Afrikada Dhexe)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (Sirilaanka)',
        'sk' => 'Isloofaak',
        'sk_SK' => 'Isloofaak (Islofaakiya)',
        'sl' => 'Islofeeniyaan',
        'sl_SI' => 'Islofeeniyaan (Islofeeniya)',
        'sn' => 'Shoona',
        'sn_ZW' => 'Shoona (Simbaabwe)',
        'so' => 'Soomaali',
        'so_DJ' => 'Soomaali (Jabuuti)',
        'so_ET' => 'Soomaali (Itoobiya)',
        'so_KE' => 'Soomaali (Kenya)',
        'so_SO' => 'Soomaali (Soomaaliya)',
        'sq' => 'Albeeniyaan',
        'sq_AL' => 'Albeeniyaan (Albaaniya)',
        'sq_MK' => 'Albeeniyaan (Masedooniya Waqooyi)',
        'sr' => 'Seerbiyaan',
        'sr_BA' => 'Seerbiyaan (Boosniya & Harsegofina)',
        'sr_Cyrl' => 'Seerbiyaan (Siriylik)',
        'sr_Cyrl_BA' => 'Seerbiyaan (Siriylik, Boosniya & Harsegofina)',
        'sr_Cyrl_ME' => 'Seerbiyaan (Siriylik, Moontenegro)',
        'sr_Cyrl_RS' => 'Seerbiyaan (Siriylik, Seerbiya)',
        'sr_Latn' => 'Seerbiyaan (Laatiin)',
        'sr_Latn_BA' => 'Seerbiyaan (Laatiin, Boosniya & Harsegofina)',
        'sr_Latn_ME' => 'Seerbiyaan (Laatiin, Moontenegro)',
        'sr_Latn_RS' => 'Seerbiyaan (Laatiin, Seerbiya)',
        'sr_ME' => 'Seerbiyaan (Moontenegro)',
        'sr_RS' => 'Seerbiyaan (Seerbiya)',
        'st' => 'Sesooto',
        'st_LS' => 'Sesooto (Losooto)',
        'st_ZA' => 'Sesooto (Koonfur Afrika)',
        'su' => 'Suudaaniis',
        'su_ID' => 'Suudaaniis (Indoneesiya)',
        'su_Latn' => 'Suudaaniis (Laatiin)',
        'su_Latn_ID' => 'Suudaaniis (Laatiin, Indoneesiya)',
        'sv' => 'Iswiidhish',
        'sv_AX' => 'Iswiidhish (Jasiiradda Aland)',
        'sv_FI' => 'Iswiidhish (Finland)',
        'sv_SE' => 'Iswiidhish (Iswidhan)',
        'sw' => 'Sawaaxili',
        'sw_CD' => 'Sawaaxili (Jamhuuriyadda Dimuquraadiga Kongo)',
        'sw_KE' => 'Sawaaxili (Kenya)',
        'sw_TZ' => 'Sawaaxili (Tansaaniya)',
        'sw_UG' => 'Sawaaxili (Ugaanda)',
        'ta' => 'Tamiil',
        'ta_IN' => 'Tamiil (Hindiya)',
        'ta_LK' => 'Tamiil (Sirilaanka)',
        'ta_MY' => 'Tamiil (Malaysiya)',
        'ta_SG' => 'Tamiil (Singaboor)',
        'te' => 'Teluugu',
        'te_IN' => 'Teluugu (Hindiya)',
        'tg' => 'Taajik',
        'tg_TJ' => 'Taajik (Tajikistan)',
        'th' => 'Taaylandays',
        'th_TH' => 'Taaylandays (Taylaand)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (Eritreeya)',
        'ti_ET' => 'Tigrinya (Itoobiya)',
        'tk' => 'Turkumaanish',
        'tk_TM' => 'Turkumaanish (Turkmenistan)',
        'tn' => 'Tswana',
        'tn_BW' => 'Tswana (Botuswaana)',
        'tn_ZA' => 'Tswana (Koonfur Afrika)',
        'to' => 'Toongan',
        'to_TO' => 'Toongan (Tonga)',
        'tr' => 'Turkish',
        'tr_CY' => 'Turkish (Qubrus)',
        'tr_TR' => 'Turkish (Turki)',
        'tt' => 'Taatar',
        'tt_RU' => 'Taatar (Ruush)',
        'ug' => 'Uighur',
        'ug_CN' => 'Uighur (Shiinaha)',
        'uk' => 'Yukreeniyaan',
        'uk_UA' => 'Yukreeniyaan (Yukrayn)',
        'ur' => 'Urduu',
        'ur_IN' => 'Urduu (Hindiya)',
        'ur_PK' => 'Urduu (Bakistaan)',
        'uz' => 'Usbakis',
        'uz_AF' => 'Usbakis (Afgaanistaan)',
        'uz_Arab' => 'Usbakis (Carabi)',
        'uz_Arab_AF' => 'Usbakis (Carabi, Afgaanistaan)',
        'uz_Cyrl' => 'Usbakis (Siriylik)',
        'uz_Cyrl_UZ' => 'Usbakis (Siriylik, Usbakistan)',
        'uz_Latn' => 'Usbakis (Laatiin)',
        'uz_Latn_UZ' => 'Usbakis (Laatiin, Usbakistan)',
        'uz_UZ' => 'Usbakis (Usbakistan)',
        'vi' => 'Fiitnaamays',
        'vi_VN' => 'Fiitnaamays (Fiyetnaam)',
        'wo' => 'Woolof',
        'wo_SN' => 'Woolof (Sinigaal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (Koonfur Afrika)',
        'yi' => 'Yadhish',
        'yi_UA' => 'Yadhish (Yukrayn)',
        'yo' => 'Yoruuba',
        'yo_BJ' => 'Yoruuba (Biniin)',
        'yo_NG' => 'Yoruuba (Nayjeeriya)',
        'za' => 'Zhuang',
        'za_CN' => 'Zhuang (Shiinaha)',
        'zh' => 'Shinees',
        'zh_CN' => 'Shinees (Shiinaha)',
        'zh_HK' => 'Shinees (Hong Kong)',
        'zh_Hans' => 'Shinees (La fududeeyay)',
        'zh_Hans_CN' => 'Shinees (La fududeeyay, Shiinaha)',
        'zh_Hans_HK' => 'Shinees (La fududeeyay, Hong Kong)',
        'zh_Hans_MO' => 'Shinees (La fududeeyay, Makaaw)',
        'zh_Hans_MY' => 'Shinees (La fududeeyay, Malaysiya)',
        'zh_Hans_SG' => 'Shinees (La fududeeyay, Singaboor)',
        'zh_Hant' => 'Shinees (Hore)',
        'zh_Hant_HK' => 'Shinees (Hore, Hong Kong)',
        'zh_Hant_MO' => 'Shinees (Hore, Makaaw)',
        'zh_Hant_MY' => 'Shinees (Hore, Malaysiya)',
        'zh_Hant_TW' => 'Shinees (Hore, Taywaan)',
        'zh_MO' => 'Shinees (Makaaw)',
        'zh_SG' => 'Shinees (Singaboor)',
        'zh_TW' => 'Shinees (Taywaan)',
        'zu' => 'Zuulu',
        'zu_ZA' => 'Zuulu (Koonfur Afrika)',
    ],
];
