<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'universala tempo kunordigita (Abiĝano)',
        'Africa/Accra' => 'universala tempo kunordigita (Akrao)',
        'Africa/Addis_Ababa' => 'orientafrika tempo (Adisabebo)',
        'Africa/Algiers' => 'centreŭropa tempo (Alĝero)',
        'Africa/Asmera' => 'orientafrika tempo (Asmero)',
        'Africa/Asmara' => 'orientafrika tempo (Asmero)',
        'Africa/Bamako' => 'universala tempo kunordigita (Bamako)',
        'Africa/Bangui' => 'okcidentafrika tempo (Bango)',
        'Africa/Banjul' => 'universala tempo kunordigita (Banjulo)',
        'Africa/Bissau' => 'universala tempo kunordigita (Bisaŭo)',
        'Africa/Blantyre' => 'centrafrika tempo (Blantyre)',
        'Africa/Brazzaville' => 'okcidentafrika tempo (Brazavilo)',
        'Africa/Bujumbura' => 'centrafrika tempo (Buĵumburo)',
        'Africa/Cairo' => 'orienteŭropa tempo (Kairo)',
        'Africa/Casablanca' => 'okcidenteŭropa tempo (Kazablanko)',
        'Africa/Ceuta' => 'centreŭropa tempo (Ceŭto)',
        'Africa/Conakry' => 'universala tempo kunordigita (Konakrio)',
        'Africa/Dakar' => 'universala tempo kunordigita (Dakaro)',
        'Africa/Dar_es_Salaam' => 'orientafrika tempo (Daresalamo)',
        'Africa/Djibouti' => 'orientafrika tempo (Ĝibutio)',
        'Africa/Douala' => 'okcidentafrika tempo (Dualao)',
        'Africa/El_Aaiun' => 'okcidenteŭropa tempo (Ajuno)',
        'Africa/Freetown' => 'universala tempo kunordigita (Fritaŭno)',
        'Africa/Gaborone' => 'centrafrika tempo (Gaborono)',
        'Africa/Harare' => 'centrafrika tempo (Harareo)',
        'Africa/Johannesburg' => 'sudafrika tempo (Johanesburgo)',
        'Africa/Juba' => 'centrafrika tempo (Ĝubao)',
        'Africa/Kampala' => 'orientafrika tempo (Kampalo)',
        'Africa/Khartoum' => 'centrafrika tempo (Ĥartumo)',
        'Africa/Kigali' => 'centrafrika tempo (Kigalo)',
        'Africa/Kinshasa' => 'okcidentafrika tempo (Kinŝaso)',
        'Africa/Lagos' => 'okcidentafrika tempo (Lagoso)',
        'Africa/Libreville' => 'okcidentafrika tempo (Librevilo)',
        'Africa/Lome' => 'universala tempo kunordigita (Lomeo)',
        'Africa/Luanda' => 'okcidentafrika tempo (Luando)',
        'Africa/Lubumbashi' => 'centrafrika tempo (Lubumbaŝo)',
        'Africa/Lusaka' => 'centrafrika tempo (Lusako)',
        'Africa/Malabo' => 'okcidentafrika tempo (Malabo)',
        'Africa/Maputo' => 'centrafrika tempo (Maputo)',
        'Africa/Maseru' => 'sudafrika tempo (Maseruo)',
        'Africa/Mbabane' => 'sudafrika tempo (Mbabano)',
        'Africa/Mogadishu' => 'orientafrika tempo (Mogadiŝo)',
        'Africa/Monrovia' => 'universala tempo kunordigita (Monrovio)',
        'Africa/Nairobi' => 'orientafrika tempo (Najrobio)',
        'Africa/Ndjamena' => 'okcidentafrika tempo (Niĝameno)',
        'Africa/Niamey' => 'okcidentafrika tempo (Niamejo)',
        'Africa/Nouakchott' => 'universala tempo kunordigita (Nuakŝoto)',
        'Africa/Ouagadougou' => 'universala tempo kunordigita (Vagaduguo)',
        'Africa/Porto-Novo' => 'okcidentafrika tempo (Portonovo)',
        'Africa/Sao_Tome' => 'universala tempo kunordigita (Santomeo)',
        'Africa/Tripoli' => 'orienteŭropa tempo (Tripolo)',
        'Africa/Tunis' => 'centreŭropa tempo (Tunizo)',
        'Africa/Windhoek' => 'centrafrika tempo (Vindhuko)',
        'America/Adak' => 'tempo: Havajo-Aleutoj (Adak)',
        'America/Anchorage' => 'alaska tempo (Anchorage)',
        'America/Anguilla' => 'atlantika nordamerika tempo (Angvilo)',
        'America/Antigua' => 'atlantika nordamerika tempo (Antigvo)',
        'America/Araguaina' => 'brazilja tempo (Araguaína)',
        'America/Argentina/La_Rioja' => 'argentina tempo (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'argentina tempo (Río Gallegos)',
        'America/Argentina/Salta' => 'argentina tempo (Saltaurbo)',
        'America/Argentina/San_Juan' => 'argentina tempo (San Juan)',
        'America/Argentina/San_Luis' => 'argentina tempo (San Luis)',
        'America/Argentina/Tucuman' => 'argentina tempo (Tucumán)',
        'America/Argentina/Ushuaia' => 'argentina tempo (Ushuaia)',
        'America/Aruba' => 'atlantika nordamerika tempo (Arubo)',
        'America/Asuncion' => 'paragvaja tempo (Asunciono)',
        'America/Bahia' => 'brazilja tempo (Bahio)',
        'America/Bahia_Banderas' => 'centra nordamerika tempo (Bahía de Banderas)',
        'America/Barbados' => 'atlantika nordamerika tempo (Barbado)',
        'America/Belem' => 'brazilja tempo (Belemo)',
        'America/Belize' => 'centra nordamerika tempo (Belizo)',
        'America/Blanc-Sablon' => 'atlantika nordamerika tempo (Blanc-Sablon)',
        'America/Boa_Vista' => 'amazona tempo (Boa Vista)',
        'America/Bogota' => 'kolombia tempo (Bogoto)',
        'America/Boise' => 'montara nordamerika tempo (Boise)',
        'America/Buenos_Aires' => 'argentina tempo (Bonaero)',
        'America/Argentina/Buenos_Aires' => 'argentina tempo (Bonaero)',
        'America/Cambridge_Bay' => 'montara nordamerika tempo (Kembriĝa Golfo)',
        'America/Campo_Grande' => 'amazona tempo (Campo Grande)',
        'America/Cancun' => 'orienta nordamerika tempo (Kankuno)',
        'America/Caracas' => 'venezuela tempo (Karakaso)',
        'America/Catamarca' => 'argentina tempo (Catamarca)',
        'America/Argentina/Catamarca' => 'argentina tempo (Catamarca)',
        'America/Cayenne' => 'tempo: Franca Gujano (Kajeno)',
        'America/Cayman' => 'orienta nordamerika tempo (Kajmanoj)',
        'America/Chicago' => 'centra nordamerika tempo (Ĉikago)',
        'America/Chihuahua' => 'centra nordamerika tempo (Chihuahua)',
        'America/Ciudad_Juarez' => 'montara nordamerika tempo (Ciudad Juárez)',
        'America/Coral_Harbour' => 'orienta nordamerika tempo (Atikokan)',
        'America/Atikokan' => 'orienta nordamerika tempo (Atikokan)',
        'America/Cordoba' => 'argentina tempo (Kordobo)',
        'America/Argentina/Cordoba' => 'argentina tempo (Kordobo)',
        'America/Costa_Rica' => 'centra nordamerika tempo (Kostariko)',
        'America/Coyhaique' => 'ĉilia tempo (Coyhaique)',
        'America/Creston' => 'montara nordamerika tempo (Creston)',
        'America/Cuiaba' => 'amazona tempo (Cuiabá)',
        'America/Curacao' => 'atlantika nordamerika tempo (Kuracao)',
        'America/Danmarkshavn' => 'universala tempo kunordigita (Danmarkshavn)',
        'America/Dawson' => 'jukonia tempo (Dawson)',
        'America/Dawson_Creek' => 'montara nordamerika tempo (Dawson Creek)',
        'America/Denver' => 'montara nordamerika tempo (Denvero)',
        'America/Detroit' => 'orienta nordamerika tempo (Detrojto)',
        'America/Dominica' => 'atlantika nordamerika tempo (Dominiko)',
        'America/Edmonton' => 'montara nordamerika tempo (Edmontono)',
        'America/Eirunepe' => 'tempo: Brazilo (Eirunepé)',
        'America/El_Salvador' => 'centra nordamerika tempo (Salvadoro)',
        'America/Fort_Nelson' => 'montara nordamerika tempo (Fort Nelson)',
        'America/Fortaleza' => 'brazilja tempo (Fortalezo)',
        'America/Glace_Bay' => 'atlantika nordamerika tempo (Glace Bay)',
        'America/Godthab' => 'tempo: Gronlando (Nuko)',
        'America/Nuuk' => 'tempo: Gronlando (Nuko)',
        'America/Goose_Bay' => 'atlantika nordamerika tempo (Goose Bay)',
        'America/Grand_Turk' => 'orienta nordamerika tempo (Granda Turko)',
        'America/Grenada' => 'atlantika nordamerika tempo (Grenado)',
        'America/Guadeloupe' => 'atlantika nordamerika tempo (Gvadelupo)',
        'America/Guatemala' => 'centra nordamerika tempo (Gvatemalo)',
        'America/Guayaquil' => 'ekvadora tempo (Guayaquil)',
        'America/Guyana' => 'gujana tempo (Gujano)',
        'America/Halifax' => 'atlantika nordamerika tempo (Halifakso)',
        'America/Havana' => 'tempo: Kubo (Havano)',
        'America/Hermosillo' => 'pacifika meksika tempo (Hermosillo)',
        'America/Indiana/Knox' => 'centra nordamerika tempo (Knox, Indianao)',
        'America/Indiana/Marengo' => 'orienta nordamerika tempo (Marengo, Indianao)',
        'America/Indiana/Petersburg' => 'orienta nordamerika tempo (Petersburg, Indianao)',
        'America/Indiana/Tell_City' => 'centra nordamerika tempo (Tell City, Indianao)',
        'America/Indiana/Vevay' => 'orienta nordamerika tempo (Vevay, Indianao)',
        'America/Indiana/Vincennes' => 'orienta nordamerika tempo (Vincennes, Indianao)',
        'America/Indiana/Winamac' => 'orienta nordamerika tempo (Winamac, Indianao)',
        'America/Indianapolis' => 'orienta nordamerika tempo (Indianapolo, Indianao)',
        'America/Indiana/Indianapolis' => 'orienta nordamerika tempo (Indianapolo, Indianao)',
        'America/Inuvik' => 'montara nordamerika tempo (Inuvik)',
        'America/Iqaluit' => 'orienta nordamerika tempo (Ikaluito)',
        'America/Jamaica' => 'orienta nordamerika tempo (Jamajko)',
        'America/Jujuy' => 'argentina tempo (Jujuy)',
        'America/Argentina/Jujuy' => 'argentina tempo (Jujuy)',
        'America/Juneau' => 'alaska tempo (Juneau)',
        'America/Kentucky/Monticello' => 'orienta nordamerika tempo (Monticello, Kentukio)',
        'America/Kralendijk' => 'atlantika nordamerika tempo (Kralendijk)',
        'America/La_Paz' => 'bolivia tempo (La Paz)',
        'America/Lima' => 'perua tempo (Limo)',
        'America/Los_Angeles' => 'pacifika nordamerika tempo (Losanĝeleso)',
        'America/Louisville' => 'orienta nordamerika tempo (Louisville)',
        'America/Kentucky/Louisville' => 'orienta nordamerika tempo (Louisville)',
        'America/Lower_Princes' => 'atlantika nordamerika tempo (Lower Prince’s Quarter)',
        'America/Maceio' => 'brazilja tempo (Maceió)',
        'America/Managua' => 'centra nordamerika tempo (Managvo)',
        'America/Manaus' => 'amazona tempo (Manaŭso)',
        'America/Marigot' => 'atlantika nordamerika tempo (Marigoto)',
        'America/Martinique' => 'atlantika nordamerika tempo (Martiniko)',
        'America/Matamoros' => 'centra nordamerika tempo (Matamoros)',
        'America/Mazatlan' => 'pacifika meksika tempo (Mazatlán)',
        'America/Mendoza' => 'argentina tempo (Mendoza)',
        'America/Argentina/Mendoza' => 'argentina tempo (Mendoza)',
        'America/Menominee' => 'centra nordamerika tempo (Menominee)',
        'America/Merida' => 'centra nordamerika tempo (Merido)',
        'America/Metlakatla' => 'alaska tempo (Metlakatla)',
        'America/Mexico_City' => 'centra nordamerika tempo (Meksikurbo)',
        'America/Miquelon' => 'tempo: Sankta Piero kaj Mikelono',
        'America/Moncton' => 'atlantika nordamerika tempo (Monktono)',
        'America/Monterrey' => 'centra nordamerika tempo (Monterejo)',
        'America/Montevideo' => 'urugvaja tempo (Montevideo)',
        'America/Montserrat' => 'atlantika nordamerika tempo (Moncerato)',
        'America/Nassau' => 'orienta nordamerika tempo (Nasaŭo)',
        'America/New_York' => 'orienta nordamerika tempo (Nov-Jorko)',
        'America/Nome' => 'alaska tempo (Nome)',
        'America/Noronha' => 'tempo: Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'centra nordamerika tempo (Beulah, Norda Dakoto)',
        'America/North_Dakota/Center' => 'centra nordamerika tempo (Center, Norda Dakoto)',
        'America/North_Dakota/New_Salem' => 'centra nordamerika tempo (New Salem, Norda Dakoto)',
        'America/Ojinaga' => 'centra nordamerika tempo (Ojinaga)',
        'America/Panama' => 'orienta nordamerika tempo (Panamo)',
        'America/Paramaribo' => 'surinama tempo (Paramaribo)',
        'America/Phoenix' => 'montara nordamerika tempo (Fenikso)',
        'America/Port-au-Prince' => 'orienta nordamerika tempo (Portoprinco)',
        'America/Port_of_Spain' => 'atlantika nordamerika tempo (Portospeno)',
        'America/Porto_Velho' => 'amazona tempo (Porto Velho)',
        'America/Puerto_Rico' => 'atlantika nordamerika tempo (Puertoriko)',
        'America/Punta_Arenas' => 'ĉilia tempo (Punta Arenas)',
        'America/Rankin_Inlet' => 'centra nordamerika tempo (Rankin Inlet)',
        'America/Recife' => 'brazilja tempo (Recife)',
        'America/Regina' => 'centra nordamerika tempo (Regina)',
        'America/Resolute' => 'centra nordamerika tempo (Resolute)',
        'America/Rio_Branco' => 'tempo: Brazilo (Rio Branco)',
        'America/Santarem' => 'brazilja tempo (Santarém)',
        'America/Santiago' => 'ĉilia tempo (Santiago)',
        'America/Santo_Domingo' => 'atlantika nordamerika tempo (Sankta Domingo)',
        'America/Sao_Paulo' => 'brazilja tempo (Sanpaŭlo)',
        'America/Scoresbysund' => 'tempo: Gronlando (Ittoqqortoormiit)',
        'America/Sitka' => 'alaska tempo (Sitka)',
        'America/St_Barthelemy' => 'atlantika nordamerika tempo (Sankta Bartolomeo)',
        'America/St_Johns' => 'tempo: Novlando (St. John’s)',
        'America/St_Kitts' => 'atlantika nordamerika tempo (Sankta Kristoforo)',
        'America/St_Lucia' => 'atlantika nordamerika tempo (Sankta Lucio)',
        'America/St_Thomas' => 'atlantika nordamerika tempo (Sankta Tomaso)',
        'America/St_Vincent' => 'atlantika nordamerika tempo (Sankta Vincento)',
        'America/Swift_Current' => 'centra nordamerika tempo (Swift Current)',
        'America/Tegucigalpa' => 'centra nordamerika tempo (Tegucigalpo)',
        'America/Thule' => 'atlantika nordamerika tempo (Qaanaaq)',
        'America/Tijuana' => 'pacifika nordamerika tempo (Tijuana)',
        'America/Toronto' => 'orienta nordamerika tempo (Toronto)',
        'America/Tortola' => 'atlantika nordamerika tempo (Tortola)',
        'America/Vancouver' => 'pacifika nordamerika tempo (Vankuvero)',
        'America/Whitehorse' => 'jukonia tempo (Whitehorse)',
        'America/Winnipeg' => 'centra nordamerika tempo (Vinipego)',
        'America/Yakutat' => 'alaska tempo (Yakutat)',
        'Antarctica/Casey' => 'okcidenta aŭstralia tempo (Casey)',
        'Antarctica/Davis' => 'tempo: Davis',
        'Antarctica/DumontDUrville' => 'tempo: Dumont d’Urville',
        'Antarctica/Macquarie' => 'orienta aŭstralia tempo (Makvora insulo)',
        'Antarctica/Mawson' => 'tempo: Mawson',
        'Antarctica/McMurdo' => 'novzelanda tempo (McMurdo)',
        'Antarctica/Palmer' => 'ĉilia tempo (Palmer)',
        'Antarctica/Rothera' => 'tempo: Rothera',
        'Antarctica/Syowa' => 'tempo: Showa',
        'Antarctica/Troll' => 'universala tempo kunordigita (Troll)',
        'Antarctica/Vostok' => 'tempo: Vostok',
        'Arctic/Longyearbyen' => 'centreŭropa tempo (Longjerurbo)',
        'Asia/Aden' => 'araba tempo (Adeno)',
        'Asia/Almaty' => 'kazaĥa tempo (Almato)',
        'Asia/Amman' => 'orienteŭropa tempo (Amano)',
        'Asia/Anadyr' => 'tempo: Rusujo (Anadir)',
        'Asia/Aqtau' => 'kazaĥa tempo (Aktau)',
        'Asia/Aqtobe' => 'kazaĥa tempo (Aktobe)',
        'Asia/Ashgabat' => 'turkmena tempo (Aŝĥabado)',
        'Asia/Atyrau' => 'kazaĥa tempo (Atirau)',
        'Asia/Baghdad' => 'araba tempo (Bagdado)',
        'Asia/Bahrain' => 'araba tempo (Barejno)',
        'Asia/Baku' => 'azerbajĝana tempo (Bakuo)',
        'Asia/Bangkok' => 'hindoĉina tempo (Bankoko)',
        'Asia/Barnaul' => 'krasnojarska tempo (Barnaul)',
        'Asia/Beirut' => 'orienteŭropa tempo (Bejruto)',
        'Asia/Bishkek' => 'kirgiza tempo (Biŝkeko)',
        'Asia/Brunei' => 'bruneja tempo (Brunejo)',
        'Asia/Calcutta' => 'hinda norma tempo (Kolkato)',
        'Asia/Kolkata' => 'hinda norma tempo (Kolkato)',
        'Asia/Chita' => 'jakutska tempo (Ĉita)',
        'Asia/Colombo' => 'hinda norma tempo (Kolombo)',
        'Asia/Damascus' => 'orienteŭropa tempo (Damasko)',
        'Asia/Dhaka' => 'bangladeŝa tempo (Dako)',
        'Asia/Dili' => 'orient-timora tempo (Dilo)',
        'Asia/Dubai' => 'arabgolfa norma tempo (Dubajurbo)',
        'Asia/Dushanbe' => 'taĝika tempo (Duŝanbeo)',
        'Asia/Famagusta' => 'orienteŭropa tempo (Famagusta)',
        'Asia/Gaza' => 'orienteŭropa tempo (Gazao)',
        'Asia/Hebron' => 'orienteŭropa tempo (Hebrono)',
        'Asia/Hong_Kong' => 'honkonga tempo (Honkongo)',
        'Asia/Hovd' => 'ĥovda tempo',
        'Asia/Irkutsk' => 'irkutska tempo (Irkutsko)',
        'Asia/Jakarta' => 'okcident-indonezia tempo (Ĝakarto)',
        'Asia/Jayapura' => 'orient-indonezia tempo (Jayapura)',
        'Asia/Jerusalem' => 'israela tempo (Jerusalemo)',
        'Asia/Kabul' => 'afgana tempo (Kabulo)',
        'Asia/Kamchatka' => 'tempo: Rusujo (Kamĉatko)',
        'Asia/Karachi' => 'pakistana tempo (Karaĉio)',
        'Asia/Katmandu' => 'nepala tempo (Katmanduo)',
        'Asia/Kathmandu' => 'nepala tempo (Katmanduo)',
        'Asia/Khandyga' => 'jakutska tempo (Ĥandiga)',
        'Asia/Krasnoyarsk' => 'krasnojarska tempo (Krasnojarsko)',
        'Asia/Kuala_Lumpur' => 'malajzia tempo (Kualalumpuro)',
        'Asia/Kuching' => 'malajzia tempo (Kuching)',
        'Asia/Kuwait' => 'araba tempo (Kuvajto)',
        'Asia/Macau' => 'ĉina tempo (Makao)',
        'Asia/Magadan' => 'magadana tempo',
        'Asia/Makassar' => 'centr-indonezia tempo (Makassar)',
        'Asia/Manila' => 'filipina tempo (Manilo)',
        'Asia/Muscat' => 'arabgolfa norma tempo (Maskato)',
        'Asia/Nicosia' => 'orienteŭropa tempo (Nikozio)',
        'Asia/Novokuznetsk' => 'krasnojarska tempo (Novokuznecko)',
        'Asia/Novosibirsk' => 'krasnojarska tempo (Novosibirsko)',
        'Asia/Omsk' => 'omska tempo (Omsko)',
        'Asia/Oral' => 'kazaĥa tempo (Oralo)',
        'Asia/Phnom_Penh' => 'hindoĉina tempo (Pnompeno)',
        'Asia/Pontianak' => 'okcident-indonezia tempo (Pontianak)',
        'Asia/Pyongyang' => 'korea tempo (Pjongjango)',
        'Asia/Qatar' => 'araba tempo (Kataro)',
        'Asia/Qostanay' => 'kazaĥa tempo (Kostanaj)',
        'Asia/Qyzylorda' => 'kazaĥa tempo (Kizilordo)',
        'Asia/Rangoon' => 'birma tempo (Ranguno)',
        'Asia/Yangon' => 'birma tempo (Ranguno)',
        'Asia/Riyadh' => 'araba tempo (Riado)',
        'Asia/Saigon' => 'hindoĉina tempo (Hoĉimino)',
        'Asia/Ho_Chi_Minh' => 'hindoĉina tempo (Hoĉimino)',
        'Asia/Sakhalin' => 'magadana tempo (Saĥaleno)',
        'Asia/Samarkand' => 'uzbeka tempo (Samarkando)',
        'Asia/Seoul' => 'korea tempo (Seulo)',
        'Asia/Shanghai' => 'ĉina tempo (Ŝanhajo)',
        'Asia/Singapore' => 'singapura norma tempo (Singapuro)',
        'Asia/Srednekolymsk' => 'magadana tempo (Srednekolimsk)',
        'Asia/Taipei' => 'tajvana tempo (Tajpeo)',
        'Asia/Tashkent' => 'uzbeka tempo (Taŝkento)',
        'Asia/Tbilisi' => 'kartvela tempo (Tbiliso)',
        'Asia/Tehran' => 'irana tempo (Teherano)',
        'Asia/Thimphu' => 'butana tempo (Timbuo)',
        'Asia/Tokyo' => 'japana tempo (Tokio)',
        'Asia/Tomsk' => 'krasnojarska tempo (Tomsk)',
        'Asia/Ulaanbaatar' => 'ulanbatora tempo (Ulanbatoro)',
        'Asia/Urumqi' => 'tempo: Ĉinujo (Urumĉio)',
        'Asia/Ust-Nera' => 'vladivostoka tempo (Ustnero)',
        'Asia/Vientiane' => 'hindoĉina tempo (Vjentiano)',
        'Asia/Vladivostok' => 'vladivostoka tempo (Vladivostoko)',
        'Asia/Yakutsk' => 'jakutska tempo (Jakutsko)',
        'Asia/Yekaterinburg' => 'jekaterinburga tempo (Jekaterinburgo)',
        'Asia/Yerevan' => 'armena tempo (Erevano)',
        'Atlantic/Azores' => 'tempo: Acoroj',
        'Atlantic/Bermuda' => 'atlantika nordamerika tempo (Bermudoj)',
        'Atlantic/Canary' => 'okcidenteŭropa tempo (Kanarioj)',
        'Atlantic/Cape_Verde' => 'kaboverda tempo (Kaboverdo)',
        'Atlantic/Faeroe' => 'okcidenteŭropa tempo (Ferooj)',
        'Atlantic/Faroe' => 'okcidenteŭropa tempo (Ferooj)',
        'Atlantic/Madeira' => 'okcidenteŭropa tempo (Madejro)',
        'Atlantic/Reykjavik' => 'universala tempo kunordigita (Rejkjaviko)',
        'Atlantic/South_Georgia' => 'tempo: Sud-Georgio',
        'Atlantic/St_Helena' => 'universala tempo kunordigita (Sankta Heleno)',
        'Atlantic/Stanley' => 'falklanda tempo (Stanlejo)',
        'Australia/Adelaide' => 'centra aŭstralia tempo (Adelajdo)',
        'Australia/Brisbane' => 'orienta aŭstralia tempo (Brisbano)',
        'Australia/Broken_Hill' => 'centra aŭstralia tempo (Broken Hill)',
        'Australia/Darwin' => 'centra aŭstralia tempo (Darvino)',
        'Australia/Eucla' => 'centrokcidenta aŭstralia tempo (Eucla)',
        'Australia/Hobart' => 'orienta aŭstralia tempo (Hobarto)',
        'Australia/Lindeman' => 'orienta aŭstralia tempo (Lindeman)',
        'Australia/Lord_Howe' => 'tempo: Lord Howe',
        'Australia/Melbourne' => 'orienta aŭstralia tempo (Melburno)',
        'Australia/Perth' => 'okcidenta aŭstralia tempo (Perto)',
        'Australia/Sydney' => 'orienta aŭstralia tempo (Sidnejo)',
        'Etc/GMT' => 'universala tempo kunordigita',
        'Etc/UTC' => 'universala tempo kunordigita',
        'Europe/Amsterdam' => 'centreŭropa tempo (Amsterdamo)',
        'Europe/Andorra' => 'centreŭropa tempo (Andoro)',
        'Europe/Astrakhan' => 'tempo: Rusujo (Astraĥano)',
        'Europe/Athens' => 'orienteŭropa tempo (Ateno)',
        'Europe/Belgrade' => 'centreŭropa tempo (Beogrado)',
        'Europe/Berlin' => 'centreŭropa tempo (Berlino)',
        'Europe/Bratislava' => 'centreŭropa tempo (Bratislavo)',
        'Europe/Brussels' => 'centreŭropa tempo (Bruselo)',
        'Europe/Bucharest' => 'orienteŭropa tempo (Bukareŝto)',
        'Europe/Budapest' => 'centreŭropa tempo (Budapeŝto)',
        'Europe/Busingen' => 'centreŭropa tempo (Büsingen am Hochrhein)',
        'Europe/Chisinau' => 'orienteŭropa tempo (Kiŝinevo)',
        'Europe/Copenhagen' => 'centreŭropa tempo (Kopenhago)',
        'Europe/Dublin' => 'universala tempo kunordigita (Dublino)',
        'Europe/Gibraltar' => 'centreŭropa tempo (Ĝibraltaro)',
        'Europe/Guernsey' => 'universala tempo kunordigita (Gernezejo)',
        'Europe/Helsinki' => 'orienteŭropa tempo (Helsinko)',
        'Europe/Isle_of_Man' => 'universala tempo kunordigita (Manksinsulo)',
        'Europe/Istanbul' => 'tempo: Turkujo (Istanbulo)',
        'Europe/Jersey' => 'universala tempo kunordigita (Ĵerzejo)',
        'Europe/Kaliningrad' => 'orienteŭropa tempo (Kaliningrado)',
        'Europe/Kiev' => 'orienteŭropa tempo (Kievo)',
        'Europe/Kyiv' => 'orienteŭropa tempo (Kievo)',
        'Europe/Kirov' => 'moskva tempo (Kirov)',
        'Europe/Lisbon' => 'okcidenteŭropa tempo (Lisbono)',
        'Europe/Ljubljana' => 'centreŭropa tempo (Ljubljano)',
        'Europe/London' => 'universala tempo kunordigita (Londono)',
        'Europe/Luxembourg' => 'centreŭropa tempo (Luksemburgo)',
        'Europe/Madrid' => 'centreŭropa tempo (Madrido)',
        'Europe/Malta' => 'centreŭropa tempo (Malto)',
        'Europe/Mariehamn' => 'orienteŭropa tempo (Mariehamn)',
        'Europe/Minsk' => 'moskva tempo (Minsko)',
        'Europe/Monaco' => 'centreŭropa tempo (Monako)',
        'Europe/Moscow' => 'moskva tempo (Moskvo)',
        'Europe/Oslo' => 'centreŭropa tempo (Oslo)',
        'Europe/Paris' => 'centreŭropa tempo (Parizo)',
        'Europe/Podgorica' => 'centreŭropa tempo (Podgorico)',
        'Europe/Prague' => 'centreŭropa tempo (Prago)',
        'Europe/Riga' => 'orienteŭropa tempo (Rigo)',
        'Europe/Rome' => 'centreŭropa tempo (Romo)',
        'Europe/Samara' => 'tempo: Rusujo (Samara)',
        'Europe/San_Marino' => 'centreŭropa tempo (Sanmarino)',
        'Europe/Sarajevo' => 'centreŭropa tempo (Sarajevo)',
        'Europe/Saratov' => 'tempo: Rusujo (Saratov)',
        'Europe/Simferopol' => 'moskva tempo (Simferopolo)',
        'Europe/Skopje' => 'centreŭropa tempo (Skopjo)',
        'Europe/Sofia' => 'orienteŭropa tempo (Sofio)',
        'Europe/Stockholm' => 'centreŭropa tempo (Stokholmo)',
        'Europe/Tallinn' => 'orienteŭropa tempo (Talino)',
        'Europe/Tirane' => 'centreŭropa tempo (Tirano)',
        'Europe/Ulyanovsk' => 'tempo: Rusujo (Uljanovsko)',
        'Europe/Vaduz' => 'centreŭropa tempo (Vaduzo)',
        'Europe/Vatican' => 'centreŭropa tempo (Vatikano)',
        'Europe/Vienna' => 'centreŭropa tempo (Vieno)',
        'Europe/Vilnius' => 'orienteŭropa tempo (Vilno)',
        'Europe/Volgograd' => 'moskva tempo (Volgogrado)',
        'Europe/Warsaw' => 'centreŭropa tempo (Varsovio)',
        'Europe/Zagreb' => 'centreŭropa tempo (Zagrebo)',
        'Europe/Zurich' => 'centreŭropa tempo (Zuriko)',
        'Indian/Antananarivo' => 'orientafrika tempo (Antananarivo)',
        'Indian/Chagos' => 'hindoceana tempo (Ĉagosoj)',
        'Indian/Christmas' => 'kristnaskinsula tempo (Kristnaskinsulo)',
        'Indian/Cocos' => 'kokosinsula tempo (Kokosinsuloj)',
        'Indian/Comoro' => 'orientafrika tempo (Komoroj)',
        'Indian/Kerguelen' => 'tempo: Francaj Sudaj Teritorioj (Kergelenoj)',
        'Indian/Mahe' => 'sejŝela tempo (Mahé)',
        'Indian/Maldives' => 'maldiva tempo (Maldivoj)',
        'Indian/Mauritius' => 'maŭricia tempo (Maŭricio)',
        'Indian/Mayotte' => 'orientafrika tempo (Majoto)',
        'Indian/Reunion' => 'tempo: Reunio',
        'Pacific/Apia' => 'samoa tempo (Apio)',
        'Pacific/Auckland' => 'novzelanda tempo (Aŭklando)',
        'Pacific/Bougainville' => 'tempo: Papuo-Nov-Gvineo (Bougainville)',
        'Pacific/Chatham' => 'ĉathama tempo (Ĉathamo)',
        'Pacific/Easter' => 'paskinsula tempo (Paskinsulo)',
        'Pacific/Efate' => 'vanuatua tempo (Efate)',
        'Pacific/Enderbury' => 'feniksinsula tempo (Kanton-insulo)',
        'Pacific/Kanton' => 'feniksinsula tempo (Kanton-insulo)',
        'Pacific/Fakaofo' => 'tokelaa tempo (Fakaofo)',
        'Pacific/Fiji' => 'fiĝia tempo (Fiĝio)',
        'Pacific/Funafuti' => 'tuvala tempo (Funafutio)',
        'Pacific/Galapagos' => 'galapaga tempo (Galapagoj)',
        'Pacific/Gambier' => 'tempo: Gambier',
        'Pacific/Guadalcanal' => 'tempo: Salomonoj (Guadalcanal)',
        'Pacific/Guam' => 'ĉamora tempo (Gvamo)',
        'Pacific/Honolulu' => 'Havajo-Aleutoj (norma tempo) (Honolulu)',
        'Pacific/Kiritimati' => 'tempo: Liniaj Insuloj (Kiritimati)',
        'Pacific/Kosrae' => 'tempo: Kosrae',
        'Pacific/Kwajalein' => 'marŝalinsula tempo (Kwajalein)',
        'Pacific/Majuro' => 'marŝalinsula tempo (Majuro)',
        'Pacific/Marquesas' => 'markizinsula tempo (Markizinsuloj)',
        'Pacific/Midway' => 'uson-samoa tempo (Midvejinsuloj)',
        'Pacific/Nauru' => 'naura tempo (Nauro)',
        'Pacific/Niue' => 'niua tempo (Niuo)',
        'Pacific/Norfolk' => 'norfolkinsula tempo (Norfolkinsulo)',
        'Pacific/Noumea' => 'novkaledonia tempo (Numeo)',
        'Pacific/Pago_Pago' => 'uson-samoa tempo (Pagopago)',
        'Pacific/Palau' => 'palaŭa tempo (Palaŭo)',
        'Pacific/Pitcairn' => 'pitkarninsula tempo (Pitkarna Insulo)',
        'Pacific/Ponape' => 'tempo: Ponape',
        'Pacific/Pohnpei' => 'tempo: Ponape',
        'Pacific/Port_Moresby' => 'tempo: Papuo-Nov-Gvineo (Port Moresby)',
        'Pacific/Rarotonga' => 'kukinsula tempo (Rarotongo)',
        'Pacific/Saipan' => 'ĉamora tempo (Saipano)',
        'Pacific/Tahiti' => 'tahitia tempo (Tahitio)',
        'Pacific/Tarawa' => 'gilbertinsula tempo (Taravo)',
        'Pacific/Tongatapu' => 'tonga tempo (Tongatapu)',
        'Pacific/Truk' => 'tempo: Ĉuuk',
        'Pacific/Chuuk' => 'tempo: Ĉuuk',
        'Pacific/Wake' => 'vejkinsula tempo (Vejkinsulo)',
        'Pacific/Wallis' => 'tempo: Valiso kaj Futuno',
    ],
    'Meta' => [
        'GmtFormat' => 'UTC%s',
    ],
];
