<?php

return [
    'Names' => [
        'aa' => 'афарська',
        'ab' => 'абхазька',
        'ace' => 'ачехська',
        'ach' => 'ачолі',
        'ada' => 'адангме',
        'ady' => 'адигейська',
        'ae' => 'авестійська',
        'af' => 'африкаанс',
        'afh' => 'африхілі',
        'agq' => 'агем',
        'ain' => 'айнська',
        'ak' => 'акан',
        'akk' => 'аккадська',
        'akz' => 'алабама',
        'ale' => 'алеутська',
        'alt' => 'південноалтайська',
        'am' => 'амхарська',
        'an' => 'арагонська',
        'ang' => 'давньоанглійська',
        'ann' => 'оболо',
        'anp' => 'ангіка',
        'ar' => 'арабська',
        'arc' => 'арамейська',
        'arn' => 'арауканська',
        'aro' => 'араона',
        'arp' => 'арапахо',
        'arq' => 'алжирська арабська',
        'ars' => 'надждійська арабська',
        'arw' => 'аравакська',
        'as' => 'ассамська',
        'asa' => 'асу',
        'ase' => 'американська мова рухів',
        'ast' => 'астурійська',
        'atj' => 'атикамек',
        'av' => 'аварська',
        'awa' => 'авадхі',
        'ay' => 'аймара',
        'az' => 'азербайджанська',
        'ba' => 'башкирська',
        'bal' => 'балучі',
        'ban' => 'балійська',
        'bar' => 'баеріш',
        'bas' => 'баса',
        'bax' => 'бамум',
        'bbc' => 'батак тоба',
        'bbj' => 'гомала',
        'be' => 'білоруська',
        'bej' => 'беджа',
        'bem' => 'бемба',
        'bew' => 'бетаві',
        'bez' => 'бена',
        'bfd' => 'бафут',
        'bfq' => 'бадага',
        'bg' => 'болгарська',
        'bgc' => 'харʼянві',
        'bgn' => 'східнобелуджійська',
        'bho' => 'бходжпурі',
        'bi' => 'біслама',
        'bik' => 'бікольська',
        'bin' => 'біні',
        'bjn' => 'банджарська',
        'bkm' => 'ком',
        'bla' => 'сіксіка',
        'blo' => 'анії',
        'bm' => 'бамбара',
        'bn' => 'бенгальська',
        'bo' => 'тибетська',
        'bqi' => 'бахтіарі',
        'br' => 'бретонська',
        'bra' => 'брадж',
        'brx' => 'бодо',
        'bs' => 'боснійська',
        'bss' => 'акус',
        'bua' => 'бурятська',
        'bug' => 'бугійська',
        'bum' => 'булу',
        'byn' => 'блін',
        'byv' => 'медумба',
        'ca' => 'каталонська',
        'cad' => 'каддо',
        'car' => 'карібська',
        'cay' => 'кайюга',
        'cch' => 'атсам',
        'ccp' => 'чакма',
        'ce' => 'чеченська',
        'ceb' => 'себуанська',
        'cgg' => 'кіга',
        'ch' => 'чаморро',
        'chb' => 'чібча',
        'chg' => 'чагатайська',
        'chk' => 'чуукська',
        'chm' => 'марійська',
        'chn' => 'чинук жаргон',
        'cho' => 'чокто',
        'chp' => 'чипевʼян',
        'chr' => 'черокі',
        'chy' => 'чейєнн',
        'ckb' => 'центральнокурдська',
        'clc' => 'чилкотін',
        'co' => 'корсиканська',
        'cop' => 'коптська',
        'cr' => 'крі',
        'crg' => 'мічиф',
        'crh' => 'кримськотатарська',
        'crj' => 'південно-східна крі',
        'crk' => 'рівнинна крі',
        'crl' => 'північна іст-крі',
        'crm' => 'муз-крі',
        'crr' => 'каролінська алгонкінська',
        'crs' => 'сейшельська креольська',
        'cs' => 'чеська',
        'csb' => 'кашубська',
        'csw' => 'свампі-крі',
        'cu' => 'церковнословʼянська',
        'cv' => 'чуваська',
        'cy' => 'валлійська',
        'da' => 'данська',
        'dak' => 'дакота',
        'dar' => 'даргінська',
        'dav' => 'таїта',
        'de' => 'німецька',
        'del' => 'делаварська',
        'den' => 'слейв',
        'dgr' => 'догрибська',
        'din' => 'дінка',
        'dje' => 'джерма',
        'doi' => 'догрі',
        'dsb' => 'нижньолужицька',
        'dua' => 'дуала',
        'dum' => 'середньонідерландська',
        'dv' => 'дивехі',
        'dyo' => 'дьола-фоні',
        'dyu' => 'діула',
        'dz' => 'дзонг-ке',
        'dzg' => 'дазага',
        'ebu' => 'ембу',
        'ee' => 'еве',
        'efi' => 'ефік',
        'egy' => 'давньоєгипетська',
        'eka' => 'екаджук',
        'el' => 'грецька',
        'elx' => 'еламська',
        'en' => 'англійська',
        'enm' => 'середньоанглійська',
        'eo' => 'есперанто',
        'es' => 'іспанська',
        'et' => 'естонська',
        'eu' => 'баскська',
        'ewo' => 'евондо',
        'fa' => 'перська',
        'fan' => 'фанг',
        'fat' => 'фанті',
        'ff' => 'фула',
        'fi' => 'фінська',
        'fil' => 'філіппінська',
        'fj' => 'фіджі',
        'fo' => 'фарерська',
        'fon' => 'фон',
        'fr' => 'французька',
        'frc' => 'кажунська французька',
        'frm' => 'середньофранцузька',
        'fro' => 'давньофранцузька',
        'frp' => 'арпітанська',
        'frr' => 'фризька північна',
        'frs' => 'фризька східна',
        'fur' => 'фріульська',
        'fy' => 'західнофризька',
        'ga' => 'ірландська',
        'gaa' => 'га',
        'gag' => 'гагаузька',
        'gan' => 'ґань',
        'gay' => 'гайо',
        'gba' => 'гбайя',
        'gd' => 'шотландська гельська',
        'gez' => 'гєез',
        'gil' => 'гільбертська',
        'gl' => 'галісійська',
        'gmh' => 'середньоверхньонімецька',
        'gn' => 'гуарані',
        'goh' => 'давньоверхньонімецька',
        'gon' => 'гонді',
        'gor' => 'горонтало',
        'got' => 'готська',
        'grb' => 'гребо',
        'grc' => 'давньогрецька',
        'gsw' => 'німецька (Швейцарія)',
        'gu' => 'гуджараті',
        'guz' => 'гусії',
        'gv' => 'менкська',
        'gwi' => 'кучін',
        'ha' => 'хауса',
        'hai' => 'хайда',
        'hak' => 'хаккаська',
        'haw' => 'гавайська',
        'hax' => 'південна гайда',
        'he' => 'іврит',
        'hi' => 'гінді',
        'hil' => 'хілігайнон',
        'hit' => 'хітіті',
        'hmn' => 'хмонг',
        'ho' => 'хірі-моту',
        'hr' => 'хорватська',
        'hsb' => 'верхньолужицька',
        'hsn' => 'сянська китайська',
        'ht' => 'гаїтянська креольська',
        'hu' => 'угорська',
        'hup' => 'хупа',
        'hur' => 'галкомелем',
        'hy' => 'вірменська',
        'hz' => 'гереро',
        'ia' => 'інтерлінгва',
        'iba' => 'ібанська',
        'ibb' => 'ібібіо',
        'id' => 'індонезійська',
        'ie' => 'інтерлінгве',
        'ig' => 'ігбо',
        'ii' => 'сичуаньська ї',
        'ik' => 'інупіак',
        'ikt' => 'західноканадська інуктитут',
        'ilo' => 'ілоканська',
        'inh' => 'інгуська',
        'io' => 'ідо',
        'is' => 'ісландська',
        'it' => 'італійська',
        'iu' => 'інуктитут',
        'ja' => 'японська',
        'jbo' => 'ложбан',
        'jgo' => 'нгомба',
        'jmc' => 'мачаме',
        'jpr' => 'юдео-перська',
        'jrb' => 'юдео-арабська',
        'jv' => 'яванська',
        'ka' => 'грузинська',
        'kaa' => 'каракалпацька',
        'kab' => 'кабільська',
        'kac' => 'качін',
        'kaj' => 'йю',
        'kam' => 'камба',
        'kaw' => 'каві',
        'kbd' => 'кабардинська',
        'kbl' => 'канембу',
        'kcg' => 'тіап',
        'kde' => 'маконде',
        'kea' => 'кабувердіану',
        'kfo' => 'коро',
        'kg' => 'конґолезька',
        'kgp' => 'кайнґанґ',
        'kha' => 'кхасі',
        'kho' => 'хотаносакська',
        'khq' => 'койра чиїні',
        'ki' => 'кікуйю',
        'kj' => 'кунама',
        'kk' => 'казахська',
        'kkj' => 'како',
        'kl' => 'калааллісут',
        'kln' => 'календжин',
        'km' => 'кхмерська',
        'kmb' => 'кімбунду',
        'kn' => 'каннада',
        'ko' => 'корейська',
        'koi' => 'комі-перм’яцька',
        'kok' => 'конкані',
        'kos' => 'косрае',
        'kpe' => 'кпеллє',
        'kr' => 'канурі',
        'krc' => 'карачаєво-балкарська',
        'krl' => 'карельська',
        'kru' => 'курукх',
        'ks' => 'кашмірська',
        'ksb' => 'шамбала',
        'ksf' => 'бафіа',
        'ksh' => 'кельнська',
        'ku' => 'курдська',
        'kum' => 'кумицька',
        'kut' => 'кутенаї',
        'kv' => 'комі',
        'kw' => 'корнська',
        'kwk' => 'кваквала',
        'kxv' => 'куві',
        'ky' => 'киргизька',
        'la' => 'латинська',
        'lad' => 'ладино',
        'lag' => 'лангі',
        'lah' => 'ланда',
        'lam' => 'ламба',
        'lb' => 'люксембурзька',
        'lez' => 'лезгінська',
        'lg' => 'ганда',
        'li' => 'лімбургійська',
        'lij' => 'лігурійська',
        'lil' => 'лілуетська',
        'lkt' => 'лакота',
        'lld' => 'ладинська',
        'lmo' => 'ломбардська',
        'ln' => 'лінгала',
        'lo' => 'лаоська',
        'lol' => 'монго',
        'lou' => 'луїзіанська креольська',
        'loz' => 'лозі',
        'lrc' => 'північнолурська',
        'lsm' => 'самія',
        'lt' => 'литовська',
        'ltg' => 'латгальська',
        'lu' => 'луба-катанга',
        'lua' => 'луба-лулуа',
        'lui' => 'луїсеньо',
        'lun' => 'лунда',
        'luo' => 'луо',
        'lus' => 'мізо',
        'luy' => 'луйя',
        'lv' => 'латиська',
        'mad' => 'мадурська',
        'maf' => 'мафа',
        'mag' => 'магадхі',
        'mai' => 'майтхілі',
        'mak' => 'макасарська',
        'man' => 'мандінго',
        'mas' => 'масаї',
        'mde' => 'маба',
        'mdf' => 'мокша',
        'mdr' => 'мандарська',
        'men' => 'менде',
        'mer' => 'меру',
        'mfe' => 'маврикійська креольська',
        'mg' => 'малагасійська',
        'mga' => 'середньоірландська',
        'mgh' => 'макува-меето',
        'mgo' => 'мета',
        'mh' => 'маршалльська',
        'mi' => 'маорі',
        'mic' => 'мікмак',
        'min' => 'мінангкабау',
        'mk' => 'македонська',
        'ml' => 'малаялам',
        'mn' => 'монгольська',
        'mnc' => 'манчжурська',
        'mni' => 'маніпурі',
        'moe' => 'інну-аймун',
        'moh' => 'магавк',
        'mos' => 'моссі',
        'mr' => 'маратхі',
        'ms' => 'малайська',
        'mt' => 'мальтійська',
        'mua' => 'мунданг',
        'mus' => 'крік',
        'mwl' => 'мірандська',
        'mwr' => 'марварі',
        'my' => 'бірманська',
        'mye' => 'миін',
        'myv' => 'ерзя',
        'mzn' => 'мазандеранська',
        'na' => 'науру',
        'nan' => 'південноміньська',
        'nap' => 'неаполітанська',
        'naq' => 'нама',
        'nb' => 'норвезька (букмол)',
        'nd' => 'північна ндебеле',
        'nds' => 'нижньонімецька',
        'ne' => 'непальська',
        'new' => 'неварі',
        'ng' => 'ндонга',
        'nia' => 'ніаська',
        'niu' => 'ніуе',
        'njo' => 'ао нага',
        'nl' => 'нідерландська',
        'nmg' => 'квазіо',
        'nn' => 'норвезька (нюношк)',
        'nnh' => 'нгємбун',
        'no' => 'норвезька',
        'nog' => 'ногайська',
        'non' => 'давньонорвезька',
        'nqo' => 'нко',
        'nr' => 'ндебелє південна',
        'nso' => 'північна сото',
        'nus' => 'нуер',
        'nv' => 'навахо',
        'nwc' => 'неварі класична',
        'ny' => 'ньянджа',
        'nym' => 'ньямвезі',
        'nyn' => 'ньянколе',
        'nyo' => 'ньоро',
        'nzi' => 'нзіма',
        'oc' => 'окситанська',
        'oj' => 'оджібва',
        'ojb' => 'північно-західна оджибве',
        'ojc' => 'центральна оджибве',
        'ojs' => 'оджи-крі',
        'ojw' => 'західна оджибве',
        'oka' => 'оканаганська',
        'om' => 'оромо',
        'or' => 'одія',
        'os' => 'осетинська',
        'osa' => 'осейдж',
        'ota' => 'османська',
        'pa' => 'панджабі',
        'pag' => 'пангасінанська',
        'pal' => 'пехлеві',
        'pam' => 'пампанга',
        'pap' => 'папʼяменто',
        'pau' => 'палауанська',
        'pcm' => 'нігерійсько-креольська',
        'peo' => 'давньоперська',
        'phn' => 'фінікійсько-пунічна',
        'pi' => 'палі',
        'pis' => 'піджин',
        'pl' => 'польська',
        'pon' => 'понапе',
        'pqm' => 'малесіт-пасамакводі',
        'prg' => 'прусська',
        'pro' => 'давньопровансальська',
        'ps' => 'пушту',
        'pt' => 'португальська',
        'qu' => 'кечуа',
        'quc' => 'кіче',
        'raj' => 'раджастхані',
        'rap' => 'рапануї',
        'rar' => 'раротонга',
        'rhg' => 'рогінджа',
        'rm' => 'ретороманська',
        'rn' => 'рунді',
        'ro' => 'румунська',
        'rof' => 'ромбо',
        'rom' => 'циганська',
        'ru' => 'російська',
        'rup' => 'арумунська',
        'rw' => 'кіньяруанда',
        'rwk' => 'рва',
        'sa' => 'санскрит',
        'sad' => 'сандаве',
        'sah' => 'якутська',
        'sam' => 'самаритянська арамейська',
        'saq' => 'самбуру',
        'sas' => 'сасакська',
        'sat' => 'сантальська',
        'sba' => 'нгамбай',
        'sbp' => 'сангу',
        'sc' => 'сардинська',
        'scn' => 'сицилійська',
        'sco' => 'шотландська',
        'sd' => 'синдхі',
        'sdh' => 'південнокурдська',
        'se' => 'північносаамська',
        'see' => 'сенека',
        'seh' => 'сена',
        'sel' => 'селькупська',
        'ses' => 'койраборо сені',
        'sg' => 'санго',
        'sga' => 'давньоірландська',
        'sh' => 'сербсько-хорватська',
        'shi' => 'тачеліт',
        'shn' => 'шанська',
        'shu' => 'чадійська арабська',
        'si' => 'сингальська',
        'sid' => 'сідамо',
        'sk' => 'словацька',
        'sl' => 'словенська',
        'slh' => 'південна лушуцид',
        'sm' => 'самоанська',
        'sma' => 'південносаамська',
        'smj' => 'саамська луле',
        'smn' => 'саамська інарі',
        'sms' => 'скольт-саамська',
        'sn' => 'шона',
        'snk' => 'сонінке',
        'so' => 'сомалі',
        'sog' => 'согдійська',
        'sq' => 'албанська',
        'sr' => 'сербська',
        'srn' => 'сранан тонго',
        'srr' => 'серер',
        'ss' => 'сисваті',
        'ssy' => 'сахо',
        'st' => 'південна сото',
        'str' => 'саліська стрейт',
        'su' => 'сунданська',
        'suk' => 'сукума',
        'sus' => 'сусу',
        'sux' => 'шумерська',
        'sv' => 'шведська',
        'sw' => 'суахілі',
        'swb' => 'коморська',
        'syc' => 'сирійська класична',
        'syr' => 'сирійська',
        'szl' => 'сілезька',
        'ta' => 'тамільська',
        'tce' => 'південна тутчон',
        'te' => 'телугу',
        'tem' => 'темне',
        'teo' => 'тесо',
        'ter' => 'терено',
        'tet' => 'тетум',
        'tg' => 'таджицька',
        'tgx' => 'тагіш',
        'th' => 'тайська',
        'tht' => 'талтан',
        'ti' => 'тигринья',
        'tig' => 'тигре',
        'tiv' => 'тів',
        'tk' => 'туркменська',
        'tkl' => 'токелау',
        'tl' => 'тагальська',
        'tlh' => 'клінгонська',
        'tli' => 'тлінгіт',
        'tmh' => 'тамашек',
        'tn' => 'тсвана',
        'to' => 'тонганська',
        'tog' => 'ньяса тонга',
        'tok' => 'токі-пона',
        'tpi' => 'ток-пісін',
        'tr' => 'турецька',
        'trv' => 'тароко',
        'ts' => 'тсонга',
        'tsi' => 'цимшиан',
        'tt' => 'татарська',
        'ttm' => 'північна тутчон',
        'tum' => 'тумбука',
        'tvl' => 'тувалу',
        'tw' => 'тві',
        'twq' => 'тасавак',
        'ty' => 'таїтянська',
        'tyv' => 'тувинська',
        'tzm' => 'центральноатласька тамазігт',
        'udm' => 'удмуртська',
        'ug' => 'уйгурська',
        'uga' => 'угаритська',
        'uk' => 'українська',
        'umb' => 'умбунду',
        'ur' => 'урду',
        'uz' => 'узбецька',
        'vai' => 'ваї',
        've' => 'венда',
        'vec' => 'венеційська',
        'vi' => 'вʼєтнамська',
        'vmw' => 'макува',
        'vo' => 'волапюк',
        'vot' => 'водська',
        'vun' => 'вуньо',
        'wa' => 'валлонська',
        'wae' => 'вальзерська',
        'wal' => 'волайтта',
        'war' => 'варай',
        'was' => 'вашо',
        'wbp' => 'валпірі',
        'wo' => 'волоф',
        'wuu' => 'китайська уська',
        'xal' => 'калмицька',
        'xh' => 'кхоса',
        'xnr' => 'кангрі',
        'xog' => 'сога',
        'yao' => 'яо',
        'yap' => 'яп',
        'yav' => 'янгбен',
        'ybb' => 'ємба',
        'yi' => 'їдиш',
        'yo' => 'йоруба',
        'yrl' => 'ньєнґату',
        'yue' => 'кантонська',
        'za' => 'чжуан',
        'zap' => 'сапотекська',
        'zbl' => 'блісса мова',
        'zen' => 'зенага',
        'zgh' => 'стандартна марокканська берберська',
        'zh' => 'китайська',
        'zu' => 'зулуська',
        'zun' => 'зуньї',
        'zza' => 'зазакі',
    ],
    'LocalizedNames' => [
        'ar_001' => 'сучасна стандартна арабська',
        'az_Arab' => 'південноазербайджанська',
        'de_CH' => 'верхньонімецька (Швейцарія)',
        'fa_AF' => 'дарі',
        'nds_NL' => 'нижньосаксонська',
        'nl_BE' => 'фламандська',
        'ro_MD' => 'молдавська',
        'sw_CD' => 'суахілі (Конго)',
        'zh_Hans' => 'китайська (спрощене письмо)',
        'zh_Hant' => 'китайська (традиційне письмо)',
    ],
];
