<?php

return [
    'Names' => [
        'Adlm' => 'ადლამი',
        'Afak' => 'აფაკა',
        'Arab' => 'არაბული',
        'Aran' => 'ნასტალიქი',
        'Armi' => 'იმპერიული არამეული',
        'Armn' => 'სომხური',
        'Avst' => 'ავესტური',
        'Bali' => 'ბალიური',
        'Bamu' => 'ბამუმი',
        'Bass' => 'ბასა ვაჰი',
        'Batk' => 'ბატაკი',
        'Beng' => 'ბენგალური',
        'Blis' => 'ბლისსიმბოლოები',
        'Bopo' => 'ბოპომოფო',
        'Brah' => 'ბრაჰმი',
        'Brai' => 'ბრაილი',
        'Buhd' => 'ბუჰიდი',
        'Cakm' => 'ჩაკმა',
        'Cans' => 'გაერთიანებული კანადური სილაბური',
        'Cari' => 'კარიული',
        'Cham' => 'ჩამი',
        'Cher' => 'ჩეროკი',
        'Cirt' => 'კირთი',
        'Copt' => 'კოპტური',
        'Cprt' => 'კვიპროსული',
        'Cyrl' => 'კირილიცა',
        'Cyrs' => 'ძველი სლავური კირილიცა',
        'Deva' => 'დევანაგარი',
        'Dsrt' => 'დეზერეტის',
        'Dupl' => 'დუპლოის სტენოგრაფია',
        'Egyd' => 'ეგვიპტური დემოტიკური',
        'Egyh' => 'ეგვიპტური იერატიკული',
        'Egyp' => 'ეგვიპტური იეროგლიფური',
        'Ethi' => 'ეთიოპიური',
        'Geok' => 'ხუცური',
        'Geor' => 'ქართული',
        'Glag' => 'გლაგოლიცა',
        'Goth' => 'გოთური',
        'Gran' => 'გრანთა',
        'Grek' => 'ბერძნული',
        'Gujr' => 'გუჯარათული',
        'Guru' => 'გურმუხი',
        'Hanb' => 'ჰანბი',
        'Hang' => 'ჰანგული',
        'Hani' => 'ჰანი',
        'Hano' => 'ჰანუნოო',
        'Hans' => 'გამარტივებული',
        'Hant' => 'ტრადიციული',
        'Hebr' => 'ებრაული',
        'Hira' => 'ჰირაგანა',
        'Hluw' => 'ანატოლიური იეროგლიფური',
        'Hmng' => 'ფაჰაუ-მონი',
        'Hrkt' => 'იაპონური კანა',
        'Hung' => 'ძველი უნგრული',
        'Jamo' => 'ჯამო',
        'Java' => 'იავური',
        'Jpan' => 'იაპონური',
        'Jurc' => 'ჯურჯენული',
        'Kali' => 'კაიაჰ-ლი',
        'Kana' => 'კატაკანა',
        'Khar' => 'ქაროშთი',
        'Khmr' => 'ქმერული',
        'Khoj' => 'ქოჯკი',
        'Knda' => 'კანადა',
        'Kore' => 'კორეული',
        'Kpel' => 'კპელე',
        'Kthi' => 'კაითი',
        'Laoo' => 'ლაოსური',
        'Latg' => 'გელური ლათინური',
        'Latn' => 'ლათინური',
        'Limb' => 'ლიმბუ',
        'Lina' => 'A-ხაზოვანი',
        'Linb' => 'B-ხაზოვანი',
        'Loma' => 'ლომა',
        'Lyci' => 'ლიკიური',
        'Lydi' => 'ლიდიური',
        'Mand' => 'მანდეური',
        'Mani' => 'მანიქეური',
        'Maya' => 'მაიას იეროგლიფები',
        'Mend' => 'მენდე',
        'Merc' => 'მეროიტული კურსივი',
        'Mero' => 'მეროიტული',
        'Mlym' => 'მალაიალამური',
        'Mong' => 'მონღოლური',
        'Mroo' => 'მრო',
        'Mtei' => 'მანიპური',
        'Mymr' => 'მიანმური',
        'Narb' => 'ძველი ჩრდილოეთ-არაბული',
        'Nbat' => 'ნაბატეური',
        'Nkoo' => 'ნკო',
        'Nshu' => 'ნუშუ',
        'Ogam' => 'ოღამი',
        'Olck' => 'ოლ-ჩიკი',
        'Orkh' => 'ორხონული',
        'Orya' => 'ორია',
        'Osma' => 'ოსმანია',
        'Palm' => 'პალმირული',
        'Perm' => 'ძველი პერმული',
        'Phag' => 'ფაგსპა',
        'Phli' => 'მონუმენტური ფალაური',
        'Phlp' => 'ფსალმუნური ფალაური',
        'Phlv' => 'წიგნური ფალაური',
        'Phnx' => 'ფინიკიური',
        'Prti' => 'მონუმენტური პართული',
        'Rjng' => 'რეჯანგი',
        'Rohg' => 'ჰანიფი',
        'Roro' => 'რონგორონგო',
        'Runr' => 'რუნული',
        'Samr' => 'სამარიული',
        'Sara' => 'სარატი',
        'Sarb' => 'ძველი სამხრეთ-არაბული',
        'Saur' => 'საურაშტრა',
        'Sgnw' => 'ჟესტთა',
        'Shrd' => 'შარადა',
        'Sind' => 'ქუდავადი',
        'Sinh' => 'სინჰალური',
        'Sora' => 'სორან-სომპენი',
        'Sund' => 'სუნდანური',
        'Sylo' => 'სილოტი ნაგრი',
        'Syrc' => 'სირიული',
        'Syre' => 'სირიული ესტრანგელო',
        'Syrj' => 'დასავლეთი სირიული',
        'Syrn' => 'აღმოსავლეთი სირიული',
        'Tagb' => 'ტაგბანვა',
        'Takr' => 'ტაკრი',
        'Tale' => 'ტაი ლე',
        'Talu' => 'ახალი ტაი ლიუ',
        'Taml' => 'ტამილური',
        'Tang' => 'ტანღუტური',
        'Tavt' => 'ტაი-ვიეტი',
        'Telu' => 'ტელუგუ',
        'Teng' => 'ტენგვარი',
        'Tfng' => 'ტიფინაღი',
        'Thaa' => 'თაანა',
        'Thai' => 'ტაილანდური',
        'Tibt' => 'ტიბეტური',
        'Tirh' => 'ტირჰუტა',
        'Ugar' => 'უგარითული',
        'Vaii' => 'ვაი',
        'Visp' => 'ხილული მეტყველება',
        'Wara' => 'ვარანგ-კშიტი',
        'Wole' => 'ვოლეაი',
        'Xpeo' => 'ძველი სპარსული',
        'Xsux' => 'შუმერულ-აქადური ლურსმნული',
        'Yiii' => 'ი',
        'Zinh' => 'გადაღებული',
        'Zmth' => 'მათემატიკური ნოტაცია',
        'Zsye' => 'Emoji',
        'Zsym' => 'სიმბოლოები',
        'Zxxx' => 'უმწერლობო',
        'Zyyy' => 'ზოგადი',
    ],
];
