<?php

return [
    'Names' => [
        'af' => 'IsiBhulu',
        'am' => 'IsiAmharic',
        'ar' => 'Isi-Arabhu',
        'as' => 'IsiAssamese',
        'az' => 'Isi-Azerbaijani',
        'be' => 'Isi-Belarusian',
        'bg' => 'Isi-Bulgaria',
        'bn' => 'IsiBangla',
        'br' => 'IsiBreton',
        'bs' => 'Isi-Bosnia',
        'ca' => 'Isi-Calatan',
        'cs' => 'Isi-Czech',
        'cy' => 'Isi-Welsh',
        'da' => 'Isi-Danish',
        'de' => 'IsiJamani',
        'el' => 'Isi-Greek',
        'en' => 'IsiNgesi',
        'eo' => 'Isi-Esperanto',
        'es' => 'Isi-Spanish',
        'et' => 'Isi-Estonian',
        'eu' => 'Isi-Basque',
        'fa' => 'Isi-Persia',
        'fi' => 'Isi-Finnish',
        'fil' => 'Isi-Taglog',
        'fo' => 'Isi-Faroese',
        'fr' => 'IsiFrentshi',
        'fy' => 'Isi-Frisian',
        'ga' => 'Isi-Irish',
        'gd' => 'Scots Gaelic',
        'gl' => 'Isi-Galician',
        'gu' => 'Isi-Gujarati',
        'he' => 'Isi-Hebrew',
        'hi' => 'IsiHindi',
        'hr' => 'Isi-Croatia',
        'hu' => 'Isi-Hungarian',
        'hy' => 'IsiArmenia',
        'ia' => 'Isi-Interlingua',
        'id' => 'Isi-Indonesia',
        'ie' => 'Isi-Interlingue',
        'is' => 'Isi-Icelandic',
        'it' => 'IsiTaliyane',
        'ja' => 'IsiJapan',
        'jv' => 'Isi-Javanese',
        'ka' => 'Isi-Georgia',
        'km' => 'IsiCambodia',
        'kn' => 'Isi-Kannada',
        'ko' => 'Isi-Korean',
        'ku' => 'IsiKurdish',
        'ky' => 'IsiKyrgz',
        'lo' => 'IsiLoathian',
        'lt' => 'Isi-Lithuanian',
        'lv' => 'Isi-Latvian',
        'mk' => 'Isi-Macedonian',
        'ml' => 'Isi-Malayalam',
        'mn' => 'IsiMongolian',
        'mr' => 'Isi-Marathi',
        'ms' => 'Isi-Malay',
        'mt' => 'Isi-Maltese',
        'ne' => 'Isi-Nepali',
        'nl' => 'IsiDatshi',
        'nn' => 'Isi-Norwegia (Nynorsk)',
        'no' => 'Isi-Norwegian',
        'oc' => 'Iso-Occitan',
        'or' => 'Oriya',
        'pa' => 'Isi-Punjabi',
        'pl' => 'Isi-Polish',
        'ps' => 'IsiPashto',
        'pt' => 'IsiPhuthukezi',
        'ro' => 'Isi-Romanian',
        'ru' => 'Isi-Russian',
        'sa' => 'IsiSanskrit',
        'sd' => 'IsiSindhi',
        'si' => 'Isi-Sinhalese',
        'sk' => 'Isi-Slovak',
        'sl' => 'Isi-Slovenian',
        'so' => 'IsiSomaliya',
        'sq' => 'IsiAlbania',
        'sr' => 'Isi-Serbia',
        'st' => 'Sesotho',
        'su' => 'Isi-Sudanese',
        'sv' => 'Isi-Swedish',
        'sw' => 'Isi-Swahili',
        'ta' => 'Isi-Tamil',
        'te' => 'Isi-Telegu',
        'th' => 'Isi-Thai',
        'ti' => 'Isi-Tigrinya',
        'tk' => 'IsiTurkmen',
        'tr' => 'Isi-Turkish',
        'ug' => 'Isi Uighur',
        'uk' => 'Isi-Ukranian',
        'ur' => 'IsiUrdu',
        'uz' => 'Isi-Uzbek',
        'vi' => 'Isi-Vietnamese',
        'xh' => 'IsiXhosa',
        'zh' => 'IsiMandarin',
        'zu' => 'IsiZulu',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Isi-Arabhu (Sale mihla)',
        'de_AT' => 'IsiJamani Sase-Austria',
        'de_CH' => 'IsiJamani Esiyi-High Swiss',
        'en_AU' => 'IsiNgesi Sase-Australia',
        'en_CA' => 'IsiNgesi SaseKhanada',
        'en_GB' => 'IsiNgesi SaseBritane',
        'en_US' => 'Isingesi SaseMelika',
        'es_419' => 'IsiSpanish SaseLatin America',
        'es_ES' => 'IsiSpanish SaseYurophu',
        'es_MX' => 'IsiSpanish SaseMexico',
        'fr_CA' => 'IsiFrentshi SaseKhanada',
        'fr_CH' => 'IsiFrentshi SaseSwitzerland',
        'hi_Latn' => 'IsiHindi (Latin)',
        'nl_BE' => 'IsiFlemish',
        'pt_BR' => 'IsiPhuthukezi SaseBrazil',
        'pt_PT' => 'IsiPhuthukezi SasePortugal',
        'zh_Hans' => 'IsiTshayina Esenziwe Lula',
        'zh_Hant' => 'IsiTshayina Esiqhelekileyo',
    ],
];
