<?php

return [
    'Names' => [
        'Adlm' => 'адлам',
        'Aghb' => 'кавказ албан',
        'Ahom' => 'ахом',
        'Arab' => 'ғәрәп',
        'Aran' => 'насталик',
        'Armi' => 'император арамей',
        'Armn' => 'әрмән',
        'Avst' => 'авестий',
        'Bali' => 'бали',
        'Bamu' => 'бамум',
        'Bass' => 'басса Вах',
        'Batk' => 'батак',
        'Beng' => 'бенгал',
        'Berf' => 'берия эрфе',
        'Bhks' => 'бхаиксуки',
        'Bopo' => 'бопомофо',
        'Brah' => 'брахми',
        'Brai' => 'брайль шрифты',
        'Bugi' => 'буги',
        'Buhd' => 'бухид',
        'Cakm' => 'чакма',
        'Cans' => 'берҙәм Канада аборигендарҙың ижектәре',
        'Cari' => 'кари',
        'Cham' => 'чам',
        'Cher' => 'чероки',
        'Chrs' => 'хәрәзм',
        'Copt' => 'копт',
        'Cpmn' => 'кипр-миной',
        'Cprt' => 'кипр',
        'Cyrl' => 'кириллица',
        'Cyrs' => 'иҫке сиркәү славян кириллицаһы',
        'Deva' => 'деванагари',
        'Diak' => 'дивес акуру',
        'Dogr' => 'догра',
        'Dsrt' => 'дезерет',
        'Dupl' => 'дюплойе ҡыҫҡа',
        'Egyp' => 'мысыр иероглифтары',
        'Elba' => 'эльбасан',
        'Elym' => 'элимай',
        'Ethi' => 'эфиоп',
        'Gara' => 'гараи',
        'Geor' => 'грузин',
        'Glag' => 'глаголица',
        'Gong' => 'гуньджала гонди',
        'Gonm' => 'масарам гонди',
        'Goth' => 'гот',
        'Gran' => 'грантха',
        'Grek' => 'грек',
        'Gujr' => 'гуджарати',
        'Gukh' => 'гурунг кхема',
        'Guru' => 'гурмукхи',
        'Hanb' => 'бопомофо менән хань',
        'Hang' => 'хангыль',
        'Hani' => 'хань (ҡытай иероглифтары)',
        'Hano' => 'хануну',
        'Hans' => 'ябайлаштырылған',
        'Hant' => 'традицион',
        'Hatr' => 'хатра',
        'Hebr' => 'йәһүд',
        'Hira' => 'хирагана',
        'Hluw' => 'анатолия иероглифтары',
        'Hmng' => 'пахау хмонг',
        'Hmnp' => 'ньякенг пуачуэ хмонг',
        'Hrkt' => 'япон ижектәре',
        'Hung' => 'иҫке венгр',
        'Ital' => 'иҫке итал',
        'Jamo' => 'джамо',
        'Java' => 'ява',
        'Jpan' => 'япон',
        'Kali' => 'кайа Ли',
        'Kana' => 'катакана',
        'Kawi' => 'кави',
        'Khar' => 'кхароштхи',
        'Khmr' => 'кхмер',
        'Khoj' => 'ходжки',
        'Kits' => 'кесе кидань',
        'Knda' => 'каннада',
        'Kore' => 'корей',
        'Krai' => 'кират раи',
        'Kthi' => 'кайтхи',
        'Lana' => 'ланна',
        'Laoo' => 'лаос',
        'Latf' => 'фрактура латин',
        'Latg' => 'гэль латин',
        'Latn' => 'латиница',
        'Lepc' => 'лепча',
        'Limb' => 'лимбу',
        'Lina' => 'һыҙыҡлы А яҙмаһы',
        'Linb' => 'һыҙыҡлы Б яҙмаһы',
        'Lisu' => 'лису',
        'Lyci' => 'лики',
        'Lydi' => 'лидия',
        'Mahj' => 'махаджани',
        'Maka' => 'макасар',
        'Mand' => 'мандей',
        'Mani' => 'манихей',
        'Marc' => 'марсен',
        'Medf' => 'медефаидрин',
        'Mend' => 'менде',
        'Merc' => 'мероит курсивы',
        'Mero' => 'мероит',
        'Mlym' => 'малаялам',
        'Modi' => 'моди',
        'Mong' => 'монгол',
        'Mroo' => 'мро',
        'Mtei' => 'мейтей майек',
        'Mult' => 'мултани',
        'Mymr' => 'мьянма',
        'Nagm' => 'наг мундари',
        'Nand' => 'нандинагари',
        'Narb' => 'иҫке төньяҡ ғәрәп',
        'Nbat' => 'набатей',
        'Newa' => 'нева',
        'Nkoo' => 'н’ко',
        'Nshu' => 'нюй-шу',
        'Ogam' => 'огам',
        'Olck' => 'ол чики',
        'Onao' => 'ол онал',
        'Orkh' => 'орхон',
        'Orya' => 'ория',
        'Osge' => 'осейдж',
        'Osma' => 'осман',
        'Ougr' => 'боронғо уйғыр',
        'Palm' => 'пальмира',
        'Pauc' => 'пау чин хау',
        'Perm' => 'боронғо пермь',
        'Phag' => 'пагспа',
        'Phli' => 'пәһләүи',
        'Phlp' => 'псалтирь пәһләүи',
        'Phnx' => 'финикия',
        'Plrd' => 'поллард фонетикаһы',
        'Prti' => 'парфия',
        'Qaag' => 'завги',
        'Rjng' => 'реджанг',
        'Rohg' => 'ханифи',
        'Runr' => 'рун',
        'Samr' => 'самаритян',
        'Sarb' => 'иҫке Көньяҡ ғәрәп',
        'Saur' => 'саураштра',
        'Sgnw' => 'ым-ишара яҙыуы',
        'Shaw' => 'шавиан',
        'Shrd' => 'шарада',
        'Sidd' => 'сиддхам',
        'Sidt' => 'сидет',
        'Sind' => 'кхудавади',
        'Sinh' => 'сингал',
        'Sogd' => 'соғҙи',
        'Sogo' => 'боронғо соғҙи',
        'Sora' => 'сора Сомпенг',
        'Soyo' => 'соёмбо',
        'Sund' => 'сундан',
        'Sunu' => 'сунувар',
        'Sylo' => 'силоти Нагри',
        'Syrc' => 'сүриә',
        'Syre' => 'эстрангело сүриә',
        'Syrj' => 'көнбайыш сүриә',
        'Syrn' => 'көнсығыш сүриә',
        'Tagb' => 'тагбанва',
        'Takr' => 'такри',
        'Tale' => 'тай Ле',
        'Talu' => 'яңы тай ле',
        'Taml' => 'тамил',
        'Tang' => 'тангут',
        'Tavt' => 'тай Вьет',
        'Tayo' => 'тай йо',
        'Telu' => 'телугу',
        'Tfng' => 'тифинаг',
        'Tglg' => 'тагалог',
        'Thaa' => 'таана',
        'Thai' => 'тай',
        'Tibt' => 'тибет',
        'Tirh' => 'тирхута',
        'Tnsa' => 'тангса',
        'Todr' => 'тодри',
        'Tols' => 'толонг сики',
        'Toto' => 'тото',
        'Tutg' => 'тулу-тигалари',
        'Ugar' => 'угарит',
        'Vaii' => 'ваи',
        'Vith' => 'виткучи',
        'Wara' => 'варанг кшити',
        'Wcho' => 'ванчо',
        'Xpeo' => 'иҫке фарсы',
        'Xsux' => 'шумер-аккад шына',
        'Yezi' => 'йәзид',
        'Yiii' => 'и',
        'Zanb' => 'занабазар',
        'Zinh' => 'вариҫләнгән',
        'Zmth' => 'математик билдәләү',
        'Zsye' => 'эмодзи',
        'Zsym' => 'символдар',
        'Zxxx' => 'яҙыуһыҙ',
        'Zyyy' => 'дөйөм',
    ],
];
