<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'اؠڑورَن پیسِٹا',
        ],
        'AED' => [
            'AED',
            'مُتحدہ عرب اِمارات دِرہم',
        ],
        'AFN' => [
            'AFN',
            'افغان افغٲنی',
        ],
        'ALL' => [
            'ALL',
            'اؠلبینِیَن لِک',
        ],
        'AMD' => [
            'AMD',
            'اَرمانؠن ڈرؠم',
        ],
        'ANG' => [
            'ANG',
            'نایدَرلینڑ اؠنٹٕلیٖیَن گِلڑَر',
        ],
        'AOA' => [
            'AOA',
            'اؠنگولَن کوانزا',
        ],
        'AOR' => [
            'AOR',
            'اؠنگولَن کوانزا رؠجِسٹاڑو',
        ],
        'ARA' => [
            'ARA',
            'أرجَنٹیٖن اَسٹرل',
        ],
        'ARS' => [
            'ARS',
            'أرجَنٹیٖن پِسو',
        ],
        'ATS' => [
            'ATS',
            'آسٹریَن شِلِنگ',
        ],
        'AUD' => [
            'A$',
            'آسٹریلِیَن ڈالَر',
        ],
        'AWG' => [
            'AWG',
            'اَروبَن فِلورِن',
        ],
        'AZN' => [
            'AZN',
            'آزَرباجانی مَنَٹ',
        ],
        'BAD' => [
            'BAD',
            'بوزنِیاہَرزِگووِنا دیٖنار',
        ],
        'BAM' => [
            'BAM',
            'بوزنِیاہَرزِگووِنا کَنوٲٹیبٕل مارٕک',
        ],
        'BBD' => [
            'BBD',
            'بابیڑِیَن ڈالَر',
        ],
        'BDT' => [
            'BDT',
            'بَنگلادیٖشی ٹَکا',
        ],
        'BEF' => [
            'BEF',
            'بَلجِیَن فرینک',
        ],
        'BGN' => [
            'BGN',
            'بیلگیرِیَن ہاڑ لِو',
        ],
        'BHD' => [
            'BHD',
            'بحریٖنی دیٖنار',
        ],
        'BIF' => [
            'BIF',
            'بُرُنڑِین فرینک',
        ],
        'BMD' => [
            'BMD',
            'بٔرمیوٗڑَن ڈالَر',
        ],
        'BND' => [
            'BND',
            'برونی ڈالَر',
        ],
        'BOB' => [
            'BOB',
            'بولِوِیَن بولوینو',
        ],
        'BOP' => [
            'BOP',
            'بولویَن پِسو',
        ],
        'BOV' => [
            'BOV',
            'بولوِیَن مَوڈال',
        ],
        'BRB' => [
            'BRB',
            'برازیٖلین کروزِرو نووو',
        ],
        'BRC' => [
            'BRC',
            'برازیٖلین کروزیڑو',
        ],
        'BRE' => [
            'BRE',
            'برازیٖلین کروزِرو',
        ],
        'BRL' => [
            'R$',
            'برازیٖلی رِیَل',
        ],
        'BRN' => [
            'BRN',
            'برازیٖلین کروزیڑو نووو',
        ],
        'BRR' => [
            'BRR',
            'برازیٖلین کروزیرو',
        ],
        'BSD' => [
            'BSD',
            'بہامِیَن ڈالر',
        ],
        'BTN' => [
            'BTN',
            'بوٗٹینیٖز نگُلٹرم',
        ],
        'BUK' => [
            'BUK',
            'بٔرمیٖز کیٹ',
        ],
        'BWP' => [
            'BWP',
            'بوٹٕسوانَن پُلا',
        ],
        'BYB' => [
            'BYB',
            'بِلیروشِیَن نِو رِبٕل',
        ],
        'BYN' => [
            'BYN',
            'بِلیروشِیَن رِبٕل',
        ],
        'BYR' => [
            'BYR',
            'بِلیروشِیَن رِبٕل (۲۰۰۰–۲۰۱۶)',
        ],
        'BZD' => [
            'BZD',
            'بِلِزی ڈالر',
        ],
        'CAD' => [
            'CA$',
            'کینَڑِیَن ڈالر',
        ],
        'CDF' => [
            'CDF',
            'کونگولیٖز فریک',
        ],
        'CHE' => [
            'CHE',
            'وِر یوٗرو',
        ],
        'CHF' => [
            'CHF',
            'سُوِز فریک',
        ],
        'CHW' => [
            'CHW',
            'وِر فریک',
        ],
        'CLF' => [
            'CLF',
            'چِلِن یوٗنِڑیدیٖز ڑِ فومیٹو',
        ],
        'CLP' => [
            'CLP',
            'چِلِن پِسو',
        ],
        'CNY' => [
            'CN¥',
            'چیٖنی یُوان',
        ],
        'COP' => [
            'COP',
            'کولَمبِین پِسو',
        ],
        'COU' => [
            'COU',
            'ِٖیوٗنِڑیڑ ڑِ ویلور رِیل',
        ],
        'CRC' => [
            'CRC',
            'کوسٹا رِکَن کولَن',
        ],
        'CSD' => [
            'CSD',
            'پرون سٔربِین ڈالر',
        ],
        'CSK' => [
            'CSK',
            'چِکوسولوواک ہاڑ کوروٗنا',
        ],
        'CUP' => [
            'CUP',
            'کیوٗبَن پِسو',
        ],
        'CYP' => [
            'CYP',
            'کیپروٹ پَوُڑ',
        ],
        'CZK' => [
            'CZK',
            'چیک کوریٖنا',
        ],
        'DDM' => [
            'DDM',
            'مٔشرِقی جٔرمَن مارٕک',
        ],
        'DEM' => [
            'DEM',
            'جٔرمَن مارٕک',
        ],
        'DKK' => [
            'DKK',
            'ڈٔنِش کرون',
        ],
        'DOP' => [
            'DOP',
            'ڈومِنِکَن پِسو',
        ],
        'DZD' => [
            'DZD',
            'اؠلجیرِیَن ڈیٖنار',
        ],
        'EEK' => [
            'EEK',
            'اؠسٹونِیَن کرون',
        ],
        'EGP' => [
            'EGP',
            'اِجِپٹِیَن پَوُنڑ',
        ],
        'ERN' => [
            'ERN',
            'رِٹریٖن نَفکا',
        ],
        'ESP' => [
            'ESP',
            'سِپینِش پیسِٹا',
        ],
        'ETB' => [
            'ETB',
            'اِتھوپِیَن بِر',
        ],
        'EUR' => [
            '€',
            'یوٗرو',
        ],
        'FIM' => [
            'FIM',
            'فِنِش مارکا',
        ],
        'FJD' => [
            'FJD',
            'فِجین ڈالر',
        ],
        'FKP' => [
            'FKP',
            'فیکلینڑِس آیلینڑ پونڑ',
        ],
        'FRF' => [
            'FRF',
            'فرانسِسی فریک',
        ],
        'GBP' => [
            '£',
            'برطٲنوی پوٗنڈ',
        ],
        'GEK' => [
            'GEK',
            'جارجِیَن کیوٗپَن لَرِٹ',
        ],
        'GEL' => [
            'GEL',
            'جارجِیَن لاری',
        ],
        'GHC' => [
            'GHC',
            'گَنییَن سؠڑی(۱۹۷۹–۲٠٠۷)',
        ],
        'GHS' => [
            'GHS',
            'گَنییَن سؠڑی',
        ],
        'GIP' => [
            'GIP',
            'گِبریلٹَر پَاونڑ',
        ],
        'GMD' => [
            'GMD',
            'گیمبِیاہُک دلاسی',
        ],
        'GNF' => [
            'GNF',
            'گِنِیَن فرینک',
        ],
        'GNS' => [
            'GNS',
            'گِنِیَن سِلی',
        ],
        'GQE' => [
            'GQE',
            'اِکویٹورِیَل گِنِیَن اؠکویٖل',
        ],
        'GRD' => [
            'GRD',
            'گریٖسُک ڑرؠکما',
        ],
        'GTQ' => [
            'GTQ',
            'گواٹَمالَن قیوٗٹزَل',
        ],
        'GWE' => [
            'GWE',
            'پورتگیٖزُک گِنی اؠسکیوٗڑو',
        ],
        'GWP' => [
            'GWP',
            'گِنی بِساوُک پؠسو',
        ],
        'GYD' => [
            'GYD',
            'گَیَنیٖزُک ڑالَر',
        ],
        'HKD' => [
            'HK$',
            'حانگ کانگُک ڑالَر',
        ],
        'HNL' => [
            'HNL',
            'حونڑورنُک لؠمپیٖرا',
        ],
        'HRD' => [
            'HRD',
            'کروایشنُک دیٖنار',
        ],
        'HRK' => [
            'HRK',
            'کروایشنُک کوٗنا',
        ],
        'HTG' => [
            'HTG',
            'حیشَنُک گوڑ',
        ],
        'HUF' => [
            'HUF',
            'حَنگیرِیَن فورِنٹ',
        ],
        'IDR' => [
            'IDR',
            'اِنڑونیشیاہُک رُپِیاہ',
        ],
        'IEP' => [
            'IEP',
            'اَیرلینڑُک پاونڑ',
        ],
        'ILP' => [
            'ILP',
            'اِزرٲیِلی پاونڑ',
        ],
        'ILS' => [
            '₪',
            'اِزرٲیِلی نٔوؠ شؠقٕل',
        ],
        'INR' => [
            '₹',
            'ہِندُستٲنؠ رۄپَے',
        ],
        'IQD' => [
            'IQD',
            'ایٖراقُک دیٖنار',
        ],
        'IRR' => [
            'IRR',
            'ایٖرانُک رِیال',
        ],
        'ISK' => [
            'ISK',
            'اَیسلینڑُک کرونا',
        ],
        'ITL' => [
            'ITL',
            'اِٹلیٖ یُک لیٖرا',
        ],
        'JMD' => [
            'JMD',
            'جَمَیکاہُک ڑالَر',
        ],
        'JOD' => [
            'JOD',
            'جَرڑینیاہُک دیٖنار',
        ],
        'JPY' => [
            '¥',
            'جاپانُک یَن',
        ],
        'KES' => [
            'KES',
            'کؠنیَن شِلِنگ',
        ],
        'KGS' => [
            'KGS',
            'کِرگِستانُک سوم',
        ],
        'KHR' => [
            'KHR',
            'کَمبوڑِیاہُک رِیال',
        ],
        'KMF' => [
            'KMF',
            'کومورِیَن فرینک',
        ],
        'KPW' => [
            'KPW',
            'جنوٗبی کورِیَن وَن',
        ],
        'KRW' => [
            '₩',
            'ساوتھ کورِیَن وَن',
        ],
        'KWD' => [
            'KWD',
            'قُویتُک دیٖنار',
        ],
        'KYD' => [
            'KYD',
            'کیمین ججیٖرُک ڑالَر',
        ],
        'KZT' => [
            'KZT',
            'کزاکِستان ٹینج',
        ],
        'LAK' => [
            'LAK',
            'لَوٹِیَن کِپ',
        ],
        'LBP' => [
            'LBP',
            'لیبنیٖزُک پاونڑ',
        ],
        'LKR' => [
            'LKR',
            'سری لَنکاہٕچ رۄپَے',
        ],
        'LRD' => [
            'LRD',
            'لَیبیرِیَن ڑالَر',
        ],
        'LSL' => [
            'LSL',
            'لِسوتھو لوٹی',
        ],
        'LTL' => [
            'LTL',
            'لِتھوینِیَن لِٹاس',
        ],
        'LTT' => [
            'LTT',
            'لِتھوینِیَن ٹؠلوناس',
        ],
        'LUC' => [
            'LUC',
            'لَکزٕمبورگِیَن کَنؤرٹِبٕل فرینک',
        ],
        'LUF' => [
            'LUF',
            'لَکزٕمبورگِیَن فرینک',
        ],
        'LUL' => [
            'LUL',
            'لَکزٕمبوگ فَینانشَل فرینک',
        ],
        'LVL' => [
            'LVL',
            'لَتوِیَن لیٹس',
        ],
        'LVR' => [
            'LVR',
            'لَتوِیَن رَبٕل',
        ],
        'LYD' => [
            'LYD',
            'لِبیَن دیٖنار',
        ],
        'MAD' => [
            'MAD',
            'موروکَن دِرہَم',
        ],
        'MAF' => [
            'MAF',
            'موروکَن فرینک',
        ],
        'MDL' => [
            'MDL',
            'مولڑووین لیوٗ',
        ],
        'MGA' => [
            'MGA',
            'مؠلؠگیسی اؠریَری',
        ],
        'MGF' => [
            'MGF',
            'مؠلؠگیسی فرینک',
        ],
        'MKD' => [
            'MKD',
            'مؠکَڑونِیَن دیٖنار',
        ],
        'MLF' => [
            'MLF',
            'میلِیَن فرینک',
        ],
        'MMK' => [
            'MMK',
            'مِیانما کیاٹ',
        ],
        'MNT' => [
            'MNT',
            'مۄنگولِیَن ٹُگرِک',
        ],
        'MOP' => [
            'MOP',
            'مؠکانیٖز پَٹاکا',
        ],
        'MRO' => [
            'MRO',
            'مورِٹینِیَن عوگیوٗیا (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'مورِٹینِیَن عوگیوٗیا',
        ],
        'MTL' => [
            'MTL',
            'مالٹیٖزُک لیٖرا',
        ],
        'MTP' => [
            'MTP',
            'مالٹیٖزُک پاونڑ',
        ],
        'MUR' => [
            'MUR',
            'مورؠشِیاہٕچ رۄپَے',
        ],
        'MVR' => [
            'MVR',
            'مالدِیٖوِیَن رُفِیا',
        ],
        'MWK' => [
            'MWK',
            'مؠلیوِیَن کواچا',
        ],
        'MXN' => [
            'MX$',
            'مؠکسِکَن پؠسو',
        ],
        'MXP' => [
            'MXP',
            'مؠکسِکَن سِلوَر پؠسو (۱۸۶۱–۱۹۹۲)',
        ],
        'MYR' => [
            'MYR',
            'مَلیشِیَن رِنگِٹ',
        ],
        'MZE' => [
            'MZE',
            'موزیمبِکَن سکیوٗڑو',
        ],
        'MZM' => [
            'MZM',
            'پرون موزیمبِکَن مؠٹِکَل',
        ],
        'MZN' => [
            'MZN',
            'موزیمبِکَن مؠٹِکَل',
        ],
        'NAD' => [
            'NAD',
            'نامِبِیَن ڑالَر',
        ],
        'NGN' => [
            'NGN',
            'نَیجیرِیَن ڑالَر',
        ],
        'NIC' => [
            'NIC',
            'نِکؠراگُوؠن کورڑوبا',
        ],
        'NIO' => [
            'NIO',
            'نِکؠراگُوؠن کورڑوبا اورو',
        ],
        'NLG' => [
            'NLG',
            'ڈَچ گِلڑَر',
        ],
        'NOK' => [
            'NOK',
            'نوروییِنُک کرون',
        ],
        'NPR' => [
            'NPR',
            'نیپالٕچ رۄپَے',
        ],
        'NZD' => [
            'NZ$',
            'نِوزیٖلینڑُک ڑالَر',
        ],
        'OMR' => [
            'OMR',
            'اومِنی رِیال',
        ],
        'PAB' => [
            'PAB',
            'پانامانِیَن بالبوز',
        ],
        'PEI' => [
            'PEI',
            'پٔریوٗوِیَن اِنٹی',
        ],
        'PEN' => [
            'PEN',
            'پٔریوٗوِیَن سولٕز',
        ],
        'PES' => [
            'PES',
            'پٔریوٗوِیَن سول (۱۸۶۳–۱۹۶۵)',
        ],
        'PGK' => [
            'PGK',
            'نیوٗ پیپُعا گِنِیَن کیٖنا',
        ],
        'PHP' => [
            '₱',
            'پھِلِپایِٔن پؠسو',
        ],
        'PKR' => [
            'PKR',
            'پاکِستٲنؠ رۄپَے',
        ],
        'PLN' => [
            'PLN',
            'پولِش زلوٹی',
        ],
        'PLZ' => [
            'PLZ',
            'پولِش زلوٹی(۱۹۵٠–۱۹۹۵)',
        ],
        'PTE' => [
            'PTE',
            'پورتُگیٖز اؠسکیوٗڑو',
        ],
        'PYG' => [
            'PYG',
            'پؠرؠگیوٗوَیَن گُعارانی',
        ],
        'QAR' => [
            'QAR',
            'قطاری رِیال',
        ],
        'RHD' => [
            'RHD',
            'رھوڑیشِیَن ڑالَر',
        ],
        'ROL' => [
            'ROL',
            'اولڑ رومانِیَن لؠیوٗ',
        ],
        'RON' => [
            'RON',
            'رومانِیَن لؠیوٗ',
        ],
        'RSD' => [
            'RSD',
            'سٔربِیَن دیٖنار',
        ],
        'RUB' => [
            'RUB',
            'روٗسی رَبٕل',
        ],
        'RUR' => [
            'RUR',
            'رٔشیَن رَبٕل(۱۹۹۱–۱۹۹۸)',
        ],
        'RWF' => [
            'RWF',
            'روانڑَن فرانک',
        ],
        'SAR' => [
            'SAR',
            'سودیٖیُک رِیال',
        ],
        'SBD' => [
            'SBD',
            'سولَمَن جٔزیٖرُک ڈالَر',
        ],
        'SDD' => [
            'SDD',
            'پرون سوٗڈانُک دیٖنار',
        ],
        'SDG' => [
            'SDG',
            'سوٗڈانُک پونڈ',
        ],
        'SDP' => [
            'SDP',
            'پرون سوٗڈانُک پونڈ',
        ],
        'SEK' => [
            'SEK',
            'سویٖڈِش کَرونا',
        ],
        'SGD' => [
            'SGD',
            'سِنگاپورُک ڈالَر',
        ],
        'SHP' => [
            'SHP',
            'سینٹ ہیلِنا پونڈ',
        ],
        'SIT' => [
            'SIT',
            'سلووینُک ٹولَر',
        ],
        'SKK' => [
            'SKK',
            'سلووَک کَرونا',
        ],
        'SOS' => [
            'SOS',
            'سومالی شِلِنگ',
        ],
        'SRD' => [
            'SRD',
            'سُریٖنامُک ڈالَر',
        ],
        'SRG' => [
            'SRG',
            'سُریٖنام گِلدَر',
        ],
        'SUR' => [
            'SUR',
            'سوویت روبٕل',
        ],
        'SVC' => [
            'SVC',
            'سَلویدَرُک کولَن',
        ],
        'SYP' => [
            'SYP',
            'سیٖریاہُک پونڈ',
        ],
        'SZL' => [
            'SZL',
            'سوازی لِلَنگینی',
        ],
        'THB' => [
            'THB',
            'تھایھک بات',
        ],
        'TJR' => [
            'TJR',
            'تاجکِستانُک رَبٕل',
        ],
        'TJS' => [
            'TJS',
            'تاجِکتانُک سَمونی',
        ],
        'TMM' => [
            'TMM',
            'تُکَمَنِستانُک مَنَت',
        ],
        'TND' => [
            'TND',
            'ٹُنیشیاہُک دیٖنار',
        ],
        'TOP' => [
            'TOP',
            'ٹونگَن پانگا',
        ],
        'TPE' => [
            'TPE',
            'ٹیموریسو ایکیٖڈو',
        ],
        'TRL' => [
            'TRL',
            'پرون تُرکِش لیرا',
        ],
        'TRY' => [
            'TRY',
            'تُرکیہُک لیرا',
        ],
        'TTD' => [
            'TTD',
            'ٹرِنہِ ڈیڈ تہٕ ٹوبیگو ڈالَر',
        ],
        'TWD' => [
            'NT$',
            'نۆو تیوانُک ڈالَر',
        ],
        'TZS' => [
            'TZS',
            'تَنزانیاہُک شِلِنگ',
        ],
        'UAH' => [
            'UAH',
            'یوٗکرینیاہُک ہرِوِنیا',
        ],
        'UAK' => [
            'UAK',
            'یوٗکرینیاہُک کاربووَنیٹس',
        ],
        'UGS' => [
            'UGS',
            'اُگاداہُک شِلِنگ(۱۹۶۶–۱۹۸۷)',
        ],
        'UGX' => [
            'UGX',
            'اُگاداہُک شِلِنگ',
        ],
        'USD' => [
            '$',
            'US ڈالر',
        ],
        'USN' => [
            'USN',
            'یوٗ ایس ڈالَر(پَگاہ)',
        ],
        'USS' => [
            'USS',
            'یوٗ ایس ڈالَر(تَمی دًۄہ)',
        ],
        'UYI' => [
            'UYI',
            'اُرگایَن پیسو یوٗنِڈیڈَس اِنڈیکسَس',
        ],
        'UYP' => [
            'UYP',
            'اُرگایَن پیسو(۱۹۷۵–۱۹۹۳)',
        ],
        'UYU' => [
            'UYU',
            'اُروٗگایَن پیسو',
        ],
        'UZS' => [
            'UZS',
            'اُبیکِستان سوم',
        ],
        'VEB' => [
            'VEB',
            'وینٕزوٗلیُک بولِوَر (۱۸۷۱–۲۰۰۸)',
        ],
        'VEF' => [
            'VEF',
            'وینٕزوٗلیُک بولِوَر (2008–2018)',
        ],
        'VES' => [
            'VES',
            'وینٕزوٗلیُک بولِوَر',
        ],
        'VND' => [
            '₫',
            'وِیَنَمُک ڈانگ',
        ],
        'VUV' => [
            'VUV',
            'وَنوٗاَتوٗ وَتوٗ',
        ],
        'WST' => [
            'WST',
            'سَمون تَلا',
        ],
        'XAF' => [
            'FCFA',
            'سی ایف اے فرینک بی ایٖ اے سی',
        ],
        'XCD' => [
            'EC$',
            'مَشرِقی کیرِبِیَن ڈالَر',
        ],
        'XEU' => [
            'XEU',
            'یوٗرپی کَرَنسی یوٗنِٹ',
        ],
        'XFO' => [
            'XFO',
            'فرینچ گولڈ فرینک',
        ],
        'XFU' => [
            'XFU',
            'فرینچ یوٗ اے سی فرینک',
        ],
        'XOF' => [
            'F CFA',
            'سی ایف اے فرینک بی سی ایٖ اے او',
        ],
        'XPF' => [
            'CFPF',
            'سی ایف پی فرینک',
        ],
        'XRE' => [
            'XRE',
            'آر آے این ایٖ ٹی فَنڈ',
        ],
        'YDD' => [
            'YDD',
            'یَمنُک دیٖنار',
        ],
        'YER' => [
            'YER',
            'یَمنُک رِیال',
        ],
        'YUD' => [
            'YUD',
            'یوگوسلاوِیَن ہاڑ دیٖنار',
        ],
        'YUM' => [
            'YUM',
            'یوگوسلاوِیَن نووِے دیٖنار',
        ],
        'YUN' => [
            'YUN',
            'یوگوسلاوِیَن کَنؤٹِبٕل دیٖنار',
        ],
        'ZAR' => [
            'ZAR',
            'ساوُتھ افریٖکاہُک رینڈ',
        ],
        'ZMK' => [
            'ZMK',
            'زِمبابیُک کواچا (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'زِمبابیُک کواچا',
        ],
        'ZRN' => [
            'ZRN',
            'زایرِیَن نِو زایِر',
        ],
        'ZRZ' => [
            'ZRZ',
            'زَیرُک ڈالَر',
        ],
        'ZWD' => [
            'ZWD',
            'زِمبابِیُک ڈالَر',
        ],
    ],
];
