<?php

return [
    'Names' => [
        'aa' => 'afár',
        'ab' => 'abkasíska',
        'ace' => 'akkíska',
        'ach' => 'acoli',
        'ada' => 'adangme',
        'ady' => 'adýge',
        'ae' => 'avestíska',
        'af' => 'afríkanska',
        'afh' => 'afríhílí',
        'agq' => 'aghem',
        'ain' => 'aínu (Japan)',
        'ak' => 'akan',
        'akk' => 'akkadíska',
        'ale' => 'aleúska',
        'alt' => 'suðuraltaíska',
        'am' => 'amharíska',
        'an' => 'aragonska',
        'ang' => 'fornenska',
        'ann' => 'obolo',
        'anp' => 'angíka',
        'ar' => 'arabíska',
        'arc' => 'arameíska',
        'arn' => 'mapuche',
        'arp' => 'arapahó',
        'ars' => 'najdi-arabíska',
        'arw' => 'aravakska',
        'as' => 'assamska',
        'asa' => 'asu',
        'ast' => 'astúríska',
        'atj' => 'atikamekw',
        'av' => 'avaríska',
        'awa' => 'avadí',
        'ay' => 'aímara',
        'az' => 'aserska',
        'ba' => 'baskír',
        'bal' => 'balúkí',
        'ban' => 'balíska',
        'bas' => 'basa',
        'bax' => 'bamun',
        'be' => 'hvítrússneska',
        'bej' => 'beja',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'búlgarska',
        'bgc' => 'haryanví',
        'bgn' => 'vesturbalotsí',
        'bho' => 'bojpúrí',
        'bi' => 'bíslama',
        'bik' => 'bíkol',
        'bin' => 'bíní',
        'bla' => 'siksika',
        'blo' => 'anii',
        'bm' => 'bambara',
        'bn' => 'bengalska',
        'bo' => 'tíbeska',
        'br' => 'bretónska',
        'bra' => 'braí',
        'brx' => 'bódó',
        'bs' => 'bosníska',
        'bss' => 'bakossi',
        'bua' => 'búríat',
        'bug' => 'búgíska',
        'byn' => 'blín',
        'ca' => 'katalónska',
        'cad' => 'kaddó',
        'car' => 'karíbamál',
        'cay' => 'kajúga',
        'cch' => 'atsam',
        'ccp' => 'tsjakma',
        'ce' => 'tsjetsjenska',
        'ceb' => 'kebúanó',
        'cgg' => 'kíga',
        'ch' => 'kamorró',
        'chb' => 'síbsja',
        'chg' => 'sjagataí',
        'chk' => 'sjúkíska',
        'chm' => 'marí',
        'chn' => 'sínúk',
        'cho' => 'sjoktá',
        'chp' => 'sípevíska',
        'chr' => 'Cherokee-mál',
        'chy' => 'sjeyen',
        'ckb' => 'miðkúrdíska',
        'clc' => 'chilcotin',
        'co' => 'korsíska',
        'cop' => 'koptíska',
        'cr' => 'krí',
        'crg' => 'michif',
        'crh' => 'krímtyrkneska',
        'crj' => 'suðaustur-cree',
        'crk' => 'nehiyawak',
        'crl' => 'norðaustur-cree',
        'crm' => 'moose cree',
        'crr' => 'Karólínu-algonkvínska',
        'crs' => 'seychelles-kreólska',
        'cs' => 'tékkneska',
        'csb' => 'kasúbíska',
        'csw' => 'maskekon',
        'cu' => 'kirkjuslavneska',
        'cv' => 'sjúvas',
        'cy' => 'velska',
        'da' => 'danska',
        'dak' => 'dakóta',
        'dar' => 'dargva',
        'dav' => 'taíta',
        'de' => 'þýska',
        'del' => 'delaver',
        'den' => 'slavneska',
        'dgr' => 'dogríb',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'dogrí',
        'dsb' => 'lágsorbneska',
        'dua' => 'dúala',
        'dum' => 'miðhollenska',
        'dv' => 'dívehí',
        'dyo' => 'jola-fonyi',
        'dyu' => 'djúla',
        'dz' => 'dsongka',
        'dzg' => 'dazaga',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efík',
        'egy' => 'fornegypska',
        'eka' => 'ekajúk',
        'el' => 'gríska',
        'elx' => 'elamít',
        'en' => 'enska',
        'enm' => 'miðenska',
        'eo' => 'esperantó',
        'es' => 'spænska',
        'et' => 'eistneska',
        'eu' => 'baskneska',
        'ewo' => 'evondó',
        'fa' => 'persneska',
        'fan' => 'fang',
        'fat' => 'fantí',
        'ff' => 'fúla',
        'fi' => 'finnska',
        'fil' => 'filippseyska',
        'fj' => 'fídjeyska',
        'fo' => 'færeyska',
        'fon' => 'fón',
        'fr' => 'franska',
        'frc' => 'cajun-franska',
        'frm' => 'miðfranska',
        'fro' => 'fornfranska',
        'frr' => 'norðurfrísneska',
        'frs' => 'austurfrísneska',
        'fur' => 'fríúlska',
        'fy' => 'vesturfrísneska',
        'ga' => 'írska',
        'gaa' => 'ga',
        'gag' => 'gagás',
        'gan' => 'gan',
        'gay' => 'gajó',
        'gba' => 'gbaja',
        'gd' => 'skosk gelíska',
        'gez' => 'gís',
        'gil' => 'gilberska',
        'gl' => 'galisíska',
        'gmh' => 'miðháþýska',
        'gn' => 'gvaraní',
        'goh' => 'fornháþýska',
        'gon' => 'gondí',
        'gor' => 'gorontaló',
        'got' => 'gotneska',
        'grb' => 'gerbó',
        'grc' => 'forngríska',
        'gsw' => 'svissnesk þýska',
        'gu' => 'gújaratí',
        'guz' => 'gusii',
        'gv' => 'manska',
        'gwi' => 'gvísín',
        'ha' => 'hása',
        'hai' => 'haída',
        'haw' => 'havaíska',
        'hax' => 'suður-haída',
        'he' => 'hebreska',
        'hi' => 'hindí',
        'hil' => 'híligaínon',
        'hit' => 'hettitíska',
        'hmn' => 'hmong',
        'ho' => 'hírímótú',
        'hr' => 'króatíska',
        'hsb' => 'hásorbneska',
        'ht' => 'haítíska',
        'hu' => 'ungverska',
        'hup' => 'húpa',
        'hur' => 'halkomelem',
        'hy' => 'armenska',
        'hz' => 'hereró',
        'ia' => 'interlingua',
        'iba' => 'íban',
        'ibb' => 'ibibio',
        'id' => 'indónesíska',
        'ie' => 'interlingve',
        'ig' => 'ígbó',
        'ii' => 'sísúanjí',
        'ik' => 'ínúpíak',
        'ikt' => 'vestur-kanadískt inúktitút',
        'ilo' => 'ílokó',
        'inh' => 'ingús',
        'io' => 'ídó',
        'is' => 'íslenska',
        'it' => 'ítalska',
        'iu' => 'inúktitút',
        'ja' => 'japanska',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'masjáme',
        'jpr' => 'gyðingapersneska',
        'jrb' => 'gyðingaarabíska',
        'jv' => 'javanska',
        'ka' => 'georgíska',
        'kaa' => 'karakalpak',
        'kab' => 'kabíle',
        'kac' => 'kasín',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kaví',
        'kbd' => 'kabardíska',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'grænhöfðeyska',
        'kfo' => 'koro',
        'kg' => 'kongóska',
        'kgp' => 'kaingang',
        'kha' => 'kasí',
        'kho' => 'kotaska',
        'khq' => 'koyra chiini',
        'ki' => 'kíkújú',
        'kj' => 'kúanjama',
        'kk' => 'kasakska',
        'kkj' => 'kako',
        'kl' => 'grænlenska',
        'kln' => 'kalenjin',
        'km' => 'kmer',
        'kmb' => 'kimbúndú',
        'kn' => 'kannada',
        'ko' => 'kóreska',
        'koi' => 'kómí-permyak',
        'kok' => 'konkaní',
        'kos' => 'kosraska',
        'kpe' => 'kpelle',
        'kr' => 'kanúrí',
        'krc' => 'karasaíbalkar',
        'krl' => 'karélska',
        'kru' => 'kúrúk',
        'ks' => 'kasmírska',
        'ksb' => 'sjambala',
        'ksf' => 'bafía',
        'ksh' => 'kölníska',
        'ku' => 'kúrdíska',
        'kum' => 'kúmík',
        'kut' => 'kútenaí',
        'kv' => 'komíska',
        'kw' => 'kornbreska',
        'kwk' => 'kwakʼwala',
        'kxv' => 'kúví',
        'ky' => 'kirgiska',
        'la' => 'latína',
        'lad' => 'ladínska',
        'lag' => 'langí',
        'lah' => 'landa',
        'lam' => 'lamba',
        'lb' => 'lúxemborgíska',
        'lez' => 'lesgíska',
        'lg' => 'ganda',
        'li' => 'limbúrgíska',
        'lij' => 'lígúríska',
        'lil' => 'lillooet',
        'lkt' => 'lakóta',
        'lmo' => 'lombardíska',
        'ln' => 'lingala',
        'lo' => 'laó',
        'lol' => 'mongó',
        'lou' => 'kreólska (Louisiana)',
        'loz' => 'lozi',
        'lrc' => 'norðurlúrí',
        'lsm' => 'saamia',
        'lt' => 'litháíska',
        'lu' => 'lúbakatanga',
        'lua' => 'luba-lulua',
        'lui' => 'lúisenó',
        'lun' => 'lúnda',
        'luo' => 'lúó',
        'lus' => 'lúsaí',
        'luy' => 'luyia',
        'lv' => 'lettneska',
        'mad' => 'madúrska',
        'mag' => 'magahí',
        'mai' => 'maítílí',
        'mak' => 'makasar',
        'man' => 'mandingó',
        'mas' => 'masaí',
        'mdf' => 'moksa',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'merú',
        'mfe' => 'máritíska',
        'mg' => 'malagasíska',
        'mga' => 'miðírska',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mh' => 'marshallska',
        'mi' => 'maorí',
        'mic' => 'mikmak',
        'min' => 'mínangkabá',
        'mk' => 'makedónska',
        'ml' => 'malajalam',
        'mn' => 'mongólska',
        'mnc' => 'mansjú',
        'mni' => 'manípúrí',
        'moe' => 'innu-aimun',
        'moh' => 'móhíska',
        'mos' => 'mossí',
        'mr' => 'maratí',
        'ms' => 'malaíska',
        'mt' => 'maltneska',
        'mua' => 'mundang',
        'mus' => 'krík',
        'mwl' => 'mirandesíska',
        'mwr' => 'marvarí',
        'my' => 'búrmneska',
        'myv' => 'ersja',
        'mzn' => 'masanderaní',
        'na' => 'nárúska',
        'nap' => 'napólíska',
        'naq' => 'nama',
        'nb' => 'norskt bókmál',
        'nd' => 'norður-ndebele',
        'nds' => 'lágþýska; lágsaxneska',
        'ne' => 'nepalska',
        'new' => 'nevarí',
        'ng' => 'ndonga',
        'nia' => 'nías',
        'niu' => 'níveska',
        'nl' => 'hollenska',
        'nmg' => 'kwasio',
        'nn' => 'nýnorska',
        'nnh' => 'ngiemboon',
        'no' => 'norska',
        'nog' => 'nógaí',
        'non' => 'norræna',
        'nqo' => 'n’ko',
        'nr' => 'suðurndebele',
        'nso' => 'norðursótó',
        'nus' => 'núer',
        'nv' => 'navahó',
        'nwc' => 'klassísk nevaríska',
        'ny' => 'nýanja',
        'nym' => 'njamvesí',
        'nyn' => 'nyankole',
        'nyo' => 'njóró',
        'nzi' => 'nsíma',
        'oc' => 'oksítaníska',
        'oj' => 'ojibva',
        'ojb' => 'norðvestur-ojibwa',
        'ojc' => 'ojibwa',
        'ojs' => 'oji-cree',
        'ojw' => 'vestur-ojibwa',
        'oka' => 'okanagan',
        'om' => 'oromo',
        'or' => 'óría',
        'os' => 'ossetíska',
        'osa' => 'ósage',
        'ota' => 'tyrkneska, ottóman',
        'pa' => 'púnjabí',
        'pag' => 'pangasínmál',
        'pal' => 'palaví',
        'pam' => 'pampanga',
        'pap' => 'papíamentó',
        'pau' => 'paláska',
        'pcm' => 'nígerískt pidgin',
        'peo' => 'fornpersneska',
        'phn' => 'fönikíska',
        'pi' => 'palí',
        'pis' => 'pijin',
        'pl' => 'pólska',
        'pon' => 'ponpeiska',
        'pqm' => 'maliseet-passamaquoddy',
        'prg' => 'prússneska',
        'pro' => 'fornpróvensalska',
        'ps' => 'pastú',
        'pt' => 'portúgalska',
        'qu' => 'kvesjúa',
        'quc' => 'kiche',
        'raj' => 'rajastaní',
        'rap' => 'rapanúí',
        'rar' => 'rarótongska',
        'rhg' => 'rohingja',
        'rm' => 'rómanska',
        'rn' => 'rúndí',
        'ro' => 'rúmenska',
        'rof' => 'rombó',
        'rom' => 'romaní',
        'ru' => 'rússneska',
        'rup' => 'arúmenska',
        'rw' => 'kínjarvanda',
        'rwk' => 'rúa',
        'sa' => 'sanskrít',
        'sad' => 'sandave',
        'sah' => 'jakút',
        'sam' => 'samversk arameíska',
        'saq' => 'sambúrú',
        'sas' => 'sasak',
        'sat' => 'santalí',
        'sba' => 'ngambay',
        'sbp' => 'sangú',
        'sc' => 'sardínska',
        'scn' => 'sikileyska',
        'sco' => 'skoska',
        'sd' => 'sindí',
        'sdh' => 'suðurkúrdíska',
        'se' => 'norðursamíska',
        'seh' => 'sena',
        'sel' => 'selkúp',
        'ses' => 'koíraboró-senní',
        'sg' => 'sangó',
        'sga' => 'fornírska',
        'sh' => 'serbókróatíska',
        'shi' => 'tachelhit',
        'shn' => 'sjan',
        'si' => 'singalíska',
        'sid' => 'sídamó',
        'sk' => 'slóvakíska',
        'sl' => 'slóvenska',
        'slh' => 'suður-lushootseed',
        'sm' => 'samóska',
        'sma' => 'suðursamíska',
        'smj' => 'lúlesamíska',
        'smn' => 'enaresamíska',
        'sms' => 'skoltesamíska',
        'sn' => 'shona',
        'snk' => 'sóninke',
        'so' => 'sómalska',
        'sog' => 'sogdíen',
        'sq' => 'albanska',
        'sr' => 'serbneska',
        'srn' => 'sranan tongo',
        'srr' => 'serer',
        'ss' => 'svatí',
        'ssy' => 'saho',
        'st' => 'suðursótó',
        'str' => 'Straits-salisíanska',
        'su' => 'súndanska',
        'suk' => 'súkúma',
        'sus' => 'súsú',
        'sux' => 'súmerska',
        'sv' => 'sænska',
        'sw' => 'svahílí',
        'swb' => 'shimaoríska',
        'syc' => 'klassísk sýrlenska',
        'syr' => 'sýrlenska',
        'szl' => 'slesíska',
        'ta' => 'tamílska',
        'tce' => 'suður-tutchone',
        'te' => 'telúgú',
        'tem' => 'tímne',
        'teo' => 'tesó',
        'ter' => 'terenó',
        'tet' => 'tetúm',
        'tg' => 'tadsjikska',
        'tgx' => 'tagíska',
        'th' => 'taílenska',
        'tht' => 'tahltan',
        'ti' => 'tígrinja',
        'tig' => 'tígre',
        'tiv' => 'tív',
        'tk' => 'túrkmenska',
        'tkl' => 'tókeláska',
        'tl' => 'tagalog',
        'tlh' => 'klingonska',
        'tli' => 'tlingit',
        'tmh' => 'tamasjek',
        'tn' => 'tsúana',
        'to' => 'tongverska',
        'tog' => 'tongverska (nyasa)',
        'tok' => 'toki pona',
        'tpi' => 'tokpisin',
        'tr' => 'tyrkneska',
        'trv' => 'tarókó',
        'ts' => 'tsonga',
        'tsi' => 'tsimsíska',
        'tt' => 'tatarska',
        'ttm' => 'norður-tutchone',
        'tum' => 'túmbúka',
        'tvl' => 'túvalúska',
        'tw' => 'tví',
        'twq' => 'tasawaq',
        'ty' => 'tahítíska',
        'tyv' => 'túvínska',
        'tzm' => 'tamazight',
        'udm' => 'údmúrt',
        'ug' => 'úígúr',
        'uga' => 'úgarítíska',
        'uk' => 'úkraínska',
        'umb' => 'úmbúndú',
        'ur' => 'úrdú',
        'uz' => 'úsbekska',
        'vai' => 'vaí',
        've' => 'venda',
        'vec' => 'feneyska',
        'vi' => 'víetnamska',
        'vmw' => 'makúva',
        'vo' => 'volapyk',
        'vot' => 'votíska',
        'vun' => 'vunjó',
        'wa' => 'vallónska',
        'wae' => 'valser',
        'wal' => 'volayatta',
        'war' => 'varaí',
        'was' => 'vasjó',
        'wbp' => 'varlpiri',
        'wo' => 'volof',
        'wuu' => 'wu-kínverska',
        'xal' => 'kalmúkska',
        'xh' => 'sósa',
        'xnr' => 'kangrí',
        'xog' => 'sóga',
        'yao' => 'jaó',
        'yap' => 'japíska',
        'yav' => 'yangben',
        'ybb' => 'yemba',
        'yi' => 'jiddíska',
        'yo' => 'jórúba',
        'yrl' => 'nheengatu',
        'yue' => 'kantónska',
        'za' => 'súang',
        'zap' => 'sapótek',
        'zbl' => 'blisstákn',
        'zen' => 'senaga',
        'zgh' => 'staðlað marokkóskt tamazight',
        'zh' => 'kínverska',
        'zu' => 'súlú',
        'zun' => 'súní',
        'zza' => 'zázáíska',
    ],
    'LocalizedNames' => [
        'ar_001' => 'stöðluð nútímaarabíska',
        'de_AT' => 'austurrísk þýska',
        'de_CH' => 'svissnesk háþýska',
        'en_AU' => 'áströlsk enska',
        'en_CA' => 'kanadísk enska',
        'en_GB' => 'bresk enska',
        'en_US' => 'bandarísk enska',
        'es_419' => 'rómönsk-amerísk spænska',
        'es_ES' => 'evrópsk spænska',
        'es_MX' => 'mexíkósk spænska',
        'fa_AF' => 'darí',
        'fr_CA' => 'kanadísk franska',
        'fr_CH' => 'svissnesk franska',
        'nds_NL' => 'lágsaxneska',
        'nl_BE' => 'flæmska',
        'pt_BR' => 'brasílísk portúgalska',
        'pt_PT' => 'evrópsk portúgalska',
        'ro_MD' => 'moldóvska',
        'sw_CD' => 'kongósvahílí',
        'zh_Hans' => 'kínverska (einfölduð)',
        'zh_Hant' => 'kínverska (hefðbundin)',
    ],
];
