<?php

return [
    'Names' => [
        'Ethi' => '埃塞俄比亞文',
        'Geor' => '格魯吉亞文',
        'Guru' => '古木基文',
        'Hans' => '簡體字',
        'Hant' => '繁體字',
        'Knda' => '坎納達文',
        'Laoo' => '老撾文',
        'Mlym' => '馬拉雅拉姆文',
        'Newa' => '尼瓦爾文',
        'Orya' => '奧里雅文',
        'Sinh' => '僧伽羅文',
        'Taml' => '泰米爾文',
        'Thaa' => '它拿字母',
    ],
];
