<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'وقت گرینویچ (آبیجان)',
        'Africa/Accra' => 'وقت گرینویچ (اکرا)',
        'Africa/Addis_Ababa' => 'وقت شرق افریقا (آدیس آبابا)',
        'Africa/Algiers' => 'وقت مرکز اروپا (الجزیره)',
        'Africa/Asmera' => 'وقت شرق افریقا (اسمره)',
        'Africa/Asmara' => 'وقت شرق افریقا (اسمره)',
        'Africa/Bamako' => 'وقت گرینویچ (باماکو)',
        'Africa/Bangui' => 'وقت غرب افریقا (بانگی)',
        'Africa/Banjul' => 'وقت گرینویچ (بانجول)',
        'Africa/Bissau' => 'وقت گرینویچ (بیسائو)',
        'Africa/Blantyre' => 'وقت مرکز آفریقا (بلانتیره)',
        'Africa/Brazzaville' => 'وقت غرب افریقا (برازویل)',
        'Africa/Bujumbura' => 'وقت مرکز آفریقا (بوجومبورا)',
        'Africa/Cairo' => 'وقت شرق اروپا (قاهره)',
        'Africa/Casablanca' => 'وقت غرب اروپا (کازابلانکا)',
        'Africa/Ceuta' => 'وقت مرکز اروپا (سبته)',
        'Africa/Conakry' => 'وقت گرینویچ (کوناکری)',
        'Africa/Dakar' => 'وقت گرینویچ (داکار)',
        'Africa/Dar_es_Salaam' => 'وقت شرق افریقا (دارالسلام)',
        'Africa/Djibouti' => 'وقت شرق افریقا (جیبوتی)',
        'Africa/Douala' => 'وقت غرب افریقا (دوآلا)',
        'Africa/El_Aaiun' => 'وقت غرب اروپا (العیون)',
        'Africa/Freetown' => 'وقت گرینویچ (فری‌تاون)',
        'Africa/Gaborone' => 'وقت مرکز آفریقا (گابورون)',
        'Africa/Harare' => 'وقت مرکز آفریقا (هراره)',
        'Africa/Johannesburg' => 'وقت عادی جنوب افریقا (ژوهانسبورگ)',
        'Africa/Juba' => 'وقت مرکز آفریقا (جوبا)',
        'Africa/Kampala' => 'وقت شرق افریقا (کامپالا)',
        'Africa/Khartoum' => 'وقت مرکز آفریقا (خارطوم)',
        'Africa/Kigali' => 'وقت مرکز آفریقا (کیگالی)',
        'Africa/Kinshasa' => 'وقت غرب افریقا (کینشاسا)',
        'Africa/Lagos' => 'وقت غرب افریقا (لاگوس)',
        'Africa/Libreville' => 'وقت غرب افریقا (لیبرویل)',
        'Africa/Lome' => 'وقت گرینویچ (لومه)',
        'Africa/Luanda' => 'وقت غرب افریقا (لواندا)',
        'Africa/Lubumbashi' => 'وقت مرکز آفریقا (لوبومباشی)',
        'Africa/Lusaka' => 'وقت مرکز آفریقا (لوزاکا)',
        'Africa/Malabo' => 'وقت غرب افریقا (مالابو)',
        'Africa/Maputo' => 'وقت مرکز آفریقا (ماپوتو)',
        'Africa/Maseru' => 'وقت عادی جنوب افریقا (ماسرو)',
        'Africa/Mbabane' => 'وقت عادی جنوب افریقا (مبابانه)',
        'Africa/Mogadishu' => 'وقت شرق افریقا (موگادیشو)',
        'Africa/Monrovia' => 'وقت گرینویچ (مونروویا)',
        'Africa/Nairobi' => 'وقت شرق افریقا (نایروبی)',
        'Africa/Ndjamena' => 'وقت غرب افریقا (انجامنا)',
        'Africa/Niamey' => 'وقت غرب افریقا (نیامی)',
        'Africa/Nouakchott' => 'وقت گرینویچ (نوآکشوت)',
        'Africa/Ouagadougou' => 'وقت گرینویچ (اوآگادوگو)',
        'Africa/Porto-Novo' => 'وقت غرب افریقا (پورتو نووو)',
        'Africa/Sao_Tome' => 'وقت گرینویچ (سائوتومه)',
        'Africa/Tripoli' => 'وقت شرق اروپا (طرابلس)',
        'Africa/Tunis' => 'وقت مرکز اروپا (تونس)',
        'Africa/Windhoek' => 'وقت مرکز آفریقا (ویندهوک)',
        'America/Adak' => 'وقت هاوایی‐الوشن (ایدک)',
        'America/Anchorage' => 'وقت آلاسکا (انکوریج)',
        'America/Anguilla' => 'وقت آتلانتیک (آنگوئیلا)',
        'America/Antigua' => 'وقت آتلانتیک (آنتیگوا)',
        'America/Araguaina' => 'وقت برازیلیا (آراگواینا)',
        'America/Argentina/La_Rioja' => 'وقت آرژانتین (لاریوخا)',
        'America/Argentina/Rio_Gallegos' => 'وقت آرژانتین (ریوگالگوس)',
        'America/Argentina/Salta' => 'وقت آرژانتین (سالتا)',
        'America/Argentina/San_Juan' => 'وقت آرژانتین (سن‌خوان)',
        'America/Argentina/San_Luis' => 'وقت آرژانتین (سن‌لوئیس)',
        'America/Argentina/Tucuman' => 'وقت آرژانتین (توکومن)',
        'America/Argentina/Ushuaia' => 'وقت آرژانتین (اوشوایا)',
        'America/Aruba' => 'وقت آتلانتیک (اروبا)',
        'America/Asuncion' => 'وقت پاراگوئه (آسونسیون)',
        'America/Bahia' => 'وقت برازیلیا (بایا)',
        'America/Bahia_Banderas' => 'وقت مرکز امریکا (باهیا باندراس)',
        'America/Barbados' => 'وقت آتلانتیک (باربادوس)',
        'America/Belem' => 'وقت برازیلیا (بلم)',
        'America/Belize' => 'وقت مرکز امریکا (بلیز)',
        'America/Blanc-Sablon' => 'وقت آتلانتیک (بلان‐سابلون)',
        'America/Boa_Vista' => 'وقت آمازون (بوئاویستا)',
        'America/Bogota' => 'وقت کلمبیا (بوگوتا)',
        'America/Boise' => 'وقت کوهستانی امریکا (بویسی)',
        'America/Buenos_Aires' => 'وقت آرژانتین (بوئنوس‌آیرس)',
        'America/Argentina/Buenos_Aires' => 'وقت آرژانتین (بوئنوس‌آیرس)',
        'America/Cambridge_Bay' => 'وقت کوهستانی امریکا (کمبریج‌بی)',
        'America/Campo_Grande' => 'وقت آمازون (کمپو گرانده)',
        'America/Cancun' => 'وقت شرق امریکا (کانکون)',
        'America/Caracas' => 'وقت ونزوئلا (کاراکاس)',
        'America/Catamarca' => 'وقت آرژانتین (کاتامارکا)',
        'America/Argentina/Catamarca' => 'وقت آرژانتین (کاتامارکا)',
        'America/Cayenne' => 'وقت گویان فرانسه (کاین)',
        'America/Cayman' => 'وقت شرق امریکا (کیمن)',
        'America/Chicago' => 'وقت مرکز امریکا (شیکاگو)',
        'America/Chihuahua' => 'وقت مرکز امریکا (چیواوا)',
        'America/Ciudad_Juarez' => 'وقت کوهستانی امریکا (سیوداد خوارز)',
        'America/Coral_Harbour' => 'وقت شرق امریکا (اتکوکان)',
        'America/Atikokan' => 'وقت شرق امریکا (اتکوکان)',
        'America/Cordoba' => 'وقت آرژانتین (کوردووا)',
        'America/Argentina/Cordoba' => 'وقت آرژانتین (کوردووا)',
        'America/Costa_Rica' => 'وقت مرکز امریکا (کاستاریکا)',
        'America/Coyhaique' => 'وقت شیلی (کویهایکیو)',
        'America/Creston' => 'وقت کوهستانی امریکا (کرستون)',
        'America/Cuiaba' => 'وقت آمازون (کویاوا)',
        'America/Curacao' => 'وقت آتلانتیک (کوراسائو)',
        'America/Danmarkshavn' => 'وقت گرینویچ (دانمارکس‌هاون)',
        'America/Dawson' => 'وقت یوکان (داوسن)',
        'America/Dawson_Creek' => 'وقت کوهستانی امریکا (داوسن کریک)',
        'America/Denver' => 'وقت کوهستانی امریکا (دنور)',
        'America/Detroit' => 'وقت شرق امریکا (دیترویت)',
        'America/Dominica' => 'وقت آتلانتیک (دومینیکا)',
        'America/Edmonton' => 'وقت کوهستانی امریکا (ادمونتون)',
        'America/Eirunepe' => 'وقت برزیل (ایرونپه)',
        'America/El_Salvador' => 'وقت مرکز امریکا (السالوادور)',
        'America/Fort_Nelson' => 'وقت کوهستانی امریکا (فورت نلسون)',
        'America/Fortaleza' => 'وقت برازیلیا (فورتالزا)',
        'America/Glace_Bay' => 'وقت آتلانتیک (گلیس‌بی)',
        'America/Godthab' => 'وقت گرینلند (نووک)',
        'America/Nuuk' => 'وقت گرینلند (نووک)',
        'America/Goose_Bay' => 'وقت آتلانتیک (گوس‌بی)',
        'America/Grand_Turk' => 'وقت شرق امریکا (گراند تورک)',
        'America/Grenada' => 'وقت آتلانتیک (گرنادا)',
        'America/Guadeloupe' => 'وقت آتلانتیک (گوادلوپ)',
        'America/Guatemala' => 'وقت مرکز امریکا (گواتمالا)',
        'America/Guayaquil' => 'وقت اکوادور (گوایاکیل)',
        'America/Guyana' => 'وقت گویان',
        'America/Halifax' => 'وقت آتلانتیک (هلیفکس)',
        'America/Havana' => 'وقت کوبا (هاوانا)',
        'America/Hermosillo' => 'وقت شرق مکزیک (ارموسیو)',
        'America/Indiana/Knox' => 'وقت مرکز امریکا (ناکس، ایندیانا)',
        'America/Indiana/Marengo' => 'وقت شرق امریکا (مارنگو، ایندیانا)',
        'America/Indiana/Petersburg' => 'وقت شرق امریکا (پیترزبرگ، ایندیانا)',
        'America/Indiana/Tell_City' => 'وقت مرکز امریکا (تل‌سیتی، ایندیانا)',
        'America/Indiana/Vevay' => 'وقت شرق امریکا (ویوی، ایندیانا)',
        'America/Indiana/Vincennes' => 'وقت شرق امریکا (وینسنس، اندیانا)',
        'America/Indiana/Winamac' => 'وقت شرق امریکا (ویناماک، ایندیانا)',
        'America/Indianapolis' => 'وقت شرق امریکا (ایندیاناپولیس)',
        'America/Indiana/Indianapolis' => 'وقت شرق امریکا (ایندیاناپولیس)',
        'America/Inuvik' => 'وقت کوهستانی امریکا (اینوویک)',
        'America/Iqaluit' => 'وقت شرق امریکا (ایکلوئت)',
        'America/Jamaica' => 'وقت شرق امریکا (جامائیکا)',
        'America/Jujuy' => 'وقت آرژانتین (خوخوی)',
        'America/Argentina/Jujuy' => 'وقت آرژانتین (خوخوی)',
        'America/Juneau' => 'وقت آلاسکا (جونو)',
        'America/Kentucky/Monticello' => 'وقت شرق امریکا (مانتیسلو، کنتاکی)',
        'America/Kralendijk' => 'وقت آتلانتیک (کرالندیک)',
        'America/La_Paz' => 'وقت بولیوی (لاپاز)',
        'America/Lima' => 'وقت پرو (لیما)',
        'America/Los_Angeles' => 'وقت غرب امریکا (لوس‌آنجلس)',
        'America/Louisville' => 'وقت شرق امریکا (لوئیزویل)',
        'America/Kentucky/Louisville' => 'وقت شرق امریکا (لوئیزویل)',
        'America/Lower_Princes' => 'وقت آتلانتیک (بخش شاهزاده‌‌نشین پایین)',
        'America/Maceio' => 'وقت برازیلیا (ماسیو)',
        'America/Managua' => 'وقت مرکز امریکا (ماناگوا)',
        'America/Manaus' => 'وقت آمازون (ماناوس)',
        'America/Marigot' => 'وقت آتلانتیک (ماریگات)',
        'America/Martinique' => 'وقت آتلانتیک (مارتینیک)',
        'America/Matamoros' => 'وقت مرکز امریکا (ماتاموروس)',
        'America/Mazatlan' => 'وقت شرق مکزیک (ماساتلان)',
        'America/Mendoza' => 'وقت آرژانتین (مندوسا)',
        'America/Argentina/Mendoza' => 'وقت آرژانتین (مندوسا)',
        'America/Menominee' => 'وقت مرکز امریکا (منامینی)',
        'America/Merida' => 'وقت مرکز امریکا (مریدا)',
        'America/Metlakatla' => 'وقت آلاسکا (متالاکاتلا)',
        'America/Mexico_City' => 'وقت مرکز امریکا (مکزیکوسیتی)',
        'America/Miquelon' => 'وقت سنت‌پیر و میکلون',
        'America/Moncton' => 'وقت آتلانتیک (مانکتون)',
        'America/Monterrey' => 'وقت مرکز امریکا (مونتری)',
        'America/Montevideo' => 'وقت اروگوئه (مونته‌ویدئو)',
        'America/Montserrat' => 'وقت آتلانتیک (مونتسرات)',
        'America/Nassau' => 'وقت شرق امریکا (ناسائو)',
        'America/New_York' => 'وقت شرق امریکا (نیویورک)',
        'America/Nome' => 'وقت آلاسکا (نوم)',
        'America/Noronha' => 'وقت فرناندو دی نورونیا',
        'America/North_Dakota/Beulah' => 'وقت مرکز امریکا (بیولا، داکوتای شمالی)',
        'America/North_Dakota/Center' => 'وقت مرکز امریکا (سنتر، داکوتای شمالی)',
        'America/North_Dakota/New_Salem' => 'وقت مرکز امریکا (نیوسالم، داکوتای شمالی)',
        'America/Ojinaga' => 'وقت مرکز امریکا (اوجیناگا)',
        'America/Panama' => 'وقت شرق امریکا (پاناما)',
        'America/Paramaribo' => 'وقت سورینام (پاراماریبو)',
        'America/Phoenix' => 'وقت کوهستانی امریکا (فینکس)',
        'America/Port-au-Prince' => 'وقت شرق امریکا (پورتوپرنس)',
        'America/Port_of_Spain' => 'وقت آتلانتیک (پورت‌آواسپین)',
        'America/Porto_Velho' => 'وقت آمازون (پورتوولیو)',
        'America/Puerto_Rico' => 'وقت آتلانتیک (پورتوریکو)',
        'America/Punta_Arenas' => 'وقت شیلی (پونتا آرناس)',
        'America/Rankin_Inlet' => 'وقت مرکز امریکا (خلیجک رنکین)',
        'America/Recife' => 'وقت برازیلیا (ریسیفی)',
        'America/Regina' => 'وقت مرکز امریکا (رجاینا)',
        'America/Resolute' => 'وقت مرکز امریکا (رزولوت)',
        'America/Rio_Branco' => 'وقت برزیل (ریوبرانکو)',
        'America/Santarem' => 'وقت برازیلیا (سنتارم)',
        'America/Santiago' => 'وقت شیلی (سانتیاگو)',
        'America/Santo_Domingo' => 'وقت آتلانتیک (سانتو دومینگو)',
        'America/Sao_Paulo' => 'وقت برازیلیا (سائوپائولو)',
        'America/Scoresbysund' => 'وقت گرینلند (اسکورسبیسوند)',
        'America/Sitka' => 'وقت آلاسکا (سیتکا)',
        'America/St_Barthelemy' => 'وقت آتلانتیک (سنت بارتلمی)',
        'America/St_Johns' => 'وقت نیوفاندلند (سنت جان)',
        'America/St_Kitts' => 'وقت آتلانتیک (سنت کیتس)',
        'America/St_Lucia' => 'وقت آتلانتیک (سنت لوسیا)',
        'America/St_Thomas' => 'وقت آتلانتیک (سنت توماس)',
        'America/St_Vincent' => 'وقت آتلانتیک (سنت وینسنت)',
        'America/Swift_Current' => 'وقت مرکز امریکا (سویفت‌کارنت)',
        'America/Tegucigalpa' => 'وقت مرکز امریکا (تگوسیگالپا)',
        'America/Thule' => 'وقت آتلانتیک (تول)',
        'America/Tijuana' => 'وقت غرب امریکا (تیخوانا)',
        'America/Toronto' => 'وقت شرق امریکا (تورنتو)',
        'America/Tortola' => 'وقت آتلانتیک (تورتولا)',
        'America/Vancouver' => 'وقت غرب امریکا (ونکوور)',
        'America/Whitehorse' => 'وقت یوکان (وایت‌هورس)',
        'America/Winnipeg' => 'وقت مرکز امریکا (وینیپگ)',
        'America/Yakutat' => 'وقت آلاسکا (یاکوتات)',
        'Antarctica/Casey' => 'وقت استرالیای غربی (کیسی)',
        'Antarctica/Davis' => 'وقت دیویس',
        'Antarctica/DumontDUrville' => 'وقت دومون دورویل',
        'Antarctica/Macquarie' => 'وقت استرالیای شرقی (مکواری)',
        'Antarctica/Mawson' => 'وقت ماوسون',
        'Antarctica/McMurdo' => 'وقت نیوزیلند (مک‌موردو)',
        'Antarctica/Palmer' => 'وقت شیلی (پالمر)',
        'Antarctica/Rothera' => 'وقت روترا',
        'Antarctica/Syowa' => 'وقت شووا',
        'Antarctica/Troll' => 'وقت گرینویچ (ترول)',
        'Antarctica/Vostok' => 'وقت وستوک',
        'Arctic/Longyearbyen' => 'وقت مرکز اروپا (لانگ‌یربین)',
        'Asia/Aden' => 'وقت عربستان (عدن)',
        'Asia/Almaty' => 'وقت قزاقستان (آلماتی)',
        'Asia/Amman' => 'وقت شرق اروپا (عَمان)',
        'Asia/Anadyr' => 'وقت پتروپاولوسک‐کامچاتسکی (آنادیر)',
        'Asia/Aqtau' => 'وقت قزاقستان (آقتاو)',
        'Asia/Aqtobe' => 'وقت قزاقستان (آقتوبه)',
        'Asia/Ashgabat' => 'وقت ترکمنستان (عشق‌آباد)',
        'Asia/Atyrau' => 'وقت قزاقستان (آتیراو)',
        'Asia/Baghdad' => 'وقت عربستان (بغداد)',
        'Asia/Bahrain' => 'وقت عربستان (بحرین)',
        'Asia/Baku' => 'وقت جمهوری آذربایجان (باکو)',
        'Asia/Bangkok' => 'وقت هندوچین (بانکوک)',
        'Asia/Barnaul' => 'وقت کراسنویارسک (بارنائول)',
        'Asia/Beirut' => 'وقت شرق اروپا (بیروت)',
        'Asia/Bishkek' => 'وقت قرقیزستان (بیشکک)',
        'Asia/Brunei' => 'وقت برونئی دارالسلام',
        'Asia/Calcutta' => 'وقت هند (کلکته)',
        'Asia/Kolkata' => 'وقت هند (کلکته)',
        'Asia/Chita' => 'وقت یاکوتسک (چیتا)',
        'Asia/Colombo' => 'وقت هند (کلمبو)',
        'Asia/Damascus' => 'وقت شرق اروپا (دمشق)',
        'Asia/Dhaka' => 'وقت بنگلادش (داکا)',
        'Asia/Dili' => 'وقت تیمور شرقی (دیلی)',
        'Asia/Dubai' => 'وقت عادی خلیج فارس (دبی)',
        'Asia/Dushanbe' => 'وقت تاجیکستان (دوشنبه)',
        'Asia/Famagusta' => 'وقت شرق اروپا (فاماگوستا)',
        'Asia/Gaza' => 'وقت شرق اروپا (غزه)',
        'Asia/Hebron' => 'وقت شرق اروپا (الخلیل)',
        'Asia/Hong_Kong' => 'وقت هنگ‌کنگ',
        'Asia/Hovd' => 'وقت خوود',
        'Asia/Irkutsk' => 'وقت ایرکوتسک',
        'Asia/Jakarta' => 'وقت غرب اندونزی (جاکارتا)',
        'Asia/Jayapura' => 'وقت شرق اندونزی (جایاپورا)',
        'Asia/Jerusalem' => 'وقت اسرائیل (اورشلیم)',
        'Asia/Kabul' => 'وقت افغانستان (کابل)',
        'Asia/Kamchatka' => 'وقت پتروپاولوسک‐کامچاتسکی (کامچاتکا)',
        'Asia/Karachi' => 'وقت پاکستان (کراچی)',
        'Asia/Katmandu' => 'وقت نپال (کاتماندو)',
        'Asia/Kathmandu' => 'وقت نپال (کاتماندو)',
        'Asia/Khandyga' => 'وقت یاکوتسک (خاندیگا)',
        'Asia/Krasnoyarsk' => 'وقت کراسنویارسک',
        'Asia/Kuala_Lumpur' => 'وقت مالزی (کوالالامپور)',
        'Asia/Kuching' => 'وقت مالزی (کوچینگ)',
        'Asia/Kuwait' => 'وقت عربستان (کویت)',
        'Asia/Macau' => 'وقت چین (ماکائو)',
        'Asia/Magadan' => 'وقت ماگادان',
        'Asia/Makassar' => 'وقت مرکز اندونزی (ماکاسار)',
        'Asia/Manila' => 'وقت فیلیپین (مانیل)',
        'Asia/Muscat' => 'وقت عادی خلیج فارس (مسقط)',
        'Asia/Nicosia' => 'وقت شرق اروپا (نیکوزیا)',
        'Asia/Novokuznetsk' => 'وقت کراسنویارسک (نوووکوزنتسک)',
        'Asia/Novosibirsk' => 'وقت کراسنویارسک (نووسیبیریسک)',
        'Asia/Omsk' => 'وقت اومسک',
        'Asia/Oral' => 'وقت قزاقستان (اورال)',
        'Asia/Phnom_Penh' => 'وقت هندوچین (پنوم‌پن)',
        'Asia/Pontianak' => 'وقت غرب اندونزی (پونتیاناک)',
        'Asia/Pyongyang' => 'وقت کره (پیونگ‌یانگ)',
        'Asia/Qatar' => 'وقت عربستان (قطر)',
        'Asia/Qostanay' => 'وقت قزاقستان (قوستانای)',
        'Asia/Qyzylorda' => 'وقت قزاقستان (قیزیل‌اوردا)',
        'Asia/Rangoon' => 'وقت میانمار (یانگون)',
        'Asia/Yangon' => 'وقت میانمار (یانگون)',
        'Asia/Riyadh' => 'وقت عربستان (ریاض)',
        'Asia/Saigon' => 'وقت هندوچین (هوشی‌مین‌سیتی)',
        'Asia/Ho_Chi_Minh' => 'وقت هندوچین (هوشی‌مین‌سیتی)',
        'Asia/Sakhalin' => 'وقت ماگادان (ساخالین)',
        'Asia/Samarkand' => 'وقت ازبکستان (سمرقند)',
        'Asia/Seoul' => 'وقت کره (سئول)',
        'Asia/Shanghai' => 'وقت چین (شانگهای)',
        'Asia/Singapore' => 'وقت سنگاپور',
        'Asia/Srednekolymsk' => 'وقت ماگادان (اسردنکولیمسک)',
        'Asia/Taipei' => 'وقت تایپه',
        'Asia/Tashkent' => 'وقت ازبکستان (تاشکند)',
        'Asia/Tbilisi' => 'وقت گرجستان (تفلیس)',
        'Asia/Tehran' => 'وقت ایران (تهران)',
        'Asia/Thimphu' => 'وقت بوتان (تیمفو)',
        'Asia/Tokyo' => 'وقت ژاپن (توکیو)',
        'Asia/Tomsk' => 'وقت کراسنویارسک (تومسک)',
        'Asia/Ulaanbaatar' => 'وقت اولان‌باتور',
        'Asia/Urumqi' => 'وقت چین (ارومچی)',
        'Asia/Ust-Nera' => 'وقت ولادی‌وستوک (اوست نرا)',
        'Asia/Vientiane' => 'وقت هندوچین (وینتیان)',
        'Asia/Vladivostok' => 'وقت ولادی‌وستوک',
        'Asia/Yakutsk' => 'وقت یاکوتسک',
        'Asia/Yekaterinburg' => 'وقت یکاترینبورگ (یکاترینبرگ)',
        'Asia/Yerevan' => 'وقت ارمنستان (ایروان)',
        'Atlantic/Azores' => 'وقت آزور',
        'Atlantic/Bermuda' => 'وقت آتلانتیک (برمودا)',
        'Atlantic/Canary' => 'وقت غرب اروپا (قناری)',
        'Atlantic/Cape_Verde' => 'وقت کیپ‌ورد',
        'Atlantic/Faeroe' => 'وقت غرب اروپا (فارو)',
        'Atlantic/Faroe' => 'وقت غرب اروپا (فارو)',
        'Atlantic/Madeira' => 'وقت غرب اروپا (مادیرا)',
        'Atlantic/Reykjavik' => 'وقت گرینویچ (ریکیاویک)',
        'Atlantic/South_Georgia' => 'وقت جورجیای جنوبی',
        'Atlantic/St_Helena' => 'وقت گرینویچ (سنت هلنا)',
        'Atlantic/Stanley' => 'وقت جزایر فالکلند (استانلی)',
        'Australia/Adelaide' => 'وقت مرکز استرالیا (آدلاید)',
        'Australia/Brisbane' => 'وقت استرالیای شرقی (بریسبین)',
        'Australia/Broken_Hill' => 'وقت مرکز استرالیا (بروکن‌هیل)',
        'Australia/Darwin' => 'وقت مرکز استرالیا (داروین)',
        'Australia/Eucla' => 'وقت مرکز استرالیای غربی (اوکلا)',
        'Australia/Hobart' => 'وقت استرالیای شرقی (هوبارت)',
        'Australia/Lindeman' => 'وقت استرالیای شرقی (لیندمن)',
        'Australia/Lord_Howe' => 'وقت لردهو (لردهاو)',
        'Australia/Melbourne' => 'وقت استرالیای شرقی (ملبورن)',
        'Australia/Perth' => 'وقت استرالیای غربی (پرت)',
        'Australia/Sydney' => 'وقت استرالیای شرقی (سیدنی)',
        'Etc/GMT' => 'وقت گرینویچ',
        'Etc/UTC' => 'زمان هماهنگ جهانی',
        'Europe/Amsterdam' => 'وقت مرکز اروپا (آمستردام)',
        'Europe/Andorra' => 'وقت مرکز اروپا (آندورا)',
        'Europe/Astrakhan' => 'وقت سامارا (آستراخان)',
        'Europe/Athens' => 'وقت شرق اروپا (آتن)',
        'Europe/Belgrade' => 'وقت مرکز اروپا (بلگراد)',
        'Europe/Berlin' => 'وقت مرکز اروپا (برلین)',
        'Europe/Bratislava' => 'وقت مرکز اروپا (براتیسلاوا)',
        'Europe/Brussels' => 'وقت مرکز اروپا (بروکسل)',
        'Europe/Bucharest' => 'وقت شرق اروپا (بخارست)',
        'Europe/Budapest' => 'وقت مرکز اروپا (بوداپست)',
        'Europe/Busingen' => 'وقت مرکز اروپا (بازنگن)',
        'Europe/Chisinau' => 'وقت شرق اروپا (کیشیناو)',
        'Europe/Copenhagen' => 'وقت مرکز اروپا (کپنهاگ)',
        'Europe/Dublin' => 'وقت گرینویچ (دوبلین)',
        'Europe/Gibraltar' => 'وقت مرکز اروپا (جبل‌الطارق)',
        'Europe/Guernsey' => 'وقت گرینویچ (گرنزی)',
        'Europe/Helsinki' => 'وقت شرق اروپا (هلسینکی)',
        'Europe/Isle_of_Man' => 'وقت گرینویچ (جزیرهٔ من)',
        'Europe/Istanbul' => 'وقت ترکیه (استانبول)',
        'Europe/Jersey' => 'وقت گرینویچ (جرزی)',
        'Europe/Kaliningrad' => 'وقت شرق اروپا (کالینینگراد)',
        'Europe/Kiev' => 'وقت شرق اروپا (کیف)',
        'Europe/Kyiv' => 'وقت شرق اروپا (کیف)',
        'Europe/Kirov' => 'وقت مسکو (کیروف)',
        'Europe/Lisbon' => 'وقت غرب اروپا (لیسبون)',
        'Europe/Ljubljana' => 'وقت مرکز اروپا (لیوبلیانا)',
        'Europe/London' => 'وقت گرینویچ (لندن)',
        'Europe/Luxembourg' => 'وقت مرکز اروپا (لوکزامبورگ)',
        'Europe/Madrid' => 'وقت مرکز اروپا (مادرید)',
        'Europe/Malta' => 'وقت مرکز اروپا (مالت)',
        'Europe/Mariehamn' => 'وقت شرق اروپا (ماریه‌هامن)',
        'Europe/Minsk' => 'وقت مسکو (مینسک)',
        'Europe/Monaco' => 'وقت مرکز اروپا (موناکو)',
        'Europe/Moscow' => 'وقت مسکو',
        'Europe/Oslo' => 'وقت مرکز اروپا (اسلو)',
        'Europe/Paris' => 'وقت مرکز اروپا (پاریس)',
        'Europe/Podgorica' => 'وقت مرکز اروپا (پادگاریتسا)',
        'Europe/Prague' => 'وقت مرکز اروپا (پراگ)',
        'Europe/Riga' => 'وقت شرق اروپا (ریگا)',
        'Europe/Rome' => 'وقت مرکز اروپا (رم)',
        'Europe/Samara' => 'وقت سامارا',
        'Europe/San_Marino' => 'وقت مرکز اروپا (سان‌مارینو)',
        'Europe/Sarajevo' => 'وقت مرکز اروپا (سارایوو)',
        'Europe/Saratov' => 'وقت سامارا (ساراتوف)',
        'Europe/Simferopol' => 'وقت مسکو (سیمفروپل)',
        'Europe/Skopje' => 'وقت مرکز اروپا (اسکوپیه)',
        'Europe/Sofia' => 'وقت شرق اروپا (صوفیه)',
        'Europe/Stockholm' => 'وقت مرکز اروپا (استکهلم)',
        'Europe/Tallinn' => 'وقت شرق اروپا (تالین)',
        'Europe/Tirane' => 'وقت مرکز اروپا (تیرانا)',
        'Europe/Ulyanovsk' => 'وقت سامارا (اولیانوفسک)',
        'Europe/Vaduz' => 'وقت مرکز اروپا (فادوتس)',
        'Europe/Vatican' => 'وقت مرکز اروپا (واتیکان)',
        'Europe/Vienna' => 'وقت مرکز اروپا (وین)',
        'Europe/Vilnius' => 'وقت شرق اروپا (ویلنیوس)',
        'Europe/Volgograd' => 'وقت مسکو (ولگاگراد)',
        'Europe/Warsaw' => 'وقت مرکز اروپا (ورشو)',
        'Europe/Zagreb' => 'وقت مرکز اروپا (زاگرب)',
        'Europe/Zurich' => 'وقت مرکز اروپا (زوریخ)',
        'Indian/Antananarivo' => 'وقت شرق افریقا (آنتاناناریوو)',
        'Indian/Chagos' => 'وقت اقیانوس هند (شاگوس)',
        'Indian/Christmas' => 'وقت جزیرهٔ کریسمس',
        'Indian/Cocos' => 'وقت جزایر کوکوس',
        'Indian/Comoro' => 'وقت شرق افریقا (کومورو)',
        'Indian/Kerguelen' => 'وقت سرزمین‌های جنوبی و جنوبگان فرانسه (کرگولن)',
        'Indian/Mahe' => 'وقت سیشل (ماهه)',
        'Indian/Maldives' => 'وقت مالدیو',
        'Indian/Mauritius' => 'وقت موریس',
        'Indian/Mayotte' => 'وقت شرق افریقا (مایوت)',
        'Indian/Reunion' => 'وقت رئونیون',
        'Pacific/Apia' => 'وقت آپیا',
        'Pacific/Auckland' => 'وقت نیوزیلند (اوکلند)',
        'Pacific/Bougainville' => 'وقت پاپوا گینهٔ نو (بوگنویل)',
        'Pacific/Chatham' => 'وقت چت‌هام',
        'Pacific/Easter' => 'وقت جزیرهٔ ایستر',
        'Pacific/Efate' => 'وقت واناتو (افاته)',
        'Pacific/Enderbury' => 'وقت جزایر فونیکس (کانتون)',
        'Pacific/Kanton' => 'وقت جزایر فونیکس (کانتون)',
        'Pacific/Fakaofo' => 'وقت توکلائو (فاکائوفو)',
        'Pacific/Fiji' => 'وقت فیجی',
        'Pacific/Funafuti' => 'وقت تووالو (فونافوتی)',
        'Pacific/Galapagos' => 'وقت گالاپاگوس',
        'Pacific/Gambier' => 'وقت گامبیه (گامبیر)',
        'Pacific/Guadalcanal' => 'وقت جزایر سلیمان (گوادال‌کانال)',
        'Pacific/Guam' => 'وقت عادی چامورو (گوام)',
        'Pacific/Honolulu' => 'وقت عادی هاوایی‐الوشن (هونولولو)',
        'Pacific/Kiritimati' => 'وقت جزایر لاین (کریتیماتی)',
        'Pacific/Kosrae' => 'وقت کوسرای',
        'Pacific/Kwajalein' => 'وقت جزایر مارشال (کواجیلین)',
        'Pacific/Majuro' => 'وقت جزایر مارشال (ماجورو)',
        'Pacific/Marquesas' => 'وقت مارکوئز (مارکوزه)',
        'Pacific/Midway' => 'وقت ساموا (میدوی)',
        'Pacific/Nauru' => 'وقت نائورو',
        'Pacific/Niue' => 'وقت نیوئه',
        'Pacific/Norfolk' => 'وقت جزیرهٔ نورفولک',
        'Pacific/Noumea' => 'وقت کالدونیای جدید (نومئا)',
        'Pacific/Pago_Pago' => 'وقت ساموا (پاگوپاگو)',
        'Pacific/Palau' => 'وقت پالائو',
        'Pacific/Pitcairn' => 'وقت پیتکایرن (پیت‌کرن)',
        'Pacific/Ponape' => 'وقت پوناپه (پانپی)',
        'Pacific/Pohnpei' => 'وقت پوناپه (پانپی)',
        'Pacific/Port_Moresby' => 'وقت پاپوا گینهٔ نو (پورت‌مورزبی)',
        'Pacific/Rarotonga' => 'وقت جزایر کوک (راروتونگا)',
        'Pacific/Saipan' => 'وقت عادی چامورو (سایپان)',
        'Pacific/Tahiti' => 'وقت تاهیتی',
        'Pacific/Tarawa' => 'وقت جزایر گیلبرت (تاراوا)',
        'Pacific/Tongatapu' => 'وقت تونگا (تونگاتاپو)',
        'Pacific/Truk' => 'وقت چوئوک (چوک)',
        'Pacific/Chuuk' => 'وقت چوئوک (چوک)',
        'Pacific/Wake' => 'وقت جزیرهٔ ویک',
        'Pacific/Wallis' => 'وقت والیس و فوتونا',
    ],
    'Meta' => [
        'GmtFormat' => '%s گرینویچ',
        'HourFormatPos' => '‎+%02d:%02d',
        'HourFormatNeg' => '‎−%02d:%02d',
    ],
];
