<?php

return [
    'Names' => [
        'af' => 'i-Afrikaans',
        'af_NA' => 'i-Afrikaans (i-Namibia)',
        'af_ZA' => 'i-Afrikaans (iNingizimu Afrika)',
        'ak' => 'isi-Akan',
        'ak_GH' => 'isi-Akan (i-Ghana)',
        'am' => 'isi-Amharic',
        'am_ET' => 'isi-Amharic (i-Ethiopia)',
        'ar' => 'isi-Arabic',
        'ar_001' => 'isi-Arabic (umhlaba)',
        'ar_AE' => 'isi-Arabic (i-United Arab Emirates)',
        'ar_BH' => 'isi-Arabic (i-Bahrain)',
        'ar_DJ' => 'isi-Arabic (i-Djibouti)',
        'ar_DZ' => 'isi-Arabic (i-Algeria)',
        'ar_EG' => 'isi-Arabic (i-Egypt)',
        'ar_EH' => 'isi-Arabic (i-Western Sahara)',
        'ar_ER' => 'isi-Arabic (i-Eritrea)',
        'ar_IL' => 'isi-Arabic (kwa-Israel)',
        'ar_IQ' => 'isi-Arabic (i-Iraq)',
        'ar_JO' => 'isi-Arabic (i-Jordan)',
        'ar_KM' => 'isi-Arabic (i-Comoros)',
        'ar_KW' => 'isi-Arabic (i-Kuwait)',
        'ar_LB' => 'isi-Arabic (i-Lebanon)',
        'ar_LY' => 'isi-Arabic (i-Libya)',
        'ar_MA' => 'isi-Arabic (i-Morocco)',
        'ar_MR' => 'isi-Arabic (i-Mauritania)',
        'ar_OM' => 'isi-Arabic (i-Oman)',
        'ar_PS' => 'isi-Arabic (i-Palestinian Territories)',
        'ar_QA' => 'isi-Arabic (i-Qatar)',
        'ar_SA' => 'isi-Arabic (i-Saudi Arabia)',
        'ar_SD' => 'isi-Arabic (i-Sudan)',
        'ar_SO' => 'isi-Arabic (i-Somalia)',
        'ar_SS' => 'isi-Arabic (i-South Sudan)',
        'ar_SY' => 'isi-Arabic (i-Syria)',
        'ar_TD' => 'isi-Arabic (i-Chad)',
        'ar_TN' => 'isi-Arabic (i-Tunisia)',
        'ar_YE' => 'isi-Arabic (i-Yemen)',
        'as' => 'isi-Assamese',
        'as_IN' => 'isi-Assamese (i-India)',
        'az' => 'isi-Azerbaijani',
        'az_AZ' => 'isi-Azerbaijani (i-Azerbaijan)',
        'az_Cyrl' => 'isi-Azerbaijani (isi-Cyrillic)',
        'az_Cyrl_AZ' => 'isi-Azerbaijani (isi-Cyrillic, i-Azerbaijan)',
        'az_Latn' => 'isi-Azerbaijani (isi-Latin)',
        'az_Latn_AZ' => 'isi-Azerbaijani (isi-Latin, i-Azerbaijan)',
        'ba' => 'isi-Bashkir',
        'ba_RU' => 'isi-Bashkir (i-Russia)',
        'be' => 'isi-Belarusian',
        'be_BY' => 'isi-Belarusian (i-Belarus)',
        'bg' => 'isi-Bulgari',
        'bg_BG' => 'isi-Bulgari (i-Bulgaria)',
        'bm' => 'isi-Bambara',
        'bm_ML' => 'isi-Bambara (iMali)',
        'bn' => 'isi-Bengali',
        'bn_BD' => 'isi-Bengali (i-Bangladesh)',
        'bn_IN' => 'isi-Bengali (i-India)',
        'bo' => 'isi-Tibetan',
        'bo_CN' => 'isi-Tibetan (i-China)',
        'bo_IN' => 'isi-Tibetan (i-India)',
        'br' => 'isi-Breton',
        'br_FR' => 'isi-Breton (i-France)',
        'bs' => 'isi-Bosnian',
        'bs_BA' => 'isi-Bosnian (i-Bosnia ne-Herzegovina)',
        'bs_Cyrl' => 'isi-Bosnian (isi-Cyrillic)',
        'bs_Cyrl_BA' => 'isi-Bosnian (isi-Cyrillic, i-Bosnia ne-Herzegovina)',
        'bs_Latn' => 'isi-Bosnian (isi-Latin)',
        'bs_Latn_BA' => 'isi-Bosnian (isi-Latin, i-Bosnia ne-Herzegovina)',
        'ca' => 'isi-Catalan',
        'ca_AD' => 'isi-Catalan (i-Andorra)',
        'ca_ES' => 'isi-Catalan (i-Spain)',
        'ca_FR' => 'isi-Catalan (i-France)',
        'ca_IT' => 'isi-Catalan (i-Italy)',
        'ce' => 'isi-Chechen',
        'ce_RU' => 'isi-Chechen (i-Russia)',
        'cs' => 'isi-Czech',
        'cs_CZ' => 'isi-Czech (i-Czechia)',
        'cv' => 'isi-Chuvash',
        'cv_RU' => 'isi-Chuvash (i-Russia)',
        'cy' => 'isi-Welsh',
        'cy_GB' => 'isi-Welsh (i-United Kingdom)',
        'da' => 'isi-Danish',
        'da_DK' => 'isi-Danish (i-Denmark)',
        'da_GL' => 'isi-Danish (i-Greenland)',
        'de' => 'isi-German',
        'de_AT' => 'isi-German (i-Austria)',
        'de_BE' => 'isi-German (i-Belgium)',
        'de_CH' => 'isi-German (i-Switzerland)',
        'de_DE' => 'isi-German (i-Germany)',
        'de_IT' => 'isi-German (i-Italy)',
        'de_LI' => 'isi-German (i-Liechtenstein)',
        'de_LU' => 'isi-German (i-Luxembourg)',
        'dz' => 'isi-Dzongkha',
        'dz_BT' => 'isi-Dzongkha (i-Bhutan)',
        'ee' => 'isi-Ewe',
        'ee_GH' => 'isi-Ewe (i-Ghana)',
        'ee_TG' => 'isi-Ewe (i-Togo)',
        'el' => 'isi-Greek',
        'el_CY' => 'isi-Greek (i-Cyprus)',
        'el_GR' => 'isi-Greek (i-Greece)',
        'en' => 'i-English',
        'en_001' => 'i-English (umhlaba)',
        'en_150' => 'i-English (i-Europe)',
        'en_AE' => 'i-English (i-United Arab Emirates)',
        'en_AG' => 'i-English (i-Antigua ne-Barbuda)',
        'en_AI' => 'i-English (i-Anguilla)',
        'en_AS' => 'i-English (i-American Samoa)',
        'en_AT' => 'i-English (i-Austria)',
        'en_AU' => 'i-English (i-Australia)',
        'en_BB' => 'i-English (i-Barbados)',
        'en_BE' => 'i-English (i-Belgium)',
        'en_BI' => 'i-English (i-Burundi)',
        'en_BM' => 'i-English (i-Bermuda)',
        'en_BS' => 'i-English (i-Bahamas)',
        'en_BW' => 'i-English (iBotswana)',
        'en_BZ' => 'i-English (i-Belize)',
        'en_CA' => 'i-English (i-Canada)',
        'en_CC' => 'i-English (i-Cocos [Keeling] Islands)',
        'en_CH' => 'i-English (i-Switzerland)',
        'en_CK' => 'i-English (i-Cook Islands)',
        'en_CM' => 'i-English (i-Cameroon)',
        'en_CX' => 'i-English (i-Christmas Island)',
        'en_CY' => 'i-English (i-Cyprus)',
        'en_CZ' => 'i-English (i-Czechia)',
        'en_DE' => 'i-English (i-Germany)',
        'en_DK' => 'i-English (i-Denmark)',
        'en_DM' => 'i-English (i-Dominica)',
        'en_EE' => 'i-English (i-Estonia)',
        'en_ER' => 'i-English (i-Eritrea)',
        'en_ES' => 'i-English (i-Spain)',
        'en_FI' => 'i-English (i-Finland)',
        'en_FJ' => 'i-English (i-Fiji)',
        'en_FK' => 'i-English (i-Falkland Islands)',
        'en_FM' => 'i-English (i-Micronesia)',
        'en_FR' => 'i-English (i-France)',
        'en_GB' => 'i-English (i-United Kingdom)',
        'en_GD' => 'i-English (i-Grenada)',
        'en_GE' => 'i-English (i-Georgia)',
        'en_GG' => 'i-English (i-Guernsey)',
        'en_GH' => 'i-English (i-Ghana)',
        'en_GI' => 'i-English (i-Gibraltar)',
        'en_GM' => 'i-English (i-Gambia)',
        'en_GS' => 'i-English (i-South Georgia ne-South Sandwich Islands)',
        'en_GU' => 'i-English (i-Guam)',
        'en_GY' => 'i-English (i-Guyana)',
        'en_HK' => 'i-English (i-Hong Kong SAR China)',
        'en_HU' => 'i-English (i-Hungary)',
        'en_ID' => 'i-English (i-Indonesia)',
        'en_IE' => 'i-English (i-Ireland)',
        'en_IL' => 'i-English (kwa-Israel)',
        'en_IM' => 'i-English (i-Isle of Man)',
        'en_IN' => 'i-English (i-India)',
        'en_IO' => 'i-English (i-British Indian Ocean Territory)',
        'en_IT' => 'i-English (i-Italy)',
        'en_JE' => 'i-English (i-Jersey)',
        'en_JM' => 'i-English (i-Jamaica)',
        'en_JP' => 'i-English (i-Japan)',
        'en_KE' => 'i-English (i-Kenya)',
        'en_KI' => 'i-English (i-Kiribati)',
        'en_KN' => 'i-English (i-Saint Kitts ne-Nevis)',
        'en_KY' => 'i-English (i-Cayman Islands)',
        'en_LC' => 'i-English (i-Saint Lucia)',
        'en_LR' => 'i-English (i-Liberia)',
        'en_LS' => 'i-English (iLesotho)',
        'en_LT' => 'i-English (i-Lithuania)',
        'en_LV' => 'i-English (i-Latvia)',
        'en_MG' => 'i-English (i-Madagascar)',
        'en_MH' => 'i-English (i-Marshall Islands)',
        'en_MO' => 'i-English (i-Macau SAR China)',
        'en_MP' => 'i-English (i-Northern Mariana Islands)',
        'en_MS' => 'i-English (i-Montserrat)',
        'en_MT' => 'i-English (i-Malta)',
        'en_MU' => 'i-English (i-Mauritius)',
        'en_MV' => 'i-English (i-Maldives)',
        'en_MW' => 'i-English (iMalawi)',
        'en_MY' => 'i-English (i-Malaysia)',
        'en_NA' => 'i-English (i-Namibia)',
        'en_NF' => 'i-English (i-Norfolk Island)',
        'en_NG' => 'i-English (i-Nigeria)',
        'en_NL' => 'i-English (i-Netherlands)',
        'en_NO' => 'i-English (i-Norway)',
        'en_NR' => 'i-English (i-Nauru)',
        'en_NU' => 'i-English (i-Niue)',
        'en_NZ' => 'i-English (i-New Zealand)',
        'en_PG' => 'i-English (i-Papua New Guinea)',
        'en_PH' => 'i-English (i-Philippines)',
        'en_PK' => 'i-English (i-Pakistan)',
        'en_PL' => 'i-English (i-Poland)',
        'en_PN' => 'i-English (i-Pitcairn Islands)',
        'en_PR' => 'i-English (i-Puerto Rico)',
        'en_PT' => 'i-English (i-Portugal)',
        'en_PW' => 'i-English (i-Palau)',
        'en_RO' => 'i-English (i-Romania)',
        'en_RW' => 'i-English (i-Rwanda)',
        'en_SB' => 'i-English (i-Solomon Islands)',
        'en_SC' => 'i-English (i-Seychelles)',
        'en_SD' => 'i-English (i-Sudan)',
        'en_SE' => 'i-English (i-Sweden)',
        'en_SG' => 'i-English (i-Singapore)',
        'en_SH' => 'i-English (i-St. Helena)',
        'en_SI' => 'i-English (i-Slovenia)',
        'en_SK' => 'i-English (i-Slovakia)',
        'en_SL' => 'i-English (i-Sierra Leone)',
        'en_SS' => 'i-English (i-South Sudan)',
        'en_SX' => 'i-English (i-Sint Maarten)',
        'en_SZ' => 'i-English (i-Swaziland)',
        'en_TC' => 'i-English (i-Turks ne-Caicos Islands)',
        'en_TK' => 'i-English (i-Tokelau)',
        'en_TO' => 'i-English (i-Tonga)',
        'en_TT' => 'i-English (i-Trinidad ne-Tobago)',
        'en_TV' => 'i-English (i-Tuvalu)',
        'en_TZ' => 'i-English (i-Tanzania)',
        'en_UA' => 'i-English (i-Ukraine)',
        'en_UG' => 'i-English (i-Uganda)',
        'en_UM' => 'i-English (I-U.S. Outlying Islands)',
        'en_US' => 'i-English (i-United States)',
        'en_VC' => 'i-English (i-Saint Vincent ne-Grenadines)',
        'en_VG' => 'i-English (i-British Virgin Islands)',
        'en_VI' => 'i-English (i-U.S. Virgin Islands)',
        'en_VU' => 'i-English (i-Vanuatu)',
        'en_WS' => 'i-English (i-Samoa)',
        'en_ZA' => 'i-English (iNingizimu Afrika)',
        'en_ZM' => 'i-English (i-Zambia)',
        'en_ZW' => 'i-English (iZimbabwe)',
        'eo' => 'isi-Esperanto',
        'eo_001' => 'isi-Esperanto (umhlaba)',
        'es' => 'isi-Spanish',
        'es_419' => 'isi-Spanish (i-Latin America)',
        'es_AR' => 'isi-Spanish (i-Argentina)',
        'es_BO' => 'isi-Spanish (i-Bolivia)',
        'es_BR' => 'isi-Spanish (i-Brazil)',
        'es_BZ' => 'isi-Spanish (i-Belize)',
        'es_CL' => 'isi-Spanish (i-Chile)',
        'es_CO' => 'isi-Spanish (i-Colombia)',
        'es_CR' => 'isi-Spanish (i-Costa Rica)',
        'es_CU' => 'isi-Spanish (i-Cuba)',
        'es_DO' => 'isi-Spanish (i-Dominican Republic)',
        'es_EC' => 'isi-Spanish (i-Ecuador)',
        'es_ES' => 'isi-Spanish (i-Spain)',
        'es_GQ' => 'isi-Spanish (i-Equatorial Guinea)',
        'es_GT' => 'isi-Spanish (i-Guatemala)',
        'es_HN' => 'isi-Spanish (i-Honduras)',
        'es_MX' => 'isi-Spanish (i-Mexico)',
        'es_NI' => 'isi-Spanish (i-Nicaragua)',
        'es_PA' => 'isi-Spanish (i-Panama)',
        'es_PE' => 'isi-Spanish (i-Peru)',
        'es_PH' => 'isi-Spanish (i-Philippines)',
        'es_PR' => 'isi-Spanish (i-Puerto Rico)',
        'es_PY' => 'isi-Spanish (i-Paraguay)',
        'es_SV' => 'isi-Spanish (i-El Salvador)',
        'es_US' => 'isi-Spanish (i-United States)',
        'es_UY' => 'isi-Spanish (i-Uruguay)',
        'es_VE' => 'isi-Spanish (i-Venezuela)',
        'et' => 'isi-Estonia',
        'et_EE' => 'isi-Estonia (i-Estonia)',
        'eu' => 'isi-Basque',
        'eu_ES' => 'isi-Basque (i-Spain)',
        'fa' => 'isi-Persian',
        'fa_AF' => 'isi-Persian (i-Afghanistan)',
        'fa_IR' => 'isi-Persian (i-Iran)',
        'ff' => 'isi-Fulah',
        'ff_Adlm' => 'isi-Fulah (isi-Adlam)',
        'ff_Adlm_BF' => 'isi-Fulah (isi-Adlam, i-Burkina Faso)',
        'ff_Adlm_CM' => 'isi-Fulah (isi-Adlam, i-Cameroon)',
        'ff_Adlm_GH' => 'isi-Fulah (isi-Adlam, i-Ghana)',
        'ff_Adlm_GM' => 'isi-Fulah (isi-Adlam, i-Gambia)',
        'ff_Adlm_GN' => 'isi-Fulah (isi-Adlam, i-Guinea)',
        'ff_Adlm_GW' => 'isi-Fulah (isi-Adlam, i-Guinea-Bissau)',
        'ff_Adlm_LR' => 'isi-Fulah (isi-Adlam, i-Liberia)',
        'ff_Adlm_MR' => 'isi-Fulah (isi-Adlam, i-Mauritania)',
        'ff_Adlm_NE' => 'isi-Fulah (isi-Adlam, i-Niger)',
        'ff_Adlm_NG' => 'isi-Fulah (isi-Adlam, i-Nigeria)',
        'ff_Adlm_SL' => 'isi-Fulah (isi-Adlam, i-Sierra Leone)',
        'ff_Adlm_SN' => 'isi-Fulah (isi-Adlam, i-Senegal)',
        'ff_CM' => 'isi-Fulah (i-Cameroon)',
        'ff_GN' => 'isi-Fulah (i-Guinea)',
        'ff_Latn' => 'isi-Fulah (isi-Latin)',
        'ff_Latn_BF' => 'isi-Fulah (isi-Latin, i-Burkina Faso)',
        'ff_Latn_CM' => 'isi-Fulah (isi-Latin, i-Cameroon)',
        'ff_Latn_GH' => 'isi-Fulah (isi-Latin, i-Ghana)',
        'ff_Latn_GM' => 'isi-Fulah (isi-Latin, i-Gambia)',
        'ff_Latn_GN' => 'isi-Fulah (isi-Latin, i-Guinea)',
        'ff_Latn_GW' => 'isi-Fulah (isi-Latin, i-Guinea-Bissau)',
        'ff_Latn_LR' => 'isi-Fulah (isi-Latin, i-Liberia)',
        'ff_Latn_MR' => 'isi-Fulah (isi-Latin, i-Mauritania)',
        'ff_Latn_NE' => 'isi-Fulah (isi-Latin, i-Niger)',
        'ff_Latn_NG' => 'isi-Fulah (isi-Latin, i-Nigeria)',
        'ff_Latn_SL' => 'isi-Fulah (isi-Latin, i-Sierra Leone)',
        'ff_Latn_SN' => 'isi-Fulah (isi-Latin, i-Senegal)',
        'ff_MR' => 'isi-Fulah (i-Mauritania)',
        'ff_SN' => 'isi-Fulah (i-Senegal)',
        'fi' => 'isi-Finnish',
        'fi_FI' => 'isi-Finnish (i-Finland)',
        'fo' => 'isi-Faroese',
        'fo_DK' => 'isi-Faroese (i-Denmark)',
        'fo_FO' => 'isi-Faroese (i-Faroe Islands)',
        'fr' => 'isi-French',
        'fr_BE' => 'isi-French (i-Belgium)',
        'fr_BF' => 'isi-French (i-Burkina Faso)',
        'fr_BI' => 'isi-French (i-Burundi)',
        'fr_BJ' => 'isi-French (i-Benin)',
        'fr_BL' => 'isi-French (i-Saint Barthélemy)',
        'fr_CA' => 'isi-French (i-Canada)',
        'fr_CD' => 'isi-French (i-Congo - Kinshasa)',
        'fr_CF' => 'isi-French (i-Central African Republic)',
        'fr_CG' => 'isi-French (i-Congo - Brazzaville)',
        'fr_CH' => 'isi-French (i-Switzerland)',
        'fr_CI' => 'isi-French (i-Côte d’Ivoire)',
        'fr_CM' => 'isi-French (i-Cameroon)',
        'fr_DJ' => 'isi-French (i-Djibouti)',
        'fr_DZ' => 'isi-French (i-Algeria)',
        'fr_FR' => 'isi-French (i-France)',
        'fr_GA' => 'isi-French (i-Gabon)',
        'fr_GF' => 'isi-French (i-French Guiana)',
        'fr_GN' => 'isi-French (i-Guinea)',
        'fr_GP' => 'isi-French (i-Guadeloupe)',
        'fr_GQ' => 'isi-French (i-Equatorial Guinea)',
        'fr_HT' => 'isi-French (i-Haiti)',
        'fr_KM' => 'isi-French (i-Comoros)',
        'fr_LU' => 'isi-French (i-Luxembourg)',
        'fr_MA' => 'isi-French (i-Morocco)',
        'fr_MC' => 'isi-French (i-Monaco)',
        'fr_MF' => 'isi-French (i-Saint Martin)',
        'fr_MG' => 'isi-French (i-Madagascar)',
        'fr_ML' => 'isi-French (iMali)',
        'fr_MQ' => 'isi-French (i-Martinique)',
        'fr_MR' => 'isi-French (i-Mauritania)',
        'fr_MU' => 'isi-French (i-Mauritius)',
        'fr_NC' => 'isi-French (i-New Caledonia)',
        'fr_NE' => 'isi-French (i-Niger)',
        'fr_PF' => 'isi-French (i-French Polynesia)',
        'fr_PM' => 'isi-French (i-Saint Pierre kanye ne-Miquelon)',
        'fr_RE' => 'isi-French (i-Réunion)',
        'fr_RW' => 'isi-French (i-Rwanda)',
        'fr_SC' => 'isi-French (i-Seychelles)',
        'fr_SN' => 'isi-French (i-Senegal)',
        'fr_SY' => 'isi-French (i-Syria)',
        'fr_TD' => 'isi-French (i-Chad)',
        'fr_TG' => 'isi-French (i-Togo)',
        'fr_TN' => 'isi-French (i-Tunisia)',
        'fr_VU' => 'isi-French (i-Vanuatu)',
        'fr_WF' => 'isi-French (i-Wallis ne-Futuna)',
        'fr_YT' => 'isi-French (i-Mayotte)',
        'fy' => 'isi-Western Frisian',
        'fy_NL' => 'isi-Western Frisian (i-Netherlands)',
        'ga' => 'isi-Irish',
        'ga_GB' => 'isi-Irish (i-United Kingdom)',
        'ga_IE' => 'isi-Irish (i-Ireland)',
        'gd' => 'isi-Scottish Gaelic',
        'gd_GB' => 'isi-Scottish Gaelic (i-United Kingdom)',
        'gl' => 'isi-Galicia',
        'gl_ES' => 'isi-Galicia (i-Spain)',
        'gu' => 'isi-Gujarati',
        'gu_IN' => 'isi-Gujarati (i-India)',
        'gv' => 'isi-Manx',
        'gv_IM' => 'isi-Manx (i-Isle of Man)',
        'ha' => 'isi-Hausa',
        'ha_GH' => 'isi-Hausa (i-Ghana)',
        'ha_NE' => 'isi-Hausa (i-Niger)',
        'ha_NG' => 'isi-Hausa (i-Nigeria)',
        'he' => 'isi-Hebrew',
        'he_IL' => 'isi-Hebrew (kwa-Israel)',
        'hi' => 'isi-Hindi',
        'hi_IN' => 'isi-Hindi (i-India)',
        'hi_Latn' => 'isi-Hindi (isi-Latin)',
        'hi_Latn_IN' => 'isi-Hindi (isi-Latin, i-India)',
        'hr' => 'isi-Croatian',
        'hr_BA' => 'isi-Croatian (i-Bosnia ne-Herzegovina)',
        'hr_HR' => 'isi-Croatian (i-Croatia)',
        'hu' => 'isi-Hungarian',
        'hu_HU' => 'isi-Hungarian (i-Hungary)',
        'hy' => 'isi-Armenia',
        'hy_AM' => 'isi-Armenia (i-Armenia)',
        'ia' => 'izilimi ezihlangene',
        'ia_001' => 'izilimi ezihlangene (umhlaba)',
        'id' => 'isi-Indonesian',
        'id_ID' => 'isi-Indonesian (i-Indonesia)',
        'ie' => 'izimili',
        'ie_EE' => 'izimili (i-Estonia)',
        'ig' => 'isi-Igbo',
        'ig_NG' => 'isi-Igbo (i-Nigeria)',
        'ii' => 'isi-Sichuan Yi',
        'ii_CN' => 'isi-Sichuan Yi (i-China)',
        'is' => 'isi-Icelandic',
        'is_IS' => 'isi-Icelandic (i-Iceland)',
        'it' => 'isi-Italian',
        'it_CH' => 'isi-Italian (i-Switzerland)',
        'it_IT' => 'isi-Italian (i-Italy)',
        'it_SM' => 'isi-Italian (i-San Marino)',
        'it_VA' => 'isi-Italian (i-Vatican City)',
        'ja' => 'isi-Japanese',
        'ja_JP' => 'isi-Japanese (i-Japan)',
        'jv' => 'isi-Javanese',
        'jv_ID' => 'isi-Javanese (i-Indonesia)',
        'ka' => 'isi-Georgian',
        'ka_GE' => 'isi-Georgian (i-Georgia)',
        'ki' => 'isi-Kikuyu',
        'ki_KE' => 'isi-Kikuyu (i-Kenya)',
        'kk' => 'isi-Kazakh',
        'kk_Arab' => 'isi-Kazakh (isi-Arabic)',
        'kk_Arab_CN' => 'isi-Kazakh (isi-Arabic, i-China)',
        'kk_Cyrl' => 'isi-Kazakh (isi-Cyrillic)',
        'kk_Cyrl_KZ' => 'isi-Kazakh (isi-Cyrillic, i-Kazakhstan)',
        'kk_KZ' => 'isi-Kazakh (i-Kazakhstan)',
        'kl' => 'isi-Kalaallisut',
        'kl_GL' => 'isi-Kalaallisut (i-Greenland)',
        'km' => 'isi-Khmer',
        'km_KH' => 'isi-Khmer (i-Cambodia)',
        'kn' => 'isi-Kannada',
        'kn_IN' => 'isi-Kannada (i-India)',
        'ko' => 'isi-Korean',
        'ko_CN' => 'isi-Korean (i-China)',
        'ko_KP' => 'isi-Korean (i-North Korea)',
        'ko_KR' => 'isi-Korean (i-South Korea)',
        'ks' => 'isi-Kashmiri',
        'ks_Arab' => 'isi-Kashmiri (isi-Arabic)',
        'ks_Arab_IN' => 'isi-Kashmiri (isi-Arabic, i-India)',
        'ks_Deva' => 'isi-Kashmiri (isi-Devanagari)',
        'ks_Deva_IN' => 'isi-Kashmiri (isi-Devanagari, i-India)',
        'ks_IN' => 'isi-Kashmiri (i-India)',
        'ku' => 'isi-Kurdish',
        'ku_Latn' => 'isi-Kurdish (isi-Latin)',
        'ku_Latn_IQ' => 'isi-Kurdish (isi-Latin, i-Iraq)',
        'ku_Latn_SY' => 'isi-Kurdish (isi-Latin, i-Syria)',
        'ku_Latn_TR' => 'isi-Kurdish (isi-Latin, i-Turkey)',
        'ku_SY' => 'isi-Kurdish (i-Syria)',
        'ku_TR' => 'isi-Kurdish (i-Turkey)',
        'kw' => 'isi-Cornish',
        'kw_GB' => 'isi-Cornish (i-United Kingdom)',
        'ky' => 'isi-Kyrgyz',
        'ky_KG' => 'isi-Kyrgyz (i-Kyrgyzstan)',
        'lb' => 'isi-Luxembourgish',
        'lb_LU' => 'isi-Luxembourgish (i-Luxembourg)',
        'lg' => 'isi-Ganda',
        'lg_UG' => 'isi-Ganda (i-Uganda)',
        'ln' => 'isi-Lingala',
        'ln_AO' => 'isi-Lingala (i-Angola)',
        'ln_CD' => 'isi-Lingala (i-Congo - Kinshasa)',
        'ln_CF' => 'isi-Lingala (i-Central African Republic)',
        'ln_CG' => 'isi-Lingala (i-Congo - Brazzaville)',
        'lo' => 'isi-Lao',
        'lo_LA' => 'isi-Lao (i-Laos)',
        'lt' => 'isi-Lithuanian',
        'lt_LT' => 'isi-Lithuanian (i-Lithuania)',
        'lu' => 'isi-Luba-Katanga',
        'lu_CD' => 'isi-Luba-Katanga (i-Congo - Kinshasa)',
        'lv' => 'isi-Latvian',
        'lv_LV' => 'isi-Latvian (i-Latvia)',
        'mg' => 'isi-Malagasy',
        'mg_MG' => 'isi-Malagasy (i-Madagascar)',
        'mi' => 'isi-Maori',
        'mi_NZ' => 'isi-Maori (i-New Zealand)',
        'mk' => 'isi-Macedonian',
        'mk_MK' => 'isi-Macedonian (i-North Macedonia)',
        'ml' => 'isi-Malayalam',
        'ml_IN' => 'isi-Malayalam (i-India)',
        'mn' => 'isi-Mongolian',
        'mn_MN' => 'isi-Mongolian (i-Mongolia)',
        'mr' => 'isi-Marathi',
        'mr_IN' => 'isi-Marathi (i-India)',
        'ms' => 'isi-Malay',
        'ms_BN' => 'isi-Malay (i-Brunei)',
        'ms_ID' => 'isi-Malay (i-Indonesia)',
        'ms_MY' => 'isi-Malay (i-Malaysia)',
        'ms_SG' => 'isi-Malay (i-Singapore)',
        'mt' => 'isi-Maltese',
        'mt_MT' => 'isi-Maltese (i-Malta)',
        'my' => 'isi-Burmese',
        'my_MM' => 'isi-Burmese (i-Myanmar [Burma])',
        'nb' => 'isi-Norwegian Bokmål',
        'nb_NO' => 'isi-Norwegian Bokmål (i-Norway)',
        'nb_SJ' => 'isi-Norwegian Bokmål (i-Svalbard ne-Jan Mayen)',
        'nd' => 'isi-North Ndebele',
        'nd_ZW' => 'isi-North Ndebele (iZimbabwe)',
        'ne' => 'isi-Nepali',
        'ne_IN' => 'isi-Nepali (i-India)',
        'ne_NP' => 'isi-Nepali (i-Nepal)',
        'nl' => 'isi-Dutch',
        'nl_AW' => 'isi-Dutch (i-Aruba)',
        'nl_BE' => 'isi-Dutch (i-Belgium)',
        'nl_BQ' => 'isi-Dutch (i-Caribbean Netherlands)',
        'nl_CW' => 'isi-Dutch (i-Curaçao)',
        'nl_NL' => 'isi-Dutch (i-Netherlands)',
        'nl_SR' => 'isi-Dutch (i-Suriname)',
        'nl_SX' => 'isi-Dutch (i-Sint Maarten)',
        'nn' => 'isi-Norwegian Nynorsk',
        'nn_NO' => 'isi-Norwegian Nynorsk (i-Norway)',
        'no' => 'isi-Norwegian',
        'no_NO' => 'isi-Norwegian (i-Norway)',
        'oc' => 'isi-Occitan',
        'oc_ES' => 'isi-Occitan (i-Spain)',
        'oc_FR' => 'isi-Occitan (i-France)',
        'om' => 'isi-Oromo',
        'om_ET' => 'isi-Oromo (i-Ethiopia)',
        'om_KE' => 'isi-Oromo (i-Kenya)',
        'or' => 'isi-Odia',
        'or_IN' => 'isi-Odia (i-India)',
        'os' => 'isi-Ossetic',
        'os_GE' => 'isi-Ossetic (i-Georgia)',
        'os_RU' => 'isi-Ossetic (i-Russia)',
        'pa' => 'isi-Punjabi',
        'pa_Arab' => 'isi-Punjabi (isi-Arabic)',
        'pa_Arab_PK' => 'isi-Punjabi (isi-Arabic, i-Pakistan)',
        'pa_Guru' => 'isi-Punjabi (isi-Gurmukhi)',
        'pa_Guru_IN' => 'isi-Punjabi (isi-Gurmukhi, i-India)',
        'pa_IN' => 'isi-Punjabi (i-India)',
        'pa_PK' => 'isi-Punjabi (i-Pakistan)',
        'pl' => 'isi-Polish',
        'pl_PL' => 'isi-Polish (i-Poland)',
        'ps' => 'isi-Pashto',
        'ps_AF' => 'isi-Pashto (i-Afghanistan)',
        'ps_PK' => 'isi-Pashto (i-Pakistan)',
        'pt' => 'isi-Portuguese',
        'pt_AO' => 'isi-Portuguese (i-Angola)',
        'pt_BR' => 'isi-Portuguese (i-Brazil)',
        'pt_CH' => 'isi-Portuguese (i-Switzerland)',
        'pt_CV' => 'isi-Portuguese (i-Cape Verde)',
        'pt_GQ' => 'isi-Portuguese (i-Equatorial Guinea)',
        'pt_GW' => 'isi-Portuguese (i-Guinea-Bissau)',
        'pt_LU' => 'isi-Portuguese (i-Luxembourg)',
        'pt_MO' => 'isi-Portuguese (i-Macau SAR China)',
        'pt_MZ' => 'isi-Portuguese (i-Mozambique)',
        'pt_PT' => 'isi-Portuguese (i-Portugal)',
        'pt_ST' => 'isi-Portuguese (i-São Tomé kanye ne-Príncipe)',
        'pt_TL' => 'isi-Portuguese (i-Timor-Leste)',
        'qu' => 'isi-Quechua',
        'qu_BO' => 'isi-Quechua (i-Bolivia)',
        'qu_EC' => 'isi-Quechua (i-Ecuador)',
        'qu_PE' => 'isi-Quechua (i-Peru)',
        'rm' => 'isi-Romansh',
        'rm_CH' => 'isi-Romansh (i-Switzerland)',
        'rn' => 'isi-Rundi',
        'rn_BI' => 'isi-Rundi (i-Burundi)',
        'ro' => 'isi-Romanian',
        'ro_MD' => 'isi-Romanian (i-Moldova)',
        'ro_RO' => 'isi-Romanian (i-Romania)',
        'ru' => 'isi-Russian',
        'ru_BY' => 'isi-Russian (i-Belarus)',
        'ru_KG' => 'isi-Russian (i-Kyrgyzstan)',
        'ru_KZ' => 'isi-Russian (i-Kazakhstan)',
        'ru_MD' => 'isi-Russian (i-Moldova)',
        'ru_RU' => 'isi-Russian (i-Russia)',
        'ru_UA' => 'isi-Russian (i-Ukraine)',
        'rw' => 'isi-Kinyarwanda',
        'rw_RW' => 'isi-Kinyarwanda (i-Rwanda)',
        'sa' => 'isi-Sanskrit',
        'sa_IN' => 'isi-Sanskrit (i-India)',
        'sc' => 'isi-Sardinian',
        'sc_IT' => 'isi-Sardinian (i-Italy)',
        'sd' => 'isi-Sindhi',
        'sd_Arab' => 'isi-Sindhi (isi-Arabic)',
        'sd_Arab_PK' => 'isi-Sindhi (isi-Arabic, i-Pakistan)',
        'sd_Deva' => 'isi-Sindhi (isi-Devanagari)',
        'sd_Deva_IN' => 'isi-Sindhi (isi-Devanagari, i-India)',
        'sd_IN' => 'isi-Sindhi (i-India)',
        'sd_PK' => 'isi-Sindhi (i-Pakistan)',
        'se' => 'isi-Northern Sami',
        'se_FI' => 'isi-Northern Sami (i-Finland)',
        'se_NO' => 'isi-Northern Sami (i-Norway)',
        'se_SE' => 'isi-Northern Sami (i-Sweden)',
        'sg' => 'isi-Sango',
        'sg_CF' => 'isi-Sango (i-Central African Republic)',
        'sh' => 'isi-Serbo-Croatian',
        'sh_BA' => 'isi-Serbo-Croatian (i-Bosnia ne-Herzegovina)',
        'si' => 'isi-Sinhala',
        'si_LK' => 'isi-Sinhala (i-Sri Lanka)',
        'sk' => 'isi-Slovak',
        'sk_SK' => 'isi-Slovak (i-Slovakia)',
        'sl' => 'isi-Slovenian',
        'sl_SI' => 'isi-Slovenian (i-Slovenia)',
        'sn' => 'isiShona',
        'sn_ZW' => 'isiShona (iZimbabwe)',
        'so' => 'isi-Somali',
        'so_DJ' => 'isi-Somali (i-Djibouti)',
        'so_ET' => 'isi-Somali (i-Ethiopia)',
        'so_KE' => 'isi-Somali (i-Kenya)',
        'so_SO' => 'isi-Somali (i-Somalia)',
        'sq' => 'isi-Albania',
        'sq_AL' => 'isi-Albania (i-Albania)',
        'sq_MK' => 'isi-Albania (i-North Macedonia)',
        'sr' => 'isi-Serbian',
        'sr_BA' => 'isi-Serbian (i-Bosnia ne-Herzegovina)',
        'sr_Cyrl' => 'isi-Serbian (isi-Cyrillic)',
        'sr_Cyrl_BA' => 'isi-Serbian (isi-Cyrillic, i-Bosnia ne-Herzegovina)',
        'sr_Cyrl_ME' => 'isi-Serbian (isi-Cyrillic, i-Montenegro)',
        'sr_Cyrl_RS' => 'isi-Serbian (isi-Cyrillic, i-Serbia)',
        'sr_Latn' => 'isi-Serbian (isi-Latin)',
        'sr_Latn_BA' => 'isi-Serbian (isi-Latin, i-Bosnia ne-Herzegovina)',
        'sr_Latn_ME' => 'isi-Serbian (isi-Latin, i-Montenegro)',
        'sr_Latn_RS' => 'isi-Serbian (isi-Latin, i-Serbia)',
        'sr_ME' => 'isi-Serbian (i-Montenegro)',
        'sr_RS' => 'isi-Serbian (i-Serbia)',
        'st' => 'isi-Southern Sotho',
        'st_LS' => 'isi-Southern Sotho (iLesotho)',
        'st_ZA' => 'isi-Southern Sotho (iNingizimu Afrika)',
        'su' => 'isi-Sundanese',
        'su_ID' => 'isi-Sundanese (i-Indonesia)',
        'su_Latn' => 'isi-Sundanese (isi-Latin)',
        'su_Latn_ID' => 'isi-Sundanese (isi-Latin, i-Indonesia)',
        'sv' => 'isi-Swedish',
        'sv_AX' => 'isi-Swedish (i-Åland Islands)',
        'sv_FI' => 'isi-Swedish (i-Finland)',
        'sv_SE' => 'isi-Swedish (i-Sweden)',
        'sw' => 'isiSwahili',
        'sw_CD' => 'isiSwahili (i-Congo - Kinshasa)',
        'sw_KE' => 'isiSwahili (i-Kenya)',
        'sw_TZ' => 'isiSwahili (i-Tanzania)',
        'sw_UG' => 'isiSwahili (i-Uganda)',
        'ta' => 'isi-Tamil',
        'ta_IN' => 'isi-Tamil (i-India)',
        'ta_LK' => 'isi-Tamil (i-Sri Lanka)',
        'ta_MY' => 'isi-Tamil (i-Malaysia)',
        'ta_SG' => 'isi-Tamil (i-Singapore)',
        'te' => 'isi-Telugu',
        'te_IN' => 'isi-Telugu (i-India)',
        'tg' => 'isi-Tajik',
        'tg_TJ' => 'isi-Tajik (i-Tajikistan)',
        'th' => 'isi-Thai',
        'th_TH' => 'isi-Thai (i-Thailand)',
        'ti' => 'isi-Tigrinya',
        'ti_ER' => 'isi-Tigrinya (i-Eritrea)',
        'ti_ET' => 'isi-Tigrinya (i-Ethiopia)',
        'tk' => 'isi-Turkmen',
        'tk_TM' => 'isi-Turkmen (i-Turkmenistan)',
        'tn' => 'isi-Tswana',
        'tn_BW' => 'isi-Tswana (iBotswana)',
        'tn_ZA' => 'isi-Tswana (iNingizimu Afrika)',
        'to' => 'isi-Tongan',
        'to_TO' => 'isi-Tongan (i-Tonga)',
        'tr' => 'isi-Turkish',
        'tr_CY' => 'isi-Turkish (i-Cyprus)',
        'tr_TR' => 'isi-Turkish (i-Turkey)',
        'tt' => 'isi-Tatar',
        'tt_RU' => 'isi-Tatar (i-Russia)',
        'ug' => 'isi-Uighur',
        'ug_CN' => 'isi-Uighur (i-China)',
        'uk' => 'isi-Ukrainian',
        'uk_UA' => 'isi-Ukrainian (i-Ukraine)',
        'ur' => 'isi-Urdu',
        'ur_IN' => 'isi-Urdu (i-India)',
        'ur_PK' => 'isi-Urdu (i-Pakistan)',
        'uz' => 'isi-Uzbek',
        'uz_AF' => 'isi-Uzbek (i-Afghanistan)',
        'uz_Arab' => 'isi-Uzbek (isi-Arabic)',
        'uz_Arab_AF' => 'isi-Uzbek (isi-Arabic, i-Afghanistan)',
        'uz_Cyrl' => 'isi-Uzbek (isi-Cyrillic)',
        'uz_Cyrl_UZ' => 'isi-Uzbek (isi-Cyrillic, i-Uzbekistan)',
        'uz_Latn' => 'isi-Uzbek (isi-Latin)',
        'uz_Latn_UZ' => 'isi-Uzbek (isi-Latin, i-Uzbekistan)',
        'uz_UZ' => 'isi-Uzbek (i-Uzbekistan)',
        'vi' => 'isi-Vietnamese',
        'vi_VN' => 'isi-Vietnamese (i-Vietnam)',
        'wo' => 'isi-Wolof',
        'wo_SN' => 'isi-Wolof (i-Senegal)',
        'xh' => 'isiXhosa',
        'xh_ZA' => 'isiXhosa (iNingizimu Afrika)',
        'yi' => 'isi-Yiddish',
        'yi_UA' => 'isi-Yiddish (i-Ukraine)',
        'yo' => 'isi-Yoruba',
        'yo_BJ' => 'isi-Yoruba (i-Benin)',
        'yo_NG' => 'isi-Yoruba (i-Nigeria)',
        'za' => 'IsiZhuang',
        'za_CN' => 'IsiZhuang (i-China)',
        'zh' => 'isi-Chinese',
        'zh_CN' => 'isi-Chinese (i-China)',
        'zh_HK' => 'isi-Chinese (i-Hong Kong SAR China)',
        'zh_Hans' => 'isi-Chinese (enziwe lula)',
        'zh_Hans_CN' => 'isi-Chinese (enziwe lula, i-China)',
        'zh_Hans_HK' => 'isi-Chinese (enziwe lula, i-Hong Kong SAR China)',
        'zh_Hans_MO' => 'isi-Chinese (enziwe lula, i-Macau SAR China)',
        'zh_Hans_MY' => 'isi-Chinese (enziwe lula, i-Malaysia)',
        'zh_Hans_SG' => 'isi-Chinese (enziwe lula, i-Singapore)',
        'zh_Hant' => 'isi-Chinese (okosiko)',
        'zh_Hant_HK' => 'isi-Chinese (okosiko, i-Hong Kong SAR China)',
        'zh_Hant_MO' => 'isi-Chinese (okosiko, i-Macau SAR China)',
        'zh_Hant_MY' => 'isi-Chinese (okosiko, i-Malaysia)',
        'zh_Hant_TW' => 'isi-Chinese (okosiko, i-Taiwan)',
        'zh_MO' => 'isi-Chinese (i-Macau SAR China)',
        'zh_SG' => 'isi-Chinese (i-Singapore)',
        'zh_TW' => 'isi-Chinese (i-Taiwan)',
        'zu' => 'isiZulu',
        'zu_ZA' => 'isiZulu (iNingizimu Afrika)',
    ],
];
