<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'pezeta andorratarra',
        ],
        'AED' => [
            'AED',
            'Arabiar Emirerri Batuetako dirhama',
        ],
        'AFA' => [
            'AFA',
            'afghani afgandarra (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'afgani afganiarra',
        ],
        'ALK' => [
            'ALK',
            'lek albaniarra (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'lek albaniarra',
        ],
        'AMD' => [
            'AMD',
            'dram armeniarra',
        ],
        'ANG' => [
            'ANG',
            'florin antillarra',
        ],
        'AOA' => [
            'AOA',
            'kwanza angolarra',
        ],
        'AOK' => [
            'AOK',
            'kwanza angolarra (1977–1991)',
        ],
        'AON' => [
            'AON',
            'kwanza angolar berria (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'kwanza angolar birdoitua (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'austral argentinarra',
        ],
        'ARL' => [
            'ARL',
            'peso ley argentinarra (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'peso argentinarra (1981–1970)',
        ],
        'ARP' => [
            'ARP',
            'peso argentinarra (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'peso argentinarra',
        ],
        'ATS' => [
            'ATS',
            'txelin austriarra',
        ],
        'AUD' => [
            'A$',
            'dolar australiarra',
        ],
        'AWG' => [
            'AWG',
            'florin arubarra',
        ],
        'AZM' => [
            'AZM',
            'manat azerbaijandarra (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'manat azerbaijandarra',
        ],
        'BAD' => [
            'BAD',
            'dinar bosnia-herzegovinarra (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'marko bihurgarri bosniarra',
        ],
        'BAN' => [
            'BAN',
            'dinar bosnia-herzegovinar berria (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'dolar barbadostarra',
        ],
        'BDT' => [
            'BDT',
            'taka bangladeshtarra',
        ],
        'BEC' => [
            'BEC',
            'franko belgikarra (bihurgarria)',
        ],
        'BEF' => [
            'BEF',
            'franko belgikarra',
        ],
        'BEL' => [
            'BEL',
            'franko belgikarra (finantzarioa)',
        ],
        'BGL' => [
            'BGL',
            'Lev bulgariar indartsua',
        ],
        'BGM' => [
            'BGM',
            'Lev bulgariar sozialista',
        ],
        'BGN' => [
            'BGN',
            'lev bulgariarra',
        ],
        'BGO' => [
            'BGO',
            'Lev bulgariarra (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'dinar bahraindarra',
        ],
        'BIF' => [
            'BIF',
            'franko burundiarra',
        ],
        'BMD' => [
            'BMD',
            'dolar bermudarra',
        ],
        'BND' => [
            'BND',
            'dolar bruneitarra',
        ],
        'BOB' => [
            'BOB',
            'boliviano boliviarra',
        ],
        'BOL' => [
            'BOL',
            'boliviano boliviarra (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'peso boliviarra',
        ],
        'BOV' => [
            'BOV',
            'mvdol boliviarra',
        ],
        'BRB' => [
            'BRB',
            'cruzeiro brasildar berria (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'cruzado brasildarra (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'cruzeiro brasildarra (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'erreal brasildarra',
        ],
        'BRN' => [
            'BRN',
            'cruzado brasildar berria (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'cruzeiro brasildar berria (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'cruzeiro brasildarra (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'dolar bahamarra',
        ],
        'BTN' => [
            'BTN',
            'ngultrum bhutandarra',
        ],
        'BUK' => [
            'BUK',
            'kyat birmaniarra',
        ],
        'BWP' => [
            'BWP',
            'pula botswanarra',
        ],
        'BYB' => [
            'BYB',
            'errublo bielorrusiarra (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'errublo bielorrusiarra',
        ],
        'BYR' => [
            'BYR',
            'Bielorrusiako errubloa (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'dolar belizetarra',
        ],
        'CAD' => [
            'CA$',
            'dolar kanadarra',
        ],
        'CDF' => [
            'CDF',
            'franko kongoarra',
        ],
        'CHE' => [
            'CHE',
            'WIR euroa',
        ],
        'CHF' => [
            'CHF',
            'franko suitzarra',
        ],
        'CHW' => [
            'CHW',
            'WIR frankoa',
        ],
        'CLE' => [
            'CLE',
            'ezkutu txiletarra',
        ],
        'CLF' => [
            'CLF',
            'kontu-unitate txiletarra (UF)',
        ],
        'CLP' => [
            'CLP',
            'peso txiletarra',
        ],
        'CNH' => [
            'CNH',
            'yuan txinatarra (itsasoz haraindikoa)',
        ],
        'CNX' => [
            'CNX',
            'Txinako Herri Bankuaren dolarra',
        ],
        'CNY' => [
            'CN¥',
            'yuan txinatarra',
        ],
        'COP' => [
            'COP',
            'peso kolonbiarra',
        ],
        'COU' => [
            'COU',
            'erreal kolonbiarraren balio-unitatea',
        ],
        'CRC' => [
            'CRC',
            'colon costarricarra',
        ],
        'CSD' => [
            'CSD',
            'dinar serbiarra (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'Txekoslovakiako koroa indartsua',
        ],
        'CUC' => [
            'CUC',
            'peso bihurgarri kubatarra',
        ],
        'CUP' => [
            'CUP',
            'peso kubatarra',
        ],
        'CVE' => [
            'CVE',
            'ezkutu caboverdetarra',
        ],
        'CYP' => [
            'CYP',
            'libera zipretarra',
        ],
        'CZK' => [
            'CZK',
            'koroa txekiarra',
        ],
        'DDM' => [
            'DDM',
            'Ekialdeko Alemaniako markoa',
        ],
        'DEM' => [
            'DEM',
            'marko alemana',
        ],
        'DJF' => [
            'DJF',
            'franko djibutiarra',
        ],
        'DKK' => [
            'DKK',
            'koroa danimarkarra',
        ],
        'DOP' => [
            'DOP',
            'peso dominikarra',
        ],
        'DZD' => [
            'DZD',
            'dinar aljeriarra',
        ],
        'ECS' => [
            'ECS',
            'sukre ekuadortarra',
        ],
        'ECV' => [
            'ECV',
            'balio-unitate konstante ekuadortarra',
        ],
        'EEK' => [
            'EEK',
            'kroon estoniarra',
        ],
        'EGP' => [
            'EGP',
            'libera egiptoarra',
        ],
        'ERN' => [
            'ERN',
            'nakfa eritrearra',
        ],
        'ESA' => [
            'ESA',
            'pezeta espainiarra (A kontua)',
        ],
        'ESB' => [
            'ESB',
            'pezeta espainiarra (kontu bihurgarria)',
        ],
        'ESP' => [
            '₧',
            'pezeta espainiarra',
        ],
        'ETB' => [
            'ETB',
            'birr etiopiarra',
        ],
        'EUR' => [
            '€',
            'euroa',
        ],
        'FIM' => [
            'FIM',
            'markka finlandiarra',
        ],
        'FJD' => [
            'FJD',
            'dolar fijiarra',
        ],
        'FKP' => [
            'FKP',
            'libera falklandarra',
        ],
        'FRF' => [
            'FRF',
            'libera frantsesa',
        ],
        'GBP' => [
            '£',
            'libera esterlina',
        ],
        'GEK' => [
            'GEK',
            'kupon larit georgiarra',
        ],
        'GEL' => [
            'GEL',
            'lari georgiarra',
        ],
        'GHC' => [
            'GHC',
            'cedi ghanatarra (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'cedi ghanatarra',
        ],
        'GIP' => [
            'GIP',
            'libera gibraltartarra',
        ],
        'GMD' => [
            'GMD',
            'dalasi gambiarra',
        ],
        'GNF' => [
            'GNF',
            'franko ginearra',
        ],
        'GNS' => [
            'GNS',
            'syli ginearra',
        ],
        'GQE' => [
            'GQE',
            'ekwele ekuatoreginearra',
        ],
        'GRD' => [
            'GRD',
            'drakma greziarra',
        ],
        'GTQ' => [
            'GTQ',
            'ketzal guatemalarra',
        ],
        'GWE' => [
            'GWE',
            'Gineako ezkutu portugesa',
        ],
        'GWP' => [
            'GWP',
            'peso gineabissautarra',
        ],
        'GYD' => [
            'GYD',
            'dolar guyanarra',
        ],
        'HKD' => [
            'HK$',
            'dolar hongkongtarra',
        ],
        'HNL' => [
            'HNL',
            'lempira hodurastarra',
        ],
        'HRD' => [
            'HRD',
            'dinar kroaziarra',
        ],
        'HRK' => [
            'HRK',
            'kuna kroaziarra',
        ],
        'HTG' => [
            'HTG',
            'gourde haitiarra',
        ],
        'HUF' => [
            'HUF',
            'forint hungariarra',
        ],
        'IDR' => [
            'IDR',
            'errupia indonesiarra',
        ],
        'IEP' => [
            'IEP',
            'libera irlandarra',
        ],
        'ILP' => [
            'ILP',
            'libera israeldarra',
        ],
        'ILR' => [
            'ILR',
            'shekel israeldarra (1980–1985)',
        ],
        'ILS' => [
            '₪',
            'shekel israeldar berria',
        ],
        'INR' => [
            '₹',
            'errupia indiarra',
        ],
        'IQD' => [
            'IQD',
            'dinar irakiarra',
        ],
        'IRR' => [
            'IRR',
            'rial irandarra',
        ],
        'ISJ' => [
            'ISJ',
            'koroa islandiarra (1918–1981)',
        ],
        'ISK' => [
            'ISK',
            'koroa islandiarra',
        ],
        'ITL' => [
            'ITL',
            'lira italiarra',
        ],
        'JMD' => [
            'JMD',
            'dolar jamaikarra',
        ],
        'JOD' => [
            'JOD',
            'dinar jordaniarra',
        ],
        'JPY' => [
            'JP¥',
            'yen japoniarra',
        ],
        'KES' => [
            'KES',
            'txelin kenyarra',
        ],
        'KGS' => [
            'KGS',
            'som kirgizistandarra',
        ],
        'KHR' => [
            'KHR',
            'riel kanbodiarra',
        ],
        'KMF' => [
            'KMF',
            'franko komoretarra',
        ],
        'KPW' => [
            'KPW',
            'won iparkorearra',
        ],
        'KRH' => [
            'KRH',
            'hwan hegokorearra (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'won hegokorearra (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'won hegokorearra',
        ],
        'KWD' => [
            'KWD',
            'dinar kuwaitarra',
        ],
        'KYD' => [
            'KYD',
            'dolar kaimandarra',
        ],
        'KZT' => [
            'KZT',
            'tenge kazakhstandarra',
        ],
        'LAK' => [
            'LAK',
            'kip laostarra',
        ],
        'LBP' => [
            'LBP',
            'libera libanoarra',
        ],
        'LKR' => [
            'LKR',
            'errupia srilankarra',
        ],
        'LRD' => [
            'LRD',
            'dolar liberiarra',
        ],
        'LSL' => [
            'LSL',
            'loti lesothoarra',
        ],
        'LTL' => [
            'LTL',
            'Lituaniako litasa',
        ],
        'LTT' => [
            'LTT',
            'Lituaniako talonasa',
        ],
        'LUC' => [
            'LUC',
            'Luxenburgoko franko bihurgarria',
        ],
        'LUF' => [
            'LUF',
            'Luxenburgoko frankoa',
        ],
        'LUL' => [
            'LUL',
            'Luxenburgoko finantza-frankoa',
        ],
        'LVL' => [
            'LVL',
            'Letoniako latsa',
        ],
        'LVR' => [
            'LVR',
            'Letoniako errubloa',
        ],
        'LYD' => [
            'LYD',
            'dinar libiarra',
        ],
        'MAD' => [
            'MAD',
            'dirham marokoarra',
        ],
        'MAF' => [
            'MAF',
            'franko marokoarra',
        ],
        'MCF' => [
            'MCF',
            'Monakoko frankoa',
        ],
        'MDC' => [
            'MDC',
            'kupoi moldaviarra',
        ],
        'MDL' => [
            'MDL',
            'leu moldaviarra',
        ],
        'MGA' => [
            'MGA',
            'ariary madagaskartarra',
        ],
        'MGF' => [
            'MGF',
            'franko malagasiarra',
        ],
        'MKD' => [
            'MKD',
            'dinar mazedoniarra',
        ],
        'MKN' => [
            'MKN',
            'dinar mazedoniarra (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'franko maliarra',
        ],
        'MMK' => [
            'MMK',
            'kyat myanmartarra',
        ],
        'MNT' => [
            'MNT',
            'tugrik mongoliarra',
        ],
        'MOP' => [
            'MOP',
            'pataca macauarra',
        ],
        'MRO' => [
            'MRO',
            'Mauritaniako ouguiya (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'uguiya mauritaniarra',
        ],
        'MTL' => [
            'MTL',
            'lira maltarra',
        ],
        'MTP' => [
            'MTP',
            'libera maltar',
        ],
        'MUR' => [
            'MUR',
            'errupia mauriziarra',
        ],
        'MVP' => [
            'MVP',
            'errupia maldivarra (1947–1981)',
        ],
        'MVR' => [
            'MVR',
            'rufiyaa maldivarra',
        ],
        'MWK' => [
            'MWK',
            'kwacha malawiarra',
        ],
        'MXN' => [
            'MX$',
            'peso mexikarra',
        ],
        'MXP' => [
            'MXP',
            'Zilar-peso amerikarra (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Inbertsio-unitate mexikarra',
        ],
        'MYR' => [
            'MYR',
            'ringgit malaysiarra',
        ],
        'MZE' => [
            'MZE',
            'ezkutu mozambiketarra',
        ],
        'MZM' => [
            'MZM',
            'metikal mozambiketarra',
        ],
        'MZN' => [
            'MZN',
            'metical mozambiketarra',
        ],
        'NAD' => [
            'NAD',
            'dolar namibiarra',
        ],
        'NGN' => [
            'NGN',
            'naira nigeriarra',
        ],
        'NIC' => [
            'NIC',
            'kordoba nikaraguar (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'cordoba nikaraguarra',
        ],
        'NLG' => [
            'NLG',
            'gilder herbeheretarra',
        ],
        'NOK' => [
            'NOK',
            'koroa norvegiarra',
        ],
        'NPR' => [
            'NPR',
            'errupia nepaldarra',
        ],
        'NZD' => [
            'NZ$',
            'dolar zeelandaberritarra',
        ],
        'OMR' => [
            'OMR',
            'rial omandarra',
        ],
        'PAB' => [
            'PAB',
            'balboa panamarra',
        ],
        'PEI' => [
            'PEI',
            'inti perutarra',
        ],
        'PEN' => [
            'PEN',
            'sol perutarra',
        ],
        'PES' => [
            'PES',
            'sol perutarra (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'kina gineaberriarra',
        ],
        'PHP' => [
            'PHP',
            'peso filipinarra',
        ],
        'PKR' => [
            'PKR',
            'errupia pakistandarra',
        ],
        'PLN' => [
            'PLN',
            'zloty poloniarra',
        ],
        'PLZ' => [
            'PLZ',
            'zloty poloniarra (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'ezkutu portugesa',
        ],
        'PYG' => [
            'PYG',
            'guarani paraguaitarra',
        ],
        'QAR' => [
            'QAR',
            'riyal qatartarra',
        ],
        'RHD' => [
            'RHD',
            'dolar rhodesiarra',
        ],
        'ROL' => [
            'ROL',
            'leu errumaniarra (1952–2006)',
        ],
        'RON' => [
            'RON',
            'leu errumaniarra',
        ],
        'RSD' => [
            'RSD',
            'dinar serbiarra',
        ],
        'RUB' => [
            'RUB',
            'errublo errusiarra',
        ],
        'RUR' => [
            'RUR',
            'errublo errusiarra (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'franko ruandarra',
        ],
        'SAR' => [
            'SAR',
            'riyal saudiarabiarra',
        ],
        'SBD' => [
            'SBD',
            'dolar salomondarra',
        ],
        'SCR' => [
            'SCR',
            'errupia seychelletarra',
        ],
        'SDD' => [
            'SDD',
            'dinar sudandarra (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'libera sudandarra',
        ],
        'SDP' => [
            'SDP',
            'libera sudandarra (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'koroa suediarra',
        ],
        'SGD' => [
            'SGD',
            'dolar singapurtarra',
        ],
        'SHP' => [
            'SHP',
            'Santa Helenako libera',
        ],
        'SIT' => [
            'SIT',
            'tolar esloveniarra',
        ],
        'SKK' => [
            'SKK',
            'koroa eslovakiarra',
        ],
        'SLE' => [
            'SLE',
            'leone sierraleonar berria',
        ],
        'SLL' => [
            'SLL',
            'leone sierraleonarra',
        ],
        'SOS' => [
            'SOS',
            'txelin somaliarra',
        ],
        'SRD' => [
            'SRD',
            'dolar surinamdarra',
        ],
        'SRG' => [
            'SRG',
            'gilder surinamdarra',
        ],
        'SSP' => [
            'SSP',
            'libera hegosudandarra',
        ],
        'STD' => [
            'STD',
            'Sao Tomeko eta Principeko dobra (1977–2017)',
        ],
        'STN' => [
            'STN',
            'dobra saotometarra',
        ],
        'SUR' => [
            'SUR',
            'errublo sovietarra',
        ],
        'SVC' => [
            'SVC',
            'kolon salvadortarra',
        ],
        'SYP' => [
            'SYP',
            'libera siriarra',
        ],
        'SZL' => [
            'SZL',
            'lilangeni swazilandiarra',
        ],
        'THB' => [
            '฿',
            'baht thailandiarra',
        ],
        'TJR' => [
            'TJR',
            'errublo tajikistandarra',
        ],
        'TJS' => [
            'TJS',
            'somoni tajikistandarra',
        ],
        'TMM' => [
            'TMM',
            'manat turkmenistandarra (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'manat turkmenistandarra',
        ],
        'TND' => [
            'TND',
            'dinar tunisiarra',
        ],
        'TOP' => [
            'TOP',
            'paʻanga tongatarra',
        ],
        'TPE' => [
            'TPE',
            'ezkutu timortarra',
        ],
        'TRL' => [
            'TRL',
            'lira turkiarra (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'lira turkiarra',
        ],
        'TTD' => [
            'TTD',
            'dolar trinitatearra',
        ],
        'TWD' => [
            'NT$',
            'dolar taiwandar berria',
        ],
        'TZS' => [
            'TZS',
            'txelin tanzaniarra',
        ],
        'UAH' => [
            'UAH',
            'hryvnia ukrainarra',
        ],
        'UAK' => [
            'UAK',
            'karbovanets ukrainarra',
        ],
        'UGS' => [
            'UGS',
            'txelin ugandarra (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'txelin ugandarra',
        ],
        'USD' => [
            'US$',
            'dolar estatubatuarra',
        ],
        'USN' => [
            'USN',
            'dolar estatubatuar (Hurrengo eguna)',
        ],
        'USS' => [
            'USS',
            'dolar estatubatuar (Egun berean)',
        ],
        'UYI' => [
            'UYI',
            'peso uruguaitarra (unitate indexatuak)',
        ],
        'UYP' => [
            'UYP',
            'peso uruguaitarra (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'peso uruguaitarra',
        ],
        'UYW' => [
            'UYW',
            'soldata nominalaren indize-unitate uruguaitarra',
        ],
        'UZS' => [
            'UZS',
            'sum uzbekistandarra',
        ],
        'VEB' => [
            'VEB',
            'Venezuelako bolivarra (1871–2008)',
        ],
        'VED' => [
            'VED',
            'bolivar subiraua',
        ],
        'VEF' => [
            'VEF',
            'Venezuelako bolivarra (2008–2018)',
        ],
        'VES' => [
            'VES',
            'bolivar venezuelarra',
        ],
        'VND' => [
            '₫',
            'dong vietnamdarra',
        ],
        'VNN' => [
            'VNN',
            'dong vietnamdar (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'vatu vanuatuarra',
        ],
        'WST' => [
            'WST',
            'tala samoarra',
        ],
        'XAF' => [
            'FCFA',
            'Afrika erdialdeko CFA frankoa',
        ],
        'XCD' => [
            'EC$',
            'dolar ekikaribearra',
        ],
        'XCG' => [
            'Cg.',
            'florin karibetarra',
        ],
        'XEU' => [
            'XEU',
            'Europako dibisa-unitatea',
        ],
        'XFO' => [
            'XFO',
            'urrezko libera frantsesa',
        ],
        'XFU' => [
            'XFU',
            'UIC libera frantsesa',
        ],
        'XOF' => [
            'F CFA',
            'Afrika mendebaldeko CFA frankoa',
        ],
        'XPF' => [
            'CFPF',
            'CFP frankoa',
        ],
        'XRE' => [
            'XRE',
            'RINET funtsak',
        ],
        'YDD' => [
            'YDD',
            'dinar yemendarra',
        ],
        'YER' => [
            'YER',
            'rial yemendarra',
        ],
        'YUD' => [
            'YUD',
            'dinar yugoslaviar indartsua (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'dinar yugoslaviar berria (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'dinar yugoslaviar bihurgarria (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'dinar yugoslaviar erreformatua (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'rand hegoafrikarra (finantzarioa)',
        ],
        'ZAR' => [
            'ZAR',
            'rand hegoafrikarra',
        ],
        'ZMK' => [
            'ZMK',
            'Zambiako kwacha (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'kwacha zambiarra',
        ],
        'ZRN' => [
            'ZRN',
            'zaire berri zairetarra (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'zaire zairetarra (1971–1993)',
        ],
        'ZWD' => [
            'ZWD',
            'dolar zimbabwetarra (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'urre zimbabwetarra',
        ],
        'ZWL' => [
            'ZWL',
            'dolar zimbabwetarra (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'dolar zimbabwetarra (2008)',
        ],
    ],
];
