<?php

return [
    'Names' => [
        'af' => 'afrikánčina',
        'af_NA' => 'afrikánčina (Namíbia)',
        'af_ZA' => 'afrikánčina (Južná Afrika)',
        'ak' => 'akančina',
        'ak_GH' => 'akančina (Ghana)',
        'am' => 'amharčina',
        'am_ET' => 'amharčina (Etiópia)',
        'ar' => 'arabčina',
        'ar_001' => 'arabčina (svet)',
        'ar_AE' => 'arabčina (Spojené arabské emiráty)',
        'ar_BH' => 'arabčina (Bahrajn)',
        'ar_DJ' => 'arabčina (Džibutsko)',
        'ar_DZ' => 'arabčina (Alžírsko)',
        'ar_EG' => 'arabčina (Egypt)',
        'ar_EH' => 'arabčina (Západná Sahara)',
        'ar_ER' => 'arabčina (Eritrea)',
        'ar_IL' => 'arabčina (Izrael)',
        'ar_IQ' => 'arabčina (Irak)',
        'ar_JO' => 'arabčina (Jordánsko)',
        'ar_KM' => 'arabčina (Komory)',
        'ar_KW' => 'arabčina (Kuvajt)',
        'ar_LB' => 'arabčina (Libanon)',
        'ar_LY' => 'arabčina (Líbya)',
        'ar_MA' => 'arabčina (Maroko)',
        'ar_MR' => 'arabčina (Mauritánia)',
        'ar_OM' => 'arabčina (Omán)',
        'ar_PS' => 'arabčina (Palestínske územia)',
        'ar_QA' => 'arabčina (Katar)',
        'ar_SA' => 'arabčina (Saudská Arábia)',
        'ar_SD' => 'arabčina (Sudán)',
        'ar_SO' => 'arabčina (Somálsko)',
        'ar_SS' => 'arabčina (Južný Sudán)',
        'ar_SY' => 'arabčina (Sýria)',
        'ar_TD' => 'arabčina (Čad)',
        'ar_TN' => 'arabčina (Tunisko)',
        'ar_YE' => 'arabčina (Jemen)',
        'as' => 'ásamčina',
        'as_IN' => 'ásamčina (India)',
        'az' => 'azerbajdžančina',
        'az_AZ' => 'azerbajdžančina (Azerbajdžan)',
        'az_Cyrl' => 'azerbajdžančina (cyrilika)',
        'az_Cyrl_AZ' => 'azerbajdžančina (cyrilika, Azerbajdžan)',
        'az_Latn' => 'azerbajdžančina (latinka)',
        'az_Latn_AZ' => 'azerbajdžančina (latinka, Azerbajdžan)',
        'ba' => 'baškirčina',
        'ba_RU' => 'baškirčina (Rusko)',
        'be' => 'bieloruština',
        'be_BY' => 'bieloruština (Bielorusko)',
        'bg' => 'bulharčina',
        'bg_BG' => 'bulharčina (Bulharsko)',
        'bm' => 'bambarčina',
        'bm_ML' => 'bambarčina (Mali)',
        'bn' => 'bengálčina',
        'bn_BD' => 'bengálčina (Bangladéš)',
        'bn_IN' => 'bengálčina (India)',
        'bo' => 'tibetčina',
        'bo_CN' => 'tibetčina (Čína)',
        'bo_IN' => 'tibetčina (India)',
        'br' => 'bretónčina',
        'br_FR' => 'bretónčina (Francúzsko)',
        'bs' => 'bosniačtina',
        'bs_BA' => 'bosniačtina (Bosna a Hercegovina)',
        'bs_Cyrl' => 'bosniačtina (cyrilika)',
        'bs_Cyrl_BA' => 'bosniačtina (cyrilika, Bosna a Hercegovina)',
        'bs_Latn' => 'bosniačtina (latinka)',
        'bs_Latn_BA' => 'bosniačtina (latinka, Bosna a Hercegovina)',
        'ca' => 'katalánčina',
        'ca_AD' => 'katalánčina (Andorra)',
        'ca_ES' => 'katalánčina (Španielsko)',
        'ca_FR' => 'katalánčina (Francúzsko)',
        'ca_IT' => 'katalánčina (Taliansko)',
        'ce' => 'čečenčina',
        'ce_RU' => 'čečenčina (Rusko)',
        'cs' => 'čeština',
        'cs_CZ' => 'čeština (Česko)',
        'cv' => 'čuvaština',
        'cv_RU' => 'čuvaština (Rusko)',
        'cy' => 'waleština',
        'cy_GB' => 'waleština (Spojené kráľovstvo)',
        'da' => 'dánčina',
        'da_DK' => 'dánčina (Dánsko)',
        'da_GL' => 'dánčina (Grónsko)',
        'de' => 'nemčina',
        'de_AT' => 'nemčina (Rakúsko)',
        'de_BE' => 'nemčina (Belgicko)',
        'de_CH' => 'nemčina (Švajčiarsko)',
        'de_DE' => 'nemčina (Nemecko)',
        'de_IT' => 'nemčina (Taliansko)',
        'de_LI' => 'nemčina (Lichtenštajnsko)',
        'de_LU' => 'nemčina (Luxembursko)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhután)',
        'ee' => 'eweština',
        'ee_GH' => 'eweština (Ghana)',
        'ee_TG' => 'eweština (Togo)',
        'el' => 'gréčtina',
        'el_CY' => 'gréčtina (Cyprus)',
        'el_GR' => 'gréčtina (Grécko)',
        'en' => 'angličtina',
        'en_001' => 'angličtina (svet)',
        'en_150' => 'angličtina (Európa)',
        'en_AE' => 'angličtina (Spojené arabské emiráty)',
        'en_AG' => 'angličtina (Antigua a Barbuda)',
        'en_AI' => 'angličtina (Anguilla)',
        'en_AS' => 'angličtina (Americká Samoa)',
        'en_AT' => 'angličtina (Rakúsko)',
        'en_AU' => 'angličtina (Austrália)',
        'en_BB' => 'angličtina (Barbados)',
        'en_BE' => 'angličtina (Belgicko)',
        'en_BI' => 'angličtina (Burundi)',
        'en_BM' => 'angličtina (Bermudy)',
        'en_BS' => 'angličtina (Bahamy)',
        'en_BW' => 'angličtina (Botswana)',
        'en_BZ' => 'angličtina (Belize)',
        'en_CA' => 'angličtina (Kanada)',
        'en_CC' => 'angličtina (Kokosové ostrovy)',
        'en_CH' => 'angličtina (Švajčiarsko)',
        'en_CK' => 'angličtina (Cookove ostrovy)',
        'en_CM' => 'angličtina (Kamerun)',
        'en_CX' => 'angličtina (Vianočný ostrov)',
        'en_CY' => 'angličtina (Cyprus)',
        'en_CZ' => 'angličtina (Česko)',
        'en_DE' => 'angličtina (Nemecko)',
        'en_DK' => 'angličtina (Dánsko)',
        'en_DM' => 'angličtina (Dominika)',
        'en_EE' => 'angličtina (Estónsko)',
        'en_ER' => 'angličtina (Eritrea)',
        'en_ES' => 'angličtina (Španielsko)',
        'en_FI' => 'angličtina (Fínsko)',
        'en_FJ' => 'angličtina (Fidži)',
        'en_FK' => 'angličtina (Falklandy)',
        'en_FM' => 'angličtina (Mikronézia)',
        'en_FR' => 'angličtina (Francúzsko)',
        'en_GB' => 'angličtina (Spojené kráľovstvo)',
        'en_GD' => 'angličtina (Grenada)',
        'en_GE' => 'angličtina (Gruzínsko)',
        'en_GG' => 'angličtina (Guernsey)',
        'en_GH' => 'angličtina (Ghana)',
        'en_GI' => 'angličtina (Gibraltár)',
        'en_GM' => 'angličtina (Gambia)',
        'en_GS' => 'angličtina (Južná Georgia a Južné Sandwichove ostrovy)',
        'en_GU' => 'angličtina (Guam)',
        'en_GY' => 'angličtina (Guyana)',
        'en_HK' => 'angličtina (Hongkong – OAO Číny)',
        'en_HU' => 'angličtina (Maďarsko)',
        'en_ID' => 'angličtina (Indonézia)',
        'en_IE' => 'angličtina (Írsko)',
        'en_IL' => 'angličtina (Izrael)',
        'en_IM' => 'angličtina (Ostrov Man)',
        'en_IN' => 'angličtina (India)',
        'en_IO' => 'angličtina (Britské indickooceánske územie)',
        'en_IT' => 'angličtina (Taliansko)',
        'en_JE' => 'angličtina (Jersey)',
        'en_JM' => 'angličtina (Jamajka)',
        'en_JP' => 'angličtina (Japonsko)',
        'en_KE' => 'angličtina (Keňa)',
        'en_KI' => 'angličtina (Kiribati)',
        'en_KN' => 'angličtina (Svätý Krištof a Nevis)',
        'en_KY' => 'angličtina (Kajmanie ostrovy)',
        'en_LC' => 'angličtina (Svätá Lucia)',
        'en_LR' => 'angličtina (Libéria)',
        'en_LS' => 'angličtina (Lesotho)',
        'en_LT' => 'angličtina (Litva)',
        'en_LV' => 'angličtina (Lotyšsko)',
        'en_MG' => 'angličtina (Madagaskar)',
        'en_MH' => 'angličtina (Marshallove ostrovy)',
        'en_MO' => 'angličtina (Macao – OAO Číny)',
        'en_MP' => 'angličtina (Severné Mariány)',
        'en_MS' => 'angličtina (Montserrat)',
        'en_MT' => 'angličtina (Malta)',
        'en_MU' => 'angličtina (Maurícius)',
        'en_MV' => 'angličtina (Maldivy)',
        'en_MW' => 'angličtina (Malawi)',
        'en_MY' => 'angličtina (Malajzia)',
        'en_NA' => 'angličtina (Namíbia)',
        'en_NF' => 'angličtina (Norfolk)',
        'en_NG' => 'angličtina (Nigéria)',
        'en_NL' => 'angličtina (Holandsko)',
        'en_NO' => 'angličtina (Nórsko)',
        'en_NR' => 'angličtina (Nauru)',
        'en_NU' => 'angličtina (Niue)',
        'en_NZ' => 'angličtina (Nový Zéland)',
        'en_PG' => 'angličtina (Papua-Nová Guinea)',
        'en_PH' => 'angličtina (Filipíny)',
        'en_PK' => 'angličtina (Pakistan)',
        'en_PL' => 'angličtina (Poľsko)',
        'en_PN' => 'angličtina (Pitcairnove ostrovy)',
        'en_PR' => 'angličtina (Portoriko)',
        'en_PT' => 'angličtina (Portugalsko)',
        'en_PW' => 'angličtina (Palau)',
        'en_RO' => 'angličtina (Rumunsko)',
        'en_RW' => 'angličtina (Rwanda)',
        'en_SB' => 'angličtina (Šalamúnove ostrovy)',
        'en_SC' => 'angličtina (Seychely)',
        'en_SD' => 'angličtina (Sudán)',
        'en_SE' => 'angličtina (Švédsko)',
        'en_SG' => 'angličtina (Singapur)',
        'en_SH' => 'angličtina (Svätá Helena)',
        'en_SI' => 'angličtina (Slovinsko)',
        'en_SK' => 'angličtina (Slovensko)',
        'en_SL' => 'angličtina (Sierra Leone)',
        'en_SS' => 'angličtina (Južný Sudán)',
        'en_SX' => 'angličtina (Svätý Martin [hol.])',
        'en_SZ' => 'angličtina (Eswatini)',
        'en_TC' => 'angličtina (Turks a Caicos)',
        'en_TK' => 'angličtina (Tokelau)',
        'en_TO' => 'angličtina (Tonga)',
        'en_TT' => 'angličtina (Trinidad a Tobago)',
        'en_TV' => 'angličtina (Tuvalu)',
        'en_TZ' => 'angličtina (Tanzánia)',
        'en_UA' => 'angličtina (Ukrajina)',
        'en_UG' => 'angličtina (Uganda)',
        'en_UM' => 'angličtina (Menšie odľahlé ostrovy USA)',
        'en_US' => 'angličtina (Spojené štáty)',
        'en_VC' => 'angličtina (Svätý Vincent a Grenadíny)',
        'en_VG' => 'angličtina (Britské Panenské ostrovy)',
        'en_VI' => 'angličtina (Americké Panenské ostrovy)',
        'en_VU' => 'angličtina (Vanuatu)',
        'en_WS' => 'angličtina (Samoa)',
        'en_ZA' => 'angličtina (Južná Afrika)',
        'en_ZM' => 'angličtina (Zambia)',
        'en_ZW' => 'angličtina (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (svet)',
        'es' => 'španielčina',
        'es_419' => 'španielčina (Latinská Amerika)',
        'es_AR' => 'španielčina (Argentína)',
        'es_BO' => 'španielčina (Bolívia)',
        'es_BR' => 'španielčina (Brazília)',
        'es_BZ' => 'španielčina (Belize)',
        'es_CL' => 'španielčina (Čile)',
        'es_CO' => 'španielčina (Kolumbia)',
        'es_CR' => 'španielčina (Kostarika)',
        'es_CU' => 'španielčina (Kuba)',
        'es_DO' => 'španielčina (Dominikánska republika)',
        'es_EC' => 'španielčina (Ekvádor)',
        'es_ES' => 'španielčina (Španielsko)',
        'es_GQ' => 'španielčina (Rovníková Guinea)',
        'es_GT' => 'španielčina (Guatemala)',
        'es_HN' => 'španielčina (Honduras)',
        'es_MX' => 'španielčina (Mexiko)',
        'es_NI' => 'španielčina (Nikaragua)',
        'es_PA' => 'španielčina (Panama)',
        'es_PE' => 'španielčina (Peru)',
        'es_PH' => 'španielčina (Filipíny)',
        'es_PR' => 'španielčina (Portoriko)',
        'es_PY' => 'španielčina (Paraguaj)',
        'es_SV' => 'španielčina (Salvádor)',
        'es_US' => 'španielčina (Spojené štáty)',
        'es_UY' => 'španielčina (Uruguaj)',
        'es_VE' => 'španielčina (Venezuela)',
        'et' => 'estónčina',
        'et_EE' => 'estónčina (Estónsko)',
        'eu' => 'baskičtina',
        'eu_ES' => 'baskičtina (Španielsko)',
        'fa' => 'perzština',
        'fa_AF' => 'perzština (Afganistan)',
        'fa_IR' => 'perzština (Irán)',
        'ff' => 'fulbčina',
        'ff_Adlm' => 'fulbčina (adlam)',
        'ff_Adlm_BF' => 'fulbčina (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulbčina (adlam, Kamerun)',
        'ff_Adlm_GH' => 'fulbčina (adlam, Ghana)',
        'ff_Adlm_GM' => 'fulbčina (adlam, Gambia)',
        'ff_Adlm_GN' => 'fulbčina (adlam, Guinea)',
        'ff_Adlm_GW' => 'fulbčina (adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'fulbčina (adlam, Libéria)',
        'ff_Adlm_MR' => 'fulbčina (adlam, Mauritánia)',
        'ff_Adlm_NE' => 'fulbčina (adlam, Niger)',
        'ff_Adlm_NG' => 'fulbčina (adlam, Nigéria)',
        'ff_Adlm_SL' => 'fulbčina (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'fulbčina (adlam, Senegal)',
        'ff_CM' => 'fulbčina (Kamerun)',
        'ff_GN' => 'fulbčina (Guinea)',
        'ff_Latn' => 'fulbčina (latinka)',
        'ff_Latn_BF' => 'fulbčina (latinka, Burkina Faso)',
        'ff_Latn_CM' => 'fulbčina (latinka, Kamerun)',
        'ff_Latn_GH' => 'fulbčina (latinka, Ghana)',
        'ff_Latn_GM' => 'fulbčina (latinka, Gambia)',
        'ff_Latn_GN' => 'fulbčina (latinka, Guinea)',
        'ff_Latn_GW' => 'fulbčina (latinka, Guinea-Bissau)',
        'ff_Latn_LR' => 'fulbčina (latinka, Libéria)',
        'ff_Latn_MR' => 'fulbčina (latinka, Mauritánia)',
        'ff_Latn_NE' => 'fulbčina (latinka, Niger)',
        'ff_Latn_NG' => 'fulbčina (latinka, Nigéria)',
        'ff_Latn_SL' => 'fulbčina (latinka, Sierra Leone)',
        'ff_Latn_SN' => 'fulbčina (latinka, Senegal)',
        'ff_MR' => 'fulbčina (Mauritánia)',
        'ff_SN' => 'fulbčina (Senegal)',
        'fi' => 'fínčina',
        'fi_FI' => 'fínčina (Fínsko)',
        'fo' => 'faerčina',
        'fo_DK' => 'faerčina (Dánsko)',
        'fo_FO' => 'faerčina (Faerské ostrovy)',
        'fr' => 'francúzština',
        'fr_BE' => 'francúzština (Belgicko)',
        'fr_BF' => 'francúzština (Burkina Faso)',
        'fr_BI' => 'francúzština (Burundi)',
        'fr_BJ' => 'francúzština (Benin)',
        'fr_BL' => 'francúzština (Svätý Bartolomej)',
        'fr_CA' => 'francúzština (Kanada)',
        'fr_CD' => 'francúzština (Konžská demokratická republika)',
        'fr_CF' => 'francúzština (Stredoafrická republika)',
        'fr_CG' => 'francúzština (Konžská republika)',
        'fr_CH' => 'francúzština (Švajčiarsko)',
        'fr_CI' => 'francúzština (Pobrežie Slonoviny)',
        'fr_CM' => 'francúzština (Kamerun)',
        'fr_DJ' => 'francúzština (Džibutsko)',
        'fr_DZ' => 'francúzština (Alžírsko)',
        'fr_FR' => 'francúzština (Francúzsko)',
        'fr_GA' => 'francúzština (Gabon)',
        'fr_GF' => 'francúzština (Francúzska Guyana)',
        'fr_GN' => 'francúzština (Guinea)',
        'fr_GP' => 'francúzština (Guadeloupe)',
        'fr_GQ' => 'francúzština (Rovníková Guinea)',
        'fr_HT' => 'francúzština (Haiti)',
        'fr_KM' => 'francúzština (Komory)',
        'fr_LU' => 'francúzština (Luxembursko)',
        'fr_MA' => 'francúzština (Maroko)',
        'fr_MC' => 'francúzština (Monako)',
        'fr_MF' => 'francúzština (Svätý Martin [fr.])',
        'fr_MG' => 'francúzština (Madagaskar)',
        'fr_ML' => 'francúzština (Mali)',
        'fr_MQ' => 'francúzština (Martinik)',
        'fr_MR' => 'francúzština (Mauritánia)',
        'fr_MU' => 'francúzština (Maurícius)',
        'fr_NC' => 'francúzština (Nová Kaledónia)',
        'fr_NE' => 'francúzština (Niger)',
        'fr_PF' => 'francúzština (Francúzska Polynézia)',
        'fr_PM' => 'francúzština (Saint Pierre a Miquelon)',
        'fr_RE' => 'francúzština (Réunion)',
        'fr_RW' => 'francúzština (Rwanda)',
        'fr_SC' => 'francúzština (Seychely)',
        'fr_SN' => 'francúzština (Senegal)',
        'fr_SY' => 'francúzština (Sýria)',
        'fr_TD' => 'francúzština (Čad)',
        'fr_TG' => 'francúzština (Togo)',
        'fr_TN' => 'francúzština (Tunisko)',
        'fr_VU' => 'francúzština (Vanuatu)',
        'fr_WF' => 'francúzština (Wallis a Futuna)',
        'fr_YT' => 'francúzština (Mayotte)',
        'fy' => 'západná frízština',
        'fy_NL' => 'západná frízština (Holandsko)',
        'ga' => 'írčina',
        'ga_GB' => 'írčina (Spojené kráľovstvo)',
        'ga_IE' => 'írčina (Írsko)',
        'gd' => 'škótska gaelčina',
        'gd_GB' => 'škótska gaelčina (Spojené kráľovstvo)',
        'gl' => 'galícijčina',
        'gl_ES' => 'galícijčina (Španielsko)',
        'gu' => 'gudžarátčina',
        'gu_IN' => 'gudžarátčina (India)',
        'gv' => 'mančina',
        'gv_IM' => 'mančina (Ostrov Man)',
        'ha' => 'hauština',
        'ha_GH' => 'hauština (Ghana)',
        'ha_NE' => 'hauština (Niger)',
        'ha_NG' => 'hauština (Nigéria)',
        'he' => 'hebrejčina',
        'he_IL' => 'hebrejčina (Izrael)',
        'hi' => 'hindčina',
        'hi_IN' => 'hindčina (India)',
        'hi_Latn' => 'hindčina (latinka)',
        'hi_Latn_IN' => 'hindčina (latinka, India)',
        'hr' => 'chorvátčina',
        'hr_BA' => 'chorvátčina (Bosna a Hercegovina)',
        'hr_HR' => 'chorvátčina (Chorvátsko)',
        'hu' => 'maďarčina',
        'hu_HU' => 'maďarčina (Maďarsko)',
        'hy' => 'arménčina',
        'hy_AM' => 'arménčina (Arménsko)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (svet)',
        'id' => 'indonézština',
        'id_ID' => 'indonézština (Indonézia)',
        'ie' => 'interlingue',
        'ie_EE' => 'interlingue (Estónsko)',
        'ig' => 'igboština',
        'ig_NG' => 'igboština (Nigéria)',
        'ii' => 's’čchuanská iovčina',
        'ii_CN' => 's’čchuanská iovčina (Čína)',
        'is' => 'islandčina',
        'is_IS' => 'islandčina (Island)',
        'it' => 'taliančina',
        'it_CH' => 'taliančina (Švajčiarsko)',
        'it_IT' => 'taliančina (Taliansko)',
        'it_SM' => 'taliančina (San Maríno)',
        'it_VA' => 'taliančina (Vatikán)',
        'ja' => 'japončina',
        'ja_JP' => 'japončina (Japonsko)',
        'jv' => 'jávčina',
        'jv_ID' => 'jávčina (Indonézia)',
        'ka' => 'gruzínčina',
        'ka_GE' => 'gruzínčina (Gruzínsko)',
        'ki' => 'kikujčina',
        'ki_KE' => 'kikujčina (Keňa)',
        'kk' => 'kazaština',
        'kk_Arab' => 'kazaština (arabské)',
        'kk_Arab_CN' => 'kazaština (arabské, Čína)',
        'kk_Cyrl' => 'kazaština (cyrilika)',
        'kk_Cyrl_KZ' => 'kazaština (cyrilika, Kazachstan)',
        'kk_KZ' => 'kazaština (Kazachstan)',
        'kl' => 'grónčina',
        'kl_GL' => 'grónčina (Grónsko)',
        'km' => 'khmérčina',
        'km_KH' => 'khmérčina (Kambodža)',
        'kn' => 'kannadčina',
        'kn_IN' => 'kannadčina (India)',
        'ko' => 'kórejčina',
        'ko_CN' => 'kórejčina (Čína)',
        'ko_KP' => 'kórejčina (Severná Kórea)',
        'ko_KR' => 'kórejčina (Južná Kórea)',
        'ks' => 'kašmírčina',
        'ks_Arab' => 'kašmírčina (arabské)',
        'ks_Arab_IN' => 'kašmírčina (arabské, India)',
        'ks_Deva' => 'kašmírčina (dévanágarí)',
        'ks_Deva_IN' => 'kašmírčina (dévanágarí, India)',
        'ks_IN' => 'kašmírčina (India)',
        'ku' => 'kurdčina',
        'ku_Latn' => 'kurdčina (latinka)',
        'ku_Latn_IQ' => 'kurdčina (latinka, Irak)',
        'ku_Latn_SY' => 'kurdčina (latinka, Sýria)',
        'ku_Latn_TR' => 'kurdčina (latinka, Turecko)',
        'ku_SY' => 'kurdčina (Sýria)',
        'ku_TR' => 'kurdčina (Turecko)',
        'kw' => 'kornčina',
        'kw_GB' => 'kornčina (Spojené kráľovstvo)',
        'ky' => 'kirgizština',
        'ky_KG' => 'kirgizština (Kirgizsko)',
        'lb' => 'luxemburčina',
        'lb_LU' => 'luxemburčina (Luxembursko)',
        'lg' => 'gandčina',
        'lg_UG' => 'gandčina (Uganda)',
        'ln' => 'lingalčina',
        'ln_AO' => 'lingalčina (Angola)',
        'ln_CD' => 'lingalčina (Konžská demokratická republika)',
        'ln_CF' => 'lingalčina (Stredoafrická republika)',
        'ln_CG' => 'lingalčina (Konžská republika)',
        'lo' => 'laoština',
        'lo_LA' => 'laoština (Laos)',
        'lt' => 'litovčina',
        'lt_LT' => 'litovčina (Litva)',
        'lu' => 'lubčina [katanžská]',
        'lu_CD' => 'lubčina [katanžská] (Konžská demokratická republika)',
        'lv' => 'lotyština',
        'lv_LV' => 'lotyština (Lotyšsko)',
        'mg' => 'malgaština',
        'mg_MG' => 'malgaština (Madagaskar)',
        'mi' => 'maorijčina',
        'mi_NZ' => 'maorijčina (Nový Zéland)',
        'mk' => 'macedónčina',
        'mk_MK' => 'macedónčina (Severné Macedónsko)',
        'ml' => 'malajálamčina',
        'ml_IN' => 'malajálamčina (India)',
        'mn' => 'mongolčina',
        'mn_MN' => 'mongolčina (Mongolsko)',
        'mr' => 'maráthčina',
        'mr_IN' => 'maráthčina (India)',
        'ms' => 'malajčina',
        'ms_BN' => 'malajčina (Brunej)',
        'ms_ID' => 'malajčina (Indonézia)',
        'ms_MY' => 'malajčina (Malajzia)',
        'ms_SG' => 'malajčina (Singapur)',
        'mt' => 'maltčina',
        'mt_MT' => 'maltčina (Malta)',
        'my' => 'barmčina',
        'my_MM' => 'barmčina (Mjanmarsko)',
        'nb' => 'nórčina [bokmal]',
        'nb_NO' => 'nórčina [bokmal] (Nórsko)',
        'nb_SJ' => 'nórčina [bokmal] (Svalbard a Jan Mayen)',
        'nd' => 'ndebelčina [severná]',
        'nd_ZW' => 'ndebelčina [severná] (Zimbabwe)',
        'ne' => 'nepálčina',
        'ne_IN' => 'nepálčina (India)',
        'ne_NP' => 'nepálčina (Nepál)',
        'nl' => 'holandčina',
        'nl_AW' => 'holandčina (Aruba)',
        'nl_BE' => 'holandčina (Belgicko)',
        'nl_BQ' => 'holandčina (Karibské Holandsko)',
        'nl_CW' => 'holandčina (Curaçao)',
        'nl_NL' => 'holandčina (Holandsko)',
        'nl_SR' => 'holandčina (Surinam)',
        'nl_SX' => 'holandčina (Svätý Martin [hol.])',
        'nn' => 'nórčina [nynorsk]',
        'nn_NO' => 'nórčina [nynorsk] (Nórsko)',
        'no' => 'nórčina',
        'no_NO' => 'nórčina (Nórsko)',
        'oc' => 'okcitánčina',
        'oc_ES' => 'okcitánčina (Španielsko)',
        'oc_FR' => 'okcitánčina (Francúzsko)',
        'om' => 'oromčina',
        'om_ET' => 'oromčina (Etiópia)',
        'om_KE' => 'oromčina (Keňa)',
        'or' => 'uríjčina',
        'or_IN' => 'uríjčina (India)',
        'os' => 'osetčina',
        'os_GE' => 'osetčina (Gruzínsko)',
        'os_RU' => 'osetčina (Rusko)',
        'pa' => 'pandžábčina',
        'pa_Arab' => 'pandžábčina (arabské)',
        'pa_Arab_PK' => 'pandžábčina (arabské, Pakistan)',
        'pa_Guru' => 'pandžábčina (gurmukhi)',
        'pa_Guru_IN' => 'pandžábčina (gurmukhi, India)',
        'pa_IN' => 'pandžábčina (India)',
        'pa_PK' => 'pandžábčina (Pakistan)',
        'pl' => 'poľština',
        'pl_PL' => 'poľština (Poľsko)',
        'ps' => 'paštčina',
        'ps_AF' => 'paštčina (Afganistan)',
        'ps_PK' => 'paštčina (Pakistan)',
        'pt' => 'portugalčina',
        'pt_AO' => 'portugalčina (Angola)',
        'pt_BR' => 'portugalčina (Brazília)',
        'pt_CH' => 'portugalčina (Švajčiarsko)',
        'pt_CV' => 'portugalčina (Kapverdy)',
        'pt_GQ' => 'portugalčina (Rovníková Guinea)',
        'pt_GW' => 'portugalčina (Guinea-Bissau)',
        'pt_LU' => 'portugalčina (Luxembursko)',
        'pt_MO' => 'portugalčina (Macao – OAO Číny)',
        'pt_MZ' => 'portugalčina (Mozambik)',
        'pt_PT' => 'portugalčina (Portugalsko)',
        'pt_ST' => 'portugalčina (Svätý Tomáš a Princov ostrov)',
        'pt_TL' => 'portugalčina (Východný Timor)',
        'qu' => 'kečuánčina',
        'qu_BO' => 'kečuánčina (Bolívia)',
        'qu_EC' => 'kečuánčina (Ekvádor)',
        'qu_PE' => 'kečuánčina (Peru)',
        'rm' => 'rétorománčina',
        'rm_CH' => 'rétorománčina (Švajčiarsko)',
        'rn' => 'rundčina',
        'rn_BI' => 'rundčina (Burundi)',
        'ro' => 'rumunčina',
        'ro_MD' => 'rumunčina (Moldavsko)',
        'ro_RO' => 'rumunčina (Rumunsko)',
        'ru' => 'ruština',
        'ru_BY' => 'ruština (Bielorusko)',
        'ru_KG' => 'ruština (Kirgizsko)',
        'ru_KZ' => 'ruština (Kazachstan)',
        'ru_MD' => 'ruština (Moldavsko)',
        'ru_RU' => 'ruština (Rusko)',
        'ru_UA' => 'ruština (Ukrajina)',
        'rw' => 'rwandčina',
        'rw_RW' => 'rwandčina (Rwanda)',
        'sa' => 'sanskrit',
        'sa_IN' => 'sanskrit (India)',
        'sc' => 'sardínčina',
        'sc_IT' => 'sardínčina (Taliansko)',
        'sd' => 'sindhčina',
        'sd_Arab' => 'sindhčina (arabské)',
        'sd_Arab_PK' => 'sindhčina (arabské, Pakistan)',
        'sd_Deva' => 'sindhčina (dévanágarí)',
        'sd_Deva_IN' => 'sindhčina (dévanágarí, India)',
        'sd_IN' => 'sindhčina (India)',
        'sd_PK' => 'sindhčina (Pakistan)',
        'se' => 'saamčina [severná]',
        'se_FI' => 'saamčina [severná] (Fínsko)',
        'se_NO' => 'saamčina [severná] (Nórsko)',
        'se_SE' => 'saamčina [severná] (Švédsko)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Stredoafrická republika)',
        'sh' => 'srbochorvátčina',
        'sh_BA' => 'srbochorvátčina (Bosna a Hercegovina)',
        'si' => 'sinhalčina',
        'si_LK' => 'sinhalčina (Srí Lanka)',
        'sk' => 'slovenčina',
        'sk_SK' => 'slovenčina (Slovensko)',
        'sl' => 'slovinčina',
        'sl_SI' => 'slovinčina (Slovinsko)',
        'sn' => 'šončina',
        'sn_ZW' => 'šončina (Zimbabwe)',
        'so' => 'somálčina',
        'so_DJ' => 'somálčina (Džibutsko)',
        'so_ET' => 'somálčina (Etiópia)',
        'so_KE' => 'somálčina (Keňa)',
        'so_SO' => 'somálčina (Somálsko)',
        'sq' => 'albánčina',
        'sq_AL' => 'albánčina (Albánsko)',
        'sq_MK' => 'albánčina (Severné Macedónsko)',
        'sr' => 'srbčina',
        'sr_BA' => 'srbčina (Bosna a Hercegovina)',
        'sr_Cyrl' => 'srbčina (cyrilika)',
        'sr_Cyrl_BA' => 'srbčina (cyrilika, Bosna a Hercegovina)',
        'sr_Cyrl_ME' => 'srbčina (cyrilika, Čierna Hora)',
        'sr_Cyrl_RS' => 'srbčina (cyrilika, Srbsko)',
        'sr_Latn' => 'srbčina (latinka)',
        'sr_Latn_BA' => 'srbčina (latinka, Bosna a Hercegovina)',
        'sr_Latn_ME' => 'srbčina (latinka, Čierna Hora)',
        'sr_Latn_RS' => 'srbčina (latinka, Srbsko)',
        'sr_ME' => 'srbčina (Čierna Hora)',
        'sr_RS' => 'srbčina (Srbsko)',
        'st' => 'sothčina [južná]',
        'st_LS' => 'sothčina [južná] (Lesotho)',
        'st_ZA' => 'sothčina [južná] (Južná Afrika)',
        'su' => 'sundčina',
        'su_ID' => 'sundčina (Indonézia)',
        'su_Latn' => 'sundčina (latinka)',
        'su_Latn_ID' => 'sundčina (latinka, Indonézia)',
        'sv' => 'švédčina',
        'sv_AX' => 'švédčina (Alandy)',
        'sv_FI' => 'švédčina (Fínsko)',
        'sv_SE' => 'švédčina (Švédsko)',
        'sw' => 'swahilčina',
        'sw_CD' => 'swahilčina (Konžská demokratická republika)',
        'sw_KE' => 'swahilčina (Keňa)',
        'sw_TZ' => 'swahilčina (Tanzánia)',
        'sw_UG' => 'swahilčina (Uganda)',
        'ta' => 'tamilčina',
        'ta_IN' => 'tamilčina (India)',
        'ta_LK' => 'tamilčina (Srí Lanka)',
        'ta_MY' => 'tamilčina (Malajzia)',
        'ta_SG' => 'tamilčina (Singapur)',
        'te' => 'telugčina',
        'te_IN' => 'telugčina (India)',
        'tg' => 'tadžičtina',
        'tg_TJ' => 'tadžičtina (Tadžikistan)',
        'th' => 'thajčina',
        'th_TH' => 'thajčina (Thajsko)',
        'ti' => 'tigriňa',
        'ti_ER' => 'tigriňa (Eritrea)',
        'ti_ET' => 'tigriňa (Etiópia)',
        'tk' => 'turkménčina',
        'tk_TM' => 'turkménčina (Turkménsko)',
        'tl' => 'tagalčina',
        'tl_PH' => 'tagalčina (Filipíny)',
        'tn' => 'tswančina',
        'tn_BW' => 'tswančina (Botswana)',
        'tn_ZA' => 'tswančina (Južná Afrika)',
        'to' => 'tongčina',
        'to_TO' => 'tongčina (Tonga)',
        'tr' => 'turečtina',
        'tr_CY' => 'turečtina (Cyprus)',
        'tr_TR' => 'turečtina (Turecko)',
        'tt' => 'tatárčina',
        'tt_RU' => 'tatárčina (Rusko)',
        'ug' => 'ujgurčina',
        'ug_CN' => 'ujgurčina (Čína)',
        'uk' => 'ukrajinčina',
        'uk_UA' => 'ukrajinčina (Ukrajina)',
        'ur' => 'urdčina',
        'ur_IN' => 'urdčina (India)',
        'ur_PK' => 'urdčina (Pakistan)',
        'uz' => 'uzbečtina',
        'uz_AF' => 'uzbečtina (Afganistan)',
        'uz_Arab' => 'uzbečtina (arabské)',
        'uz_Arab_AF' => 'uzbečtina (arabské, Afganistan)',
        'uz_Cyrl' => 'uzbečtina (cyrilika)',
        'uz_Cyrl_UZ' => 'uzbečtina (cyrilika, Uzbekistan)',
        'uz_Latn' => 'uzbečtina (latinka)',
        'uz_Latn_UZ' => 'uzbečtina (latinka, Uzbekistan)',
        'uz_UZ' => 'uzbečtina (Uzbekistan)',
        'vi' => 'vietnamčina',
        'vi_VN' => 'vietnamčina (Vietnam)',
        'wo' => 'wolofčina',
        'wo_SN' => 'wolofčina (Senegal)',
        'xh' => 'xhoština',
        'xh_ZA' => 'xhoština (Južná Afrika)',
        'yi' => 'jidiš',
        'yi_UA' => 'jidiš (Ukrajina)',
        'yo' => 'jorubčina',
        'yo_BJ' => 'jorubčina (Benin)',
        'yo_NG' => 'jorubčina (Nigéria)',
        'za' => 'čuangčina',
        'za_CN' => 'čuangčina (Čína)',
        'zh' => 'čínština',
        'zh_CN' => 'čínština (Čína)',
        'zh_HK' => 'čínština (Hongkong – OAO Číny)',
        'zh_Hans' => 'čínština (zjednodušené)',
        'zh_Hans_CN' => 'čínština (zjednodušené, Čína)',
        'zh_Hans_HK' => 'čínština (zjednodušené, Hongkong – OAO Číny)',
        'zh_Hans_MO' => 'čínština (zjednodušené, Macao – OAO Číny)',
        'zh_Hans_MY' => 'čínština (zjednodušené, Malajzia)',
        'zh_Hans_SG' => 'čínština (zjednodušené, Singapur)',
        'zh_Hant' => 'čínština (tradičné)',
        'zh_Hant_HK' => 'čínština (tradičné, Hongkong – OAO Číny)',
        'zh_Hant_MO' => 'čínština (tradičné, Macao – OAO Číny)',
        'zh_Hant_MY' => 'čínština (tradičné, Malajzia)',
        'zh_Hant_TW' => 'čínština (tradičné, Taiwan)',
        'zh_MO' => 'čínština (Macao – OAO Číny)',
        'zh_SG' => 'čínština (Singapur)',
        'zh_TW' => 'čínština (Taiwan)',
        'zu' => 'zuluština',
        'zu_ZA' => 'zuluština (Južná Afrika)',
    ],
];
