<?php

return [
    'Names' => [
        'ak' => 'Akan',
        'am' => 'Amharika',
        'ar' => 'Arabo',
        'be' => 'Bielorosy',
        'bg' => 'Biolgara',
        'bn' => 'Bengali',
        'cs' => 'Tseky',
        'de' => 'Alemanina',
        'el' => 'Grika',
        'en' => 'Anglisy',
        'es' => 'Espaniola',
        'fa' => 'Persa',
        'fr' => 'Frantsay',
        'ha' => 'haoussa',
        'hi' => 'hindi',
        'hu' => 'hongroà',
        'id' => 'Indonezianina',
        'ig' => 'igbo',
        'it' => 'Italianina',
        'ja' => 'Japoney',
        'jv' => 'Javaney',
        'km' => 'khmer',
        'ko' => 'Koreanina',
        'mg' => 'Malagasy',
        'ms' => 'Malay',
        'my' => 'Birmana',
        'ne' => 'Nepale',
        'nl' => 'Holandey',
        'pa' => 'Penjabi',
        'pl' => 'Poloney',
        'pt' => 'Portiogey',
        'ro' => 'Romanianina',
        'ru' => 'Rosianina',
        'rw' => 'Roande',
        'so' => 'Somalianina',
        'sv' => 'Soisa',
        'ta' => 'Tamoila',
        'th' => 'Taioaney',
        'tr' => 'Tiorka',
        'uk' => 'Okrainianina',
        'ur' => 'Ordò',
        'vi' => 'Vietnamianina',
        'yo' => 'Yôrobà',
        'zh' => 'Sinoa, Mandarin',
        'zu' => 'Zolò',
    ],
    'LocalizedNames' => [],
];
