<?php

return [
    'UserAssignedNames' => [
        'XK' => 'Kosowo',
    ],
    'Names' => [
        'AD' => 'Andorra',
        'AE' => 'Birleşen Arap Emirlikleri',
        'AF' => 'Owganystan',
        'AG' => 'Antigua we Barbuda',
        'AI' => 'Angilýa',
        'AL' => 'Albaniýa',
        'AM' => 'Ermenistan',
        'AO' => 'Angola',
        'AQ' => 'Antarktika',
        'AR' => 'Argentina',
        'AS' => 'Amerikan Samoasy',
        'AT' => 'Awstriýa',
        'AU' => 'Awstraliýa',
        'AW' => 'Aruba',
        'AX' => 'Aland adalary',
        'AZ' => 'Azerbaýjan',
        'BA' => 'Bosniýa we Gersegowina',
        'BB' => 'Barbados',
        'BD' => 'Bangladeş',
        'BE' => 'Belgiýa',
        'BF' => 'Burkina-Faso',
        'BG' => 'Bolgariýa',
        'BH' => 'Bahreýn',
        'BI' => 'Burundi',
        'BJ' => 'Benin',
        'BL' => 'Sen-Bartelemi',
        'BM' => 'Bermuda',
        'BN' => 'Bruneý',
        'BO' => 'Boliwiýa',
        'BQ' => 'Karib Niderlandlary',
        'BR' => 'Braziliýa',
        'BS' => 'Bagama adalary',
        'BT' => 'Butan',
        'BV' => 'Buwe adasy',
        'BW' => 'Botswana',
        'BY' => 'Belarus',
        'BZ' => 'Beliz',
        'CA' => 'Kanada',
        'CC' => 'Kokos (Kiling) adalary',
        'CD' => 'Kongo - Kinşasa',
        'CF' => 'Merkezi Afrika Respublikasy',
        'CG' => 'Kongo - Brazzawil',
        'CH' => 'Şweýsariýa',
        'CI' => 'Kot-d’Iwuar',
        'CK' => 'Kuk adalary',
        'CL' => 'Çili',
        'CM' => 'Kamerun',
        'CN' => 'Hytaý',
        'CO' => 'Kolumbiýa',
        'CR' => 'Kosta-Rika',
        'CU' => 'Kuba',
        'CV' => 'Kabo-Werde',
        'CW' => 'Kýurasao',
        'CX' => 'Roždestwo adasy',
        'CY' => 'Kipr',
        'CZ' => 'Çehiýa',
        'DE' => 'Germaniýa',
        'DJ' => 'Jibuti',
        'DK' => 'Daniýa',
        'DM' => 'Dominika',
        'DO' => 'Dominikan Respublikasy',
        'DZ' => 'Alžir',
        'EC' => 'Ekwador',
        'EE' => 'Estoniýa',
        'EG' => 'Müsür',
        'EH' => 'Günbatar Sahara',
        'ER' => 'Eritreýa',
        'ES' => 'Ispaniýa',
        'ET' => 'Efiopiýa',
        'FI' => 'Finlýandiýa',
        'FJ' => 'Fiji',
        'FK' => 'Folklend adalary',
        'FM' => 'Mikroneziýa',
        'FO' => 'Farer adalary',
        'FR' => 'Fransiýa',
        'GA' => 'Gabon',
        'GB' => 'Birleşen Patyşalyk',
        'GD' => 'Grenada',
        'GE' => 'Gruziýa',
        'GF' => 'Fransuz Gwianasy',
        'GG' => 'Gernsi',
        'GH' => 'Gana',
        'GI' => 'Gibraltar',
        'GL' => 'Grenlandiýa',
        'GM' => 'Gambiýa',
        'GN' => 'Gwineýa',
        'GP' => 'Gwadelupa',
        'GQ' => 'Ekwatorial Gwineýa',
        'GR' => 'Gresiýa',
        'GS' => 'Günorta Georgiýa we Günorta Sendwiç adasy',
        'GT' => 'Gwatemala',
        'GU' => 'Guam',
        'GW' => 'Gwineýa-Bisau',
        'GY' => 'Gaýana',
        'HK' => 'Gonkong AAS Hytaý',
        'HM' => 'Herd we Makdonald adalary',
        'HN' => 'Gonduras',
        'HR' => 'Horwatiýa',
        'HT' => 'Gaiti',
        'HU' => 'Wengriýa',
        'ID' => 'Indoneziýa',
        'IE' => 'Irlandiýa',
        'IL' => 'Ysraýyl',
        'IM' => 'Men adasy',
        'IN' => 'Hindistan',
        'IO' => 'Britaniýanyň Hindi okeanyndaky territoriýalary',
        'IQ' => 'Yrak',
        'IR' => 'Eýran',
        'IS' => 'Islandiýa',
        'IT' => 'Italiýa',
        'JE' => 'Jersi',
        'JM' => 'Ýamaýka',
        'JO' => 'Iordaniýa',
        'JP' => 'Ýaponiýa',
        'KE' => 'Keniýa',
        'KG' => 'Gyrgyzystan',
        'KH' => 'Kamboja',
        'KI' => 'Kiribati',
        'KM' => 'Komor adalary',
        'KN' => 'Sent-Kits we Newis',
        'KP' => 'Demirgazyk Koreýa',
        'KR' => 'Günorta Koreýa',
        'KW' => 'Kuweýt',
        'KY' => 'Kaýman adalary',
        'KZ' => 'Gazagystan',
        'LA' => 'Laos',
        'LB' => 'Liwan',
        'LC' => 'Sent-Lýusiýa',
        'LI' => 'Lihtenşteýn',
        'LK' => 'Şri-Lanka',
        'LR' => 'Liberiýa',
        'LS' => 'Lesoto',
        'LT' => 'Litwa',
        'LU' => 'Lýuksemburg',
        'LV' => 'Latwiýa',
        'LY' => 'Liwiýa',
        'MA' => 'Marokko',
        'MC' => 'Monako',
        'MD' => 'Moldowa',
        'ME' => 'Çernogoriýa',
        'MF' => 'Sen-Marten',
        'MG' => 'Madagaskar',
        'MH' => 'Marşall adalary',
        'MK' => 'Demirgazyk Makedoniýa',
        'ML' => 'Mali',
        'MM' => 'Mýanma (Birma)',
        'MN' => 'Mongoliýa',
        'MO' => 'Makao AAS Hytaý',
        'MP' => 'Demirgazyk Mariana adalary',
        'MQ' => 'Martinika',
        'MR' => 'Mawritaniýa',
        'MS' => 'Monserrat',
        'MT' => 'Malta',
        'MU' => 'Mawrikiý',
        'MV' => 'Maldiwler',
        'MW' => 'Malawi',
        'MX' => 'Meksika',
        'MY' => 'Malaýziýa',
        'MZ' => 'Mozambik',
        'NA' => 'Namibiýa',
        'NC' => 'Täze Kaledoniýa',
        'NE' => 'Niger',
        'NF' => 'Norfolk adasy',
        'NG' => 'Nigeriýa',
        'NI' => 'Nikaragua',
        'NL' => 'Niderlandlar',
        'NO' => 'Norwegiýa',
        'NP' => 'Nepal',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'Täze Zelandiýa',
        'OM' => 'Oman',
        'PA' => 'Panama',
        'PE' => 'Peru',
        'PF' => 'Fransuz Polineziýasy',
        'PG' => 'Papua - Täze Gwineýa',
        'PH' => 'Filippinler',
        'PK' => 'Pakistan',
        'PL' => 'Polşa',
        'PM' => 'Sen-Pýer we Mikelon',
        'PN' => 'Pitkern adalary',
        'PR' => 'Puerto-Riko',
        'PS' => 'Palestina territoriýasy',
        'PT' => 'Portugaliýa',
        'PW' => 'Palau',
        'PY' => 'Paragwaý',
        'QA' => 'Katar',
        'RE' => 'Reýunýon',
        'RO' => 'Rumyniýa',
        'RS' => 'Serbiýa',
        'RU' => 'Russiýa',
        'RW' => 'Ruanda',
        'SA' => 'Saud Arabystany',
        'SB' => 'Solomon adalary',
        'SC' => 'Seýşel adalary',
        'SD' => 'Sudan',
        'SE' => 'Şwesiýa',
        'SG' => 'Singapur',
        'SH' => 'Keramatly Ýelena adasy',
        'SI' => 'Sloweniýa',
        'SJ' => 'Şpisbergen we Ýan-Maýen',
        'SK' => 'Slowakiýa',
        'SL' => 'Sýerra-Leone',
        'SM' => 'San-Marino',
        'SN' => 'Senegal',
        'SO' => 'Somali',
        'SR' => 'Surinam',
        'SS' => 'Günorta Sudan',
        'ST' => 'San-Tome we Prinsipi',
        'SV' => 'Salwador',
        'SX' => 'Sint-Marten',
        'SY' => 'Siriýa',
        'SZ' => 'Eswatini',
        'TC' => 'Terks we Kaýkos adalary',
        'TD' => 'Çad',
        'TF' => 'Fransuz günorta territoriýalary',
        'TG' => 'Togo',
        'TH' => 'Taýland',
        'TJ' => 'Täjigistan',
        'TK' => 'Tokelau',
        'TL' => 'Timor-Leste',
        'TM' => 'Türkmenistan',
        'TN' => 'Tunis',
        'TO' => 'Tonga',
        'TR' => 'Türkiýe',
        'TT' => 'Trinidad we Tobago',
        'TV' => 'Tuwalu',
        'TW' => 'Taýwan',
        'TZ' => 'Tanzaniýa',
        'UA' => 'Ukraina',
        'UG' => 'Uganda',
        'UM' => 'ABŞ-nyň daşarky adalary',
        'US' => 'Amerikanyň Birleşen Ştatlary',
        'UY' => 'Urugwaý',
        'UZ' => 'Özbegistan',
        'VA' => 'Watikan',
        'VC' => 'Sent-Winsent we Grenadinler',
        'VE' => 'Wenesuela',
        'VG' => 'Britan Wirgin adalary',
        'VI' => 'ABŞ-nyň Wirgin adalary',
        'VN' => 'Wýetnam',
        'VU' => 'Wanuatu',
        'WF' => 'Uollis we Futuna',
        'WS' => 'Samoa',
        'YE' => 'Ýemen',
        'YT' => 'Maýotta',
        'ZA' => 'Günorta Afrika',
        'ZM' => 'Zambiýa',
        'ZW' => 'Zimbabwe',
    ],
];
