<?php

return [
    '🇦🇨' => 'ala: Girava Ascensionê',
    '🇦🇩' => 'ala: Andorra',
    '🇦🇪' => 'ala: Mîrgehên Erebî yên Yekbûyî',
    '🇦🇫' => 'ala: Efxanistan',
    '🇦🇬' => 'ala: Antîgua û Berbûda',
    '🇦🇮' => 'ala: Anguîla',
    '🇦🇱' => 'ala: Albanya',
    '🇦🇲' => 'ala: Ermenistan',
    '🇦🇴' => 'ala: Angola',
    '🇦🇶' => 'ala: Antarktîka',
    '🇦🇷' => 'ala: Arjantîn',
    '🇦🇸' => 'ala: Samoaya Amerîkanî',
    '🇦🇹' => 'ala: Awistirya',
    '🇦🇺' => 'ala: Awistralya',
    '🇦🇼' => 'ala: Arûba',
    '🇦🇽' => 'ala: Giravên Alandê',
    '🇦🇿' => 'ala: Azerbeycan',
    '🇧🇦' => 'ala: Bosna û Hersek',
    '🇧🇧' => 'ala: Barbados',
    '🇧🇩' => 'ala: Bengladeş',
    '🇧🇪' => 'ala: Belçîka',
    '🇧🇫' => 'ala: Burkîna Faso',
    '🇧🇬' => 'ala: Bulgaristan',
    '🇧🇭' => 'ala: Behreyn',
    '🇧🇮' => 'ala: Bûrûndî',
    '🇧🇯' => 'ala: Bênîn',
    '🇧🇱' => 'ala: Saint Barthelemy',
    '🇧🇲' => 'ala: Bermûda',
    '🇧🇳' => 'ala: Brûney',
    '🇧🇴' => 'ala: Bolîvya',
    '🇧🇶' => 'ala: Holendaya Karayîbê',
    '🇧🇷' => 'ala: Brezîlya',
    '🇧🇸' => 'ala: Bahama',
    '🇧🇹' => 'ala: Bûtan',
    '🇧🇻' => 'ala: Girava Bouvetê',
    '🇧🇼' => 'ala: Botswana',
    '🇧🇾' => 'ala: Belarûs',
    '🇧🇿' => 'ala: Belîze',
    '🇨🇦' => 'ala: Kanada',
    '🇨🇨' => 'ala: Giravên Kokosê (Keeling)',
    '🇨🇩' => 'ala: Kongo - Kînşasa',
    '🇨🇫' => 'ala: Cimhûrîyeta Afrîkaya Navîn',
    '🇨🇬' => 'ala: Kongo - Brazzaville',
    '🇨🇭' => 'ala: Swîsre',
    '🇨🇮' => 'ala: Côte d’Ivoire',
    '🇨🇰' => 'ala: Giravên Cookê',
    '🇨🇱' => 'ala: Şîlî',
    '🇨🇲' => 'ala: Kamerûn',
    '🇨🇳' => 'ala: Çîn',
    '🇨🇴' => 'ala: Kolombîya',
    '🇨🇵' => 'ala: Girava Clippertonê',
    '🇨🇶' => 'ala: Sark',
    '🇨🇷' => 'ala: Kosta Rîka',
    '🇨🇺' => 'ala: Kuba',
    '🇨🇻' => 'ala: Kap Verde',
    '🇨🇼' => 'ala: Curaçao',
    '🇨🇽' => 'ala: Girava Christmasê',
    '🇨🇾' => 'ala: Qibris',
    '🇨🇿' => 'ala: Çekya',
    '🇩🇪' => 'ala: Almanya',
    '🇩🇬' => 'ala: Diego Garcia',
    '🇩🇯' => 'ala: Cîbûtî',
    '🇩🇰' => 'ala: Danîmarka',
    '🇩🇲' => 'ala: Domînîka',
    '🇩🇴' => 'ala: Cimhûrîyeta Domînîkê',
    '🇩🇿' => 'ala: Cezayîr',
    '🇪🇦' => 'ala: Ceuta û Melîla',
    '🇪🇨' => 'ala: Ekwador',
    '🇪🇪' => 'ala: Estonya',
    '🇪🇬' => 'ala: Misir',
    '🇪🇭' => 'ala: Sahraya Rojava',
    '🇪🇷' => 'ala: Erître',
    '🇪🇸' => 'ala: Spanya',
    '🇪🇹' => 'ala: Etîyopya',
    '🇪🇺' => 'ala: Yekîtîya Ewropayê',
    '🇫🇮' => 'ala: Fînlenda',
    '🇫🇯' => 'ala: Fîjî',
    '🇫🇰' => 'ala: Giravên Falklandê',
    '🇫🇲' => 'ala: Mîkronezya',
    '🇫🇴' => 'ala: Giravên Faroeyê',
    '🇫🇷' => 'ala: Fransa',
    '🇬🇦' => 'ala: Gabon',
    '🇬🇧' => 'ala: Qiralîyeta Yekbûyî',
    '🇬🇩' => 'ala: Grenada',
    '🇬🇪' => 'ala: Gurcistan',
    '🇬🇫' => 'ala: Guyanaya Fransî',
    '🇬🇬' => 'ala: Guernsey',
    '🇬🇭' => 'ala: Gana',
    '🇬🇮' => 'ala: Cebelîtariq',
    '🇬🇱' => 'ala: Grînlanda',
    '🇬🇲' => 'ala: Gambîya',
    '🇬🇳' => 'ala: Gîne',
    '🇬🇵' => 'ala: Guadeloupe',
    '🇬🇶' => 'ala: Gîneya Ekwadorê',
    '🇬🇷' => 'ala: Yûnanistan',
    '🇬🇸' => 'ala: Giravên Georgîyaya Başûr û Sandwicha Başûr',
    '🇬🇹' => 'ala: Guatemala',
    '🇬🇺' => 'ala: Guam',
    '🇬🇼' => 'ala: Gîne-Bissau',
    '🇬🇾' => 'ala: Guyana',
    '🇭🇰' => 'ala: Hong Konga HîT ya Çînê',
    '🇭🇲' => 'ala: Giravên Heard û MacDonaldê',
    '🇭🇳' => 'ala: Hondûras',
    '🇭🇷' => 'ala: Xirwatistan',
    '🇭🇹' => 'ala: Haîtî',
    '🇭🇺' => 'ala: Macaristan',
    '🇮🇨' => 'ala: Giravên Kanaryayê',
    '🇮🇩' => 'ala: Endonezya',
    '🇮🇪' => 'ala: Îrlanda',
    '🇮🇱' => 'ala: Îsraîl',
    '🇮🇲' => 'ala: Girava Manê',
    '🇮🇳' => 'ala: Hindistan',
    '🇮🇴' => 'ala: Herêma Okyanûsa Hindî ya Brîtanyayê',
    '🇮🇶' => 'ala: Îraq',
    '🇮🇷' => 'ala: Îran',
    '🇮🇸' => 'ala: Îslanda',
    '🇮🇹' => 'ala: Îtalya',
    '🇯🇪' => 'ala: Jersey',
    '🇯🇲' => 'ala: Jamaîka',
    '🇯🇴' => 'ala: Urdun',
    '🇯🇵' => 'ala: Japonya',
    '🇰🇪' => 'ala: Kenya',
    '🇰🇬' => 'ala: Qirgizistan',
    '🇰🇭' => 'ala: Kamboçya',
    '🇰🇮' => 'ala: Kirîbatî',
    '🇰🇲' => 'ala: Komor',
    '🇰🇳' => 'ala: Saint Kitts û Nevîs',
    '🇰🇵' => 'ala: Koreya Bakur',
    '🇰🇷' => 'ala: Koreya Başûr',
    '🇰🇼' => 'ala: Kuweyt',
    '🇰🇾' => 'ala: Giravên Kaymanê',
    '🇰🇿' => 'ala: Qazaxistan',
    '🇱🇦' => 'ala: Laos',
    '🇱🇧' => 'ala: Libnan',
    '🇱🇨' => 'ala: Saint Lucia',
    '🇱🇮' => 'ala: Liechtenstein',
    '🇱🇰' => 'ala: Srî Lanka',
    '🇱🇷' => 'ala: Lîberya',
    '🇱🇸' => 'ala: Lesoto',
    '🇱🇹' => 'ala: Lîtvanya',
    '🇱🇺' => 'ala: Luksembûrg',
    '🇱🇻' => 'ala: Letonya',
    '🇱🇾' => 'ala: Lîbya',
    '🇲🇦' => 'ala: Fas',
    '🇲🇨' => 'ala: Monako',
    '🇲🇩' => 'ala: Moldova',
    '🇲🇪' => 'ala: Qeredax',
    '🇲🇫' => 'ala: Saint Martin',
    '🇲🇬' => 'ala: Madagaskar',
    '🇲🇭' => 'ala: Giravên Marşalê',
    '🇲🇰' => 'ala: Makedonyaya Bakur',
    '🇲🇱' => 'ala: Malî',
    '🇲🇲' => 'ala: Myanmar (Bûrma)',
    '🇲🇳' => 'ala: Moxolistan',
    '🇲🇴' => 'ala: Makaoya Hît ya Çînê',
    '🇲🇵' => 'ala: Giravên Bakurê Marianan',
    '🇲🇶' => 'ala: Martînîk',
    '🇲🇷' => 'ala: Morîtanya',
    '🇲🇸' => 'ala: Montserat',
    '🇲🇹' => 'ala: Malta',
    '🇲🇺' => 'ala: Mauritius',
    '🇲🇻' => 'ala: Maldîv',
    '🇲🇼' => 'ala: Malawî',
    '🇲🇽' => 'ala: Meksîka',
    '🇲🇾' => 'ala: Malezya',
    '🇲🇿' => 'ala: Mozambîk',
    '🇳🇦' => 'ala: Namîbya',
    '🇳🇨' => 'ala: Kaledonyaya Nû',
    '🇳🇪' => 'ala: Nîjer',
    '🇳🇫' => 'ala: Girava Norfolkê',
    '🇳🇬' => 'ala: Nîjerya',
    '🇳🇮' => 'ala: Nîkaragua',
    '🇳🇱' => 'ala: Holanda',
    '🇳🇴' => 'ala: Norwec',
    '🇳🇵' => 'ala: Nepal',
    '🇳🇷' => 'ala: Naûrû',
    '🇳🇺' => 'ala: Niûe',
    '🇳🇿' => 'ala: Zelandaya Nû',
    '🇴🇲' => 'ala: Uman',
    '🇵🇦' => 'ala: Panama',
    '🇵🇪' => 'ala: Perû',
    '🇵🇫' => 'ala: Polînezyaya Fransizî',
    '🇵🇬' => 'ala: Papua Gîneya Nû',
    '🇵🇭' => 'ala: Fîlîpîn',
    '🇵🇰' => 'ala: Pakistan',
    '🇵🇱' => 'ala: Polonya',
    '🇵🇲' => 'ala: Saint-Pierre û Miquelon',
    '🇵🇳' => 'ala: Giravên Pitcairnê',
    '🇵🇷' => 'ala: Porto Rîko',
    '🇵🇸' => 'ala: Herêmên Filistînî',
    '🇵🇹' => 'ala: Portugal',
    '🇵🇼' => 'ala: Palau',
    '🇵🇾' => 'ala: Paragûay',
    '🇶🇦' => 'ala: Qeter',
    '🇷🇪' => 'ala: Réunion',
    '🇷🇴' => 'ala: Romanya',
    '🇷🇸' => 'ala: Sirbistan',
    '🇷🇺' => 'ala: Rûsya',
    '🇷🇼' => 'ala: Rwanda',
    '🇸🇦' => 'ala: Erebistana Siûdî',
    '🇸🇧' => 'ala: Giravên Solomonê',
    '🇸🇨' => 'ala: Seyşel',
    '🇸🇩' => 'ala: Sûdan',
    '🇸🇪' => 'ala: Swêd',
    '🇸🇬' => 'ala: Sîngapûr',
    '🇸🇭' => 'ala: Saint Helena',
    '🇸🇮' => 'ala: Slovenya',
    '🇸🇯' => 'ala: Svalbard û Jan Mayen',
    '🇸🇰' => 'ala: Slovakya',
    '🇸🇱' => 'ala: Sierra Leone',
    '🇸🇲' => 'ala: San Marîno',
    '🇸🇳' => 'ala: Senegal',
    '🇸🇴' => 'ala: Somalya',
    '🇸🇷' => 'ala: Surînam',
    '🇸🇸' => 'ala: Sûdana Başûr',
    '🇸🇹' => 'ala: Sao Tome û Prînsîpe',
    '🇸🇻' => 'ala: El Salvador',
    '🇸🇽' => 'ala: Sint Marteen',
    '🇸🇾' => 'ala: Sûrîye',
    '🇸🇿' => 'ala: Eswatînî',
    '🇹🇦' => 'ala: Tristan da Cunha',
    '🇹🇨' => 'ala: Giravên Turks û Kaîkosê',
    '🇹🇩' => 'ala: Çad',
    '🇹🇫' => 'ala: Herêmên Başûr ên Fransayê',
    '🇹🇬' => 'ala: Togo',
    '🇹🇭' => 'ala: Tayland',
    '🇹🇯' => 'ala: Tacikistan',
    '🇹🇰' => 'ala: Tokelau',
    '🇹🇱' => 'ala: Tîmor-Leste',
    '🇹🇲' => 'ala: Tirkmenistan',
    '🇹🇳' => 'ala: Tûnis',
    '🇹🇴' => 'ala: Tonga',
    '🇹🇷' => 'ala: Türkiye',
    '🇹🇹' => 'ala: Trînîdad û Tobago',
    '🇹🇻' => 'ala: Tûvalû',
    '🇹🇼' => 'ala: Taywan',
    '🇹🇿' => 'ala: Tanzanya',
    '🇺🇦' => 'ala: Ûkrayna',
    '🇺🇬' => 'ala: Ûganda',
    '🇺🇲' => 'ala: Giravên Biçûk ên Derveyî DAYê',
    '🇺🇳' => 'ala: Miletên Yekbûyî',
    '🇺🇸' => 'ala: Dewletên Amerîkayê yên Yekbûyî',
    '🇺🇾' => 'ala: Ûrûguay',
    '🇺🇿' => 'ala: Ozbekistan',
    '🇻🇦' => 'ala: Vatîkan',
    '🇻🇨' => 'ala: Saint Vincent û Giravên Grenadînê',
    '🇻🇪' => 'ala: Venezuela',
    '🇻🇬' => 'ala: Giravên Vîrjînê yên Brîtanyayê',
    '🇻🇮' => 'ala: Giravên Vîrjînê yên Amerîkayê',
    '🇻🇳' => 'ala: Vîetnam',
    '🇻🇺' => 'ala: Vanûatû',
    '🇼🇫' => 'ala: Wallis û Futuna',
    '🇼🇸' => 'ala: Samoa',
    '🇽🇰' => 'ala: Kosova',
    '🇾🇪' => 'ala: Yemen',
    '🇾🇹' => 'ala: Mayotte',
    '🇿🇦' => 'ala: Afrîkaya Başûr',
    '🇿🇲' => 'ala: Zambîya',
    '🇿🇼' => 'ala: Zîmbabwe',
    '🧒' => 'zarok',
    '👧' => 'keç',
    '🧑' => 'kes',
    '👨' => 'mêr',
    '👩' => 'jin',
    '🐵' => 'rûyê meymûnê',
    '🐒' => 'meymûn',
    '🦍' => 'gorîl',
    '🐶' => 'rûyê kûçikê',
    '🐕' => 'kûçik',
    '🐺' => 'gur',
    '🦊' => 'rovî',
    '🐈' => 'pisîk',
    '🦁' => 'şêr',
    '🫏' => 'ker',
    '🐎' => 'hesp',
    '🦓' => 'zebra',
    '🐂' => 'ga',
    '🐄' => 'çêl',
    '🐖' => 'beraz',
    '🐏' => 'beran',
    '🐑' => 'mih',
    '🐐' => 'bizin',
    '🐪' => 'hêştir',
    '🦙' => 'lama',
    '🐘' => 'fîl',
    '🐁' => 'mişk',
    '🐻' => 'hirç',
    '🐼' => 'panda',
    '🦃' => 'elok',
    '🐔' => 'mirîşk',
    '🐓' => 'dîk',
    '🐸' => 'beq',
    '🐢' => 'kûsî',
    '🐍' => 'mar',
    '🐟' => 'masî',
    '🍇' => 'tirî',
    '🍉' => 'zebeş',
    '🍋' => 'lîmon',
    '🍌' => 'mûz',
    '🥭' => 'mango',
    '🍎' => 'sêva sor',
    '🍏' => 'sêva kesk',
    '🍐' => 'hirmî',
    '🍑' => 'xox',
    '🍒' => 'gêraz',
    '🍅' => 'firengî',
    '🥥' => 'giwêza hindê',
    '🥑' => 'avokado',
    '🍆' => 'balîcan',
    '🥔' => 'kartol',
];
