<?php

return [
    '👩‍❤‍💋‍👨' => 'poton: femna e òme',
    '👨‍❤‍💋‍👨' => 'poton: òme e òme',
    '👩‍❤‍💋‍👩' => 'poton: femna e femna',
    '👨‍👩‍👧‍👦' => 'familha: òme, femna, dròlla e dròlle',
    '👨‍👩‍👦‍👦' => 'familha: òme, femna, dròlle e dròlle',
    '👨‍👩‍👧‍👧' => 'familha: òme, femna, dròlla e dròlla',
    '👨‍👨‍👧‍👦' => 'familha: òme, òme, dròlla e dròlle',
    '👨‍👨‍👦‍👦' => 'familha: òme, òme, dròlle e dròlle',
    '👨‍👨‍👧‍👧' => 'familha: òme, òme, dròlla e dròlla',
    '👩‍👩‍👧‍👦' => 'familha: femna, femna, dròlla e dròlle',
    '👩‍👩‍👦‍👦' => 'familha: femna, femna, dròlle e dròlle',
    '👩‍👩‍👧‍👧' => 'familha: femna, femna, dròlla e dròlla',
    '👨‍👩‍👦' => 'familha: òme, femna e dròlle',
    '👨‍👩‍👧' => 'familha: òme, femna e dròlla',
    '👨‍👨‍👦' => 'familha: òme, òme e dròlle',
    '👨‍👨‍👧' => 'familha: òme, òme e dròlla',
    '👩‍👩‍👦' => 'familha: femna, femna e dròlle',
    '👩‍👩‍👧' => 'familha: femna, femna e dròlla',
    '👨‍👦‍👦' => 'familha: òme, dròlle e dròlle',
    '👨‍👧‍👦' => 'familha: òme, dròlla e dròlle',
    '👨‍👧‍👧' => 'familha: òme, dròlla e dròlla',
    '👩‍👦‍👦' => 'familha: femna, dròlle e dròlle',
    '👩‍👧‍👦' => 'familha: femna, dròlla e dròlle',
    '👩‍👧‍👧' => 'familha: femna, dròlla e dròlla',
    '👨‍👦' => 'familha: òme e dròlle',
    '👨‍👧' => 'familha: òme e dròlla',
    '👩‍👦' => 'familha: femna e dròlle',
    '👩‍👧' => 'familha: femna e dròlla',
    '❤‍🔥' => 'còr en fòc',
    '🧑‍🎓' => 'estudiant',
    '🧑‍🏫' => 'professor',
    '🧑‍⚖' => 'jutge',
    '🧑‍🌾' => 'pagès',
    '🧑‍🔧' => 'mecanician',
    '👨‍🔧' => 'mecanician (òme)',
    '👩‍🔧' => 'mecaniciana',
    '🧑‍🔬' => 'scientific',
    '🧑‍🎤' => 'cantaire',
    '🧑‍🚀' => 'astronauta',
    '🧑‍🚒' => 'pompièr',
    '🧚‍♂' => 'fada (òme)',
    '🧚‍♀' => 'fada (femna)',
    '🐈‍⬛' => 'cat negre',
    '🇦🇨' => 'bandièra: Isla Ascension',
    '🇦🇩' => 'bandièra: Andòrra',
    '🇦🇪' => 'bandièra: Emirats Arabs Units',
    '🇦🇫' => 'bandièra: Afganistan',
    '🇦🇬' => 'bandièra: Antigua e Barbuda',
    '🇦🇮' => 'bandièra: Anguilla',
    '🇦🇱' => 'bandièra: Albania',
    '🇦🇲' => 'bandièra: Armenia',
    '🇦🇴' => 'bandièra: Angòla',
    '🇦🇶' => 'bandièra: Antartica',
    '🇦🇷' => 'bandièra: Argentina',
    '🇦🇸' => 'bandièra: Samoa americana',
    '🇦🇹' => 'bandièra: Àustria',
    '🇦🇺' => 'bandièra: Austràlia',
    '🇦🇼' => 'bandièra: Aruba',
    '🇦🇽' => 'bandièra: llas Åland',
    '🇦🇿' => 'bandièra: Azerbaijan',
    '🇧🇦' => 'bandièra: Bòsnia e Ercegovina',
    '🇧🇧' => 'bandièra: Barbados',
    '🇧🇩' => 'bandièra: Bangladesh',
    '🇧🇪' => 'bandièra: Belgica',
    '🇧🇫' => 'bandièra: Burkina Faso',
    '🇧🇬' => 'bandièra: Bolgària',
    '🇧🇭' => 'bandièra: Barain',
    '🇧🇮' => 'bandièra: Burundi',
    '🇧🇯' => 'bandièra: Benin',
    '🇧🇱' => 'bandièra: Sant Bertomiu',
    '🇧🇲' => 'bandièra: Bermuda',
    '🇧🇳' => 'bandièra: Brunei',
    '🇧🇴' => 'bandièra: Bolívia',
    '🇧🇶' => 'bandièra: Païses Basses caribèus',
    '🇧🇷' => 'bandièra: Brasil',
    '🇧🇸' => 'bandièra: Bahamas',
    '🇧🇹' => 'bandièra: Botan',
    '🇧🇻' => 'bandièra: Isla Bouvet',
    '🇧🇼' => 'bandièra: Botswana',
    '🇧🇾' => 'bandièra: Bielorussia',
    '🇧🇿' => 'bandièra: Belize',
    '🇨🇦' => 'bandièra: Canadà',
    '🇨🇨' => 'bandièra: Illas Còcos',
    '🇨🇩' => 'bandièra: Còngo de Kinshasa',
    '🇨🇫' => 'bandièra: Republica Centraficana',
    '🇨🇬' => 'bandièra: Còngo de Brazzavila',
    '🇨🇭' => 'bandièra: Soïssa',
    '🇨🇮' => 'bandièra: Còsta d’Evòri',
    '🇨🇰' => 'bandièra: Illas Cook',
    '🇨🇱' => 'bandièra: Chile',
    '🇨🇲' => 'bandièra: Cameron',
    '🇨🇳' => 'bandièra: China',
    '🇨🇴' => 'bandièra: Colómbia',
    '🇨🇵' => 'bandièra: Iscla Clipperton',
    '🇨🇷' => 'bandièra: Còsta Rica',
    '🇨🇺' => 'bandièra: Cuba',
    '🇨🇻' => 'bandièra: Cap Verd',
    '🇨🇼' => 'bandièra: Curaçao',
    '🇨🇽' => 'bandièra: Illa Christmas',
    '🇨🇾' => 'bandièra: Chipre',
    '🇨🇿' => 'bandièra: Chequia',
    '🇩🇪' => 'bandièra: Alemanha',
    '🇩🇬' => 'bandièra: Diego Garcia',
    '🇩🇯' => 'bandièra: Jiboti',
    '🇩🇰' => 'bandièra: Danemarc',
    '🇩🇲' => 'bandièra: Dominica',
    '🇩🇴' => 'bandièra: Republica dominicana',
    '🇩🇿' => 'bandièra: Argeria',
    '🇪🇦' => 'bandièra: Ceuta e Melilha',
    '🇪🇨' => 'bandièra: Eqüator',
    '🇪🇪' => 'bandièra: Estònia',
    '🇪🇬' => 'bandièra: Egipte',
    '🇪🇭' => 'bandièra: Saharà occidental',
    '🇪🇷' => 'bandièra: Eritrèa',
    '🇪🇸' => 'bandièra: Espanha',
    '🇪🇹' => 'bandièra: Etiopia',
    '🇪🇺' => 'bandièra: Union Europèa',
    '🇫🇮' => 'bandièra: Finlàndia',
    '🇫🇯' => 'bandièra: Fiji',
    '🇫🇰' => 'bandièra: Isclas Falkland',
    '🇫🇲' => 'bandièra: Micronesia',
    '🇫🇴' => 'bandièra: Illas Feròe',
    '🇫🇷' => 'bandièra: França',
    '🇬🇦' => 'bandièra: Gabon',
    '🇬🇧' => 'bandièra: Reiaume Unit',
    '🇬🇩' => 'bandièra: Grenada',
    '🇬🇪' => 'bandièra: Geòrgia',
    '🇬🇫' => 'bandièra: Guiana francesa',
    '🇬🇬' => 'bandièra: Guernsey',
    '🇬🇭' => 'bandièra: Ganà',
    '🇬🇮' => 'bandièra: Gibartar',
    '🇬🇱' => 'bandièra: Groenlàndia',
    '🇬🇲' => 'bandièra: Gàmbia',
    '🇬🇳' => 'bandièra: Guinèa',
    '🇬🇵' => 'bandièra: Guadalope',
    '🇬🇶' => 'bandièra: Guinèa Eqüatoriala',
    '🇬🇷' => 'bandièra: Grècia',
    '🇬🇸' => 'bandièra: Georgie del Sud e les Illes Sandwich del Sud',
    '🇬🇹' => 'bandièra: Guatemala',
    '🇬🇺' => 'bandièra: Guam',
    '🇬🇼' => 'bandièra: Guinèa-Bissau',
    '🇬🇾' => 'bandièra: Guianà',
    '🇭🇰' => 'bandièra: Hong Kong',
    '🇭🇲' => 'bandièra: Illas Heard e McDonald',
    '🇭🇳' => 'bandièra: Onduras',
    '🇭🇷' => 'bandièra: Croàcia',
    '🇭🇹' => 'bandièra: Haití',
    '🇭🇺' => 'bandièra: Ongria',
    '🇮🇨' => 'bandièra: Isclas Canàrias',
    '🇮🇩' => 'bandièra: Indonesia',
    '🇮🇪' => 'bandièra: Irlanda',
    '🇮🇱' => 'bandièra: Israèl',
    '🇮🇲' => 'bandièra: Illa de Man',
    '🇮🇳' => 'bandièra: Índia',
    '🇮🇴' => 'bandièra: Territòri Britanic de l’Ocean Indian',
    '🇮🇶' => 'bandièra: Iraq',
    '🇮🇷' => 'bandièra: Iran',
    '🇮🇸' => 'bandièra: Islàndia',
    '🇮🇹' => 'bandièra: Itàlia',
    '🇯🇪' => 'bandièra: Jersey',
    '🇯🇲' => 'bandièra: Jamaïca',
    '🇯🇴' => 'bandièra: Jordania',
    '🇯🇵' => 'bandièra: Japon',
    '🇰🇪' => 'bandièra: Kenya',
    '🇰🇬' => 'bandièra: Kirguizstan',
    '🇰🇭' => 'bandièra: Cambòja',
    '🇰🇮' => 'bandièra: Kiribatí',
    '🇰🇲' => 'bandièra: Comòras',
    '🇰🇳' => 'bandièra: Sant Kitts e Nevis',
    '🇰🇵' => 'bandièra: Corèa del Nòrd',
    '🇰🇷' => 'bandièra: Corèa del Sud',
    '🇰🇼' => 'bandièra: Kowait',
    '🇰🇾' => 'bandièra: Islas Caiman',
    '🇰🇿' => 'bandièra: Cazacstan',
    '🇱🇦' => 'bandièra: Laos',
    '🇱🇧' => 'bandièra: Liban',
    '🇱🇨' => 'bandièra: Santa Lucia',
    '🇱🇮' => 'bandièra: Liechtenstein',
    '🇱🇰' => 'bandièra: Sri Lanka',
    '🇱🇷' => 'bandièra: Liberià',
    '🇱🇸' => 'bandièra: Lesotho',
    '🇱🇹' => 'bandièra: Lituània',
    '🇱🇺' => 'bandièra: Luxemborg',
    '🇱🇻' => 'bandièra: Letònia',
    '🇱🇾' => 'bandièra: Libia',
    '🇲🇦' => 'bandièra: Marròc',
    '🇲🇨' => 'bandièra: Mónegue',
    '🇲🇩' => 'bandièra: Moldàvia',
    '🇲🇪' => 'bandièra: Montenegro',
    '🇲🇫' => 'bandièra: St. Martin',
    '🇲🇬' => 'bandièra: Madagascar',
    '🇲🇭' => 'bandièra: Illas Marshall',
    '🇲🇰' => 'bandièra: Macedónia del Nòrd',
    '🇲🇱' => 'bandièra: Mali',
    '🇲🇲' => 'bandièra: Birmania',
    '🇲🇳' => 'bandièra: Mongolia',
    '🇲🇴' => 'bandièra: Macau',
    '🇲🇵' => 'bandièra: Illas Mariannas del Nòrd',
    '🇲🇶' => 'bandièra: Martinica',
    '🇲🇷' => 'bandièra: Mauritània',
    '🇲🇸' => 'bandièra: Montserrat',
    '🇲🇹' => 'bandièra: Malta',
    '🇲🇺' => 'bandièra: Maurici',
    '🇲🇻' => 'bandièra: Maldivas',
    '🇲🇼' => 'bandièra: Malavi',
    '🇲🇽' => 'bandièra: Mexic',
    '🇲🇾' => 'bandièra: Malàisia',
    '🇲🇿' => 'bandièra: Moçambic',
    '🇳🇦' => 'bandièra: Namibia',
    '🇳🇨' => 'bandièra: Nòva Caledonia',
    '🇳🇪' => 'bandièra: Nigèr',
    '🇳🇫' => 'bandièra: Illas Norfòlk',
    '🇳🇬' => 'bandièra: Nigèria',
    '🇳🇮' => 'bandièra: Nicaragüa',
    '🇳🇱' => 'bandièra: Païses Basses',
    '🇳🇴' => 'bandièra: Norvègia',
    '🇳🇵' => 'bandièra: Nepal',
    '🇳🇷' => 'bandièra: Nauru',
    '🇳🇺' => 'bandièra: Niue',
    '🇳🇿' => 'bandièra: Nòva Zelanda',
    '🇴🇲' => 'bandièra: Òman',
    '🇵🇦' => 'bandièra: Panamà',
    '🇵🇪' => 'bandièra: Peró',
    '🇵🇫' => 'bandièra: Polinesia francesa',
    '🇵🇬' => 'bandièra: Papoa-Nòva Guinèa',
    '🇵🇭' => 'bandièra: Filipinas',
    '🇵🇰' => 'bandièra: Paquistan',
    '🇵🇱' => 'bandièra: Polonha',
    '🇵🇲' => 'bandièra: Sant Pèire e Miquelon',
    '🇵🇳' => 'bandièra: Iscla Pitcairn',
    '🇵🇷' => 'bandièra: Puerto Rico',
    '🇵🇸' => 'bandièra: Territòris palestinians',
    '🇵🇹' => 'bandièra: Portugal',
    '🇵🇼' => 'bandièra: Belau',
    '🇵🇾' => 'bandièra: Paraguai',
    '🇶🇦' => 'bandièra: Catar',
    '🇷🇪' => 'bandièra: Reünion',
    '🇷🇴' => 'bandièra: Romania',
    '🇷🇸' => 'bandièra: Serbia',
    '🇷🇺' => 'bandièra: Russia',
    '🇷🇼' => 'bandièra: Roanda',
    '🇸🇦' => 'bandièra: Arabia Saudita',
    '🇸🇧' => 'bandièra: Illas Salamon',
    '🇸🇨' => 'bandièra: Seissèlas',
    '🇸🇩' => 'bandièra: Sodan',
    '🇸🇪' => 'bandièra: Suècia',
    '🇸🇬' => 'bandièra: Singapor',
    '🇸🇭' => 'bandièra: Santa Elena',
    '🇸🇮' => 'bandièra: Eslovènia',
    '🇸🇯' => 'bandièra: Svalbard e Jan Mayen',
    '🇸🇰' => 'bandièra: Eslovaquia',
    '🇸🇱' => 'bandièra: Sierra Leone',
    '🇸🇲' => 'bandièra: Sant Marin',
    '🇸🇳' => 'bandièra: Senegal',
    '🇸🇴' => 'bandièra: Somalia',
    '🇸🇷' => 'bandièra: Surinam',
    '🇸🇸' => 'bandièra: Sodan del Sud',
    '🇸🇹' => 'bandièra: Sant Tomàs e Prince',
    '🇸🇻' => 'bandièra: Lo Salvador',
    '🇸🇽' => 'bandièra: Sant Martin',
    '🇸🇾' => 'bandièra: Súria',
    '🇸🇿' => 'bandièra: Eswatini',
    '🇹🇦' => 'bandièra: Tristan da Cunha',
    '🇹🇨' => 'bandièra: Illas Turcas e Caïcas',
    '🇹🇩' => 'bandièra: Chad',
    '🇹🇫' => 'bandièra: Territòris del Sud franceses',
    '🇹🇬' => 'bandièra: Tògo',
    '🇹🇭' => 'bandièra: Tailàndia',
    '🇹🇯' => 'bandièra: Tatgiquistan',
    '🇹🇰' => 'bandièra: Tokelau',
    '🇹🇱' => 'bandièra: Timòr Èst',
    '🇹🇲' => 'bandièra: Turcmenistan',
    '🇹🇳' => 'bandièra: Tunisia',
    '🇹🇴' => 'bandièra: Tònga',
    '🇹🇷' => 'bandièra: Turquia',
    '🇹🇹' => 'bandièra: Trinidad e Tobago',
    '🇹🇻' => 'bandièra: Tuvalu',
    '🇹🇼' => 'bandièra: Taiwan',
    '🇹🇿' => 'bandièra: Tanzania',
    '🇺🇦' => 'bandièra: Ucraïna',
    '🇺🇬' => 'bandièra: Oganda',
    '🇺🇳' => 'bandièra: Nacions Unidas',
    '🇺🇸' => 'bandièra: Estats Units',
    '🇺🇾' => 'bandièra: Uruguai',
    '🇺🇿' => 'bandièra: Ozbequistan',
    '🇻🇦' => 'bandièra: Ciutat del Vatican',
    '🇻🇨' => 'bandièra: St Vincent e Granadinas',
    '🇻🇪' => 'bandièra: Veneçuèla',
    '🇻🇬' => 'bandièra: Illas Verges britanicas',
    '🇻🇮' => 'bandièra: Illas Verges estatsunidencas',
    '🇻🇳' => 'bandièra: Vietnam',
    '🇻🇺' => 'bandièra: Vanuatú',
    '🇼🇫' => 'bandièra: Wallis e Futuna',
    '🇼🇸' => 'bandièra: Samoa',
    '🇽🇰' => 'bandièra: Kosova',
    '🇾🇪' => 'bandièra: Iémen',
    '🇾🇹' => 'bandièra: Maiòta',
    '🇿🇦' => 'bandièra: Africa del Sud',
    '🇿🇲' => 'bandièra: Zambia',
    '🇿🇼' => 'bandièra: Zimbabwe',
    '😂' => 'cara amb lagremas de jòia',
    '😷' => 'cara amb masqueta medicala',
    '💚' => 'còr verd',
    '👐' => 'mans dubèrtas',
    '💪' => 'bicèps contractats',
    '🦵' => 'camba',
    '🦶' => 'pè',
    '👂' => 'aurelha',
    '👃' => 'nas',
    '🧠' => 'cervèl',
    '🫁' => 'palmons',
    '🦷' => 'dent',
    '🦴' => 'òs',
    '👀' => 'uèlhs',
    '👁' => 'uèlh',
    '👅' => 'lenga',
    '👄' => 'boca',
    '👶' => 'nenet',
    '🧒' => 'enfant',
    '👦' => 'dròlle',
    '👧' => 'dròlla',
    '🧑' => 'persona',
    '👨' => 'òme',
    '👩' => 'femna',
    '👮' => 'policièr',
    '🕵' => 'detectiu',
    '🤴' => 'prince',
    '👸' => 'princessa',
    '🎅' => 'Paire Nadal',
    '🧚' => 'fada',
    '🧛' => 'vampire',
    '🧜' => 'serena',
    '🧞' => 'gèni',
    '💏' => 'poton',
    '👪' => 'familha',
    '🐶' => 'morre can',
    '🐕' => 'can',
    '🐺' => 'lop',
    '🦊' => 'rainal',
    '🐱' => 'cara cat',
    '🐈' => 'cat',
    '🦁' => 'leon',
    '🐯' => 'cara de tigre',
    '🐅' => 'tigre',
    '🐆' => 'leopard',
    '🐴' => 'morre caval',
    '🫏' => 'ase',
    '🐎' => 'chaval',
    '🦄' => 'unicòrn',
    '🦓' => 'zèbre',
    '🦌' => 'cèrvi',
    '🦬' => 'bison',
    '🐮' => 'cara de vaca',
    '🐄' => 'vaca',
    '🐷' => 'cara de tesson',
    '🐖' => 'tesson',
    '🐘' => 'elefant',
    '🐁' => 'mirga',
    '🐀' => 'rat',
    '🐻' => 'ors',
    '🐨' => 'coalà',
    '🐼' => 'panda',
    '🦘' => 'cangoró',
    '🦡' => 'tais',
    '🐦' => 'aucèl',
    '🦉' => 'chòt',
    '🦜' => 'papagai',
    '🪽' => 'ala',
    '🪿' => 'auca',
    '🐸' => 'granhòta',
    '🐟' => 'peis',
    '🪸' => 'coralh',
    '🪼' => 'carnmarina',
    '🦋' => 'parpalhon',
    '🐜' => 'formiga',
    '🦂' => 'escorpion',
    '💐' => 'flòc',
    '🌷' => 'tulipa',
    '🌴' => 'palmièr',
    '🌵' => 'cactus',
    '🍈' => 'melon',
    '🍉' => 'pastèca',
    '🍋' => 'citron',
    '🍌' => 'banana',
    '🍍' => 'ananàs',
    '🥭' => 'manga',
    '🍎' => 'poma roja',
    '🍏' => 'poma verda',
    '🍐' => 'pera',
    '🍑' => 'persèga',
    '🍒' => 'cerièras',
    '🍓' => 'fraga',
    '🫐' => 'avajon',
    '🍅' => 'tomata',
    '🫒' => 'oliva',
    '🥑' => 'avocat',
    '🧄' => 'alh',
    '🧅' => 'ceba',
    '🍞' => 'pan',
    '🥐' => 'banut',
    '🥚' => 'uòu',
    '🫕' => 'fonduda',
    '🧈' => 'burre',
    '🧂' => 'sal',
    '🥧' => 'tarta',
    '🧉' => 'mate',
    '🧊' => 'glaçon',
    '🥄' => 'culhièr',
    '🧭' => 'compàs',
    '⛰' => 'montanha',
    '🌋' => 'volcan',
    '🏕' => 'campatge',
    '🏟' => 'estadi',
    '🧱' => 'brica',
    '🪨' => 'ròca',
    '🪵' => 'lenha',
    '🏘' => 'ostals',
    '🏠' => 'ostal',
    '🏡' => 'ostal amb jardin',
    '🏥' => 'espital',
    '🏦' => 'banca',
    '🏫' => 'escòla',
    '🏰' => 'castèl',
    '⛪' => 'glèsia',
    '⛲' => 'font',
    '⛺' => 'tenda',
    '🚆' => 'tren',
    '🚇' => 'mètro',
    '🚉' => 'estacion',
    '🚊' => 'tram',
    '🚌' => 'bus',
    '🚑' => 'ambulància',
    '🚕' => 'taxi',
    '🚜' => 'tractor',
    '🚲' => 'bicicleta',
    '⌚' => 'mòstra',
    '☀' => 'solelh',
    '⭐' => 'estela',
    '🌈' => 'arcolan',
    '🔥' => 'fòc',
    '💧' => 'goteta',
    '🎃' => 'coja',
    '🎄' => 'Arbre de Nadal',
    '🎁' => 'present',
    '🎫' => 'bilhet',
    '🏉' => 'rugby',
    '🎾' => 'tenís',
    '🎮' => 'jòc vidèo',
    '🕹' => 'maneta',
    '👖' => 'bragas',
    '🧣' => 'eissarpa',
    '🧤' => 'gants',
    '🧦' => 'cauceta',
    '🎩' => 'capèl',
    '💍' => 'anèl',
    '🔔' => 'campana',
    '🎤' => 'microfòn',
    '📻' => 'ràdio',
    '🪗' => 'acordeon',
    '🪈' => 'flaüta',
    '☎' => 'telefòn',
    '🖨' => 'imprimenta',
    '⌨' => 'clavièr',
    '💿' => 'disc optic',
    '📀' => 'dvd',
    '📺' => 'television',
    '📷' => 'camèra',
    '📹' => 'camèra (v)',
    '🕯' => 'candèla',
    '📕' => 'libre tampat',
    '📖' => 'libre dobèrt',
    '📗' => 'libre verd',
    '📘' => 'libre blau',
    '📚' => 'libres',
    '🔖' => 'marcapagina',
    '🏷' => 'etiqueta',
    '🪙' => 'pèça',
    '💳' => 'carta de crèdit',
    '📦' => 'paquet',
    '📅' => 'calendièr',
    '🔑' => 'clau',
    '🔨' => 'martèl',
    '🛡' => 'escut',
    '🔗' => 'ligam',
    '⛓' => 'cadenas',
    '🪜' => 'escala',
    '💉' => 'seringa',
    '🚪' => 'pòrta',
    '🪞' => 'miralh',
    '🪟' => 'fenèstra',
    '🛏' => 'lièch',
    '🪑' => 'cadièra',
    '🚿' => 'docha',
    '🧼' => 'sabon',
    '🏧' => 'avertiment',
    '🎦' => 'cinèma',
];
