<?php

return [
    'Names' => [
        'Adlm' => 'адлам',
        'Arab' => 'арабскае',
        'Aran' => 'насталік',
        'Armn' => 'армянскае',
        'Beng' => 'бенгальскае',
        'Bopo' => 'бапамофа',
        'Brai' => 'шрыфт Брайля',
        'Cakm' => 'чакма',
        'Cans' => 'складавае пісьмо канадскіх абарыгенаў',
        'Cher' => 'чэрокі',
        'Cyrl' => 'кірыліца',
        'Deva' => 'дэванагары',
        'Ethi' => 'эфіопскае',
        'Geor' => 'грузінскае',
        'Grek' => 'грэчаскае',
        'Gujr' => 'гуджараці',
        'Guru' => 'гурмукхі',
        'Hanb' => 'хан з бапамофа',
        'Hang' => 'хангыль',
        'Hani' => 'хан',
        'Hans' => 'спрошчанае кітайскае',
        'Hant' => 'традыцыйнае кітайскае',
        'Hebr' => 'яўрэйскае',
        'Hira' => 'хірагана',
        'Hrkt' => 'японскія складовыя пісьмы',
        'Jamo' => 'чамо',
        'Jpan' => 'японскае',
        'Kana' => 'катакана',
        'Khmr' => 'кхмерскае',
        'Knda' => 'канада',
        'Kore' => 'карэйскае',
        'Laoo' => 'лаоскае',
        'Latn' => 'лацініца',
        'Mlym' => 'малаялам',
        'Mong' => 'старамангольскае',
        'Mtei' => 'маніпуры',
        'Mymr' => 'бірманскае',
        'Nkoo' => 'нко',
        'Olck' => 'ол-чыкі',
        'Orya' => 'орыя',
        'Rohg' => 'ханіфі',
        'Sinh' => 'сінгальскае',
        'Sund' => 'сунданскае',
        'Syrc' => 'сірыйскае',
        'Taml' => 'тамільскае',
        'Telu' => 'тэлугу',
        'Tfng' => 'тыфінаг',
        'Thaa' => 'тана',
        'Thai' => 'тайскае',
        'Tibt' => 'тыбецкае',
        'Vaii' => 'вайскае',
        'Yiii' => 'йі',
        'Zmth' => 'матэматычныя знакі',
        'Zsye' => 'эмодзі',
        'Zsym' => 'сімвалы',
        'Zxxx' => 'беспісьменная',
        'Zyyy' => 'агульнае',
    ],
];
