<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Horário do Meridiano de Greenwich (Abidjan)',
        'Africa/Accra' => 'Horário do Meridiano de Greenwich (Acra)',
        'Africa/Addis_Ababa' => 'Horário da África Oriental (Adis Abeba)',
        'Africa/Algiers' => 'Horário da Europa Central (Argel)',
        'Africa/Asmera' => 'Horário da África Oriental (Asmara)',
        'Africa/Asmara' => 'Horário da África Oriental (Asmara)',
        'Africa/Bamako' => 'Horário do Meridiano de Greenwich (Bamako)',
        'Africa/Bangui' => 'Horário da África Ocidental (Bangui)',
        'Africa/Banjul' => 'Horário do Meridiano de Greenwich (Banjul)',
        'Africa/Bissau' => 'Horário do Meridiano de Greenwich (Bissau)',
        'Africa/Blantyre' => 'Horário da África Central (Blantyre)',
        'Africa/Brazzaville' => 'Horário da África Ocidental (Brazzaville)',
        'Africa/Bujumbura' => 'Horário da África Central (Bujumbura)',
        'Africa/Cairo' => 'Horário da Europa Oriental (Cairo)',
        'Africa/Casablanca' => 'Horário da Europa Ocidental (Casablanca)',
        'Africa/Ceuta' => 'Horário da Europa Central (Ceuta)',
        'Africa/Conakry' => 'Horário do Meridiano de Greenwich (Conacri)',
        'Africa/Dakar' => 'Horário do Meridiano de Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Horário da África Oriental (Dar es Salaam)',
        'Africa/Djibouti' => 'Horário da África Oriental (Djibuti)',
        'Africa/Douala' => 'Horário da África Ocidental (Douala)',
        'Africa/El_Aaiun' => 'Horário da Europa Ocidental (El Aaiún)',
        'Africa/Freetown' => 'Horário do Meridiano de Greenwich (Freetown)',
        'Africa/Gaborone' => 'Horário da África Central (Gaborone)',
        'Africa/Harare' => 'Horário da África Central (Harare)',
        'Africa/Johannesburg' => 'Horário da África do Sul (Joanesburgo)',
        'Africa/Juba' => 'Horário da África Central (Juba)',
        'Africa/Kampala' => 'Horário da África Oriental (Kampala)',
        'Africa/Khartoum' => 'Horário da África Central (Cartum)',
        'Africa/Kigali' => 'Horário da África Central (Kigali)',
        'Africa/Kinshasa' => 'Horário da África Ocidental (Kinshasa)',
        'Africa/Lagos' => 'Horário da África Ocidental (Lagos)',
        'Africa/Libreville' => 'Horário da África Ocidental (Libreville)',
        'Africa/Lome' => 'Horário do Meridiano de Greenwich (Lomé)',
        'Africa/Luanda' => 'Horário da África Ocidental (Luanda)',
        'Africa/Lubumbashi' => 'Horário da África Central (Lubumbashi)',
        'Africa/Lusaka' => 'Horário da África Central (Lusaka)',
        'Africa/Malabo' => 'Horário da África Ocidental (Malabo)',
        'Africa/Maputo' => 'Horário da África Central (Maputo)',
        'Africa/Maseru' => 'Horário da África do Sul (Maseru)',
        'Africa/Mbabane' => 'Horário da África do Sul (Mbabane)',
        'Africa/Mogadishu' => 'Horário da África Oriental (Mogadíscio)',
        'Africa/Monrovia' => 'Horário do Meridiano de Greenwich (Monróvia)',
        'Africa/Nairobi' => 'Horário da África Oriental (Nairóbi)',
        'Africa/Ndjamena' => 'Horário da África Ocidental (N’Djamena)',
        'Africa/Niamey' => 'Horário da África Ocidental (Niamey)',
        'Africa/Nouakchott' => 'Horário do Meridiano de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Horário do Meridiano de Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Horário da África Ocidental (Porto Novo)',
        'Africa/Sao_Tome' => 'Horário do Meridiano de Greenwich (São Tomé)',
        'Africa/Tripoli' => 'Horário da Europa Oriental (Trípoli)',
        'Africa/Tunis' => 'Horário da Europa Central (Túnis)',
        'Africa/Windhoek' => 'Horário da África Central (Windhoek)',
        'America/Adak' => 'Horário do Havaí e Ilhas Aleutas (Adak)',
        'America/Anchorage' => 'Horário do Alasca (Anchorage)',
        'America/Anguilla' => 'Horário do Atlântico (Anguila)',
        'America/Antigua' => 'Horário do Atlântico (Antígua)',
        'America/Araguaina' => 'Horário de Brasília (Araguaína)',
        'America/Argentina/La_Rioja' => 'Horário da Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Horário da Argentina (Río Gallegos)',
        'America/Argentina/Salta' => 'Horário da Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Horário da Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Horário da Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Horário da Argentina (Tucumã)',
        'America/Argentina/Ushuaia' => 'Horário da Argentina (Ushuaia)',
        'America/Aruba' => 'Horário do Atlântico (Aruba)',
        'America/Asuncion' => 'Horário do Paraguai (Assunção)',
        'America/Bahia' => 'Horário de Brasília (Bahia)',
        'America/Bahia_Banderas' => 'Horário Central (Bahia de Banderas)',
        'America/Barbados' => 'Horário do Atlântico (Barbados)',
        'America/Belem' => 'Horário de Brasília (Belém)',
        'America/Belize' => 'Horário Central (Belize)',
        'America/Blanc-Sablon' => 'Horário do Atlântico (Blanc-Sablon)',
        'America/Boa_Vista' => 'Horário do Amazonas (Boa Vista)',
        'America/Bogota' => 'Horário da Colômbia (Bogotá)',
        'America/Boise' => 'Horário das Montanhas (Boise)',
        'America/Buenos_Aires' => 'Horário da Argentina (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Horário da Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Horário das Montanhas (Cambridge Bay)',
        'America/Campo_Grande' => 'Horário do Amazonas (Campo Grande)',
        'America/Cancun' => 'Horário do Leste (Cancún)',
        'America/Caracas' => 'Horário da Venezuela (Caracas)',
        'America/Catamarca' => 'Horário da Argentina (Catamarca)',
        'America/Argentina/Catamarca' => 'Horário da Argentina (Catamarca)',
        'America/Cayenne' => 'Horário da Guiana Francesa (Caiena)',
        'America/Cayman' => 'Horário do Leste (Cayman)',
        'America/Chicago' => 'Horário Central (Chicago)',
        'America/Chihuahua' => 'Horário Central (Chihuahua)',
        'America/Ciudad_Juarez' => 'Horário das Montanhas (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Horário do Leste (Atikokan)',
        'America/Atikokan' => 'Horário do Leste (Atikokan)',
        'America/Cordoba' => 'Horário da Argentina (Córdoba)',
        'America/Argentina/Cordoba' => 'Horário da Argentina (Córdoba)',
        'America/Costa_Rica' => 'Horário Central (Costa Rica)',
        'America/Coyhaique' => 'Horário do Chile (Coihaique)',
        'America/Creston' => 'Horário das Montanhas (Creston)',
        'America/Cuiaba' => 'Horário do Amazonas (Cuiabá)',
        'America/Curacao' => 'Horário do Atlântico (Curaçao)',
        'America/Danmarkshavn' => 'Horário do Meridiano de Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Horário do Yukon (Dawson)',
        'America/Dawson_Creek' => 'Horário das Montanhas (Dawson Creek)',
        'America/Denver' => 'Horário das Montanhas (Denver)',
        'America/Detroit' => 'Horário do Leste (Detroit)',
        'America/Dominica' => 'Horário do Atlântico (Dominica)',
        'America/Edmonton' => 'Horário das Montanhas (Edmonton)',
        'America/Eirunepe' => 'Horário do Acre (Eirunepé)',
        'America/El_Salvador' => 'Horário Central (El Salvador)',
        'America/Fort_Nelson' => 'Horário das Montanhas (Fort Nelson)',
        'America/Fortaleza' => 'Horário de Brasília (Fortaleza)',
        'America/Glace_Bay' => 'Horário do Atlântico (Glace Bay)',
        'America/Godthab' => 'Horário Groenlândia (Nuuk)',
        'America/Nuuk' => 'Horário Groenlândia (Nuuk)',
        'America/Goose_Bay' => 'Horário do Atlântico (Goose Bay)',
        'America/Grand_Turk' => 'Horário do Leste (Grand Turk)',
        'America/Grenada' => 'Horário do Atlântico (Granada)',
        'America/Guadeloupe' => 'Horário do Atlântico (Guadalupe)',
        'America/Guatemala' => 'Horário Central (Guatemala)',
        'America/Guayaquil' => 'Horário do Equador (Guaiaquil)',
        'America/Guyana' => 'Horário da Guiana',
        'America/Halifax' => 'Horário do Atlântico (Halifax)',
        'America/Havana' => 'Horário de Cuba (Havana)',
        'America/Hermosillo' => 'Horário do Pacífico Mexicano (Hermosillo)',
        'America/Indiana/Knox' => 'Horário Central (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Horário do Leste (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Horário do Leste (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Horário Central (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Horário do Leste (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Horário do Leste (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Horário do Leste (Winamac, Indiana)',
        'America/Indianapolis' => 'Horário do Leste (Indianápolis)',
        'America/Indiana/Indianapolis' => 'Horário do Leste (Indianápolis)',
        'America/Inuvik' => 'Horário das Montanhas (Inuvik)',
        'America/Iqaluit' => 'Horário do Leste (Iqaluit)',
        'America/Jamaica' => 'Horário do Leste (Jamaica)',
        'America/Jujuy' => 'Horário da Argentina (Jujuy)',
        'America/Argentina/Jujuy' => 'Horário da Argentina (Jujuy)',
        'America/Juneau' => 'Horário do Alasca (Juneau)',
        'America/Kentucky/Monticello' => 'Horário do Leste (Monticello, Kentucky)',
        'America/Kralendijk' => 'Horário do Atlântico (Kralendijk)',
        'America/La_Paz' => 'Horário da Bolívia (La Paz)',
        'America/Lima' => 'Horário do Peru (Lima)',
        'America/Los_Angeles' => 'Horário do Pacífico (Los Angeles)',
        'America/Louisville' => 'Horário do Leste (Louisville)',
        'America/Kentucky/Louisville' => 'Horário do Leste (Louisville)',
        'America/Lower_Princes' => 'Horário do Atlântico (Lower Prince’s Quarter)',
        'America/Maceio' => 'Horário de Brasília (Maceió)',
        'America/Managua' => 'Horário Central (Manágua)',
        'America/Manaus' => 'Horário do Amazonas (Manaus)',
        'America/Marigot' => 'Horário do Atlântico (Marigot)',
        'America/Martinique' => 'Horário do Atlântico (Martinica)',
        'America/Matamoros' => 'Horário Central (Matamoros)',
        'America/Mazatlan' => 'Horário do Pacífico Mexicano (Mazatlán)',
        'America/Mendoza' => 'Horário da Argentina (Mendoza)',
        'America/Argentina/Mendoza' => 'Horário da Argentina (Mendoza)',
        'America/Menominee' => 'Horário Central (Menominee)',
        'America/Merida' => 'Horário Central (Mérida)',
        'America/Metlakatla' => 'Horário do Alasca (Metlakatla)',
        'America/Mexico_City' => 'Horário Central (Cidade do México)',
        'America/Miquelon' => 'Horário de São Pedro e Miquelão (Saint-Pierre)',
        'America/Moncton' => 'Horário do Atlântico (Moncton)',
        'America/Monterrey' => 'Horário Central (Monterrey)',
        'America/Montevideo' => 'Horário do Uruguai (Montevidéu)',
        'America/Montserrat' => 'Horário do Atlântico (Montserrat)',
        'America/Nassau' => 'Horário do Leste (Nassau)',
        'America/New_York' => 'Horário do Leste (Nova York)',
        'America/Nome' => 'Horário do Alasca (Nome)',
        'America/Noronha' => 'Horário de Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Horário Central (Beulah, Dakota do Norte)',
        'America/North_Dakota/Center' => 'Horário Central (Center, Dakota do Norte)',
        'America/North_Dakota/New_Salem' => 'Horário Central (New Salen, Dakota do Norte)',
        'America/Ojinaga' => 'Horário Central (Ojinaga)',
        'America/Panama' => 'Horário do Leste (Panamá)',
        'America/Paramaribo' => 'Horário do Suriname (Paramaribo)',
        'America/Phoenix' => 'Horário das Montanhas (Phoenix)',
        'America/Port-au-Prince' => 'Horário do Leste (Porto Príncipe)',
        'America/Port_of_Spain' => 'Horário do Atlântico (Port of Spain)',
        'America/Porto_Velho' => 'Horário do Amazonas (Porto Velho)',
        'America/Puerto_Rico' => 'Horário do Atlântico (Porto Rico)',
        'America/Punta_Arenas' => 'Horário do Chile (Punta Arenas)',
        'America/Rankin_Inlet' => 'Horário Central (Rankin Inlet)',
        'America/Recife' => 'Horário de Brasília (Recife)',
        'America/Regina' => 'Horário Central (Regina)',
        'America/Resolute' => 'Horário Central (Resolute)',
        'America/Rio_Branco' => 'Horário do Acre (Rio Branco)',
        'America/Santarem' => 'Horário de Brasília (Santarém)',
        'America/Santiago' => 'Horário do Chile (Santiago)',
        'America/Santo_Domingo' => 'Horário do Atlântico (Santo Domingo)',
        'America/Sao_Paulo' => 'Horário de Brasília (São Paulo)',
        'America/Scoresbysund' => 'Horário Groenlândia (Ittoqqortoormiit)',
        'America/Sitka' => 'Horário do Alasca (Sitka)',
        'America/St_Barthelemy' => 'Horário do Atlântico (São Bartolomeu)',
        'America/St_Johns' => 'Horário da Terra Nova (Saint John’s)',
        'America/St_Kitts' => 'Horário do Atlântico (São Cristóvão)',
        'America/St_Lucia' => 'Horário do Atlântico (Santa Lúcia)',
        'America/St_Thomas' => 'Horário do Atlântico (Saint Thomas)',
        'America/St_Vincent' => 'Horário do Atlântico (São Vicente)',
        'America/Swift_Current' => 'Horário Central (Swift Current)',
        'America/Tegucigalpa' => 'Horário Central (Tegucigalpa)',
        'America/Thule' => 'Horário do Atlântico (Thule)',
        'America/Tijuana' => 'Horário do Pacífico (Tijuana)',
        'America/Toronto' => 'Horário do Leste (Toronto)',
        'America/Tortola' => 'Horário do Atlântico (Tortola)',
        'America/Vancouver' => 'Horário do Pacífico (Vancouver)',
        'America/Whitehorse' => 'Horário do Yukon (Whitehorse)',
        'America/Winnipeg' => 'Horário Central (Winnipeg)',
        'America/Yakutat' => 'Horário do Alasca (Yakutat)',
        'Antarctica/Casey' => 'Horário da Austrália Ocidental (Casey)',
        'Antarctica/Davis' => 'Horário de Davis',
        'Antarctica/DumontDUrville' => 'Horário de Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Horário da Austrália Oriental (Macquarie)',
        'Antarctica/Mawson' => 'Horário de Mawson',
        'Antarctica/McMurdo' => 'Horário da Nova Zelândia (McMurdo)',
        'Antarctica/Palmer' => 'Horário do Chile (Palmer)',
        'Antarctica/Rothera' => 'Horário de Rothera',
        'Antarctica/Syowa' => 'Horário de Syowa (Showa)',
        'Antarctica/Troll' => 'Horário do Meridiano de Greenwich (Troll)',
        'Antarctica/Vostok' => 'Horário de Vostok',
        'Arctic/Longyearbyen' => 'Horário da Europa Central (Longyearbyen)',
        'Asia/Aden' => 'Horário da Arábia (Áden)',
        'Asia/Almaty' => 'Horário do Cazaquistão (Almaty)',
        'Asia/Amman' => 'Horário da Europa Oriental (Amã)',
        'Asia/Anadyr' => 'Horário de Petropavlovsk-Kamchatski (Anadyr)',
        'Asia/Aqtau' => 'Horário do Cazaquistão (Aktau)',
        'Asia/Aqtobe' => 'Horário do Cazaquistão (Aktobe)',
        'Asia/Ashgabat' => 'Horário do Turcomenistão (Asgabate)',
        'Asia/Atyrau' => 'Horário do Cazaquistão (Atyrau)',
        'Asia/Baghdad' => 'Horário da Arábia (Bagdá)',
        'Asia/Bahrain' => 'Horário da Arábia (Bahrein)',
        'Asia/Baku' => 'Horário do Arzeibaijão (Baku)',
        'Asia/Bangkok' => 'Horário da Indochina (Bangkok)',
        'Asia/Barnaul' => 'Horário de Krasnoyarsk (Barnaul)',
        'Asia/Beirut' => 'Horário da Europa Oriental (Beirute)',
        'Asia/Bishkek' => 'Horário do Quirguistão (Bishkek)',
        'Asia/Brunei' => 'Horário de Brunei Darussalam',
        'Asia/Calcutta' => 'Horário Padrão da Índia (Calcutá)',
        'Asia/Kolkata' => 'Horário Padrão da Índia (Calcutá)',
        'Asia/Chita' => 'Horário de Yakutsk (Chita)',
        'Asia/Colombo' => 'Horário Padrão da Índia (Colombo)',
        'Asia/Damascus' => 'Horário da Europa Oriental (Damasco)',
        'Asia/Dhaka' => 'Horário de Bangladesh (Dacca)',
        'Asia/Dili' => 'Horário do Timor-Leste (Dili)',
        'Asia/Dubai' => 'Horário do Golfo (Dubai)',
        'Asia/Dushanbe' => 'Horário do Tajiquistão (Duchambe)',
        'Asia/Famagusta' => 'Horário da Europa Oriental (Famagusta)',
        'Asia/Gaza' => 'Horário da Europa Oriental (Gaza)',
        'Asia/Hebron' => 'Horário da Europa Oriental (Hebron)',
        'Asia/Hong_Kong' => 'Horário de Hong Kong',
        'Asia/Hovd' => 'Horário de Hovd (Khovd)',
        'Asia/Irkutsk' => 'Horário de Irkutsk',
        'Asia/Jakarta' => 'Horário da Indonésia Ocidental (Jacarta)',
        'Asia/Jayapura' => 'Horário da Indonésia Oriental (Jayapura)',
        'Asia/Jerusalem' => 'Horário de Israel (Jerusalém)',
        'Asia/Kabul' => 'Horário do Afeganistão (Cabul)',
        'Asia/Kamchatka' => 'Horário de Petropavlovsk-Kamchatski (Kamchatka)',
        'Asia/Karachi' => 'Horário do Paquistão (Karachi)',
        'Asia/Katmandu' => 'Horário do Nepal (Katmandu)',
        'Asia/Kathmandu' => 'Horário do Nepal (Katmandu)',
        'Asia/Khandyga' => 'Horário de Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Horário de Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Horário da Malásia (Kuala Lumpur)',
        'Asia/Kuching' => 'Horário da Malásia (Kuching)',
        'Asia/Kuwait' => 'Horário da Arábia (Kuwait)',
        'Asia/Macau' => 'Horário da China (Macau)',
        'Asia/Magadan' => 'Horário de Magadan',
        'Asia/Makassar' => 'Horário da Indonésia Central (Makassar)',
        'Asia/Manila' => 'Horário das Filipinas (Manila)',
        'Asia/Muscat' => 'Horário do Golfo (Mascate)',
        'Asia/Nicosia' => 'Horário da Europa Oriental (Nicósia)',
        'Asia/Novokuznetsk' => 'Horário de Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Horário de Krasnoyarsk (Novosibirsk)',
        'Asia/Omsk' => 'Horário de Omsk',
        'Asia/Oral' => 'Horário do Cazaquistão (Oral)',
        'Asia/Phnom_Penh' => 'Horário da Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'Horário da Indonésia Ocidental (Pontianak)',
        'Asia/Pyongyang' => 'Horário da Coreia (Pyongyang)',
        'Asia/Qatar' => 'Horário da Arábia (Catar)',
        'Asia/Qostanay' => 'Horário do Cazaquistão (Qostanay)',
        'Asia/Qyzylorda' => 'Horário do Cazaquistão (Qyzylorda)',
        'Asia/Rangoon' => 'Horário de Mianmar (Rangum)',
        'Asia/Yangon' => 'Horário de Mianmar (Rangum)',
        'Asia/Riyadh' => 'Horário da Arábia (Riade)',
        'Asia/Saigon' => 'Horário da Indochina (Cidade de Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'Horário da Indochina (Cidade de Ho Chi Minh)',
        'Asia/Sakhalin' => 'Horário de Magadan (Sacalina)',
        'Asia/Samarkand' => 'Horário do Uzbequistão (Samarcanda)',
        'Asia/Seoul' => 'Horário da Coreia (Seul)',
        'Asia/Shanghai' => 'Horário da China (Xangai)',
        'Asia/Singapore' => 'Horário Padrão de Singapura',
        'Asia/Srednekolymsk' => 'Horário de Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Horário de Taipei',
        'Asia/Tashkent' => 'Horário do Uzbequistão (Tashkent)',
        'Asia/Tbilisi' => 'Horário da Geórgia (Tbilisi)',
        'Asia/Tehran' => 'Horário do Irã (Teerã)',
        'Asia/Thimphu' => 'Horário do Butão (Thimphu)',
        'Asia/Tokyo' => 'Horário do Japão (Tóquio)',
        'Asia/Tomsk' => 'Horário de Krasnoyarsk (Tomsk)',
        'Asia/Ulaanbaatar' => 'Horário de Ulan Bator',
        'Asia/Urumqi' => 'Horário China (Ürümqi)',
        'Asia/Ust-Nera' => 'Horário de Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Horário da Indochina (Vientiane)',
        'Asia/Vladivostok' => 'Horário de Vladivostok',
        'Asia/Yakutsk' => 'Horário de Yakutsk',
        'Asia/Yekaterinburg' => 'Horário de Ecaterimburgo',
        'Asia/Yerevan' => 'Horário da Armênia (Yerevan)',
        'Atlantic/Azores' => 'Horário dos Açores',
        'Atlantic/Bermuda' => 'Horário do Atlântico (Bermudas)',
        'Atlantic/Canary' => 'Horário da Europa Ocidental (Canárias)',
        'Atlantic/Cape_Verde' => 'Horário de Cabo Verde',
        'Atlantic/Faeroe' => 'Horário da Europa Ocidental (Ilhas Faroé)',
        'Atlantic/Faroe' => 'Horário da Europa Ocidental (Ilhas Faroé)',
        'Atlantic/Madeira' => 'Horário da Europa Ocidental (Madeira)',
        'Atlantic/Reykjavik' => 'Horário do Meridiano de Greenwich (Reykjavík)',
        'Atlantic/South_Georgia' => 'Horário da Geórgia do Sul',
        'Atlantic/St_Helena' => 'Horário do Meridiano de Greenwich (Santa Helena)',
        'Atlantic/Stanley' => 'Horário das Ilhas Malvinas (Stanley)',
        'Australia/Adelaide' => 'Horário da Austrália Central (Adelaide)',
        'Australia/Brisbane' => 'Horário da Austrália Oriental (Brisbane)',
        'Australia/Broken_Hill' => 'Horário da Austrália Central (Broken Hill)',
        'Australia/Darwin' => 'Horário da Austrália Central (Darwin)',
        'Australia/Eucla' => 'Horário da Austrália Centro-Ocidental (Eucla)',
        'Australia/Hobart' => 'Horário da Austrália Oriental (Hobart)',
        'Australia/Lindeman' => 'Horário da Austrália Oriental (Lindeman)',
        'Australia/Lord_Howe' => 'Horário de Lord Howe',
        'Australia/Melbourne' => 'Horário da Austrália Oriental (Melbourne)',
        'Australia/Perth' => 'Horário da Austrália Ocidental (Perth)',
        'Australia/Sydney' => 'Horário da Austrália Oriental (Sydney)',
        'Etc/GMT' => 'Horário do Meridiano de Greenwich',
        'Etc/UTC' => 'Horário Universal Coordenado',
        'Europe/Amsterdam' => 'Horário da Europa Central (Amsterdã)',
        'Europe/Andorra' => 'Horário da Europa Central (Andorra)',
        'Europe/Astrakhan' => 'Horário de Samara (Astracã)',
        'Europe/Athens' => 'Horário da Europa Oriental (Atenas)',
        'Europe/Belgrade' => 'Horário da Europa Central (Belgrado)',
        'Europe/Berlin' => 'Horário da Europa Central (Berlim)',
        'Europe/Bratislava' => 'Horário da Europa Central (Bratislava)',
        'Europe/Brussels' => 'Horário da Europa Central (Bruxelas)',
        'Europe/Bucharest' => 'Horário da Europa Oriental (Bucareste)',
        'Europe/Budapest' => 'Horário da Europa Central (Budapeste)',
        'Europe/Busingen' => 'Horário da Europa Central (Büsingen)',
        'Europe/Chisinau' => 'Horário da Europa Oriental (Chișinău)',
        'Europe/Copenhagen' => 'Horário da Europa Central (Copenhague)',
        'Europe/Dublin' => 'Horário do Meridiano de Greenwich (Dublin)',
        'Europe/Gibraltar' => 'Horário da Europa Central (Gibraltar)',
        'Europe/Guernsey' => 'Horário do Meridiano de Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Horário da Europa Oriental (Helsinque)',
        'Europe/Isle_of_Man' => 'Horário do Meridiano de Greenwich (Ilha de Man)',
        'Europe/Istanbul' => 'Horário da Turquia (Istambul)',
        'Europe/Jersey' => 'Horário do Meridiano de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Horário da Europa Oriental (Kaliningrado)',
        'Europe/Kiev' => 'Horário da Europa Oriental (Kiev)',
        'Europe/Kyiv' => 'Horário da Europa Oriental (Kiev)',
        'Europe/Kirov' => 'Horário de Moscou (Kirov)',
        'Europe/Lisbon' => 'Horário da Europa Ocidental (Lisboa)',
        'Europe/Ljubljana' => 'Horário da Europa Central (Liubliana)',
        'Europe/London' => 'Horário do Meridiano de Greenwich (Londres)',
        'Europe/Luxembourg' => 'Horário da Europa Central (Luxemburgo)',
        'Europe/Madrid' => 'Horário da Europa Central (Madri)',
        'Europe/Malta' => 'Horário da Europa Central (Malta)',
        'Europe/Mariehamn' => 'Horário da Europa Oriental (Mariehamn)',
        'Europe/Minsk' => 'Horário de Moscou (Minsk)',
        'Europe/Monaco' => 'Horário da Europa Central (Mônaco)',
        'Europe/Moscow' => 'Horário de Moscou',
        'Europe/Oslo' => 'Horário da Europa Central (Oslo)',
        'Europe/Paris' => 'Horário da Europa Central (Paris)',
        'Europe/Podgorica' => 'Horário da Europa Central (Podgorica)',
        'Europe/Prague' => 'Horário da Europa Central (Praga)',
        'Europe/Riga' => 'Horário da Europa Oriental (Riga)',
        'Europe/Rome' => 'Horário da Europa Central (Roma)',
        'Europe/Samara' => 'Horário de Samara',
        'Europe/San_Marino' => 'Horário da Europa Central (San Marino)',
        'Europe/Sarajevo' => 'Horário da Europa Central (Sarajevo)',
        'Europe/Saratov' => 'Horário de Samara (Saratov)',
        'Europe/Simferopol' => 'Horário de Moscou (Simferopol)',
        'Europe/Skopje' => 'Horário da Europa Central (Skopje)',
        'Europe/Sofia' => 'Horário da Europa Oriental (Sófia)',
        'Europe/Stockholm' => 'Horário da Europa Central (Estocolmo)',
        'Europe/Tallinn' => 'Horário da Europa Oriental (Tallinn)',
        'Europe/Tirane' => 'Horário da Europa Central (Tirana)',
        'Europe/Ulyanovsk' => 'Horário de Samara (Ulianovsk)',
        'Europe/Vaduz' => 'Horário da Europa Central (Vaduz)',
        'Europe/Vatican' => 'Horário da Europa Central (Vaticano)',
        'Europe/Vienna' => 'Horário da Europa Central (Viena)',
        'Europe/Vilnius' => 'Horário da Europa Oriental (Vilnius)',
        'Europe/Volgograd' => 'Horário de Moscou (Volgogrado)',
        'Europe/Warsaw' => 'Horário da Europa Central (Varsóvia)',
        'Europe/Zagreb' => 'Horário da Europa Central (Zagreb)',
        'Europe/Zurich' => 'Horário da Europa Central (Zurique)',
        'Indian/Antananarivo' => 'Horário da África Oriental (Antananarivo)',
        'Indian/Chagos' => 'Horário do Oceano Índico (Chagos)',
        'Indian/Christmas' => 'Horário da Ilha Christmas',
        'Indian/Cocos' => 'Horário das Ilhas Coco (Cocos)',
        'Indian/Comoro' => 'Horário da África Oriental (Comores)',
        'Indian/Kerguelen' => 'Horário dos Territórios Franceses do Sul e Antártida (Kerguelen)',
        'Indian/Mahe' => 'Horário de Seicheles (Mahé)',
        'Indian/Maldives' => 'Horário das Ilhas Maldivas',
        'Indian/Mauritius' => 'Horário de Maurício',
        'Indian/Mayotte' => 'Horário da África Oriental (Mayotte)',
        'Indian/Reunion' => 'Horário de Reunião',
        'Pacific/Apia' => 'Horário de Apia',
        'Pacific/Auckland' => 'Horário da Nova Zelândia (Auckland)',
        'Pacific/Bougainville' => 'Horário de Papua-Nova Guiné (Bougainville)',
        'Pacific/Chatham' => 'Horário de Chatham (Chatnam)',
        'Pacific/Easter' => 'Horário da Ilha de Páscoa',
        'Pacific/Efate' => 'Horário de Vanuatu (Éfaté)',
        'Pacific/Enderbury' => 'Horário das Ilhas Fênix (Ilha de Canton)',
        'Pacific/Kanton' => 'Horário das Ilhas Fênix (Ilha de Canton)',
        'Pacific/Fakaofo' => 'Horário de Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Horário de Fiji',
        'Pacific/Funafuti' => 'Horário de Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Horário de Galápagos',
        'Pacific/Gambier' => 'Horário de Gambier',
        'Pacific/Guadalcanal' => 'Horário das Ilhas Salomão (Guadalcanal)',
        'Pacific/Guam' => 'Horário de Chamorro (Guam)',
        'Pacific/Honolulu' => 'Horário Padrão do Havaí e Ilhas Aleutas (Honolulu)',
        'Pacific/Kiritimati' => 'Horário das Ilhas da Linha (Kiritimati)',
        'Pacific/Kosrae' => 'Horário de Kosrae',
        'Pacific/Kwajalein' => 'Horário das Ilhas Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Horário das Ilhas Marshall (Majuro)',
        'Pacific/Marquesas' => 'Horário das Marquesas',
        'Pacific/Midway' => 'Horário de Samoa (Midway)',
        'Pacific/Nauru' => 'Horário de Nauru',
        'Pacific/Niue' => 'Horário de Niue',
        'Pacific/Norfolk' => 'Horário da Ilha Norfolk',
        'Pacific/Noumea' => 'Horário da Nova Caledônia (Nouméa)',
        'Pacific/Pago_Pago' => 'Horário de Samoa (Pago Pago)',
        'Pacific/Palau' => 'Horário de Palau',
        'Pacific/Pitcairn' => 'Horário de Pitcairn',
        'Pacific/Ponape' => 'Horário de Ponape (Pohnpei)',
        'Pacific/Pohnpei' => 'Horário de Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Horário de Papua-Nova Guiné (Port Moresby)',
        'Pacific/Rarotonga' => 'Horário das Ilhas Cook (Rarotonga)',
        'Pacific/Saipan' => 'Horário de Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Horário do Taiti',
        'Pacific/Tarawa' => 'Horário das Ilhas Gilberto (Taraua)',
        'Pacific/Tongatapu' => 'Horário de Tonga (Tongatapu)',
        'Pacific/Truk' => 'Horário de Chuuk',
        'Pacific/Chuuk' => 'Horário de Chuuk',
        'Pacific/Wake' => 'Horário das Ilhas Wake',
        'Pacific/Wallis' => 'Horário de Wallis e Futuna (Wallis & Futuna)',
    ],
    'Meta' => [],
];
