<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'pezetayê andorrayî',
        ],
        'AED' => [
            'AED',
            'dîrhemê mîrgehên erebî yên yekbûyî',
        ],
        'AFA' => [
            'AFA',
            'efxanîyê efxanistanî (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'efxanîyê efxanistanî',
        ],
        'ALK' => [
            'ALK',
            'lekê arnawidî (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'lekê arnawidî',
        ],
        'AMD' => [
            'AMD',
            'dramê ermenî',
        ],
        'ANG' => [
            'ANG',
            'guldenê antîlê yê holandî',
        ],
        'AOA' => [
            'AOA',
            'kwanzayê angolayî',
        ],
        'AOK' => [
            'AOK',
            'kwanzayê angolayî (1977–1991)',
        ],
        'AON' => [
            'AON',
            'kwanzayê nû ya angolayî (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'kwanza reajustadoyê angolayî (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'australê arjantînî',
        ],
        'ARL' => [
            'ARL',
            'peso leyê arjantînî (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'pesoyê arjantînî (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'pesoyê arjantînî (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'pesoyê arjantînî',
        ],
        'ATS' => [
            'ATS',
            'şîllîngê awistiryayî',
        ],
        'AUD' => [
            'A$',
            'dolarê awistralyayî',
        ],
        'AWG' => [
            'AWG',
            'florînê arubayî',
        ],
        'AZM' => [
            'AZM',
            'manatê azerbeycanî (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'manatê azerbeycanî',
        ],
        'BAD' => [
            'BAD',
            'dînarê bosna hersekî (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'markê konvertibl ê bosna hersekî',
        ],
        'BAN' => [
            'BAN',
            'dînarê nû yê bosna hersekî (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'dolarê barbadosî',
        ],
        'BDT' => [
            'BDT',
            'takayê bengladeşî',
        ],
        'BEC' => [
            'BEC',
            'frankê belçîkayî (konvertibl)',
        ],
        'BEF' => [
            'BEF',
            'frankê belçîkayî',
        ],
        'BEL' => [
            'BEL',
            'frankê belçîkayî (fînansî)',
        ],
        'BGL' => [
            'BGL',
            'levê bulgarî (hard)',
        ],
        'BGM' => [
            'BGM',
            'levê bulgarî (1952–1962)',
        ],
        'BGN' => [
            'BGN',
            'levê bulgarî',
        ],
        'BGO' => [
            'BGO',
            'levê bulgarî (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'dînarê behreynê',
        ],
        'BIF' => [
            'BIF',
            'frankê birûndîyî',
        ],
        'BMD' => [
            'BMD',
            'dolarê bermûdayî',
        ],
        'BND' => [
            'BND',
            'dolarê brûneyî',
        ],
        'BOB' => [
            'BOB',
            'bolîvyanoyê bolîvyayî',
        ],
        'BOL' => [
            'BOL',
            'bolîvyanoyê bolîvyayî (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'pesoyê bolîvyayî',
        ],
        'BOV' => [
            'BOV',
            'mvodolê bolîvyayî',
        ],
        'BRB' => [
            'BRB',
            'kruzeîroyê nû ya brezîlyayî (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'kruzadoyê brezîlyayî (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'kruzeîroyê brezîlyayî (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'realê brezîlyayî',
        ],
        'BRN' => [
            'BRN',
            'kruzadoyê nû yê brezîlyayî (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'kruzeîroyê brezîlyayî (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'kruzeîroyê brezîlyayî (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'dolarê bahamayî',
        ],
        'BTN' => [
            'BTN',
            'ngultrumê bûtanî',
        ],
        'BUK' => [
            'BUK',
            'kyatê burmayî',
        ],
        'BWP' => [
            'BWP',
            'pulayê botswanayî',
        ],
        'BYB' => [
            'BYB',
            'rubleyê belarûsî (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'rubleyê belarûsî',
        ],
        'BYR' => [
            'BYR',
            'rubleyê belarûsî (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'dolarê belîzeyî',
        ],
        'CAD' => [
            'CA$',
            'dolarê kanadayî',
        ],
        'CDF' => [
            'CDF',
            'frankê kongoyî',
        ],
        'CHE' => [
            'CHE',
            'ewroyê WIRê',
        ],
        'CHF' => [
            'CHF',
            'frankê swîsrî',
        ],
        'CHW' => [
            'CHW',
            'frankê WIRê',
        ],
        'CLE' => [
            'CLE',
            'eskodoyê şîlîyî',
        ],
        'CLF' => [
            'CLF',
            'unidades de fomentoyê şîlîyî',
        ],
        'CLP' => [
            'CLP',
            'pesoyê şîlîyî',
        ],
        'CNH' => [
            'CNH',
            'yûanê çînî (offshore)',
        ],
        'CNX' => [
            'CNX',
            'dolarê Banka Xelkî ya çînî',
        ],
        'CNY' => [
            'CN¥',
            'yûanê çînî',
        ],
        'COP' => [
            'COP',
            'pesoyê kolombîyayî',
        ],
        'COU' => [
            'COU',
            'unidad de valor realê kolombîyayî',
        ],
        'CRC' => [
            'CRC',
            'kolonê kosta rîkayî',
        ],
        'CSD' => [
            'CSD',
            'poundê maltayî (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'kronê çekoslovakî (hard)',
        ],
        'CUC' => [
            'CUC',
            'pesoyên konvertibl ê kubayî',
        ],
        'CUP' => [
            'CUP',
            'pesoyê kubayî',
        ],
        'CVE' => [
            'CVE',
            'eskudoyê kape verdeyî',
        ],
        'CYP' => [
            'CYP',
            'lîreyê qibrisî',
        ],
        'CZK' => [
            'CZK',
            'kronê çekî',
        ],
        'DDM' => [
            'DDM',
            'markê almanyaya rojhilatî',
        ],
        'DEM' => [
            'DEM',
            'markê almanî',
        ],
        'DJF' => [
            'DJF',
            'frankê cîbûtîyî',
        ],
        'DKK' => [
            'DKK',
            'kronê danîmarkî',
        ],
        'DOP' => [
            'DOP',
            'pesoyê domînîkî',
        ],
        'DZD' => [
            'DZD',
            'dînarê cezayîrî',
        ],
        'ECS' => [
            'ECS',
            'sukreyê ekwadorî',
        ],
        'ECV' => [
            'ECV',
            'unidad de valor constanteyê ekwadorî (UVC)',
        ],
        'EEK' => [
            'EEK',
            'krûnê estonî',
        ],
        'EGP' => [
            'EGP',
            'lîreyê misirî',
        ],
        'ERN' => [
            'ERN',
            'nakfayê erîtreyî',
        ],
        'ESA' => [
            'ESA',
            'pezetayê spanî (hesabê Ayê)',
        ],
        'ESB' => [
            'ESB',
            'pezetayê spanî (hesabê konvertibl)',
        ],
        'ESP' => [
            'ESP',
            'pezetayê spanî',
        ],
        'ETB' => [
            'ETB',
            'bîrê etyopyayî',
        ],
        'EUR' => [
            '€',
            'ewro',
        ],
        'FIM' => [
            'FIM',
            'markkayê fînî',
        ],
        'FJD' => [
            'FJD',
            'dolarê fîjîyî',
        ],
        'FKP' => [
            'FKP',
            'paundê giravên falklandî',
        ],
        'FRF' => [
            'FRF',
            'markê fransî',
        ],
        'GBP' => [
            '£',
            'sterlînê brîtanî',
        ],
        'GEK' => [
            'GEK',
            'kupon larîtê gurcistanî',
        ],
        'GEL' => [
            'GEL',
            'larîyê gurcistanî',
        ],
        'GHC' => [
            'GHC',
            'cedîyê ganayî (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'cedîyê ganayî',
        ],
        'GIP' => [
            'GIP',
            'lîreyê cebelîtariqî',
        ],
        'GMD' => [
            'GMD',
            'dalasîyê gambîyayî',
        ],
        'GNF' => [
            'GNF',
            'frankê gîneyî',
        ],
        'GNS' => [
            'GNS',
            'sylîyê gîneyî',
        ],
        'GQE' => [
            'GQE',
            'ekweleyê gîneya ekvatorî',
        ],
        'GRD' => [
            'GRD',
            'draxmayê yûnanî',
        ],
        'GTQ' => [
            'GTQ',
            'quertzalê guatemalayî',
        ],
        'GWE' => [
            'GWE',
            'eskudoyê gîneya portugalî',
        ],
        'GWP' => [
            'GWP',
            'pezoyê gîne-bissauyî',
        ],
        'GYD' => [
            'GYD',
            'dolarê guayanayî',
        ],
        'HKD' => [
            'HK$',
            'dolarê hong kongî',
        ],
        'HNL' => [
            'HNL',
            'lempîrayê hondurasî',
        ],
        'HRD' => [
            'HRD',
            'dînarê xirwatî',
        ],
        'HRK' => [
            'HRK',
            'kunayê xirwatî',
        ],
        'HTG' => [
            'HTG',
            'gûrdeyê haîtîyî',
        ],
        'HUF' => [
            'HUF',
            'forîntê macarî',
        ],
        'IDR' => [
            'IDR',
            'rûpîyê endonezî',
        ],
        'IEP' => [
            'IEP',
            'lîreyê îrlandî',
        ],
        'ILP' => [
            'ILP',
            'lîreyê îsraîlî',
        ],
        'ILR' => [
            'ILR',
            'şekelê îsraîlî (1980–1985)',
        ],
        'ILS' => [
            '₪',
            'şekelê nû yê îsraîlî',
        ],
        'INR' => [
            '₹',
            'rûpîyê hindistanî',
        ],
        'IQD' => [
            'IQD',
            'dînarê îraqî',
        ],
        'IRR' => [
            'IRR',
            'rîyalê îranî',
        ],
        'ISJ' => [
            'ISJ',
            'kronê îslandayî (1918–1981)',
        ],
        'ISK' => [
            'ISK',
            'kronê îslandayî',
        ],
        'ITL' => [
            'ITL',
            'lîrayê îtalî',
        ],
        'JMD' => [
            'JMD',
            'dolarê jamaîkayî',
        ],
        'JOD' => [
            'JOD',
            'dînarê urdunî',
        ],
        'JPY' => [
            'JP¥',
            'yenê japonî',
        ],
        'KES' => [
            'KES',
            'şîlîngê kenyayî',
        ],
        'KGS' => [
            'KGS',
            'somê qirxizistanî',
        ],
        'KHR' => [
            'KHR',
            'rîelê kamboçyayî',
        ],
        'KMF' => [
            'KMF',
            'frankê komoranî',
        ],
        'KPW' => [
            'KPW',
            'wonê koreya bakurî',
        ],
        'KRH' => [
            'KRH',
            'hwanê koreya başûrî (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'wonê koreya başûrî (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'wonê koreya başûrî',
        ],
        'KWD' => [
            'KWD',
            'dînarê kuweytî',
        ],
        'KYD' => [
            'KYD',
            'dolarê giravên keymanî',
        ],
        'KZT' => [
            'KZT',
            'tengeyê qazaxistanî',
        ],
        'LAK' => [
            'LAK',
            'kîpê laosî',
        ],
        'LBP' => [
            'LBP',
            'lîreyê libnanî',
        ],
        'LKR' => [
            'LKR',
            'rûpîyê srî lankayî',
        ],
        'LRD' => [
            'LRD',
            'dolarê lîberyayî',
        ],
        'LSL' => [
            'LSL',
            'lotîyê lesothoyî',
        ],
        'LTL' => [
            'LTL',
            'lîtayê lîtvanyayî',
        ],
        'LTT' => [
            'LTT',
            'talonasê lîtvanyayî',
        ],
        'LUC' => [
            'LUC',
            'frankê konvertibl ya luksembûrgî',
        ],
        'LUF' => [
            'LUF',
            'frankê luksembûrgî',
        ],
        'LUL' => [
            'LUL',
            'frankê fînansî yê luksembûrgî',
        ],
        'LVL' => [
            'LVL',
            'latê letonyayî',
        ],
        'LVR' => [
            'LVR',
            'rubleyê letonyayî',
        ],
        'LYD' => [
            'LYD',
            'dînarê lîbyayî',
        ],
        'MAD' => [
            'MAD',
            'dîrhemê fasî',
        ],
        'MAF' => [
            'MAF',
            'franka fasî',
        ],
        'MCF' => [
            'MCF',
            'frankê monakoyî',
        ],
        'MDC' => [
            'MDC',
            'kuponê moldovayî',
        ],
        'MDL' => [
            'MDL',
            'leyê moldovayî',
        ],
        'MGA' => [
            'MGA',
            'arîarîyê madagaskarî',
        ],
        'MGF' => [
            'MGF',
            'frankê madagaskarî',
        ],
        'MKD' => [
            'MKD',
            'dînarê makedonî',
        ],
        'MKN' => [
            'MKN',
            'dînarê makedonî (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'franka malîyî',
        ],
        'MMK' => [
            'MMK',
            'kyatê myanmarî',
        ],
        'MNT' => [
            'MNT',
            'togrokê moxolî',
        ],
        'MOP' => [
            'MOP',
            'patakayê makaoyî',
        ],
        'MRO' => [
            'MRO',
            'ouguîayê morîtanyayî (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'ouguîayê morîtanyayî',
        ],
        'MTL' => [
            'MTL',
            'lîreyê maltayî',
        ],
        'MTP' => [
            'MTP',
            'poundê maltayî',
        ],
        'MUR' => [
            'MUR',
            'rûpîyê maûrîtîûsê',
        ],
        'MVP' => [
            'MVP',
            'rûpîyê maldîvayî (1947–1981)',
        ],
        'MVR' => [
            'MVR',
            'rûfîyaayê maldîvayî',
        ],
        'MWK' => [
            'MWK',
            'kwaçayê malawîyê',
        ],
        'MXN' => [
            'MX$',
            'pesoyê meksîkayî',
        ],
        'MXP' => [
            'MXP',
            'pesoyê zîvî yê meksîkayî (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'unidad de inversionê meksîkayî (UDI)',
        ],
        'MYR' => [
            'MYR',
            'ringgitê malezyayî',
        ],
        'MZE' => [
            'MZE',
            'eskudoyê mozambîkî',
        ],
        'MZM' => [
            'MZM',
            'metîkalê mozambîkî (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'metîkalê mozambîkî',
        ],
        'NAD' => [
            'NAD',
            'dolarê namîbyayî',
        ],
        'NGN' => [
            'NGN',
            'naîrayê nîjeryayî',
        ],
        'NIC' => [
            'NIC',
            'kordobayê nîkaraguayî (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'kordobayê nîkaraguayî',
        ],
        'NLG' => [
            'NLG',
            'florînê holendî',
        ],
        'NOK' => [
            'NOK',
            'kronê norweçî',
        ],
        'NPR' => [
            'NPR',
            'rûpîyê nepalî',
        ],
        'NZD' => [
            'NZ$',
            'dolarê zelandayî',
        ],
        'OMR' => [
            'OMR',
            'rîyalê umanî',
        ],
        'PAB' => [
            'PAB',
            'balboayê panamayî',
        ],
        'PEI' => [
            'PEI',
            'întîyê perûyî',
        ],
        'PEN' => [
            'PEN',
            'solê perûyî',
        ],
        'PES' => [
            'PES',
            'solê perûyî (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'kînayê gîneya nû ya papûayî',
        ],
        'PHP' => [
            '₱',
            'pesoyê fîlîpînî',
        ],
        'PKR' => [
            'PKR',
            'rûpîyê pakistanî',
        ],
        'PLN' => [
            'PLN',
            'zlotîyê polonyayî',
        ],
        'PLZ' => [
            'PLZ',
            'zlotîyê polonyayî (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'eskudoyê portugalî',
        ],
        'PYG' => [
            'PYG',
            'gûaranîyê paragûayî',
        ],
        'QAR' => [
            'QAR',
            'rîyalê qeterî',
        ],
        'RHD' => [
            'RHD',
            'dolarê rodezyayî',
        ],
        'ROL' => [
            'ROL',
            'leyê romanyayî (1952–2006)',
        ],
        'RON' => [
            'RON',
            'leyê romanyayî',
        ],
        'RSD' => [
            'RSD',
            'dînarê sirbî',
        ],
        'RUB' => [
            'RUB',
            'rubleyê rûsî',
        ],
        'RUR' => [
            'RUR',
            'rubleyê belarûsî (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'frankê rwandayî',
        ],
        'SAR' => [
            'SAR',
            'rîyalê siûdî',
        ],
        'SBD' => [
            'SBD',
            'dolarê giravên solomonî',
        ],
        'SCR' => [
            'SCR',
            'rûpîyê seyşelerî',
        ],
        'SDD' => [
            'SDD',
            'dînarê sûdanî (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'lîreyê sûdanî',
        ],
        'SDP' => [
            'SDP',
            'lîreyê sûdanî (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'kronê swêdî',
        ],
        'SGD' => [
            'SGD',
            'dolarê sîngapurî',
        ],
        'SHP' => [
            'SHP',
            'lîreyê saînt helenayî',
        ],
        'SIT' => [
            'SIT',
            'tolarê slovenî',
        ],
        'SKK' => [
            'SKK',
            'korunayê slovakî',
        ],
        'SLE' => [
            'SLE',
            'leoneyê sîera leoneyî',
        ],
        'SLL' => [
            'SLL',
            'leoneyê sîera leoneyî (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'şîlîngê somalî',
        ],
        'SRD' => [
            'SRD',
            'dolarê surînamî',
        ],
        'SRG' => [
            'SRG',
            'guldenê surînamî',
        ],
        'SSP' => [
            'SSP',
            'lîreyê sûdana başûrî',
        ],
        'STD' => [
            'STD',
            'dobrayê sao tome û principeyî (1977–2017)',
        ],
        'STN' => [
            'STN',
            'dobrayê sao tome û principeyî',
        ],
        'SUR' => [
            'SUR',
            'rubleyê sovyetî',
        ],
        'SVC' => [
            'SVC',
            'kolonê el salvadorî',
        ],
        'SYP' => [
            'SYP',
            'lîreyê sûrî',
        ],
        'SZL' => [
            'SZL',
            'lîlangenîyê swazîlî',
        ],
        'THB' => [
            'THB',
            'bahtê taylandî',
        ],
        'TJR' => [
            'TJR',
            'rubleyê tacikistanî',
        ],
        'TJS' => [
            'TJS',
            'somonê tacikistanî',
        ],
        'TMM' => [
            'TMM',
            'manatê tirkmenî (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'manatê tirkmenî',
        ],
        'TND' => [
            'TND',
            'dînarê tûnisî',
        ],
        'TOP' => [
            'TOP',
            'paʻangayê tonganî',
        ],
        'TPE' => [
            'TPE',
            'ekudoyê tîmorî',
        ],
        'TRL' => [
            'TRL',
            'lîreyê tirkî (1922–2005)',
        ],
        'TRY' => [
            '₺',
            'lîreyê tirkî',
        ],
        'TTD' => [
            'TTD',
            'dolarê trinidad û tobagoyî',
        ],
        'TWD' => [
            'NT$',
            'dolarê taywanî',
        ],
        'TZS' => [
            'TZS',
            'şîlîngê tanzanî',
        ],
        'UAH' => [
            'UAH',
            'grîvnayê ûkraynî',
        ],
        'UAK' => [
            'UAK',
            'karbovanetzê ûkraynî',
        ],
        'UGS' => [
            'UGS',
            'şîlîngê ûgandayî (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'şîlîngê ûgandayî',
        ],
        'USD' => [
            '$',
            'dolarê amerîkî',
        ],
        'USN' => [
            'USN',
            'dolarê amerîkî (roja din)',
        ],
        'USS' => [
            'USS',
            'dolarê amerîkî (eynî roj)',
        ],
        'UYI' => [
            'UYI',
            'peso en unidades indexadasê ûrûguayî',
        ],
        'UYP' => [
            'UYP',
            'pesoyê ûrûgûayî (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'pesoyê ûrûgûayî',
        ],
        'UYW' => [
            'UYW',
            'yekeya îndeksa heqdestê nomînal yê ûrûguayî',
        ],
        'UZS' => [
            'UZS',
            'somê ozbekî',
        ],
        'VEB' => [
            'VEB',
            'bolîvarê venezuelayî (1871–2008)',
        ],
        'VED' => [
            'VED',
            'bolivar soberano (VED)',
        ],
        'VEF' => [
            'VEF',
            'bolîvarê venezuelayî (2008–2018)',
        ],
        'VES' => [
            'VES',
            'bolîvarê venezuelayî',
        ],
        'VND' => [
            '₫',
            'dongê vîetnamî',
        ],
        'VNN' => [
            'VNN',
            'dongê vîetnamî (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'vatûyê vanûatûyî',
        ],
        'WST' => [
            'WST',
            'talayê somonî',
        ],
        'XAF' => [
            'FCFA',
            'frenkê CFA yê afrîkaya navîn',
        ],
        'XCD' => [
            'EC$',
            'dolarê karayîba rojhilatî',
        ],
        'XCG' => [
            'Cg.',
            'guldenê karayîbî',
        ],
        'XEU' => [
            'XEU',
            'Yekeya Pereyê ya Ewropayê',
        ],
        'XFO' => [
            'XFO',
            'Franka Fransî ya Zêrê',
        ],
        'XFU' => [
            'XFU',
            'Franka Fransî ya UICê',
        ],
        'XOF' => [
            'F CFA',
            'frankê CFA yê afrîkaya başûrî',
        ],
        'XPF' => [
            'CFPF',
            'frankê CFPî',
        ],
        'XRE' => [
            'XRE',
            'Fonên RINETê',
        ],
        'YDD' => [
            'YDD',
            'dînarê yemenî',
        ],
        'YER' => [
            'YER',
            'rîyalê yemenî',
        ],
        'YUD' => [
            'YUD',
            'hard dînarê yûgoslavî (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'dînarê nû ya yûgoslavî (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'dînarê konvertibl ya yûgoslavî (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'dînarê reformkirî ya yûgoslavî (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'randê afrîkaya başûrî (fînansî)',
        ],
        'ZAR' => [
            'ZAR',
            'randê afrîkaya başûrî',
        ],
        'ZMK' => [
            'ZMK',
            'kwaçayê zambîyayî (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'kwaçayê zambîyayî',
        ],
        'ZRN' => [
            'ZRN',
            'zaîreyê nû ya zaîreyî (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'zaîreyê zaîreyî (1971–1993)',
        ],
        'ZWD' => [
            'ZWD',
            'dolarê zîmbabweyî (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'zêrê zîmbabweyî',
        ],
        'ZWL' => [
            'ZWL',
            'dolarê zîmbabweyî (2009–2024)',
        ],
        'ZWR' => [
            'ZWR',
            'dolarê zîmbabweyî (2008)',
        ],
    ],
];
