<?php

return [
    'UserAssignedNames' => [
        'XK' => 'کوسوو',
    ],
    'Names' => [
        'AD' => 'اینڈورا',
        'AE' => 'مُتحدہ عرَب امارات',
        'AF' => 'اَفغانَستان',
        'AG' => 'اؠنٹِگُوا تہٕ باربوڑا',
        'AI' => 'انگوئیلا',
        'AL' => 'البانیا',
        'AM' => 'اَرمانِیا',
        'AO' => 'انگولا',
        'AQ' => 'اینٹارٹِکا',
        'AR' => 'أرجَنٹینا',
        'AS' => 'اَمریٖکَن سَموا',
        'AT' => 'آسٹریا',
        'AU' => 'آسٹریلِیا',
        'AW' => 'اَروٗبا',
        'AX' => 'ایلینڑ جٔزیٖرٕ',
        'AZ' => 'آذربائیجان',
        'BA' => 'بوسنِیا تہٕ ہَرزِگووِنا',
        'BB' => 'باربیڈوس',
        'BD' => 'بَنگلادیش',
        'BE' => 'بیلجِیَم',
        'BF' => 'بُرکِنا فیسو',
        'BG' => 'بَلجیرِیا',
        'BH' => 'بحریٖن',
        'BI' => 'بورَنڈِ',
        'BJ' => 'بِنِن',
        'BL' => 'سینٹ بارتَھیلمی',
        'BM' => 'برمودا',
        'BN' => 'برونے',
        'BO' => 'بولِوِیا',
        'BQ' => 'کیریبین نیدرلینڈس',
        'BR' => 'برازِل',
        'BS' => 'بَہامَس',
        'BT' => 'بوٗٹان',
        'BV' => 'بووَٹ جٔزیٖرٕ',
        'BW' => 'بوتَسوانا',
        'BY' => 'بیلاروٗس',
        'BZ' => 'بیلز',
        'CA' => 'کینیڈا',
        'CC' => 'کوکَس (کیٖلِنگ) جٔزیٖرٕ',
        'CD' => 'کونگو کِنشاسا',
        'CF' => 'مرکٔزی اَفریٖکی جموٗریَت',
        'CG' => 'کونگو بٔرزاوِلی',
        'CH' => 'سُوِزَرلینڑ',
        'CI' => 'کوٹ ڈلوائر',
        'CK' => 'کُک جٔزیٖرٕ',
        'CL' => 'چِلی',
        'CM' => 'کیمِروٗن',
        'CN' => 'چیٖن',
        'CO' => 'کولَمبِیا',
        'CR' => 'کوسٹا ریکا',
        'CU' => 'کیوٗبا',
        'CV' => 'کیپ ؤرڑی',
        'CW' => 'کیوراکو',
        'CX' => 'کرِسمَس جٔزیٖرٕ',
        'CY' => 'سائپرس',
        'CZ' => 'چیکیا',
        'DE' => 'جرمٔنی',
        'DJ' => 'جِبوٗتی',
        'DK' => 'ڈینمارٕک',
        'DM' => 'ڈومِنِکا',
        'DO' => 'ڈومِنِکَن جموٗرِیَت',
        'DZ' => 'اؠلجیرِیا',
        'EC' => 'اِکواڑور',
        'EE' => 'ایسٹونِیا',
        'EG' => 'مصر',
        'EH' => 'مشرِقی سَہارا',
        'ER' => 'اِرٕٹِیا',
        'ES' => 'سٕپین',
        'ET' => 'اِتھوپِیا',
        'FI' => 'فِن لینڈ',
        'FJ' => 'فِجی',
        'FK' => 'فٕلاکلینڑ جٔزیٖرٕ',
        'FM' => 'مائیکرونیشیا',
        'FO' => 'فارو جزیرہ',
        'FR' => 'فرانس',
        'GA' => 'گیبان',
        'GB' => 'متحدہ مملِکت',
        'GD' => 'گرینیڈا',
        'GE' => 'جارجِیا',
        'GF' => 'فرانسِسی گِانا',
        'GG' => 'گورنسے',
        'GH' => 'گانا',
        'GI' => 'جِبرالٹَر',
        'GL' => 'گرین لینڈ',
        'GM' => 'گَمبِیا',
        'GN' => 'گِنی',
        'GP' => 'گواڈلوپ',
        'GQ' => 'اِکوِٹورِیَل گِنی',
        'GR' => 'گریٖس',
        'GS' => 'جنوٗبی جارجِیا تہٕ جنوٗبی سینڑوٕچ جٔزیٖرٕ',
        'GT' => 'گواٹمالا',
        'GU' => 'گُوام',
        'GW' => 'گیٖنی بِساو',
        'GY' => 'گُیانا',
        'HK' => 'ہانگ کانگ ایس اے آر چیٖن',
        'HM' => 'ہَرٕڑ تہٕ مؠکڈونالڑٕ جٔزیٖرٕ',
        'HN' => 'ہونڈورس',
        'HR' => 'کروشِیا',
        'HT' => 'ہیتی',
        'HU' => 'ہَنگری',
        'ID' => 'انڈونیشیا',
        'IE' => 'اَیَرلینڑ',
        'IL' => 'اسرا ییل',
        'IM' => 'آیِل آف مین',
        'IN' => 'ہِندوستان',
        'IQ' => 'ایٖراق',
        'IR' => 'ایٖران',
        'IS' => 'اَیِسلینڑ',
        'IT' => 'اِٹلی',
        'JE' => 'جٔرسی',
        'JM' => 'جَمایکا',
        'JO' => 'جورڈن',
        'JP' => 'جاپان',
        'KE' => 'کِنیا',
        'KG' => 'کرغزستان',
        'KH' => 'کَمبوڑِیا',
        'KI' => 'کِرٕباتی',
        'KM' => 'کَمورَس',
        'KN' => 'سینٹ کِٹَس تہٕ نیوِس',
        'KP' => 'شُمٲلی کورِیا',
        'KR' => 'جنوٗبی کورِیا',
        'KW' => 'کُویت',
        'KY' => 'کیمَن جٔزیٖرٕ',
        'KZ' => 'قازقستان',
        'LA' => 'لاس',
        'LB' => 'لؠبنان',
        'LC' => 'سینٹ لوٗسِیا',
        'LI' => 'لِکٹیسٹیٖن',
        'LK' => 'سری لنکا',
        'LR' => 'لایبیرِیا',
        'LS' => 'لیسوتھو',
        'LT' => 'لِتھُوانِیا',
        'LU' => 'لَکسَمبٔرٕگ',
        'LV' => 'لیٹوِیا',
        'LY' => 'لِبیا',
        'MA' => 'موروکو',
        'MC' => 'مونیکو',
        'MD' => 'مولڈووا',
        'ME' => 'موٹونیگِریو',
        'MF' => 'سینٹ مارٹِن',
        'MG' => 'میڈاگاسکار',
        'MH' => 'مارشَل جٔزیٖرٕ',
        'MK' => 'شُمالی میسڈونیا',
        'ML' => 'مالی',
        'MM' => 'میانمار (برما)',
        'MN' => 'مَنگولِیا',
        'MO' => 'مَکاوو ایس اے آر چیٖن',
        'MP' => 'شُمٲلی مارِیانا جٔزیٖرٕ',
        'MQ' => 'مارٹِنِک',
        'MR' => 'مارٕٹانِیا',
        'MS' => 'مانٹسیراٹ',
        'MT' => 'مالٹا',
        'MU' => 'مورِشَس',
        'MV' => 'مالدیٖو',
        'MW' => 'ملاوی',
        'MX' => 'مؠکسِکو',
        'MY' => 'مَلیشِیا',
        'MZ' => 'موزَمبِک',
        'NA' => 'نامِبِیا',
        'NC' => 'نِو کیلِڑونِیا',
        'NE' => 'نایجَر',
        'NF' => 'نارفاک جٔزیٖرٕ',
        'NG' => 'نایجیرِیا',
        'NI' => 'ناکاراگُوا',
        'NL' => 'نیٖدَرلینڑ',
        'NO' => 'ناروے',
        'NP' => 'نیپال',
        'NR' => 'نارووٗ',
        'NU' => 'نیوٗ',
        'NZ' => 'نیوزی لینڈ',
        'OM' => 'اومان',
        'PA' => 'پَناما',
        'PE' => 'پیٖروٗ',
        'PF' => 'فرانسی پولِنیشِیا',
        'PG' => 'پاپُوا نیوٗ گیٖنی',
        'PH' => 'فلپائن',
        'PK' => 'پاکِستان',
        'PL' => 'پولینڈ',
        'PM' => 'سینٹ پیٖری تہٕ موکیلِیَن',
        'PN' => 'پِٹکیرٕنؠ جٔزیٖرٕ',
        'PR' => 'پٔرٹو رِکو',
        'PS' => 'فلسطینی علاقٕہ',
        'PT' => 'پُرتِگال',
        'PW' => 'پَلاو',
        'PY' => 'پَراگُے',
        'QA' => 'قَطِر',
        'RE' => 'رِیوٗنِیَن',
        'RO' => 'رومانِیا',
        'RS' => 'سَربِیا',
        'RU' => 'روٗس',
        'RW' => 'روٗوانڈا',
        'SA' => 'سعودی عرب',
        'SB' => 'سولامان جٔزیٖرٕ',
        'SC' => 'سیشَلِس',
        'SD' => 'سوٗڈان',
        'SE' => 'سویڈن',
        'SG' => 'سِنگاپوٗر',
        'SH' => 'سینٹ ہؠلِنا',
        'SI' => 'سَلووینِیا',
        'SJ' => 'سَوالبریڑ تہٕ جان ماییڑ',
        'SK' => 'سَلوواکِیا',
        'SL' => 'سیرا لیون',
        'SM' => 'سین میرِنو',
        'SN' => 'سینیگَل',
        'SO' => 'سومالِیا',
        'SR' => 'سُرِنام',
        'SS' => 'جنوبی سوڈان',
        'ST' => 'ساو توم تہٕ پرنسِپی',
        'SV' => 'ایل سلویڈر',
        'SX' => 'سِنٹ مارٹِن',
        'SY' => 'شام',
        'SZ' => 'ایسواتنی',
        'TC' => 'تُرکس تٕہ کیکو جزیرٕ',
        'TD' => 'چاڑ',
        'TF' => 'فرانسِسی جَنوٗبی عَلاقہٕ',
        'TG' => 'ٹوگو',
        'TH' => 'تھائی لینڈ',
        'TJ' => 'تاجکِستان',
        'TK' => 'ٹوکلو',
        'TL' => 'تیمور-لیسٹ',
        'TM' => 'تُرکمنستان',
        'TN' => 'ٹونیشِیا',
        'TO' => 'ٹونگا',
        'TR' => 'تُرکی',
        'TT' => 'ٹرنِنداد تہٕ ٹوبیگو',
        'TV' => 'توٗوالوٗ',
        'TW' => 'تایوان',
        'TZ' => 'تَنجانِیا',
        'UA' => 'یوٗرِکین',
        'UG' => 'یوٗگانڑا',
        'UM' => 'یوٗنایٹِڑ سِٹیٹِس ماینَر آوُٹلییِنگ جٔزیٖرٕ',
        'US' => 'یوٗنایٹِڑ سِٹیٹِس',
        'UY' => 'یوٗروگے',
        'UZ' => 'اُزبِکِستان',
        'VA' => 'ویٹِکَن سِٹی',
        'VC' => 'سینٹ وینسؠٹ تہٕ گریناڑاینٕز',
        'VE' => 'وینازوٗلا',
        'VG' => 'بَرطانوی ؤرجِن جٔزیٖرٕ',
        'VI' => 'یوٗ ایس ؤرجِن جٔزیٖرٕ',
        'VN' => 'ویتنام',
        'VU' => 'وانوٗتوٗ',
        'WF' => 'والِس تہٕ فیوٗچوٗنا',
        'WS' => 'سامو',
        'YE' => 'یَمَن',
        'YT' => 'مَییٹ',
        'ZA' => 'جنوبی افریقہ',
        'ZM' => 'زیمبیا',
        'ZW' => 'زِمبابے',
    ],
];
