<?php

return [
    'Names' => [
        'ar_EH' => 'árabe (Sahara Occidental)',
        'tn' => 'setswana',
        'tn_BW' => 'setswana (Botsuana)',
        'tn_ZA' => 'setswana (Sudáfrica)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
    ],
];
