<?php

return [
    'Names' => [
        'aa' => 'lea fakaʻafāla',
        'ab' => 'lea fakaʻapakasia',
        'ace' => 'lea fakaʻatisē',
        'ach' => 'lea fakaʻakoli',
        'ada' => 'lea fakaʻatangimē',
        'ady' => 'lea fakaʻatikē',
        'ae' => 'lea fakaʻavesitani',
        'aeb' => 'lea fakaʻalepea-tunīsia',
        'af' => 'lea fakaʻafilikana',
        'afh' => 'lea fakaʻafilihili',
        'agq' => 'lea fakaʻakihemi',
        'ain' => 'lea fakaʻainu',
        'ak' => 'lea fakaʻakani',
        'akk' => 'lea fakaʻakatia',
        'akz' => 'lea fakaʻalapama',
        'ale' => 'lea fakaʻaleuti',
        'aln' => 'lea fakaʻalapēnia-keki',
        'alt' => 'lea fakaʻalitai-tonga',
        'am' => 'lea fakaʻameliki',
        'an' => 'lea fakaʻalakoni',
        'ang' => 'lea fakapālangi-motuʻa',
        'ann' => 'lea fakaʻopolo',
        'anp' => 'lea fakaʻangika',
        'ar' => 'lea fakaʻalepea',
        'arc' => 'lea fakaʻalāmiti',
        'arn' => 'lea fakamapuse',
        'aro' => 'lea fakaʻalaona',
        'arp' => 'lea fakaʻalapaho',
        'arq' => 'lea fakaʻalepea-ʻaisilia',
        'ars' => 'lea fakaʻalepea-nāsiti',
        'arw' => 'lea fakaʻalauaki',
        'ary' => 'lea fakaʻalepea-moloko',
        'arz' => 'lea fakaʻalepea-ʻisipite',
        'as' => 'lea fakaʻasamia',
        'asa' => 'lea fakaʻasu',
        'ase' => 'lea fakaʻilonga-ʻamelika',
        'ast' => 'lea fakaʻasitūlia',
        'atj' => 'lea fakaʻatikameku',
        'av' => 'lea fakaʻavaliki',
        'avk' => 'lea fakakotava',
        'awa' => 'lea fakaʻauati',
        'ay' => 'lea fakaʻaimala',
        'az' => 'lea fakaʻasepaisani',
        'ba' => 'lea fakapasikili',
        'bal' => 'lea fakapalusi',
        'ban' => 'lea fakapali',
        'bar' => 'lea fakapavālia',
        'bas' => 'lea fakapasaʻa',
        'bax' => 'lea fakapamuni',
        'bbc' => 'lea fakatōpe-pēteki',
        'bbj' => 'lea fakakomala',
        'be' => 'lea fakapelalusi',
        'bej' => 'lea fakapesa',
        'bem' => 'lea fakapēmipa',
        'bew' => 'lea fakapetavi',
        'bez' => 'lea fakapena',
        'bfd' => 'lea fakapafuti',
        'bfq' => 'lea fakapataka',
        'bg' => 'lea fakapulukalia',
        'bgc' => 'lea fakahalaiānivi',
        'bgn' => 'lea fakapalusi-hihifo',
        'bho' => 'lea fakaposipuli',
        'bi' => 'lea fakapisilama',
        'bik' => 'lea fakapikoli',
        'bin' => 'lea fakapini',
        'bjn' => 'lea fakapanisali',
        'bkm' => 'lea fakakome',
        'bla' => 'lea fakasikesikā',
        'bm' => 'lea fakapamipala',
        'bn' => 'lea fakapāngilā',
        'bo' => 'lea fakatipeti',
        'bpy' => 'lea fakapisinupilia',
        'bqi' => 'lea fakapakitiāli',
        'br' => 'lea fakapeletoni',
        'bra' => 'lea fakapalai',
        'brh' => 'lea fakapalahui',
        'brx' => 'lea fakapōto',
        'bs' => 'lea fakaposinia',
        'bss' => 'lea fakaʻakōse',
        'bua' => 'lea fakapuliati',
        'bug' => 'lea fakapukisi',
        'bum' => 'lea fakapulu',
        'byn' => 'lea fakapilini',
        'byv' => 'lea fakametūmipa',
        'ca' => 'lea fakakatalani',
        'cad' => 'lea fakakato',
        'car' => 'lea fakakalipa',
        'cay' => 'lea fakakaiuka',
        'cch' => 'lea fakaʻatisami',
        'ccp' => 'lea fakasākima',
        'ce' => 'lea fakasese',
        'ceb' => 'lea fakasepuano',
        'cgg' => 'lea fakakika',
        'ch' => 'lea fakakamolo',
        'chb' => 'lea fakasīpisa',
        'chg' => 'lea fakasakatāi',
        'chk' => 'lea fakatūke',
        'chm' => 'lea fakamalī',
        'chn' => 'lea fakasinuki-takote',
        'cho' => 'lea fakasokitau',
        'chp' => 'lea fakasipeuiani',
        'chr' => 'lea fakaselokī',
        'chy' => 'lea fakaseiene',
        'ckb' => 'lea fakakūtisi-loloto',
        'clc' => 'lea fakatisilikōtini',
        'co' => 'lea fakakōsika',
        'cop' => 'lea fakakopitika',
        'cps' => 'lea fakakapiseno',
        'cr' => 'lea fakakelī',
        'crg' => 'lea fakametisifi',
        'crh' => 'lea fakatatali-kilimea',
        'crj' => 'lea fakakilī-tongahahake',
        'crk' => 'lea fakakilī-toafa',
        'crl' => 'lea fakakilī-tokelauhahake',
        'crm' => 'lea fakamose-kilī',
        'crr' => 'lea fakaʻalakonikuia-kalolina',
        'crs' => 'lea fakaseselua-falanisē',
        'cs' => 'lea fakaseki',
        'csb' => 'lea fakakasiupia',
        'csw' => 'lea fakakilī-ano',
        'cu' => 'lea fakasilavia-fakasiasi',
        'cv' => 'lea fakasuvasa',
        'cy' => 'lea fakauēlesi',
        'da' => 'lea fakatenimaʻake',
        'dak' => 'lea fakatakota',
        'dar' => 'lea fakatalakuā',
        'dav' => 'lea fakataita',
        'de' => 'lea fakasiamane',
        'del' => 'lea fakatelauale',
        'den' => 'lea fakasilave',
        'dgr' => 'lea fakatōkelipi',
        'din' => 'lea fakatingikā',
        'dje' => 'lea fakatisāma',
        'doi' => 'lea fakatokili',
        'dsb' => 'lea fakasōpia-hifo',
        'dtp' => 'lea fakatusuni-loloto',
        'dua' => 'lea fakatuala',
        'dum' => 'lea fakahōlani-lotoloto',
        'dv' => 'lea fakativehi',
        'dyo' => 'lea fakaiola-fonī',
        'dyu' => 'lea fakatiula',
        'dz' => 'lea fakatisōngika',
        'dzg' => 'lea fakatasaka',
        'ebu' => 'lea fakaʻemipū',
        'ee' => 'lea fakaʻeue',
        'efi' => 'lea fakaʻefiki',
        'egl' => 'lea fakaʻemilia',
        'egy' => 'lea fakaʻisipitemuʻa',
        'eka' => 'lea fakaʻekaiuki',
        'el' => 'lea fakakalisi',
        'elx' => 'lea fakaʻelamite',
        'en' => 'lea fakapālangi',
        'enm' => 'lea fakapālangi-lotoloto',
        'eo' => 'lea fakaʻesipulanito',
        'es' => 'lea fakasipēnisi',
        'esu' => 'lea fakaiūpiki-loloto',
        'et' => 'lea fakaʻesitōnia',
        'eu' => 'lea fakapāsiki',
        'ewo' => 'lea fakaʻeuōnito',
        'ext' => 'lea fakaʻekisitematula',
        'fa' => 'lea fakapēsia',
        'fan' => 'lea fakafangi',
        'fat' => 'lea fakafanitē',
        'ff' => 'lea fakafulā',
        'fi' => 'lea fakafinilani',
        'fil' => 'lea fakafilipaini',
        'fit' => 'lea fakafinilani-tōnetale',
        'fj' => 'lea fakafisi',
        'fo' => 'lea fakafaloe',
        'fon' => 'lea fakafōngi',
        'fr' => 'lea fakafalanisē',
        'frc' => 'lea fakafalanisē-kasuni',
        'frm' => 'lea fakafalanisē-lotoloto',
        'fro' => 'lea fakafalanisē-motuʻa',
        'frp' => 'lea fakaʻāpitano',
        'frr' => 'lea fakafilisia-tokelau',
        'frs' => 'lea fakafilisia-hahake',
        'fur' => 'lea fakafulilāni',
        'fy' => 'lea fakafilisia-hihifo',
        'ga' => 'lea fakaʻaelani',
        'gaa' => 'lea fakakā',
        'gag' => 'lea fakakakausi',
        'gan' => 'lea fakasiaina-kani',
        'gay' => 'lea fakakaio',
        'gba' => 'lea fakakapaia',
        'gbz' => 'lea fakateli-soloasitelia',
        'gd' => 'lea fakakaeliki',
        'gez' => 'lea fakasiʻisi',
        'gil' => 'lea fakakilipasi',
        'gl' => 'lea fakakalisia',
        'glk' => 'lea fakakilaki',
        'gmh' => 'lea fakasiamane-hake-lotoloto',
        'gn' => 'lea fakakualani',
        'goh' => 'lea fakasiamane-hake-motuʻa',
        'gon' => 'lea fakakonitī',
        'gor' => 'lea fakakolonitalo',
        'got' => 'lea fakakotika',
        'grb' => 'lea fakakēpo',
        'grc' => 'lea fakakalisimuʻa',
        'gsw' => 'lea fakasiamane-suisilani',
        'gu' => 'lea fakakutalati',
        'guc' => 'lea fakaʻuaiū',
        'gur' => 'lea fakafalefale',
        'guz' => 'lea fakakusī',
        'gv' => 'lea fakamangikī',
        'gwi' => 'lea fakaʻuīsini',
        'ha' => 'lea fakahausa',
        'hai' => 'lea fakahaita',
        'hak' => 'lea fakasiaina-haka',
        'haw' => 'lea fakahauaiʻi',
        'hax' => 'lea fakahaita-tonga',
        'he' => 'lea fakahepelū',
        'hi' => 'lea fakahinitī',
        'hif' => 'lea fakahinitī-fisi',
        'hil' => 'lea fakahilikainoni',
        'hit' => 'lea fakahitite',
        'hmn' => 'lea fakamōngi',
        'ho' => 'lea fakahili-motu',
        'hr' => 'lea fakakuloisia',
        'hsb' => 'lea fakasōpia-hake',
        'hsn' => 'lea fakasiaina-siangi',
        'ht' => 'lea fakahaiti',
        'hu' => 'lea fakahungakalia',
        'hup' => 'lea fakahupa',
        'hur' => 'lea fakahalikomele',
        'hy' => 'lea fakaʻāmenia',
        'hz' => 'lea fakahelelo',
        'ia' => 'lea fakavahaʻalea',
        'iba' => 'lea fakaʻipani',
        'ibb' => 'lea fakaʻipipio',
        'id' => 'lea fakaʻinitōnesia',
        'ie' => 'lea fakavahaʻalingikē',
        'ig' => 'lea fakaʻikipō',
        'ii' => 'lea fakasisiuani-ī',
        'ik' => 'lea fakaʻinupiaki',
        'ikt' => 'lea fakaʻinuketītuti-kānata-hihifo',
        'ilo' => 'lea fakaʻiloko',
        'inh' => 'lea fakaʻingusi',
        'io' => 'lea fakaʻito',
        'is' => 'lea fakaʻaisilani',
        'it' => 'lea fakaʻītali',
        'iu' => 'lea fakaʻinuketītuti',
        'izh' => 'lea fakaʻingiliani',
        'ja' => 'lea fakasiapani',
        'jam' => 'lea fakapālangi-samaika',
        'jbo' => 'lea fakalosipani',
        'jgo' => 'lea fakanikōmipa',
        'jmc' => 'lea fakamasame',
        'jpr' => 'lea fakaʻiuteo-pēsia',
        'jrb' => 'lea fakaʻiuteo-ʻalepea',
        'jut' => 'lea fakaʻiutilani',
        'jv' => 'lea fakasava',
        'ka' => 'lea fakaseōsia',
        'kaa' => 'lea fakakala-kalipaki',
        'kab' => 'lea fakakapile',
        'kac' => 'lea fakakasini',
        'kaj' => 'lea fakasisū',
        'kam' => 'lea fakakamipa',
        'kaw' => 'lea fakakavi',
        'kbd' => 'lea fakakapālitia',
        'kbl' => 'lea fakakanēmipu',
        'kcg' => 'lea fakatiapi',
        'kde' => 'lea fakamakōnite',
        'kea' => 'lea fakakapuvelitianu',
        'ken' => 'lea fakakeniangi',
        'kfo' => 'lea fakakolo',
        'kg' => 'lea fakakongikō',
        'kgp' => 'lea fakakaingangi',
        'kha' => 'lea fakakāsi',
        'kho' => 'lea fakakōtani',
        'khq' => 'lea fakakoila-sīni',
        'khw' => 'lea fakakouali',
        'ki' => 'lea fakakikuiu',
        'kiu' => 'lea fakakilimanisikī',
        'kj' => 'lea fakakuaniama',
        'kk' => 'lea fakakasaki',
        'kkj' => 'lea fakakako',
        'kl' => 'lea fakakalaʻalisuti',
        'kln' => 'lea fakakalenisini',
        'km' => 'lea fakakamipōtia',
        'kmb' => 'lea fakakimipūnitu',
        'kn' => 'lea fakakanata',
        'ko' => 'lea fakakōlea',
        'koi' => 'lea fakakomi-pelemiaki',
        'kok' => 'lea fakakonikanī',
        'kos' => 'lea fakakosilae',
        'kpe' => 'lea fakakepele',
        'kr' => 'lea fakakanuli',
        'krc' => 'lea fakakalate-palakili',
        'kri' => 'lea fakakilio',
        'krj' => 'lea fakakinaraiā',
        'krl' => 'lea fakakalelia',
        'kru' => 'lea fakakuluki',
        'ks' => 'lea fakakāsimila',
        'ksb' => 'lea fakasiamipala',
        'ksf' => 'lea fakapafia',
        'ksh' => 'lea fakakolongia',
        'ku' => 'lea fakakulitī',
        'kum' => 'lea fakakumiki',
        'kut' => 'lea fakakutenai',
        'kv' => 'lea fakakomi',
        'kw' => 'lea fakakoniuali',
        'kwk' => 'lea fakakuakuala',
        'ky' => 'lea fakakīsisi',
        'la' => 'lea fakalatina',
        'lad' => 'lea fakalatino',
        'lag' => 'lea fakalangi',
        'lah' => 'lea fakapunisapi-hihifoi',
        'lam' => 'lea fakalamipā',
        'lb' => 'lea fakalakisimipeki',
        'lez' => 'lea fakalesikia',
        'lfn' => 'lea fakakavakava-foʻou',
        'lg' => 'lea fakakanita',
        'li' => 'lea fakalimipūliki',
        'lij' => 'lea fakalikulia',
        'lil' => 'lea fakalilōeti',
        'liv' => 'lea fakalivonia',
        'lkt' => 'lea fakalakota',
        'lmo' => 'lea fakalomipāti',
        'ln' => 'lea lingikala',
        'lo' => 'lea fakalau',
        'lol' => 'lea fakamongikō',
        'lou' => 'lea fakaluisiana',
        'loz' => 'lea fakalosi',
        'lrc' => 'lea fakaluli-tokelau',
        'lsm' => 'lea fakasāmia',
        'lt' => 'lea fakalituania',
        'ltg' => 'lea fakalatakale',
        'lu' => 'lea fakalupa-katanga',
        'lua' => 'lea fakalupa-lulua',
        'lui' => 'lea fakaluiseno',
        'lun' => 'lea fakalunitā',
        'luo' => 'lea fakaluo',
        'lus' => 'lea fakamiso',
        'luy' => 'lea fakaluīa',
        'lv' => 'lea fakalativia',
        'lzh' => 'lea fakasiaina-faʻutohi',
        'lzz' => 'lea fakalasu',
        'mad' => 'lea fakamatula',
        'maf' => 'lea fakamafa',
        'mag' => 'lea fakamakahi',
        'mai' => 'lea fakamaitili',
        'mak' => 'lea fakamakasali',
        'man' => 'lea fakamanitīngiko',
        'mas' => 'lea fakamasai',
        'mde' => 'lea fakamapa',
        'mdf' => 'lea fakamokisiā',
        'mdr' => 'lea fakamanetali',
        'men' => 'lea fakamenetī',
        'mer' => 'lea fakamelu',
        'mfe' => 'lea fakamolisieni',
        'mg' => 'lea fakamalakasi',
        'mga' => 'lea fakaʻaelani-lotoloto',
        'mgh' => 'lea fakamakūa-meʻeto',
        'mgo' => 'lea fakametā',
        'mh' => 'lea fakamāsolo',
        'mi' => 'lea fakamāuli',
        'mic' => 'lea fakamikemaki',
        'min' => 'lea fakaminangikapau',
        'mk' => 'lea fakamasitōnia',
        'ml' => 'lea fakaʻinitia-malāialami',
        'mn' => 'lea fakamongokōlia',
        'mnc' => 'lea fakamanisū',
        'mni' => 'lea fakamanipuli',
        'moe' => 'lea fakaʻinuʻaimuni',
        'moh' => 'lea fakamohauki',
        'mos' => 'lea fakamosi',
        'mr' => 'lea fakamalati',
        'mrj' => 'lea fakamali-hihifo',
        'ms' => 'lea fakamalei',
        'mt' => 'lea fakamalita',
        'mua' => 'lea fakamunitangi',
        'mus' => 'lea fakakileki',
        'mwl' => 'lea fakamilanitēsi',
        'mwr' => 'lea fakamaliwali',
        'mwv' => 'lea fakamenitauai',
        'my' => 'lea fakapema',
        'mye' => 'lea fakamiene',
        'myv' => 'lea fakaʻelisia',
        'mzn' => 'lea fakamasanitelani',
        'na' => 'lea fakanaulu',
        'nan' => 'lea fakasiaina-mininani',
        'nap' => 'lea fakanapoletano',
        'naq' => 'lea fakanama',
        'nb' => 'lea fakanouaē-pokimali',
        'nd' => 'lea fakanetepele-tokelau',
        'nds' => 'lea fakasiamane-hifo',
        'ne' => 'lea fakanepali',
        'new' => 'lea fakaneuali',
        'ng' => 'lea fakanetongikā',
        'nia' => 'lea fakaniasi',
        'niu' => 'lea fakaniuē',
        'njo' => 'lea fakaʻaonasa',
        'nl' => 'lea fakahōlani',
        'nmg' => 'lea fakakuasio',
        'nn' => 'lea fakanoauē-ninosiki',
        'nnh' => 'lea fakangiemipōni',
        'no' => 'lea fakanouaē',
        'nog' => 'lea fakanokai',
        'non' => 'lea fakanoauē-motuʻa',
        'nov' => 'lea fakanoviale',
        'nqo' => 'lea fakanikō',
        'nr' => 'lea fakanetepele-tonga',
        'nso' => 'lea fakasoto-tokelau',
        'nus' => 'lea fakanueli',
        'nv' => 'lea fakanavaho',
        'nwc' => 'lea fakaneuali-motuʻa',
        'ny' => 'lea fakanianisa',
        'nym' => 'lea fakaniamiuesi',
        'nyn' => 'lea fakanianikole',
        'nyo' => 'lea fakaniolo',
        'nzi' => 'lea fakanesima',
        'oc' => 'lea fakaʻokitane',
        'oj' => 'lea fakaʻosipiuā',
        'ojb' => 'lea fakaʻosipiuā-tokelauhihifo',
        'ojc' => 'lea fakaʻosipiuā-loto',
        'ojs' => 'lea fakakilī-osi',
        'ojw' => 'lea fakaʻosipiuā-hihifo',
        'oka' => 'lea faka-ʻokanākani',
        'om' => 'lea fakaʻolomo',
        'or' => 'lea fakaʻotia',
        'os' => 'lea fakaʻosetiki',
        'osa' => 'lea fakaʻosēse',
        'ota' => 'lea fakatoake-ʻotomani',
        'pa' => 'lea fakapūnusapi',
        'pag' => 'lea fakapangasinani',
        'pal' => 'lea fakapālavi',
        'pam' => 'lea fakapamipanga',
        'pap' => 'lea fakapapiamēnito',
        'pau' => 'lea fakapalau',
        'pcd' => 'lea fakapikāti',
        'pcm' => 'lea fakanaisilia',
        'pdc' => 'lea fakasiamane-penisilivania',
        'pdt' => 'lea fakasiamane-lafalafa',
        'peo' => 'lea fakapēsia-motuʻa',
        'pfl' => 'lea fakasiamane-palatine',
        'phn' => 'lea fakafoinikia',
        'pi' => 'lea fakapāli',
        'pis' => 'lea fakapisini',
        'pl' => 'lea fakapolani',
        'pms' => 'lea fakapiemonite',
        'pnt' => 'lea fakaponitiki',
        'pon' => 'lea fakaponapē',
        'pqm' => 'lea fakamaliseti-pasamakuoti',
        'prg' => 'lea fakapulūsia',
        'pro' => 'lea fakapolovenisi-motuʻa',
        'ps' => 'lea fakapasitō',
        'pt' => 'lea fakapotukali',
        'qu' => 'lea fakakuetisa',
        'quc' => 'lea fakakīsē',
        'qug' => 'lea fakakuitisa-simipolaso',
        'raj' => 'lea fakalasasitani',
        'rap' => 'lea fakalapanui',
        'rar' => 'lea fakalalotonga',
        'rgn' => 'lea fakalomaniolo',
        'rhg' => 'lea fakalouhingia',
        'rif' => 'lea fakalifi',
        'rm' => 'lea fakalaito-lomēnia',
        'rn' => 'lea fakaluaniti',
        'ro' => 'lea fakalōmenia',
        'rof' => 'lea fakalomipō',
        'rom' => 'lea fakalomani',
        'rtm' => 'lea fakalotuma',
        'ru' => 'lea fakalūsia',
        'rue' => 'lea fakalusini',
        'rug' => 'lea fakaloviana',
        'rup' => 'lea fakaʻalomania',
        'rw' => 'lea fakakiniāuanita',
        'rwk' => 'lea fakaluā',
        'sa' => 'lea fakasanisukuliti',
        'sad' => 'lea fakasanitaue',
        'sah' => 'lea fakaiakuti',
        'sam' => 'lea fakasamalitani-ʻalāmiti',
        'saq' => 'lea fakasamipulu',
        'sas' => 'lea fakasasaki',
        'sat' => 'lea fakasanitali',
        'saz' => 'lea fakasaulasitilā',
        'sba' => 'lea fakangāmipai',
        'sbp' => 'lea fakasangu',
        'sc' => 'lea fakasaletīnia',
        'scn' => 'lea fakasisīlia',
        'sco' => 'lea fakasikotilani',
        'sd' => 'lea fakasīniti',
        'sdc' => 'lea fakasaletīnia-sasalesu',
        'sdh' => 'lea faka-tonga ‘o Ketesi',
        'se' => 'lea fakasami-tokelau',
        'see' => 'lea fakaseneka',
        'seh' => 'lea fakasena',
        'sei' => 'lea fakaseli',
        'sel' => 'lea fakaselikupi',
        'ses' => 'lea fakakoilapolo-seni',
        'sg' => 'lea fakasangikō',
        'sga' => 'lea fakaʻaelani-motuʻa',
        'sgs' => 'lea fakasamositia',
        'sh' => 'lea fakakuloisia-sēpia',
        'shi' => 'lea fakataselihiti',
        'shn' => 'lea fakasiani',
        'shu' => 'lea fakaʻalepea-sāti',
        'si' => 'lea fakasingihala',
        'sid' => 'lea fakasitamo',
        'sk' => 'lea fakasolāvaki',
        'sl' => 'lea fakasolovenia',
        'slh' => 'lea fakalusūtisiti',
        'sli' => 'lea fakasilesia-hifo',
        'sly' => 'lea fakaselaiā',
        'sm' => 'lea fakahaʻamoa',
        'sma' => 'lea fakasami-tonga',
        'smj' => 'lea fakasami-lule',
        'smn' => 'lea fakasami-ʻinali',
        'sms' => 'lea fakasami-sikolita',
        'sn' => 'lea fakasiona',
        'snk' => 'lea fakasoninekē',
        'so' => 'lea fakasomali',
        'sog' => 'lea fakasokitiana',
        'sq' => 'lea fakaʻalapēnia',
        'sr' => 'lea fakasēpia',
        'srn' => 'lea fakasulanane-tongikō',
        'srr' => 'lea fakasēlēle',
        'ss' => 'lea fakasuati',
        'ssy' => 'lea fakasaho',
        'st' => 'lea fakasoto-tonga',
        'stq' => 'lea fakafilisia-satēlani',
        'str' => 'lea fakasalisi-vahatokelau',
        'su' => 'lea fakasunitā',
        'suk' => 'lea fakasukuma',
        'sus' => 'lea fakasusū',
        'sux' => 'lea fakasumelia',
        'sv' => 'lea fakasuēteni',
        'sw' => 'lea fakasuahili',
        'swb' => 'lea fakakomolo',
        'syc' => 'lea fakasuliāiā-muʻa',
        'syr' => 'lea fakasuliāiā',
        'szl' => 'lea fakasilesia',
        'ta' => 'lea fakatamili',
        'tce' => 'lea fakatutisone-tonga',
        'tcy' => 'lea fakatulu',
        'te' => 'lea fakaʻinitia-teluku',
        'tem' => 'lea fakatimenē',
        'teo' => 'lea fakateso',
        'ter' => 'lea fakateleno',
        'tet' => 'lea fakatetumu',
        'tg' => 'lea fakatāsiki',
        'tgx' => 'lea fakatākisi',
        'th' => 'lea fakatailani',
        'tht' => 'lea fakatālitāni',
        'ti' => 'lea fakatikilinia',
        'tig' => 'lea fakatikilē',
        'tiv' => 'lea fakativi',
        'tk' => 'lea fakatēkimeni',
        'tkl' => 'lea fakatokelau',
        'tkr' => 'lea fakasākuli',
        'tl' => 'lea fakatakāloka',
        'tlh' => 'lea fakakilingoni',
        'tli' => 'lea fakatilingikīte',
        'tly' => 'lea fakatalisi',
        'tmh' => 'lea fakatamasieki',
        'tn' => 'lea fakatisuana',
        'to' => 'lea fakatonga',
        'tog' => 'lea fakaniasa-tonga',
        'tok' => 'lea fakatoki-pona',
        'tpi' => 'lea fakatoki-pisini',
        'tr' => 'lea fakatoake',
        'tru' => 'lea fakatuloio',
        'trv' => 'lea fakataloko',
        'ts' => 'lea fakatisonga',
        'tsd' => 'lea fakasakōnia',
        'tsi' => 'lea fakatisīmisiani',
        'tt' => 'lea fakatatale',
        'ttm' => 'lea fakatutisone-tokelau',
        'ttt' => 'lea fakatati-moselemi',
        'tum' => 'lea fakatumepuka',
        'tvl' => 'lea fakatūvalu',
        'tw' => 'lea fakatusuī',
        'twq' => 'lea fakatasauaki',
        'ty' => 'lea fakatahiti',
        'tyv' => 'lea fakatuvīnia',
        'tzm' => 'lea fakatamasaiti-ʻatilasi-loloto',
        'udm' => 'lea fakaʻutimuliti',
        'ug' => 'lea fakaʻuikūli',
        'uga' => 'lea fakaʻūkaliti',
        'uk' => 'lea fakaʻūkalaʻine',
        'umb' => 'lea fakaʻumipūnitu',
        'ur' => 'lea fakaʻūtū',
        'uz' => 'lea fakaʻusipeki',
        'vai' => 'lea fakavai',
        've' => 'lea fakavenitā',
        'vec' => 'lea fakavenēsia',
        'vep' => 'lea fakavepisi',
        'vi' => 'lea fakavietinami',
        'vls' => 'lea fakavelamingi-hihifo',
        'vmf' => 'lea fakafalanikoni-loloto',
        'vo' => 'lea fakavolapiki',
        'vot' => 'lea fakavotiki',
        'vro' => 'lea fakavōlo',
        'vun' => 'lea fakavūniso',
        'wa' => 'lea fakaʻualonia',
        'wae' => 'lea fakaʻualiseli',
        'wal' => 'lea fakaʻuolaita',
        'war' => 'lea fakaʻualai',
        'was' => 'lea fakaʻuasiō',
        'wbp' => 'lea fakaʻuālipili',
        'wo' => 'lea fakaʻuolofo',
        'wuu' => 'lea fakasiaina-uū',
        'xal' => 'lea fakakalimiki',
        'xh' => 'lea fakatōsa',
        'xmf' => 'lea fakamingilelia',
        'xog' => 'lea fakasoka',
        'yao' => 'lea fakaʻiao',
        'yap' => 'lea fakaʻiapi',
        'yav' => 'lea fakaʻiangipeni',
        'ybb' => 'lea fakaʻiēmipa',
        'yi' => 'lea fakaītisi',
        'yo' => 'lea fakaʻiōlupa',
        'yrl' => 'lea fakaneʻēngatū',
        'yue' => 'lea fakakuangitongi',
        'za' => 'lea fakasuangi',
        'zap' => 'lea fakasapoteki',
        'zbl' => 'lea fakaʻilonga-pilisi',
        'zea' => 'lea fakasēlani',
        'zen' => 'lea fakasenaka',
        'zgh' => 'lea fakatamasaiti-moloko',
        'zh' => 'lea fakasiaina',
        'zu' => 'lea fakasulu',
        'zun' => 'lea fakasuni',
        'zza' => 'lea fakasāsā',
    ],
    'LocalizedNames' => [
        'ar_001' => 'lea fakaʻalepea (māmani)',
        'de_AT' => 'lea fakasiamane-ʻaositulia',
        'de_CH' => 'lea fakasiamane-hake-suisilani',
        'en_AU' => 'lea fakapālangi-ʻaositelēlia',
        'en_CA' => 'lea fakapālangi-kānata',
        'en_GB' => 'lea fakapilitānia',
        'en_US' => 'lea fakapālangi-ʻamelika',
        'es_419' => 'lea fakasipeini-lātini-ʻamelika',
        'es_ES' => 'lea fakasipeini-ʻeulope',
        'es_MX' => 'lea fakasipeini-mekisikou',
        'fa_AF' => 'lea fakapēsia (ʻtalī)',
        'fr_CA' => 'lea fakafalanisē-kānata',
        'fr_CH' => 'lea fakafalanisē-suisilani',
        'hi_Latn' => 'lea fakahinitī (fakalatina)',
        'nds_NL' => 'lea fakasakisoni-hifo',
        'nl_BE' => 'lea fakahōlani-pelesiume',
        'ro_MD' => 'lea fakamolitāvia',
        'sw_CD' => 'lea fakasuahili-kongikō',
        'zh_Hans' => 'lea fakasiaina-fakafaingofua',
        'zh_Hant' => 'lea fakasiaina-tukufakaholo',
    ],
];
