<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Arab' => 'Arabaidd',
        'Aran' => 'Nastaliq',
        'Armn' => 'Armenaidd',
        'Beng' => 'Bangla',
        'Bopo' => 'Bopomofo',
        'Brai' => 'Braille',
        'Cakm' => 'Chakma',
        'Cans' => 'Meysydd Llafur Cynfrodorol Unedig Canada',
        'Cher' => 'Cherokee',
        'Cyrl' => 'Cyrilig',
        'Deva' => 'Devanagari',
        'Ethi' => 'Ethiopig',
        'Geor' => 'Georgaidd',
        'Grek' => 'Groegaidd',
        'Gujr' => 'Gwjarataidd',
        'Guru' => 'Gwrmwci',
        'Hanb' => 'Han gyda Bopomofo',
        'Hang' => 'Hangul',
        'Hani' => 'Han',
        'Hans' => 'Symledig',
        'Hant' => 'Traddodiadol',
        'Hebr' => 'Hebreig',
        'Hira' => 'Hiragana',
        'Hrkt' => 'Syllwyddor Japaneaidd',
        'Jpan' => 'Japaneaidd',
        'Kana' => 'Catacana',
        'Khmr' => 'Chmeraidd',
        'Knda' => 'Canaraidd',
        'Kore' => 'Coreaidd',
        'Laoo' => 'Laoaidd',
        'Latn' => 'Lladin',
        'Mlym' => 'Malayalamaidd',
        'Mong' => 'Mongolaidd',
        'Mtei' => 'Meitei Mayek',
        'Mymr' => 'Myanmaraidd',
        'Nkoo' => 'N’Ko',
        'Olck' => 'Ol Chiki',
        'Orya' => 'Orïaidd',
        'Rohg' => 'Hanifi',
        'Sinh' => 'Sinhanaidd',
        'Sund' => 'Swndaneg',
        'Syrc' => 'Syrieg',
        'Taml' => 'Tamilaidd',
        'Telu' => 'Telugu',
        'Tfng' => 'Tifinagh',
        'Thaa' => 'Thaana',
        'Thai' => 'Tai',
        'Tibt' => 'Tibetaidd',
        'Vaii' => 'Vai',
        'Yiii' => 'Yi',
        'Zmth' => 'Nodiant Mathemategol',
        'Zsye' => 'Emoji',
        'Zsym' => 'Symbolau',
        'Zxxx' => 'Anysgrifenedig',
        'Zyyy' => 'Cyffredin',
    ],
];
