<?php

declare(strict_types=1);

namespace SimpleSAML\SAML2\XML\saml;

/**
 * Abstract class to be implemented by all the conditions in this namespace
 *
 * @package simplesamlphp/saml2
 */
abstract class AbstractConditionType extends AbstractSamlElement
{
}
