<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Ego Dirham obodo United Arab Emirates',
        ],
        'AFN' => [
            'AFN',
            'Ego Afghani Obodo Afghanistan',
        ],
        'ALL' => [
            'ALL',
            'Ego Lek Obodo Albania',
        ],
        'AMD' => [
            'AMD',
            'Ego Dram obodo Armenia',
        ],
        'ANG' => [
            'ANG',
            'Ego Antillean Guilder obodo Netherlands',
        ],
        'AOA' => [
            'AOA',
            'Ego Kwanza obodo Angola',
        ],
        'ARS' => [
            'ARS',
            'Ego Peso obodo Argentina',
        ],
        'AUD' => [
            'A$',
            'Ego Dollar obodo Australia',
        ],
        'AWG' => [
            'AWG',
            'Ego Florin obodo Aruba',
        ],
        'AZN' => [
            'AZN',
            'Ego Manat obodo Azerbaijan',
        ],
        'BAM' => [
            'BAM',
            'Akara mgbanwe ego obodo Bosnia-Herzegovina',
        ],
        'BBD' => [
            'BBD',
            'Ego Dollar obodo Barbados',
        ],
        'BDT' => [
            'BDT',
            'Ego Taka obodo Bangladesh',
        ],
        'BGN' => [
            'BGN',
            'Ego Lev mba Bulgaria',
        ],
        'BHD' => [
            'BHD',
            'Ego Dinar Obodo Bahrain',
        ],
        'BIF' => [
            'BIF',
            'Ego Franc obodo Burundi',
        ],
        'BMD' => [
            'BMD',
            'Dollar Bermuda',
        ],
        'BND' => [
            'BND',
            'Ego Dollar obodo Brunei',
        ],
        'BOB' => [
            'BOB',
            'Ego Boliviano obodo Bolivia',
        ],
        'BRL' => [
            'R$',
            'Real Brazil',
        ],
        'BSD' => [
            'BSD',
            'Ego Dollar Obodo Bahamas',
        ],
        'BTN' => [
            'BTN',
            'Ego Ngultrum obodo Bhutan',
        ],
        'BWP' => [
            'BWP',
            'Ego Pula obodo Bostwana',
        ],
        'BYN' => [
            'BYN',
            'Ego Ruble mba Belarus',
        ],
        'BZD' => [
            'BZD',
            'Dollar Belize',
        ],
        'CAD' => [
            'CA$',
            'Dollar Canada',
        ],
        'CDF' => [
            'CDF',
            'Ego Franc obodo Congo',
        ],
        'CHF' => [
            'CHF',
            'Ego Franc mba Switzerland',
        ],
        'CLP' => [
            'CLP',
            'Ego Peso obodo Chile',
        ],
        'CNH' => [
            'CNH',
            'Ego Yuan Obodo China (ndị bi na mmiri)',
        ],
        'CNY' => [
            'CN¥',
            'Yuan China',
        ],
        'COP' => [
            'COP',
            'Ego Peso obodo Columbia',
        ],
        'CRC' => [
            'CRC',
            'Ego Colón obodo Costa Rica',
        ],
        'CUC' => [
            'CUC',
            'Ego Peso e nwere ike ịgbanwe nke obodo Cuba',
        ],
        'CUP' => [
            'CUP',
            'Ego Peso obodo Cuba',
        ],
        'CVE' => [
            'CVE',
            'Escudo Caboverdiano',
        ],
        'CZK' => [
            'CZK',
            'Ego Koruna obodo Czech',
        ],
        'DJF' => [
            'DJF',
            'Ego Franc obodo Djibouti',
        ],
        'DKK' => [
            'DKK',
            'Ego Krone Obodo Denmark',
        ],
        'DOP' => [
            'DOP',
            'Ego Peso Obodo Dominica',
        ],
        'DZD' => [
            'DZD',
            'Ego Dinar Obodo Algeria',
        ],
        'EGP' => [
            'EGP',
            'Ego Pound obodo Egypt',
        ],
        'ERN' => [
            'ERN',
            'Ego Nakfa obodo Eritrea',
        ],
        'ETB' => [
            'ETB',
            'Ego Birr obodo Ethiopia',
        ],
        'EUR' => [
            '€',
            'Euro',
        ],
        'FJD' => [
            'FJD',
            'Ego Dollar obodo Fiji',
        ],
        'FKP' => [
            'FKP',
            'Ego Pound obodo Falkland Islands',
        ],
        'GBP' => [
            '£',
            'Pound British',
        ],
        'GEL' => [
            'GEL',
            'Ego Lari Obodo Georgia',
        ],
        'GHS' => [
            'GHS',
            'Ego Cedi obodo Ghana',
        ],
        'GIP' => [
            'GIP',
            'Ego Pound obodo Gibraltar',
        ],
        'GMD' => [
            'GMD',
            'Ego Dalasi obodo Gambia',
        ],
        'GNF' => [
            'GNF',
            'Ego Franc obodo Guinea',
        ],
        'GTQ' => [
            'GTQ',
            'Ego Quetzal obodo Guatemala',
        ],
        'GYD' => [
            'GYD',
            'Ego Dollar obodo Guyana',
        ],
        'HKD' => [
            'HK$',
            'Ego Dollar Obodo Honk Kong',
        ],
        'HNL' => [
            'HNL',
            'Ego Lempira obodo Honduras',
        ],
        'HRK' => [
            'HRK',
            'Ego Kuna obodo Croatia',
        ],
        'HTG' => [
            'HTG',
            'Ego Gourde obodo Haiti',
        ],
        'HUF' => [
            'HUF',
            'Ego Forint obodo Hungary',
        ],
        'IDR' => [
            'IDR',
            'Ego Rupiah Obodo Indonesia',
        ],
        'ILS' => [
            '₪',
            'Ego Shekel ọhụrụ obodo Israel',
        ],
        'INR' => [
            '₹',
            'Rupee India',
        ],
        'IQD' => [
            'IQD',
            'Ego Dinar obodo Iraq',
        ],
        'IRR' => [
            'IRR',
            'Ego Rial obodo Iran',
        ],
        'ISK' => [
            'ISK',
            'Ego Króna obodo Iceland',
        ],
        'JMD' => [
            'JMD',
            'Ego Dollar obodo Jamaica',
        ],
        'JOD' => [
            'JOD',
            'Ego Dinar Obodo Jordan',
        ],
        'JPY' => [
            '¥',
            'Yen Japan',
        ],
        'KES' => [
            'KES',
            'Ego Shilling obodo Kenya',
        ],
        'KGS' => [
            'KGS',
            'Ego Som Obodo Kyrgyzstan',
        ],
        'KHR' => [
            'KHR',
            'Ego Riel obodo Cambodia',
        ],
        'KMF' => [
            'KMF',
            'Ego Franc obodo Comoros',
        ],
        'KPW' => [
            'KPW',
            'Ego Won Obodo North Korea',
        ],
        'KRW' => [
            '₩',
            'Ego Won Obodo South Korea',
        ],
        'KWD' => [
            'KWD',
            'Ego Dinar Obodo Kuwait',
        ],
        'KYD' => [
            'KYD',
            'Ego Dollar obodo Cayman Islands',
        ],
        'KZT' => [
            'KZT',
            'Ego Tenge obodo Kazakhstani',
        ],
        'LAK' => [
            'LAK',
            'Ego Kip Obodo Laos',
        ],
        'LBP' => [
            'LBP',
            'Ego Pound obodo Lebanon',
        ],
        'LKR' => [
            'LKR',
            'Ego Rupee obodo Sri Lanka',
        ],
        'LRD' => [
            'LRD',
            'Ego Dollar obodo Liberia',
        ],
        'LSL' => [
            'LSL',
            'Ego loti obodo Lesotho',
        ],
        'LYD' => [
            'LYD',
            'Ego Dinar obodo Libya',
        ],
        'MAD' => [
            'MAD',
            'Ego Dirham obodo Morocco',
        ],
        'MDL' => [
            'MDL',
            'Ego Leu obodo Moldova',
        ],
        'MGA' => [
            'MGA',
            'Ego Ariary obodo Madagascar',
        ],
        'MKD' => [
            'MKD',
            'Ego Denar Obodo Macedonia',
        ],
        'MMK' => [
            'MMK',
            'Ego Kyat obodo Myanmar',
        ],
        'MNT' => [
            'MNT',
            'Ego Turgik Obodo Mongolia',
        ],
        'MOP' => [
            'MOP',
            'Ego Pataca ndị Obodo Macanese',
        ],
        'MRU' => [
            'MRU',
            'Ego Ouguiya Obodo Mauritania',
        ],
        'MUR' => [
            'MUR',
            'Ego Rupee obodo Mauritania',
        ],
        'MVR' => [
            'MVR',
            'Ego Rufiyaa obodo Moldova',
        ],
        'MWK' => [
            'MWK',
            'Ego Kwacha obodo Malawi',
        ],
        'MXN' => [
            'MX$',
            'Ego Peso obodo Mexico',
        ],
        'MYR' => [
            'MYR',
            'Ego Ringgit obodo Malaysia',
        ],
        'MZN' => [
            'MZN',
            'Ego Metical obodo Mozambique',
        ],
        'NAD' => [
            'NAD',
            'Ego Dollar obodo Namibia',
        ],
        'NGN' => [
            '₦',
            'Naịra',
        ],
        'NIO' => [
            'NIO',
            'Ego Córodoba obodo Nicaragua',
        ],
        'NOK' => [
            'NOK',
            'Ego Krone Obodo Norway',
        ],
        'NPR' => [
            'NPR',
            'Ego Rupee obodo Nepal',
        ],
        'NZD' => [
            'NZ$',
            'Ego Dollar obodo New Zealand',
        ],
        'OMR' => [
            'OMR',
            'Ego Rial obodo Oman',
        ],
        'PAB' => [
            'PAB',
            'Ego Balboa obodo Panama',
        ],
        'PEN' => [
            'PEN',
            'Ego Sol obodo Peru',
        ],
        'PGK' => [
            'PGK',
            'Ego Kina obodo Papua New Guinea',
        ],
        'PHP' => [
            '₱',
            'Ego Piso obodo Philippine',
        ],
        'PKR' => [
            'PKR',
            'Ego Rupee obodo Pakistan',
        ],
        'PLN' => [
            'PLN',
            'Ego Zloty mba Poland',
        ],
        'PYG' => [
            'PYG',
            'Ego Guarani obodo Paraguay',
        ],
        'QAR' => [
            'QAR',
            'Ego Rial obodo Qatar',
        ],
        'RON' => [
            'RON',
            'Ego Leu obodo Romania',
        ],
        'RSD' => [
            'RSD',
            'Ego Dinar obodo Serbia',
        ],
        'RUB' => [
            'RUB',
            'Ruble Russia',
        ],
        'RWF' => [
            'RWF',
            'Ego Franc obodo Rwanda',
        ],
        'SAR' => [
            'SAR',
            'Ego Riyal obodo Saudi',
        ],
        'SBD' => [
            'SBD',
            'Ego Dollar obodo Solomon Islands',
        ],
        'SCR' => [
            'SCR',
            'Ego Rupee obodo Seychelles',
        ],
        'SDG' => [
            'SDG',
            'Ego Pound obodo Sudan',
        ],
        'SEK' => [
            'SEK',
            'Ego Krona Obodo Sweden',
        ],
        'SGD' => [
            'SGD',
            'Ego Dollar obodo Singapore',
        ],
        'SHP' => [
            'SHP',
            'Ego Pound obodo St Helena',
        ],
        'SLE' => [
            'SLE',
            'Ego Leone obodo Sierra Leone',
        ],
        'SLL' => [
            'SLL',
            'Ego Leone obodo Sierra Leone (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Ego shilling obodo Somali',
        ],
        'SRD' => [
            'SRD',
            'Dollar Surinamese',
        ],
        'SSP' => [
            'SSP',
            'Ego Pound obodo South Sudan',
        ],
        'STN' => [
            'STN',
            'Ego Dobra nke obodo Sāo Tomé na Principe',
        ],
        'SYP' => [
            'SYP',
            'Ego Pound obodo Syria',
        ],
        'SZL' => [
            'SZL',
            'Ego Lilangeni obodo Swaziland',
        ],
        'THB' => [
            'THB',
            'Ego Baht obodo Thai',
        ],
        'TJS' => [
            'TJS',
            'Who Somoni obodo Tajikistan',
        ],
        'TMT' => [
            'TMT',
            'Ego Manat Obodo Turkmenistan',
        ],
        'TND' => [
            'TND',
            'Ego Dinar Obodo Tunisia',
        ],
        'TOP' => [
            'TOP',
            'Ego paʻanga obodo Tonga',
        ],
        'TRY' => [
            'TRY',
            'Ego Lira obodo Turkey',
        ],
        'TTD' => [
            'TTD',
            'Dollar Trinidad & Tobago',
        ],
        'TWD' => [
            'NT$',
            'Dollar obodo New Taiwan',
        ],
        'TZS' => [
            'TZS',
            'Ego Shilling Obodo Tanzania',
        ],
        'UAH' => [
            'UAH',
            'Ego Hryvnia obodo Ukraine',
        ],
        'UGX' => [
            'UGX',
            'Ego Shilling obodo Uganda',
        ],
        'USD' => [
            '$',
            'Dollar US',
        ],
        'UYU' => [
            'UYU',
            'Ego Peso obodo Uruguay',
        ],
        'UZS' => [
            'UZS',
            'Ego Som obodo Uzbekistan',
        ],
        'VES' => [
            'VES',
            'Ego Bolivar obodo Venezuela',
        ],
        'VND' => [
            '₫',
            'Ego Dong obodo Vietnam',
        ],
        'VUV' => [
            'VUV',
            'Ego Vatu obodo Vanuatu',
        ],
        'WST' => [
            'WST',
            'Ego Tala obodo Samoa',
        ],
        'XAF' => [
            'FCFA',
            'Ego Franc mba etiti Africa',
        ],
        'XCD' => [
            'EC$',
            'Ego Dollar obodo East Carribbean',
        ],
        'XCG' => [
            'Cg.',
            'Ego Guilder Caribbean',
        ],
        'XOF' => [
            'F CFA',
            'Ego CFA Franc obodo West Africa',
        ],
        'XPF' => [
            'CFPF',
            'Ego Franc obodo CFP',
        ],
        'YER' => [
            'YER',
            'Ego Rial obodo Yemeni',
        ],
        'ZAR' => [
            'ZAR',
            'Ego Rand obodo South Africa',
        ],
        'ZMW' => [
            'ZMW',
            'Ego Kwacha Obodo Zambia',
        ],
        'ZWG' => [
            'ZWG',
            'Ego Ọlaọcha Zimbabwe',
        ],
    ],
];
