<?php

return [
    'Names' => [
        'ar' => 'arabic',
        'cs' => 'tchec',
        'da' => 'danesi',
        'de' => 'german',
        'el' => 'grec',
        'en' => 'anglesi',
        'eo' => 'Esperanto',
        'es' => 'hispan',
        'et' => 'estonian',
        'fa' => 'persian',
        'fi' => 'finn',
        'fil' => 'filipinesi',
        'fr' => 'francesi',
        'ga' => 'irlandesi',
        'gl' => 'galician',
        'ha' => 'hausa',
        'he' => 'hebreic',
        'hi' => 'hindi',
        'hu' => 'hungarian',
        'ia' => 'Interlingua',
        'id' => 'indonesian',
        'ie' => 'Interlingue',
        'is' => 'islandesi',
        'it' => 'italian',
        'ja' => 'japanesi',
        'jv' => 'javan',
        'ka' => 'georgian',
        'ko' => 'korean',
        'lij' => 'ligurian',
        'lv' => 'lettonian',
        'mt' => 'maltesi',
        'nl' => 'hollandesi',
        'pl' => 'polonesi',
        'prg' => 'prussian',
        'pt' => 'portugalesi',
        'ru' => 'russ',
        'sk' => 'slovac',
        'sl' => 'slovenian',
        'sv' => 'sved',
        'sw' => 'swahili',
        'th' => 'thai',
        'tr' => 'turc',
        'zh' => 'chinesi',
    ],
    'LocalizedNames' => [
        'de_AT' => 'austrian german',
        'de_CH' => 'sviss alt-german',
        'en_AU' => 'australian anglesi',
        'en_CA' => 'canadian anglesi',
        'en_GB' => 'britannic anglesi',
        'en_US' => 'american anglesi',
        'es_419' => 'hispan del latin America',
        'es_ES' => 'europan hispan',
        'es_MX' => 'mexican hispan',
        'fr_CA' => 'canadian francesi',
        'fr_CH' => 'sviss francesi',
        'nl_BE' => 'flandrian',
        'pt_BR' => 'brasilian portugalesi',
        'pt_PT' => 'europan portugalesi',
        'zh_Hans' => 'chinesi simplificat',
        'zh_Hant' => 'chinesi traditional',
    ],
];
