<?php

return [
    'Names' => [
        'af' => 'აფრიკაანსი',
        'af_NA' => 'აფრიკაანსი (ნამიბია)',
        'af_ZA' => 'აფრიკაანსი (სამხრეთ აფრიკის რესპუბლიკა)',
        'ak' => 'აკანი',
        'ak_GH' => 'აკანი (განა)',
        'am' => 'ამჰარული',
        'am_ET' => 'ამჰარული (ეთიოპია)',
        'ar' => 'არაბული',
        'ar_001' => 'არაბული (მსოფლიო)',
        'ar_AE' => 'არაბული (არაბთა გაერთიანებული საამიროები)',
        'ar_BH' => 'არაბული (ბაჰრეინი)',
        'ar_DJ' => 'არაბული (ჯიბუტი)',
        'ar_DZ' => 'არაბული (ალჟირი)',
        'ar_EG' => 'არაბული (ეგვიპტე)',
        'ar_EH' => 'არაბული (დასავლეთ საჰარა)',
        'ar_ER' => 'არაბული (ერიტრეა)',
        'ar_IL' => 'არაბული (ისრაელი)',
        'ar_IQ' => 'არაბული (ერაყი)',
        'ar_JO' => 'არაბული (იორდანია)',
        'ar_KM' => 'არაბული (კომორის კუნძულები)',
        'ar_KW' => 'არაბული (ქუვეითი)',
        'ar_LB' => 'არაბული (ლიბანი)',
        'ar_LY' => 'არაბული (ლიბია)',
        'ar_MA' => 'არაბული (მაროკო)',
        'ar_MR' => 'არაბული (მავრიტანია)',
        'ar_OM' => 'არაბული (ომანი)',
        'ar_PS' => 'არაბული (პალესტინის ტერიტორიები)',
        'ar_QA' => 'არაბული (კატარი)',
        'ar_SA' => 'არაბული (საუდის არაბეთი)',
        'ar_SD' => 'არაბული (სუდანი)',
        'ar_SO' => 'არაბული (სომალი)',
        'ar_SS' => 'არაბული (სამხრეთ სუდანი)',
        'ar_SY' => 'არაბული (სირია)',
        'ar_TD' => 'არაბული (ჩადი)',
        'ar_TN' => 'არაბული (ტუნისი)',
        'ar_YE' => 'არაბული (იემენი)',
        'as' => 'ასამური',
        'as_IN' => 'ასამური (ინდოეთი)',
        'az' => 'აზერბაიჯანული',
        'az_AZ' => 'აზერბაიჯანული (აზერბაიჯანი)',
        'az_Cyrl' => 'აზერბაიჯანული (კირილიცა)',
        'az_Cyrl_AZ' => 'აზერბაიჯანული (კირილიცა, აზერბაიჯანი)',
        'az_Latn' => 'აზერბაიჯანული (ლათინური)',
        'az_Latn_AZ' => 'აზერბაიჯანული (ლათინური, აზერბაიჯანი)',
        'ba' => 'ბაშკირული',
        'ba_RU' => 'ბაშკირული (რუსეთი)',
        'be' => 'ბელარუსული',
        'be_BY' => 'ბელარუსული (ბელარუსი)',
        'bg' => 'ბულგარული',
        'bg_BG' => 'ბულგარული (ბულგარეთი)',
        'bm' => 'ბამბარა',
        'bm_ML' => 'ბამბარა (მალი)',
        'bn' => 'ბენგალური',
        'bn_BD' => 'ბენგალური (ბანგლადეში)',
        'bn_IN' => 'ბენგალური (ინდოეთი)',
        'bo' => 'ტიბეტური',
        'bo_CN' => 'ტიბეტური (ჩინეთი)',
        'bo_IN' => 'ტიბეტური (ინდოეთი)',
        'br' => 'ბრეტონული',
        'br_FR' => 'ბრეტონული (საფრანგეთი)',
        'bs' => 'ბოსნიური',
        'bs_BA' => 'ბოსნიური (ბოსნია და ჰერცეგოვინა)',
        'bs_Cyrl' => 'ბოსნიური (კირილიცა)',
        'bs_Cyrl_BA' => 'ბოსნიური (კირილიცა, ბოსნია და ჰერცეგოვინა)',
        'bs_Latn' => 'ბოსნიური (ლათინური)',
        'bs_Latn_BA' => 'ბოსნიური (ლათინური, ბოსნია და ჰერცეგოვინა)',
        'ca' => 'კატალანური',
        'ca_AD' => 'კატალანური (ანდორა)',
        'ca_ES' => 'კატალანური (ესპანეთი)',
        'ca_FR' => 'კატალანური (საფრანგეთი)',
        'ca_IT' => 'კატალანური (იტალია)',
        'ce' => 'ჩეჩნური',
        'ce_RU' => 'ჩეჩნური (რუსეთი)',
        'cs' => 'ჩეხური',
        'cs_CZ' => 'ჩეხური (ჩეხეთი)',
        'cv' => 'ჩუვაშური',
        'cv_RU' => 'ჩუვაშური (რუსეთი)',
        'cy' => 'უელსური',
        'cy_GB' => 'უელსური (გაერთიანებული სამეფო)',
        'da' => 'დანიური',
        'da_DK' => 'დანიური (დანია)',
        'da_GL' => 'დანიური (გრენლანდია)',
        'de' => 'გერმანული',
        'de_AT' => 'გერმანული (ავსტრია)',
        'de_BE' => 'გერმანული (ბელგია)',
        'de_CH' => 'გერმანული (შვეიცარია)',
        'de_DE' => 'გერმანული (გერმანია)',
        'de_IT' => 'გერმანული (იტალია)',
        'de_LI' => 'გერმანული (ლიხტენშტაინი)',
        'de_LU' => 'გერმანული (ლუქსემბურგი)',
        'dz' => 'ძონგკხა',
        'dz_BT' => 'ძონგკხა (ბუტანი)',
        'ee' => 'ევე',
        'ee_GH' => 'ევე (განა)',
        'ee_TG' => 'ევე (ტოგო)',
        'el' => 'ბერძნული',
        'el_CY' => 'ბერძნული (კვიპროსი)',
        'el_GR' => 'ბერძნული (საბერძნეთი)',
        'en' => 'ინგლისური',
        'en_001' => 'ინგლისური (მსოფლიო)',
        'en_150' => 'ინგლისური (ევროპა)',
        'en_AE' => 'ინგლისური (არაბთა გაერთიანებული საამიროები)',
        'en_AG' => 'ინგლისური (ანტიგუა და ბარბუდა)',
        'en_AI' => 'ინგლისური (ანგილია)',
        'en_AS' => 'ინგლისური (ამერიკის სამოა)',
        'en_AT' => 'ინგლისური (ავსტრია)',
        'en_AU' => 'ინგლისური (ავსტრალია)',
        'en_BB' => 'ინგლისური (ბარბადოსი)',
        'en_BE' => 'ინგლისური (ბელგია)',
        'en_BI' => 'ინგლისური (ბურუნდი)',
        'en_BM' => 'ინგლისური (ბერმუდა)',
        'en_BS' => 'ინგლისური (ბაჰამის კუნძულები)',
        'en_BW' => 'ინგლისური (ბოტსვანა)',
        'en_BZ' => 'ინგლისური (ბელიზი)',
        'en_CA' => 'ინგლისური (კანადა)',
        'en_CC' => 'ინგლისური (ქოქოსის [კილინგის] კუნძულები)',
        'en_CH' => 'ინგლისური (შვეიცარია)',
        'en_CK' => 'ინგლისური (კუკის კუნძულები)',
        'en_CM' => 'ინგლისური (კამერუნი)',
        'en_CX' => 'ინგლისური (შობის კუნძული)',
        'en_CY' => 'ინგლისური (კვიპროსი)',
        'en_CZ' => 'ინგლისური (ჩეხეთი)',
        'en_DE' => 'ინგლისური (გერმანია)',
        'en_DK' => 'ინგლისური (დანია)',
        'en_DM' => 'ინგლისური (დომინიკა)',
        'en_EE' => 'ინგლისური (ესტონეთი)',
        'en_ER' => 'ინგლისური (ერიტრეა)',
        'en_ES' => 'ინგლისური (ესპანეთი)',
        'en_FI' => 'ინგლისური (ფინეთი)',
        'en_FJ' => 'ინგლისური (ფიჯი)',
        'en_FK' => 'ინგლისური (ფოლკლენდის კუნძულები)',
        'en_FM' => 'ინგლისური (მიკრონეზია)',
        'en_FR' => 'ინგლისური (საფრანგეთი)',
        'en_GB' => 'ინგლისური (გაერთიანებული სამეფო)',
        'en_GD' => 'ინგლისური (გრენადა)',
        'en_GE' => 'ინგლისური (საქართველო)',
        'en_GG' => 'ინგლისური (გერნსი)',
        'en_GH' => 'ინგლისური (განა)',
        'en_GI' => 'ინგლისური (გიბრალტარი)',
        'en_GM' => 'ინგლისური (გამბია)',
        'en_GS' => 'ინგლისური (სამხრეთ ჯორჯია და სამხრეთ სენდვიჩის კუნძულები)',
        'en_GU' => 'ინგლისური (გუამი)',
        'en_GY' => 'ინგლისური (გაიანა)',
        'en_HK' => 'ინგლისური (ჰონკონგის სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი)',
        'en_HU' => 'ინგლისური (უნგრეთი)',
        'en_ID' => 'ინგლისური (ინდონეზია)',
        'en_IE' => 'ინგლისური (ირლანდია)',
        'en_IL' => 'ინგლისური (ისრაელი)',
        'en_IM' => 'ინგლისური (მენის კუნძული)',
        'en_IN' => 'ინგლისური (ინდოეთი)',
        'en_IO' => 'ინგლისური (ბრიტანეთის ტერიტორია ინდოეთის ოკეანეში)',
        'en_IT' => 'ინგლისური (იტალია)',
        'en_JE' => 'ინგლისური (ჯერსი)',
        'en_JM' => 'ინგლისური (იამაიკა)',
        'en_JP' => 'ინგლისური (იაპონია)',
        'en_KE' => 'ინგლისური (კენია)',
        'en_KI' => 'ინგლისური (კირიბატი)',
        'en_KN' => 'ინგლისური (სენტ-კიტსი და ნევისი)',
        'en_KY' => 'ინგლისური (კაიმანის კუნძულები)',
        'en_LC' => 'ინგლისური (სენტ-ლუსია)',
        'en_LR' => 'ინგლისური (ლიბერია)',
        'en_LS' => 'ინგლისური (ლესოთო)',
        'en_LT' => 'ინგლისური (ლიეტუვა)',
        'en_LV' => 'ინგლისური (ლატვია)',
        'en_MG' => 'ინგლისური (მადაგასკარი)',
        'en_MH' => 'ინგლისური (მარშალის კუნძულები)',
        'en_MO' => 'ინგლისური (მაკაოს სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი)',
        'en_MP' => 'ინგლისური (ჩრდილოეთ მარიანას კუნძულები)',
        'en_MS' => 'ინგლისური (მონსერატი)',
        'en_MT' => 'ინგლისური (მალტა)',
        'en_MU' => 'ინგლისური (მავრიკი)',
        'en_MV' => 'ინგლისური (მალდივები)',
        'en_MW' => 'ინგლისური (მალავი)',
        'en_MY' => 'ინგლისური (მალაიზია)',
        'en_NA' => 'ინგლისური (ნამიბია)',
        'en_NF' => 'ინგლისური (ნორფოლკის კუნძული)',
        'en_NG' => 'ინგლისური (ნიგერია)',
        'en_NL' => 'ინგლისური (ნიდერლანდები)',
        'en_NO' => 'ინგლისური (ნორვეგია)',
        'en_NR' => 'ინგლისური (ნაურუ)',
        'en_NU' => 'ინგლისური (ნიუე)',
        'en_NZ' => 'ინგლისური (ახალი ზელანდია)',
        'en_PG' => 'ინგლისური (პაპუა-ახალი გვინეა)',
        'en_PH' => 'ინგლისური (ფილიპინები)',
        'en_PK' => 'ინგლისური (პაკისტანი)',
        'en_PL' => 'ინგლისური (პოლონეთი)',
        'en_PN' => 'ინგლისური (პიტკერნის კუნძულები)',
        'en_PR' => 'ინგლისური (პუერტო-რიკო)',
        'en_PT' => 'ინგლისური (პორტუგალია)',
        'en_PW' => 'ინგლისური (პალაუ)',
        'en_RO' => 'ინგლისური (რუმინეთი)',
        'en_RW' => 'ინგლისური (რუანდა)',
        'en_SB' => 'ინგლისური (სოლომონის კუნძულები)',
        'en_SC' => 'ინგლისური (სეიშელის კუნძულები)',
        'en_SD' => 'ინგლისური (სუდანი)',
        'en_SE' => 'ინგლისური (შვედეთი)',
        'en_SG' => 'ინგლისური (სინგაპური)',
        'en_SH' => 'ინგლისური (წმინდა ელენეს კუნძული)',
        'en_SI' => 'ინგლისური (სლოვენია)',
        'en_SK' => 'ინგლისური (სლოვაკეთი)',
        'en_SL' => 'ინგლისური (სიერა-ლეონე)',
        'en_SS' => 'ინგლისური (სამხრეთ სუდანი)',
        'en_SX' => 'ინგლისური (სინტ-მარტენი)',
        'en_SZ' => 'ინგლისური (სვაზილენდი)',
        'en_TC' => 'ინგლისური (თერქს-ქაიქოსის კუნძულები)',
        'en_TK' => 'ინგლისური (ტოკელაუ)',
        'en_TO' => 'ინგლისური (ტონგა)',
        'en_TT' => 'ინგლისური (ტრინიდადი და ტობაგო)',
        'en_TV' => 'ინგლისური (ტუვალუ)',
        'en_TZ' => 'ინგლისური (ტანზანია)',
        'en_UA' => 'ინგლისური (უკრაინა)',
        'en_UG' => 'ინგლისური (უგანდა)',
        'en_UM' => 'ინგლისური (აშშ-ის შორეული კუნძულები)',
        'en_US' => 'ინგლისური (ამერიკის შეერთებული შტატები)',
        'en_VC' => 'ინგლისური (სენტ-ვინსენტი და გრენადინები)',
        'en_VG' => 'ინგლისური (ბრიტანეთის ვირჯინის კუნძულები)',
        'en_VI' => 'ინგლისური (აშშ-ის ვირჯინის კუნძულები)',
        'en_VU' => 'ინგლისური (ვანუატუ)',
        'en_WS' => 'ინგლისური (სამოა)',
        'en_ZA' => 'ინგლისური (სამხრეთ აფრიკის რესპუბლიკა)',
        'en_ZM' => 'ინგლისური (ზამბია)',
        'en_ZW' => 'ინგლისური (ზიმბაბვე)',
        'eo' => 'ესპერანტო',
        'eo_001' => 'ესპერანტო (მსოფლიო)',
        'es' => 'ესპანური',
        'es_419' => 'ესპანური (ლათინური ამერიკა)',
        'es_AR' => 'ესპანური (არგენტინა)',
        'es_BO' => 'ესპანური (ბოლივია)',
        'es_BR' => 'ესპანური (ბრაზილია)',
        'es_BZ' => 'ესპანური (ბელიზი)',
        'es_CL' => 'ესპანური (ჩილე)',
        'es_CO' => 'ესპანური (კოლუმბია)',
        'es_CR' => 'ესპანური (კოსტა-რიკა)',
        'es_CU' => 'ესპანური (კუბა)',
        'es_DO' => 'ესპანური (დომინიკელთა რესპუბლიკა)',
        'es_EC' => 'ესპანური (ეკვადორი)',
        'es_ES' => 'ესპანური (ესპანეთი)',
        'es_GQ' => 'ესპანური (ეკვატორული გვინეა)',
        'es_GT' => 'ესპანური (გვატემალა)',
        'es_HN' => 'ესპანური (ჰონდურასი)',
        'es_MX' => 'ესპანური (მექსიკა)',
        'es_NI' => 'ესპანური (ნიკარაგუა)',
        'es_PA' => 'ესპანური (პანამა)',
        'es_PE' => 'ესპანური (პერუ)',
        'es_PH' => 'ესპანური (ფილიპინები)',
        'es_PR' => 'ესპანური (პუერტო-რიკო)',
        'es_PY' => 'ესპანური (პარაგვაი)',
        'es_SV' => 'ესპანური (სალვადორი)',
        'es_US' => 'ესპანური (ამერიკის შეერთებული შტატები)',
        'es_UY' => 'ესპანური (ურუგვაი)',
        'es_VE' => 'ესპანური (ვენესუელა)',
        'et' => 'ესტონური',
        'et_EE' => 'ესტონური (ესტონეთი)',
        'eu' => 'ბასკური',
        'eu_ES' => 'ბასკური (ესპანეთი)',
        'fa' => 'სპარსული',
        'fa_AF' => 'სპარსული (ავღანეთი)',
        'fa_IR' => 'სპარსული (ირანი)',
        'ff' => 'ფულა',
        'ff_Adlm' => 'ფულა (ადლამი)',
        'ff_Adlm_BF' => 'ფულა (ადლამი, ბურკინა-ფასო)',
        'ff_Adlm_CM' => 'ფულა (ადლამი, კამერუნი)',
        'ff_Adlm_GH' => 'ფულა (ადლამი, განა)',
        'ff_Adlm_GM' => 'ფულა (ადლამი, გამბია)',
        'ff_Adlm_GN' => 'ფულა (ადლამი, გვინეა)',
        'ff_Adlm_GW' => 'ფულა (ადლამი, გვინეა-ბისაუ)',
        'ff_Adlm_LR' => 'ფულა (ადლამი, ლიბერია)',
        'ff_Adlm_MR' => 'ფულა (ადლამი, მავრიტანია)',
        'ff_Adlm_NE' => 'ფულა (ადლამი, ნიგერი)',
        'ff_Adlm_NG' => 'ფულა (ადლამი, ნიგერია)',
        'ff_Adlm_SL' => 'ფულა (ადლამი, სიერა-ლეონე)',
        'ff_Adlm_SN' => 'ფულა (ადლამი, სენეგალი)',
        'ff_CM' => 'ფულა (კამერუნი)',
        'ff_GN' => 'ფულა (გვინეა)',
        'ff_Latn' => 'ფულა (ლათინური)',
        'ff_Latn_BF' => 'ფულა (ლათინური, ბურკინა-ფასო)',
        'ff_Latn_CM' => 'ფულა (ლათინური, კამერუნი)',
        'ff_Latn_GH' => 'ფულა (ლათინური, განა)',
        'ff_Latn_GM' => 'ფულა (ლათინური, გამბია)',
        'ff_Latn_GN' => 'ფულა (ლათინური, გვინეა)',
        'ff_Latn_GW' => 'ფულა (ლათინური, გვინეა-ბისაუ)',
        'ff_Latn_LR' => 'ფულა (ლათინური, ლიბერია)',
        'ff_Latn_MR' => 'ფულა (ლათინური, მავრიტანია)',
        'ff_Latn_NE' => 'ფულა (ლათინური, ნიგერი)',
        'ff_Latn_NG' => 'ფულა (ლათინური, ნიგერია)',
        'ff_Latn_SL' => 'ფულა (ლათინური, სიერა-ლეონე)',
        'ff_Latn_SN' => 'ფულა (ლათინური, სენეგალი)',
        'ff_MR' => 'ფულა (მავრიტანია)',
        'ff_SN' => 'ფულა (სენეგალი)',
        'fi' => 'ფინური',
        'fi_FI' => 'ფინური (ფინეთი)',
        'fo' => 'ფარერული',
        'fo_DK' => 'ფარერული (დანია)',
        'fo_FO' => 'ფარერული (ფარერის კუნძულები)',
        'fr' => 'ფრანგული',
        'fr_BE' => 'ფრანგული (ბელგია)',
        'fr_BF' => 'ფრანგული (ბურკინა-ფასო)',
        'fr_BI' => 'ფრანგული (ბურუნდი)',
        'fr_BJ' => 'ფრანგული (ბენინი)',
        'fr_BL' => 'ფრანგული (სენ-ბართელმი)',
        'fr_CA' => 'ფრანგული (კანადა)',
        'fr_CD' => 'ფრანგული (კონგო - კინშასა)',
        'fr_CF' => 'ფრანგული (ცენტრალური აფრიკის რესპუბლიკა)',
        'fr_CG' => 'ფრანგული (კონგო - ბრაზავილი)',
        'fr_CH' => 'ფრანგული (შვეიცარია)',
        'fr_CI' => 'ფრანგული (კოტ-დივუარი)',
        'fr_CM' => 'ფრანგული (კამერუნი)',
        'fr_DJ' => 'ფრანგული (ჯიბუტი)',
        'fr_DZ' => 'ფრანგული (ალჟირი)',
        'fr_FR' => 'ფრანგული (საფრანგეთი)',
        'fr_GA' => 'ფრანგული (გაბონი)',
        'fr_GF' => 'ფრანგული (საფრანგეთის გვიანა)',
        'fr_GN' => 'ფრანგული (გვინეა)',
        'fr_GP' => 'ფრანგული (გვადელუპა)',
        'fr_GQ' => 'ფრანგული (ეკვატორული გვინეა)',
        'fr_HT' => 'ფრანგული (ჰაიტი)',
        'fr_KM' => 'ფრანგული (კომორის კუნძულები)',
        'fr_LU' => 'ფრანგული (ლუქსემბურგი)',
        'fr_MA' => 'ფრანგული (მაროკო)',
        'fr_MC' => 'ფრანგული (მონაკო)',
        'fr_MF' => 'ფრანგული (სენ-მარტენი)',
        'fr_MG' => 'ფრანგული (მადაგასკარი)',
        'fr_ML' => 'ფრანგული (მალი)',
        'fr_MQ' => 'ფრანგული (მარტინიკა)',
        'fr_MR' => 'ფრანგული (მავრიტანია)',
        'fr_MU' => 'ფრანგული (მავრიკი)',
        'fr_NC' => 'ფრანგული (ახალი კალედონია)',
        'fr_NE' => 'ფრანგული (ნიგერი)',
        'fr_PF' => 'ფრანგული (საფრანგეთის პოლინეზია)',
        'fr_PM' => 'ფრანგული (სენ-პიერი და მიკელონი)',
        'fr_RE' => 'ფრანგული (რეუნიონი)',
        'fr_RW' => 'ფრანგული (რუანდა)',
        'fr_SC' => 'ფრანგული (სეიშელის კუნძულები)',
        'fr_SN' => 'ფრანგული (სენეგალი)',
        'fr_SY' => 'ფრანგული (სირია)',
        'fr_TD' => 'ფრანგული (ჩადი)',
        'fr_TG' => 'ფრანგული (ტოგო)',
        'fr_TN' => 'ფრანგული (ტუნისი)',
        'fr_VU' => 'ფრანგული (ვანუატუ)',
        'fr_WF' => 'ფრანგული (უოლისი და ფუტუნა)',
        'fr_YT' => 'ფრანგული (მაიოტა)',
        'fy' => 'დასავლეთფრიზიული',
        'fy_NL' => 'დასავლეთფრიზიული (ნიდერლანდები)',
        'ga' => 'ირლანდიური',
        'ga_GB' => 'ირლანდიური (გაერთიანებული სამეფო)',
        'ga_IE' => 'ირლანდიური (ირლანდია)',
        'gd' => 'შოტლანდიური გელური',
        'gd_GB' => 'შოტლანდიური გელური (გაერთიანებული სამეფო)',
        'gl' => 'გალისიური',
        'gl_ES' => 'გალისიური (ესპანეთი)',
        'gu' => 'გუჯარათი',
        'gu_IN' => 'გუჯარათი (ინდოეთი)',
        'gv' => 'მენური',
        'gv_IM' => 'მენური (მენის კუნძული)',
        'ha' => 'ჰაუსა',
        'ha_GH' => 'ჰაუსა (განა)',
        'ha_NE' => 'ჰაუსა (ნიგერი)',
        'ha_NG' => 'ჰაუსა (ნიგერია)',
        'he' => 'ებრაული',
        'he_IL' => 'ებრაული (ისრაელი)',
        'hi' => 'ჰინდი',
        'hi_IN' => 'ჰინდი (ინდოეთი)',
        'hi_Latn' => 'ჰინდი (ლათინური)',
        'hi_Latn_IN' => 'ჰინდი (ლათინური, ინდოეთი)',
        'hr' => 'ხორვატული',
        'hr_BA' => 'ხორვატული (ბოსნია და ჰერცეგოვინა)',
        'hr_HR' => 'ხორვატული (ხორვატია)',
        'hu' => 'უნგრული',
        'hu_HU' => 'უნგრული (უნგრეთი)',
        'hy' => 'სომხური',
        'hy_AM' => 'სომხური (სომხეთი)',
        'ia' => 'ინტერლინგუალური',
        'ia_001' => 'ინტერლინგუალური (მსოფლიო)',
        'id' => 'ინდონეზიური',
        'id_ID' => 'ინდონეზიური (ინდონეზია)',
        'ie' => 'ინტერლინგი',
        'ie_EE' => 'ინტერლინგი (ესტონეთი)',
        'ig' => 'იგბო',
        'ig_NG' => 'იგბო (ნიგერია)',
        'ii' => 'სიჩუანის ი',
        'ii_CN' => 'სიჩუანის ი (ჩინეთი)',
        'is' => 'ისლანდიური',
        'is_IS' => 'ისლანდიური (ისლანდია)',
        'it' => 'იტალიური',
        'it_CH' => 'იტალიური (შვეიცარია)',
        'it_IT' => 'იტალიური (იტალია)',
        'it_SM' => 'იტალიური (სან-მარინო)',
        'it_VA' => 'იტალიური (ქალაქი ვატიკანი)',
        'ja' => 'იაპონური',
        'ja_JP' => 'იაპონური (იაპონია)',
        'jv' => 'იავური',
        'jv_ID' => 'იავური (ინდონეზია)',
        'ka' => 'ქართული',
        'ka_GE' => 'ქართული (საქართველო)',
        'ki' => 'კიკუიუ',
        'ki_KE' => 'კიკუიუ (კენია)',
        'kk' => 'ყაზახური',
        'kk_Arab' => 'ყაზახური (არაბული)',
        'kk_Arab_CN' => 'ყაზახური (არაბული, ჩინეთი)',
        'kk_Cyrl' => 'ყაზახური (კირილიცა)',
        'kk_Cyrl_KZ' => 'ყაზახური (კირილიცა, ყაზახეთი)',
        'kk_KZ' => 'ყაზახური (ყაზახეთი)',
        'kl' => 'დასავლეთ გრენლანდიური',
        'kl_GL' => 'დასავლეთ გრენლანდიური (გრენლანდია)',
        'km' => 'ქმერული',
        'km_KH' => 'ქმერული (კამბოჯა)',
        'kn' => 'კანადა',
        'kn_IN' => 'კანადა (ინდოეთი)',
        'ko' => 'კორეული',
        'ko_CN' => 'კორეული (ჩინეთი)',
        'ko_KP' => 'კორეული (ჩრდილოეთ კორეა)',
        'ko_KR' => 'კორეული (სამხრეთ კორეა)',
        'ks' => 'ქაშმირული',
        'ks_Arab' => 'ქაშმირული (არაბული)',
        'ks_Arab_IN' => 'ქაშმირული (არაბული, ინდოეთი)',
        'ks_Deva' => 'ქაშმირული (დევანაგარი)',
        'ks_Deva_IN' => 'ქაშმირული (დევანაგარი, ინდოეთი)',
        'ks_IN' => 'ქაშმირული (ინდოეთი)',
        'ku' => 'ქურთული',
        'ku_Latn' => 'ქურთული (ლათინური)',
        'ku_Latn_IQ' => 'ქურთული (ლათინური, ერაყი)',
        'ku_Latn_SY' => 'ქურთული (ლათინური, სირია)',
        'ku_Latn_TR' => 'ქურთული (ლათინური, თურქეთი)',
        'ku_SY' => 'ქურთული (სირია)',
        'ku_TR' => 'ქურთული (თურქეთი)',
        'kw' => 'კორნული',
        'kw_GB' => 'კორნული (გაერთიანებული სამეფო)',
        'ky' => 'ყირგიზული',
        'ky_KG' => 'ყირგიზული (ყირგიზეთი)',
        'lb' => 'ლუქსემბურგული',
        'lb_LU' => 'ლუქსემბურგული (ლუქსემბურგი)',
        'lg' => 'განდა',
        'lg_UG' => 'განდა (უგანდა)',
        'ln' => 'ლინგალა',
        'ln_AO' => 'ლინგალა (ანგოლა)',
        'ln_CD' => 'ლინგალა (კონგო - კინშასა)',
        'ln_CF' => 'ლინგალა (ცენტრალური აფრიკის რესპუბლიკა)',
        'ln_CG' => 'ლინგალა (კონგო - ბრაზავილი)',
        'lo' => 'ლაოსური',
        'lo_LA' => 'ლაოსური (ლაოსი)',
        'lt' => 'ლიეტუვური',
        'lt_LT' => 'ლიეტუვური (ლიეტუვა)',
        'lu' => 'ლუბა-კატანგა',
        'lu_CD' => 'ლუბა-კატანგა (კონგო - კინშასა)',
        'lv' => 'ლატვიური',
        'lv_LV' => 'ლატვიური (ლატვია)',
        'mg' => 'მალაგასიური',
        'mg_MG' => 'მალაგასიური (მადაგასკარი)',
        'mi' => 'მაორი',
        'mi_NZ' => 'მაორი (ახალი ზელანდია)',
        'mk' => 'მაკედონური',
        'mk_MK' => 'მაკედონური (ჩრდილოეთ მაკედონია)',
        'ml' => 'მალაიალამური',
        'ml_IN' => 'მალაიალამური (ინდოეთი)',
        'mn' => 'მონღოლური',
        'mn_MN' => 'მონღოლური (მონღოლეთი)',
        'mr' => 'მარათჰი',
        'mr_IN' => 'მარათჰი (ინდოეთი)',
        'ms' => 'მალაიური',
        'ms_BN' => 'მალაიური (ბრუნეი)',
        'ms_ID' => 'მალაიური (ინდონეზია)',
        'ms_MY' => 'მალაიური (მალაიზია)',
        'ms_SG' => 'მალაიური (სინგაპური)',
        'mt' => 'მალტური',
        'mt_MT' => 'მალტური (მალტა)',
        'my' => 'ბირმული',
        'my_MM' => 'ბირმული (მიანმარი [ბირმა])',
        'nb' => 'ნორვეგიული ბუკმოლი',
        'nb_NO' => 'ნორვეგიული ბუკმოლი (ნორვეგია)',
        'nb_SJ' => 'ნორვეგიული ბუკმოლი (შპიცბერგენი და იან-მაიენი)',
        'nd' => 'ჩრდილოეთ ნდებელე',
        'nd_ZW' => 'ჩრდილოეთ ნდებელე (ზიმბაბვე)',
        'ne' => 'ნეპალური',
        'ne_IN' => 'ნეპალური (ინდოეთი)',
        'ne_NP' => 'ნეპალური (ნეპალი)',
        'nl' => 'ნიდერლანდური',
        'nl_AW' => 'ნიდერლანდური (არუბა)',
        'nl_BE' => 'ნიდერლანდური (ბელგია)',
        'nl_BQ' => 'ნიდერლანდური (კარიბის ნიდერლანდები)',
        'nl_CW' => 'ნიდერლანდური (კიურასაო)',
        'nl_NL' => 'ნიდერლანდური (ნიდერლანდები)',
        'nl_SR' => 'ნიდერლანდური (სურინამი)',
        'nl_SX' => 'ნიდერლანდური (სინტ-მარტენი)',
        'nn' => 'ნორვეგიული ნიუნორსკი',
        'nn_NO' => 'ნორვეგიული ნიუნორსკი (ნორვეგია)',
        'no' => 'ნორვეგიული',
        'no_NO' => 'ნორვეგიული (ნორვეგია)',
        'oc' => 'ოქსიტანური',
        'oc_ES' => 'ოქსიტანური (ესპანეთი)',
        'oc_FR' => 'ოქსიტანური (საფრანგეთი)',
        'om' => 'ორომო',
        'om_ET' => 'ორომო (ეთიოპია)',
        'om_KE' => 'ორომო (კენია)',
        'or' => 'ორია',
        'or_IN' => 'ორია (ინდოეთი)',
        'os' => 'ოსური',
        'os_GE' => 'ოსური (საქართველო)',
        'os_RU' => 'ოსური (რუსეთი)',
        'pa' => 'პენჯაბური',
        'pa_Arab' => 'პენჯაბური (არაბული)',
        'pa_Arab_PK' => 'პენჯაბური (არაბული, პაკისტანი)',
        'pa_Guru' => 'პენჯაბური (გურმუხი)',
        'pa_Guru_IN' => 'პენჯაბური (გურმუხი, ინდოეთი)',
        'pa_IN' => 'პენჯაბური (ინდოეთი)',
        'pa_PK' => 'პენჯაბური (პაკისტანი)',
        'pl' => 'პოლონური',
        'pl_PL' => 'პოლონური (პოლონეთი)',
        'ps' => 'პუშტუ',
        'ps_AF' => 'პუშტუ (ავღანეთი)',
        'ps_PK' => 'პუშტუ (პაკისტანი)',
        'pt' => 'პორტუგალიური',
        'pt_AO' => 'პორტუგალიური (ანგოლა)',
        'pt_BR' => 'პორტუგალიური (ბრაზილია)',
        'pt_CH' => 'პორტუგალიური (შვეიცარია)',
        'pt_CV' => 'პორტუგალიური (კაბო-ვერდე)',
        'pt_GQ' => 'პორტუგალიური (ეკვატორული გვინეა)',
        'pt_GW' => 'პორტუგალიური (გვინეა-ბისაუ)',
        'pt_LU' => 'პორტუგალიური (ლუქსემბურგი)',
        'pt_MO' => 'პორტუგალიური (მაკაოს სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი)',
        'pt_MZ' => 'პორტუგალიური (მოზამბიკი)',
        'pt_PT' => 'პორტუგალიური (პორტუგალია)',
        'pt_ST' => 'პორტუგალიური (სან-ტომე და პრინსიპი)',
        'pt_TL' => 'პორტუგალიური (ტიმორ-ლესტე)',
        'qu' => 'კეჩუა',
        'qu_BO' => 'კეჩუა (ბოლივია)',
        'qu_EC' => 'კეჩუა (ეკვადორი)',
        'qu_PE' => 'კეჩუა (პერუ)',
        'rm' => 'რეტორომანული',
        'rm_CH' => 'რეტორომანული (შვეიცარია)',
        'rn' => 'რუნდი',
        'rn_BI' => 'რუნდი (ბურუნდი)',
        'ro' => 'რუმინული',
        'ro_MD' => 'რუმინული (მოლდოვა)',
        'ro_RO' => 'რუმინული (რუმინეთი)',
        'ru' => 'რუსული',
        'ru_BY' => 'რუსული (ბელარუსი)',
        'ru_KG' => 'რუსული (ყირგიზეთი)',
        'ru_KZ' => 'რუსული (ყაზახეთი)',
        'ru_MD' => 'რუსული (მოლდოვა)',
        'ru_RU' => 'რუსული (რუსეთი)',
        'ru_UA' => 'რუსული (უკრაინა)',
        'rw' => 'კინიარუანდა',
        'rw_RW' => 'კინიარუანდა (რუანდა)',
        'sa' => 'სანსკრიტი',
        'sa_IN' => 'სანსკრიტი (ინდოეთი)',
        'sc' => 'სარდინიული',
        'sc_IT' => 'სარდინიული (იტალია)',
        'sd' => 'სინდჰური',
        'sd_Arab' => 'სინდჰური (არაბული)',
        'sd_Arab_PK' => 'სინდჰური (არაბული, პაკისტანი)',
        'sd_Deva' => 'სინდჰური (დევანაგარი)',
        'sd_Deva_IN' => 'სინდჰური (დევანაგარი, ინდოეთი)',
        'sd_IN' => 'სინდჰური (ინდოეთი)',
        'sd_PK' => 'სინდჰური (პაკისტანი)',
        'se' => 'ჩრდილოეთ საამური',
        'se_FI' => 'ჩრდილოეთ საამური (ფინეთი)',
        'se_NO' => 'ჩრდილოეთ საამური (ნორვეგია)',
        'se_SE' => 'ჩრდილოეთ საამური (შვედეთი)',
        'sg' => 'სანგო',
        'sg_CF' => 'სანგო (ცენტრალური აფრიკის რესპუბლიკა)',
        'sh' => 'სერბულ-ხორვატული',
        'sh_BA' => 'სერბულ-ხორვატული (ბოსნია და ჰერცეგოვინა)',
        'si' => 'სინჰალური',
        'si_LK' => 'სინჰალური (შრი-ლანკა)',
        'sk' => 'სლოვაკური',
        'sk_SK' => 'სლოვაკური (სლოვაკეთი)',
        'sl' => 'სლოვენური',
        'sl_SI' => 'სლოვენური (სლოვენია)',
        'sn' => 'შონა',
        'sn_ZW' => 'შონა (ზიმბაბვე)',
        'so' => 'სომალიური',
        'so_DJ' => 'სომალიური (ჯიბუტი)',
        'so_ET' => 'სომალიური (ეთიოპია)',
        'so_KE' => 'სომალიური (კენია)',
        'so_SO' => 'სომალიური (სომალი)',
        'sq' => 'ალბანური',
        'sq_AL' => 'ალბანური (ალბანეთი)',
        'sq_MK' => 'ალბანური (ჩრდილოეთ მაკედონია)',
        'sr' => 'სერბული',
        'sr_BA' => 'სერბული (ბოსნია და ჰერცეგოვინა)',
        'sr_Cyrl' => 'სერბული (კირილიცა)',
        'sr_Cyrl_BA' => 'სერბული (კირილიცა, ბოსნია და ჰერცეგოვინა)',
        'sr_Cyrl_ME' => 'სერბული (კირილიცა, მონტენეგრო)',
        'sr_Cyrl_RS' => 'სერბული (კირილიცა, სერბეთი)',
        'sr_Latn' => 'სერბული (ლათინური)',
        'sr_Latn_BA' => 'სერბული (ლათინური, ბოსნია და ჰერცეგოვინა)',
        'sr_Latn_ME' => 'სერბული (ლათინური, მონტენეგრო)',
        'sr_Latn_RS' => 'სერბული (ლათინური, სერბეთი)',
        'sr_ME' => 'სერბული (მონტენეგრო)',
        'sr_RS' => 'სერბული (სერბეთი)',
        'st' => 'სამხრეთ სოთოს ენა',
        'st_LS' => 'სამხრეთ სოთოს ენა (ლესოთო)',
        'st_ZA' => 'სამხრეთ სოთოს ენა (სამხრეთ აფრიკის რესპუბლიკა)',
        'su' => 'სუნდური',
        'su_ID' => 'სუნდური (ინდონეზია)',
        'su_Latn' => 'სუნდური (ლათინური)',
        'su_Latn_ID' => 'სუნდური (ლათინური, ინდონეზია)',
        'sv' => 'შვედური',
        'sv_AX' => 'შვედური (ალანდის კუნძულები)',
        'sv_FI' => 'შვედური (ფინეთი)',
        'sv_SE' => 'შვედური (შვედეთი)',
        'sw' => 'სუაჰილი',
        'sw_CD' => 'სუაჰილი (კონგო - კინშასა)',
        'sw_KE' => 'სუაჰილი (კენია)',
        'sw_TZ' => 'სუაჰილი (ტანზანია)',
        'sw_UG' => 'სუაჰილი (უგანდა)',
        'ta' => 'ტამილური',
        'ta_IN' => 'ტამილური (ინდოეთი)',
        'ta_LK' => 'ტამილური (შრი-ლანკა)',
        'ta_MY' => 'ტამილური (მალაიზია)',
        'ta_SG' => 'ტამილური (სინგაპური)',
        'te' => 'ტელუგუ',
        'te_IN' => 'ტელუგუ (ინდოეთი)',
        'tg' => 'ტაჯიკური',
        'tg_TJ' => 'ტაჯიკური (ტაჯიკეთი)',
        'th' => 'ტაილანდური',
        'th_TH' => 'ტაილანდური (ტაილანდი)',
        'ti' => 'ტიგრინია',
        'ti_ER' => 'ტიგრინია (ერიტრეა)',
        'ti_ET' => 'ტიგრინია (ეთიოპია)',
        'tk' => 'თურქმენული',
        'tk_TM' => 'თურქმენული (თურქმენეთი)',
        'tn' => 'ტსვანა',
        'tn_BW' => 'ტსვანა (ბოტსვანა)',
        'tn_ZA' => 'ტსვანა (სამხრეთ აფრიკის რესპუბლიკა)',
        'to' => 'ტონგანური',
        'to_TO' => 'ტონგანური (ტონგა)',
        'tr' => 'თურქული',
        'tr_CY' => 'თურქული (კვიპროსი)',
        'tr_TR' => 'თურქული (თურქეთი)',
        'tt' => 'თათრული',
        'tt_RU' => 'თათრული (რუსეთი)',
        'ug' => 'უიღურული',
        'ug_CN' => 'უიღურული (ჩინეთი)',
        'uk' => 'უკრაინული',
        'uk_UA' => 'უკრაინული (უკრაინა)',
        'ur' => 'ურდუ',
        'ur_IN' => 'ურდუ (ინდოეთი)',
        'ur_PK' => 'ურდუ (პაკისტანი)',
        'uz' => 'უზბეკური',
        'uz_AF' => 'უზბეკური (ავღანეთი)',
        'uz_Arab' => 'უზბეკური (არაბული)',
        'uz_Arab_AF' => 'უზბეკური (არაბული, ავღანეთი)',
        'uz_Cyrl' => 'უზბეკური (კირილიცა)',
        'uz_Cyrl_UZ' => 'უზბეკური (კირილიცა, უზბეკეთი)',
        'uz_Latn' => 'უზბეკური (ლათინური)',
        'uz_Latn_UZ' => 'უზბეკური (ლათინური, უზბეკეთი)',
        'uz_UZ' => 'უზბეკური (უზბეკეთი)',
        'vi' => 'ვიეტნამური',
        'vi_VN' => 'ვიეტნამური (ვიეტნამი)',
        'wo' => 'ვოლოფური',
        'wo_SN' => 'ვოლოფური (სენეგალი)',
        'xh' => 'ქჰოსა',
        'xh_ZA' => 'ქჰოსა (სამხრეთ აფრიკის რესპუბლიკა)',
        'yi' => 'იდიში',
        'yi_UA' => 'იდიში (უკრაინა)',
        'yo' => 'იორუბა',
        'yo_BJ' => 'იორუბა (ბენინი)',
        'yo_NG' => 'იორუბა (ნიგერია)',
        'za' => 'ზჰუანგი',
        'za_CN' => 'ზჰუანგი (ჩინეთი)',
        'zh' => 'ჩინური',
        'zh_CN' => 'ჩინური (ჩინეთი)',
        'zh_HK' => 'ჩინური (ჰონკონგის სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი)',
        'zh_Hans' => 'ჩინური (გამარტივებული)',
        'zh_Hans_CN' => 'ჩინური (გამარტივებული, ჩინეთი)',
        'zh_Hans_HK' => 'ჩინური (გამარტივებული, ჰონკონგის სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი)',
        'zh_Hans_MO' => 'ჩინური (გამარტივებული, მაკაოს სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი)',
        'zh_Hans_MY' => 'ჩინური (გამარტივებული, მალაიზია)',
        'zh_Hans_SG' => 'ჩინური (გამარტივებული, სინგაპური)',
        'zh_Hant' => 'ჩინური (ტრადიციული)',
        'zh_Hant_HK' => 'ჩინური (ტრადიციული, ჰონკონგის სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი)',
        'zh_Hant_MO' => 'ჩინური (ტრადიციული, მაკაოს სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი)',
        'zh_Hant_MY' => 'ჩინური (ტრადიციული, მალაიზია)',
        'zh_Hant_TW' => 'ჩინური (ტრადიციული, ტაივანი)',
        'zh_MO' => 'ჩინური (მაკაოს სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი)',
        'zh_SG' => 'ჩინური (სინგაპური)',
        'zh_TW' => 'ჩინური (ტაივანი)',
        'zu' => 'ზულუ',
        'zu_ZA' => 'ზულუ (სამხრეთ აფრიკის რესპუბლიკა)',
    ],
];
