<?php

return [
    'Names' => [
        'ar_EH' => 'árabe (Sahara Occidental)',
        'en_GG' => 'inglés (Guernsey)',
        'ff_Adlm' => 'fula (adlam)',
        'ff_Adlm_BF' => 'fula (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fula (adlam, Camerún)',
        'ff_Adlm_GH' => 'fula (adlam, Ghana)',
        'ff_Adlm_GM' => 'fula (adlam, Gambia)',
        'ff_Adlm_GN' => 'fula (adlam, Guinea)',
        'ff_Adlm_GW' => 'fula (adlam, Guinea-Bisáu)',
        'ff_Adlm_LR' => 'fula (adlam, Liberia)',
        'ff_Adlm_MR' => 'fula (adlam, Mauritania)',
        'ff_Adlm_NE' => 'fula (adlam, Níger)',
        'ff_Adlm_NG' => 'fula (adlam, Nigeria)',
        'ff_Adlm_SL' => 'fula (adlam, Sierra Leona)',
        'ff_Adlm_SN' => 'fula (adlam, Senegal)',
        'gu' => 'gurayatí',
        'gu_IN' => 'gurayatí (India)',
        'nd' => 'ndebele del norte',
        'nd_ZW' => 'ndebele del norte (Zimbabue)',
        'se' => 'sami del norte',
        'se_FI' => 'sami del norte (Finlandia)',
        'se_NO' => 'sami del norte (Noruega)',
        'se_SE' => 'sami del norte (Suecia)',
    ],
];
