<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'arabské',
        'Aran' => 'nastaliq',
        'Armn' => 'arménske',
        'Bali' => 'balijský',
        'Beng' => 'bengálske',
        'Bopo' => 'bopomofo',
        'Brai' => 'braillovo',
        'Cakm' => 'čakma',
        'Cans' => 'zjednotené kanadské domorodé slabiky',
        'Cher' => 'čerokézčina',
        'Cyrl' => 'cyrilika',
        'Deva' => 'dévanágarí',
        'Egyp' => 'egyptské hieroglyfy',
        'Ethi' => 'etiópske',
        'Geor' => 'gruzínske',
        'Glag' => 'hlaholika',
        'Goth' => 'gotický',
        'Grek' => 'grécke',
        'Gujr' => 'gudžarátí',
        'Guru' => 'gurmukhi',
        'Hanb' => 'čínske a bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'čínske',
        'Hans' => 'zjednodušené',
        'Hant' => 'tradičné',
        'Hebr' => 'hebrejské',
        'Hira' => 'hiragana',
        'Hrkt' => 'kana',
        'Jamo' => 'jamo',
        'Jpan' => 'japonské',
        'Kana' => 'katakana',
        'Khmr' => 'khmérske',
        'Knda' => 'kannadské',
        'Kore' => 'kórejské',
        'Laoo' => 'laoské',
        'Latn' => 'latinka',
        'Lina' => 'lineárna A',
        'Linb' => 'lineárna B',
        'Maya' => 'mayské hieroglyfy',
        'Mlym' => 'malajálamske',
        'Mong' => 'mongolské',
        'Mtei' => 'mejtej majek (manipurské)',
        'Mymr' => 'barmské',
        'Nkoo' => 'bambarčina',
        'Olck' => 'santálske (ol chiki)',
        'Orya' => 'uríjske',
        'Osma' => 'osmanský',
        'Qaag' => 'zawgyi',
        'Rohg' => 'hanifi',
        'Runr' => 'Runové písmo',
        'Sinh' => 'sinhálske',
        'Sund' => 'sundčina',
        'Syrc' => 'sýrčina',
        'Taml' => 'tamilské',
        'Telu' => 'telugské',
        'Tfng' => 'tifinagh',
        'Thaa' => 'tána',
        'Thai' => 'thajské',
        'Tibt' => 'tibetské',
        'Vaii' => 'vai',
        'Yiii' => 'yi',
        'Zmth' => 'matematický zápis',
        'Zsye' => 'emodži',
        'Zsym' => 'symboly',
        'Zxxx' => 'bez zápisu',
        'Zyyy' => 'všeobecné',
    ],
];
