<?php

declare(strict_types=1);

namespace SimpleSAML\XMLSecurity\XML\xenc;

/**
 * Class representing a xenc:EncryptionProperties element.
 *
 * @package simplesaml/xml-security
 */
final class EncryptionProperties extends AbstractEncryptionPropertiesType
{
}
