<?php

return [
    'Names' => [
        'Arab' => 'arabic',
        'Aran' => 'nastalik',
        'Brai' => 'Braille',
        'Cyrl' => 'cirillic',
        'Hans' => 'simplificat',
        'Hant' => 'traditional',
        'Hrkt' => 'japanesi sillabariums',
        'Jpan' => 'japanesi',
        'Kore' => 'korean',
        'Latn' => 'latin',
        'Mong' => 'mongolian',
        'Zmth' => 'matematic notation',
        'Zsye' => 'emoji',
        'Zsym' => 'simboles',
        'Zxxx' => 'ínscrit',
    ],
];
