<?php

return [
    'Names' => [
        'aa' => 'isi-Afar',
        'ab' => 'isi-Abkhazian',
        'ace' => 'isi-Achinese',
        'ach' => 'isi-Acoli',
        'ada' => 'isi-Adangme',
        'ady' => 'isi-Adyghe',
        'af' => 'i-Afrikaans',
        'agq' => 'isi-Aghem',
        'ain' => 'isi-Ainu',
        'ak' => 'isi-Akan',
        'ale' => 'isi-Aleut',
        'alt' => 'isi-Southern Altai',
        'am' => 'isi-Amharic',
        'an' => 'isi-Aragonese',
        'ann' => 'isi-Obolo',
        'anp' => 'isi-Angika',
        'ar' => 'isi-Arabic',
        'arn' => 'isi-Mapuche',
        'arp' => 'isi-Arapaho',
        'ars' => 'isi-Najdi Arabic',
        'as' => 'isi-Assamese',
        'asa' => 'isi-Asu',
        'ast' => 'isi-Asturian',
        'atj' => 'isi-Atikamekw',
        'av' => 'isi-Avaric',
        'awa' => 'isi-Awadhi',
        'ay' => 'isi-Aymara',
        'az' => 'isi-Azerbaijani',
        'ba' => 'isi-Bashkir',
        'bal' => 'IsiBaluchi',
        'ban' => 'isi-Balinese',
        'bas' => 'isi-Basaa',
        'be' => 'isi-Belarusian',
        'bem' => 'isi-Bemba',
        'bez' => 'isi-Bena',
        'bg' => 'isi-Bulgari',
        'bgc' => 'isi-Haryanvi',
        'bgn' => 'isi-Western Balochi',
        'bho' => 'isi-Bhojpuri',
        'bi' => 'isi-Bislama',
        'bin' => 'isi-Bini',
        'bla' => 'isi-Siksika',
        'blo' => 'isi-Anii',
        'bm' => 'isi-Bambara',
        'bn' => 'isi-Bengali',
        'bo' => 'isi-Tibetan',
        'br' => 'isi-Breton',
        'brx' => 'isi-Bodo',
        'bs' => 'isi-Bosnian',
        'bug' => 'isi-Buginese',
        'byn' => 'isi-Blin',
        'ca' => 'isi-Catalan',
        'cay' => 'isi-Cayuga',
        'ccp' => 'i-Chakma',
        'ce' => 'isi-Chechen',
        'ceb' => 'isi-Cebuano',
        'cgg' => 'isi-Chiga',
        'ch' => 'isi-Chamorro',
        'chk' => 'isi-Chuukese',
        'chm' => 'isi-Mari',
        'cho' => 'isi-Choctaw',
        'chp' => 'isi-Chipewyan',
        'chr' => 'isi-Cherokee',
        'chy' => 'isi-Cheyenne',
        'ckb' => 'isi-Central Kurdish',
        'clc' => 'isi-Chilcotin',
        'co' => 'isi-Corsican',
        'crg' => 'isi-Michif',
        'crj' => 'Southern East Cree',
        'crk' => 'Plains Cree',
        'crl' => 'isi-Northern East Cree',
        'crm' => 'isi-Moose Cree',
        'crr' => 'isi-Carolina Algonquian',
        'crs' => 'i-Seselwa Creole French',
        'cs' => 'isi-Czech',
        'csw' => 'isi-Swampy Cree',
        'cu' => 'isi-Church Slavic',
        'cv' => 'isi-Chuvash',
        'cy' => 'isi-Welsh',
        'da' => 'isi-Danish',
        'dak' => 'isi-Dakota',
        'dar' => 'isi-Dargwa',
        'dav' => 'isi-Taita',
        'de' => 'isi-German',
        'dgr' => 'isi-Dogrib',
        'dje' => 'isi-Zarma',
        'doi' => 'isi-Dogri',
        'dsb' => 'isi-Lower Sorbian',
        'dua' => 'isi-Duala',
        'dv' => 'isi-Divehi',
        'dyo' => 'isi-Jola-Fonyi',
        'dz' => 'isi-Dzongkha',
        'dzg' => 'isi-Dazaga',
        'ebu' => 'isi-Embu',
        'ee' => 'isi-Ewe',
        'efi' => 'isi-Efik',
        'eka' => 'isi-Ekajuk',
        'el' => 'isi-Greek',
        'en' => 'i-English',
        'eo' => 'isi-Esperanto',
        'es' => 'isi-Spanish',
        'et' => 'isi-Estonia',
        'eu' => 'isi-Basque',
        'ewo' => 'isi-Ewondo',
        'fa' => 'isi-Persian',
        'ff' => 'isi-Fulah',
        'fi' => 'isi-Finnish',
        'fil' => 'isi-Filipino',
        'fj' => 'isi-Fijian',
        'fo' => 'isi-Faroese',
        'fon' => 'isi-Fon',
        'fr' => 'isi-French',
        'frc' => 'isi-Cajun French',
        'frr' => 'isi-Northern Frisian',
        'fur' => 'isi-Friulian',
        'fy' => 'isi-Western Frisian',
        'ga' => 'isi-Irish',
        'gaa' => 'isi-Ga',
        'gag' => 'isi-Gagauz',
        'gan' => 'isi-Gan Chinese',
        'gd' => 'isi-Scottish Gaelic',
        'gez' => 'isi-Geez',
        'gil' => 'isi-Gilbertese',
        'gl' => 'isi-Galicia',
        'gn' => 'isi-Guarani',
        'gor' => 'isi-Gorontalo',
        'gsw' => 'isi-Swiss German',
        'gu' => 'isi-Gujarati',
        'guz' => 'isi-Gusli',
        'gv' => 'isi-Manx',
        'gwi' => 'isi-Gwichʼin',
        'ha' => 'isi-Hausa',
        'hai' => 'isi-Haida',
        'hak' => 'isi-Hakka Chinese',
        'haw' => 'isi-Hawaiian',
        'hax' => 'Southern Haida',
        'he' => 'isi-Hebrew',
        'hi' => 'isi-Hindi',
        'hil' => 'isi-Hiligaynon',
        'hmn' => 'isi-Hmong',
        'hr' => 'isi-Croatian',
        'hsb' => 'isi-Upper Sorbian',
        'hsn' => 'isi-Xiang Chinese',
        'ht' => 'isi-Haitian',
        'hu' => 'isi-Hungarian',
        'hup' => 'isi-Hupa',
        'hur' => 'isi-Halkomelem',
        'hy' => 'isi-Armenia',
        'hz' => 'isi-Herero',
        'ia' => 'izilimi ezihlangene',
        'iba' => 'isi-Iban',
        'ibb' => 'isi-Ibibio',
        'id' => 'isi-Indonesian',
        'ie' => 'izimili',
        'ig' => 'isi-Igbo',
        'ii' => 'isi-Sichuan Yi',
        'ikt' => 'Western Canadian Inuktitut',
        'ilo' => 'isi-Iloko',
        'inh' => 'isi-Ingush',
        'io' => 'isi-Ido',
        'is' => 'isi-Icelandic',
        'it' => 'isi-Italian',
        'iu' => 'isi-Inuktitut',
        'ja' => 'isi-Japanese',
        'jbo' => 'isi-Lojban',
        'jgo' => 'isi-Ngomba',
        'jmc' => 'isi-Machame',
        'jv' => 'isi-Javanese',
        'ka' => 'isi-Georgian',
        'kab' => 'isi-Kabyle',
        'kac' => 'isi-Kachin',
        'kaj' => 'isi-Jju',
        'kam' => 'isi-Kamba',
        'kbd' => 'isi-Kabardian',
        'kcg' => 'isi-Tyap',
        'kde' => 'isi-Makonde',
        'kea' => 'isi-Kabuverdianu',
        'kfo' => 'isi-Koro',
        'kg' => 'isi-Kongo',
        'kgp' => 'isi-Kaingang',
        'kha' => 'isi-Khasi',
        'khq' => 'isi-Koyra Chiini',
        'ki' => 'isi-Kikuyu',
        'kj' => 'isi-Kuanyama',
        'kk' => 'isi-Kazakh',
        'kkj' => 'isi-Kako',
        'kl' => 'isi-Kalaallisut',
        'kln' => 'isi-Kalenjin',
        'km' => 'isi-Khmer',
        'kmb' => 'isi-Kimbundu',
        'kn' => 'isi-Kannada',
        'ko' => 'isi-Korean',
        'koi' => 'isi-Komi-Permyak',
        'kok' => 'isi-Konkani',
        'kpe' => 'isi-Kpelle',
        'kr' => 'isi-Kanuri',
        'krc' => 'isi-Karachay-Balkar',
        'krl' => 'isi-Karelian',
        'kru' => 'isi-Kurukh',
        'ks' => 'isi-Kashmiri',
        'ksb' => 'isiShambala',
        'ksf' => 'isi-Bafia',
        'ksh' => 'isi-Colognian',
        'ku' => 'isi-Kurdish',
        'kum' => 'isi-Kumyk',
        'kv' => 'isi-Komi',
        'kw' => 'isi-Cornish',
        'kwk' => 'Kwakʼwala',
        'kxv' => 'isiKuvi',
        'ky' => 'isi-Kyrgyz',
        'la' => 'isi-Latin',
        'lad' => 'isi-Ladino',
        'lag' => 'isi-Langi',
        'lb' => 'isi-Luxembourgish',
        'lez' => 'isi-Lezghian',
        'lg' => 'isi-Ganda',
        'li' => 'isi-Limburgish',
        'lij' => 'IsiLigurian',
        'lil' => 'isi-Lillooet',
        'lkt' => 'isi-Lakota',
        'lmo' => 'IsiLombard',
        'ln' => 'isi-Lingala',
        'lo' => 'isi-Lao',
        'lou' => 'isi-Louisiana Creole',
        'loz' => 'isi-Lozi',
        'lrc' => 'isi-Northern Luri',
        'lsm' => 'isi-Saamia',
        'lt' => 'isi-Lithuanian',
        'lu' => 'isi-Luba-Katanga',
        'lua' => 'isi-Luba-Lulua',
        'lun' => 'isi-Lunda',
        'luo' => 'isi-Luo',
        'lus' => 'isi-Mizo',
        'luy' => 'isi-Luyia',
        'lv' => 'isi-Latvian',
        'mad' => 'isi-Madurese',
        'mag' => 'isi-Magahi',
        'mai' => 'isi-Maithili',
        'mak' => 'isi-Makasar',
        'mas' => 'isi-Masai',
        'mdf' => 'isi-Moksha',
        'men' => 'isi-Mende',
        'mer' => 'isi-Meru',
        'mfe' => 'isi-Morisyen',
        'mg' => 'isi-Malagasy',
        'mgh' => 'isi-Makhuwa-Meetto',
        'mgo' => 'isi-Meta’',
        'mh' => 'isi-Marshallese',
        'mi' => 'isi-Maori',
        'mic' => 'isi-Micmac',
        'min' => 'isi-Minangkabau',
        'mk' => 'isi-Macedonian',
        'ml' => 'isi-Malayalam',
        'mn' => 'isi-Mongolian',
        'mni' => 'isi-Manipuri',
        'moe' => 'isi-Innu-aimun',
        'moh' => 'isi-Mohawk',
        'mos' => 'isi-Mossi',
        'mr' => 'isi-Marathi',
        'ms' => 'isi-Malay',
        'mt' => 'isi-Maltese',
        'mua' => 'isi-Mundang',
        'mus' => 'isi-Creek',
        'mwl' => 'isi-Mirandese',
        'my' => 'isi-Burmese',
        'myv' => 'isi-Erzya',
        'mzn' => 'isi-Mazanderani',
        'na' => 'isi-Nauru',
        'nan' => 'isi-Min Nan Chinese',
        'nap' => 'isi-Neapolitan',
        'naq' => 'isi-Nama',
        'nb' => 'isi-Norwegian Bokmål',
        'nd' => 'isi-North Ndebele',
        'nds' => 'isi-Low German',
        'ne' => 'isi-Nepali',
        'new' => 'isi-Newari',
        'ng' => 'isi-Ndonga',
        'nia' => 'isi-Nias',
        'niu' => 'isi-Niuean',
        'nl' => 'isi-Dutch',
        'nmg' => 'isi-Kwasio',
        'nn' => 'isi-Norwegian Nynorsk',
        'nnh' => 'isi-Ngiemboon',
        'no' => 'isi-Norwegian',
        'nog' => 'isi-Nogai',
        'nqo' => 'isi-N’Ko',
        'nr' => 'isi-South Ndebele',
        'nso' => 'isi-Northern Sotho',
        'nus' => 'isi-Nuer',
        'nv' => 'isi-Navajo',
        'ny' => 'isi-Nyanja',
        'nyn' => 'isi-Nyankole',
        'oc' => 'isi-Occitan',
        'ojb' => 'Northwestern Ojibwa',
        'ojc' => 'isi-Central Ojibwa',
        'ojs' => 'isi-Oji-Cree',
        'ojw' => 'Western Ojibwa',
        'oka' => 'isi-Okanagan',
        'om' => 'isi-Oromo',
        'or' => 'isi-Odia',
        'os' => 'isi-Ossetic',
        'pa' => 'isi-Punjabi',
        'pag' => 'isi-Pangasinan',
        'pam' => 'isi-Pampanga',
        'pap' => 'isi-Papiamento',
        'pau' => 'isi-Palauan',
        'pcm' => 'isi-Nigerian Pidgin',
        'pis' => 'Pijin',
        'pl' => 'isi-Polish',
        'pqm' => 'Maliseet-Passamaquoddy',
        'prg' => 'isi-Prussian',
        'ps' => 'isi-Pashto',
        'pt' => 'isi-Portuguese',
        'qu' => 'isi-Quechua',
        'quc' => 'isi-Kʼicheʼ',
        'raj' => 'isi-Rajasthani',
        'rap' => 'isi-Rapanui',
        'rar' => 'isi-Rarotongan',
        'rhg' => 'Rohingya',
        'rm' => 'isi-Romansh',
        'rn' => 'isi-Rundi',
        'ro' => 'isi-Romanian',
        'rof' => 'isi-Rombo',
        'ru' => 'isi-Russian',
        'rup' => 'isi-Aromanian',
        'rw' => 'isi-Kinyarwanda',
        'rwk' => 'isi-Rwa',
        'sa' => 'isi-Sanskrit',
        'sad' => 'isi-Sandawe',
        'sah' => 'i-Sakha',
        'saq' => 'isi-Samburu',
        'sat' => 'isi-Santali',
        'sba' => 'isi-Ngambay',
        'sbp' => 'isi-Sangu',
        'sc' => 'isi-Sardinian',
        'scn' => 'isi-Sicilian',
        'sco' => 'isi-Scots',
        'sd' => 'isi-Sindhi',
        'sdh' => 'i-Southern Kurdish',
        'se' => 'isi-Northern Sami',
        'seh' => 'isi-Sena',
        'ses' => 'isi-Koyraboro Senni',
        'sg' => 'isi-Sango',
        'sh' => 'isi-Serbo-Croatian',
        'shi' => 'isi-Tachelhit',
        'shn' => 'isi-Shan',
        'si' => 'isi-Sinhala',
        'sk' => 'isi-Slovak',
        'sl' => 'isi-Slovenian',
        'slh' => 'Southern Lushootseed',
        'sm' => 'isi-Samoan',
        'sma' => 'isi-Southern Sami',
        'smj' => 'isi-Lule Sami',
        'smn' => 'isi-Inari Sami',
        'sms' => 'isi-Skolt Sami',
        'sn' => 'isiShona',
        'snk' => 'isi-Soninke',
        'so' => 'isi-Somali',
        'sq' => 'isi-Albania',
        'sr' => 'isi-Serbian',
        'srn' => 'isi-Sranan Tongo',
        'ss' => 'isiSwati',
        'ssy' => 'isi-Saho',
        'st' => 'isi-Southern Sotho',
        'str' => 'Straits Salish',
        'su' => 'isi-Sundanese',
        'suk' => 'isi-Sukuma',
        'sv' => 'isi-Swedish',
        'sw' => 'isiSwahili',
        'swb' => 'isi-Comorian',
        'syr' => 'isi-Syriac',
        'szl' => 'iSilesian',
        'ta' => 'isi-Tamil',
        'tce' => 'Southern Tutchone',
        'te' => 'isi-Telugu',
        'tem' => 'isi-Timne',
        'teo' => 'isi-Teso',
        'tet' => 'isi-Tetum',
        'tg' => 'isi-Tajik',
        'tgx' => 'isi-Tagish',
        'th' => 'isi-Thai',
        'tht' => 'Tahltan',
        'ti' => 'isi-Tigrinya',
        'tig' => 'isi-Tigre',
        'tk' => 'isi-Turkmen',
        'tlh' => 'isi-Klingon',
        'tli' => 'Tlingit',
        'tn' => 'isi-Tswana',
        'to' => 'isi-Tongan',
        'tok' => 'Toki Pona',
        'tpi' => 'isi-Tok Pisin',
        'tr' => 'isi-Turkish',
        'trv' => 'isi-Taroko',
        'ts' => 'isi-Tsonga',
        'tt' => 'isi-Tatar',
        'ttm' => 'Northern Tutchone',
        'tum' => 'isi-Tumbuka',
        'tvl' => 'isi-Tuvalu',
        'tw' => 'isi-Twi',
        'twq' => 'isi-Tasawaq',
        'ty' => 'isi-Tahitian',
        'tyv' => 'isi-Tuvinian',
        'tzm' => 'isi-Central Atlas Tamazight',
        'udm' => 'isi-Udmurt',
        'ug' => 'isi-Uighur',
        'uk' => 'isi-Ukrainian',
        'umb' => 'isi-Umbundu',
        'ur' => 'isi-Urdu',
        'uz' => 'isi-Uzbek',
        'vai' => 'isi-Vai',
        've' => 'isi-Venda',
        'vec' => 'isiVenetian',
        'vi' => 'isi-Vietnamese',
        'vmw' => 'isiMakhuwa',
        'vo' => 'isi-Volapük',
        'vun' => 'isiVunjo',
        'wa' => 'isi-Walloon',
        'wae' => 'isi-Walser',
        'wal' => 'isi-Wolaytta',
        'war' => 'isi-Waray',
        'wbp' => 'isi-Warlpiri',
        'wo' => 'isi-Wolof',
        'wuu' => 'isi-Wu Chinese',
        'xal' => 'isi-Kalmyk',
        'xh' => 'isiXhosa',
        'xnr' => 'Kangri',
        'xog' => 'isi-Soga',
        'yav' => 'isi-Yangben',
        'ybb' => 'isi-Yemba',
        'yi' => 'isi-Yiddish',
        'yo' => 'isi-Yoruba',
        'yrl' => 'isi-Nheengatu',
        'yue' => 'isi-Cantonese',
        'za' => 'IsiZhuang',
        'zgh' => 'isi-Moroccan Tamazight esivamile',
        'zh' => 'isi-Chinese',
        'zu' => 'isiZulu',
        'zun' => 'isi-Zuni',
        'zza' => 'isi-Zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Isi-Arabic Esivamile Sesimanje',
        'de_AT' => 'isi-Austrian German',
        'de_CH' => 'Isi-Swiss High German',
        'en_AU' => 'i-Australian English',
        'en_CA' => 'i-Canadian English',
        'en_GB' => 'i-British English',
        'en_US' => 'i-American English',
        'es_419' => 'isi-Latin American Spanish',
        'es_ES' => 'isi-European Spanish',
        'es_MX' => 'isi-Mexican Spanish',
        'fa_AF' => 'isi-Dari',
        'fr_CA' => 'isi-Canadian French',
        'fr_CH' => 'isi-Swiss French',
        'nds_NL' => 'isi-Low Saxon',
        'nl_BE' => 'isi-Flemish',
        'pt_BR' => 'isi-Brazillian Portuguese',
        'pt_PT' => 'isi-European Portuguese',
        'ro_MD' => 'isi-Moldavian',
        'sw_CD' => 'isi-Congo Swahili',
        'zh_Hans' => 'isi-Chinese (esenziwe-lula)',
        'zh_Hant' => 'Isi-Chinese Sasendulo',
    ],
];
