<?php

return [
    'Names' => [
        'Adlm' => 'adlamski',
        'Arab' => 'arabski',
        'Aran' => 'nastalik',
        'Armi' => 'imperialno-aramejski',
        'Armn' => 'armenski',
        'Avst' => 'avestanski',
        'Bali' => 'balijski',
        'Batk' => 'bataški',
        'Beng' => 'bengalski',
        'Blis' => 'znakovna pisava Bliss',
        'Bopo' => 'bopomofo',
        'Brah' => 'bramanski',
        'Brai' => 'braillova pisava',
        'Bugi' => 'buginski',
        'Buhd' => 'buhidski',
        'Cakm' => 'čakmajski',
        'Cans' => 'poenotena zlogovna pisava kanadskih staroselcev',
        'Cher' => 'čerokeški',
        'Cirt' => 'kirt',
        'Copt' => 'koptski',
        'Cprt' => 'ciprski',
        'Cyrl' => 'cirilica',
        'Cyrs' => 'starocerkvenoslovanska cirilica',
        'Deva' => 'devanagarščica',
        'Dsrt' => 'fonetska pisava deseret',
        'Egyd' => 'demotska egipčanska pisava',
        'Egyh' => 'hieratska egipčanska pisava',
        'Egyp' => 'egipčanska slikovna pisava',
        'Ethi' => 'etiopski',
        'Geok' => 'cerkvenogruzijski',
        'Geor' => 'gruzijski',
        'Glag' => 'glagoliški',
        'Goth' => 'gotski',
        'Grek' => 'grški',
        'Gujr' => 'gudžaratski',
        'Guru' => 'gurmuki',
        'Hanb' => 'han + bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'kanji',
        'Hano' => 'hanunski',
        'Hans' => 'poenostavljena pisava',
        'Hant' => 'tradicionalna pisava',
        'Hebr' => 'hebrejski',
        'Hira' => 'hiragana',
        'Hmng' => 'pahavhmonska zlogovna pisava',
        'Hrkt' => 'japonska zlogovnica',
        'Hung' => 'staroogrski',
        'Inds' => 'induški',
        'Ital' => 'staroitalski',
        'Jamo' => 'jamo',
        'Java' => 'javanski',
        'Jpan' => 'japonski',
        'Kali' => 'karenski',
        'Kana' => 'katakana',
        'Khar' => 'gandarski',
        'Khmr' => 'kmerski',
        'Knda' => 'kanadski',
        'Kore' => 'korejski',
        'Kthi' => 'kajatski',
        'Laoo' => 'laoški',
        'Latf' => 'fraktura',
        'Latg' => 'gelski latinični',
        'Latn' => 'latinica',
        'Lepc' => 'lepški',
        'Limb' => 'limbuški',
        'Lina' => 'linearna pisava A',
        'Linb' => 'linearna pisava B',
        'Lyci' => 'licijski',
        'Lydi' => 'lidijski',
        'Mand' => 'mandanski',
        'Mani' => 'manihejski',
        'Maya' => 'majevska slikovna pisava',
        'Mero' => 'meroitski',
        'Mlym' => 'malajalamski',
        'Mong' => 'mongolska',
        'Moon' => 'Moonova pisava za slepe',
        'Mtei' => 'meiteiski',
        'Mymr' => 'mjanmarski',
        'Nkoo' => 'nkojski',
        'Ogam' => 'ogamski',
        'Olck' => 'santalski',
        'Orkh' => 'orkonski',
        'Orya' => 'orijski',
        'Osma' => 'osmanski',
        'Perm' => 'staropermijski',
        'Phag' => 'pagpajski',
        'Phli' => 'vrezani napisi pahlavi',
        'Phlp' => 'psalmski pahlavi',
        'Phlv' => 'knjižno palavanski',
        'Phnx' => 'feničanski',
        'Plrd' => 'Pollardova fonetska pisava',
        'Rohg' => 'hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'runski',
        'Samr' => 'samaritanski',
        'Sara' => 'saratski',
        'Sgnw' => 'znakovna pisava',
        'Shaw' => 'šojevski',
        'Sinh' => 'sinhalski',
        'Sund' => 'sundanski',
        'Sylo' => 'siletsko-nagarijski',
        'Syrc' => 'sirijski',
        'Syre' => 'sirska abeceda estrangelo',
        'Syrj' => 'zahodnosirijski',
        'Syrn' => 'vzhodnosirijski',
        'Tagb' => 'tagbanski',
        'Taml' => 'tamilski',
        'Tavt' => 'tajsko-vietnamski',
        'Telu' => 'teluški',
        'Teng' => 'tengvarski',
        'Tfng' => 'tifinajski',
        'Tglg' => 'tagaloški',
        'Thaa' => 'tanajski',
        'Thai' => 'tajski',
        'Tibt' => 'tibetanski',
        'Ugar' => 'ugaritski',
        'Vaii' => 'zlogovna pisava vai',
        'Visp' => 'vidni govor',
        'Xpeo' => 'staroperzijski',
        'Xsux' => 'sumersko-akadski klinopis',
        'Yiii' => 'jiški',
        'Zinh' => 'podedovan',
        'Zmth' => 'matematična znamenja',
        'Zsye' => 'čustvenček',
        'Zsym' => 'simboli',
        'Zxxx' => 'nenapisano',
        'Zyyy' => 'splošno',
    ],
];
