<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Ahom' => 'ahom',
        'Arab' => 'arabisk',
        'Aran' => 'nastaliq',
        'Armn' => 'armenskt',
        'Avst' => 'avestanskt',
        'Bali' => 'baliskt',
        'Bamu' => 'bamum',
        'Bass' => 'bassa vah',
        'Batk' => 'batak',
        'Beng' => 'bangla',
        'Bhks' => 'bhaiksuki',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'blindaskrift',
        'Bugi' => 'buginskt',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'sameindir kanadiskir uppruna stavir',
        'Cari' => 'carian',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Chrs' => 'chorasmian',
        'Copt' => 'koptiskt',
        'Cpmn' => 'cypro-minoan',
        'Cprt' => 'kýpriskt',
        'Cyrl' => 'kyrilliskt',
        'Deva' => 'devanagari',
        'Diak' => 'dives akuru',
        'Dogr' => 'dogra',
        'Dsrt' => 'deseret',
        'Egyp' => 'egyptiskar hieroglyffur',
        'Elba' => 'elbasan',
        'Elym' => 'elymaic',
        'Ethi' => 'etiopiskt',
        'Gara' => 'garay',
        'Geor' => 'georgianskt',
        'Glag' => 'glagolitic',
        'Gong' => 'gunjala gondi',
        'Gonm' => 'masaram gondi',
        'Goth' => 'gotiskt',
        'Gran' => 'grantha',
        'Grek' => 'grikskt',
        'Gujr' => 'gujarati',
        'Gukh' => 'gurung khema',
        'Guru' => 'gurmukhi',
        'Hanb' => 'hanb',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'einkult',
        'Hant' => 'vanligt',
        'Hatr' => 'hatran',
        'Hebr' => 'hebraiskt',
        'Hira' => 'hiragana',
        'Hluw' => 'anatoliskar hieroglyffur',
        'Hmng' => 'pahawh hmong',
        'Hmnp' => 'nyiakeng puachue hmong',
        'Hrkt' => 'japanskir stavir',
        'Hung' => 'gamalt ungarskt',
        'Ital' => 'gamalt italienskt',
        'Jamo' => 'jamo',
        'Java' => 'javanskt',
        'Jpan' => 'japanskt',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Kawi' => 'kawi',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmer',
        'Khoj' => 'khojki',
        'Knda' => 'kannada',
        'Kore' => 'koreanskt',
        'Lana' => 'lanna',
        'Laoo' => 'lao',
        'Latn' => 'latínskt',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lisu' => 'fraser',
        'Mand' => 'mandaean',
        'Mend' => 'mende',
        'Mlym' => 'malayalam',
        'Modi' => 'modi',
        'Mong' => 'mongolsk',
        'Mtei' => 'meitei mayek',
        'Mymr' => 'myanmarskt',
        'Newa' => 'newa',
        'Nkoo' => 'n’ko',
        'Nshu' => 'nüshu',
        'Ogam' => 'ogham',
        'Olck' => 'ol chiki',
        'Onao' => 'ol onal',
        'Orkh' => 'orkhon',
        'Orya' => 'odia',
        'Osge' => 'osage',
        'Osma' => 'osmanya',
        'Ougr' => 'gamalt uyghur',
        'Palm' => 'palmyrene',
        'Pauc' => 'pau cin hau',
        'Perm' => 'gamalt permic',
        'Phag' => 'phags-pa',
        'Rohg' => 'hanifi',
        'Runr' => 'rúnar',
        'Saur' => 'saurashtra',
        'Sidd' => 'siddham',
        'Sinh' => 'sinhala',
        'Sogd' => 'sogdian',
        'Sogo' => 'gamalt sogdian',
        'Soyo' => 'soyombo',
        'Sund' => 'sudanskt',
        'Sunu' => 'sunuwar',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'syriac',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takri',
        'Tale' => 'tai le',
        'Talu' => 'nýtt tai lue',
        'Taml' => 'tamilskt',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalog',
        'Thaa' => 'thaana',
        'Thai' => 'tailendskt',
        'Tibt' => 'tibetskt',
        'Tirh' => 'tirhuta',
        'Tnsa' => 'tangsa',
        'Todr' => 'todhri',
        'Toto' => 'toto',
        'Tutg' => 'tulu-tigalari',
        'Ugar' => 'ugaritic',
        'Vaii' => 'vai',
        'Vith' => 'vithkuqi',
        'Wara' => 'varang kshiti',
        'Wcho' => 'wancho',
        'Xsux' => 'sumero-akkadian cuneiform',
        'Yezi' => 'vezidi',
        'Yiii' => 'yi',
        'Zinh' => 'arva skrift',
        'Zmth' => 'støddfrøðilig teknskipan',
        'Zsye' => 'emoji',
        'Zsym' => 'tekin',
        'Zxxx' => 'óskriva',
        'Zyyy' => 'vanlig',
    ],
];
