<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Saeta Navînî ya Greenwichê (Abidjan)',
        'Africa/Accra' => 'Saeta Navînî ya Greenwichê (Accra)',
        'Africa/Addis_Ababa' => 'Saeta Afrîkaya Rojhilat (Addis Ababa)',
        'Africa/Algiers' => 'Saeta Ewropaya Navîn (Cezayîr)',
        'Africa/Asmera' => 'Saeta Afrîkaya Rojhilat (Asmara)',
        'Africa/Asmara' => 'Saeta Afrîkaya Rojhilat (Asmara)',
        'Africa/Bamako' => 'Saeta Navînî ya Greenwichê (Bamako)',
        'Africa/Bangui' => 'Saeta Afrîkaya Rojava (Bangui)',
        'Africa/Banjul' => 'Saeta Navînî ya Greenwichê (Banjul)',
        'Africa/Bissau' => 'Saeta Navînî ya Greenwichê (Bissau)',
        'Africa/Blantyre' => 'Saeta Afrîkaya Navîn (Blantyre)',
        'Africa/Brazzaville' => 'Saeta Afrîkaya Rojava (Brazzaville)',
        'Africa/Bujumbura' => 'Saeta Afrîkaya Navîn (Bujumbura)',
        'Africa/Cairo' => 'Saeta Ewropaya Rojhilat (Qahîre)',
        'Africa/Casablanca' => 'Saeta Ewropaya Rojava (Kazablanka)',
        'Africa/Ceuta' => 'Saeta Ewropaya Navîn (Septe)',
        'Africa/Conakry' => 'Saeta Navînî ya Greenwichê (Konakrî)',
        'Africa/Dakar' => 'Saeta Navînî ya Greenwichê (Dakar)',
        'Africa/Dar_es_Salaam' => 'Saeta Afrîkaya Rojhilat (Daruselam)',
        'Africa/Djibouti' => 'Saeta Afrîkaya Rojhilat (Cibûtî)',
        'Africa/Douala' => 'Saeta Afrîkaya Rojava (Douala)',
        'Africa/El_Aaiun' => 'Saeta Ewropaya Rojava (El Aaiún)',
        'Africa/Freetown' => 'Saeta Navînî ya Greenwichê (Freetown)',
        'Africa/Gaborone' => 'Saeta Afrîkaya Navîn (Gaborone)',
        'Africa/Harare' => 'Saeta Afrîkaya Navîn (Harare)',
        'Africa/Johannesburg' => 'Saeta Standard a Afrîkaya Başûr (Johannesburg)',
        'Africa/Juba' => 'Saeta Afrîkaya Navîn (Juba)',
        'Africa/Kampala' => 'Saeta Afrîkaya Rojhilat (Kampala)',
        'Africa/Khartoum' => 'Saeta Afrîkaya Navîn (Xartûm)',
        'Africa/Kigali' => 'Saeta Afrîkaya Navîn (Kîgalî)',
        'Africa/Kinshasa' => 'Saeta Afrîkaya Rojava (Kînşasa)',
        'Africa/Lagos' => 'Saeta Afrîkaya Rojava (Lagos)',
        'Africa/Libreville' => 'Saeta Afrîkaya Rojava (Lîbrevîl)',
        'Africa/Lome' => 'Saeta Navînî ya Greenwichê (Lomé)',
        'Africa/Luanda' => 'Saeta Afrîkaya Rojava (Luanda)',
        'Africa/Lubumbashi' => 'Saeta Afrîkaya Navîn (Lubumbashi)',
        'Africa/Lusaka' => 'Saeta Afrîkaya Navîn (Lusaka)',
        'Africa/Malabo' => 'Saeta Afrîkaya Rojava (Malabo)',
        'Africa/Maputo' => 'Saeta Afrîkaya Navîn (Maputo)',
        'Africa/Maseru' => 'Saeta Standard a Afrîkaya Başûr (Maserû)',
        'Africa/Mbabane' => 'Saeta Standard a Afrîkaya Başûr (Mbabane)',
        'Africa/Mogadishu' => 'Saeta Afrîkaya Rojhilat (Mogadîşû)',
        'Africa/Monrovia' => 'Saeta Navînî ya Greenwichê (Monrovia)',
        'Africa/Nairobi' => 'Saeta Afrîkaya Rojhilat (Naîrobî)',
        'Africa/Ndjamena' => 'Saeta Afrîkaya Rojava (N’Djamena)',
        'Africa/Niamey' => 'Saeta Afrîkaya Rojava (Niamey)',
        'Africa/Nouakchott' => 'Saeta Navînî ya Greenwichê (Nouakchott)',
        'Africa/Ouagadougou' => 'Saeta Navînî ya Greenwichê (Ouagadougou)',
        'Africa/Porto-Novo' => 'Saeta Afrîkaya Rojava (Porto-Novo)',
        'Africa/Sao_Tome' => 'Saeta Navînî ya Greenwichê (São Tomé)',
        'Africa/Tripoli' => 'Saeta Ewropaya Rojhilat (Trablûs)',
        'Africa/Tunis' => 'Saeta Ewropaya Navîn (Tûnis)',
        'Africa/Windhoek' => 'Saeta Afrîkaya Navîn (Windhoek)',
        'America/Adak' => 'Saeta Hawaii-Aleutianê (Adak)',
        'America/Anchorage' => 'Saeta Alaskayê (Anchorage)',
        'America/Anguilla' => 'Saeta Atlantîkê (Anguilla)',
        'America/Antigua' => 'Saeta Atlantîkê (Antigua)',
        'America/Araguaina' => 'Saeta Brasîlyayê (Araguaína)',
        'America/Argentina/La_Rioja' => 'Saeta Arjantînê (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Saeta Arjantînê (Río Gallegos)',
        'America/Argentina/Salta' => 'Saeta Arjantînê (Salta)',
        'America/Argentina/San_Juan' => 'Saeta Arjantînê (San Juan)',
        'America/Argentina/San_Luis' => 'Saeta Arjantînê (San Luis)',
        'America/Argentina/Tucuman' => 'Saeta Arjantînê (Tucumán)',
        'America/Argentina/Ushuaia' => 'Saeta Arjantînê (Ushuaia)',
        'America/Aruba' => 'Saeta Atlantîkê (Arûba)',
        'America/Asuncion' => 'Saeta Paragûayê (Asunción)',
        'America/Bahia' => 'Saeta Brasîlyayê (Bahia)',
        'America/Bahia_Banderas' => 'Saeta Merkezî ya Amerîkaya Bakur (Bahîa Banderas)',
        'America/Barbados' => 'Saeta Atlantîkê (Barbados)',
        'America/Belem' => 'Saeta Brasîlyayê (Belém)',
        'America/Belize' => 'Saeta Merkezî ya Amerîkaya Bakur (Belîze)',
        'America/Blanc-Sablon' => 'Saeta Atlantîkê (Blanc-Sablon)',
        'America/Boa_Vista' => 'Saeta Amazonê (Boa Vista)',
        'America/Bogota' => 'Saeta Kolombîyayê (Bogotá)',
        'America/Boise' => 'Saeta Çîyayî ya Amerîkaya Bakur (Boise)',
        'America/Buenos_Aires' => 'Saeta Arjantînê (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Saeta Arjantînê (Buenos Aires)',
        'America/Cambridge_Bay' => 'Saeta Çîyayî ya Amerîkaya Bakur (Cambridge Bay)',
        'America/Campo_Grande' => 'Saeta Amazonê (Campo Grande)',
        'America/Cancun' => 'Saeta Rojhilat a Amerîkaya Bakur (Cancûn)',
        'America/Caracas' => 'Saeta Venezûelayê (Caracas)',
        'America/Catamarca' => 'Saeta Arjantînê (Catamarca)',
        'America/Argentina/Catamarca' => 'Saeta Arjantînê (Catamarca)',
        'America/Cayenne' => 'Saeta Guiyanaya Fransî (Cayenne)',
        'America/Cayman' => 'Saeta Rojhilat a Amerîkaya Bakur (Cayman)',
        'America/Chicago' => 'Saeta Merkezî ya Amerîkaya Bakur (Chicago)',
        'America/Chihuahua' => 'Saeta Merkezî ya Amerîkaya Bakur (Chihuahua)',
        'America/Ciudad_Juarez' => 'Saeta Çîyayî ya Amerîkaya Bakur (Ciûdad Juarez)',
        'America/Coral_Harbour' => 'Saeta Rojhilat a Amerîkaya Bakur (Atikokan)',
        'America/Atikokan' => 'Saeta Rojhilat a Amerîkaya Bakur (Atikokan)',
        'America/Cordoba' => 'Saeta Arjantînê (Córdoba)',
        'America/Argentina/Cordoba' => 'Saeta Arjantînê (Córdoba)',
        'America/Costa_Rica' => 'Saeta Merkezî ya Amerîkaya Bakur (Kosta Rîka)',
        'America/Coyhaique' => 'Saeta Şîlîyê (Coyhaique)',
        'America/Creston' => 'Saeta Çîyayî ya Amerîkaya Bakur (Creston)',
        'America/Cuiaba' => 'Saeta Amazonê (Cuiabá)',
        'America/Curacao' => 'Saeta Atlantîkê (Curaçao)',
        'America/Danmarkshavn' => 'Saeta Navînî ya Greenwichê (Danmarkshavn)',
        'America/Dawson' => 'Saeta Yukonê (Dawson)',
        'America/Dawson_Creek' => 'Saeta Çîyayî ya Amerîkaya Bakur (Dawson Creek)',
        'America/Denver' => 'Saeta Çîyayî ya Amerîkaya Bakur (Denver)',
        'America/Detroit' => 'Saeta Rojhilat a Amerîkaya Bakur (Detroit)',
        'America/Dominica' => 'Saeta Atlantîkê (Domînîka)',
        'America/Edmonton' => 'Saeta Çîyayî ya Amerîkaya Bakur (Edmonton)',
        'America/Eirunepe' => 'Saeta Acreyê (Eirunepé)',
        'America/El_Salvador' => 'Saeta Merkezî ya Amerîkaya Bakur (El Salvador)',
        'America/Fort_Nelson' => 'Saeta Çîyayî ya Amerîkaya Bakur (Fort Nelson)',
        'America/Fortaleza' => 'Saeta Brasîlyayê (Fortaleza)',
        'America/Glace_Bay' => 'Saeta Atlantîkê (Glace Bay)',
        'America/Godthab' => 'Saeta Grînlendayê (Nuuk)',
        'America/Nuuk' => 'Saeta Grînlendayê (Nuuk)',
        'America/Goose_Bay' => 'Saeta Atlantîkê (Goose Bay)',
        'America/Grand_Turk' => 'Saeta Rojhilat a Amerîkaya Bakur (Grand Turk)',
        'America/Grenada' => 'Saeta Atlantîkê (Grenada)',
        'America/Guadeloupe' => 'Saeta Atlantîkê (Guadeloupe)',
        'America/Guatemala' => 'Saeta Merkezî ya Amerîkaya Bakur (Guatemala)',
        'America/Guayaquil' => 'Saeta Ekwadorê (Guayaquil)',
        'America/Guyana' => 'Saeta Guyanayê',
        'America/Halifax' => 'Saeta Atlantîkê (Halifax)',
        'America/Havana' => 'Saeta Kubayê (Havana)',
        'America/Hermosillo' => 'Saeta Pasîfîka Meksîkayê (Hermosillo)',
        'America/Indiana/Knox' => 'Saeta Merkezî ya Amerîkaya Bakur (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Saeta Rojhilat a Amerîkaya Bakur (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Saeta Rojhilat a Amerîkaya Bakur (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Saeta Merkezî ya Amerîkaya Bakur (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Saeta Rojhilat a Amerîkaya Bakur (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Saeta Rojhilat a Amerîkaya Bakur (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Saeta Rojhilat a Amerîkaya Bakur (Winamac, Indiana)',
        'America/Indianapolis' => 'Saeta Rojhilat a Amerîkaya Bakur (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Saeta Rojhilat a Amerîkaya Bakur (Indianapolis)',
        'America/Inuvik' => 'Saeta Çîyayî ya Amerîkaya Bakur (Inuvik)',
        'America/Iqaluit' => 'Saeta Rojhilat a Amerîkaya Bakur (Iqaluit)',
        'America/Jamaica' => 'Saeta Rojhilat a Amerîkaya Bakur (Jamaîka)',
        'America/Jujuy' => 'Saeta Arjantînê (Jujuy)',
        'America/Argentina/Jujuy' => 'Saeta Arjantînê (Jujuy)',
        'America/Juneau' => 'Saeta Alaskayê (Juneau)',
        'America/Kentucky/Monticello' => 'Saeta Rojhilat a Amerîkaya Bakur (Monticello, Kentucky)',
        'America/Kralendijk' => 'Saeta Atlantîkê (Kralendijk)',
        'America/La_Paz' => 'Saeta Bolîvyayê (La Paz)',
        'America/Lima' => 'Saeta Perûyê (Lima)',
        'America/Los_Angeles' => 'Saeta Pasîfîkê ya Amerîkaya Bakur (Los Angeles)',
        'America/Louisville' => 'Saeta Rojhilat a Amerîkaya Bakur (Louisville)',
        'America/Kentucky/Louisville' => 'Saeta Rojhilat a Amerîkaya Bakur (Louisville)',
        'America/Lower_Princes' => 'Saeta Atlantîkê (Lower Prince’s Quarter)',
        'America/Maceio' => 'Saeta Brasîlyayê (Maceió)',
        'America/Managua' => 'Saeta Merkezî ya Amerîkaya Bakur (Managua)',
        'America/Manaus' => 'Saeta Amazonê (Manaus)',
        'America/Marigot' => 'Saeta Atlantîkê (Marigot)',
        'America/Martinique' => 'Saeta Atlantîkê (Martinique)',
        'America/Matamoros' => 'Saeta Merkezî ya Amerîkaya Bakur (Matamoros)',
        'America/Mazatlan' => 'Saeta Pasîfîka Meksîkayê (Mazatlán)',
        'America/Mendoza' => 'Saeta Arjantînê (Mendoza)',
        'America/Argentina/Mendoza' => 'Saeta Arjantînê (Mendoza)',
        'America/Menominee' => 'Saeta Merkezî ya Amerîkaya Bakur (Menominee)',
        'America/Merida' => 'Saeta Merkezî ya Amerîkaya Bakur (Merîda)',
        'America/Metlakatla' => 'Saeta Alaskayê (Metlakatla)',
        'America/Mexico_City' => 'Saeta Merkezî ya Amerîkaya Bakur (Ciudad de México)',
        'America/Miquelon' => 'Saeta Saint Pierre û Miquelonê',
        'America/Moncton' => 'Saeta Atlantîkê (Moncton)',
        'America/Monterrey' => 'Saeta Merkezî ya Amerîkaya Bakur (Monterrey)',
        'America/Montevideo' => 'Saeta Ûrûgûayê (Montevideo)',
        'America/Montserrat' => 'Saeta Atlantîkê (Montserrat)',
        'America/Nassau' => 'Saeta Rojhilat a Amerîkaya Bakur (Nassau)',
        'America/New_York' => 'Saeta Rojhilat a Amerîkaya Bakur (New York)',
        'America/Nome' => 'Saeta Alaskayê (Nome)',
        'America/Noronha' => 'Saeta Fernando de Noronhayê',
        'America/North_Dakota/Beulah' => 'Saeta Merkezî ya Amerîkaya Bakur (Beûlah, Dakotaya Bakur)',
        'America/North_Dakota/Center' => 'Saeta Merkezî ya Amerîkaya Bakur (Center, Dakotaya Bakur)',
        'America/North_Dakota/New_Salem' => 'Saeta Merkezî ya Amerîkaya Bakur (New Salem, Dakotaya Bakur)',
        'America/Ojinaga' => 'Saeta Merkezî ya Amerîkaya Bakur (Ojinaga)',
        'America/Panama' => 'Saeta Rojhilat a Amerîkaya Bakur (Panama)',
        'America/Paramaribo' => 'Saeta Surînamê (Paramaribo)',
        'America/Phoenix' => 'Saeta Çîyayî ya Amerîkaya Bakur (Phoenix)',
        'America/Port-au-Prince' => 'Saeta Rojhilat a Amerîkaya Bakur (Port-au-Prince)',
        'America/Port_of_Spain' => 'Saeta Atlantîkê (Port of Spain)',
        'America/Porto_Velho' => 'Saeta Amazonê (Porto Velho)',
        'America/Puerto_Rico' => 'Saeta Atlantîkê (Porto Rîko)',
        'America/Punta_Arenas' => 'Saeta Şîlîyê (Punta Arenas)',
        'America/Rankin_Inlet' => 'Saeta Merkezî ya Amerîkaya Bakur (Rankin Inlet)',
        'America/Recife' => 'Saeta Brasîlyayê (Recife)',
        'America/Regina' => 'Saeta Merkezî ya Amerîkaya Bakur (Regina)',
        'America/Resolute' => 'Saeta Merkezî ya Amerîkaya Bakur (Resolute)',
        'America/Rio_Branco' => 'Saeta Acreyê (Rio Branco)',
        'America/Santarem' => 'Saeta Brasîlyayê (Santarém)',
        'America/Santiago' => 'Saeta Şîlîyê (Santiago)',
        'America/Santo_Domingo' => 'Saeta Atlantîkê (Santo Domingo)',
        'America/Sao_Paulo' => 'Saeta Brasîlyayê (São Paulo)',
        'America/Scoresbysund' => 'Saeta Grînlendayê (Ittoqqortoormiit)',
        'America/Sitka' => 'Saeta Alaskayê (Sitka)',
        'America/St_Barthelemy' => 'Saeta Atlantîkê (Saint Barthelemy)',
        'America/St_Johns' => 'Saeta Newfoundlandê (St. John’s)',
        'America/St_Kitts' => 'Saeta Atlantîkê (St. Kitts)',
        'America/St_Lucia' => 'Saeta Atlantîkê (St. Lucia)',
        'America/St_Thomas' => 'Saeta Atlantîkê (St. Thomas)',
        'America/St_Vincent' => 'Saeta Atlantîkê (St. Vincent)',
        'America/Swift_Current' => 'Saeta Merkezî ya Amerîkaya Bakur (Swift Current)',
        'America/Tegucigalpa' => 'Saeta Merkezî ya Amerîkaya Bakur (Tegucigalpa)',
        'America/Thule' => 'Saeta Atlantîkê (Thule)',
        'America/Tijuana' => 'Saeta Pasîfîkê ya Amerîkaya Bakur (Tijuana)',
        'America/Toronto' => 'Saeta Rojhilat a Amerîkaya Bakur (Toronto)',
        'America/Tortola' => 'Saeta Atlantîkê (Tortola)',
        'America/Vancouver' => 'Saeta Pasîfîkê ya Amerîkaya Bakur (Vancouver)',
        'America/Whitehorse' => 'Saeta Yukonê (Whitehorse)',
        'America/Winnipeg' => 'Saeta Merkezî ya Amerîkaya Bakur (Winnipeg)',
        'America/Yakutat' => 'Saeta Alaskayê (Yakutat)',
        'Antarctica/Casey' => 'Saeta Awistralyaya Rojava (Casey)',
        'Antarctica/Davis' => 'Saeta Davîsê',
        'Antarctica/DumontDUrville' => 'Saeta Dumont-d’Urvilleyê',
        'Antarctica/Macquarie' => 'Saeta Awistralyaya Rojhilat (Macquarie)',
        'Antarctica/Mawson' => 'Saeta Mawsonê',
        'Antarctica/McMurdo' => 'Saeta Zelandaya Nû (McMurdo)',
        'Antarctica/Palmer' => 'Saeta Şîlîyê (Palmer)',
        'Antarctica/Rothera' => 'Saeta Rotherayê',
        'Antarctica/Syowa' => 'Saeta Syowayê (Showa)',
        'Antarctica/Troll' => 'Saeta Navînî ya Greenwichê (Troll)',
        'Antarctica/Vostok' => 'Saeta Vostokê',
        'Arctic/Longyearbyen' => 'Saeta Ewropaya Navîn (Longyearbyen)',
        'Asia/Aden' => 'Saeta Erebistanê (Aden)',
        'Asia/Almaty' => 'Saeta Qazaxistanê (Almatî)',
        'Asia/Amman' => 'Saeta Ewropaya Rojhilat (Eman)',
        'Asia/Anadyr' => 'Saeta Kamchatkayê (Anadir)',
        'Asia/Aqtau' => 'Saeta Qazaxistanê (Aqtaw)',
        'Asia/Aqtobe' => 'Saeta Qazaxistanê (Aqtobe)',
        'Asia/Ashgabat' => 'Saeta Tirkmenistanê (Eşqabat)',
        'Asia/Atyrau' => 'Saeta Qazaxistanê (Atîrav)',
        'Asia/Baghdad' => 'Saeta Erebistanê (Bexda)',
        'Asia/Bahrain' => 'Saeta Erebistanê (Behreyn)',
        'Asia/Baku' => 'Saeta Azerbeycanê (Bakû)',
        'Asia/Bangkok' => 'Saeta Hindiçînê (Bangkok)',
        'Asia/Barnaul' => 'Saeta Krasnoyarskê (Barnaul)',
        'Asia/Beirut' => 'Saeta Ewropaya Rojhilat (Beyrût)',
        'Asia/Bishkek' => 'Saeta Qirxizistanê (Bîşkek)',
        'Asia/Brunei' => 'Saeta Brûneyê',
        'Asia/Calcutta' => 'Saeta Hindistanê ya Standard (Kolkata)',
        'Asia/Kolkata' => 'Saeta Hindistanê ya Standard (Kolkata)',
        'Asia/Chita' => 'Saeta Yakutskê (Çîta)',
        'Asia/Colombo' => 'Saeta Hindistanê ya Standard (Kolombo)',
        'Asia/Damascus' => 'Saeta Ewropaya Rojhilat (Şam)',
        'Asia/Dhaka' => 'Saeta Bengladeşê (Daka)',
        'Asia/Dili' => 'Saeta Tîmûra Rojhilat (Dîlî)',
        'Asia/Dubai' => 'Saeta Kendavê ya Standard (Dûbaî)',
        'Asia/Dushanbe' => 'Saeta Tacikistanê (Duşenbe)',
        'Asia/Famagusta' => 'Saeta Ewropaya Rojhilat (Famagusta)',
        'Asia/Gaza' => 'Saeta Ewropaya Rojhilat (Xeze)',
        'Asia/Hebron' => 'Saeta Ewropaya Rojhilat (Hebron)',
        'Asia/Hong_Kong' => 'Saeta Hong Kongê',
        'Asia/Hovd' => 'Saeta Hovdê (Khovd)',
        'Asia/Irkutsk' => 'Saeta Irkutskê',
        'Asia/Jakarta' => 'Saeta Endonezyaya Rojava (Cakarta)',
        'Asia/Jayapura' => 'Saeta Endonezyaya Rojhilat (Cayapûra)',
        'Asia/Jerusalem' => 'Saeta Îsraîlê (Quds)',
        'Asia/Kabul' => 'Saeta Efxanistanê (Kabûl)',
        'Asia/Kamchatka' => 'Saeta Kamchatkayê (Kamçatka)',
        'Asia/Karachi' => 'Saeta Pakistanê (Karaçî)',
        'Asia/Katmandu' => 'Saeta Nepalê (Katmandû)',
        'Asia/Kathmandu' => 'Saeta Nepalê (Katmandû)',
        'Asia/Khandyga' => 'Saeta Yakutskê (Xandîga)',
        'Asia/Krasnoyarsk' => 'Saeta Krasnoyarskê',
        'Asia/Kuala_Lumpur' => 'Saeta Malezyayê (Kûala Lûmpûr)',
        'Asia/Kuching' => 'Saeta Malezyayê (Kûçîng)',
        'Asia/Kuwait' => 'Saeta Erebistanê (Kuweyt)',
        'Asia/Macau' => 'Saeta Çînê (Makao)',
        'Asia/Magadan' => 'Saeta Magadanê',
        'Asia/Makassar' => 'Saeta Endonezyaya Navîn (Makasar)',
        'Asia/Manila' => 'Saeta Fîlîpînê (Manîla)',
        'Asia/Muscat' => 'Saeta Kendavê ya Standard (Muskat)',
        'Asia/Nicosia' => 'Saeta Ewropaya Rojhilat (Lefkoşe)',
        'Asia/Novokuznetsk' => 'Saeta Krasnoyarskê (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Saeta Krasnoyarskê (Novosibirsk)',
        'Asia/Omsk' => 'Saeta Omskê',
        'Asia/Oral' => 'Saeta Qazaxistanê (Oral)',
        'Asia/Phnom_Penh' => 'Saeta Hindiçînê (Phnom Penh)',
        'Asia/Pontianak' => 'Saeta Endonezyaya Rojava (Pontianak)',
        'Asia/Pyongyang' => 'Saeta Koreyê (Pyongyang)',
        'Asia/Qatar' => 'Saeta Erebistanê (Qeter)',
        'Asia/Qostanay' => 'Saeta Qazaxistanê (Qostanay)',
        'Asia/Qyzylorda' => 'Saeta Qazaxistanê (Qizilorda)',
        'Asia/Rangoon' => 'Saeta Myanmarê (Yangon)',
        'Asia/Yangon' => 'Saeta Myanmarê (Yangon)',
        'Asia/Riyadh' => 'Saeta Erebistanê (Riyad)',
        'Asia/Saigon' => 'Saeta Hindiçînê (Bajarê Ho Chi Minhê)',
        'Asia/Ho_Chi_Minh' => 'Saeta Hindiçînê (Bajarê Ho Chi Minhê)',
        'Asia/Sakhalin' => 'Saeta Magadanê (Saxalîn)',
        'Asia/Samarkand' => 'Saeta Ozbekistanê (Semerkand)',
        'Asia/Seoul' => 'Saeta Koreyê (Seûl)',
        'Asia/Shanghai' => 'Saeta Çînê (Şanghay)',
        'Asia/Singapore' => 'Saeta Sîngapûrê ya Standard',
        'Asia/Srednekolymsk' => 'Saeta Magadanê (Srednekolymsk)',
        'Asia/Taipei' => 'Saeta Taîpeîyê',
        'Asia/Tashkent' => 'Saeta Ozbekistanê (Taşkent)',
        'Asia/Tbilisi' => 'Saeta Gurcistanê (Tiflîs)',
        'Asia/Tehran' => 'Saeta Îranê (Tehran)',
        'Asia/Thimphu' => 'Saeta Bûtanê (Thimphu)',
        'Asia/Tokyo' => 'Saeta Japonyayê (Tokyo)',
        'Asia/Tomsk' => 'Saeta Krasnoyarskê (Tomsk)',
        'Asia/Ulaanbaatar' => 'Saeta Ûlanbatarê',
        'Asia/Urumqi' => 'Saeta Çîn(y)ê (Ûrûmçî)',
        'Asia/Ust-Nera' => 'Saeta Vladivostokê (Ûst-Nera)',
        'Asia/Vientiane' => 'Saeta Hindiçînê (Vientiane)',
        'Asia/Vladivostok' => 'Saeta Vladivostokê',
        'Asia/Yakutsk' => 'Saeta Yakutskê',
        'Asia/Yekaterinburg' => 'Saeta Yekaterinburgê',
        'Asia/Yerevan' => 'Saeta Ermenistanê (Rewan)',
        'Atlantic/Azores' => 'Saeta Azoran (Giravên Azorê)',
        'Atlantic/Bermuda' => 'Saeta Atlantîkê (Bermûda)',
        'Atlantic/Canary' => 'Saeta Ewropaya Rojava (Giravên Kanaryayê)',
        'Atlantic/Cape_Verde' => 'Saeta Cape Verdeyê (Kap Verde)',
        'Atlantic/Faeroe' => 'Saeta Ewropaya Rojava (Faroe)',
        'Atlantic/Faroe' => 'Saeta Ewropaya Rojava (Faroe)',
        'Atlantic/Madeira' => 'Saeta Ewropaya Rojava (Madeira)',
        'Atlantic/Reykjavik' => 'Saeta Navînî ya Greenwichê (Reykjavik)',
        'Atlantic/South_Georgia' => 'Saeta Georgiaya Başûr',
        'Atlantic/St_Helena' => 'Saeta Navînî ya Greenwichê (St. Helena)',
        'Atlantic/Stanley' => 'Saeta Giravên Falklandê (Stanley)',
        'Australia/Adelaide' => 'Saeta Awistralyaya Navîn (Adelaide)',
        'Australia/Brisbane' => 'Saeta Awistralyaya Rojhilat (Brisbane)',
        'Australia/Broken_Hill' => 'Saeta Awistralyaya Navîn (Broken Hill)',
        'Australia/Darwin' => 'Saeta Awistralyaya Navîn (Darwin)',
        'Australia/Eucla' => 'Saeta Rojavaya Navîn a Awistralyayê (Eucla)',
        'Australia/Hobart' => 'Saeta Awistralyaya Rojhilat (Hobart)',
        'Australia/Lindeman' => 'Saeta Awistralyaya Rojhilat (Lindeman)',
        'Australia/Lord_Howe' => 'Saeta Lord Howeyê',
        'Australia/Melbourne' => 'Saeta Awistralyaya Rojhilat (Melbourne)',
        'Australia/Perth' => 'Saeta Awistralyaya Rojava (Perth)',
        'Australia/Sydney' => 'Saeta Awistralyaya Rojhilat (Sîdney)',
        'Etc/GMT' => 'Saeta Navînî ya Greenwichê',
        'Etc/UTC' => 'Saeta Gerdûnî ya Hevdemî',
        'Europe/Amsterdam' => 'Saeta Ewropaya Navîn (Amsterdam)',
        'Europe/Andorra' => 'Saeta Ewropaya Navîn (Andora)',
        'Europe/Astrakhan' => 'Saeta Samarayê (Astraxan)',
        'Europe/Athens' => 'Saeta Ewropaya Rojhilat (Atîna)',
        'Europe/Belgrade' => 'Saeta Ewropaya Navîn (Belgrad)',
        'Europe/Berlin' => 'Saeta Ewropaya Navîn (Berlîn)',
        'Europe/Bratislava' => 'Saeta Ewropaya Navîn (Bratislava)',
        'Europe/Brussels' => 'Saeta Ewropaya Navîn (Bruksel)',
        'Europe/Bucharest' => 'Saeta Ewropaya Rojhilat (Bukreş)',
        'Europe/Budapest' => 'Saeta Ewropaya Navîn (Bûdapeşt)',
        'Europe/Busingen' => 'Saeta Ewropaya Navîn (Bûsîngen)',
        'Europe/Chisinau' => 'Saeta Ewropaya Rojhilat (Kişînew)',
        'Europe/Copenhagen' => 'Saeta Ewropaya Navîn (Kopenhag)',
        'Europe/Dublin' => 'Saeta Navînî ya Greenwichê (Dûblîn)',
        'Europe/Gibraltar' => 'Saeta Ewropaya Navîn (Cebelîtariq)',
        'Europe/Guernsey' => 'Saeta Navînî ya Greenwichê (Guernsey)',
        'Europe/Helsinki' => 'Saeta Ewropaya Rojhilat (Helsînkî)',
        'Europe/Isle_of_Man' => 'Saeta Navînî ya Greenwichê (Girava Manê)',
        'Europe/Istanbul' => 'Saeta Türkiye(y)ê (Stenbol)',
        'Europe/Jersey' => 'Saeta Navînî ya Greenwichê (Jersey)',
        'Europe/Kaliningrad' => 'Saeta Ewropaya Rojhilat (Kalînîngrad)',
        'Europe/Kiev' => 'Saeta Ewropaya Rojhilat (Kîev)',
        'Europe/Kyiv' => 'Saeta Ewropaya Rojhilat (Kîev)',
        'Europe/Kirov' => 'Saeta Moskovayê (Kîrov)',
        'Europe/Lisbon' => 'Saeta Ewropaya Rojava (Lîzbon)',
        'Europe/Ljubljana' => 'Saeta Ewropaya Navîn (Ljubljana)',
        'Europe/London' => 'Saeta Navînî ya Greenwichê (Londra)',
        'Europe/Luxembourg' => 'Saeta Ewropaya Navîn (Luksembûrg)',
        'Europe/Madrid' => 'Saeta Ewropaya Navîn (Madrîd)',
        'Europe/Malta' => 'Saeta Ewropaya Navîn (Malta)',
        'Europe/Mariehamn' => 'Saeta Ewropaya Rojhilat (Mariehamn)',
        'Europe/Minsk' => 'Saeta Moskovayê (Mînsk)',
        'Europe/Monaco' => 'Saeta Ewropaya Navîn (Monako)',
        'Europe/Moscow' => 'Saeta Moskovayê',
        'Europe/Oslo' => 'Saeta Ewropaya Navîn (Oslo)',
        'Europe/Paris' => 'Saeta Ewropaya Navîn (Parîs)',
        'Europe/Podgorica' => 'Saeta Ewropaya Navîn (Podgorîka)',
        'Europe/Prague' => 'Saeta Ewropaya Navîn (Prag)',
        'Europe/Riga' => 'Saeta Ewropaya Rojhilat (Rîga)',
        'Europe/Rome' => 'Saeta Ewropaya Navîn (Roma)',
        'Europe/Samara' => 'Saeta Samarayê',
        'Europe/San_Marino' => 'Saeta Ewropaya Navîn (San Marîno)',
        'Europe/Sarajevo' => 'Saeta Ewropaya Navîn (Saraybosna)',
        'Europe/Saratov' => 'Saeta Samarayê (Saratov)',
        'Europe/Simferopol' => 'Saeta Moskovayê (Simferopol)',
        'Europe/Skopje' => 'Saeta Ewropaya Navîn (Uskup)',
        'Europe/Sofia' => 'Saeta Ewropaya Rojhilat (Sofya)',
        'Europe/Stockholm' => 'Saeta Ewropaya Navîn (Stokholm)',
        'Europe/Tallinn' => 'Saeta Ewropaya Rojhilat (Talîn)',
        'Europe/Tirane' => 'Saeta Ewropaya Navîn (Tîran)',
        'Europe/Ulyanovsk' => 'Saeta Samarayê (Ulyanovsk)',
        'Europe/Vaduz' => 'Saeta Ewropaya Navîn (Vaduz)',
        'Europe/Vatican' => 'Saeta Ewropaya Navîn (Vatîkan)',
        'Europe/Vienna' => 'Saeta Ewropaya Navîn (Viyana)',
        'Europe/Vilnius' => 'Saeta Ewropaya Rojhilat (Vîlnûs)',
        'Europe/Volgograd' => 'Saeta Moskovayê (Volgograd)',
        'Europe/Warsaw' => 'Saeta Ewropaya Navîn (Warşova)',
        'Europe/Zagreb' => 'Saeta Ewropaya Navîn (Zagreb)',
        'Europe/Zurich' => 'Saeta Ewropaya Navîn (Zûrîh)',
        'Indian/Antananarivo' => 'Saeta Afrîkaya Rojhilat (Antananarivo)',
        'Indian/Chagos' => 'Saeta Okyanûsa Hindê (Chagos)',
        'Indian/Christmas' => 'Saeta Girava Christmasê',
        'Indian/Cocos' => 'Saeta Giravên Cocosê',
        'Indian/Comoro' => 'Saeta Afrîkaya Rojhilat (Komor)',
        'Indian/Kerguelen' => 'Saeta Antarktîka û Başûrê Fransayê (Kerguelen)',
        'Indian/Mahe' => 'Saeta Seyşelerê (Mahé)',
        'Indian/Maldives' => 'Saeta Maldîvan',
        'Indian/Mauritius' => 'Saeta Mauritiusê',
        'Indian/Mayotte' => 'Saeta Afrîkaya Rojhilat (Mayotte)',
        'Indian/Reunion' => 'Saeta Réunionê',
        'Pacific/Apia' => 'Saeta Apiayê',
        'Pacific/Auckland' => 'Saeta Zelandaya Nû (Auckland)',
        'Pacific/Bougainville' => 'Saeta Gîneya Nû ya Papûayê (Bougainville)',
        'Pacific/Chatham' => 'Saeta Chathamê',
        'Pacific/Easter' => 'Saeta Girava Paskalyayê (Easter)',
        'Pacific/Efate' => 'Saeta Vanûatûyê (Efate)',
        'Pacific/Enderbury' => 'Saeta Giravên Phoenîks (Canton)',
        'Pacific/Kanton' => 'Saeta Giravên Phoenîks (Canton)',
        'Pacific/Fakaofo' => 'Saeta Tokelauyê (Fakaofo)',
        'Pacific/Fiji' => 'Saeta Fîjîyê',
        'Pacific/Funafuti' => 'Saeta Tûvalûyê (Funafuti)',
        'Pacific/Galapagos' => 'Saeta Galapagosê (Galápagos)',
        'Pacific/Gambier' => 'Saeta Gambierê',
        'Pacific/Guadalcanal' => 'Saeta Giravên Solomonê (Guadalcanal)',
        'Pacific/Guam' => 'Saeta Chamorroyê ya Standard (Guam)',
        'Pacific/Honolulu' => 'Saeta Standard a Hawaii-Aleutianê (Honolulu)',
        'Pacific/Kiritimati' => 'Saeta Giravên Lîneyê (Kiritimati)',
        'Pacific/Kosrae' => 'Saeta Kosraeyê',
        'Pacific/Kwajalein' => 'Saeta Giravên Marşalê (Kwajalein)',
        'Pacific/Majuro' => 'Saeta Giravên Marşalê (Majuro)',
        'Pacific/Marquesas' => 'Saeta Marquesasê',
        'Pacific/Midway' => 'Saeta Samoayê (Midway)',
        'Pacific/Nauru' => 'Saeta Naûrûyê (Nauru)',
        'Pacific/Niue' => 'Saeta Niueyê',
        'Pacific/Norfolk' => 'Saeta Girava Norfolkê',
        'Pacific/Noumea' => 'Saeta Kaledonyaya Nû (Nouméa)',
        'Pacific/Pago_Pago' => 'Saeta Samoayê (Pago Pago)',
        'Pacific/Palau' => 'Saeta Palauyê',
        'Pacific/Pitcairn' => 'Saeta Pitcairnê',
        'Pacific/Ponape' => 'Saeta Ponapeyê (Pohnpei)',
        'Pacific/Pohnpei' => 'Saeta Ponapeyê (Pohnpei)',
        'Pacific/Port_Moresby' => 'Saeta Gîneya Nû ya Papûayê (Port Moresby)',
        'Pacific/Rarotonga' => 'Saeta Giravên Cookê (Rarotonga)',
        'Pacific/Saipan' => 'Saeta Chamorroyê ya Standard (Saipan)',
        'Pacific/Tahiti' => 'Saeta Tahîtîyê',
        'Pacific/Tarawa' => 'Saeta Giravên Gilbertê (Tarawa)',
        'Pacific/Tongatapu' => 'Saeta Tongayê (Tongatapu)',
        'Pacific/Truk' => 'Saeta Chuukê',
        'Pacific/Chuuk' => 'Saeta Chuukê',
        'Pacific/Wake' => 'Saeta Girava Wakeyê',
        'Pacific/Wallis' => 'Saeta Wallis û Futunayê (Wallis & Futuna)',
    ],
    'Meta' => [],
];
