<?php

declare(strict_types=1);

namespace SimpleSAML\SAML2\XML\md;

/**
 * ManageNameIDService element of type EndpointType
 *
 * @package simplesamlphp/saml2
 */
final class ManageNameIDService extends AbstractEndpointType
{
}
