<?php

return [
    'Names' => [
        'ar_001' => 'arapski (svijet)',
        'ar_KM' => 'arapski (Komori)',
        'ar_PS' => 'arapski (palestinske teritorije)',
        'be' => 'bjeloruski',
        'be_BY' => 'bjeloruski (Bjelorusija)',
        'bm' => 'bamanankan',
        'bm_ML' => 'bamanankan (Mali)',
        'bn' => 'bangla',
        'bn_BD' => 'bangla (Bangladeš)',
        'bn_IN' => 'bangla (Indija)',
        'cs_CZ' => 'češki (Češka Republika)',
        'de' => 'njemački',
        'de_AT' => 'njemački (Austrija)',
        'de_BE' => 'njemački (Belgija)',
        'de_CH' => 'njemački (Švajcarska)',
        'de_DE' => 'njemački (Njemačka)',
        'de_IT' => 'njemački (Italija)',
        'de_LI' => 'njemački (Lihtenštajn)',
        'de_LU' => 'njemački (Luksemburg)',
        'en_001' => 'engleski (svijet)',
        'en_CC' => 'engleski (Kokosova [Kiling] ostrva)',
        'en_CZ' => 'engleski (Češka Republika)',
        'en_DE' => 'engleski (Njemačka)',
        'en_FK' => 'engleski (Foklandska ostrva)',
        'en_GS' => 'engleski (Južna Džordžija i Južna Sendvička ostrva)',
        'en_GU' => 'engleski (Gvam)',
        'en_HK' => 'engleski (Hongkong [SAO Kine])',
        'en_MP' => 'engleski (Sjeverna Marijanska ostrva)',
        'en_NF' => 'engleski (ostrvo Norfok)',
        'en_NU' => 'engleski (Nijue)',
        'en_UM' => 'engleski (Spoljna ostrva SAD)',
        'en_VC' => 'engleski (Sveti Vinsent i Grenadini)',
        'en_VG' => 'engleski (Britanska Djevičanska ostrva)',
        'en_VI' => 'engleski (Američka Djevičanska ostrva)',
        'eo_001' => 'esperanto (svijet)',
        'ff_Adlm_GW' => 'fula (adlam, Gvineja Bisao)',
        'ff_Latn_GW' => 'fula (latinica, Gvineja Bisao)',
        'fo_FO' => 'farski (Farska ostrva)',
        'fr_BL' => 'francuski (Sen Bartelemi)',
        'fr_KM' => 'francuski (Komori)',
        'fr_RE' => 'francuski (Reunion)',
        'ia_001' => 'interlingva (svijet)',
        'ko_KP' => 'korejski (Sjeverna Koreja)',
        'mk_MK' => 'makedonski (Sjeverna Makedonija)',
        'ms_BN' => 'malajski (Bruneji)',
        'my_MM' => 'burmanski (Mjanmar [Burma])',
        'nd' => 'sjeverni ndebele',
        'nd_ZW' => 'sjeverni ndebele (Zimbabve)',
        'pt_GW' => 'portugalski (Gvineja Bisao)',
        'ru_BY' => 'ruski (Bjelorusija)',
        'se' => 'sjeverni sami',
        'se_FI' => 'sjeverni sami (Finska)',
        'se_NO' => 'sjeverni sami (Norveška)',
        'se_SE' => 'sjeverni sami (Švedska)',
        'sq_MK' => 'albanski (Sjeverna Makedonija)',
        'sv_AX' => 'švedski (Olandska ostrva)',
        'zh_HK' => 'kineski (Hongkong [SAO Kine])',
        'zh_Hans_HK' => 'kineski (pojednostavljeno kinesko pismo, Hongkong [SAO Kine])',
        'zh_Hant_HK' => 'kineski (tradicionalno kinesko pismo, Hongkong [SAO Kine])',
    ],
];
