<?php

return [
    'Names' => [
        'AUD' => [
            '$',
            'Australian Dollar',
        ],
        'BAM' => [
            'BAM',
            'Bosnia-Herzegovina Convertible Marka',
        ],
        'BBD' => [
            'BBD',
            'Barbados Dollar',
        ],
        'BMD' => [
            'BMD',
            'Bermuda Dollar',
        ],
        'BOB' => [
            'BOB',
            'Bolivian boliviano',
        ],
        'BRL' => [
            'BRL',
            'Brazilian Real',
        ],
        'CAD' => [
            'CAD',
            'Canadian Dollar',
        ],
        'CNY' => [
            'CNY',
            'Chinese Yuan',
        ],
        'EUR' => [
            'EUR',
            'Euro',
        ],
        'GBP' => [
            'GBP',
            'British Pound',
        ],
        'HKD' => [
            'HKD',
            'Hong Kong Dollar',
        ],
        'ILS' => [
            'ILS',
            'Israeli Shekel',
        ],
        'INR' => [
            'INR',
            'Indian Rupee',
        ],
        'JPY' => [
            'JPY',
            'Japanese Yen',
        ],
        'KRW' => [
            'KRW',
            'South Korean Won',
        ],
        'MXN' => [
            'MXN',
            'Mexican Peso',
        ],
        'NZD' => [
            'NZD',
            'New Zealand Dollar',
        ],
        'PHP' => [
            'PHP',
            'Philippine Peso',
        ],
        'SCR' => [
            'Rs',
            'Seychellois Rupee',
        ],
        'SLL' => [
            'SLL',
            'Sierra Leonean Leone (1964–2022)',
        ],
        'SRD' => [
            'SRD',
            'Suriname Dollar',
        ],
        'TWD' => [
            'TWD',
            'New Taiwan Dollar',
        ],
        'USD' => [
            'USD',
            'US Dollar',
        ],
        'UYU' => [
            'UYU',
            'Peso Uruguayo',
        ],
        'VES' => [
            'VES',
            'Venezuelan bolívar',
        ],
        'VND' => [
            'VND',
            'Vietnamese Dong',
        ],
        'XAF' => [
            'XAF',
            'Central African CFA Franc',
        ],
        'XCD' => [
            'XCD',
            'East Caribbean Dollar',
        ],
        'XOF' => [
            'XOF',
            'West African CFA Franc',
        ],
        'XPF' => [
            'CFP',
            'CFP Franc',
        ],
    ],
];
