<?php

declare(strict_types=1);

namespace SimpleSAML\XMLSecurity\XML\xenc;

/**
 * Class representing the <xenc:DataReference> element.
 *
 * @package simplesamlphp/xml-security
 */
class DataReference extends AbstractReference
{
}
