<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'گڏيل عرب امارات درهم',
        ],
        'AFN' => [
            'AFN',
            'افغاني افغاني',
        ],
        'ALL' => [
            'ALL',
            'الباني ليڪ',
        ],
        'AMD' => [
            'AMD',
            'ارماني ڊرم',
        ],
        'ANG' => [
            'ANG',
            'نيڌرلينڊ انٽليئن گلڊر',
        ],
        'AOA' => [
            'AOA',
            'انگوليائي ڪوانزا',
        ],
        'ARS' => [
            'ARS',
            'ارجنٽائن پيسو',
        ],
        'AUD' => [
            'A$',
            'آسٽريلوي ڊالر',
        ],
        'AWG' => [
            'AWG',
            'اروبن فلورن',
        ],
        'AZN' => [
            'AZN',
            'آذربائيجاني منت',
        ],
        'BAM' => [
            'BAM',
            'بوسنيا هرزگوينا ڪنورٽبل مارڪ',
        ],
        'BBD' => [
            'BBD',
            'باربيڊين ڊالر',
        ],
        'BDT' => [
            'BDT',
            'بنگلاديشي ٽڪا',
        ],
        'BGN' => [
            'BGN',
            'بلغارین لیو',
        ],
        'BHD' => [
            'BHD',
            'بحريني دينار',
        ],
        'BIF' => [
            'BIF',
            'برونڊي فرينڪ',
        ],
        'BMD' => [
            'BMD',
            'برمودي ڊالر',
        ],
        'BND' => [
            'BND',
            'برونائي ڊالر',
        ],
        'BOB' => [
            'BOB',
            'بولیوین بولیویانو',
        ],
        'BRL' => [
            'R$',
            'برازيلي ريل',
        ],
        'BSD' => [
            'BSD',
            'بهاماني ڊادلر',
        ],
        'BTN' => [
            'BTN',
            'ڀوٽاني گلٽرم',
        ],
        'BWP' => [
            'BWP',
            'بوستواني پولا',
        ],
        'BYN' => [
            'BYN',
            'بیلاروسی ربل',
        ],
        'BZD' => [
            'BZD',
            'بيليز ڊالر',
        ],
        'CAD' => [
            'CA$',
            'ڪئينڊيائي ڊالر',
        ],
        'CDF' => [
            'CDF',
            'ڪانگو فرينڪ',
        ],
        'CHF' => [
            'CHF',
            'سوئس فرينڪ',
        ],
        'CLP' => [
            'CLP',
            'چلي پيسو',
        ],
        'CNH' => [
            'CNH',
            'چيني يوآن (غير ملڪي)',
        ],
        'CNY' => [
            'CN¥',
            'چيني يوآن',
        ],
        'COP' => [
            'COP',
            'ڪولمبيائي پيسو',
        ],
        'CRC' => [
            'CRC',
            'ڪوسٽا ريڪا ڪولن',
        ],
        'CUC' => [
            'CUC',
            'ڪيوبن ڪنورٽيبل پيسو',
        ],
        'CUP' => [
            'CUP',
            'ڪيوبن پيسو',
        ],
        'CVE' => [
            'CVE',
            'ڪيپ وردي ايسڪوڊو',
        ],
        'CZK' => [
            'CZK',
            'چيڪ ڪرونا',
        ],
        'DJF' => [
            'DJF',
            'جبوتي فرينڪ',
        ],
        'DKK' => [
            'DKK',
            'دانش ڪرون',
        ],
        'DOP' => [
            'DOP',
            'ڊومينيڪن پيسو',
        ],
        'DZD' => [
            'DZD',
            'الجيريائي دينار',
        ],
        'EGP' => [
            'EGP',
            'مصري پائونڊ',
        ],
        'ERN' => [
            'ERN',
            'ايريٽيريائي ناڪفا',
        ],
        'ETB' => [
            'ETB',
            'ايٿوپيائي بر',
        ],
        'EUR' => [
            '€',
            'يورو',
        ],
        'FJD' => [
            'FJD',
            'فجي ڊالر',
        ],
        'FKP' => [
            'FKP',
            'فاڪلينڊ ٻيٽ پائونڊ',
        ],
        'GBP' => [
            '£',
            'برطانوي پائونڊ',
        ],
        'GEL' => [
            'GEL',
            'جارجيائي لاري',
        ],
        'GHS' => [
            'GHS',
            'گهانين سيدي',
        ],
        'GIP' => [
            'GIP',
            'جبرالٽر پائونڊ',
        ],
        'GMD' => [
            'GMD',
            'گيمبيا دلاسائي',
        ],
        'GNF' => [
            'GNF',
            'گني فرينڪ',
        ],
        'GTQ' => [
            'GTQ',
            'گوئٽي مالا ڪٽزل',
        ],
        'GYD' => [
            'GYD',
            'گيانا ڊالر',
        ],
        'HKD' => [
            'HK$',
            'هانگ ڪانگ ڊالر',
        ],
        'HNL' => [
            'HNL',
            'هونڊوراس ليمپرا',
        ],
        'HRK' => [
            'HRK',
            'ڪروشيائي ڪونا',
        ],
        'HTG' => [
            'HTG',
            'هيٽي گورڊي',
        ],
        'HUF' => [
            'HUF',
            'هنگيرين فورنٽ',
        ],
        'IDR' => [
            'IDR',
            'انڊونيشيائي رپيه',
        ],
        'ILS' => [
            '₪',
            'اسرائيلي نيو شيڪل',
        ],
        'INR' => [
            '₹',
            'انڊين رپي',
        ],
        'IQD' => [
            'IQD',
            'عراقي دينار',
        ],
        'IRR' => [
            'IRR',
            'ايراني ريال',
        ],
        'ISK' => [
            'ISK',
            'آئيس لينڊي ڪرونا',
        ],
        'JMD' => [
            'JMD',
            'جميڪائي ڊالر',
        ],
        'JOD' => [
            'JOD',
            'اردني دينار',
        ],
        'JPY' => [
            'JP¥',
            'جاپاني يين',
        ],
        'KES' => [
            'KES',
            'ڪينيائي سلنگ',
        ],
        'KGS' => [
            'KGS',
            'ڪرغزستاني سوم',
        ],
        'KHR' => [
            'KHR',
            'ڪمبوڊيائي ريال',
        ],
        'KMF' => [
            'KMF',
            'ڪوموريائي فرينڪ',
        ],
        'KPW' => [
            'KPW',
            'اتر ڪوريائي ون',
        ],
        'KRW' => [
            '₩',
            'ڏکڻ ڪوريائي ون',
        ],
        'KWD' => [
            'KWD',
            'ڪويتي دينار',
        ],
        'KYD' => [
            'KYD',
            'ڪيمين ٻيٽ ڊالر',
        ],
        'KZT' => [
            'KZT',
            'قازقستان ٽينگا',
        ],
        'LAK' => [
            'LAK',
            'لائوشيائي ڪپ',
        ],
        'LBP' => [
            'LBP',
            'لبناني پائونڊ',
        ],
        'LKR' => [
            'LKR',
            'سري لنڪن رپي',
        ],
        'LRD' => [
            'LRD',
            'لائبیریائی ڊالر',
        ],
        'LSL' => [
            'LSL',
            'ليسوٿو لوٽي',
        ],
        'LYD' => [
            'LYD',
            'لبيائي دينار',
        ],
        'MAD' => [
            'MAD',
            'موروڪيائي درهم',
        ],
        'MDL' => [
            'MDL',
            'مالديپ ليو',
        ],
        'MGA' => [
            'MGA',
            'ملاگاسي اریاری',
        ],
        'MKD' => [
            'MKD',
            'ميسي ڊوني دينار',
        ],
        'MMK' => [
            'MMK',
            'ميانمار ڪياٽ',
        ],
        'MNT' => [
            'MNT',
            'منگولي تجرڪ',
        ],
        'MOP' => [
            'MOP',
            'ميڪانيز پٽاڪا',
        ],
        'MRO' => [
            'MRO',
            'موريشيائي اوگوئیا (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'موريشيائي اوگوئیا',
        ],
        'MUR' => [
            'MUR',
            'ماريشيائي رپي',
        ],
        'MVR' => [
            'MVR',
            'مالديپ روفيا',
        ],
        'MWK' => [
            'MWK',
            'ملاوي ڪواچا',
        ],
        'MXN' => [
            'MX$',
            'ميڪسيڪو پيسو',
        ],
        'MYR' => [
            'MYR',
            'ملائيشيائي رنگٽ',
        ],
        'MZN' => [
            'MZN',
            'موزمبيق ميٽيڪل',
        ],
        'NAD' => [
            'NAD',
            'نميبائي ڊالر',
        ],
        'NGN' => [
            'NGN',
            'نائجريائي نائرا',
        ],
        'NIO' => [
            'NIO',
            'نڪارا گوا ڪارڊوبا',
        ],
        'NOK' => [
            'NOK',
            'نارويائي ڪرون',
        ],
        'NPR' => [
            'NPR',
            'نيپالي رپي',
        ],
        'NZD' => [
            'NZ$',
            'نيوزي لينڊي ڊالر',
        ],
        'OMR' => [
            'OMR',
            'عماني ريال',
        ],
        'PAB' => [
            'PAB',
            'پاناما پالبوا',
        ],
        'PEN' => [
            'PEN',
            'پيرو سول',
        ],
        'PGK' => [
            'PGK',
            'پاپوا نيو گني ڪنا',
        ],
        'PHP' => [
            'PHP',
            'فلپائني پيسو',
        ],
        'PKR' => [
            'Rs',
            'پاڪستاني رپي',
        ],
        'PLN' => [
            'PLN',
            'پولش زلاٽي',
        ],
        'PYG' => [
            'PYG',
            'پيراگوئي گاراني',
        ],
        'QAR' => [
            'QAR',
            'قطري ريال',
        ],
        'RON' => [
            'RON',
            'رومانیائي لیو',
        ],
        'RSD' => [
            'RSD',
            'سربيا دينار',
        ],
        'RUB' => [
            'RUB',
            'روسي ربل',
        ],
        'RWF' => [
            'RWF',
            'روانڊا فرينڪ',
        ],
        'SAR' => [
            'SAR',
            'سعودي ريال',
        ],
        'SBD' => [
            'SBD',
            'سولومان ٻيٽ ڊالر',
        ],
        'SCR' => [
            'SCR',
            'سشلي رپي',
        ],
        'SDG' => [
            'SDG',
            'سوڊاني پائونڊ',
        ],
        'SEK' => [
            'SEK',
            'سويڊني ڪرونا',
        ],
        'SGD' => [
            'SGD',
            'سنگاپوري ڊالر',
        ],
        'SHP' => [
            'SHP',
            'سينٽ هيلنا پائونڊ',
        ],
        'SLE' => [
            'SLE',
            'سیرا لیونيائي لیون',
        ],
        'SLL' => [
            'SLL',
            'سیرا لیونيائي لیون (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'سومالي شلنگ',
        ],
        'SRD' => [
            'SRD',
            'سرينامي ڊالر',
        ],
        'SSP' => [
            'SSP',
            'ڏکڻ سوڊاني پائونڊ',
        ],
        'STD' => [
            'STD',
            'سائو ٽوم ۽ پرنسپي دوبرا (1977–2017)',
        ],
        'STN' => [
            'STN',
            'سائو ٽوم ۽ پرنسپي دوبرا',
        ],
        'SYP' => [
            'SYP',
            'شامي پائونڊ',
        ],
        'SZL' => [
            'SZL',
            'سوازي للانگيني',
        ],
        'THB' => [
            'THB',
            'ٿائي باهت',
        ],
        'TJS' => [
            'TJS',
            'تاجڪستاني سوموني',
        ],
        'TMT' => [
            'TMT',
            'ترڪمانستان منت',
        ],
        'TND' => [
            'TND',
            'تیونس دینار',
        ],
        'TOP' => [
            'TOP',
            'تونگن پانگا',
        ],
        'TRY' => [
            'TRY',
            'ترڪي لرا',
        ],
        'TTD' => [
            'TTD',
            'ٽرينڊيڊ ۽ ٽوباگو ڊالر',
        ],
        'TWD' => [
            'NT$',
            'نيو تائيوان ڊالر',
        ],
        'TZS' => [
            'TZS',
            'تنزانيائي شلنگ',
        ],
        'UAH' => [
            'UAH',
            'یوڪرائن هریونیا',
        ],
        'UGX' => [
            'UGX',
            'يگانڊا شلنگ',
        ],
        'USD' => [
            'US$',
            'آمريڪي ڊالر',
        ],
        'UYU' => [
            'UYU',
            'يوروگوئي پيسو',
        ],
        'UZS' => [
            'UZS',
            'ازبڪستاني سوم',
        ],
        'VEF' => [
            'VEF',
            'Venezuelan Bolívar (2008–2018)',
        ],
        'VES' => [
            'VES',
            'وینزویلا بولیور',
        ],
        'VND' => [
            '₫',
            'ويٽنامي ڊونگ',
        ],
        'VUV' => [
            'VUV',
            'وانواتو واتو',
        ],
        'WST' => [
            'WST',
            'ساموآن ٽالا',
        ],
        'XAF' => [
            'FCFA',
            'وچ آفريڪا فرينڪ',
        ],
        'XCD' => [
            'EC$',
            'اوڀر ڪيريبين ڊالر',
        ],
        'XCG' => [
            'Cg.',
            'ڪريبيئن گلڊر',
        ],
        'XOF' => [
            'F CFA',
            'اولهه آفريڪا فرينڪ',
        ],
        'XPF' => [
            'CFPF',
            'CFP فرينڪ',
        ],
        'YER' => [
            'YER',
            'يمني ريال',
        ],
        'ZAR' => [
            'ZAR',
            'ڏکڻ آفريقي رانڊ',
        ],
        'ZMW' => [
            'ZMW',
            'زمبائي ڪواچا',
        ],
        'ZWG' => [
            'ZWG',
            'زمبابوي سون',
        ],
    ],
];
