<?php

return [
    'Names' => [
        'BMD' => [
            'BMD',
            'Bermudian Dollar',
        ],
        'BYB' => [
            'BYB',
            'Belarusian New Rouble (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'Belarusian Rouble',
        ],
        'BYR' => [
            'BYR',
            'Belarusian Rouble (2000–2016)',
        ],
        'JPY' => [
            'JP¥',
            'Japanese Yen',
        ],
        'LVR' => [
            'LVR',
            'Latvian Rouble',
        ],
        'RUB' => [
            'RUB',
            'Russian Rouble',
        ],
        'RUR' => [
            'RUR',
            'Russian Rouble (1991–1998)',
        ],
        'SHP' => [
            'SHP',
            'St Helena Pound',
        ],
        'TJR' => [
            'TJR',
            'Tajikistani Rouble',
        ],
        'USD' => [
            'US$',
            'US Dollar',
        ],
    ],
];
