<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'af_NA' => 'африкаанс (Намиби)',
        'af_ZA' => 'африкаанс (Къилба-Африкин Республика)',
        'ak' => 'акан',
        'ak_GH' => 'акан (Гана)',
        'am' => 'амхаройн',
        'am_ET' => 'амхаройн (Эфиопи)',
        'ar' => 'Ӏаьрбийн',
        'ar_001' => 'Ӏаьрбийн (Дерригдуьненан)',
        'ar_AE' => 'Ӏаьрбийн (Ӏарбийн Цхьанатоьхна Эмираташ)',
        'ar_BH' => 'Ӏаьрбийн (Бахрейн)',
        'ar_DJ' => 'Ӏаьрбийн (Джибути)',
        'ar_DZ' => 'Ӏаьрбийн (Алжир)',
        'ar_EG' => 'Ӏаьрбийн (Мисар)',
        'ar_EH' => 'Ӏаьрбийн (Малхбузен Саьхьара)',
        'ar_ER' => 'Ӏаьрбийн (Эритрей)',
        'ar_IL' => 'Ӏаьрбийн (Израиль)',
        'ar_IQ' => 'Ӏаьрбийн (Ӏиракъ)',
        'ar_JO' => 'Ӏаьрбийн (Урдан)',
        'ar_KM' => 'Ӏаьрбийн (Комораш)',
        'ar_KW' => 'Ӏаьрбийн (Кувейт)',
        'ar_LB' => 'Ӏаьрбийн (Ливан)',
        'ar_LY' => 'Ӏаьрбийн (Ливи)',
        'ar_MA' => 'Ӏаьрбийн (Марокко)',
        'ar_MR' => 'Ӏаьрбийн (Мавритани)',
        'ar_OM' => 'Ӏаьрбийн (Ӏоман)',
        'ar_PS' => 'Ӏаьрбийн (ПалестӀинан латтанаш)',
        'ar_QA' => 'Ӏаьрбийн (Катар)',
        'ar_SA' => 'Ӏаьрбийн (СаӀудийн Ӏаьрбийчоь)',
        'ar_SD' => 'Ӏаьрбийн (Судан)',
        'ar_SO' => 'Ӏаьрбийн (Сомали)',
        'ar_SS' => 'Ӏаьрбийн (Къилба Судан)',
        'ar_SY' => 'Ӏаьрбийн (Шема)',
        'ar_TD' => 'Ӏаьрбийн (Чад)',
        'ar_TN' => 'Ӏаьрбийн (Тунис)',
        'ar_YE' => 'Ӏаьрбийн (Йемен)',
        'as' => 'ассамийн',
        'as_IN' => 'ассамийн (ХӀинди)',
        'az' => 'азербайджанийн',
        'az_AZ' => 'азербайджанийн (Азербайджан)',
        'az_Cyrl' => 'азербайджанийн (кириллица)',
        'az_Cyrl_AZ' => 'азербайджанийн (кириллица, Азербайджан)',
        'az_Latn' => 'азербайджанийн (латинан)',
        'az_Latn_AZ' => 'азербайджанийн (латинан, Азербайджан)',
        'ba' => 'башкирийн',
        'ba_RU' => 'башкирийн (Росси)',
        'be' => 'белорусийн',
        'be_BY' => 'белорусийн (Белорусси)',
        'bg' => 'болгарийн',
        'bg_BG' => 'болгарийн (Болгари)',
        'bm' => 'бамбара',
        'bm_ML' => 'бамбара (Мали)',
        'bn' => 'бенгалийн',
        'bn_BD' => 'бенгалийн (Бангладеш)',
        'bn_IN' => 'бенгалийн (ХӀинди)',
        'bo' => 'тибетхойн',
        'bo_CN' => 'тибетхойн (Цийчоь)',
        'bo_IN' => 'тибетхойн (ХӀинди)',
        'br' => 'бретонийн',
        'br_FR' => 'бретонийн (Франци)',
        'bs' => 'боснийн',
        'bs_BA' => 'боснийн (Босни а, Герцеговина а)',
        'bs_Cyrl' => 'боснийн (кириллица)',
        'bs_Cyrl_BA' => 'боснийн (кириллица, Босни а, Герцеговина а)',
        'bs_Latn' => 'боснийн (латинан)',
        'bs_Latn_BA' => 'боснийн (латинан, Босни а, Герцеговина а)',
        'ca' => 'каталонийн',
        'ca_AD' => 'каталонийн (Андорра)',
        'ca_ES' => 'каталонийн (Испани)',
        'ca_FR' => 'каталонийн (Франци)',
        'ca_IT' => 'каталонийн (Итали)',
        'ce' => 'нохчийн',
        'ce_RU' => 'нохчийн (Росси)',
        'cs' => 'чехийн',
        'cs_CZ' => 'чехийн (Чехи)',
        'cv' => 'чувашийн',
        'cv_RU' => 'чувашийн (Росси)',
        'cy' => 'валлийн',
        'cy_GB' => 'валлийн (Йоккха Британи)',
        'da' => 'датхойн',
        'da_DK' => 'датхойн (Дани)',
        'da_GL' => 'датхойн (Гренланди)',
        'de' => 'немцойн',
        'de_AT' => 'немцойн (Австри)',
        'de_BE' => 'немцойн (Бельги)',
        'de_CH' => 'немцойн (Швейцари)',
        'de_DE' => 'немцойн (Германи)',
        'de_IT' => 'немцойн (Итали)',
        'de_LI' => 'немцойн (Лихтенштейн)',
        'de_LU' => 'немцойн (Люксембург)',
        'dz' => 'дзонг-кэ',
        'dz_BT' => 'дзонг-кэ (Бутан)',
        'ee' => 'эве',
        'ee_GH' => 'эве (Гана)',
        'ee_TG' => 'эве (Того)',
        'el' => 'грекийн',
        'el_CY' => 'грекийн (Кипр)',
        'el_GR' => 'грекийн (Греци)',
        'en' => 'ингалсан',
        'en_001' => 'ингалсан (Дерригдуьненан)',
        'en_150' => 'ингалсан (Европа)',
        'en_AE' => 'ингалсан (Ӏарбийн Цхьанатоьхна Эмираташ)',
        'en_AG' => 'ингалсан (Антигуа а, Барбуда а)',
        'en_AI' => 'ингалсан (Ангилья)',
        'en_AS' => 'ингалсан (Американ Самоа)',
        'en_AT' => 'ингалсан (Австри)',
        'en_AU' => 'ингалсан (Австрали)',
        'en_BB' => 'ингалсан (Барбадос)',
        'en_BE' => 'ингалсан (Бельги)',
        'en_BI' => 'ингалсан (Бурунди)',
        'en_BM' => 'ингалсан (Бермудан гӀайренаш)',
        'en_BS' => 'ингалсан (Багаман гӀайренаш)',
        'en_BW' => 'ингалсан (Ботсвана)',
        'en_BZ' => 'ингалсан (Белиз)',
        'en_CA' => 'ингалсан (Канада)',
        'en_CC' => 'ингалсан (Кокосийн гӀайренаш)',
        'en_CH' => 'ингалсан (Швейцари)',
        'en_CK' => 'ингалсан (Кукан гӀайренаш)',
        'en_CM' => 'ингалсан (Камерун)',
        'en_CX' => 'ингалсан (ГӀайре ӏиса пайхӏамар вина де)',
        'en_CY' => 'ингалсан (Кипр)',
        'en_CZ' => 'ингалсан (Чехи)',
        'en_DE' => 'ингалсан (Германи)',
        'en_DK' => 'ингалсан (Дани)',
        'en_DM' => 'ингалсан (Доминика)',
        'en_EE' => 'ингалсан (Эстони)',
        'en_ER' => 'ингалсан (Эритрей)',
        'en_ES' => 'ингалсан (Испани)',
        'en_FI' => 'ингалсан (Финлянди)',
        'en_FJ' => 'ингалсан (Фиджи)',
        'en_FK' => 'ингалсан (Фолклендан гӀайренаш)',
        'en_FM' => 'ингалсан (Микронезин Федеративни штаташ)',
        'en_FR' => 'ингалсан (Франци)',
        'en_GB' => 'ингалсан (Йоккха Британи)',
        'en_GD' => 'ингалсан (Гренада)',
        'en_GE' => 'ингалсан (Гуьржийчоь)',
        'en_GG' => 'ингалсан (Гернси)',
        'en_GH' => 'ингалсан (Гана)',
        'en_GI' => 'ингалсан (Гибралтар)',
        'en_GM' => 'ингалсан (Гамби)',
        'en_GS' => 'ингалсан (Къилба Джорджи а, Къилба Гавайн гӀайренаш а)',
        'en_GU' => 'ингалсан (Гуам)',
        'en_GY' => 'ингалсан (Гайана)',
        'en_HK' => 'ингалсан (Гонконг [ша-къаьстина кӀошт])',
        'en_HU' => 'ингалсан (Венгри)',
        'en_ID' => 'ингалсан (Индонези)',
        'en_IE' => 'ингалсан (Ирланди)',
        'en_IL' => 'ингалсан (Израиль)',
        'en_IM' => 'ингалсан (Мэн гӀайре)',
        'en_IN' => 'ингалсан (ХӀинди)',
        'en_IT' => 'ингалсан (Итали)',
        'en_JE' => 'ингалсан (Джерси)',
        'en_JM' => 'ингалсан (Ямайка)',
        'en_JP' => 'ингалсан (Япони)',
        'en_KE' => 'ингалсан (Кени)',
        'en_KI' => 'ингалсан (Кирибати)',
        'en_KN' => 'ингалсан (Сент-Китс а, Невис а)',
        'en_KY' => 'ингалсан (Кайман гӀайренаш)',
        'en_LC' => 'ингалсан (Сент-Люси)',
        'en_LR' => 'ингалсан (Либери)',
        'en_LS' => 'ингалсан (Лесото)',
        'en_LT' => 'ингалсан (Литва)',
        'en_LV' => 'ингалсан (Латви)',
        'en_MG' => 'ингалсан (Мадагаскар)',
        'en_MH' => 'ингалсан (Маршаллан гӀайренаш)',
        'en_MO' => 'ингалсан (Макао [ша-къаьстина кӀошт])',
        'en_MP' => 'ингалсан (Къилбаседа Марианан гӀайренаш)',
        'en_MS' => 'ингалсан (Монтсеррат)',
        'en_MT' => 'ингалсан (Мальта)',
        'en_MU' => 'ингалсан (Маврики)',
        'en_MV' => 'ингалсан (Мальдиваш)',
        'en_MW' => 'ингалсан (Малави)',
        'en_MY' => 'ингалсан (Малайзи)',
        'en_NA' => 'ингалсан (Намиби)',
        'en_NF' => 'ингалсан (Норфолк гӀайре)',
        'en_NG' => 'ингалсан (Нигери)',
        'en_NL' => 'ингалсан (Нидерландаш)',
        'en_NO' => 'ингалсан (Норвеги)',
        'en_NR' => 'ингалсан (Науру)',
        'en_NU' => 'ингалсан (Ниуэ)',
        'en_NZ' => 'ингалсан (Керла Зеланди)',
        'en_PG' => 'ингалсан (Папуа — Керла Гвиней)',
        'en_PH' => 'ингалсан (Филиппинаш)',
        'en_PK' => 'ингалсан (Пакистан)',
        'en_PL' => 'ингалсан (Польша)',
        'en_PN' => 'ингалсан (Питкэрн гӀайренаш)',
        'en_PR' => 'ингалсан (Пуэрто-Рико)',
        'en_PT' => 'ингалсан (Португали)',
        'en_PW' => 'ингалсан (Палау)',
        'en_RO' => 'ингалсан (Румыни)',
        'en_RW' => 'ингалсан (Руанда)',
        'en_SB' => 'ингалсан (Соломонан гӀайренаш)',
        'en_SC' => 'ингалсан (Сейшелан гӀайренаш)',
        'en_SD' => 'ингалсан (Судан)',
        'en_SE' => 'ингалсан (Швеци)',
        'en_SG' => 'ингалсан (Сингапур)',
        'en_SH' => 'ингалсан (Сийлахьчу Еленин гӀайре)',
        'en_SI' => 'ингалсан (Словени)',
        'en_SK' => 'ингалсан (Словаки)',
        'en_SL' => 'ингалсан (Сьерра- Леоне)',
        'en_SS' => 'ингалсан (Къилба Судан)',
        'en_SX' => 'ингалсан (Синт-Мартен)',
        'en_SZ' => 'ингалсан (Свазиленд)',
        'en_TC' => 'ингалсан (Тёркс а, Кайкос а гӀайренаш)',
        'en_TK' => 'ингалсан (Токелау)',
        'en_TO' => 'ингалсан (Тонга)',
        'en_TT' => 'ингалсан (Тринидад а, Тобаго а)',
        'en_TV' => 'ингалсан (Тувалу)',
        'en_TZ' => 'ингалсан (Танзани)',
        'en_UA' => 'ингалсан (Украина)',
        'en_UG' => 'ингалсан (Уганда)',
        'en_UM' => 'ингалсан (АЦШн арахьара кегийн гӀайренаш)',
        'en_US' => 'ингалсан (Цхьанатоьхна Штаташ)',
        'en_VC' => 'ингалсан (Сент-Винсент а, Гренадинаш а)',
        'en_VG' => 'ингалсан (Виргинийн гӀайренаш [Британи])',
        'en_VI' => 'ингалсан (Виргинийн гӀайренаш [АЦШ])',
        'en_VU' => 'ингалсан (Вануату)',
        'en_WS' => 'ингалсан (Самоа)',
        'en_ZA' => 'ингалсан (Къилба-Африкин Республика)',
        'en_ZM' => 'ингалсан (Замби)',
        'en_ZW' => 'ингалсан (Зимбабве)',
        'eo' => 'эсперанто',
        'eo_001' => 'эсперанто (Дерригдуьненан)',
        'es' => 'испанхойн',
        'es_419' => 'испанхойн (Латинан Америка)',
        'es_AR' => 'испанхойн (Аргентина)',
        'es_BO' => 'испанхойн (Боливи)',
        'es_BR' => 'испанхойн (Бразили)',
        'es_BZ' => 'испанхойн (Белиз)',
        'es_CL' => 'испанхойн (Чили)',
        'es_CO' => 'испанхойн (Колумби)',
        'es_CR' => 'испанхойн (Коста-Рика)',
        'es_CU' => 'испанхойн (Куба)',
        'es_DO' => 'испанхойн (Доминикан Республика)',
        'es_EC' => 'испанхойн (Эквадор)',
        'es_ES' => 'испанхойн (Испани)',
        'es_GQ' => 'испанхойн (Экваторан Гвиней)',
        'es_GT' => 'испанхойн (Гватемала)',
        'es_HN' => 'испанхойн (Гондурас)',
        'es_MX' => 'испанхойн (Мексика)',
        'es_NI' => 'испанхойн (Никарагуа)',
        'es_PA' => 'испанхойн (Панама)',
        'es_PE' => 'испанхойн (Перу)',
        'es_PH' => 'испанхойн (Филиппинаш)',
        'es_PR' => 'испанхойн (Пуэрто-Рико)',
        'es_PY' => 'испанхойн (Парагвай)',
        'es_SV' => 'испанхойн (Сальвадор)',
        'es_US' => 'испанхойн (Цхьанатоьхна Штаташ)',
        'es_UY' => 'испанхойн (Уругвай)',
        'es_VE' => 'испанхойн (Венесуэла)',
        'et' => 'эстонийн',
        'et_EE' => 'эстонийн (Эстони)',
        'eu' => 'баскийн',
        'eu_ES' => 'баскийн (Испани)',
        'fa' => 'гӀажарийн',
        'fa_AF' => 'гӀажарийн (ОвхӀан мохк)',
        'fa_IR' => 'гӀажарийн (ГӀажарийчоь)',
        'ff' => 'фулах',
        'ff_CM' => 'фулах (Камерун)',
        'ff_GN' => 'фулах (Гвиней)',
        'ff_Latn' => 'фулах (латинан)',
        'ff_Latn_BF' => 'фулах (латинан, Буркина- Фасо)',
        'ff_Latn_CM' => 'фулах (латинан, Камерун)',
        'ff_Latn_GH' => 'фулах (латинан, Гана)',
        'ff_Latn_GM' => 'фулах (латинан, Гамби)',
        'ff_Latn_GN' => 'фулах (латинан, Гвиней)',
        'ff_Latn_GW' => 'фулах (латинан, Гвиней-Бисау)',
        'ff_Latn_LR' => 'фулах (латинан, Либери)',
        'ff_Latn_MR' => 'фулах (латинан, Мавритани)',
        'ff_Latn_NE' => 'фулах (латинан, Нигер)',
        'ff_Latn_NG' => 'фулах (латинан, Нигери)',
        'ff_Latn_SL' => 'фулах (латинан, Сьерра- Леоне)',
        'ff_Latn_SN' => 'фулах (латинан, Сенегал)',
        'ff_MR' => 'фулах (Мавритани)',
        'ff_SN' => 'фулах (Сенегал)',
        'fi' => 'финнийн',
        'fi_FI' => 'финнийн (Финлянди)',
        'fo' => 'фарерийн',
        'fo_DK' => 'фарерийн (Дани)',
        'fo_FO' => 'фарерийн (Фарерийн гӀайренаш)',
        'fr' => 'французийн',
        'fr_BE' => 'французийн (Бельги)',
        'fr_BF' => 'французийн (Буркина- Фасо)',
        'fr_BI' => 'французийн (Бурунди)',
        'fr_BJ' => 'французийн (Бенин)',
        'fr_BL' => 'французийн (Сен-Бартельми)',
        'fr_CA' => 'французийн (Канада)',
        'fr_CD' => 'французийн (Демократин Республика Конго)',
        'fr_CF' => 'французийн (Юккъерчу Африкин Республика)',
        'fr_CG' => 'французийн (Конго - Браззавиль)',
        'fr_CH' => 'французийн (Швейцари)',
        'fr_CI' => 'французийн (Кот-Д’ивуар)',
        'fr_CM' => 'французийн (Камерун)',
        'fr_DJ' => 'французийн (Джибути)',
        'fr_DZ' => 'французийн (Алжир)',
        'fr_FR' => 'французийн (Франци)',
        'fr_GA' => 'французийн (Габон)',
        'fr_GF' => 'французийн (Французийн Гвиана)',
        'fr_GN' => 'французийн (Гвиней)',
        'fr_GP' => 'французийн (Гваделупа)',
        'fr_GQ' => 'французийн (Экваторан Гвиней)',
        'fr_HT' => 'французийн (Гаити)',
        'fr_KM' => 'французийн (Комораш)',
        'fr_LU' => 'французийн (Люксембург)',
        'fr_MA' => 'французийн (Марокко)',
        'fr_MC' => 'французийн (Монако)',
        'fr_MF' => 'французийн (Сен-Мартен)',
        'fr_MG' => 'французийн (Мадагаскар)',
        'fr_ML' => 'французийн (Мали)',
        'fr_MQ' => 'французийн (Мартиника)',
        'fr_MR' => 'французийн (Мавритани)',
        'fr_MU' => 'французийн (Маврики)',
        'fr_NC' => 'французийн (Керла Каледони)',
        'fr_NE' => 'французийн (Нигер)',
        'fr_PF' => 'французийн (Французийн Полинези)',
        'fr_PM' => 'французийн (Сен-Пьер а, Микелон а)',
        'fr_RE' => 'французийн (Реюньон)',
        'fr_RW' => 'французийн (Руанда)',
        'fr_SC' => 'французийн (Сейшелан гӀайренаш)',
        'fr_SN' => 'французийн (Сенегал)',
        'fr_SY' => 'французийн (Шема)',
        'fr_TD' => 'французийн (Чад)',
        'fr_TG' => 'французийн (Того)',
        'fr_TN' => 'французийн (Тунис)',
        'fr_VU' => 'французийн (Вануату)',
        'fr_WF' => 'французийн (Уоллис а, Футуна а)',
        'fr_YT' => 'французийн (Майотта)',
        'fy' => 'малхбузен-фризийн',
        'fy_NL' => 'малхбузен-фризийн (Нидерландаш)',
        'ga' => 'ирландхойн',
        'ga_GB' => 'ирландхойн (Йоккха Британи)',
        'ga_IE' => 'ирландхойн (Ирланди)',
        'gd' => 'гэлийн',
        'gd_GB' => 'гэлийн (Йоккха Британи)',
        'gl' => 'галисийн',
        'gl_ES' => 'галисийн (Испани)',
        'gu' => 'гуджарати',
        'gu_IN' => 'гуджарати (ХӀинди)',
        'gv' => 'мэнийн',
        'gv_IM' => 'мэнийн (Мэн гӀайре)',
        'ha' => 'хауса',
        'ha_GH' => 'хауса (Гана)',
        'ha_NE' => 'хауса (Нигер)',
        'ha_NG' => 'хауса (Нигери)',
        'he' => 'жугтийн',
        'he_IL' => 'жугтийн (Израиль)',
        'hi' => 'хӀинди',
        'hi_IN' => 'хӀинди (ХӀинди)',
        'hi_Latn' => 'хӀинди (латинан)',
        'hi_Latn_IN' => 'хӀинди (латинан, ХӀинди)',
        'hr' => 'хорватийн',
        'hr_BA' => 'хорватийн (Босни а, Герцеговина а)',
        'hr_HR' => 'хорватийн (Хорвати)',
        'hu' => 'венгрийн',
        'hu_HU' => 'венгрийн (Венгри)',
        'hy' => 'эрмалойн',
        'hy_AM' => 'эрмалойн (Эрмалойчоь)',
        'ia' => 'интерлингва',
        'ia_001' => 'интерлингва (Дерригдуьненан)',
        'id' => 'индонезихойн',
        'id_ID' => 'индонезихойн (Индонези)',
        'ig' => 'игбо',
        'ig_NG' => 'игбо (Нигери)',
        'ii' => 'сычуань',
        'ii_CN' => 'сычуань (Цийчоь)',
        'is' => 'исландхойн',
        'is_IS' => 'исландхойн (Исланди)',
        'it' => 'итальянийн',
        'it_CH' => 'итальянийн (Швейцари)',
        'it_IT' => 'итальянийн (Итали)',
        'it_SM' => 'итальянийн (Сан-Марино)',
        'it_VA' => 'итальянийн (Ватикан)',
        'ja' => 'японийн',
        'ja_JP' => 'японийн (Япони)',
        'jv' => 'яванийн',
        'jv_ID' => 'яванийн (Индонези)',
        'ka' => 'гуьржийн',
        'ka_GE' => 'гуьржийн (Гуьржийчоь)',
        'ki' => 'кикуйю',
        'ki_KE' => 'кикуйю (Кени)',
        'kk' => 'кхазакхийн',
        'kk_Arab' => 'кхазакхийн (Ӏаьрбийн)',
        'kk_Arab_CN' => 'кхазакхийн (Ӏаьрбийн, Цийчоь)',
        'kk_Cyrl' => 'кхазакхийн (кириллица)',
        'kk_Cyrl_KZ' => 'кхазакхийн (кириллица, Кхазакхстан)',
        'kk_KZ' => 'кхазакхийн (Кхазакхстан)',
        'kl' => 'гренландхойн',
        'kl_GL' => 'гренландхойн (Гренланди)',
        'km' => 'кхмерийн',
        'km_KH' => 'кхмерийн (Камбоджа)',
        'kn' => 'каннада',
        'kn_IN' => 'каннада (ХӀинди)',
        'ko' => 'корейн',
        'ko_CN' => 'корейн (Цийчоь)',
        'ko_KP' => 'корейн (Къилбаседа Корей)',
        'ko_KR' => 'корейн (Къилба Корей)',
        'ks' => 'кашмири',
        'ks_Arab' => 'кашмири (Ӏаьрбийн)',
        'ks_Arab_IN' => 'кашмири (Ӏаьрбийн, ХӀинди)',
        'ks_Deva' => 'кашмири (деванагари)',
        'ks_Deva_IN' => 'кашмири (деванагари, ХӀинди)',
        'ks_IN' => 'кашмири (ХӀинди)',
        'ku' => 'курдийн',
        'ku_Latn' => 'курдийн (латинан)',
        'ku_Latn_IQ' => 'курдийн (латинан, Ӏиракъ)',
        'ku_Latn_SY' => 'курдийн (латинан, Шема)',
        'ku_Latn_TR' => 'курдийн (латинан, Туркойчоь)',
        'ku_SY' => 'курдийн (Шема)',
        'ku_TR' => 'курдийн (Туркойчоь)',
        'kw' => 'корнуоллийн',
        'kw_GB' => 'корнуоллийн (Йоккха Британи)',
        'ky' => 'гӀиргӀизойн',
        'ky_KG' => 'гӀиргӀизойн (Киргизи)',
        'lb' => 'люксембургхойн',
        'lb_LU' => 'люксембургхойн (Люксембург)',
        'lg' => 'ганда',
        'lg_UG' => 'ганда (Уганда)',
        'ln' => 'лингала',
        'ln_AO' => 'лингала (Ангола)',
        'ln_CD' => 'лингала (Демократин Республика Конго)',
        'ln_CF' => 'лингала (Юккъерчу Африкин Республика)',
        'ln_CG' => 'лингала (Конго - Браззавиль)',
        'lo' => 'лаоссийн',
        'lo_LA' => 'лаоссийн (Лаос)',
        'lt' => 'литвахойн',
        'lt_LT' => 'литвахойн (Литва)',
        'lu' => 'луба-катанга',
        'lu_CD' => 'луба-катанга (Демократин Республика Конго)',
        'lv' => 'латышийн',
        'lv_LV' => 'латышийн (Латви)',
        'mg' => 'малагасийн',
        'mg_MG' => 'малагасийн (Мадагаскар)',
        'mi' => 'маори',
        'mi_NZ' => 'маори (Керла Зеланди)',
        'mk' => 'македонхойн',
        'ml' => 'малаялам',
        'ml_IN' => 'малаялам (ХӀинди)',
        'mn' => 'монголийн',
        'mn_MN' => 'монголийн (Монголи)',
        'mr' => 'маратхи',
        'mr_IN' => 'маратхи (ХӀинди)',
        'ms' => 'малайн',
        'ms_BN' => 'малайн (Бруней-Даруссалам)',
        'ms_ID' => 'малайн (Индонези)',
        'ms_MY' => 'малайн (Малайзи)',
        'ms_SG' => 'малайн (Сингапур)',
        'mt' => 'мальтойн',
        'mt_MT' => 'мальтойн (Мальта)',
        'my' => 'бирманийн',
        'my_MM' => 'бирманийн (Мьянма [Бирма])',
        'nb' => 'норвегийн букмол',
        'nb_NO' => 'норвегийн букмол (Норвеги)',
        'nb_SJ' => 'норвегийн букмол (Шпицберген а, Ян-Майен а)',
        'nd' => 'къилбаседа ндебели',
        'nd_ZW' => 'къилбаседа ндебели (Зимбабве)',
        'ne' => 'непалхойн',
        'ne_IN' => 'непалхойн (ХӀинди)',
        'ne_NP' => 'непалхойн (Непал)',
        'nl' => 'голландхойн',
        'nl_AW' => 'голландхойн (Аруба)',
        'nl_BE' => 'голландхойн (Бельги)',
        'nl_BQ' => 'голландхойн (Бонэйр, Синт-Эстатиус а, Саба а)',
        'nl_CW' => 'голландхойн (Кюрасао)',
        'nl_NL' => 'голландхойн (Нидерландаш)',
        'nl_SR' => 'голландхойн (Суринам)',
        'nl_SX' => 'голландхойн (Синт-Мартен)',
        'nn' => 'норвегийн нюнорск',
        'nn_NO' => 'норвегийн нюнорск (Норвеги)',
        'oc' => 'окситанойн',
        'oc_ES' => 'окситанойн (Испани)',
        'oc_FR' => 'окситанойн (Франци)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Эфиопи)',
        'om_KE' => 'оромо (Кени)',
        'or' => 'ори',
        'or_IN' => 'ори (ХӀинди)',
        'os' => 'хӀирийн',
        'os_GE' => 'хӀирийн (Гуьржийчоь)',
        'os_RU' => 'хӀирийн (Росси)',
        'pa' => 'панджаби',
        'pa_Arab' => 'панджаби (Ӏаьрбийн)',
        'pa_Arab_PK' => 'панджаби (Ӏаьрбийн, Пакистан)',
        'pa_Guru' => 'панджаби (гурмукхи)',
        'pa_Guru_IN' => 'панджаби (гурмукхи, ХӀинди)',
        'pa_IN' => 'панджаби (ХӀинди)',
        'pa_PK' => 'панджаби (Пакистан)',
        'pl' => 'полякийн',
        'pl_PL' => 'полякийн (Польша)',
        'ps' => 'пушту',
        'ps_AF' => 'пушту (ОвхӀан мохк)',
        'ps_PK' => 'пушту (Пакистан)',
        'pt' => 'португалихойн',
        'pt_AO' => 'португалихойн (Ангола)',
        'pt_BR' => 'португалихойн (Бразили)',
        'pt_CH' => 'португалихойн (Швейцари)',
        'pt_CV' => 'португалихойн (Кабо-Верде)',
        'pt_GQ' => 'португалихойн (Экваторан Гвиней)',
        'pt_GW' => 'португалихойн (Гвиней-Бисау)',
        'pt_LU' => 'португалихойн (Люксембург)',
        'pt_MO' => 'португалихойн (Макао [ша-къаьстина кӀошт])',
        'pt_MZ' => 'португалихойн (Мозамбик)',
        'pt_PT' => 'португалихойн (Португали)',
        'pt_ST' => 'португалихойн (Сан-Томе а, Принсипи а)',
        'pt_TL' => 'португалихойн (Малхбален Тимор)',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Боливи)',
        'qu_EC' => 'кечуа (Эквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'романшийн',
        'rm_CH' => 'романшийн (Швейцари)',
        'rn' => 'рунди',
        'rn_BI' => 'рунди (Бурунди)',
        'ro' => 'румынийн',
        'ro_MD' => 'румынийн (Молдави)',
        'ro_RO' => 'румынийн (Румыни)',
        'ru' => 'оьрсийн',
        'ru_BY' => 'оьрсийн (Белорусси)',
        'ru_KG' => 'оьрсийн (Киргизи)',
        'ru_KZ' => 'оьрсийн (Кхазакхстан)',
        'ru_MD' => 'оьрсийн (Молдави)',
        'ru_RU' => 'оьрсийн (Росси)',
        'ru_UA' => 'оьрсийн (Украина)',
        'rw' => 'киньяруанда',
        'rw_RW' => 'киньяруанда (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (ХӀинди)',
        'sc' => 'сардинийн',
        'sc_IT' => 'сардинийн (Итали)',
        'sd' => 'синдхи',
        'sd_Arab' => 'синдхи (Ӏаьрбийн)',
        'sd_Arab_PK' => 'синдхи (Ӏаьрбийн, Пакистан)',
        'sd_Deva' => 'синдхи (деванагари)',
        'sd_Deva_IN' => 'синдхи (деванагари, ХӀинди)',
        'sd_IN' => 'синдхи (ХӀинди)',
        'sd_PK' => 'синдхи (Пакистан)',
        'se' => 'къилбаседа саамийн',
        'se_FI' => 'къилбаседа саамийн (Финлянди)',
        'se_NO' => 'къилбаседа саамийн (Норвеги)',
        'se_SE' => 'къилбаседа саамийн (Швеци)',
        'sg' => 'санго',
        'sg_CF' => 'санго (Юккъерчу Африкин Республика)',
        'si' => 'сингалхойн',
        'si_LK' => 'сингалхойн (Шри-Ланка)',
        'sk' => 'словакийн',
        'sk_SK' => 'словакийн (Словаки)',
        'sl' => 'словенийн',
        'sl_SI' => 'словенийн (Словени)',
        'sn' => 'шона',
        'sn_ZW' => 'шона (Зимбабве)',
        'so' => 'сомали',
        'so_DJ' => 'сомали (Джибути)',
        'so_ET' => 'сомали (Эфиопи)',
        'so_KE' => 'сомали (Кени)',
        'so_SO' => 'сомали (Сомали)',
        'sq' => 'албанойн',
        'sq_AL' => 'албанойн (Албани)',
        'sr' => 'сербийн',
        'sr_BA' => 'сербийн (Босни а, Герцеговина а)',
        'sr_Cyrl' => 'сербийн (кириллица)',
        'sr_Cyrl_BA' => 'сербийн (кириллица, Босни а, Герцеговина а)',
        'sr_Cyrl_ME' => 'сербийн (кириллица, Ӏаьржаламанчоь)',
        'sr_Cyrl_RS' => 'сербийн (кириллица, Серби)',
        'sr_Latn' => 'сербийн (латинан)',
        'sr_Latn_BA' => 'сербийн (латинан, Босни а, Герцеговина а)',
        'sr_Latn_ME' => 'сербийн (латинан, Ӏаьржаламанчоь)',
        'sr_Latn_RS' => 'сербийн (латинан, Серби)',
        'sr_ME' => 'сербийн (Ӏаьржаламанчоь)',
        'sr_RS' => 'сербийн (Серби)',
        'st' => 'къилба сото',
        'st_LS' => 'къилба сото (Лесото)',
        'st_ZA' => 'къилба сото (Къилба-Африкин Республика)',
        'su' => 'сунданхойн',
        'su_ID' => 'сунданхойн (Индонези)',
        'su_Latn' => 'сунданхойн (латинан)',
        'su_Latn_ID' => 'сунданхойн (латинан, Индонези)',
        'sv' => 'шведийн',
        'sv_AX' => 'шведийн (Аландан гӀайренаш)',
        'sv_FI' => 'шведийн (Финлянди)',
        'sv_SE' => 'шведийн (Швеци)',
        'sw' => 'суахили',
        'sw_CD' => 'суахили (Демократин Республика Конго)',
        'sw_KE' => 'суахили (Кени)',
        'sw_TZ' => 'суахили (Танзани)',
        'sw_UG' => 'суахили (Уганда)',
        'ta' => 'тамилхойн',
        'ta_IN' => 'тамилхойн (ХӀинди)',
        'ta_LK' => 'тамилхойн (Шри-Ланка)',
        'ta_MY' => 'тамилхойн (Малайзи)',
        'ta_SG' => 'тамилхойн (Сингапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (ХӀинди)',
        'tg' => 'таджикийн',
        'tg_TJ' => 'таджикийн (Таджикистан)',
        'th' => 'тайн',
        'th_TH' => 'тайн (Таиланд)',
        'ti' => 'тигринья',
        'ti_ER' => 'тигринья (Эритрей)',
        'ti_ET' => 'тигринья (Эфиопи)',
        'tk' => 'туркменийн',
        'tk_TM' => 'туркменийн (Туркмени)',
        'tn' => 'тсвана',
        'tn_BW' => 'тсвана (Ботсвана)',
        'tn_ZA' => 'тсвана (Къилба-Африкин Республика)',
        'to' => 'тонганийн',
        'to_TO' => 'тонганийн (Тонга)',
        'tr' => 'туркойн',
        'tr_CY' => 'туркойн (Кипр)',
        'tr_TR' => 'туркойн (Туркойчоь)',
        'tt' => 'гӀезалойн',
        'tt_RU' => 'гӀезалойн (Росси)',
        'ug' => 'уйгурийн',
        'ug_CN' => 'уйгурийн (Цийчоь)',
        'uk' => 'украинийн',
        'uk_UA' => 'украинийн (Украина)',
        'ur' => 'урду',
        'ur_IN' => 'урду (ХӀинди)',
        'ur_PK' => 'урду (Пакистан)',
        'uz' => 'узбекийн',
        'uz_AF' => 'узбекийн (ОвхӀан мохк)',
        'uz_Arab' => 'узбекийн (Ӏаьрбийн)',
        'uz_Arab_AF' => 'узбекийн (Ӏаьрбийн, ОвхӀан мохк)',
        'uz_Cyrl' => 'узбекийн (кириллица)',
        'uz_Cyrl_UZ' => 'узбекийн (кириллица, Узбекистан)',
        'uz_Latn' => 'узбекийн (латинан)',
        'uz_Latn_UZ' => 'узбекийн (латинан, Узбекистан)',
        'uz_UZ' => 'узбекийн (Узбекистан)',
        'vi' => 'вьетнамхойн',
        'vi_VN' => 'вьетнамхойн (Вьетнам)',
        'wo' => 'волоф',
        'wo_SN' => 'волоф (Сенегал)',
        'xh' => 'коса',
        'xh_ZA' => 'коса (Къилба-Африкин Республика)',
        'yi' => 'идиш',
        'yi_UA' => 'идиш (Украина)',
        'yo' => 'йоруба',
        'yo_BJ' => 'йоруба (Бенин)',
        'yo_NG' => 'йоруба (Нигери)',
        'zh' => 'цийн',
        'zh_CN' => 'цийн (Цийчоь)',
        'zh_HK' => 'цийн (Гонконг [ша-къаьстина кӀошт])',
        'zh_Hans' => 'цийн (атта китайн)',
        'zh_Hans_CN' => 'цийн (атта китайн, Цийчоь)',
        'zh_Hans_HK' => 'цийн (атта китайн, Гонконг [ша-къаьстина кӀошт])',
        'zh_Hans_MO' => 'цийн (атта китайн, Макао [ша-къаьстина кӀошт])',
        'zh_Hans_MY' => 'цийн (атта китайн, Малайзи)',
        'zh_Hans_SG' => 'цийн (атта китайн, Сингапур)',
        'zh_Hant' => 'цийн (ламастан китайн)',
        'zh_Hant_HK' => 'цийн (ламастан китайн, Гонконг [ша-къаьстина кӀошт])',
        'zh_Hant_MO' => 'цийн (ламастан китайн, Макао [ша-къаьстина кӀошт])',
        'zh_Hant_MY' => 'цийн (ламастан китайн, Малайзи)',
        'zh_Hant_TW' => 'цийн (ламастан китайн, Тайвань)',
        'zh_MO' => 'цийн (Макао [ша-къаьстина кӀошт])',
        'zh_SG' => 'цийн (Сингапур)',
        'zh_TW' => 'цийн (Тайвань)',
        'zu' => 'зулу',
        'zu_ZA' => 'зулу (Къилба-Африкин Республика)',
    ],
];
