<?php

return [
    'Names' => [
        'af' => 'африканс',
        'af_NA' => 'африканс (Намибия)',
        'af_ZA' => 'африканс (Южна Африка)',
        'ak' => 'акан',
        'ak_GH' => 'акан (Гана)',
        'am' => 'амхарски',
        'am_ET' => 'амхарски (Етиопия)',
        'ar' => 'арабски',
        'ar_001' => 'арабски (свят)',
        'ar_AE' => 'арабски (Обединени арабски емирства)',
        'ar_BH' => 'арабски (Бахрейн)',
        'ar_DJ' => 'арабски (Джибути)',
        'ar_DZ' => 'арабски (Алжир)',
        'ar_EG' => 'арабски (Египет)',
        'ar_EH' => 'арабски (Западна Сахара)',
        'ar_ER' => 'арабски (Еритрея)',
        'ar_IL' => 'арабски (Израел)',
        'ar_IQ' => 'арабски (Ирак)',
        'ar_JO' => 'арабски (Йордания)',
        'ar_KM' => 'арабски (Коморски острови)',
        'ar_KW' => 'арабски (Кувейт)',
        'ar_LB' => 'арабски (Ливан)',
        'ar_LY' => 'арабски (Либия)',
        'ar_MA' => 'арабски (Мароко)',
        'ar_MR' => 'арабски (Мавритания)',
        'ar_OM' => 'арабски (Оман)',
        'ar_PS' => 'арабски (Палестински територии)',
        'ar_QA' => 'арабски (Катар)',
        'ar_SA' => 'арабски (Саудитска Арабия)',
        'ar_SD' => 'арабски (Судан)',
        'ar_SO' => 'арабски (Сомалия)',
        'ar_SS' => 'арабски (Южен Судан)',
        'ar_SY' => 'арабски (Сирия)',
        'ar_TD' => 'арабски (Чад)',
        'ar_TN' => 'арабски (Тунис)',
        'ar_YE' => 'арабски (Йемен)',
        'as' => 'асамски',
        'as_IN' => 'асамски (Индия)',
        'az' => 'азербайджански',
        'az_AZ' => 'азербайджански (Азербайджан)',
        'az_Cyrl' => 'азербайджански (кирилица)',
        'az_Cyrl_AZ' => 'азербайджански (кирилица, Азербайджан)',
        'az_Latn' => 'азербайджански (латиница)',
        'az_Latn_AZ' => 'азербайджански (латиница, Азербайджан)',
        'ba' => 'башкирски',
        'ba_RU' => 'башкирски (Русия)',
        'be' => 'беларуски',
        'be_BY' => 'беларуски (Беларус)',
        'bg' => 'български',
        'bg_BG' => 'български (България)',
        'bm' => 'бамбара',
        'bm_ML' => 'бамбара (Мали)',
        'bn' => 'бенгалски',
        'bn_BD' => 'бенгалски (Бангладеш)',
        'bn_IN' => 'бенгалски (Индия)',
        'bo' => 'тибетски',
        'bo_CN' => 'тибетски (Китай)',
        'bo_IN' => 'тибетски (Индия)',
        'br' => 'бретонски',
        'br_FR' => 'бретонски (Франция)',
        'bs' => 'босненски',
        'bs_BA' => 'босненски (Босна и Херцеговина)',
        'bs_Cyrl' => 'босненски (кирилица)',
        'bs_Cyrl_BA' => 'босненски (кирилица, Босна и Херцеговина)',
        'bs_Latn' => 'босненски (латиница)',
        'bs_Latn_BA' => 'босненски (латиница, Босна и Херцеговина)',
        'ca' => 'каталонски',
        'ca_AD' => 'каталонски (Андора)',
        'ca_ES' => 'каталонски (Испания)',
        'ca_FR' => 'каталонски (Франция)',
        'ca_IT' => 'каталонски (Италия)',
        'ce' => 'чеченски',
        'ce_RU' => 'чеченски (Русия)',
        'cs' => 'чешки',
        'cs_CZ' => 'чешки (Чехия)',
        'cv' => 'чувашки',
        'cv_RU' => 'чувашки (Русия)',
        'cy' => 'уелски',
        'cy_GB' => 'уелски (Обединеното кралство)',
        'da' => 'датски',
        'da_DK' => 'датски (Дания)',
        'da_GL' => 'датски (Гренландия)',
        'de' => 'немски',
        'de_AT' => 'немски (Австрия)',
        'de_BE' => 'немски (Белгия)',
        'de_CH' => 'немски (Швейцария)',
        'de_DE' => 'немски (Германия)',
        'de_IT' => 'немски (Италия)',
        'de_LI' => 'немски (Лихтенщайн)',
        'de_LU' => 'немски (Люксембург)',
        'dz' => 'дзонгкха',
        'dz_BT' => 'дзонгкха (Бутан)',
        'ee' => 'еве',
        'ee_GH' => 'еве (Гана)',
        'ee_TG' => 'еве (Того)',
        'el' => 'гръцки',
        'el_CY' => 'гръцки (Кипър)',
        'el_GR' => 'гръцки (Гърция)',
        'en' => 'английски',
        'en_001' => 'английски (свят)',
        'en_150' => 'английски (Европа)',
        'en_AE' => 'английски (Обединени арабски емирства)',
        'en_AG' => 'английски (Антигуа и Барбуда)',
        'en_AI' => 'английски (Ангуила)',
        'en_AS' => 'английски (Американска Самоа)',
        'en_AT' => 'английски (Австрия)',
        'en_AU' => 'английски (Австралия)',
        'en_BB' => 'английски (Барбадос)',
        'en_BE' => 'английски (Белгия)',
        'en_BI' => 'английски (Бурунди)',
        'en_BM' => 'английски (Бермудски острови)',
        'en_BS' => 'английски (Бахамски острови)',
        'en_BW' => 'английски (Ботсвана)',
        'en_BZ' => 'английски (Белиз)',
        'en_CA' => 'английски (Канада)',
        'en_CC' => 'английски (Кокосови острови [острови Кийлинг])',
        'en_CH' => 'английски (Швейцария)',
        'en_CK' => 'английски (острови Кук)',
        'en_CM' => 'английски (Камерун)',
        'en_CX' => 'английски (остров Рождество)',
        'en_CY' => 'английски (Кипър)',
        'en_CZ' => 'английски (Чехия)',
        'en_DE' => 'английски (Германия)',
        'en_DK' => 'английски (Дания)',
        'en_DM' => 'английски (Доминика)',
        'en_EE' => 'английски (Естония)',
        'en_ER' => 'английски (Еритрея)',
        'en_ES' => 'английски (Испания)',
        'en_FI' => 'английски (Финландия)',
        'en_FJ' => 'английски (Фиджи)',
        'en_FK' => 'английски (Фолкландски острови)',
        'en_FM' => 'английски (Микронезия)',
        'en_FR' => 'английски (Франция)',
        'en_GB' => 'английски (Обединеното кралство)',
        'en_GD' => 'английски (Гренада)',
        'en_GE' => 'английски (Грузия)',
        'en_GG' => 'английски (Гърнзи)',
        'en_GH' => 'английски (Гана)',
        'en_GI' => 'английски (Гибралтар)',
        'en_GM' => 'английски (Гамбия)',
        'en_GS' => 'английски (Южна Джорджия и Южни Сандвичеви острови)',
        'en_GU' => 'английски (Гуам)',
        'en_GY' => 'английски (Гаяна)',
        'en_HK' => 'английски (Хонконг, САР на Китай)',
        'en_HU' => 'английски (Унгария)',
        'en_ID' => 'английски (Индонезия)',
        'en_IE' => 'английски (Ирландия)',
        'en_IL' => 'английски (Израел)',
        'en_IM' => 'английски (остров Ман)',
        'en_IN' => 'английски (Индия)',
        'en_IO' => 'английски (Британска територия в Индийския океан)',
        'en_IT' => 'английски (Италия)',
        'en_JE' => 'английски (Джърси)',
        'en_JM' => 'английски (Ямайка)',
        'en_JP' => 'английски (Япония)',
        'en_KE' => 'английски (Кения)',
        'en_KI' => 'английски (Кирибати)',
        'en_KN' => 'английски (Сейнт Китс и Невис)',
        'en_KY' => 'английски (Кайманови острови)',
        'en_LC' => 'английски (Сейнт Лусия)',
        'en_LR' => 'английски (Либерия)',
        'en_LS' => 'английски (Лесото)',
        'en_LT' => 'английски (Литва)',
        'en_LV' => 'английски (Латвия)',
        'en_MG' => 'английски (Мадагаскар)',
        'en_MH' => 'английски (Маршалови острови)',
        'en_MO' => 'английски (Макао, САР на Китай)',
        'en_MP' => 'английски (Северни Мариански острови)',
        'en_MS' => 'английски (Монтсерат)',
        'en_MT' => 'английски (Малта)',
        'en_MU' => 'английски (Мавриций)',
        'en_MV' => 'английски (Малдиви)',
        'en_MW' => 'английски (Малави)',
        'en_MY' => 'английски (Малайзия)',
        'en_NA' => 'английски (Намибия)',
        'en_NF' => 'английски (остров Норфолк)',
        'en_NG' => 'английски (Нигерия)',
        'en_NL' => 'английски (Нидерландия)',
        'en_NO' => 'английски (Норвегия)',
        'en_NR' => 'английски (Науру)',
        'en_NU' => 'английски (Ниуе)',
        'en_NZ' => 'английски (Нова Зеландия)',
        'en_PG' => 'английски (Папуа-Нова Гвинея)',
        'en_PH' => 'английски (Филипини)',
        'en_PK' => 'английски (Пакистан)',
        'en_PL' => 'английски (Полша)',
        'en_PN' => 'английски (Острови Питкерн)',
        'en_PR' => 'английски (Пуерто Рико)',
        'en_PT' => 'английски (Португалия)',
        'en_PW' => 'английски (Палау)',
        'en_RO' => 'английски (Румъния)',
        'en_RW' => 'английски (Руанда)',
        'en_SB' => 'английски (Соломонови острови)',
        'en_SC' => 'английски (Сейшели)',
        'en_SD' => 'английски (Судан)',
        'en_SE' => 'английски (Швеция)',
        'en_SG' => 'английски (Сингапур)',
        'en_SH' => 'английски (Света Елена)',
        'en_SI' => 'английски (Словения)',
        'en_SK' => 'английски (Словакия)',
        'en_SL' => 'английски (Сиера Леоне)',
        'en_SS' => 'английски (Южен Судан)',
        'en_SX' => 'английски (Синт Мартен)',
        'en_SZ' => 'английски (Есватини)',
        'en_TC' => 'английски (острови Търкс и Кайкос)',
        'en_TK' => 'английски (Токелау)',
        'en_TO' => 'английски (Тонга)',
        'en_TT' => 'английски (Тринидад и Тобаго)',
        'en_TV' => 'английски (Тувалу)',
        'en_TZ' => 'английски (Танзания)',
        'en_UA' => 'английски (Украйна)',
        'en_UG' => 'английски (Уганда)',
        'en_UM' => 'английски (Отдалечени острови на САЩ)',
        'en_US' => 'английски (Съединени щати)',
        'en_VC' => 'английски (Сейнт Винсънт и Гренадини)',
        'en_VG' => 'английски (Британски Вирджински острови)',
        'en_VI' => 'английски (Американски Вирджински острови)',
        'en_VU' => 'английски (Вануату)',
        'en_WS' => 'английски (Самоа)',
        'en_ZA' => 'английски (Южна Африка)',
        'en_ZM' => 'английски (Замбия)',
        'en_ZW' => 'английски (Зимбабве)',
        'eo' => 'есперанто',
        'eo_001' => 'есперанто (свят)',
        'es' => 'испански',
        'es_419' => 'испански (Латинска Америка)',
        'es_AR' => 'испански (Аржентина)',
        'es_BO' => 'испански (Боливия)',
        'es_BR' => 'испански (Бразилия)',
        'es_BZ' => 'испански (Белиз)',
        'es_CL' => 'испански (Чили)',
        'es_CO' => 'испански (Колумбия)',
        'es_CR' => 'испански (Коста Рика)',
        'es_CU' => 'испански (Куба)',
        'es_DO' => 'испански (Доминиканска република)',
        'es_EC' => 'испански (Еквадор)',
        'es_ES' => 'испански (Испания)',
        'es_GQ' => 'испански (Екваториална Гвинея)',
        'es_GT' => 'испански (Гватемала)',
        'es_HN' => 'испански (Хондурас)',
        'es_MX' => 'испански (Мексико)',
        'es_NI' => 'испански (Никарагуа)',
        'es_PA' => 'испански (Панама)',
        'es_PE' => 'испански (Перу)',
        'es_PH' => 'испански (Филипини)',
        'es_PR' => 'испански (Пуерто Рико)',
        'es_PY' => 'испански (Парагвай)',
        'es_SV' => 'испански (Салвадор)',
        'es_US' => 'испански (Съединени щати)',
        'es_UY' => 'испански (Уругвай)',
        'es_VE' => 'испански (Венецуела)',
        'et' => 'естонски',
        'et_EE' => 'естонски (Естония)',
        'eu' => 'баски',
        'eu_ES' => 'баски (Испания)',
        'fa' => 'персийски',
        'fa_AF' => 'персийски (Афганистан)',
        'fa_IR' => 'персийски (Иран)',
        'ff' => 'фула',
        'ff_Adlm' => 'фула (адлам)',
        'ff_Adlm_BF' => 'фула (адлам, Буркина Фасо)',
        'ff_Adlm_CM' => 'фула (адлам, Камерун)',
        'ff_Adlm_GH' => 'фула (адлам, Гана)',
        'ff_Adlm_GM' => 'фула (адлам, Гамбия)',
        'ff_Adlm_GN' => 'фула (адлам, Гвинея)',
        'ff_Adlm_GW' => 'фула (адлам, Гвинея-Бисау)',
        'ff_Adlm_LR' => 'фула (адлам, Либерия)',
        'ff_Adlm_MR' => 'фула (адлам, Мавритания)',
        'ff_Adlm_NE' => 'фула (адлам, Нигер)',
        'ff_Adlm_NG' => 'фула (адлам, Нигерия)',
        'ff_Adlm_SL' => 'фула (адлам, Сиера Леоне)',
        'ff_Adlm_SN' => 'фула (адлам, Сенегал)',
        'ff_CM' => 'фула (Камерун)',
        'ff_GN' => 'фула (Гвинея)',
        'ff_Latn' => 'фула (латиница)',
        'ff_Latn_BF' => 'фула (латиница, Буркина Фасо)',
        'ff_Latn_CM' => 'фула (латиница, Камерун)',
        'ff_Latn_GH' => 'фула (латиница, Гана)',
        'ff_Latn_GM' => 'фула (латиница, Гамбия)',
        'ff_Latn_GN' => 'фула (латиница, Гвинея)',
        'ff_Latn_GW' => 'фула (латиница, Гвинея-Бисау)',
        'ff_Latn_LR' => 'фула (латиница, Либерия)',
        'ff_Latn_MR' => 'фула (латиница, Мавритания)',
        'ff_Latn_NE' => 'фула (латиница, Нигер)',
        'ff_Latn_NG' => 'фула (латиница, Нигерия)',
        'ff_Latn_SL' => 'фула (латиница, Сиера Леоне)',
        'ff_Latn_SN' => 'фула (латиница, Сенегал)',
        'ff_MR' => 'фула (Мавритания)',
        'ff_SN' => 'фула (Сенегал)',
        'fi' => 'фински',
        'fi_FI' => 'фински (Финландия)',
        'fo' => 'фарьорски',
        'fo_DK' => 'фарьорски (Дания)',
        'fo_FO' => 'фарьорски (Фарьорски острови)',
        'fr' => 'френски',
        'fr_BE' => 'френски (Белгия)',
        'fr_BF' => 'френски (Буркина Фасо)',
        'fr_BI' => 'френски (Бурунди)',
        'fr_BJ' => 'френски (Бенин)',
        'fr_BL' => 'френски (Сен Бартелеми)',
        'fr_CA' => 'френски (Канада)',
        'fr_CD' => 'френски (Конго [Киншаса])',
        'fr_CF' => 'френски (Централноафриканска република)',
        'fr_CG' => 'френски (Конго [Бразавил])',
        'fr_CH' => 'френски (Швейцария)',
        'fr_CI' => 'френски (Кот д’Ивоар)',
        'fr_CM' => 'френски (Камерун)',
        'fr_DJ' => 'френски (Джибути)',
        'fr_DZ' => 'френски (Алжир)',
        'fr_FR' => 'френски (Франция)',
        'fr_GA' => 'френски (Габон)',
        'fr_GF' => 'френски (Френска Гвиана)',
        'fr_GN' => 'френски (Гвинея)',
        'fr_GP' => 'френски (Гваделупа)',
        'fr_GQ' => 'френски (Екваториална Гвинея)',
        'fr_HT' => 'френски (Хаити)',
        'fr_KM' => 'френски (Коморски острови)',
        'fr_LU' => 'френски (Люксембург)',
        'fr_MA' => 'френски (Мароко)',
        'fr_MC' => 'френски (Монако)',
        'fr_MF' => 'френски (Сен Мартен)',
        'fr_MG' => 'френски (Мадагаскар)',
        'fr_ML' => 'френски (Мали)',
        'fr_MQ' => 'френски (Мартиника)',
        'fr_MR' => 'френски (Мавритания)',
        'fr_MU' => 'френски (Мавриций)',
        'fr_NC' => 'френски (Нова Каледония)',
        'fr_NE' => 'френски (Нигер)',
        'fr_PF' => 'френски (Френска Полинезия)',
        'fr_PM' => 'френски (Сен Пиер и Микелон)',
        'fr_RE' => 'френски (Реюнион)',
        'fr_RW' => 'френски (Руанда)',
        'fr_SC' => 'френски (Сейшели)',
        'fr_SN' => 'френски (Сенегал)',
        'fr_SY' => 'френски (Сирия)',
        'fr_TD' => 'френски (Чад)',
        'fr_TG' => 'френски (Того)',
        'fr_TN' => 'френски (Тунис)',
        'fr_VU' => 'френски (Вануату)',
        'fr_WF' => 'френски (Уолис и Футуна)',
        'fr_YT' => 'френски (Майот)',
        'fy' => 'западнофризийски',
        'fy_NL' => 'западнофризийски (Нидерландия)',
        'ga' => 'ирландски',
        'ga_GB' => 'ирландски (Обединеното кралство)',
        'ga_IE' => 'ирландски (Ирландия)',
        'gd' => 'шотландски келтски',
        'gd_GB' => 'шотландски келтски (Обединеното кралство)',
        'gl' => 'галисийски',
        'gl_ES' => 'галисийски (Испания)',
        'gu' => 'гуджарати',
        'gu_IN' => 'гуджарати (Индия)',
        'gv' => 'манкски',
        'gv_IM' => 'манкски (остров Ман)',
        'ha' => 'хауса',
        'ha_GH' => 'хауса (Гана)',
        'ha_NE' => 'хауса (Нигер)',
        'ha_NG' => 'хауса (Нигерия)',
        'he' => 'иврит',
        'he_IL' => 'иврит (Израел)',
        'hi' => 'хинди',
        'hi_IN' => 'хинди (Индия)',
        'hi_Latn' => 'хинди (латиница)',
        'hi_Latn_IN' => 'хинди (латиница, Индия)',
        'hr' => 'хърватски',
        'hr_BA' => 'хърватски (Босна и Херцеговина)',
        'hr_HR' => 'хърватски (Хърватия)',
        'hu' => 'унгарски',
        'hu_HU' => 'унгарски (Унгария)',
        'hy' => 'арменски',
        'hy_AM' => 'арменски (Армения)',
        'ia' => 'интерлингва',
        'ia_001' => 'интерлингва (свят)',
        'id' => 'индонезийски',
        'id_ID' => 'индонезийски (Индонезия)',
        'ie' => 'интерлингве',
        'ie_EE' => 'интерлингве (Естония)',
        'ig' => 'игбо',
        'ig_NG' => 'игбо (Нигерия)',
        'ii' => 'съчуански йи',
        'ii_CN' => 'съчуански йи (Китай)',
        'is' => 'исландски',
        'is_IS' => 'исландски (Исландия)',
        'it' => 'италиански',
        'it_CH' => 'италиански (Швейцария)',
        'it_IT' => 'италиански (Италия)',
        'it_SM' => 'италиански (Сан Марино)',
        'it_VA' => 'италиански (Ватикан)',
        'ja' => 'японски',
        'ja_JP' => 'японски (Япония)',
        'jv' => 'явански',
        'jv_ID' => 'явански (Индонезия)',
        'ka' => 'грузински',
        'ka_GE' => 'грузински (Грузия)',
        'ki' => 'кикую',
        'ki_KE' => 'кикую (Кения)',
        'kk' => 'казахски',
        'kk_Arab' => 'казахски (арабска)',
        'kk_Arab_CN' => 'казахски (арабска, Китай)',
        'kk_Cyrl' => 'казахски (кирилица)',
        'kk_Cyrl_KZ' => 'казахски (кирилица, Казахстан)',
        'kk_KZ' => 'казахски (Казахстан)',
        'kl' => 'гренландски',
        'kl_GL' => 'гренландски (Гренландия)',
        'km' => 'кхмерски',
        'km_KH' => 'кхмерски (Камбоджа)',
        'kn' => 'каннада',
        'kn_IN' => 'каннада (Индия)',
        'ko' => 'корейски',
        'ko_CN' => 'корейски (Китай)',
        'ko_KP' => 'корейски (Северна Корея)',
        'ko_KR' => 'корейски (Южна Корея)',
        'ks' => 'кашмирски',
        'ks_Arab' => 'кашмирски (арабска)',
        'ks_Arab_IN' => 'кашмирски (арабска, Индия)',
        'ks_Deva' => 'кашмирски (деванагари)',
        'ks_Deva_IN' => 'кашмирски (деванагари, Индия)',
        'ks_IN' => 'кашмирски (Индия)',
        'ku' => 'кюрдски',
        'ku_Latn' => 'кюрдски (латиница)',
        'ku_Latn_IQ' => 'кюрдски (латиница, Ирак)',
        'ku_Latn_SY' => 'кюрдски (латиница, Сирия)',
        'ku_Latn_TR' => 'кюрдски (латиница, Турция)',
        'ku_SY' => 'кюрдски (Сирия)',
        'ku_TR' => 'кюрдски (Турция)',
        'kw' => 'корнуолски',
        'kw_GB' => 'корнуолски (Обединеното кралство)',
        'ky' => 'киргизки',
        'ky_KG' => 'киргизки (Киргизстан)',
        'lb' => 'люксембургски',
        'lb_LU' => 'люксембургски (Люксембург)',
        'lg' => 'ганда',
        'lg_UG' => 'ганда (Уганда)',
        'ln' => 'лингала',
        'ln_AO' => 'лингала (Ангола)',
        'ln_CD' => 'лингала (Конго [Киншаса])',
        'ln_CF' => 'лингала (Централноафриканска република)',
        'ln_CG' => 'лингала (Конго [Бразавил])',
        'lo' => 'лаоски',
        'lo_LA' => 'лаоски (Лаос)',
        'lt' => 'литовски',
        'lt_LT' => 'литовски (Литва)',
        'lu' => 'луба-катанга',
        'lu_CD' => 'луба-катанга (Конго [Киншаса])',
        'lv' => 'латвийски',
        'lv_LV' => 'латвийски (Латвия)',
        'mg' => 'малгашки',
        'mg_MG' => 'малгашки (Мадагаскар)',
        'mi' => 'маорски',
        'mi_NZ' => 'маорски (Нова Зеландия)',
        'mk' => 'македонски',
        'mk_MK' => 'македонски (Северна Македония)',
        'ml' => 'малаялам',
        'ml_IN' => 'малаялам (Индия)',
        'mn' => 'монголски',
        'mn_MN' => 'монголски (Монголия)',
        'mr' => 'марати',
        'mr_IN' => 'марати (Индия)',
        'ms' => 'малайски',
        'ms_BN' => 'малайски (Бруней Даруссалам)',
        'ms_ID' => 'малайски (Индонезия)',
        'ms_MY' => 'малайски (Малайзия)',
        'ms_SG' => 'малайски (Сингапур)',
        'mt' => 'малтийски',
        'mt_MT' => 'малтийски (Малта)',
        'my' => 'бирмански',
        'my_MM' => 'бирмански (Мианмар [Бирма])',
        'nb' => 'норвежки [букмол]',
        'nb_NO' => 'норвежки [букмол] (Норвегия)',
        'nb_SJ' => 'норвежки [букмол] (Свалбард и Ян Майен)',
        'nd' => 'северен ндебеле',
        'nd_ZW' => 'северен ндебеле (Зимбабве)',
        'ne' => 'непалски',
        'ne_IN' => 'непалски (Индия)',
        'ne_NP' => 'непалски (Непал)',
        'nl' => 'нидерландски',
        'nl_AW' => 'нидерландски (Аруба)',
        'nl_BE' => 'нидерландски (Белгия)',
        'nl_BQ' => 'нидерландски (Карибска Нидерландия)',
        'nl_CW' => 'нидерландски (Кюрасао)',
        'nl_NL' => 'нидерландски (Нидерландия)',
        'nl_SR' => 'нидерландски (Суринам)',
        'nl_SX' => 'нидерландски (Синт Мартен)',
        'nn' => 'норвежки [нюношк]',
        'nn_NO' => 'норвежки [нюношк] (Норвегия)',
        'no' => 'норвежки',
        'no_NO' => 'норвежки (Норвегия)',
        'oc' => 'окситански',
        'oc_ES' => 'окситански (Испания)',
        'oc_FR' => 'окситански (Франция)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Етиопия)',
        'om_KE' => 'оромо (Кения)',
        'or' => 'ория',
        'or_IN' => 'ория (Индия)',
        'os' => 'осетински',
        'os_GE' => 'осетински (Грузия)',
        'os_RU' => 'осетински (Русия)',
        'pa' => 'пенджабски',
        'pa_Arab' => 'пенджабски (арабска)',
        'pa_Arab_PK' => 'пенджабски (арабска, Пакистан)',
        'pa_Guru' => 'пенджабски (гурмукхи)',
        'pa_Guru_IN' => 'пенджабски (гурмукхи, Индия)',
        'pa_IN' => 'пенджабски (Индия)',
        'pa_PK' => 'пенджабски (Пакистан)',
        'pl' => 'полски',
        'pl_PL' => 'полски (Полша)',
        'ps' => 'пущу',
        'ps_AF' => 'пущу (Афганистан)',
        'ps_PK' => 'пущу (Пакистан)',
        'pt' => 'португалски',
        'pt_AO' => 'португалски (Ангола)',
        'pt_BR' => 'португалски (Бразилия)',
        'pt_CH' => 'португалски (Швейцария)',
        'pt_CV' => 'португалски (Кабо Верде)',
        'pt_GQ' => 'португалски (Екваториална Гвинея)',
        'pt_GW' => 'португалски (Гвинея-Бисау)',
        'pt_LU' => 'португалски (Люксембург)',
        'pt_MO' => 'португалски (Макао, САР на Китай)',
        'pt_MZ' => 'португалски (Мозамбик)',
        'pt_PT' => 'португалски (Португалия)',
        'pt_ST' => 'португалски (Сао Томе и Принсипи)',
        'pt_TL' => 'португалски (Тимор Лесте)',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Боливия)',
        'qu_EC' => 'кечуа (Еквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'реторомански',
        'rm_CH' => 'реторомански (Швейцария)',
        'rn' => 'рунди',
        'rn_BI' => 'рунди (Бурунди)',
        'ro' => 'румънски',
        'ro_MD' => 'румънски (Молдова)',
        'ro_RO' => 'румънски (Румъния)',
        'ru' => 'руски',
        'ru_BY' => 'руски (Беларус)',
        'ru_KG' => 'руски (Киргизстан)',
        'ru_KZ' => 'руски (Казахстан)',
        'ru_MD' => 'руски (Молдова)',
        'ru_RU' => 'руски (Русия)',
        'ru_UA' => 'руски (Украйна)',
        'rw' => 'киняруанда',
        'rw_RW' => 'киняруанда (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (Индия)',
        'sc' => 'сардински',
        'sc_IT' => 'сардински (Италия)',
        'sd' => 'синдхи',
        'sd_Arab' => 'синдхи (арабска)',
        'sd_Arab_PK' => 'синдхи (арабска, Пакистан)',
        'sd_Deva' => 'синдхи (деванагари)',
        'sd_Deva_IN' => 'синдхи (деванагари, Индия)',
        'sd_IN' => 'синдхи (Индия)',
        'sd_PK' => 'синдхи (Пакистан)',
        'se' => 'северносаамски',
        'se_FI' => 'северносаамски (Финландия)',
        'se_NO' => 'северносаамски (Норвегия)',
        'se_SE' => 'северносаамски (Швеция)',
        'sg' => 'санго',
        'sg_CF' => 'санго (Централноафриканска република)',
        'sh' => 'сърбохърватски',
        'sh_BA' => 'сърбохърватски (Босна и Херцеговина)',
        'si' => 'синхалски',
        'si_LK' => 'синхалски (Шри Ланка)',
        'sk' => 'словашки',
        'sk_SK' => 'словашки (Словакия)',
        'sl' => 'словенски',
        'sl_SI' => 'словенски (Словения)',
        'sn' => 'шона',
        'sn_ZW' => 'шона (Зимбабве)',
        'so' => 'сомалийски',
        'so_DJ' => 'сомалийски (Джибути)',
        'so_ET' => 'сомалийски (Етиопия)',
        'so_KE' => 'сомалийски (Кения)',
        'so_SO' => 'сомалийски (Сомалия)',
        'sq' => 'албански',
        'sq_AL' => 'албански (Албания)',
        'sq_MK' => 'албански (Северна Македония)',
        'sr' => 'сръбски',
        'sr_BA' => 'сръбски (Босна и Херцеговина)',
        'sr_Cyrl' => 'сръбски (кирилица)',
        'sr_Cyrl_BA' => 'сръбски (кирилица, Босна и Херцеговина)',
        'sr_Cyrl_ME' => 'сръбски (кирилица, Черна гора)',
        'sr_Cyrl_RS' => 'сръбски (кирилица, Сърбия)',
        'sr_Latn' => 'сръбски (латиница)',
        'sr_Latn_BA' => 'сръбски (латиница, Босна и Херцеговина)',
        'sr_Latn_ME' => 'сръбски (латиница, Черна гора)',
        'sr_Latn_RS' => 'сръбски (латиница, Сърбия)',
        'sr_ME' => 'сръбски (Черна гора)',
        'sr_RS' => 'сръбски (Сърбия)',
        'st' => 'сото',
        'st_LS' => 'сото (Лесото)',
        'st_ZA' => 'сото (Южна Африка)',
        'su' => 'сундански',
        'su_ID' => 'сундански (Индонезия)',
        'su_Latn' => 'сундански (латиница)',
        'su_Latn_ID' => 'сундански (латиница, Индонезия)',
        'sv' => 'шведски',
        'sv_AX' => 'шведски (Оландски острови)',
        'sv_FI' => 'шведски (Финландия)',
        'sv_SE' => 'шведски (Швеция)',
        'sw' => 'суахили',
        'sw_CD' => 'суахили (Конго [Киншаса])',
        'sw_KE' => 'суахили (Кения)',
        'sw_TZ' => 'суахили (Танзания)',
        'sw_UG' => 'суахили (Уганда)',
        'ta' => 'тамилски',
        'ta_IN' => 'тамилски (Индия)',
        'ta_LK' => 'тамилски (Шри Ланка)',
        'ta_MY' => 'тамилски (Малайзия)',
        'ta_SG' => 'тамилски (Сингапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (Индия)',
        'tg' => 'таджикски',
        'tg_TJ' => 'таджикски (Таджикистан)',
        'th' => 'тайски',
        'th_TH' => 'тайски (Тайланд)',
        'ti' => 'тигриня',
        'ti_ER' => 'тигриня (Еритрея)',
        'ti_ET' => 'тигриня (Етиопия)',
        'tk' => 'туркменски',
        'tk_TM' => 'туркменски (Туркменистан)',
        'tl' => 'тагалог',
        'tl_PH' => 'тагалог (Филипини)',
        'tn' => 'тсвана',
        'tn_BW' => 'тсвана (Ботсвана)',
        'tn_ZA' => 'тсвана (Южна Африка)',
        'to' => 'тонгански',
        'to_TO' => 'тонгански (Тонга)',
        'tr' => 'турски',
        'tr_CY' => 'турски (Кипър)',
        'tr_TR' => 'турски (Турция)',
        'tt' => 'татарски',
        'tt_RU' => 'татарски (Русия)',
        'ug' => 'уйгурски',
        'ug_CN' => 'уйгурски (Китай)',
        'uk' => 'украински',
        'uk_UA' => 'украински (Украйна)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Индия)',
        'ur_PK' => 'урду (Пакистан)',
        'uz' => 'узбекски',
        'uz_AF' => 'узбекски (Афганистан)',
        'uz_Arab' => 'узбекски (арабска)',
        'uz_Arab_AF' => 'узбекски (арабска, Афганистан)',
        'uz_Cyrl' => 'узбекски (кирилица)',
        'uz_Cyrl_UZ' => 'узбекски (кирилица, Узбекистан)',
        'uz_Latn' => 'узбекски (латиница)',
        'uz_Latn_UZ' => 'узбекски (латиница, Узбекистан)',
        'uz_UZ' => 'узбекски (Узбекистан)',
        'vi' => 'виетнамски',
        'vi_VN' => 'виетнамски (Виетнам)',
        'wo' => 'волоф',
        'wo_SN' => 'волоф (Сенегал)',
        'xh' => 'кхоса',
        'xh_ZA' => 'кхоса (Южна Африка)',
        'yi' => 'идиш',
        'yi_UA' => 'идиш (Украйна)',
        'yo' => 'йоруба',
        'yo_BJ' => 'йоруба (Бенин)',
        'yo_NG' => 'йоруба (Нигерия)',
        'za' => 'зуанг',
        'za_CN' => 'зуанг (Китай)',
        'zh' => 'китайски',
        'zh_CN' => 'китайски (Китай)',
        'zh_HK' => 'китайски (Хонконг, САР на Китай)',
        'zh_Hans' => 'китайски (опростена)',
        'zh_Hans_CN' => 'китайски (опростена, Китай)',
        'zh_Hans_HK' => 'китайски (опростена, Хонконг, САР на Китай)',
        'zh_Hans_MO' => 'китайски (опростена, Макао, САР на Китай)',
        'zh_Hans_MY' => 'китайски (опростена, Малайзия)',
        'zh_Hans_SG' => 'китайски (опростена, Сингапур)',
        'zh_Hant' => 'китайски (традиционна)',
        'zh_Hant_HK' => 'китайски (традиционна, Хонконг, САР на Китай)',
        'zh_Hant_MO' => 'китайски (традиционна, Макао, САР на Китай)',
        'zh_Hant_MY' => 'китайски (традиционна, Малайзия)',
        'zh_Hant_TW' => 'китайски (традиционна, Тайван)',
        'zh_MO' => 'китайски (Макао, САР на Китай)',
        'zh_SG' => 'китайски (Сингапур)',
        'zh_TW' => 'китайски (Тайван)',
        'zu' => 'зулуски',
        'zu_ZA' => 'зулуски (Южна Африка)',
    ],
];
