<?php

return [
    'Names' => [
        'ak' => 'akankan',
        'ak_GH' => 'akankan (Gana)',
        'am' => 'amarikikan',
        'am_ET' => 'amarikikan (Etiopi)',
        'ar' => 'larabukan',
        'ar_AE' => 'larabukan (Arabu mara kafoli)',
        'ar_BH' => 'larabukan (Bareyini)',
        'ar_DJ' => 'larabukan (Jibuti)',
        'ar_DZ' => 'larabukan (Alizeri)',
        'ar_EG' => 'larabukan (Eziputi)',
        'ar_ER' => 'larabukan (Eritere)',
        'ar_IL' => 'larabukan (Isirayeli)',
        'ar_IQ' => 'larabukan (Iraki)',
        'ar_JO' => 'larabukan (Zɔrdani)',
        'ar_KM' => 'larabukan (Komɔri)',
        'ar_KW' => 'larabukan (Kowɛti)',
        'ar_LB' => 'larabukan (Libaŋ)',
        'ar_LY' => 'larabukan (Libi)',
        'ar_MA' => 'larabukan (Marɔku)',
        'ar_MR' => 'larabukan (Mɔritani)',
        'ar_OM' => 'larabukan (Omaŋ)',
        'ar_PS' => 'larabukan (Palesitini)',
        'ar_QA' => 'larabukan (Katari)',
        'ar_SA' => 'larabukan (Arabiya Sawudiya)',
        'ar_SD' => 'larabukan (Sudaŋ)',
        'ar_SO' => 'larabukan (Somali)',
        'ar_SY' => 'larabukan (Siri)',
        'ar_TD' => 'larabukan (Cadi)',
        'ar_TN' => 'larabukan (Tunizi)',
        'ar_YE' => 'larabukan (Yemɛni)',
        'be' => 'biyelorisikan',
        'be_BY' => 'biyelorisikan (Belarusi)',
        'bg' => 'buligarikan',
        'bg_BG' => 'buligarikan (Buligari)',
        'bm' => 'bamanakan',
        'bm_ML' => 'bamanakan (Mali)',
        'bn' => 'bɛngalikan',
        'bn_BD' => 'bɛngalikan (Bɛngiladɛsi)',
        'bn_IN' => 'bɛngalikan (Ɛndujamana)',
        'cs' => 'cɛkikan',
        'cs_CZ' => 'cɛkikan (Ceki republiki)',
        'de' => 'alimaɲikan',
        'de_AT' => 'alimaɲikan (Otirisi)',
        'de_BE' => 'alimaɲikan (Bɛliziki)',
        'de_CH' => 'alimaɲikan (Suwisi)',
        'de_DE' => 'alimaɲikan (Alimaɲi)',
        'de_IT' => 'alimaɲikan (Itali)',
        'de_LI' => 'alimaɲikan (Lisɛnsitayini)',
        'de_LU' => 'alimaɲikan (Likisanburu)',
        'el' => 'gɛrɛsikan',
        'el_CY' => 'gɛrɛsikan (Cipri)',
        'el_GR' => 'gɛrɛsikan (Gɛrɛsi)',
        'en' => 'angilɛkan',
        'en_AE' => 'angilɛkan (Arabu mara kafoli)',
        'en_AG' => 'angilɛkan (Antiga-ni-Barbuda)',
        'en_AI' => 'angilɛkan (Angiya)',
        'en_AS' => 'angilɛkan (Samowa amerikani)',
        'en_AT' => 'angilɛkan (Otirisi)',
        'en_AU' => 'angilɛkan (Ositirali)',
        'en_BB' => 'angilɛkan (Barbadi)',
        'en_BE' => 'angilɛkan (Bɛliziki)',
        'en_BI' => 'angilɛkan (Burundi)',
        'en_BM' => 'angilɛkan (Bermudi)',
        'en_BS' => 'angilɛkan (Bahamasi)',
        'en_BW' => 'angilɛkan (Bɔtisiwana)',
        'en_BZ' => 'angilɛkan (Belizi)',
        'en_CA' => 'angilɛkan (Kanada)',
        'en_CH' => 'angilɛkan (Suwisi)',
        'en_CK' => 'angilɛkan (Kuki Gun)',
        'en_CM' => 'angilɛkan (Kameruni)',
        'en_CY' => 'angilɛkan (Cipri)',
        'en_CZ' => 'angilɛkan (Ceki republiki)',
        'en_DE' => 'angilɛkan (Alimaɲi)',
        'en_DK' => 'angilɛkan (Danemarki)',
        'en_DM' => 'angilɛkan (Dɔminiki)',
        'en_EE' => 'angilɛkan (Esetoni)',
        'en_ER' => 'angilɛkan (Eritere)',
        'en_ES' => 'angilɛkan (Esipaɲi)',
        'en_FI' => 'angilɛkan (Finilandi)',
        'en_FJ' => 'angilɛkan (Fiji)',
        'en_FK' => 'angilɛkan (Maluwini Gun)',
        'en_FM' => 'angilɛkan (Mikironesi)',
        'en_FR' => 'angilɛkan (Faransi)',
        'en_GB' => 'angilɛkan (Angilɛtɛri)',
        'en_GD' => 'angilɛkan (Granadi)',
        'en_GE' => 'angilɛkan (Zeyɔrzi)',
        'en_GH' => 'angilɛkan (Gana)',
        'en_GI' => 'angilɛkan (Zibralitari)',
        'en_GM' => 'angilɛkan (Ganbi)',
        'en_GU' => 'angilɛkan (Gwam)',
        'en_GY' => 'angilɛkan (Gwiyana)',
        'en_HU' => 'angilɛkan (Hɔngri)',
        'en_ID' => 'angilɛkan (Ɛndonezi)',
        'en_IE' => 'angilɛkan (Irilandi)',
        'en_IL' => 'angilɛkan (Isirayeli)',
        'en_IN' => 'angilɛkan (Ɛndujamana)',
        'en_IT' => 'angilɛkan (Itali)',
        'en_JM' => 'angilɛkan (Zamayiki)',
        'en_JP' => 'angilɛkan (Zapɔn)',
        'en_KE' => 'angilɛkan (Keniya)',
        'en_KI' => 'angilɛkan (Kiribati)',
        'en_KN' => 'angilɛkan (Kristɔfo-Senu-ni-Ɲevɛs)',
        'en_KY' => 'angilɛkan (Bama Gun)',
        'en_LC' => 'angilɛkan (Lusi-Senu)',
        'en_LR' => 'angilɛkan (Liberiya)',
        'en_LS' => 'angilɛkan (Lesoto)',
        'en_LT' => 'angilɛkan (Lituyani)',
        'en_LV' => 'angilɛkan (Letoni)',
        'en_MG' => 'angilɛkan (Madagasikari)',
        'en_MH' => 'angilɛkan (Marisali Gun)',
        'en_MP' => 'angilɛkan (Kɛɲɛka Mariyani Gun)',
        'en_MS' => 'angilɛkan (Moŋsera)',
        'en_MT' => 'angilɛkan (Malti)',
        'en_MU' => 'angilɛkan (Morisi)',
        'en_MV' => 'angilɛkan (Maldivi)',
        'en_MW' => 'angilɛkan (Malawi)',
        'en_MY' => 'angilɛkan (Malɛzi)',
        'en_NA' => 'angilɛkan (Namibi)',
        'en_NF' => 'angilɛkan (Nɔrofoliki Gun)',
        'en_NG' => 'angilɛkan (Nizeriya)',
        'en_NL' => 'angilɛkan (Peyiba)',
        'en_NO' => 'angilɛkan (Nɔriwɛzi)',
        'en_NR' => 'angilɛkan (Nawuru)',
        'en_NU' => 'angilɛkan (Nyuwe)',
        'en_NZ' => 'angilɛkan (Zelandi Koura)',
        'en_PG' => 'angilɛkan (Papuwasi-Gine-Koura)',
        'en_PH' => 'angilɛkan (Filipini)',
        'en_PK' => 'angilɛkan (Pakisitaŋ)',
        'en_PL' => 'angilɛkan (Poloɲi)',
        'en_PN' => 'angilɛkan (Pitikarini)',
        'en_PR' => 'angilɛkan (Pɔrotoriko)',
        'en_PT' => 'angilɛkan (Pɔritigali)',
        'en_PW' => 'angilɛkan (Palawu)',
        'en_RO' => 'angilɛkan (Rumani)',
        'en_RW' => 'angilɛkan (Ruwanda)',
        'en_SB' => 'angilɛkan (Salomo Gun)',
        'en_SC' => 'angilɛkan (Sesɛli)',
        'en_SD' => 'angilɛkan (Sudaŋ)',
        'en_SE' => 'angilɛkan (Suwɛdi)',
        'en_SG' => 'angilɛkan (Sɛngapuri)',
        'en_SH' => 'angilɛkan (Ɛlɛni Senu)',
        'en_SI' => 'angilɛkan (Sloveni)',
        'en_SK' => 'angilɛkan (Slowaki)',
        'en_SL' => 'angilɛkan (Siyera Lewɔni)',
        'en_SZ' => 'angilɛkan (Swazilandi)',
        'en_TC' => 'angilɛkan (Turiki Gun ni Kayiki)',
        'en_TK' => 'angilɛkan (Tokelo)',
        'en_TO' => 'angilɛkan (Tonga)',
        'en_TT' => 'angilɛkan (Trinite-ni-Tobago)',
        'en_TV' => 'angilɛkan (Tuvalu)',
        'en_TZ' => 'angilɛkan (Tanzani)',
        'en_UA' => 'angilɛkan (Ukɛrɛni)',
        'en_UG' => 'angilɛkan (Uganda)',
        'en_US' => 'angilɛkan (Ameriki)',
        'en_VC' => 'angilɛkan (Vinisɛn-Senu-ni-Grenadini)',
        'en_VG' => 'angilɛkan (Angilɛ ka Sungurunnin Gun)',
        'en_VI' => 'angilɛkan (Ameriki ka Sungurunnin Gun)',
        'en_VU' => 'angilɛkan (Vanuwatu)',
        'en_WS' => 'angilɛkan (Samowa)',
        'en_ZA' => 'angilɛkan (Worodugu Afriki)',
        'en_ZM' => 'angilɛkan (Zanbi)',
        'en_ZW' => 'angilɛkan (Zimbabuwe)',
        'es' => 'esipaɲolkan',
        'es_AR' => 'esipaɲolkan (Arizantin)',
        'es_BO' => 'esipaɲolkan (Bolivi)',
        'es_BR' => 'esipaɲolkan (Berezili)',
        'es_BZ' => 'esipaɲolkan (Belizi)',
        'es_CL' => 'esipaɲolkan (Sili)',
        'es_CO' => 'esipaɲolkan (Kolombi)',
        'es_CR' => 'esipaɲolkan (Kɔsitarika)',
        'es_CU' => 'esipaɲolkan (Kuba)',
        'es_DO' => 'esipaɲolkan (Dɔmimiki republiki)',
        'es_EC' => 'esipaɲolkan (Ekwatɔr)',
        'es_ES' => 'esipaɲolkan (Esipaɲi)',
        'es_GQ' => 'esipaɲolkan (Gine ekwatɔri)',
        'es_GT' => 'esipaɲolkan (Gwatemala)',
        'es_HN' => 'esipaɲolkan (Hɔndirasi)',
        'es_MX' => 'esipaɲolkan (Meksiki)',
        'es_NI' => 'esipaɲolkan (Nikaragwa)',
        'es_PA' => 'esipaɲolkan (Panama)',
        'es_PE' => 'esipaɲolkan (Peru)',
        'es_PH' => 'esipaɲolkan (Filipini)',
        'es_PR' => 'esipaɲolkan (Pɔrotoriko)',
        'es_PY' => 'esipaɲolkan (Paraguwayi)',
        'es_SV' => 'esipaɲolkan (Salivadɔr)',
        'es_US' => 'esipaɲolkan (Ameriki)',
        'es_UY' => 'esipaɲolkan (Urugwayi)',
        'es_VE' => 'esipaɲolkan (Venezuwela)',
        'fa' => 'perisanikan',
        'fa_AF' => 'perisanikan (Afiganistaŋ)',
        'fa_IR' => 'perisanikan (Iraŋ)',
        'fr' => 'tubabukan',
        'fr_BE' => 'tubabukan (Bɛliziki)',
        'fr_BF' => 'tubabukan (Burukina Faso)',
        'fr_BI' => 'tubabukan (Burundi)',
        'fr_BJ' => 'tubabukan (Benɛn)',
        'fr_CA' => 'tubabukan (Kanada)',
        'fr_CD' => 'tubabukan (Kongo ka republiki demɔkratiki)',
        'fr_CF' => 'tubabukan (Santarafiriki)',
        'fr_CG' => 'tubabukan (Kongo)',
        'fr_CH' => 'tubabukan (Suwisi)',
        'fr_CI' => 'tubabukan (Kodiwari)',
        'fr_CM' => 'tubabukan (Kameruni)',
        'fr_DJ' => 'tubabukan (Jibuti)',
        'fr_DZ' => 'tubabukan (Alizeri)',
        'fr_FR' => 'tubabukan (Faransi)',
        'fr_GA' => 'tubabukan (Gabɔŋ)',
        'fr_GF' => 'tubabukan (Faransi ka gwiyani)',
        'fr_GN' => 'tubabukan (Gine)',
        'fr_GP' => 'tubabukan (Gwadelup)',
        'fr_GQ' => 'tubabukan (Gine ekwatɔri)',
        'fr_HT' => 'tubabukan (Ayiti)',
        'fr_KM' => 'tubabukan (Komɔri)',
        'fr_LU' => 'tubabukan (Likisanburu)',
        'fr_MA' => 'tubabukan (Marɔku)',
        'fr_MC' => 'tubabukan (Monako)',
        'fr_MG' => 'tubabukan (Madagasikari)',
        'fr_ML' => 'tubabukan (Mali)',
        'fr_MQ' => 'tubabukan (Maritiniki)',
        'fr_MR' => 'tubabukan (Mɔritani)',
        'fr_MU' => 'tubabukan (Morisi)',
        'fr_NC' => 'tubabukan (Kaledoni Koura)',
        'fr_NE' => 'tubabukan (Nizɛri)',
        'fr_PF' => 'tubabukan (Faransi ka polinezi)',
        'fr_PM' => 'tubabukan (Piyɛri-Senu-ni-Mikelɔŋ)',
        'fr_RE' => 'tubabukan (Reyuɲɔŋ)',
        'fr_RW' => 'tubabukan (Ruwanda)',
        'fr_SC' => 'tubabukan (Sesɛli)',
        'fr_SN' => 'tubabukan (Senegali)',
        'fr_SY' => 'tubabukan (Siri)',
        'fr_TD' => 'tubabukan (Cadi)',
        'fr_TG' => 'tubabukan (Togo)',
        'fr_TN' => 'tubabukan (Tunizi)',
        'fr_VU' => 'tubabukan (Vanuwatu)',
        'fr_WF' => 'tubabukan (Walisi-ni-Futuna)',
        'fr_YT' => 'tubabukan (Mayoti)',
        'ha' => 'awusakan',
        'ha_GH' => 'awusakan (Gana)',
        'ha_NE' => 'awusakan (Nizɛri)',
        'ha_NG' => 'awusakan (Nizeriya)',
        'hi' => 'inidikan',
        'hi_IN' => 'inidikan (Ɛndujamana)',
        'hu' => 'oŋirikan',
        'hu_HU' => 'oŋirikan (Hɔngri)',
        'id' => 'Ɛndonezikan',
        'id_ID' => 'Ɛndonezikan (Ɛndonezi)',
        'ig' => 'igibokan',
        'ig_NG' => 'igibokan (Nizeriya)',
        'it' => 'italikan',
        'it_CH' => 'italikan (Suwisi)',
        'it_IT' => 'italikan (Itali)',
        'it_SM' => 'italikan (Marini-Senu)',
        'it_VA' => 'italikan (Vatikaŋ)',
        'ja' => 'zapɔnekan',
        'ja_JP' => 'zapɔnekan (Zapɔn)',
        'jv' => 'javanekan',
        'jv_ID' => 'javanekan (Ɛndonezi)',
        'km' => 'kambojikan',
        'km_KH' => 'kambojikan (Kamboji)',
        'ko' => 'korekan',
        'ko_CN' => 'korekan (Siniwajamana)',
        'ko_KP' => 'korekan (Kɛɲɛka Kore)',
        'ko_KR' => 'korekan (Worodugu Kore)',
        'ms' => 'malɛzikan',
        'ms_BN' => 'malɛzikan (Burinɛyi)',
        'ms_ID' => 'malɛzikan (Ɛndonezi)',
        'ms_MY' => 'malɛzikan (Malɛzi)',
        'ms_SG' => 'malɛzikan (Sɛngapuri)',
        'my' => 'birimanikan',
        'my_MM' => 'birimanikan (Myanimari)',
        'ne' => 'nepalekan',
        'ne_IN' => 'nepalekan (Ɛndujamana)',
        'ne_NP' => 'nepalekan (Nepali)',
        'nl' => 'olandekan',
        'nl_AW' => 'olandekan (Aruba)',
        'nl_BE' => 'olandekan (Bɛliziki)',
        'nl_NL' => 'olandekan (Peyiba)',
        'nl_SR' => 'olandekan (Surinami)',
        'pa' => 'pɛnijabikan',
        'pa_IN' => 'pɛnijabikan (Ɛndujamana)',
        'pa_PK' => 'pɛnijabikan (Pakisitaŋ)',
        'pl' => 'polonekan',
        'pl_PL' => 'polonekan (Poloɲi)',
        'pt' => 'pɔritigalikan',
        'pt_AO' => 'pɔritigalikan (Angola)',
        'pt_BR' => 'pɔritigalikan (Berezili)',
        'pt_CH' => 'pɔritigalikan (Suwisi)',
        'pt_CV' => 'pɔritigalikan (Capivɛrdi)',
        'pt_GQ' => 'pɔritigalikan (Gine ekwatɔri)',
        'pt_GW' => 'pɔritigalikan (Gine Bisawo)',
        'pt_LU' => 'pɔritigalikan (Likisanburu)',
        'pt_MZ' => 'pɔritigalikan (Mozanbiki)',
        'pt_PT' => 'pɔritigalikan (Pɔritigali)',
        'pt_ST' => 'pɔritigalikan (Sawo Tome-ni-Prinicipe)',
        'pt_TL' => 'pɔritigalikan (Kɔrɔn Timɔr)',
        'ro' => 'rumanikan',
        'ro_MD' => 'rumanikan (Molidavi)',
        'ro_RO' => 'rumanikan (Rumani)',
        'ru' => 'irisikan',
        'ru_BY' => 'irisikan (Belarusi)',
        'ru_KG' => 'irisikan (Kirigizisitaŋ)',
        'ru_KZ' => 'irisikan (Kazakistaŋ)',
        'ru_MD' => 'irisikan (Molidavi)',
        'ru_RU' => 'irisikan (Irisi)',
        'ru_UA' => 'irisikan (Ukɛrɛni)',
        'rw' => 'ruwandakan',
        'rw_RW' => 'ruwandakan (Ruwanda)',
        'so' => 'somalikan',
        'so_DJ' => 'somalikan (Jibuti)',
        'so_ET' => 'somalikan (Etiopi)',
        'so_KE' => 'somalikan (Keniya)',
        'so_SO' => 'somalikan (Somali)',
        'sv' => 'suwɛdikan',
        'sv_FI' => 'suwɛdikan (Finilandi)',
        'sv_SE' => 'suwɛdikan (Suwɛdi)',
        'ta' => 'tamulikan',
        'ta_IN' => 'tamulikan (Ɛndujamana)',
        'ta_LK' => 'tamulikan (Sirilanka)',
        'ta_MY' => 'tamulikan (Malɛzi)',
        'ta_SG' => 'tamulikan (Sɛngapuri)',
        'th' => 'tayikan',
        'th_TH' => 'tayikan (Tayilandi)',
        'tr' => 'turikikan',
        'tr_CY' => 'turikikan (Cipri)',
        'tr_TR' => 'turikikan (Turiki)',
        'uk' => 'ukɛrɛnikan',
        'uk_UA' => 'ukɛrɛnikan (Ukɛrɛni)',
        'ur' => 'urudukan',
        'ur_IN' => 'urudukan (Ɛndujamana)',
        'ur_PK' => 'urudukan (Pakisitaŋ)',
        'vi' => 'wiyɛtinamukan',
        'vi_VN' => 'wiyɛtinamukan (Wiyɛtinamu)',
        'yo' => 'yorubakan',
        'yo_BJ' => 'yorubakan (Benɛn)',
        'yo_NG' => 'yorubakan (Nizeriya)',
        'zh' => 'siniwakan',
        'zh_CN' => 'siniwakan (Siniwajamana)',
        'zh_SG' => 'siniwakan (Sɛngapuri)',
        'zh_TW' => 'siniwakan (Tayiwani)',
        'zu' => 'zulukan',
        'zu_ZA' => 'zulukan (Worodugu Afriki)',
    ],
];
