<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Mëttler Greenwich-Zäit (Abidjan)',
        'Africa/Accra' => 'Mëttler Greenwich-Zäit (Accra)',
        'Africa/Addis_Ababa' => 'Ostafrikanesch Zäit (Addis Abeba)',
        'Africa/Algiers' => 'Mëtteleuropäesch Zäit (Alger)',
        'Africa/Asmera' => 'Ostafrikanesch Zäit (Asmara)',
        'Africa/Asmara' => 'Ostafrikanesch Zäit (Asmara)',
        'Africa/Bamako' => 'Mëttler Greenwich-Zäit (Bamako)',
        'Africa/Bangui' => 'Westafrikanesch Zäit (Bangui)',
        'Africa/Banjul' => 'Mëttler Greenwich-Zäit (Banjul)',
        'Africa/Bissau' => 'Mëttler Greenwich-Zäit (Bissau)',
        'Africa/Blantyre' => 'Zentralafrikanesch Zäit (Blantyre)',
        'Africa/Brazzaville' => 'Westafrikanesch Zäit (Brazzaville)',
        'Africa/Bujumbura' => 'Zentralafrikanesch Zäit (Bujumbura)',
        'Africa/Cairo' => 'Osteuropäesch Zäit (Kairo)',
        'Africa/Casablanca' => 'Westeuropäesch Zäit (Casablanca)',
        'Africa/Ceuta' => 'Mëtteleuropäesch Zäit (Ceuta)',
        'Africa/Conakry' => 'Mëttler Greenwich-Zäit (Conakry)',
        'Africa/Dakar' => 'Mëttler Greenwich-Zäit (Dakar)',
        'Africa/Dar_es_Salaam' => 'Ostafrikanesch Zäit (Dar es Salaam)',
        'Africa/Djibouti' => 'Ostafrikanesch Zäit (Dschibuti)',
        'Africa/Douala' => 'Westafrikanesch Zäit (Douala)',
        'Africa/El_Aaiun' => 'Westeuropäesch Zäit (El Aaiún)',
        'Africa/Freetown' => 'Mëttler Greenwich-Zäit (Freetown)',
        'Africa/Gaborone' => 'Zentralafrikanesch Zäit (Gaborone)',
        'Africa/Harare' => 'Zentralafrikanesch Zäit (Harare)',
        'Africa/Johannesburg' => 'Südafrikanesch Zäit (Johannesburg)',
        'Africa/Juba' => 'Zentralafrikanesch Zäit (Juba)',
        'Africa/Kampala' => 'Ostafrikanesch Zäit (Kampala)',
        'Africa/Khartoum' => 'Zentralafrikanesch Zäit (Khartum)',
        'Africa/Kigali' => 'Zentralafrikanesch Zäit (Kigali)',
        'Africa/Kinshasa' => 'Westafrikanesch Zäit (Kinshasa)',
        'Africa/Lagos' => 'Westafrikanesch Zäit (Lagos)',
        'Africa/Libreville' => 'Westafrikanesch Zäit (Libreville)',
        'Africa/Lome' => 'Mëttler Greenwich-Zäit (Lomé)',
        'Africa/Luanda' => 'Westafrikanesch Zäit (Luanda)',
        'Africa/Lubumbashi' => 'Zentralafrikanesch Zäit (Lubumbashi)',
        'Africa/Lusaka' => 'Zentralafrikanesch Zäit (Lusaka)',
        'Africa/Malabo' => 'Westafrikanesch Zäit (Malabo)',
        'Africa/Maputo' => 'Zentralafrikanesch Zäit (Maputo)',
        'Africa/Maseru' => 'Südafrikanesch Zäit (Maseru)',
        'Africa/Mbabane' => 'Südafrikanesch Zäit (Mbabane)',
        'Africa/Mogadishu' => 'Ostafrikanesch Zäit (Mogadischu)',
        'Africa/Monrovia' => 'Mëttler Greenwich-Zäit (Monrovia)',
        'Africa/Nairobi' => 'Ostafrikanesch Zäit (Nairobi)',
        'Africa/Ndjamena' => 'Westafrikanesch Zäit (N’Djamena)',
        'Africa/Niamey' => 'Westafrikanesch Zäit (Niamey)',
        'Africa/Nouakchott' => 'Mëttler Greenwich-Zäit (Nouakchott)',
        'Africa/Ouagadougou' => 'Mëttler Greenwich-Zäit (Wagadugu)',
        'Africa/Porto-Novo' => 'Westafrikanesch Zäit (Porto-Novo)',
        'Africa/Sao_Tome' => 'Mëttler Greenwich-Zäit (São Tomé)',
        'Africa/Tripoli' => 'Osteuropäesch Zäit (Tripoli)',
        'Africa/Tunis' => 'Mëtteleuropäesch Zäit (Tunis)',
        'Africa/Windhoek' => 'Zentralafrikanesch Zäit (Windhoek)',
        'America/Adak' => 'Hawaii-Aleuten-Zäit (Adak)',
        'America/Anchorage' => 'Alaska-Zäit (Anchorage)',
        'America/Anguilla' => 'Atlantik-Zäit (Anguilla)',
        'America/Antigua' => 'Atlantik-Zäit (Antigua)',
        'America/Araguaina' => 'Brasília-Zäit (Araguaína)',
        'America/Argentina/La_Rioja' => 'Argentinesch Zäit (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentinesch Zäit (Río Gallegos)',
        'America/Argentina/Salta' => 'Argentinesch Zäit (Salta)',
        'America/Argentina/San_Juan' => 'Argentinesch Zäit (San Juan)',
        'America/Argentina/San_Luis' => 'Argentinesch Zäit (San Luis)',
        'America/Argentina/Tucuman' => 'Argentinesch Zäit (Tucumán)',
        'America/Argentina/Ushuaia' => 'Argentinesch Zäit (Ushuaia)',
        'America/Aruba' => 'Atlantik-Zäit (Aruba)',
        'America/Asuncion' => 'Paraguayanesch Zäit (Asunción)',
        'America/Bahia' => 'Brasília-Zäit (Bahia)',
        'America/Bahia_Banderas' => 'Nordamerikanesch Inlandzäit (Bahía de Banderas)',
        'America/Barbados' => 'Atlantik-Zäit (Barbados)',
        'America/Belem' => 'Brasília-Zäit (Belém)',
        'America/Belize' => 'Nordamerikanesch Inlandzäit (Belize)',
        'America/Blanc-Sablon' => 'Atlantik-Zäit (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazonas-Zäit (Boa Vista)',
        'America/Bogota' => 'Kolumbianesch Zäit (Bogotá)',
        'America/Boise' => 'Rocky-Mountain-Zäit (Boise)',
        'America/Buenos_Aires' => 'Argentinesch Zäit (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Argentinesch Zäit (Buenos Aires)',
        'America/Cambridge_Bay' => 'Rocky-Mountain-Zäit (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazonas-Zäit (Campo Grande)',
        'America/Cancun' => 'Nordamerikanesch Ostküstenzäit (Cancún)',
        'America/Caracas' => 'Venezuela-Zäit (Caracas)',
        'America/Catamarca' => 'Argentinesch Zäit (Catamarca)',
        'America/Argentina/Catamarca' => 'Argentinesch Zäit (Catamarca)',
        'America/Cayenne' => 'Franséisch-Guayane-Zäit (Cayenne)',
        'America/Cayman' => 'Nordamerikanesch Ostküstenzäit (Kaimaninselen)',
        'America/Chicago' => 'Nordamerikanesch Inlandzäit (Chicago)',
        'America/Chihuahua' => 'Nordamerikanesch Inlandzäit (Chihuahua)',
        'America/Ciudad_Juarez' => 'Rocky-Mountain-Zäit (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Nordamerikanesch Ostküstenzäit (Atikokan)',
        'America/Atikokan' => 'Nordamerikanesch Ostküstenzäit (Atikokan)',
        'America/Cordoba' => 'Argentinesch Zäit (Córdoba)',
        'America/Argentina/Cordoba' => 'Argentinesch Zäit (Córdoba)',
        'America/Costa_Rica' => 'Nordamerikanesch Inlandzäit (Costa Rica)',
        'America/Coyhaique' => 'Chilenesch Zäit (Coyhaique)',
        'America/Creston' => 'Rocky-Mountain-Zäit (Creston)',
        'America/Cuiaba' => 'Amazonas-Zäit (Cuiabá)',
        'America/Curacao' => 'Atlantik-Zäit (Curaçao)',
        'America/Danmarkshavn' => 'Mëttler Greenwich-Zäit (Danmarkshavn)',
        'America/Dawson' => 'Kanada Zäit (Dawson)',
        'America/Dawson_Creek' => 'Rocky-Mountain-Zäit (Dawson Creek)',
        'America/Denver' => 'Rocky-Mountain-Zäit (Denver)',
        'America/Detroit' => 'Nordamerikanesch Ostküstenzäit (Detroit)',
        'America/Dominica' => 'Atlantik-Zäit (Dominica)',
        'America/Edmonton' => 'Rocky-Mountain-Zäit (Edmonton)',
        'America/Eirunepe' => 'Acre-Zäit (Eirunepé)',
        'America/El_Salvador' => 'Nordamerikanesch Inlandzäit (Salvador)',
        'America/Fort_Nelson' => 'Rocky-Mountain-Zäit (Fort Nelson)',
        'America/Fortaleza' => 'Brasília-Zäit (Fortaleza)',
        'America/Glace_Bay' => 'Atlantik-Zäit (Glace Bay)',
        'America/Godthab' => 'Grönland Zäit (Nuuk)',
        'America/Nuuk' => 'Grönland Zäit (Nuuk)',
        'America/Goose_Bay' => 'Atlantik-Zäit (Goose Bay)',
        'America/Grand_Turk' => 'Nordamerikanesch Ostküstenzäit (Grand Turk)',
        'America/Grenada' => 'Atlantik-Zäit (Grenada)',
        'America/Guadeloupe' => 'Atlantik-Zäit (Guadeloupe)',
        'America/Guatemala' => 'Nordamerikanesch Inlandzäit (Guatemala)',
        'America/Guayaquil' => 'Ecuadorianesch Zäit (Guayaquil)',
        'America/Guyana' => 'Guyana-Zäit',
        'America/Halifax' => 'Atlantik-Zäit (Halifax)',
        'America/Havana' => 'Kubanesch Zäit (Havanna)',
        'America/Hermosillo' => 'Mexikanesch Pazifikzäit (Hermosillo)',
        'America/Indiana/Knox' => 'Nordamerikanesch Inlandzäit (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Nordamerikanesch Ostküstenzäit (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Nordamerikanesch Ostküstenzäit (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Nordamerikanesch Inlandzäit (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Nordamerikanesch Ostküstenzäit (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Nordamerikanesch Ostküstenzäit (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Nordamerikanesch Ostküstenzäit (Winamac, Indiana)',
        'America/Indianapolis' => 'Nordamerikanesch Ostküstenzäit (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Nordamerikanesch Ostküstenzäit (Indianapolis)',
        'America/Inuvik' => 'Rocky-Mountain-Zäit (Inuvik)',
        'America/Iqaluit' => 'Nordamerikanesch Ostküstenzäit (Iqaluit)',
        'America/Jamaica' => 'Nordamerikanesch Ostküstenzäit (Jamaika)',
        'America/Jujuy' => 'Argentinesch Zäit (Jujuy)',
        'America/Argentina/Jujuy' => 'Argentinesch Zäit (Jujuy)',
        'America/Juneau' => 'Alaska-Zäit (Juneau)',
        'America/Kentucky/Monticello' => 'Nordamerikanesch Ostküstenzäit (Monticello, Kentucky)',
        'America/Kralendijk' => 'Atlantik-Zäit (Kralendijk)',
        'America/La_Paz' => 'Bolivianesch Zäit (La Paz)',
        'America/Lima' => 'Peruanesch Zäit (Lima)',
        'America/Los_Angeles' => 'Nordamerikanesch Westküstenzäit (Los Angeles)',
        'America/Louisville' => 'Nordamerikanesch Ostküstenzäit (Louisville)',
        'America/Kentucky/Louisville' => 'Nordamerikanesch Ostküstenzäit (Louisville)',
        'America/Lower_Princes' => 'Atlantik-Zäit (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasília-Zäit (Maceió)',
        'America/Managua' => 'Nordamerikanesch Inlandzäit (Managua)',
        'America/Manaus' => 'Amazonas-Zäit (Manaus)',
        'America/Marigot' => 'Atlantik-Zäit (Marigot)',
        'America/Martinique' => 'Atlantik-Zäit (Martinique)',
        'America/Matamoros' => 'Nordamerikanesch Inlandzäit (Matamoros)',
        'America/Mazatlan' => 'Mexikanesch Pazifikzäit (Mazatlán)',
        'America/Mendoza' => 'Argentinesch Zäit (Mendoza)',
        'America/Argentina/Mendoza' => 'Argentinesch Zäit (Mendoza)',
        'America/Menominee' => 'Nordamerikanesch Inlandzäit (Menominee)',
        'America/Merida' => 'Nordamerikanesch Inlandzäit (Mérida)',
        'America/Metlakatla' => 'Alaska-Zäit (Metlakatla)',
        'America/Mexico_City' => 'Nordamerikanesch Inlandzäit (Mexiko-Stad)',
        'America/Miquelon' => 'Saint-Pierre-a-Miquelon-Zäit',
        'America/Moncton' => 'Atlantik-Zäit (Moncton)',
        'America/Monterrey' => 'Nordamerikanesch Inlandzäit (Monterrey)',
        'America/Montevideo' => 'Uruguayanesch Zäit (Montevideo)',
        'America/Montserrat' => 'Atlantik-Zäit (Montserrat)',
        'America/Nassau' => 'Nordamerikanesch Ostküstenzäit (Nassau)',
        'America/New_York' => 'Nordamerikanesch Ostküstenzäit (New York)',
        'America/Nome' => 'Alaska-Zäit (Nome)',
        'America/Noronha' => 'Fernando-de-Noronha-Zäit',
        'America/North_Dakota/Beulah' => 'Nordamerikanesch Inlandzäit (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Nordamerikanesch Inlandzäit (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Nordamerikanesch Inlandzäit (New Salem, North Dakota)',
        'America/Ojinaga' => 'Nordamerikanesch Inlandzäit (Ojinaga)',
        'America/Panama' => 'Nordamerikanesch Ostküstenzäit (Panama)',
        'America/Paramaribo' => 'Suriname-Zäit (Paramaribo)',
        'America/Phoenix' => 'Rocky-Mountain-Zäit (Phoenix)',
        'America/Port-au-Prince' => 'Nordamerikanesch Ostküstenzäit (Port-au-Prince)',
        'America/Port_of_Spain' => 'Atlantik-Zäit (Port-of-Spain)',
        'America/Porto_Velho' => 'Amazonas-Zäit (Porto Velho)',
        'America/Puerto_Rico' => 'Atlantik-Zäit (Puerto Rico)',
        'America/Punta_Arenas' => 'Chilenesch Zäit (Punta Arenas)',
        'America/Rankin_Inlet' => 'Nordamerikanesch Inlandzäit (Rankin Inlet)',
        'America/Recife' => 'Brasília-Zäit (Recife)',
        'America/Regina' => 'Nordamerikanesch Inlandzäit (Regina)',
        'America/Resolute' => 'Nordamerikanesch Inlandzäit (Resolute)',
        'America/Rio_Branco' => 'Acre-Zäit (Rio Branco)',
        'America/Santarem' => 'Brasília-Zäit (Santarém)',
        'America/Santiago' => 'Chilenesch Zäit (Santiago)',
        'America/Santo_Domingo' => 'Atlantik-Zäit (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasília-Zäit (São Paulo)',
        'America/Scoresbysund' => 'Grönland Zäit (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaska-Zäit (Sitka)',
        'America/St_Barthelemy' => 'Atlantik-Zäit (Saint-Barthélemy)',
        'America/St_Johns' => 'Neifundland-Zäit (St. John’s)',
        'America/St_Kitts' => 'Atlantik-Zäit (St. Kitts)',
        'America/St_Lucia' => 'Atlantik-Zäit (St. Lucia)',
        'America/St_Thomas' => 'Atlantik-Zäit (St. Thomas)',
        'America/St_Vincent' => 'Atlantik-Zäit (St. Vincent)',
        'America/Swift_Current' => 'Nordamerikanesch Inlandzäit (Swift Current)',
        'America/Tegucigalpa' => 'Nordamerikanesch Inlandzäit (Tegucigalpa)',
        'America/Thule' => 'Atlantik-Zäit (Thule)',
        'America/Tijuana' => 'Nordamerikanesch Westküstenzäit (Tijuana)',
        'America/Toronto' => 'Nordamerikanesch Ostküstenzäit (Toronto)',
        'America/Tortola' => 'Atlantik-Zäit (Tortola)',
        'America/Vancouver' => 'Nordamerikanesch Westküstenzäit (Vancouver)',
        'America/Whitehorse' => 'Kanada Zäit (Whitehorse)',
        'America/Winnipeg' => 'Nordamerikanesch Inlandzäit (Winnipeg)',
        'America/Yakutat' => 'Alaska-Zäit (Yakutat)',
        'Antarctica/Casey' => 'Westaustralesch Zäit (Casey)',
        'Antarctica/Davis' => 'Davis-Zäit',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urville-Zäit',
        'Antarctica/Macquarie' => 'Ostaustralesch Zäit (Macquarie)',
        'Antarctica/Mawson' => 'Mawson-Zäit',
        'Antarctica/McMurdo' => 'Neiséiland-Zäit (McMurdo)',
        'Antarctica/Palmer' => 'Chilenesch Zäit (Palmer)',
        'Antarctica/Rothera' => 'Rothera-Zäit',
        'Antarctica/Syowa' => 'Syowa-Zäit (Showa)',
        'Antarctica/Troll' => 'Mëttler Greenwich-Zäit (Troll)',
        'Antarctica/Vostok' => 'Wostok-Zäit',
        'Arctic/Longyearbyen' => 'Mëtteleuropäesch Zäit (Longyearbyen)',
        'Asia/Aden' => 'Arabesch Zäit (Aden)',
        'Asia/Almaty' => 'Kasachstan Zäit (Almaty)',
        'Asia/Amman' => 'Osteuropäesch Zäit (Amman)',
        'Asia/Anadyr' => 'Kamtschatka-Zäit (Anadyr)',
        'Asia/Aqtau' => 'Kasachstan Zäit (Aqtau)',
        'Asia/Aqtobe' => 'Kasachstan Zäit (Aqtöbe)',
        'Asia/Ashgabat' => 'Turkmenistan-Zäit (Ashgabat)',
        'Asia/Atyrau' => 'Kasachstan Zäit (Atyrau)',
        'Asia/Baghdad' => 'Arabesch Zäit (Bagdad)',
        'Asia/Bahrain' => 'Arabesch Zäit (Bahrain)',
        'Asia/Baku' => 'Aserbaidschanesch Zäit (Baku)',
        'Asia/Bangkok' => 'Indochina-Zäit (Bangkok)',
        'Asia/Barnaul' => 'Krasnojarsk-Zäit (Barnaul)',
        'Asia/Beirut' => 'Osteuropäesch Zäit (Beirut)',
        'Asia/Bishkek' => 'Kirgisistan-Zäit (Bischkek)',
        'Asia/Brunei' => 'Brunei-Zäit',
        'Asia/Calcutta' => 'Indesch Zäit (Kalkutta)',
        'Asia/Kolkata' => 'Indesch Zäit (Kalkutta)',
        'Asia/Chita' => 'Jakutsk-Zäit (Chita)',
        'Asia/Colombo' => 'Indesch Zäit (Colombo)',
        'Asia/Damascus' => 'Osteuropäesch Zäit (Damaskus)',
        'Asia/Dhaka' => 'Bangladesch-Zäit (Dhaka)',
        'Asia/Dili' => 'Osttimor-Zäit (Dili)',
        'Asia/Dubai' => 'Golf-Zäit (Dubai)',
        'Asia/Dushanbe' => 'Tadschikistan-Zäit (Duschanbe)',
        'Asia/Famagusta' => 'Osteuropäesch Zäit (Famagusta)',
        'Asia/Gaza' => 'Osteuropäesch Zäit (Gaza)',
        'Asia/Hebron' => 'Osteuropäesch Zäit (Hebron)',
        'Asia/Hong_Kong' => 'Hong-Kong-Zäit',
        'Asia/Hovd' => 'Hovd-Zäit (Khovd)',
        'Asia/Irkutsk' => 'Irkutsk-Zäit',
        'Asia/Jakarta' => 'Westindonesesch Zäit (Jakarta)',
        'Asia/Jayapura' => 'Ostindonesesch Zäit (Port Numbay)',
        'Asia/Jerusalem' => 'Israelesch Zäit (Jerusalem)',
        'Asia/Kabul' => 'Afghanistan-Zäit (Kabul)',
        'Asia/Kamchatka' => 'Kamtschatka-Zäit',
        'Asia/Karachi' => 'Pakistanesch Zäit (Karachi)',
        'Asia/Katmandu' => 'Nepalesesch Zäit (Kathmandu)',
        'Asia/Kathmandu' => 'Nepalesesch Zäit (Kathmandu)',
        'Asia/Khandyga' => 'Jakutsk-Zäit (Khandyga)',
        'Asia/Krasnoyarsk' => 'Krasnojarsk-Zäit',
        'Asia/Kuala_Lumpur' => 'Malaysesch Zäit (Kuala Lumpur)',
        'Asia/Kuching' => 'Malaysesch Zäit (Kuching)',
        'Asia/Kuwait' => 'Arabesch Zäit (Kuwait)',
        'Asia/Macau' => 'Chinesesch Zäit (Macau)',
        'Asia/Magadan' => 'Magadan-Zäit',
        'Asia/Makassar' => 'Zentralindonesesch Zäit (Makassar)',
        'Asia/Manila' => 'Philippinnesch Zäit (Manila)',
        'Asia/Muscat' => 'Golf-Zäit (Muskat)',
        'Asia/Nicosia' => 'Osteuropäesch Zäit (Nikosia)',
        'Asia/Novokuznetsk' => 'Krasnojarsk-Zäit (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Krasnojarsk-Zäit (Nowosibirsk)',
        'Asia/Omsk' => 'Omsk-Zäit',
        'Asia/Oral' => 'Kasachstan Zäit (Oral)',
        'Asia/Phnom_Penh' => 'Indochina-Zäit (Phnom Penh)',
        'Asia/Pontianak' => 'Westindonesesch Zäit (Pontianak)',
        'Asia/Pyongyang' => 'Koreanesch Zäit (Pjöngjang)',
        'Asia/Qatar' => 'Arabesch Zäit (Katar)',
        'Asia/Qostanay' => 'Kasachstan Zäit (Qostanay)',
        'Asia/Qyzylorda' => 'Kasachstan Zäit (Qyzylorda)',
        'Asia/Rangoon' => 'Myanmar-Zäit (Yangon)',
        'Asia/Yangon' => 'Myanmar-Zäit (Yangon)',
        'Asia/Riyadh' => 'Arabesch Zäit (Riad)',
        'Asia/Saigon' => 'Indochina-Zäit (Ho-Chi-Minh-Stad)',
        'Asia/Ho_Chi_Minh' => 'Indochina-Zäit (Ho-Chi-Minh-Stad)',
        'Asia/Sakhalin' => 'Magadan-Zäit (Sachalin)',
        'Asia/Samarkand' => 'Usbekistan-Zäit (Samarkand)',
        'Asia/Seoul' => 'Koreanesch Zäit (Seoul)',
        'Asia/Shanghai' => 'Chinesesch Zäit (Shanghai)',
        'Asia/Singapore' => 'Singapur-Standardzäit',
        'Asia/Srednekolymsk' => 'Magadan-Zäit (Srednekolymsk)',
        'Asia/Taipei' => 'Taipei-Zäit (Taipeh)',
        'Asia/Tashkent' => 'Usbekistan-Zäit (Taschkent)',
        'Asia/Tbilisi' => 'Georgesch Zäit (Tiflis)',
        'Asia/Tehran' => 'Iranesch Zäit (Teheran)',
        'Asia/Thimphu' => 'Bhutan-Zäit (Thimphu)',
        'Asia/Tokyo' => 'Japanesch Zäit (Tokio)',
        'Asia/Tomsk' => 'Krasnojarsk-Zäit (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulaanbaatar-Zäit',
        'Asia/Urumqi' => 'China Zäit (Ürümqi)',
        'Asia/Ust-Nera' => 'Wladiwostok-Zäit (Ust-Nera)',
        'Asia/Vientiane' => 'Indochina-Zäit (Vientiane)',
        'Asia/Vladivostok' => 'Wladiwostok-Zäit',
        'Asia/Yakutsk' => 'Jakutsk-Zäit',
        'Asia/Yekaterinburg' => 'Jekaterinbuerg-Zäit',
        'Asia/Yerevan' => 'Armenesch Zäit (Erivan)',
        'Atlantic/Azores' => 'Azoren-Zäit',
        'Atlantic/Bermuda' => 'Atlantik-Zäit (Bermudas)',
        'Atlantic/Canary' => 'Westeuropäesch Zäit (Kanaresch Inselen)',
        'Atlantic/Cape_Verde' => 'Kap-Verde-Zäit',
        'Atlantic/Faeroe' => 'Westeuropäesch Zäit (Färöer)',
        'Atlantic/Faroe' => 'Westeuropäesch Zäit (Färöer)',
        'Atlantic/Madeira' => 'Westeuropäesch Zäit (Madeira)',
        'Atlantic/Reykjavik' => 'Mëttler Greenwich-Zäit (Reykjavik)',
        'Atlantic/South_Georgia' => 'Südgeorgesch Zäit (Südgeorgien)',
        'Atlantic/St_Helena' => 'Mëttler Greenwich-Zäit (St. Helena)',
        'Atlantic/Stanley' => 'Falklandinselen-Zäit (Stanley)',
        'Australia/Adelaide' => 'Zentralaustralesch Zäit (Adelaide)',
        'Australia/Brisbane' => 'Ostaustralesch Zäit (Brisbane)',
        'Australia/Broken_Hill' => 'Zentralaustralesch Zäit (Broken Hill)',
        'Australia/Darwin' => 'Zentralaustralesch Zäit (Darwin)',
        'Australia/Eucla' => 'Zentral-/Westaustralesch Zäit (Eucla)',
        'Australia/Hobart' => 'Ostaustralesch Zäit (Hobart)',
        'Australia/Lindeman' => 'Ostaustralesch Zäit (Lindeman)',
        'Australia/Lord_Howe' => 'Lord-Howe-Zäit',
        'Australia/Melbourne' => 'Ostaustralesch Zäit (Melbourne)',
        'Australia/Perth' => 'Westaustralesch Zäit (Perth)',
        'Australia/Sydney' => 'Ostaustralesch Zäit (Sydney)',
        'Etc/GMT' => 'Mëttler Greenwich-Zäit',
        'Europe/Amsterdam' => 'Mëtteleuropäesch Zäit (Amsterdam)',
        'Europe/Andorra' => 'Mëtteleuropäesch Zäit (Andorra)',
        'Europe/Astrakhan' => 'Samara-Zäit (Astrakhan)',
        'Europe/Athens' => 'Osteuropäesch Zäit (Athen)',
        'Europe/Belgrade' => 'Mëtteleuropäesch Zäit (Belgrad)',
        'Europe/Berlin' => 'Mëtteleuropäesch Zäit (Berlin)',
        'Europe/Bratislava' => 'Mëtteleuropäesch Zäit (Bratislava)',
        'Europe/Brussels' => 'Mëtteleuropäesch Zäit (Bréissel)',
        'Europe/Bucharest' => 'Osteuropäesch Zäit (Bukarest)',
        'Europe/Budapest' => 'Mëtteleuropäesch Zäit (Budapest)',
        'Europe/Busingen' => 'Mëtteleuropäesch Zäit (Büsingen)',
        'Europe/Chisinau' => 'Osteuropäesch Zäit (Kischinau)',
        'Europe/Copenhagen' => 'Mëtteleuropäesch Zäit (Kopenhagen)',
        'Europe/Dublin' => 'Mëttler Greenwich-Zäit (Dublin)',
        'Europe/Gibraltar' => 'Mëtteleuropäesch Zäit (Gibraltar)',
        'Europe/Guernsey' => 'Mëttler Greenwich-Zäit (Guernsey)',
        'Europe/Helsinki' => 'Osteuropäesch Zäit (Helsinki)',
        'Europe/Isle_of_Man' => 'Mëttler Greenwich-Zäit (Isle of Man)',
        'Europe/Istanbul' => 'Tierkei Zäit (Istanbul)',
        'Europe/Jersey' => 'Mëttler Greenwich-Zäit (Jersey)',
        'Europe/Kaliningrad' => 'Osteuropäesch Zäit (Kaliningrad)',
        'Europe/Kiev' => 'Osteuropäesch Zäit (Kiew)',
        'Europe/Kyiv' => 'Osteuropäesch Zäit (Kiew)',
        'Europe/Kirov' => 'Moskauer Zäit (Kirov)',
        'Europe/Lisbon' => 'Westeuropäesch Zäit (Lissabon)',
        'Europe/Ljubljana' => 'Mëtteleuropäesch Zäit (Ljubljana)',
        'Europe/London' => 'Mëttler Greenwich-Zäit (London)',
        'Europe/Luxembourg' => 'Mëtteleuropäesch Zäit (Lëtzebuerg)',
        'Europe/Madrid' => 'Mëtteleuropäesch Zäit (Madrid)',
        'Europe/Malta' => 'Mëtteleuropäesch Zäit (Malta)',
        'Europe/Mariehamn' => 'Osteuropäesch Zäit (Mariehamn)',
        'Europe/Minsk' => 'Moskauer Zäit (Minsk)',
        'Europe/Monaco' => 'Mëtteleuropäesch Zäit (Monaco)',
        'Europe/Moscow' => 'Moskauer Zäit',
        'Europe/Oslo' => 'Mëtteleuropäesch Zäit (Oslo)',
        'Europe/Paris' => 'Mëtteleuropäesch Zäit (Paris)',
        'Europe/Podgorica' => 'Mëtteleuropäesch Zäit (Podgorica)',
        'Europe/Prague' => 'Mëtteleuropäesch Zäit (Prag)',
        'Europe/Riga' => 'Osteuropäesch Zäit (Riga)',
        'Europe/Rome' => 'Mëtteleuropäesch Zäit (Roum)',
        'Europe/Samara' => 'Samara-Zäit',
        'Europe/San_Marino' => 'Mëtteleuropäesch Zäit (San Marino)',
        'Europe/Sarajevo' => 'Mëtteleuropäesch Zäit (Sarajevo)',
        'Europe/Saratov' => 'Samara-Zäit (Saratov)',
        'Europe/Simferopol' => 'Moskauer Zäit (Simferopol)',
        'Europe/Skopje' => 'Mëtteleuropäesch Zäit (Skopje)',
        'Europe/Sofia' => 'Osteuropäesch Zäit (Sofia)',
        'Europe/Stockholm' => 'Mëtteleuropäesch Zäit (Stockholm)',
        'Europe/Tallinn' => 'Osteuropäesch Zäit (Tallinn)',
        'Europe/Tirane' => 'Mëtteleuropäesch Zäit (Tirana)',
        'Europe/Ulyanovsk' => 'Samara-Zäit (Ulyanovsk)',
        'Europe/Vaduz' => 'Mëtteleuropäesch Zäit (Vaduz)',
        'Europe/Vatican' => 'Mëtteleuropäesch Zäit (Vatikan)',
        'Europe/Vienna' => 'Mëtteleuropäesch Zäit (Wien)',
        'Europe/Vilnius' => 'Osteuropäesch Zäit (Wilna)',
        'Europe/Volgograd' => 'Moskauer Zäit (Wolgograd)',
        'Europe/Warsaw' => 'Mëtteleuropäesch Zäit (Warschau)',
        'Europe/Zagreb' => 'Mëtteleuropäesch Zäit (Zagreb)',
        'Europe/Zurich' => 'Mëtteleuropäesch Zäit (Zürech)',
        'Indian/Antananarivo' => 'Ostafrikanesch Zäit (Antananarivo)',
        'Indian/Chagos' => 'Indeschen Ozean-Zäit (Chagos)',
        'Indian/Christmas' => 'Chrëschtdagsinsel-Zäit',
        'Indian/Cocos' => 'Kokosinselen-Zäit (Cocos)',
        'Indian/Comoro' => 'Ostafrikanesch Zäit (Komoren)',
        'Indian/Kerguelen' => 'Franséisch Süd- an Antarktisgebidder-Zäit (Kerguelen)',
        'Indian/Mahe' => 'Seychellen-Zäit (Mahé)',
        'Indian/Maldives' => 'Maldiven-Zäit',
        'Indian/Mauritius' => 'Mauritius-Zäit',
        'Indian/Mayotte' => 'Ostafrikanesch Zäit (Mayotte)',
        'Indian/Reunion' => 'Réunion-Zäit',
        'Pacific/Apia' => 'Samoa Zäit (Apia)',
        'Pacific/Auckland' => 'Neiséiland-Zäit (Auckland)',
        'Pacific/Bougainville' => 'Papua-Neiguinea-Zäit (Bougainville)',
        'Pacific/Chatham' => 'Chatham-Zäit',
        'Pacific/Easter' => 'Ouschterinsel-Zäit',
        'Pacific/Efate' => 'Vanuatu-Zäit (Efate)',
        'Pacific/Enderbury' => 'Phoenixinselen-Zäit (Canton)',
        'Pacific/Kanton' => 'Phoenixinselen-Zäit (Canton)',
        'Pacific/Fakaofo' => 'Tokelau-Zäit (Fakaofo)',
        'Pacific/Fiji' => 'Fidschi-Zäit',
        'Pacific/Funafuti' => 'Tuvalu-Zäit (Funafuti)',
        'Pacific/Galapagos' => 'Galapagos-Zäit (Galápagos)',
        'Pacific/Gambier' => 'Gambier-Zäit',
        'Pacific/Guadalcanal' => 'Salomoninselen-Zäit (Guadalcanal)',
        'Pacific/Guam' => 'Chamorro-Zäit (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleuten-Normalzäit (Honolulu)',
        'Pacific/Kiritimati' => 'Linneninselen-Zäit (Kiritimati)',
        'Pacific/Kosrae' => 'Kosrae-Zäit',
        'Pacific/Kwajalein' => 'Marshallinselen-Zäit (Kwajalein)',
        'Pacific/Majuro' => 'Marshallinselen-Zäit (Majuro)',
        'Pacific/Marquesas' => 'Marquesas-Zäit',
        'Pacific/Midway' => 'Samoa-Zäit (Midway)',
        'Pacific/Nauru' => 'Nauru-Zäit',
        'Pacific/Niue' => 'Niue-Zäit',
        'Pacific/Norfolk' => 'Norfolkinselen-Zäit',
        'Pacific/Noumea' => 'Neikaledonesch Zäit (Nouméa)',
        'Pacific/Pago_Pago' => 'Samoa-Zäit (Pago Pago)',
        'Pacific/Palau' => 'Palau-Zäit',
        'Pacific/Pitcairn' => 'Pitcairninselen-Zäit',
        'Pacific/Ponape' => 'Ponape-Zäit (Pohnpei)',
        'Pacific/Pohnpei' => 'Ponape-Zäit (Pohnpei)',
        'Pacific/Port_Moresby' => 'Papua-Neiguinea-Zäit (Port Moresby)',
        'Pacific/Rarotonga' => 'Cookinselen-Zäit (Rarotonga)',
        'Pacific/Saipan' => 'Chamorro-Zäit (Saipan)',
        'Pacific/Tahiti' => 'Tahiti-Zäit',
        'Pacific/Tarawa' => 'Gilbert-Inselen-Zäit (Tarawa)',
        'Pacific/Tongatapu' => 'Tonganesch Zäit (Tongatapu)',
        'Pacific/Truk' => 'Chuuk-Zäit',
        'Pacific/Chuuk' => 'Chuuk-Zäit',
        'Pacific/Wake' => 'Wake-Insel-Zäit',
        'Pacific/Wallis' => 'Wallis-a-Futuna-Zäit (Wallis & Futuna)',
    ],
    'Meta' => [],
];
