<?php

return [
    'Names' => [
        'aa' => 'afar dili',
        'ab' => 'abhaz dili',
        'ace' => 'açeh dili',
        'ada' => 'adangme dili',
        'ady' => 'adygeý dili',
        'af' => 'afrikaans dili',
        'agq' => 'ahem dili',
        'ain' => 'aýn dili',
        'ak' => 'akan dili',
        'ale' => 'aleut dili',
        'alt' => 'günorta Altaý dili',
        'am' => 'amhar dili',
        'an' => 'aragon dili',
        'ann' => 'obolo dili',
        'anp' => 'angika dili',
        'ar' => 'arap dili',
        'arn' => 'mapuçe dili',
        'arp' => 'arapaho dili',
        'ars' => 'nejdi arap dili',
        'as' => 'assam dili',
        'asa' => 'asu dili',
        'ast' => 'asturiý dili',
        'atj' => 'atikamekw dili',
        'av' => 'awar dili',
        'awa' => 'awadhi dili',
        'ay' => 'aýmara dili',
        'az' => 'azerbaýjan dili',
        'ba' => 'başgyrt dili',
        'bal' => 'buluç dili',
        'ban' => 'baliý dili',
        'bas' => 'basaa dili',
        'be' => 'belarus dili',
        'bem' => 'bemba dili',
        'bez' => 'bena dili',
        'bg' => 'bolgar dili',
        'bgc' => 'harýanwi dili',
        'bho' => 'bhojpuri dili',
        'bi' => 'bislama dili',
        'bin' => 'bini dili',
        'bla' => 'siksika dili',
        'blo' => 'blo dili',
        'bm' => 'bamana',
        'bn' => 'bengal dili',
        'bo' => 'tibet dili',
        'br' => 'breton dili',
        'brx' => 'bodo dili',
        'bs' => 'bosniýa dili',
        'bug' => 'bugiý dili',
        'byn' => 'blin dili',
        'ca' => 'katalan dili',
        'cay' => 'kaýuga dili',
        'ccp' => 'çakma dili',
        'ce' => 'çeçen dili',
        'ceb' => 'sebuan dili',
        'cgg' => 'kiga',
        'ch' => 'çamorro',
        'chk' => 'çuuk dili',
        'chm' => 'mariý dili',
        'cho' => 'çokto',
        'chp' => 'çipewýan dili',
        'chr' => 'çeroki',
        'chy' => 'şaýenn dili',
        'ckb' => 'merkezi kürt dili',
        'clc' => 'çilkotin dili',
        'co' => 'korsikan dili',
        'crg' => 'miçif dili',
        'crj' => 'günorta-gündogar kri dili',
        'crk' => 'düzdeçi kri dili',
        'crl' => 'demirgazyk-gündogar kri dili',
        'crm' => 'los-kri dili',
        'crr' => 'karolina algonkin dili',
        'crs' => 'seselwa kreole-fransuz dili',
        'cs' => 'çeh dili',
        'csw' => 'batgalyk kri dili',
        'cu' => 'buthana slaw dili',
        'cv' => 'çuwaş dili',
        'cy' => 'walliý dili',
        'da' => 'daniýa dili',
        'dak' => 'dakota dili',
        'dar' => 'dargi dili',
        'dav' => 'taita dili',
        'de' => 'nemes dili',
        'dgr' => 'dogrib dili',
        'dje' => 'zarma dili',
        'doi' => 'dogri',
        'dsb' => 'aşaky lužits dili',
        'dua' => 'duala dili',
        'dv' => 'diwehi dili',
        'dyo' => 'ýola-fonýi dili',
        'dz' => 'dzong-ke dili',
        'dzg' => 'daza dili',
        'ebu' => 'embu dili',
        'ee' => 'ewe dili',
        'efi' => 'efik dili',
        'eka' => 'ekajuk dili',
        'el' => 'grek dili',
        'en' => 'iňlis dili',
        'eo' => 'esperanto dili',
        'es' => 'ispan dili',
        'et' => 'eston dili',
        'eu' => 'bask dili',
        'ewo' => 'ewondo dili',
        'fa' => 'pars dili',
        'ff' => 'fula dili',
        'fi' => 'fin dili',
        'fil' => 'filippin dili',
        'fj' => 'fiji dili',
        'fo' => 'farer dili',
        'fon' => 'fon dili',
        'fr' => 'fransuz dili',
        'frc' => 'fransuz diliniň kajun şiwesi',
        'frr' => 'demirgazyk friz dili',
        'fur' => 'friul dili',
        'fy' => 'günbatar friz dili',
        'ga' => 'irland dili',
        'gaa' => 'ga dili',
        'gd' => 'şotland kelt dili',
        'gez' => 'geez dili',
        'gil' => 'gilbert dili',
        'gl' => 'galisiý dili',
        'gn' => 'guarani dili',
        'gor' => 'gorontalo dili',
        'gsw' => 'nemes dili (Şweýsariýa)',
        'gu' => 'gujarati dili',
        'guz' => 'gusii dili',
        'gv' => 'men dili',
        'gwi' => 'gwiçin dili',
        'ha' => 'hausa dili',
        'hai' => 'haýda dili',
        'haw' => 'gawaý dili',
        'hax' => 'günorta haýda dili',
        'he' => 'ýewreý dili',
        'hi' => 'hindi dili',
        'hil' => 'hiligaýnon dili',
        'hmn' => 'hmong dili',
        'hr' => 'horwat dili',
        'hsb' => 'ýokarky lužits dili',
        'ht' => 'gaiti kreol dili',
        'hu' => 'wenger dili',
        'hup' => 'hupa',
        'hur' => 'halkomelem dili',
        'hy' => 'ermeni dili',
        'hz' => 'gerero dili',
        'ia' => 'interlingwa dili',
        'iba' => 'iban dili',
        'ibb' => 'ibibio dili',
        'id' => 'indonez dili',
        'ie' => 'interlingwe dili',
        'ig' => 'igbo dili',
        'ii' => 'syçuan-i dili',
        'ikt' => 'Günorta Kanada iniktitut dili',
        'ilo' => 'iloko dili',
        'inh' => 'inguş dili',
        'io' => 'ido dili',
        'is' => 'island dili',
        'it' => 'italýan dili',
        'iu' => 'inuktitut dili',
        'ja' => 'ýapon dili',
        'jbo' => 'lojban dili',
        'jgo' => 'ngomba dili',
        'jmc' => 'maçame dili',
        'jv' => 'ýawa dili',
        'ka' => 'gruzin dili',
        'kab' => 'kabil dili',
        'kac' => 'kaçin dili',
        'kaj' => 'ju dili',
        'kam' => 'kamba dili',
        'kbd' => 'kabardin dili',
        'kcg' => 'tiap dili',
        'kde' => 'makonde dili',
        'kea' => 'kabuwerdianu dili',
        'kfo' => 'koro dili',
        'kgp' => 'kaýngang dili',
        'kha' => 'khasi dili',
        'khq' => 'koýra-çini dili',
        'ki' => 'kikuýu dili',
        'kj' => 'kwanýama dili',
        'kk' => 'gazak dili',
        'kkj' => 'kako dili',
        'kl' => 'grenland dili',
        'kln' => 'kalenjin dili',
        'km' => 'khmer dili',
        'kmb' => 'kimbundu dili',
        'kn' => 'kannada dili',
        'ko' => 'koreý dili',
        'kok' => 'konkani dili',
        'kpe' => 'kpelle dili',
        'kr' => 'kanuri',
        'krc' => 'karaçaý-balkar dili',
        'krl' => 'karel dili',
        'kru' => 'kuruh dili',
        'ks' => 'kaşmiri dili',
        'ksb' => 'şambala dili',
        'ksf' => 'bafia dili',
        'ksh' => 'keln dili',
        'ku' => 'kürt dili',
        'kum' => 'kumyk dili',
        'kv' => 'komi dili',
        'kw' => 'korn dili',
        'kwk' => 'kwakwala dili',
        'kxv' => 'kuwi dili',
        'ky' => 'gyrgyz dili',
        'la' => 'latyn dili',
        'lad' => 'ladino dili',
        'lag' => 'langi dili',
        'lb' => 'lýuksemburg dili',
        'lez' => 'lezgin dili',
        'lg' => 'ganda dili',
        'li' => 'limburg dili',
        'lij' => 'ligur dili',
        'lil' => 'lilluet dili',
        'lkt' => 'lakota dili',
        'lmo' => 'lombard dili',
        'ln' => 'lingala dili',
        'lo' => 'laos dili',
        'lou' => 'Luiziana kreol dili',
        'loz' => 'lozi dili',
        'lrc' => 'demirgazyk luri dili',
        'lsm' => 'samiýa dili',
        'lt' => 'litwa dili',
        'lu' => 'luba-katanga dili',
        'lua' => 'luba-Lulua dili',
        'lun' => 'lunda dili',
        'luo' => 'luo dili',
        'lus' => 'mizo dili',
        'luy' => 'luýýa dili',
        'lv' => 'latyş dili',
        'mad' => 'madur dili',
        'mag' => 'magahi dili',
        'mai' => 'maýthili dili',
        'mak' => 'makasar dili',
        'mas' => 'masai dili',
        'mdf' => 'mokşa dili',
        'men' => 'mende dili',
        'mer' => 'meru dili',
        'mfe' => 'morisýen dili',
        'mg' => 'malagasiý dili',
        'mgh' => 'makuwa-mito dili',
        'mgo' => 'meta dili',
        'mh' => 'marşall dili',
        'mi' => 'maori dili',
        'mic' => 'mikmak dili',
        'min' => 'minangkabau dili',
        'mk' => 'makedon dili',
        'ml' => 'malaýalam dili',
        'mn' => 'mongol dili',
        'mni' => 'manipuri dili',
        'moe' => 'innu-aýmun dili',
        'moh' => 'mogauk dili',
        'mos' => 'mossi dili',
        'mr' => 'marathi dili',
        'ms' => 'malaý dili',
        'mt' => 'malta dili',
        'mua' => 'mundang dili',
        'mus' => 'krik dili',
        'mwl' => 'mirand dili',
        'my' => 'birma dili',
        'myv' => 'erzýan dili',
        'mzn' => 'mazanderan dili',
        'na' => 'nauru dili',
        'nap' => 'neapolitan dili',
        'naq' => 'nama dili',
        'nb' => 'norwegiýa bukmol dili',
        'nd' => 'demirgazyk ndebele dili',
        'nds' => 'aşaky nemes dili',
        'ne' => 'nepal dili',
        'new' => 'newari dili',
        'ng' => 'ndonga dili',
        'nia' => 'nias dili',
        'niu' => 'niue dili',
        'nl' => 'niderland dili',
        'nmg' => 'kwasio dili',
        'nn' => 'norwegiýa nýunorsk dili',
        'nnh' => 'ngembun dili',
        'no' => 'norweg dili',
        'nog' => 'nogaý dili',
        'nqo' => 'nko dili',
        'nr' => 'günorta ndebele dili',
        'nso' => 'demirgazyk soto dili',
        'nus' => 'nuer dili',
        'nv' => 'nawaho dili',
        'ny' => 'nýanja dili',
        'nyn' => 'nýankole dili',
        'oc' => 'oksitan dili',
        'ojb' => 'demirgazyk-günbatar ojibwa dili',
        'ojc' => 'merkezi ojibwa dili',
        'ojs' => 'oji-kri dili',
        'ojw' => 'günbatar ojibwa dili',
        'oka' => 'okanagan dili',
        'om' => 'oromo dili',
        'or' => 'oriýa dili',
        'os' => 'osetin dili',
        'pa' => 'penjab dili',
        'pag' => 'pangansinan dili',
        'pam' => 'kapampangan dili',
        'pap' => 'papýamento dili',
        'pau' => 'palau dili',
        'pcm' => 'nigeriýa-pijin dili',
        'pis' => 'pijin dili',
        'pl' => 'polýak dili',
        'pqm' => 'malisit-passamakwodi dili',
        'prg' => 'prus dili',
        'ps' => 'puştu dili',
        'pt' => 'portugal dili',
        'qu' => 'keçua dili',
        'quc' => 'kiçe dili',
        'raj' => 'rajastani dili',
        'rap' => 'rapanuý dili',
        'rar' => 'kuk dili',
        'rhg' => 'rohinýa dili',
        'rm' => 'retoroman dili',
        'rn' => 'rundi dili',
        'ro' => 'rumyn dili',
        'rof' => 'rombo dili',
        'ru' => 'rus dili',
        'rup' => 'arumyn dili',
        'rw' => 'kinýaruanda dili',
        'rwk' => 'rwa dili',
        'sa' => 'sanskrit dili',
        'sad' => 'sandawe dili',
        'sah' => 'ýakut dili',
        'saq' => 'samburu dili',
        'sat' => 'santali dili',
        'sba' => 'ngambaý dili',
        'sbp' => 'sangu dili',
        'sc' => 'sardin dili',
        'scn' => 'sisiliýa dili',
        'sco' => 'şotland dili',
        'sd' => 'sindhi dili',
        'se' => 'demirgazyk saam dili',
        'seh' => 'sena dili',
        'ses' => 'koýraboro-senni dili',
        'sg' => 'sango dili',
        'shi' => 'tahelhit dili',
        'shn' => 'şan dili',
        'si' => 'singal dili',
        'sk' => 'slowak dili',
        'sl' => 'slowen dili',
        'slh' => 'günorta Luşutsid dili',
        'sm' => 'samoa dili',
        'sma' => 'günorta saam dili',
        'smj' => 'lule-saam dili',
        'smn' => 'inari-saam dili',
        'sms' => 'skolt-saam dili',
        'sn' => 'şona dili',
        'snk' => 'soninke dili',
        'so' => 'somali dili',
        'sq' => 'alban dili',
        'sr' => 'serb dili',
        'srn' => 'sranan-tongo dili',
        'ss' => 'swati dili',
        'ssy' => 'saho dili',
        'st' => 'günorta soto dili',
        'str' => 'demirgazyk bogaz saliş dili',
        'su' => 'sundan dili',
        'suk' => 'sukuma dili',
        'sv' => 'şwed dili',
        'sw' => 'suahili dili',
        'swb' => 'komor dili',
        'syr' => 'siriýa dili',
        'szl' => 'silez dili',
        'ta' => 'tamil dili',
        'tce' => 'günorta tutçone dili',
        'te' => 'telugu dili',
        'tem' => 'temne dili',
        'teo' => 'teso dili',
        'tet' => 'tetum dili',
        'tg' => 'täjik dili',
        'tgx' => 'tagiş dili',
        'th' => 'taý dili',
        'tht' => 'taltan dili',
        'ti' => 'tigrinýa dili',
        'tig' => 'tigre dili',
        'tk' => 'türkmen dili',
        'tlh' => 'klingon dili',
        'tli' => 'tlinkit dili',
        'tn' => 'tswana dili',
        'to' => 'tongan dili',
        'tok' => 'toki pona dili',
        'tpi' => 'tok-pisin dili',
        'tr' => 'türk dili',
        'trv' => 'taroko dili',
        'ts' => 'tsonga dili',
        'tt' => 'tatar dili',
        'ttm' => 'demirgazyk tutçone dili',
        'tum' => 'tumbuka dili',
        'tvl' => 'tuwalu dili',
        'twq' => 'tasawak dili',
        'ty' => 'taiti dili',
        'tyv' => 'tuwa dili',
        'tzm' => 'orta-atlas tamazight dili',
        'udm' => 'udmurt dili',
        'ug' => 'uýgur dili',
        'uk' => 'ukrain dili',
        'umb' => 'umbundu dili',
        'ur' => 'urdu',
        'uz' => 'özbek dili',
        'vai' => 'wai dili',
        've' => 'wenda dili',
        'vec' => 'wenesian dili',
        'vi' => 'wýetnam dili',
        'vmw' => 'mahuwa dili',
        'vo' => 'wolapýuk dili',
        'vun' => 'wunýo dili',
        'wa' => 'wallon dili',
        'wae' => 'walzer dili',
        'wal' => 'wolaýta dili',
        'war' => 'waraý dili',
        'wo' => 'wolof dili',
        'wuu' => 'u hytaý dili',
        'xal' => 'galmyk dili',
        'xh' => 'kosa dili',
        'xnr' => 'kangri dili',
        'xog' => 'soga dili',
        'yav' => 'ýangben dili',
        'ybb' => 'ýemba dili',
        'yi' => 'idiş dili',
        'yo' => 'ýoruba dili',
        'yrl' => 'nhengatu dili',
        'yue' => 'kanton dili',
        'za' => 'çžuan dili',
        'zgh' => 'standart Marokko tamazight dili',
        'zh' => 'hytaý dili',
        'zu' => 'zulu dili',
        'zun' => 'zuni dili',
        'zza' => 'zazaki dili',
    ],
    'LocalizedNames' => [
        'ar_001' => 'häzirki zaman standart arap dili',
        'de_CH' => 'ýokarky nemes dili (Şweýsariýa)',
        'en_GB' => 'iňlis dili (Beýik Britaniýa)',
        'en_US' => 'iňlis dili (Amerika)',
        'es_ES' => 'ispan dili (Ýewropa)',
        'fa_AF' => 'dari dili',
        'nl_BE' => 'flamand dili',
        'pt_PT' => 'portugal dili (Ýewropa)',
        'ro_MD' => 'moldaw dili',
        'sw_CD' => 'kongo suahili dili',
        'zh_Hans' => 'ýönekeýleşdirilen hytaý dili',
        'zh_Hant' => 'adaty hytaý dili',
    ],
];
