<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Ora e Grinuiçit (Abixhan)',
        'Africa/Accra' => 'Ora e Grinuiçit (Akra)',
        'Africa/Addis_Ababa' => 'Ora e Afrikës Lindore (Adis-Ababë)',
        'Africa/Algiers' => 'Ora e Evropës Qendrore (Algjer)',
        'Africa/Asmera' => 'Ora e Afrikës Lindore (Asmarë)',
        'Africa/Asmara' => 'Ora e Afrikës Lindore (Asmarë)',
        'Africa/Bamako' => 'Ora e Grinuiçit (Bamako)',
        'Africa/Bangui' => 'Ora e Afrikës Perëndimore (Bangui)',
        'Africa/Banjul' => 'Ora e Grinuiçit (Banxhul)',
        'Africa/Bissau' => 'Ora e Grinuiçit (Bisau)',
        'Africa/Blantyre' => 'Ora e Afrikës Qendrore (Blantirë)',
        'Africa/Brazzaville' => 'Ora e Afrikës Perëndimore (Brazavillë)',
        'Africa/Bujumbura' => 'Ora e Afrikës Qendrore (Buxhumburë)',
        'Africa/Cairo' => 'Ora e Evropës Lindore (Kajro)',
        'Africa/Casablanca' => 'Ora e Evropës Perëndimore (Kazablankë)',
        'Africa/Ceuta' => 'Ora e Evropës Qendrore (Theuta)',
        'Africa/Conakry' => 'Ora e Grinuiçit (Konakri)',
        'Africa/Dakar' => 'Ora e Grinuiçit (Dakar)',
        'Africa/Dar_es_Salaam' => 'Ora e Afrikës Lindore (Dar-es-Salam)',
        'Africa/Djibouti' => 'Ora e Afrikës Lindore (Xhibuti)',
        'Africa/Douala' => 'Ora e Afrikës Perëndimore (Douala)',
        'Africa/El_Aaiun' => 'Ora e Evropës Perëndimore (El Ajun)',
        'Africa/Freetown' => 'Ora e Grinuiçit (Fritaun)',
        'Africa/Gaborone' => 'Ora e Afrikës Qendrore (Gaborone)',
        'Africa/Harare' => 'Ora e Afrikës Qendrore (Harare)',
        'Africa/Johannesburg' => 'Ora standarde e Afrikës Jugore (Johanesburg)',
        'Africa/Juba' => 'Ora e Afrikës Qendrore (Xhuba)',
        'Africa/Kampala' => 'Ora e Afrikës Lindore (Kampala)',
        'Africa/Khartoum' => 'Ora e Afrikës Qendrore (Kartum)',
        'Africa/Kigali' => 'Ora e Afrikës Qendrore (Kigali)',
        'Africa/Kinshasa' => 'Ora e Afrikës Perëndimore (Kinshasa)',
        'Africa/Lagos' => 'Ora e Afrikës Perëndimore (Lagos)',
        'Africa/Libreville' => 'Ora e Afrikës Perëndimore (Librevilë)',
        'Africa/Lome' => 'Ora e Grinuiçit (Lomé)',
        'Africa/Luanda' => 'Ora e Afrikës Perëndimore (Luanda)',
        'Africa/Lubumbashi' => 'Ora e Afrikës Qendrore (Lubumbashi)',
        'Africa/Lusaka' => 'Ora e Afrikës Qendrore (Lusaka)',
        'Africa/Malabo' => 'Ora e Afrikës Perëndimore (Malabo)',
        'Africa/Maputo' => 'Ora e Afrikës Qendrore (Maputo)',
        'Africa/Maseru' => 'Ora standarde e Afrikës Jugore (Maseru)',
        'Africa/Mbabane' => 'Ora standarde e Afrikës Jugore (Mbabane)',
        'Africa/Mogadishu' => 'Ora e Afrikës Lindore (Mogadishu)',
        'Africa/Monrovia' => 'Ora e Grinuiçit (Monrovia)',
        'Africa/Nairobi' => 'Ora e Afrikës Lindore (Nairobi)',
        'Africa/Ndjamena' => 'Ora e Afrikës Perëndimore (N’Djamena)',
        'Africa/Niamey' => 'Ora e Afrikës Perëndimore (Niamej)',
        'Africa/Nouakchott' => 'Ora e Grinuiçit (Nouakot)',
        'Africa/Ouagadougou' => 'Ora e Grinuiçit (Uagëdugu)',
        'Africa/Porto-Novo' => 'Ora e Afrikës Perëndimore (Porto-Novo)',
        'Africa/Sao_Tome' => 'Ora e Grinuiçit (Sao-Tome)',
        'Africa/Tripoli' => 'Ora e Evropës Lindore (Tripoli)',
        'Africa/Tunis' => 'Ora e Evropës Qendrore (Tuniz)',
        'Africa/Windhoek' => 'Ora e Afrikës Qendrore (Vint’huk)',
        'America/Adak' => 'Ora e Ishujve Hauai-Aleutian (Adak)',
        'America/Anchorage' => 'Ora e Alaskës (Ankorejxh)',
        'America/Anguilla' => 'Ora e Atlantikut (Anguilë)',
        'America/Antigua' => 'Ora e Atlantikut (Antigua)',
        'America/Araguaina' => 'Ora e Brazilisë (Araguajana)',
        'America/Argentina/La_Rioja' => 'Ora e Argjentinës (La Rioha)',
        'America/Argentina/Rio_Gallegos' => 'Ora e Argjentinës (Rio-Galegos)',
        'America/Argentina/Salta' => 'Ora e Argjentinës (Saltë)',
        'America/Argentina/San_Juan' => 'Ora e Argjentinës (San-Huan)',
        'America/Argentina/San_Luis' => 'Ora e Argjentinës (Shën-Luis)',
        'America/Argentina/Tucuman' => 'Ora e Argjentinës (Tukuman)',
        'America/Argentina/Ushuaia' => 'Ora e Argjentinës (Ushuaja)',
        'America/Aruba' => 'Ora e Atlantikut (Arubë)',
        'America/Asuncion' => 'Ora e Paraguait (Asunsion)',
        'America/Bahia' => 'Ora e Brazilisë (Bahia)',
        'America/Bahia_Banderas' => 'Ora e SHBA-së Qendrore (Bahia-Banderas)',
        'America/Barbados' => 'Ora e Atlantikut (Barbados)',
        'America/Belem' => 'Ora e Brazilisë (Belém)',
        'America/Belize' => 'Ora e SHBA-së Qendrore (Belizë)',
        'America/Blanc-Sablon' => 'Ora e Atlantikut (Blank-Sablon)',
        'America/Boa_Vista' => 'Ora e Amazonës (Boa-Vista)',
        'America/Bogota' => 'Ora e Kolumbisë (Bogotë)',
        'America/Boise' => 'Ora e Territoreve Amerikane të Brezit Malor (Boizë)',
        'America/Buenos_Aires' => 'Ora e Argjentinës (Buenos-Ajres)',
        'America/Argentina/Buenos_Aires' => 'Ora e Argjentinës (Buenos-Ajres)',
        'America/Cambridge_Bay' => 'Ora e Territoreve Amerikane të Brezit Malor (Gjiri i Kembrixhit)',
        'America/Campo_Grande' => 'Ora e Amazonës (Kampo-Grande)',
        'America/Cancun' => 'Ora e SHBA-së Lindore (Kankun)',
        'America/Caracas' => 'Ora e Venezuelës (Karakas)',
        'America/Catamarca' => 'Ora e Argjentinës (Katamarka)',
        'America/Argentina/Catamarca' => 'Ora e Argjentinës (Katamarka)',
        'America/Cayenne' => 'Ora e Guajanës Franceze (Kajenë)',
        'America/Cayman' => 'Ora e SHBA-së Lindore (Kajman)',
        'America/Chicago' => 'Ora e SHBA-së Qendrore (Çikago)',
        'America/Chihuahua' => 'Ora e SHBA-së Qendrore (Çihahua)',
        'America/Ciudad_Juarez' => 'Ora e Territoreve Amerikane të Brezit Malor (Siudad-Huarez)',
        'America/Coral_Harbour' => 'Ora e SHBA-së Lindore (Atikokan)',
        'America/Atikokan' => 'Ora e SHBA-së Lindore (Atikokan)',
        'America/Cordoba' => 'Ora e Argjentinës (Kordoba)',
        'America/Argentina/Cordoba' => 'Ora e Argjentinës (Kordoba)',
        'America/Costa_Rica' => 'Ora e SHBA-së Qendrore (Kosta-Rikë)',
        'America/Coyhaique' => 'Ora e Kilit (Koihaiku)',
        'America/Creston' => 'Ora e Territoreve Amerikane të Brezit Malor (Kreston)',
        'America/Cuiaba' => 'Ora e Amazonës (Kujaba)',
        'America/Curacao' => 'Ora e Atlantikut (Kurasao)',
        'America/Danmarkshavn' => 'Ora e Grinuiçit (Denmarkshavën)',
        'America/Dawson' => 'Ora e Jukonit (Douson)',
        'America/Dawson_Creek' => 'Ora e Territoreve Amerikane të Brezit Malor (Gjiri i Dousonit)',
        'America/Denver' => 'Ora e Territoreve Amerikane të Brezit Malor (Denver)',
        'America/Detroit' => 'Ora e SHBA-së Lindore (Detroit)',
        'America/Dominica' => 'Ora e Atlantikut (Dominikë)',
        'America/Edmonton' => 'Ora e Territoreve Amerikane të Brezit Malor (Edmonton)',
        'America/Eirunepe' => 'Ora e Ejkrit [Ako] (Ejrunep)',
        'America/El_Salvador' => 'Ora e SHBA-së Qendrore (Salvador)',
        'America/Fort_Nelson' => 'Ora e Territoreve Amerikane të Brezit Malor (Fort-Nelson)',
        'America/Fortaleza' => 'Ora e Brazilisë (Fortaleza)',
        'America/Glace_Bay' => 'Ora e Atlantikut (Gjiri i Ngrirë)',
        'America/Godthab' => 'Ora: Grënlandë (Njuk)',
        'America/Nuuk' => 'Ora: Grënlandë (Njuk)',
        'America/Goose_Bay' => 'Ora e Atlantikut (Gjiri i Patës)',
        'America/Grand_Turk' => 'Ora e SHBA-së Lindore (Turku i Madh)',
        'America/Grenada' => 'Ora e Atlantikut (Granadë)',
        'America/Guadeloupe' => 'Ora e Atlantikut (Guadelupë)',
        'America/Guatemala' => 'Ora e SHBA-së Qendrore (Guatemalë)',
        'America/Guayaquil' => 'Ora e Ekuadorit (Guajakuil)',
        'America/Guyana' => 'Ora e Guajanës',
        'America/Halifax' => 'Ora e Atlantikut (Halifaks)',
        'America/Havana' => 'Ora e Kubës (Havanë)',
        'America/Hermosillo' => 'Ora e Territoreve Meksikane të Bregut të Paqësorit (Hermosijo)',
        'America/Indiana/Knox' => 'Ora e SHBA-së Qendrore (Knoks, Indiana)',
        'America/Indiana/Marengo' => 'Ora e SHBA-së Lindore (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Ora e SHBA-së Lindore (Petërsburg, Indiana)',
        'America/Indiana/Tell_City' => 'Ora e SHBA-së Qendrore (Tell-Siti, Indiana)',
        'America/Indiana/Vevay' => 'Ora e SHBA-së Lindore (Vevëj, Indiana)',
        'America/Indiana/Vincennes' => 'Ora e SHBA-së Lindore (Vincenes, Indiana)',
        'America/Indiana/Winamac' => 'Ora e SHBA-së Lindore (Uinamak, Indiana)',
        'America/Indianapolis' => 'Ora e SHBA-së Lindore (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Ora e SHBA-së Lindore (Indianapolis)',
        'America/Inuvik' => 'Ora e Territoreve Amerikane të Brezit Malor (Inuvik)',
        'America/Iqaluit' => 'Ora e SHBA-së Lindore (Ikaluit)',
        'America/Jamaica' => 'Ora e SHBA-së Lindore (Xhamajkë)',
        'America/Jujuy' => 'Ora e Argjentinës (Huhui)',
        'America/Argentina/Jujuy' => 'Ora e Argjentinës (Huhui)',
        'America/Juneau' => 'Ora e Alaskës (Xhunou)',
        'America/Kentucky/Monticello' => 'Ora e SHBA-së Lindore (Montiçelo, Kentaki)',
        'America/Kralendijk' => 'Ora e Atlantikut (Kralendijk)',
        'America/La_Paz' => 'Ora e Bolivisë (La Paz)',
        'America/Lima' => 'Ora e Perusë (Limë)',
        'America/Los_Angeles' => 'Ora e Territoreve Amerikane të Bregut të Paqësorit (Los Anxhelos)',
        'America/Louisville' => 'Ora e SHBA-së Lindore (Luizvilë)',
        'America/Kentucky/Louisville' => 'Ora e SHBA-së Lindore (Luizvilë)',
        'America/Lower_Princes' => 'Ora e Atlantikut (Louer-Prinsis-Kuortër)',
        'America/Maceio' => 'Ora e Brazilisë (Makejo)',
        'America/Managua' => 'Ora e SHBA-së Qendrore (Managua)',
        'America/Manaus' => 'Ora e Amazonës (Manaus)',
        'America/Marigot' => 'Ora e Atlantikut (Marigot)',
        'America/Martinique' => 'Ora e Atlantikut (Martinikë)',
        'America/Matamoros' => 'Ora e SHBA-së Qendrore (Matamoros)',
        'America/Mazatlan' => 'Ora e Territoreve Meksikane të Bregut të Paqësorit (Mazatlán)',
        'America/Mendoza' => 'Ora e Argjentinës (Mendoza)',
        'America/Argentina/Mendoza' => 'Ora e Argjentinës (Mendoza)',
        'America/Menominee' => 'Ora e SHBA-së Qendrore (Menomini)',
        'America/Merida' => 'Ora e SHBA-së Qendrore (Merida)',
        'America/Metlakatla' => 'Ora e Alaskës (Metlakatla)',
        'America/Mexico_City' => 'Ora e SHBA-së Qendrore (Qyteti i Meksikës)',
        'America/Miquelon' => 'Ora e Shën-Pier dhe Mikelon',
        'America/Moncton' => 'Ora e Atlantikut (Monkton)',
        'America/Monterrey' => 'Ora e SHBA-së Qendrore (Monterrej)',
        'America/Montevideo' => 'Ora e Uruguait (Montevideo)',
        'America/Montserrat' => 'Ora e Atlantikut (Montserat)',
        'America/Nassau' => 'Ora e SHBA-së Lindore (Nasao)',
        'America/New_York' => 'Ora e SHBA-së Lindore (Nju-Jork)',
        'America/Nome' => 'Ora e Alaskës (Nome)',
        'America/Noronha' => 'Ora e Fernando-de-Noronjës (Noronja)',
        'America/North_Dakota/Beulah' => 'Ora e SHBA-së Qendrore (Beula, Dakota e Veriut)',
        'America/North_Dakota/Center' => 'Ora e SHBA-së Qendrore (Qendër, Dakota e Veriut)',
        'America/North_Dakota/New_Salem' => 'Ora e SHBA-së Qendrore (Nju-Salem, Dakota e Veriut)',
        'America/Ojinaga' => 'Ora e SHBA-së Qendrore (Ohinaga)',
        'America/Panama' => 'Ora e SHBA-së Lindore (Panama)',
        'America/Paramaribo' => 'Ora e Surinamit (Paramaribo)',
        'America/Phoenix' => 'Ora e Territoreve Amerikane të Brezit Malor (Feniks)',
        'America/Port-au-Prince' => 'Ora e SHBA-së Lindore (Port-o-Prins)',
        'America/Port_of_Spain' => 'Ora e Atlantikut (Port of Spain)',
        'America/Porto_Velho' => 'Ora e Amazonës (Porto-Velho)',
        'America/Puerto_Rico' => 'Ora e Atlantikut (Porto-Riko)',
        'America/Punta_Arenas' => 'Ora e Kilit (Punta-Arenas)',
        'America/Rankin_Inlet' => 'Ora e SHBA-së Qendrore (Gryka Inlet)',
        'America/Recife' => 'Ora e Brazilisë (Recife)',
        'America/Regina' => 'Ora e SHBA-së Qendrore (Rexhina)',
        'America/Resolute' => 'Ora e SHBA-së Qendrore (Resolute)',
        'America/Rio_Branco' => 'Ora e Ejkrit [Ako] (Rio-Branko)',
        'America/Santarem' => 'Ora e Brazilisë (Santarém)',
        'America/Santiago' => 'Ora e Kilit (Santiago)',
        'America/Santo_Domingo' => 'Ora e Atlantikut (Santo-Domingo)',
        'America/Sao_Paulo' => 'Ora e Brazilisë (Sao-Paulo)',
        'America/Scoresbysund' => 'Ora: Grënlandë (Itokorturmit)',
        'America/Sitka' => 'Ora e Alaskës (Sitka)',
        'America/St_Barthelemy' => 'Ora e Atlantikut (Sen-Bartelemi)',
        'America/St_Johns' => 'Ora e Njufaundlendit [Tokës së Re] (Shën-Gjon)',
        'America/St_Kitts' => 'Ora e Atlantikut (Shën-Kits)',
        'America/St_Lucia' => 'Ora e Atlantikut (Shën-Luçia)',
        'America/St_Thomas' => 'Ora e Atlantikut (Shën-Tomas)',
        'America/St_Vincent' => 'Ora e Atlantikut (Shën-Vincent)',
        'America/Swift_Current' => 'Ora e SHBA-së Qendrore (Rryma e Shpejtë)',
        'America/Tegucigalpa' => 'Ora e SHBA-së Qendrore (Tegusigalpa)',
        'America/Thule' => 'Ora e Atlantikut (Dhule)',
        'America/Tijuana' => 'Ora e Territoreve Amerikane të Bregut të Paqësorit (Tihuana)',
        'America/Toronto' => 'Ora e SHBA-së Lindore (Toronto)',
        'America/Tortola' => 'Ora e Atlantikut (Tortolë)',
        'America/Vancouver' => 'Ora e Territoreve Amerikane të Bregut të Paqësorit (Vankuver)',
        'America/Whitehorse' => 'Ora e Jukonit (Uajt’hors)',
        'America/Winnipeg' => 'Ora e SHBA-së Qendrore (Uinipeg)',
        'America/Yakutat' => 'Ora e Alaskës (Jakutat)',
        'Antarctica/Casey' => 'Ora e Australisë Perëndimore (Kejsi)',
        'Antarctica/Davis' => 'Ora e Dejvisit',
        'Antarctica/DumontDUrville' => 'Ora e Dumont-d’Urvilës',
        'Antarctica/Macquarie' => 'Ora e Australisë Lindore (Mekuari)',
        'Antarctica/Mawson' => 'Ora e Mausonit',
        'Antarctica/McMurdo' => 'Ora e Zelandës së Re (Mekmurdo)',
        'Antarctica/Palmer' => 'Ora e Kilit (Palmer)',
        'Antarctica/Rothera' => 'Ora e Rodherës',
        'Antarctica/Syowa' => 'Ora e Sjouit (Sjoua)',
        'Antarctica/Troll' => 'Ora e Grinuiçit (Troll)',
        'Antarctica/Vostok' => 'Ora e Vostokut',
        'Arctic/Longyearbyen' => 'Ora e Evropës Qendrore (Long’jëbjen)',
        'Asia/Aden' => 'Ora arabe (Aden)',
        'Asia/Almaty' => 'Ora e Kazakistanit (Almati)',
        'Asia/Amman' => 'Ora e Evropës Lindore (Aman)',
        'Asia/Anadyr' => 'Ora e Petropavllovsk-Kamçatkës (Anadir)',
        'Asia/Aqtau' => 'Ora e Kazakistanit (Aktau)',
        'Asia/Aqtobe' => 'Ora e Kazakistanit (Aktobe)',
        'Asia/Ashgabat' => 'Ora e Turkmenistanit (Ashgabat)',
        'Asia/Atyrau' => 'Ora e Kazakistanit (Atirau)',
        'Asia/Baghdad' => 'Ora arabe (Bagdad)',
        'Asia/Bahrain' => 'Ora arabe (Bahrejn)',
        'Asia/Baku' => 'Ora e Azerbajxhanit (Baku)',
        'Asia/Bangkok' => 'Ora e Indokinës (Bangkok)',
        'Asia/Barnaul' => 'Ora e Krasnojarskut (Barnaul)',
        'Asia/Beirut' => 'Ora e Evropës Lindore (Bejrut)',
        'Asia/Bishkek' => 'Ora e Kirgizisë (Bishkek)',
        'Asia/Brunei' => 'Ora e Brunei-Durasalamit',
        'Asia/Calcutta' => 'Ora standarde e Indisë (Kalkutë)',
        'Asia/Kolkata' => 'Ora standarde e Indisë (Kalkutë)',
        'Asia/Chita' => 'Ora e Jakutskut (Çita)',
        'Asia/Colombo' => 'Ora standarde e Indisë (Kolombo)',
        'Asia/Damascus' => 'Ora e Evropës Lindore (Damask)',
        'Asia/Dhaka' => 'Ora e Bangladeshit (Daka)',
        'Asia/Dili' => 'Ora e Timorit Lindor (Dili)',
        'Asia/Dubai' => 'Ora e Gjirit (Dubai)',
        'Asia/Dushanbe' => 'Ora e Taxhikistanit (Dushanbe)',
        'Asia/Famagusta' => 'Ora e Evropës Lindore (Famagustë)',
        'Asia/Gaza' => 'Ora e Evropës Lindore (Gaza)',
        'Asia/Hebron' => 'Ora e Evropës Lindore (Hebron)',
        'Asia/Hong_Kong' => 'Ora e Hong-Kongut',
        'Asia/Hovd' => 'Ora e Hovdit (Khovd)',
        'Asia/Irkutsk' => 'Ora e Irkutskut',
        'Asia/Jakarta' => 'Ora e Indonezisë Perëndimore (Xhakartë)',
        'Asia/Jayapura' => 'Ora e Indonezisë Lindore (Xhajapurë)',
        'Asia/Jerusalem' => 'Ora e Izraelit (Jerusalem)',
        'Asia/Kabul' => 'Ora e Afganistanit (Kabul)',
        'Asia/Kamchatka' => 'Ora e Petropavllovsk-Kamçatkës',
        'Asia/Karachi' => 'Ora e Pakistanit (Karaçi)',
        'Asia/Katmandu' => 'Ora e Nepalit (Katmandu)',
        'Asia/Kathmandu' => 'Ora e Nepalit (Katmandu)',
        'Asia/Khandyga' => 'Ora e Jakutskut (Kandigë)',
        'Asia/Krasnoyarsk' => 'Ora e Krasnojarskut',
        'Asia/Kuala_Lumpur' => 'Ora e Malajzisë (Kuala-Lumpur)',
        'Asia/Kuching' => 'Ora e Malajzisë (Kuçing)',
        'Asia/Kuwait' => 'Ora arabe (Kuvajt)',
        'Asia/Macau' => 'Ora e Kinës (Makao)',
        'Asia/Magadan' => 'Ora e Magadanit',
        'Asia/Makassar' => 'Ora e Indonezisë Qendrore (Makasar)',
        'Asia/Manila' => 'Ora e Filipineve (Manilë)',
        'Asia/Muscat' => 'Ora e Gjirit (Muskat)',
        'Asia/Nicosia' => 'Ora e Evropës Lindore (Nikozia)',
        'Asia/Novokuznetsk' => 'Ora e Krasnojarskut (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Ora e Krasnojarskut (Novosibirsk)',
        'Asia/Omsk' => 'Ora e Omskut',
        'Asia/Oral' => 'Ora e Kazakistanit (Oral)',
        'Asia/Phnom_Penh' => 'Ora e Indokinës (Pnom-Pen)',
        'Asia/Pontianak' => 'Ora e Indonezisë Perëndimore (Pontianak)',
        'Asia/Pyongyang' => 'Ora koreane (Penian)',
        'Asia/Qatar' => 'Ora arabe (Katar)',
        'Asia/Qostanay' => 'Ora e Kazakistanit (Kostanaj)',
        'Asia/Qyzylorda' => 'Ora e Kazakistanit (Kizilorda)',
        'Asia/Rangoon' => 'Ora e Mianmarit (Rangun)',
        'Asia/Yangon' => 'Ora e Mianmarit (Rangun)',
        'Asia/Riyadh' => 'Ora arabe (Riad)',
        'Asia/Saigon' => 'Ora e Indokinës (Ho-Çi-Min)',
        'Asia/Ho_Chi_Minh' => 'Ora e Indokinës (Ho-Çi-Min)',
        'Asia/Sakhalin' => 'Ora e Magadanit (Sakalin)',
        'Asia/Samarkand' => 'Ora e Uzbekistanit (Samarkand)',
        'Asia/Seoul' => 'Ora koreane (Seul)',
        'Asia/Shanghai' => 'Ora e Kinës (Shangai)',
        'Asia/Singapore' => 'Ora e Singaporit',
        'Asia/Srednekolymsk' => 'Ora e Magadanit (Srednekolimsk)',
        'Asia/Taipei' => 'Ora e Tajpeit (Tajpej)',
        'Asia/Tashkent' => 'Ora e Uzbekistanit (Tashkent)',
        'Asia/Tbilisi' => 'Ora e Gjeorgjisë (Tbilis)',
        'Asia/Tehran' => 'Ora e Iranit (Teheran)',
        'Asia/Thimphu' => 'Ora e Butanit (Thimpu)',
        'Asia/Tokyo' => 'Ora e Japonisë (Tokio)',
        'Asia/Tomsk' => 'Ora e Krasnojarskut (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ora e Ulan-Batorit (Ulanbatar)',
        'Asia/Urumqi' => 'Ora: Kinë (Ürümqi)',
        'Asia/Ust-Nera' => 'Ora e Vladivostokut (Ust-Nera)',
        'Asia/Vientiane' => 'Ora e Indokinës (Vjentianë)',
        'Asia/Vladivostok' => 'Ora e Vladivostokut',
        'Asia/Yakutsk' => 'Ora e Jakutskut',
        'Asia/Yekaterinburg' => 'Ora e Ekaterinburgut',
        'Asia/Yerevan' => 'Ora e Armenisë (Jerevan)',
        'Atlantic/Azores' => 'Ora e Azoreve',
        'Atlantic/Bermuda' => 'Ora e Atlantikut (Bermude)',
        'Atlantic/Canary' => 'Ora e Evropës Perëndimore (Kanari)',
        'Atlantic/Cape_Verde' => 'Ora e Kepit të Gjelbër (Kepi i Gjelbër)',
        'Atlantic/Faeroe' => 'Ora e Evropës Perëndimore (Faroe)',
        'Atlantic/Faroe' => 'Ora e Evropës Perëndimore (Faroe)',
        'Atlantic/Madeira' => 'Ora e Evropës Perëndimore (Madeira)',
        'Atlantic/Reykjavik' => 'Ora e Grinuiçit (Reikjavik)',
        'Atlantic/South_Georgia' => 'Ora e Xhorxhas të Jugut (Xhorxha e Jugut)',
        'Atlantic/St_Helena' => 'Ora e Grinuiçit (Shën-Elenë)',
        'Atlantic/Stanley' => 'Ora e Ishujve Falkland (Stenli)',
        'Australia/Adelaide' => 'Ora e Australisë Qendrore (Adelajde)',
        'Australia/Brisbane' => 'Ora e Australisë Lindore (Brisbejn)',
        'Australia/Broken_Hill' => 'Ora e Australisë Qendrore (Brokën-Hill)',
        'Australia/Darwin' => 'Ora e Australisë Qendrore (Darvin)',
        'Australia/Eucla' => 'Ora e Australisë Qendroro-Perëndimore (Eukla)',
        'Australia/Hobart' => 'Ora e Australisë Lindore (Hobart)',
        'Australia/Lindeman' => 'Ora e Australisë Lindore (Lindëmen)',
        'Australia/Lord_Howe' => 'Ora e Lord-Houit',
        'Australia/Melbourne' => 'Ora e Australisë Lindore (Melburn)',
        'Australia/Perth' => 'Ora e Australisë Perëndimore (Përth)',
        'Australia/Sydney' => 'Ora e Australisë Lindore (Sidnej)',
        'Etc/GMT' => 'Ora e Grinuiçit',
        'Etc/UTC' => 'Ora universale e koordinuar',
        'Europe/Amsterdam' => 'Ora e Evropës Qendrore (Amsterdam)',
        'Europe/Andorra' => 'Ora e Evropës Qendrore (Andorrë)',
        'Europe/Astrakhan' => 'Ora e Samarës (Astrakan)',
        'Europe/Athens' => 'Ora e Evropës Lindore (Athinë)',
        'Europe/Belgrade' => 'Ora e Evropës Qendrore (Beograd)',
        'Europe/Berlin' => 'Ora e Evropës Qendrore (Berlin)',
        'Europe/Bratislava' => 'Ora e Evropës Qendrore (Bratislavë)',
        'Europe/Brussels' => 'Ora e Evropës Qendrore (Bruksel)',
        'Europe/Bucharest' => 'Ora e Evropës Lindore (Bukuresht)',
        'Europe/Budapest' => 'Ora e Evropës Qendrore (Budapest)',
        'Europe/Busingen' => 'Ora e Evropës Qendrore (Büsingen)',
        'Europe/Chisinau' => 'Ora e Evropës Lindore (Kishineu)',
        'Europe/Copenhagen' => 'Ora e Evropës Qendrore (Kopenhagen)',
        'Europe/Dublin' => 'Ora e Grinuiçit (Dublin)',
        'Europe/Gibraltar' => 'Ora e Evropës Qendrore (Gjibraltar)',
        'Europe/Guernsey' => 'Ora e Grinuiçit (Gernsej)',
        'Europe/Helsinki' => 'Ora e Evropës Lindore (Helsinki)',
        'Europe/Isle_of_Man' => 'Ora e Grinuiçit (Ishulli i Manit)',
        'Europe/Istanbul' => 'Ora: Turqi (Stamboll)',
        'Europe/Jersey' => 'Ora e Grinuiçit (Xhersej)',
        'Europe/Kaliningrad' => 'Ora e Evropës Lindore (Kaliningrad)',
        'Europe/Kiev' => 'Ora e Evropës Lindore (Kiev)',
        'Europe/Kyiv' => 'Ora e Evropës Lindore (Kiev)',
        'Europe/Kirov' => 'Ora e Moskës (Kirov)',
        'Europe/Lisbon' => 'Ora e Evropës Perëndimore (Lisbonë)',
        'Europe/Ljubljana' => 'Ora e Evropës Qendrore (Lubjanë)',
        'Europe/London' => 'Ora e Grinuiçit (Londër)',
        'Europe/Luxembourg' => 'Ora e Evropës Qendrore (Luksemburg)',
        'Europe/Madrid' => 'Ora e Evropës Qendrore (Madrid)',
        'Europe/Malta' => 'Ora e Evropës Qendrore (Maltë)',
        'Europe/Mariehamn' => 'Ora e Evropës Lindore (Mariehamn)',
        'Europe/Minsk' => 'Ora e Moskës (Minsk)',
        'Europe/Monaco' => 'Ora e Evropës Qendrore (Monako)',
        'Europe/Moscow' => 'Ora e Moskës',
        'Europe/Oslo' => 'Ora e Evropës Qendrore (Oslo)',
        'Europe/Paris' => 'Ora e Evropës Qendrore (Paris)',
        'Europe/Podgorica' => 'Ora e Evropës Qendrore (Podgoricë)',
        'Europe/Prague' => 'Ora e Evropës Qendrore (Pragë)',
        'Europe/Riga' => 'Ora e Evropës Lindore (Rigë)',
        'Europe/Rome' => 'Ora e Evropës Qendrore (Romë)',
        'Europe/Samara' => 'Ora e Samarës (Samara)',
        'Europe/San_Marino' => 'Ora e Evropës Qendrore (San-Marino)',
        'Europe/Sarajevo' => 'Ora e Evropës Qendrore (Sarajevë)',
        'Europe/Saratov' => 'Ora e Samarës (Saratov)',
        'Europe/Simferopol' => 'Ora e Moskës (Simferopol)',
        'Europe/Skopje' => 'Ora e Evropës Qendrore (Shkup)',
        'Europe/Sofia' => 'Ora e Evropës Lindore (Sofje)',
        'Europe/Stockholm' => 'Ora e Evropës Qendrore (Stokholm)',
        'Europe/Tallinn' => 'Ora e Evropës Lindore (Talin)',
        'Europe/Tirane' => 'Ora e Evropës Qendrore (Tiranë)',
        'Europe/Ulyanovsk' => 'Ora e Samarës (Uljanovsk)',
        'Europe/Vaduz' => 'Ora e Evropës Qendrore (Vaduz)',
        'Europe/Vatican' => 'Ora e Evropës Qendrore (Vatikan)',
        'Europe/Vienna' => 'Ora e Evropës Qendrore (Vjenë)',
        'Europe/Vilnius' => 'Ora e Evropës Lindore (Vilnius)',
        'Europe/Volgograd' => 'Ora e Moskës (Volgograd)',
        'Europe/Warsaw' => 'Ora e Evropës Qendrore (Varshavë)',
        'Europe/Zagreb' => 'Ora e Evropës Qendrore (Zagreb)',
        'Europe/Zurich' => 'Ora e Evropës Qendrore (Zyrih)',
        'Indian/Antananarivo' => 'Ora e Afrikës Lindore (Antananarivo)',
        'Indian/Chagos' => 'Ora e Oqeanit Indian (Çagos)',
        'Indian/Christmas' => 'Ora e Ishullit të Krishtlindjeve',
        'Indian/Cocos' => 'Ora e Ishujve Kokos',
        'Indian/Comoro' => 'Ora e Afrikës Lindore (Komore)',
        'Indian/Kerguelen' => 'Ora e Territoreve Jugore dhe Antarktike Franceze (Kerguelen)',
        'Indian/Mahe' => 'Ora e Sejshelleve (Mahé)',
        'Indian/Maldives' => 'Ora e Maldiveve',
        'Indian/Mauritius' => 'Ora e Mauritiusit',
        'Indian/Mayotte' => 'Ora e Afrikës Lindore (Majotë)',
        'Indian/Reunion' => 'Ora e Reunionit (Réunion)',
        'Pacific/Apia' => 'Ora e Apias',
        'Pacific/Auckland' => 'Ora e Zelandës së Re (Okland)',
        'Pacific/Bougainville' => 'Ora e Guinesë së Re-Papua (Bunganvilë)',
        'Pacific/Chatham' => 'Ora e Katamit (Çatman)',
        'Pacific/Easter' => 'Ora e Ishullit të Pashkës',
        'Pacific/Efate' => 'Ora e Vanuatusë (Efate)',
        'Pacific/Enderbury' => 'Ora e Ishujve Feniks (Ishulli i Kantonit)',
        'Pacific/Kanton' => 'Ora e Ishujve Feniks (Ishulli i Kantonit)',
        'Pacific/Fakaofo' => 'Ora e Tokelaut (Fakaofo)',
        'Pacific/Fiji' => 'Ora e Fixhit',
        'Pacific/Funafuti' => 'Ora e Tuvalusë (Funafuti)',
        'Pacific/Galapagos' => 'Ora e Galapagosit (Galápagos)',
        'Pacific/Gambier' => 'Ora e Gambierit',
        'Pacific/Guadalcanal' => 'Ora e Ishujve Solomon (Guadalkanal)',
        'Pacific/Guam' => 'Ora e Kamorros (Guam)',
        'Pacific/Honolulu' => 'Ora standarde e Ishujve Hauai-Aleutian (Honolulu)',
        'Pacific/Kiritimati' => 'Ora e Ishujve Sporadikë Ekuatorialë (Kiritimat)',
        'Pacific/Kosrae' => 'Ora e Kosrës (Kosre)',
        'Pacific/Kwajalein' => 'Ora e Ishujve Marshall (Kuaxhalein)',
        'Pacific/Majuro' => 'Ora e Ishujve Marshall (Mahuro)',
        'Pacific/Marquesas' => 'Ora e Ishujve Markezë',
        'Pacific/Midway' => 'Ora e Samoas (Miduej)',
        'Pacific/Nauru' => 'Ora e Naurusë',
        'Pacific/Niue' => 'Ora e Niuesë',
        'Pacific/Norfolk' => 'Ora e Ishullit Norfolk',
        'Pacific/Noumea' => 'Ora e Kaledonisë së Re (Nouméa)',
        'Pacific/Pago_Pago' => 'Ora e Samoas (Pago-Pago)',
        'Pacific/Palau' => 'Ora e Palaut',
        'Pacific/Pitcairn' => 'Ora e Pitkernit',
        'Pacific/Ponape' => 'Ora e Ponapeit',
        'Pacific/Pohnpei' => 'Ora e Ponapeit',
        'Pacific/Port_Moresby' => 'Ora e Guinesë së Re-Papua (Port-Moresbi)',
        'Pacific/Rarotonga' => 'Ora e Ishujve Kuk (Rarotongë)',
        'Pacific/Saipan' => 'Ora e Kamorros (Saipan)',
        'Pacific/Tahiti' => 'Ora e Tahitit',
        'Pacific/Tarawa' => 'Ora e Ishujve Gilbert (Taravë)',
        'Pacific/Tongatapu' => 'Ora e Tongës (Tongatapu)',
        'Pacific/Truk' => 'Ora e Çukut',
        'Pacific/Chuuk' => 'Ora e Çukut',
        'Pacific/Wake' => 'Ora e Ishullit Uejk',
        'Pacific/Wallis' => 'Ora e Uollisit dhe Futunës',
    ],
    'Meta' => [],
];
