<?php

return [
    'Names' => [
        'BYN' => [
            'Br',
            'белорусский рубль',
        ],
        'RUR' => [
            'RUR',
            'Российский рубль (1991–1998)',
        ],
    ],
];
