<?php

declare(strict_types=1);

namespace SimpleSAML\XMLSecurity\XML\xenc;

/**
 * Class representing the <xenc:KeyReference> element.
 *
 * @package simplesamlphp/xml-security
 */
class KeyReference extends AbstractReference
{
}
