<?php

return [
    'Names' => [
        'af' => 'Afrikans',
        'af_NA' => 'Afrikans (in-Namibja)',
        'af_ZA' => 'Afrikans (l-Afrika t’Isfel)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (il-Ghana)',
        'am' => 'Amhariku',
        'am_ET' => 'Amhariku (l-Etjopja)',
        'ar' => 'Għarbi',
        'ar_001' => 'Għarbi (Dinja)',
        'ar_AE' => 'Għarbi (l-Emirati Għarab Magħquda)',
        'ar_BH' => 'Għarbi (il-Bahrain)',
        'ar_DJ' => 'Għarbi (il-Djibouti)',
        'ar_DZ' => 'Għarbi (l-Alġerija)',
        'ar_EG' => 'Għarbi (l-Eġittu)',
        'ar_EH' => 'Għarbi (is-Saħara tal-Punent)',
        'ar_ER' => 'Għarbi (l-Eritrea)',
        'ar_IL' => 'Għarbi (Iżrael)',
        'ar_IQ' => 'Għarbi (l-Iraq)',
        'ar_JO' => 'Għarbi (il-Ġordan)',
        'ar_KM' => 'Għarbi (Comoros)',
        'ar_KW' => 'Għarbi (il-Kuwajt)',
        'ar_LB' => 'Għarbi (il-Libanu)',
        'ar_LY' => 'Għarbi (il-Libja)',
        'ar_MA' => 'Għarbi (il-Marokk)',
        'ar_MR' => 'Għarbi (il-Mauritania)',
        'ar_OM' => 'Għarbi (l-Oman)',
        'ar_PS' => 'Għarbi (it-Territorji Palestinjani)',
        'ar_QA' => 'Għarbi (il-Qatar)',
        'ar_SA' => 'Għarbi (l-Arabja Sawdija)',
        'ar_SD' => 'Għarbi (is-Sudan)',
        'ar_SO' => 'Għarbi (is-Somalja)',
        'ar_SS' => 'Għarbi (is-Sudan t’Isfel)',
        'ar_SY' => 'Għarbi (is-Sirja)',
        'ar_TD' => 'Għarbi (iċ-Chad)',
        'ar_TN' => 'Għarbi (it-Tuneżija)',
        'ar_YE' => 'Għarbi (il-Jemen)',
        'as' => 'Assamiż',
        'as_IN' => 'Assamiż (l-Indja)',
        'az' => 'Ażerbajġani',
        'az_AZ' => 'Ażerbajġani (l-Ażerbajġan)',
        'az_Cyrl' => 'Ażerbajġani (Ċirilliku)',
        'az_Cyrl_AZ' => 'Ażerbajġani (Ċirilliku, l-Ażerbajġan)',
        'az_Latn' => 'Ażerbajġani (Latin)',
        'az_Latn_AZ' => 'Ażerbajġani (Latin, l-Ażerbajġan)',
        'ba' => 'Bashkir',
        'ba_RU' => 'Bashkir (ir-Russja)',
        'be' => 'Belarussu',
        'be_BY' => 'Belarussu (il-Belarussja)',
        'bg' => 'Bulgaru',
        'bg_BG' => 'Bulgaru (il-Bulgarija)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (il-Mali)',
        'bn' => 'Bengali',
        'bn_BD' => 'Bengali (il-Bangladesh)',
        'bn_IN' => 'Bengali (l-Indja)',
        'bo' => 'Tibetjan',
        'bo_CN' => 'Tibetjan (iċ-Ċina)',
        'bo_IN' => 'Tibetjan (l-Indja)',
        'br' => 'Breton',
        'br_FR' => 'Breton (Franza)',
        'bs' => 'Bożnijaku',
        'bs_BA' => 'Bożnijaku (il-Bożnija-Ħerzegovina)',
        'bs_Cyrl' => 'Bożnijaku (Ċirilliku)',
        'bs_Cyrl_BA' => 'Bożnijaku (Ċirilliku, il-Bożnija-Ħerzegovina)',
        'bs_Latn' => 'Bożnijaku (Latin)',
        'bs_Latn_BA' => 'Bożnijaku (Latin, il-Bożnija-Ħerzegovina)',
        'ca' => 'Katalan',
        'ca_AD' => 'Katalan (Andorra)',
        'ca_ES' => 'Katalan (Spanja)',
        'ca_FR' => 'Katalan (Franza)',
        'ca_IT' => 'Katalan (l-Italja)',
        'ce' => 'Chechen',
        'ce_RU' => 'Chechen (ir-Russja)',
        'cs' => 'Ċek',
        'cs_CZ' => 'Ċek (ir-Repubblika Ċeka)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (ir-Russja)',
        'cy' => 'Welsh',
        'cy_GB' => 'Welsh (ir-Renju Unit)',
        'da' => 'Daniż',
        'da_DK' => 'Daniż (id-Danimarka)',
        'da_GL' => 'Daniż (Greenland)',
        'de' => 'Ġermaniż',
        'de_AT' => 'Ġermaniż (l-Awstrija)',
        'de_BE' => 'Ġermaniż (il-Belġju)',
        'de_CH' => 'Ġermaniż (l-Iżvizzera)',
        'de_DE' => 'Ġermaniż (il-Ġermanja)',
        'de_IT' => 'Ġermaniż (l-Italja)',
        'de_LI' => 'Ġermaniż (il-Liechtenstein)',
        'de_LU' => 'Ġermaniż (il-Lussemburgu)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (il-Bhutan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (il-Ghana)',
        'ee_TG' => 'Ewe (it-Togo)',
        'el' => 'Grieg',
        'el_CY' => 'Grieg (Ċipru)',
        'el_GR' => 'Grieg (il-Greċja)',
        'en' => 'Ingliż',
        'en_001' => 'Ingliż (Dinja)',
        'en_150' => 'Ingliż (Ewropa)',
        'en_AE' => 'Ingliż (l-Emirati Għarab Magħquda)',
        'en_AG' => 'Ingliż (Antigua u Barbuda)',
        'en_AI' => 'Ingliż (Anguilla)',
        'en_AS' => 'Ingliż (is-Samoa Amerikana)',
        'en_AT' => 'Ingliż (l-Awstrija)',
        'en_AU' => 'Ingliż (l-Awstralja)',
        'en_BB' => 'Ingliż (Barbados)',
        'en_BE' => 'Ingliż (il-Belġju)',
        'en_BI' => 'Ingliż (il-Burundi)',
        'en_BM' => 'Ingliż (Bermuda)',
        'en_BS' => 'Ingliż (il-Bahamas)',
        'en_BW' => 'Ingliż (il-Botswana)',
        'en_BZ' => 'Ingliż (il-Belize)',
        'en_CA' => 'Ingliż (il-Kanada)',
        'en_CC' => 'Ingliż (Gżejjer Cocos [Keeling])',
        'en_CH' => 'Ingliż (l-Iżvizzera)',
        'en_CK' => 'Ingliż (Gżejjer Cook)',
        'en_CM' => 'Ingliż (il-Kamerun)',
        'en_CX' => 'Ingliż (il-Gżira Christmas)',
        'en_CY' => 'Ingliż (Ċipru)',
        'en_CZ' => 'Ingliż (ir-Repubblika Ċeka)',
        'en_DE' => 'Ingliż (il-Ġermanja)',
        'en_DK' => 'Ingliż (id-Danimarka)',
        'en_DM' => 'Ingliż (Dominica)',
        'en_EE' => 'Ingliż (l-Estonja)',
        'en_ER' => 'Ingliż (l-Eritrea)',
        'en_ES' => 'Ingliż (Spanja)',
        'en_FI' => 'Ingliż (il-Finlandja)',
        'en_FJ' => 'Ingliż (Fiġi)',
        'en_FK' => 'Ingliż (il-Gżejjer Falkland)',
        'en_FM' => 'Ingliż (il-Mikroneżja)',
        'en_FR' => 'Ingliż (Franza)',
        'en_GB' => 'Ingliż (ir-Renju Unit)',
        'en_GD' => 'Ingliż (Grenada)',
        'en_GE' => 'Ingliż (il-Georgia)',
        'en_GG' => 'Ingliż (Guernsey)',
        'en_GH' => 'Ingliż (il-Ghana)',
        'en_GI' => 'Ingliż (Ġibiltà)',
        'en_GM' => 'Ingliż (il-Gambja)',
        'en_GS' => 'Ingliż (il-Georgia tan-Nofsinhar u l-Gżejjer Sandwich tan-Nofsinhar)',
        'en_GU' => 'Ingliż (Guam)',
        'en_GY' => 'Ingliż (il-Guyana)',
        'en_HK' => 'Ingliż (ir-Reġjun Amministrattiv Speċjali ta’ Hong Kong tar-Repubblika tal-Poplu taċ-Ċina)',
        'en_HU' => 'Ingliż (l-Ungerija)',
        'en_ID' => 'Ingliż (l-Indoneżja)',
        'en_IE' => 'Ingliż (l-Irlanda)',
        'en_IL' => 'Ingliż (Iżrael)',
        'en_IM' => 'Ingliż (Isle of Man)',
        'en_IN' => 'Ingliż (l-Indja)',
        'en_IT' => 'Ingliż (l-Italja)',
        'en_JE' => 'Ingliż (Jersey)',
        'en_JM' => 'Ingliż (il-Ġamajka)',
        'en_JP' => 'Ingliż (il-Ġappun)',
        'en_KE' => 'Ingliż (il-Kenja)',
        'en_KI' => 'Ingliż (Kiribati)',
        'en_KN' => 'Ingliż (Saint Kitts u Nevis)',
        'en_KY' => 'Ingliż (il-Gżejjer Cayman)',
        'en_LC' => 'Ingliż (Saint Lucia)',
        'en_LR' => 'Ingliż (il-Liberja)',
        'en_LS' => 'Ingliż (il-Lesoto)',
        'en_LT' => 'Ingliż (il-Litwanja)',
        'en_LV' => 'Ingliż (il-Latvja)',
        'en_MG' => 'Ingliż (Madagascar)',
        'en_MH' => 'Ingliż (Gżejjer Marshall)',
        'en_MO' => 'Ingliż (ir-Reġjun Amministrattiv Speċjali tal-Macao tar-Repubblika tal-Poplu taċ-Ċina)',
        'en_MP' => 'Ingliż (Ġżejjer Mariana tat-Tramuntana)',
        'en_MS' => 'Ingliż (Montserrat)',
        'en_MT' => 'Ingliż (Malta)',
        'en_MU' => 'Ingliż (Mauritius)',
        'en_MV' => 'Ingliż (il-Maldivi)',
        'en_MW' => 'Ingliż (il-Malawi)',
        'en_MY' => 'Ingliż (il-Malasja)',
        'en_NA' => 'Ingliż (in-Namibja)',
        'en_NF' => 'Ingliż (Gżira Norfolk)',
        'en_NG' => 'Ingliż (in-Niġerja)',
        'en_NL' => 'Ingliż (in-Netherlands)',
        'en_NO' => 'Ingliż (in-Norveġja)',
        'en_NR' => 'Ingliż (Nauru)',
        'en_NU' => 'Ingliż (Niue)',
        'en_NZ' => 'Ingliż (New Zealand)',
        'en_PG' => 'Ingliż (Papua New Guinea)',
        'en_PH' => 'Ingliż (il-Filippini)',
        'en_PK' => 'Ingliż (il-Pakistan)',
        'en_PL' => 'Ingliż (il-Polonja)',
        'en_PN' => 'Ingliż (Gżejjer Pitcairn)',
        'en_PR' => 'Ingliż (Puerto Rico)',
        'en_PT' => 'Ingliż (il-Portugall)',
        'en_PW' => 'Ingliż (Palau)',
        'en_RO' => 'Ingliż (ir-Rumanija)',
        'en_RW' => 'Ingliż (ir-Rwanda)',
        'en_SB' => 'Ingliż (il-Gżejjer Solomon)',
        'en_SC' => 'Ingliż (is-Seychelles)',
        'en_SD' => 'Ingliż (is-Sudan)',
        'en_SE' => 'Ingliż (l-Iżvezja)',
        'en_SG' => 'Ingliż (Singapore)',
        'en_SH' => 'Ingliż (Saint Helena)',
        'en_SI' => 'Ingliż (is-Slovenja)',
        'en_SK' => 'Ingliż (is-Slovakkja)',
        'en_SL' => 'Ingliż (Sierra Leone)',
        'en_SS' => 'Ingliż (is-Sudan t’Isfel)',
        'en_SX' => 'Ingliż (Sint Maarten)',
        'en_SZ' => 'Ingliż (l-Eswatini)',
        'en_TC' => 'Ingliż (il-Gżejjer Turks u Caicos)',
        'en_TK' => 'Ingliż (it-Tokelau)',
        'en_TO' => 'Ingliż (Tonga)',
        'en_TT' => 'Ingliż (Trinidad u Tobago)',
        'en_TV' => 'Ingliż (Tuvalu)',
        'en_TZ' => 'Ingliż (it-Tanzanija)',
        'en_UA' => 'Ingliż (l-Ukrajna)',
        'en_UG' => 'Ingliż (l-Uganda)',
        'en_UM' => 'Ingliż (Il-Gżejjer Minuri Mbiegħda tal-Istati Uniti)',
        'en_US' => 'Ingliż (l-Istati Uniti)',
        'en_VC' => 'Ingliż (Saint Vincent u l-Grenadini)',
        'en_VG' => 'Ingliż (il-Gżejjer Verġni Brittaniċi)',
        'en_VI' => 'Ingliż (il-Gżejjer Verġni tal-Istati Uniti)',
        'en_VU' => 'Ingliż (Vanuatu)',
        'en_WS' => 'Ingliż (Samoa)',
        'en_ZA' => 'Ingliż (l-Afrika t’Isfel)',
        'en_ZM' => 'Ingliż (iż-Żambja)',
        'en_ZW' => 'Ingliż (iż-Żimbabwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (Dinja)',
        'es' => 'Spanjol',
        'es_419' => 'Spanjol (Amerika Latina)',
        'es_AR' => 'Spanjol (l-Arġentina)',
        'es_BO' => 'Spanjol (il-Bolivja)',
        'es_BR' => 'Spanjol (Il-Brażil)',
        'es_BZ' => 'Spanjol (il-Belize)',
        'es_CL' => 'Spanjol (iċ-Ċili)',
        'es_CO' => 'Spanjol (il-Kolombja)',
        'es_CR' => 'Spanjol (il-Costa Rica)',
        'es_CU' => 'Spanjol (Kuba)',
        'es_DO' => 'Spanjol (ir-Repubblika Dominicana)',
        'es_EC' => 'Spanjol (l-Ekwador)',
        'es_ES' => 'Spanjol (Spanja)',
        'es_GQ' => 'Spanjol (il-Guinea Ekwatorjali)',
        'es_GT' => 'Spanjol (il-Gwatemala)',
        'es_HN' => 'Spanjol (il-Honduras)',
        'es_MX' => 'Spanjol (il-Messiku)',
        'es_NI' => 'Spanjol (in-Nikaragwa)',
        'es_PA' => 'Spanjol (il-Panama)',
        'es_PE' => 'Spanjol (il-Perù)',
        'es_PH' => 'Spanjol (il-Filippini)',
        'es_PR' => 'Spanjol (Puerto Rico)',
        'es_PY' => 'Spanjol (il-Paragwaj)',
        'es_SV' => 'Spanjol (El Salvador)',
        'es_US' => 'Spanjol (l-Istati Uniti)',
        'es_UY' => 'Spanjol (l-Urugwaj)',
        'es_VE' => 'Spanjol (il-Venezwela)',
        'et' => 'Estonjan',
        'et_EE' => 'Estonjan (l-Estonja)',
        'eu' => 'Bask',
        'eu_ES' => 'Bask (Spanja)',
        'fa' => 'Persjan',
        'fa_AF' => 'Persjan (l-Afganistan)',
        'fa_IR' => 'Persjan (l-Iran)',
        'ff' => 'Fulah',
        'ff_CM' => 'Fulah (il-Kamerun)',
        'ff_GN' => 'Fulah (il-Guinea)',
        'ff_Latn' => 'Fulah (Latin)',
        'ff_Latn_BF' => 'Fulah (Latin, il-Burkina Faso)',
        'ff_Latn_CM' => 'Fulah (Latin, il-Kamerun)',
        'ff_Latn_GH' => 'Fulah (Latin, il-Ghana)',
        'ff_Latn_GM' => 'Fulah (Latin, il-Gambja)',
        'ff_Latn_GN' => 'Fulah (Latin, il-Guinea)',
        'ff_Latn_GW' => 'Fulah (Latin, il-Guinea-Bissau)',
        'ff_Latn_LR' => 'Fulah (Latin, il-Liberja)',
        'ff_Latn_MR' => 'Fulah (Latin, il-Mauritania)',
        'ff_Latn_NE' => 'Fulah (Latin, in-Niġer)',
        'ff_Latn_NG' => 'Fulah (Latin, in-Niġerja)',
        'ff_Latn_SL' => 'Fulah (Latin, Sierra Leone)',
        'ff_Latn_SN' => 'Fulah (Latin, is-Senegal)',
        'ff_MR' => 'Fulah (il-Mauritania)',
        'ff_SN' => 'Fulah (is-Senegal)',
        'fi' => 'Finlandiż',
        'fi_FI' => 'Finlandiż (il-Finlandja)',
        'fo' => 'Faroese',
        'fo_DK' => 'Faroese (id-Danimarka)',
        'fo_FO' => 'Faroese (il-Gżejjer Faeroe)',
        'fr' => 'Franċiż',
        'fr_BE' => 'Franċiż (il-Belġju)',
        'fr_BF' => 'Franċiż (il-Burkina Faso)',
        'fr_BI' => 'Franċiż (il-Burundi)',
        'fr_BJ' => 'Franċiż (il-Benin)',
        'fr_BL' => 'Franċiż (Saint Barthélemy)',
        'fr_CA' => 'Franċiż (il-Kanada)',
        'fr_CD' => 'Franċiż (ir-Repubblika Demokratika tal-Kongo)',
        'fr_CF' => 'Franċiż (ir-Repubblika Ċentru-Afrikana)',
        'fr_CG' => 'Franċiż (il-Kongo - Brazzaville)',
        'fr_CH' => 'Franċiż (l-Iżvizzera)',
        'fr_CI' => 'Franċiż (il-Kosta tal-Avorju)',
        'fr_CM' => 'Franċiż (il-Kamerun)',
        'fr_DJ' => 'Franċiż (il-Djibouti)',
        'fr_DZ' => 'Franċiż (l-Alġerija)',
        'fr_FR' => 'Franċiż (Franza)',
        'fr_GA' => 'Franċiż (il-Gabon)',
        'fr_GF' => 'Franċiż (il-Guyana Franċiża)',
        'fr_GN' => 'Franċiż (il-Guinea)',
        'fr_GP' => 'Franċiż (Guadeloupe)',
        'fr_GQ' => 'Franċiż (il-Guinea Ekwatorjali)',
        'fr_HT' => 'Franċiż (il-Haiti)',
        'fr_KM' => 'Franċiż (Comoros)',
        'fr_LU' => 'Franċiż (il-Lussemburgu)',
        'fr_MA' => 'Franċiż (il-Marokk)',
        'fr_MC' => 'Franċiż (Monaco)',
        'fr_MF' => 'Franċiż (Saint Martin)',
        'fr_MG' => 'Franċiż (Madagascar)',
        'fr_ML' => 'Franċiż (il-Mali)',
        'fr_MQ' => 'Franċiż (Martinique)',
        'fr_MR' => 'Franċiż (il-Mauritania)',
        'fr_MU' => 'Franċiż (Mauritius)',
        'fr_NC' => 'Franċiż (New Caledonia)',
        'fr_NE' => 'Franċiż (in-Niġer)',
        'fr_PF' => 'Franċiż (Polineżja Franċiża)',
        'fr_PM' => 'Franċiż (Saint Pierre u Miquelon)',
        'fr_RE' => 'Franċiż (Réunion)',
        'fr_RW' => 'Franċiż (ir-Rwanda)',
        'fr_SC' => 'Franċiż (is-Seychelles)',
        'fr_SN' => 'Franċiż (is-Senegal)',
        'fr_SY' => 'Franċiż (is-Sirja)',
        'fr_TD' => 'Franċiż (iċ-Chad)',
        'fr_TG' => 'Franċiż (it-Togo)',
        'fr_TN' => 'Franċiż (it-Tuneżija)',
        'fr_VU' => 'Franċiż (Vanuatu)',
        'fr_WF' => 'Franċiż (Wallis u Futuna)',
        'fr_YT' => 'Franċiż (Mayotte)',
        'fy' => 'Frisian tal-Punent',
        'fy_NL' => 'Frisian tal-Punent (in-Netherlands)',
        'ga' => 'Irlandiż',
        'ga_GB' => 'Irlandiż (ir-Renju Unit)',
        'ga_IE' => 'Irlandiż (l-Irlanda)',
        'gd' => 'Galliku Skoċċiż',
        'gd_GB' => 'Galliku Skoċċiż (ir-Renju Unit)',
        'gl' => 'Galiċjan',
        'gl_ES' => 'Galiċjan (Spanja)',
        'gu' => 'Gujarati',
        'gu_IN' => 'Gujarati (l-Indja)',
        'gv' => 'Manx',
        'gv_IM' => 'Manx (Isle of Man)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (il-Ghana)',
        'ha_NE' => 'Hausa (in-Niġer)',
        'ha_NG' => 'Hausa (in-Niġerja)',
        'he' => 'Ebrajk',
        'he_IL' => 'Ebrajk (Iżrael)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (l-Indja)',
        'hi_Latn' => 'Hindi (Latin)',
        'hi_Latn_IN' => 'Hindi (Latin, l-Indja)',
        'hr' => 'Kroat',
        'hr_BA' => 'Kroat (il-Bożnija-Ħerzegovina)',
        'hr_HR' => 'Kroat (il-Kroazja)',
        'hu' => 'Ungeriż',
        'hu_HU' => 'Ungeriż (l-Ungerija)',
        'hy' => 'Armen',
        'hy_AM' => 'Armen (l-Armenja)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (Dinja)',
        'id' => 'Indoneżjan',
        'id_ID' => 'Indoneżjan (l-Indoneżja)',
        'ie' => 'Interlingue',
        'ie_EE' => 'Interlingue (l-Estonja)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (in-Niġerja)',
        'ii' => 'Sichuan Yi',
        'ii_CN' => 'Sichuan Yi (iċ-Ċina)',
        'is' => 'Iżlandiż',
        'is_IS' => 'Iżlandiż (l-Iżlanda)',
        'it' => 'Taljan',
        'it_CH' => 'Taljan (l-Iżvizzera)',
        'it_IT' => 'Taljan (l-Italja)',
        'it_SM' => 'Taljan (San Marino)',
        'it_VA' => 'Taljan (l-Istat tal-Belt tal-Vatikan)',
        'ja' => 'Ġappuniż',
        'ja_JP' => 'Ġappuniż (il-Ġappun)',
        'jv' => 'Ġavaniż',
        'jv_ID' => 'Ġavaniż (l-Indoneżja)',
        'ka' => 'Ġorġjan',
        'ka_GE' => 'Ġorġjan (il-Georgia)',
        'ki' => 'Kikuju',
        'ki_KE' => 'Kikuju (il-Kenja)',
        'kk' => 'Każak',
        'kk_Arab' => 'Każak (Għarbi)',
        'kk_Arab_CN' => 'Każak (Għarbi, iċ-Ċina)',
        'kk_Cyrl' => 'Każak (Ċirilliku)',
        'kk_Cyrl_KZ' => 'Każak (Ċirilliku, il-Każakistan)',
        'kk_KZ' => 'Każak (il-Każakistan)',
        'kl' => 'Kalallisut',
        'kl_GL' => 'Kalallisut (Greenland)',
        'km' => 'Khmer',
        'km_KH' => 'Khmer (il-Kambodja)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (l-Indja)',
        'ko' => 'Korean',
        'ko_CN' => 'Korean (iċ-Ċina)',
        'ko_KP' => 'Korean (il-Korea ta’ Fuq)',
        'ko_KR' => 'Korean (il-Korea t’Isfel)',
        'ks' => 'Kashmiri',
        'ks_Arab' => 'Kashmiri (Għarbi)',
        'ks_Arab_IN' => 'Kashmiri (Għarbi, l-Indja)',
        'ks_IN' => 'Kashmiri (l-Indja)',
        'ku' => 'Kurd',
        'ku_Latn' => 'Kurd (Latin)',
        'ku_Latn_IQ' => 'Kurd (Latin, l-Iraq)',
        'ku_Latn_SY' => 'Kurd (Latin, is-Sirja)',
        'ku_Latn_TR' => 'Kurd (Latin, it-Turkija)',
        'ku_SY' => 'Kurd (is-Sirja)',
        'ku_TR' => 'Kurd (it-Turkija)',
        'kw' => 'Korniku',
        'kw_GB' => 'Korniku (ir-Renju Unit)',
        'ky' => 'Kirgiż',
        'ky_KG' => 'Kirgiż (il-Kirgiżistan)',
        'lb' => 'Lussemburgiż',
        'lb_LU' => 'Lussemburgiż (il-Lussemburgu)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (l-Uganda)',
        'ln' => 'Lingaljan',
        'ln_AO' => 'Lingaljan (l-Angola)',
        'ln_CD' => 'Lingaljan (ir-Repubblika Demokratika tal-Kongo)',
        'ln_CF' => 'Lingaljan (ir-Repubblika Ċentru-Afrikana)',
        'ln_CG' => 'Lingaljan (il-Kongo - Brazzaville)',
        'lo' => 'Laosjan',
        'lo_LA' => 'Laosjan (il-Laos)',
        'lt' => 'Litwan',
        'lt_LT' => 'Litwan (il-Litwanja)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (ir-Repubblika Demokratika tal-Kongo)',
        'lv' => 'Latvjan',
        'lv_LV' => 'Latvjan (il-Latvja)',
        'mg' => 'Malagasy',
        'mg_MG' => 'Malagasy (Madagascar)',
        'mi' => 'Maori',
        'mi_NZ' => 'Maori (New Zealand)',
        'mk' => 'Maċedonjan',
        'mk_MK' => 'Maċedonjan (il-Maċedonja ta’ Fuq)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (l-Indja)',
        'mn' => 'Mongoljan',
        'mn_MN' => 'Mongoljan (il-Mongolja)',
        'mr' => 'Marathi',
        'mr_IN' => 'Marathi (l-Indja)',
        'ms' => 'Malay',
        'ms_BN' => 'Malay (il-Brunei)',
        'ms_ID' => 'Malay (l-Indoneżja)',
        'ms_MY' => 'Malay (il-Malasja)',
        'ms_SG' => 'Malay (Singapore)',
        'mt' => 'Malti',
        'mt_MT' => 'Malti (Malta)',
        'my' => 'Burmiż',
        'my_MM' => 'Burmiż (il-Myanmar/Burma)',
        'nb' => 'Bokmal Norveġiż',
        'nb_NO' => 'Bokmal Norveġiż (in-Norveġja)',
        'nb_SJ' => 'Bokmal Norveġiż (Svalbard u Jan Mayen)',
        'nd' => 'Ndebeli tat-Tramuntana',
        'nd_ZW' => 'Ndebeli tat-Tramuntana (iż-Żimbabwe)',
        'ne' => 'Nepaliż',
        'ne_IN' => 'Nepaliż (l-Indja)',
        'ne_NP' => 'Nepaliż (in-Nepal)',
        'nl' => 'Olandiż',
        'nl_AW' => 'Olandiż (Aruba)',
        'nl_BE' => 'Olandiż (il-Belġju)',
        'nl_BQ' => 'Olandiż (in-Netherlands tal-Karibew)',
        'nl_CW' => 'Olandiż (Curaçao)',
        'nl_NL' => 'Olandiż (in-Netherlands)',
        'nl_SR' => 'Olandiż (is-Suriname)',
        'nl_SX' => 'Olandiż (Sint Maarten)',
        'nn' => 'Ninorsk Norveġiż',
        'nn_NO' => 'Ninorsk Norveġiż (in-Norveġja)',
        'no' => 'Norveġiż',
        'no_NO' => 'Norveġiż (in-Norveġja)',
        'oc' => 'Oċċitan',
        'oc_ES' => 'Oċċitan (Spanja)',
        'oc_FR' => 'Oċċitan (Franza)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (l-Etjopja)',
        'om_KE' => 'Oromo (il-Kenja)',
        'or' => 'Odia',
        'or_IN' => 'Odia (l-Indja)',
        'os' => 'Ossettiku',
        'os_GE' => 'Ossettiku (il-Georgia)',
        'os_RU' => 'Ossettiku (ir-Russja)',
        'pa' => 'Punjabi',
        'pa_Arab' => 'Punjabi (Għarbi)',
        'pa_Arab_PK' => 'Punjabi (Għarbi, il-Pakistan)',
        'pa_IN' => 'Punjabi (l-Indja)',
        'pa_PK' => 'Punjabi (il-Pakistan)',
        'pl' => 'Pollakk',
        'pl_PL' => 'Pollakk (il-Polonja)',
        'ps' => 'Pashto',
        'ps_AF' => 'Pashto (l-Afganistan)',
        'ps_PK' => 'Pashto (il-Pakistan)',
        'pt' => 'Portugiż',
        'pt_AO' => 'Portugiż (l-Angola)',
        'pt_BR' => 'Portugiż (Il-Brażil)',
        'pt_CH' => 'Portugiż (l-Iżvizzera)',
        'pt_CV' => 'Portugiż (Cape Verde)',
        'pt_GQ' => 'Portugiż (il-Guinea Ekwatorjali)',
        'pt_GW' => 'Portugiż (il-Guinea-Bissau)',
        'pt_LU' => 'Portugiż (il-Lussemburgu)',
        'pt_MO' => 'Portugiż (ir-Reġjun Amministrattiv Speċjali tal-Macao tar-Repubblika tal-Poplu taċ-Ċina)',
        'pt_MZ' => 'Portugiż (il-Mozambique)',
        'pt_PT' => 'Portugiż (il-Portugall)',
        'pt_ST' => 'Portugiż (São Tomé u Príncipe)',
        'pt_TL' => 'Portugiż (Timor Leste)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (il-Bolivja)',
        'qu_EC' => 'Quechua (l-Ekwador)',
        'qu_PE' => 'Quechua (il-Perù)',
        'rm' => 'Romanz',
        'rm_CH' => 'Romanz (l-Iżvizzera)',
        'rn' => 'Rundi',
        'rn_BI' => 'Rundi (il-Burundi)',
        'ro' => 'Rumen',
        'ro_MD' => 'Rumen (il-Moldova)',
        'ro_RO' => 'Rumen (ir-Rumanija)',
        'ru' => 'Russu',
        'ru_BY' => 'Russu (il-Belarussja)',
        'ru_KG' => 'Russu (il-Kirgiżistan)',
        'ru_KZ' => 'Russu (il-Każakistan)',
        'ru_MD' => 'Russu (il-Moldova)',
        'ru_RU' => 'Russu (ir-Russja)',
        'ru_UA' => 'Russu (l-Ukrajna)',
        'rw' => 'Kinjarwanda',
        'rw_RW' => 'Kinjarwanda (ir-Rwanda)',
        'sa' => 'Sanskrit',
        'sa_IN' => 'Sanskrit (l-Indja)',
        'sc' => 'Sardinjan',
        'sc_IT' => 'Sardinjan (l-Italja)',
        'sd' => 'Sindhi',
        'sd_Arab' => 'Sindhi (Għarbi)',
        'sd_Arab_PK' => 'Sindhi (Għarbi, il-Pakistan)',
        'sd_IN' => 'Sindhi (l-Indja)',
        'sd_PK' => 'Sindhi (il-Pakistan)',
        'se' => 'Sami tat-Tramuntana',
        'se_FI' => 'Sami tat-Tramuntana (il-Finlandja)',
        'se_NO' => 'Sami tat-Tramuntana (in-Norveġja)',
        'se_SE' => 'Sami tat-Tramuntana (l-Iżvezja)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (ir-Repubblika Ċentru-Afrikana)',
        'sh' => 'Serbo-Kroat',
        'sh_BA' => 'Serbo-Kroat (il-Bożnija-Ħerzegovina)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (is-Sri Lanka)',
        'sk' => 'Slovakk',
        'sk_SK' => 'Slovakk (is-Slovakkja)',
        'sl' => 'Sloven',
        'sl_SI' => 'Sloven (is-Slovenja)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (iż-Żimbabwe)',
        'so' => 'Somali',
        'so_DJ' => 'Somali (il-Djibouti)',
        'so_ET' => 'Somali (l-Etjopja)',
        'so_KE' => 'Somali (il-Kenja)',
        'so_SO' => 'Somali (is-Somalja)',
        'sq' => 'Albaniż',
        'sq_AL' => 'Albaniż (l-Albanija)',
        'sq_MK' => 'Albaniż (il-Maċedonja ta’ Fuq)',
        'sr' => 'Serb',
        'sr_BA' => 'Serb (il-Bożnija-Ħerzegovina)',
        'sr_Cyrl' => 'Serb (Ċirilliku)',
        'sr_Cyrl_BA' => 'Serb (Ċirilliku, il-Bożnija-Ħerzegovina)',
        'sr_Cyrl_ME' => 'Serb (Ċirilliku, il-Montenegro)',
        'sr_Cyrl_RS' => 'Serb (Ċirilliku, is-Serbja)',
        'sr_Latn' => 'Serb (Latin)',
        'sr_Latn_BA' => 'Serb (Latin, il-Bożnija-Ħerzegovina)',
        'sr_Latn_ME' => 'Serb (Latin, il-Montenegro)',
        'sr_Latn_RS' => 'Serb (Latin, is-Serbja)',
        'sr_ME' => 'Serb (il-Montenegro)',
        'sr_RS' => 'Serb (is-Serbja)',
        'st' => 'Soto tan-Nofsinhar',
        'st_LS' => 'Soto tan-Nofsinhar (il-Lesoto)',
        'st_ZA' => 'Soto tan-Nofsinhar (l-Afrika t’Isfel)',
        'su' => 'Sundaniż',
        'su_ID' => 'Sundaniż (l-Indoneżja)',
        'su_Latn' => 'Sundaniż (Latin)',
        'su_Latn_ID' => 'Sundaniż (Latin, l-Indoneżja)',
        'sv' => 'Żvediż',
        'sv_AX' => 'Żvediż (il-Gżejjer Aland)',
        'sv_FI' => 'Żvediż (il-Finlandja)',
        'sv_SE' => 'Żvediż (l-Iżvezja)',
        'sw' => 'Swahili',
        'sw_CD' => 'Swahili (ir-Repubblika Demokratika tal-Kongo)',
        'sw_KE' => 'Swahili (il-Kenja)',
        'sw_TZ' => 'Swahili (it-Tanzanija)',
        'sw_UG' => 'Swahili (l-Uganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (l-Indja)',
        'ta_LK' => 'Tamil (is-Sri Lanka)',
        'ta_MY' => 'Tamil (il-Malasja)',
        'ta_SG' => 'Tamil (Singapore)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (l-Indja)',
        'tg' => 'Taġik',
        'tg_TJ' => 'Taġik (it-Taġikistan)',
        'th' => 'Tajlandiż',
        'th_TH' => 'Tajlandiż (it-Tajlandja)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (l-Eritrea)',
        'ti_ET' => 'Tigrinya (l-Etjopja)',
        'tk' => 'Turkmeni',
        'tk_TM' => 'Turkmeni (it-Turkmenistan)',
        'tl' => 'Tagalog',
        'tl_PH' => 'Tagalog (il-Filippini)',
        'tn' => 'Tswana',
        'tn_BW' => 'Tswana (il-Botswana)',
        'tn_ZA' => 'Tswana (l-Afrika t’Isfel)',
        'to' => 'Tongan',
        'to_TO' => 'Tongan (Tonga)',
        'tr' => 'Tork',
        'tr_CY' => 'Tork (Ċipru)',
        'tr_TR' => 'Tork (it-Turkija)',
        'tt' => 'Tatar',
        'tt_RU' => 'Tatar (ir-Russja)',
        'ug' => 'Uyghur',
        'ug_CN' => 'Uyghur (iċ-Ċina)',
        'uk' => 'Ukren',
        'uk_UA' => 'Ukren (l-Ukrajna)',
        'ur' => 'Urdu',
        'ur_IN' => 'Urdu (l-Indja)',
        'ur_PK' => 'Urdu (il-Pakistan)',
        'uz' => 'Uzbek',
        'uz_AF' => 'Uzbek (l-Afganistan)',
        'uz_Arab' => 'Uzbek (Għarbi)',
        'uz_Arab_AF' => 'Uzbek (Għarbi, l-Afganistan)',
        'uz_Cyrl' => 'Uzbek (Ċirilliku)',
        'uz_Cyrl_UZ' => 'Uzbek (Ċirilliku, l-Użbekistan)',
        'uz_Latn' => 'Uzbek (Latin)',
        'uz_Latn_UZ' => 'Uzbek (Latin, l-Użbekistan)',
        'uz_UZ' => 'Uzbek (l-Użbekistan)',
        'vi' => 'Vjetnamiż',
        'vi_VN' => 'Vjetnamiż (il-Vjetnam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (is-Senegal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (l-Afrika t’Isfel)',
        'yi' => 'Yiddish',
        'yi_UA' => 'Yiddish (l-Ukrajna)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (il-Benin)',
        'yo_NG' => 'Yoruba (in-Niġerja)',
        'za' => 'Zhuang',
        'za_CN' => 'Zhuang (iċ-Ċina)',
        'zh' => 'Ċiniż',
        'zh_CN' => 'Ċiniż (iċ-Ċina)',
        'zh_HK' => 'Ċiniż (ir-Reġjun Amministrattiv Speċjali ta’ Hong Kong tar-Repubblika tal-Poplu taċ-Ċina)',
        'zh_Hans' => 'Ċiniż (Simplifikat)',
        'zh_Hans_CN' => 'Ċiniż (Simplifikat, iċ-Ċina)',
        'zh_Hans_HK' => 'Ċiniż (Simplifikat, ir-Reġjun Amministrattiv Speċjali ta’ Hong Kong tar-Repubblika tal-Poplu taċ-Ċina)',
        'zh_Hans_MO' => 'Ċiniż (Simplifikat, ir-Reġjun Amministrattiv Speċjali tal-Macao tar-Repubblika tal-Poplu taċ-Ċina)',
        'zh_Hans_MY' => 'Ċiniż (Simplifikat, il-Malasja)',
        'zh_Hans_SG' => 'Ċiniż (Simplifikat, Singapore)',
        'zh_Hant' => 'Ċiniż (Tradizzjonali)',
        'zh_Hant_HK' => 'Ċiniż (Tradizzjonali, ir-Reġjun Amministrattiv Speċjali ta’ Hong Kong tar-Repubblika tal-Poplu taċ-Ċina)',
        'zh_Hant_MO' => 'Ċiniż (Tradizzjonali, ir-Reġjun Amministrattiv Speċjali tal-Macao tar-Repubblika tal-Poplu taċ-Ċina)',
        'zh_Hant_MY' => 'Ċiniż (Tradizzjonali, il-Malasja)',
        'zh_Hant_TW' => 'Ċiniż (Tradizzjonali, it-Tajwan)',
        'zh_MO' => 'Ċiniż (ir-Reġjun Amministrattiv Speċjali tal-Macao tar-Repubblika tal-Poplu taċ-Ċina)',
        'zh_SG' => 'Ċiniż (Singapore)',
        'zh_TW' => 'Ċiniż (it-Tajwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (l-Afrika t’Isfel)',
    ],
];
