<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'arapsko pismo',
        'Aran' => 'nastalik',
        'Armi' => 'imperijsko aramejsko pismo',
        'Armn' => 'jermensko pismo',
        'Avst' => 'avestansko pismo',
        'Bali' => 'balijsko pismo',
        'Batk' => 'batak pismo',
        'Beng' => 'bengalsko pismo',
        'Blis' => 'blisimbolično pismo',
        'Bopo' => 'bopomofo pismo',
        'Brah' => 'bramansko pismo',
        'Brai' => 'brajevo pismo',
        'Bugi' => 'buginsko pismo',
        'Buhd' => 'buhidsko pismo',
        'Cakm' => 'čakma',
        'Cans' => 'ujedinjeni kanadski aboridžinski silabici',
        'Cari' => 'karijsko pismo',
        'Cham' => 'čamsko pismo',
        'Cher' => 'čeroki',
        'Cirt' => 'cirt pismo',
        'Copt' => 'koptičko pismo',
        'Cprt' => 'kiparsko pismo',
        'Cyrl' => 'ćirilica',
        'Cyrs' => 'Staroslovenska crkvena ćirilica',
        'Deva' => 'devanagari',
        'Dsrt' => 'Dezeret',
        'Egyd' => 'egipatsko narodno pismo',
        'Egyh' => 'egipatsko hijeratsko pismo',
        'Egyp' => 'egipatski hijeroglifi',
        'Ethi' => 'etiopsko pismo',
        'Geok' => 'gruzijsko khutsuri pismo',
        'Geor' => 'gruzijsko pismo',
        'Glag' => 'glagoljica',
        'Goth' => 'Gotika',
        'Grek' => 'grčko pismo',
        'Gujr' => 'gudžaratsko pismo',
        'Guru' => 'gurmuki pismo',
        'Hanb' => 'hanb',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanuno',
        'Hans' => 'pojednostavljeno kinesko pismo',
        'Hant' => 'tradicionalno kinesko pismo',
        'Hebr' => 'hebrejsko pismo',
        'Hira' => 'hiragana',
        'Hmng' => 'pahav hmong pismo',
        'Hrkt' => 'japanska slogovna pisma',
        'Hung' => 'staromađarsko pismo',
        'Inds' => 'induško pismo',
        'Ital' => 'stari italik',
        'Jamo' => 'džamo',
        'Java' => 'javansko pismo',
        'Jpan' => 'japansko pismo',
        'Kali' => 'kajah-li pismo',
        'Kana' => 'katakana',
        'Khar' => 'karošti pismo',
        'Khmr' => 'kmersko pismo',
        'Knda' => 'kanada pismo',
        'Kore' => 'korejsko pismo',
        'Kthi' => 'kaiti',
        'Lana' => 'lanna pismo',
        'Laoo' => 'laoško pismo',
        'Latf' => 'latinica (fraktur varijanta)',
        'Latg' => 'galska latinica',
        'Latn' => 'latinica',
        'Lepc' => 'lepča pismo',
        'Limb' => 'limbu pismo',
        'Lina' => 'linearno A pismo',
        'Linb' => 'linearno B pismo',
        'Lyci' => 'lisijsko pismo',
        'Lydi' => 'lidijsko pismo',
        'Mand' => 'mandeansko pismo',
        'Mani' => 'manihejsko pismo',
        'Maya' => 'majanski hijeroglifi',
        'Mero' => 'meroitik pismo',
        'Mlym' => 'malajalamsko pismo',
        'Mong' => 'mongolsko pismo',
        'Moon' => 'mesečevo pismo',
        'Mtei' => 'meitei majek',
        'Mymr' => 'mijanmarsko pismo',
        'Nkoo' => 'nko',
        'Ogam' => 'ogamsko pismo',
        'Olck' => 'ol čiki',
        'Orkh' => 'orkonsko pismo',
        'Orya' => 'orijansko pismo',
        'Osma' => 'osmanjansko pismo',
        'Perm' => 'staro permiksko pismo',
        'Phag' => 'pags-pa pismo',
        'Phli' => 'pisani pahlavi',
        'Phlp' => 'psalter pahlavi',
        'Phlv' => 'pahlavi pismo',
        'Phnx' => 'Feničansko pismo',
        'Plrd' => 'porald fonetsko pismo',
        'Prti' => 'pisani partian',
        'Rjng' => 'rejang pismo',
        'Rohg' => 'hanifi',
        'Roro' => 'rongorongo pismo',
        'Runr' => 'runsko pismo',
        'Samr' => 'samaritansko pismo',
        'Sara' => 'sarati pismo',
        'Saur' => 'sauraštra pismo',
        'Sgnw' => 'znakovno pismo',
        'Shaw' => 'šavijansko pismo',
        'Sinh' => 'sinhalsko pismo',
        'Sund' => 'sundansko pismo',
        'Sylo' => 'siloti nagri pismo',
        'Syrc' => 'sirijsko pismo',
        'Syre' => 'sirijsko estrangelo pismo',
        'Syrj' => 'zapadnosirijsko pismo',
        'Syrn' => 'pismo istočne Sirije',
        'Tagb' => 'tagbanva pismo',
        'Tale' => 'tai le pismo',
        'Talu' => 'novi tai lue',
        'Taml' => 'tamilsko pismo',
        'Tavt' => 'tai viet pismo',
        'Telu' => 'telugu pismo',
        'Teng' => 'tengvar pismo',
        'Tfng' => 'tifinag',
        'Tglg' => 'Tagalog',
        'Thaa' => 'tana pismo',
        'Thai' => 'tajlandsko pismo',
        'Tibt' => 'tibetansko pismo',
        'Ugar' => 'ugaritsko pismo',
        'Vaii' => 'vai',
        'Visp' => 'vidljivi govor',
        'Xpeo' => 'staropersijsko pismo',
        'Xsux' => 'sumersko-akadsko kuneiform pismo',
        'Yiii' => 'ji',
        'Zinh' => 'nasledno pismo',
        'Zmth' => 'matematička notacija',
        'Zsye' => 'emodži',
        'Zsym' => 'simboli',
        'Zxxx' => 'nepisani jezik',
        'Zyyy' => 'zajedničko pismo',
    ],
];
