<?php

return [
    'Names' => [
        'Adlm' => 'Адлам (жазуу)',
        'Arab' => 'Араб',
        'Aran' => 'Насталик (Араб жазуусу)',
        'Armn' => 'Армян',
        'Beng' => 'Бенгал',
        'Bopo' => 'Бопомофо',
        'Brai' => 'Брейл',
        'Cakm' => 'Чакма (жазуу)',
        'Cans' => 'канадалык муун жазуусу',
        'Cher' => 'чероки (жазуу)',
        'Cyrl' => 'Кирилл',
        'Deva' => 'Деванагари',
        'Ethi' => 'Эфиоп',
        'Geor' => 'Грузин',
        'Grek' => 'Грек',
        'Gujr' => 'Гужарати',
        'Guru' => 'Гурмухи',
        'Hanb' => 'Ханб',
        'Hang' => 'Хангул',
        'Hani' => 'Хань',
        'Hans' => 'Жөнөкөйлөштүрүлгөн',
        'Hant' => 'Салттуу',
        'Hebr' => 'Иврит',
        'Hira' => 'Хирагана',
        'Hrkt' => 'Жапон силлабографиясы',
        'Jamo' => 'Джамо',
        'Jpan' => 'Жапан',
        'Kana' => 'Катакана',
        'Khmr' => 'Кмер',
        'Knda' => 'Каннада',
        'Kore' => 'Корей',
        'Laoo' => 'Лао',
        'Latn' => 'Латын',
        'Mlym' => 'Малайалам',
        'Mong' => 'Монгол',
        'Mtei' => 'мейтей-маек (жазуу)',
        'Mymr' => 'Мйанмар',
        'Nkoo' => 'нко (жазуу)',
        'Olck' => 'Ол-чики (жазуу)',
        'Orya' => 'Орийа',
        'Rohg' => 'Ханифи (жазуу)',
        'Sinh' => 'Сингала',
        'Sund' => 'сундан жазуусу',
        'Syrc' => 'сириялык жазуу',
        'Taml' => 'Тамил',
        'Telu' => 'Телу',
        'Tfng' => 'Тифинаг (жазуу)',
        'Thaa' => 'Таана',
        'Thai' => 'Тай',
        'Tibt' => 'Тибет',
        'Vaii' => 'Ваи (жазуу)',
        'Yiii' => 'Йи (жазуу)',
        'Zmth' => 'Математикалык маани',
        'Zsye' => 'Быйтыкча',
        'Zsym' => 'Белгилер',
        'Zxxx' => 'Жазылбаган',
        'Zyyy' => 'Жалпы',
    ],
];
