<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'árabe',
        'Aran' => 'nastaliq',
        'Armi' => 'armi',
        'Armn' => 'armênio',
        'Avst' => 'avéstico',
        'Bali' => 'balinês',
        'Bamu' => 'bamum',
        'Batk' => 'bataque',
        'Beng' => 'bengali',
        'Blis' => 'símbolos bliss',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille',
        'Bugi' => 'buginês',
        'Buhd' => 'buhid',
        'Cakm' => 'cakm',
        'Cans' => 'escrita silábica unificada dos aborígenes canadenses',
        'Cari' => 'cariano',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Cirt' => 'cirth',
        'Copt' => 'cóptico',
        'Cprt' => 'cipriota',
        'Cyrl' => 'cirílico',
        'Cyrs' => 'cirílico eslavo eclesiástico',
        'Deva' => 'devanágari',
        'Dsrt' => 'deseret',
        'Egyd' => 'demótico egípcio',
        'Egyh' => 'hierático egípcio',
        'Egyp' => 'hieróglifos egípcios',
        'Ethi' => 'etiópico',
        'Geok' => 'khutsuri georgiano',
        'Geor' => 'georgiano',
        'Glag' => 'glagolítico',
        'Goth' => 'gótico',
        'Grek' => 'grego',
        'Gujr' => 'guzerate',
        'Guru' => 'gurmuqui',
        'Hanb' => 'hanb',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'simplificado',
        'Hant' => 'tradicional',
        'Hebr' => 'hebraico',
        'Hira' => 'hiragana',
        'Hmng' => 'pahawh hmong',
        'Hrkt' => 'silabários japoneses',
        'Hung' => 'húngaro antigo',
        'Inds' => 'indo',
        'Ital' => 'itálico antigo',
        'Jamo' => 'jamo',
        'Java' => 'javanês',
        'Jpan' => 'japonês',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmer',
        'Knda' => 'kannada',
        'Kore' => 'coreano',
        'Kthi' => 'kthi',
        'Lana' => 'lanna',
        'Laoo' => 'lao',
        'Latf' => 'latim fraktur',
        'Latg' => 'latim gaélico',
        'Latn' => 'latim',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'linear A',
        'Linb' => 'linear B',
        'Lisu' => 'lisu',
        'Lyci' => 'lício',
        'Lydi' => 'lídio',
        'Mand' => 'mandaico',
        'Mani' => 'maniqueano',
        'Maya' => 'hieróglifos maias',
        'Merc' => 'meroítico cursivo',
        'Mero' => 'meroítico',
        'Mlym' => 'malaiala',
        'Mong' => 'mongol',
        'Moon' => 'moon',
        'Mtei' => 'meitei mayek',
        'Mymr' => 'birmanês',
        'Nkoo' => 'n’ko',
        'Ogam' => 'ogâmico',
        'Olck' => 'ol chiki',
        'Orkh' => 'orkhon',
        'Orya' => 'oriá',
        'Osma' => 'osmania',
        'Perm' => 'pérmico antigo',
        'Phag' => 'phags-pa',
        'Phli' => 'phli',
        'Phlp' => 'phlp',
        'Phlv' => 'pahlavi antigo',
        'Phnx' => 'fenício',
        'Plrd' => 'fonético pollard',
        'Prti' => 'prti',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'rúnico',
        'Samr' => 'samaritano',
        'Sara' => 'sarati',
        'Saur' => 'saurashtra',
        'Sgnw' => 'signwriting',
        'Shaw' => 'shaviano',
        'Sinh' => 'cingalês',
        'Sund' => 'sundanês',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'siríaco',
        'Syre' => 'siríaco estrangelo',
        'Syrj' => 'siríaco ocidental',
        'Syrn' => 'siríaco oriental',
        'Tagb' => 'tagbanwa',
        'Tale' => 'tai Le',
        'Talu' => 'novo tai lue',
        'Taml' => 'tâmil',
        'Tavt' => 'tavt',
        'Telu' => 'télugo',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalo',
        'Thaa' => 'thaana',
        'Thai' => 'tailandês',
        'Tibt' => 'tibetano',
        'Ugar' => 'ugarítico',
        'Vaii' => 'vai',
        'Visp' => 'visible speech',
        'Xpeo' => 'persa antigo',
        'Xsux' => 'sumério-acadiano cuneiforme',
        'Yiii' => 'yi',
        'Zinh' => 'herdado',
        'Zmth' => 'notação matemática',
        'Zsye' => 'emoji',
        'Zsym' => 'zsym',
        'Zxxx' => 'ágrafo',
        'Zyyy' => 'comum',
    ],
];
