<?php

return [
    'UserAssignedNames' => [
        'XK' => 'Косово',
    ],
    'Names' => [
        'AD' => 'Андорра',
        'AE' => 'Бирләшмиш Әрәб Әмирликләри',
        'AF' => 'Әфганыстан',
        'AG' => 'Антигуа вә Барбуда',
        'AI' => 'Анҝилја',
        'AL' => 'Албанија',
        'AM' => 'Ермәнистан',
        'AO' => 'Ангола',
        'AQ' => 'Антарктика',
        'AR' => 'Арҝентина',
        'AS' => 'Америка Самоасы',
        'AT' => 'Австрија',
        'AU' => 'Австралија',
        'AW' => 'Аруба',
        'AX' => 'Аланд адалары',
        'AZ' => 'Азәрбајҹан',
        'BA' => 'Боснија вә Һерсеговина',
        'BB' => 'Барбадос',
        'BD' => 'Бангладеш',
        'BE' => 'Белчика',
        'BF' => 'Буркина Фасо',
        'BG' => 'Болгарыстан',
        'BH' => 'Бәһрејн',
        'BI' => 'Бурунди',
        'BJ' => 'Бенин',
        'BL' => 'Сент-Бартелеми',
        'BM' => 'Бермуд адалары',
        'BN' => 'Брунеј',
        'BO' => 'Боливија',
        'BR' => 'Бразилија',
        'BS' => 'Баһам адалары',
        'BT' => 'Бутан',
        'BV' => 'Буве адасы',
        'BW' => 'Ботсвана',
        'BY' => 'Беларус',
        'BZ' => 'Белиз',
        'CA' => 'Канада',
        'CC' => 'Кокос (Килинг) адалары',
        'CD' => 'Конго-Киншаса',
        'CF' => 'Мәркәзи Африка Республикасы',
        'CG' => 'Конго-Браззавил',
        'CH' => 'Исвечрә',
        'CI' => 'Котд’ивуар',
        'CK' => 'Кук адалары',
        'CL' => 'Чили',
        'CM' => 'Камерун',
        'CN' => 'Чин',
        'CO' => 'Колумбија',
        'CR' => 'Коста Рика',
        'CU' => 'Куба',
        'CV' => 'Кабо-Верде',
        'CW' => 'Курасао',
        'CX' => 'Милад адасы',
        'CY' => 'Кипр',
        'CZ' => 'Чехија',
        'DE' => 'Алманија',
        'DJ' => 'Ҹибути',
        'DK' => 'Данимарка',
        'DM' => 'Доминика',
        'DO' => 'Доминикан Республикасы',
        'DZ' => 'Әлҹәзаир',
        'EC' => 'Еквадор',
        'EE' => 'Естонија',
        'EG' => 'Мисир',
        'ER' => 'Еритреја',
        'ES' => 'Испанија',
        'ET' => 'Ефиопија',
        'FI' => 'Финландија',
        'FJ' => 'Фиҹи',
        'FK' => 'Фолкленд адалары',
        'FM' => 'Микронезија',
        'FO' => 'Фарер адалары',
        'FR' => 'Франса',
        'GA' => 'Габон',
        'GB' => 'Бирләшмиш Краллыг',
        'GD' => 'Гренада',
        'GE' => 'Ҝүрҹүстан',
        'GF' => 'Франса Гвианасы',
        'GG' => 'Ҝернси',
        'GH' => 'Гана',
        'GI' => 'Ҹәбәллүтариг',
        'GL' => 'Гренландија',
        'GM' => 'Гамбија',
        'GN' => 'Гвинеја',
        'GP' => 'Гваделупа',
        'GQ' => 'Екваториал Гвинеја',
        'GR' => 'Јунаныстан',
        'GS' => 'Ҹәнуби Ҹорҹија вә Ҹәнуби Сендвич адалары',
        'GT' => 'Гватемала',
        'GU' => 'Гуам',
        'GW' => 'Гвинеја-Бисау',
        'GY' => 'Гајана',
        'HK' => 'Һонк Конг Хүсуси Инзибати Әрази Чин',
        'HM' => 'Һерд вә Макдоналд адалары',
        'HN' => 'Һондурас',
        'HR' => 'Хорватија',
        'HT' => 'Һаити',
        'HU' => 'Маҹарыстан',
        'ID' => 'Индонезија',
        'IE' => 'Ирландија',
        'IL' => 'Исраил',
        'IM' => 'Мен адасы',
        'IN' => 'Һиндистан',
        'IQ' => 'Ираг',
        'IR' => 'Иран',
        'IS' => 'Исландија',
        'IT' => 'Италија',
        'JE' => 'Ҹерси',
        'JM' => 'Јамајка',
        'JO' => 'Иорданија',
        'JP' => 'Јапонија',
        'KE' => 'Кенија',
        'KG' => 'Гырғызыстан',
        'KH' => 'Камбоҹа',
        'KI' => 'Кирибати',
        'KM' => 'Комор адалары',
        'KN' => 'Сент-Китс вә Невис',
        'KP' => 'Шимали Кореја',
        'KR' => 'Ҹәнуби Кореја',
        'KW' => 'Күвејт',
        'KY' => 'Кајман адалары',
        'KZ' => 'Газахыстан',
        'LA' => 'Лаос',
        'LB' => 'Ливан',
        'LC' => 'Сент-Лусија',
        'LI' => 'Лихтенштејн',
        'LK' => 'Шри-Ланка',
        'LR' => 'Либерија',
        'LS' => 'Лесото',
        'LT' => 'Литва',
        'LU' => 'Лүксембург',
        'LV' => 'Латвија',
        'LY' => 'Ливија',
        'MA' => 'Мәракеш',
        'MC' => 'Монако',
        'MD' => 'Молдова',
        'ME' => 'Монтенегро',
        'MF' => 'Сент Мартин',
        'MG' => 'Мадагаскар',
        'MH' => 'Маршал адалары',
        'ML' => 'Мали',
        'MM' => 'Мјанма',
        'MN' => 'Монголустан',
        'MO' => 'Макао Хүсуси Инзибати Әрази Чин',
        'MP' => 'Шимали Мариан адалары',
        'MQ' => 'Мартиник',
        'MR' => 'Мавританија',
        'MS' => 'Монсерат',
        'MT' => 'Малта',
        'MU' => 'Маврики',
        'MV' => 'Малдив адалары',
        'MW' => 'Малави',
        'MX' => 'Мексика',
        'MY' => 'Малајзија',
        'MZ' => 'Мозамбик',
        'NA' => 'Намибија',
        'NC' => 'Јени Каледонија',
        'NE' => 'Ниҝер',
        'NF' => 'Норфолк адасы',
        'NG' => 'Ниҝерија',
        'NI' => 'Никарагуа',
        'NL' => 'Нидерланд',
        'NO' => 'Норвеч',
        'NP' => 'Непал',
        'NR' => 'Науру',
        'NU' => 'Ниуе',
        'NZ' => 'Јени Зеландија',
        'OM' => 'Оман',
        'PA' => 'Панама',
        'PE' => 'Перу',
        'PF' => 'Франса Полинезијасы',
        'PG' => 'Папуа-Јени Гвинеја',
        'PH' => 'Филиппин',
        'PK' => 'Пакистан',
        'PL' => 'Полша',
        'PM' => 'Мүгәддәс Пјер вә Микелон',
        'PN' => 'Питкерн адалары',
        'PR' => 'Пуерто Рико',
        'PT' => 'Португалија',
        'PW' => 'Палау',
        'PY' => 'Парагвај',
        'QA' => 'Гәтәр',
        'RE' => 'Рејунјон',
        'RO' => 'Румынија',
        'RS' => 'Сербија',
        'RU' => 'Русија',
        'RW' => 'Руанда',
        'SA' => 'Сәудијјә Әрәбистаны',
        'SB' => 'Соломон адалары',
        'SC' => 'Сејшел адалары',
        'SD' => 'Судан',
        'SE' => 'Исвеч',
        'SG' => 'Сингапур',
        'SH' => 'Мүгәддәс Јелена',
        'SI' => 'Словенија',
        'SJ' => 'Свалбард вә Јан-Мајен',
        'SK' => 'Словакија',
        'SL' => 'Сјерра-Леоне',
        'SM' => 'Сан-Марино',
        'SN' => 'Сенегал',
        'SO' => 'Сомали',
        'SR' => 'Суринам',
        'SS' => 'Ҹәнуби Судан',
        'ST' => 'Сан-Томе вә Принсипи',
        'SV' => 'Салвадор',
        'SX' => 'Синт-Мартен',
        'SY' => 'Сурија',
        'SZ' => 'Свазиленд',
        'TC' => 'Төркс вә Кајкос адалары',
        'TD' => 'Чад',
        'TF' => 'Франсанын Ҹәнуб Әразиләри',
        'TG' => 'Того',
        'TH' => 'Таиланд',
        'TJ' => 'Таҹикистан',
        'TK' => 'Токелау',
        'TL' => 'Шәрги Тимор',
        'TM' => 'Түркмәнистан',
        'TN' => 'Тунис',
        'TO' => 'Тонга',
        'TR' => 'Түркијә',
        'TT' => 'Тринидад вә Тобаго',
        'TV' => 'Тувалу',
        'TW' => 'Тајван',
        'TZ' => 'Танзанија',
        'UA' => 'Украјна',
        'UG' => 'Уганда',
        'UM' => 'АБШ-а бағлы кичик адаҹыглар',
        'US' => 'Америка Бирләшмиш Штатлары',
        'UY' => 'Уругвај',
        'UZ' => 'Өзбәкистан',
        'VA' => 'Ватикан',
        'VC' => 'Сент-Винсент вә Гренадинләр',
        'VE' => 'Венесуела',
        'VG' => 'Британијанын Вирҝин адалары',
        'VI' => 'АБШ Вирҝин адалары',
        'VN' => 'Вјетнам',
        'VU' => 'Вануату',
        'WF' => 'Уоллис вә Футуна',
        'WS' => 'Самоа',
        'YE' => 'Јәмән',
        'YT' => 'Мајот',
        'ZA' => 'Ҹәнуб Африка',
        'ZM' => 'Замбија',
        'ZW' => 'Зимбабве',
    ],
];
