<?php

declare(strict_types=1);

namespace SimpleSAML\XMLSecurity\Assert;

use SimpleSAML\XML\Assert\Assert as BaseAssert;

/**
 * SimpleSAML\XMLSecurity\Assert\Assert wrapper class
 *
 * @package simplesamlphp/xml-security
 */
class Assert extends BaseAssert
{
}
