<?php

return [
    'Names' => [
        'aa' => 'afara',
        'ab' => 'abĥaza',
        'ace' => 'aĉea',
        'ada' => 'dangba',
        'ady' => 'adigea',
        'af' => 'afrikansa',
        'ain' => 'ajnua',
        'ak' => 'akana',
        'ale' => 'aleuta',
        'alt' => 'sud-altaja',
        'am' => 'amhara',
        'an' => 'aragona',
        'anp' => 'angika',
        'apc' => 'araba levantenia',
        'ar' => 'araba',
        'arn' => 'mapuĉa',
        'arp' => 'arapaha',
        'ars' => 'araba naĝda',
        'as' => 'asama',
        'ast' => 'astura',
        'atj' => 'atikameka',
        'av' => 'avara',
        'awa' => 'avadhia',
        'ay' => 'ajmara',
        'az' => 'azerbajĝana',
        'ba' => 'baŝkira',
        'bal' => 'baluĉa',
        'ban' => 'balia',
        'bas' => 'basaa',
        'be' => 'belorusa',
        'bem' => 'bemba',
        'bew' => 'batavia',
        'bez' => 'benaa',
        'bg' => 'bulgara',
        'bgc' => 'harjana',
        'bho' => 'boĝpura',
        'bi' => 'Bislamo',
        'bin' => 'edoa',
        'bla' => 'nigrapieda',
        'blo' => 'aniia',
        'bm' => 'bambara',
        'bn' => 'bengala',
        'bo' => 'tibeta',
        'bqi' => 'baĥtiara',
        'br' => 'bretona',
        'brx' => 'bodoa',
        'bs' => 'bosna',
        'bua' => 'burjata',
        'bug' => 'buĝia',
        'byn' => 'bilena',
        'ca' => 'kataluna',
        'cay' => 'kajuga',
        'ccp' => 'ĉakma',
        'ce' => 'ĉeĉena',
        'ceb' => 'cebua',
        'cgg' => 'kigaa',
        'ch' => 'ĉamora',
        'chk' => 'ĉuuka',
        'chm' => 'maria',
        'cho' => 'ĉaktaa',
        'chp' => 'ĉipevajana',
        'chr' => 'ĉeroka',
        'chy' => 'ĉejena',
        'ckb' => 'kurda centra',
        'clc' => 'ĉilkotina',
        'co' => 'korsika',
        'cop' => 'kopta',
        'crg' => 'miĉifa',
        'crj' => 'kria jakob-golfa suda',
        'crk' => 'kria preria',
        'crl' => 'kria jakob-golfa norda',
        'crm' => 'kria alka',
        'crr' => 'algonkena (Norda Karolino)',
        'cs' => 'ĉeĥa',
        'csw' => 'kria marĉa',
        'cu' => 'malnovslava',
        'cv' => 'ĉuvaŝa',
        'cy' => 'kimra',
        'da' => 'dana',
        'dak' => 'dakota',
        'dar' => 'dargva',
        'dav' => 'taitaa',
        'de' => 'germana',
        'dgr' => 'dogriba',
        'dje' => 'zarmaa',
        'doi' => 'dogra',
        'dsb' => 'malsuprasoraba',
        'dua' => 'dualaa',
        'dv' => 'maldiva',
        'dyo' => 'djola',
        'dz' => 'Dzonko',
        'dzg' => 'dazaa',
        'ebu' => 'embua',
        'ee' => 'evea',
        'efi' => 'efika',
        'eka' => 'ekaĝuka',
        'el' => 'greka',
        'en' => 'angla',
        'eo' => 'Esperanto',
        'es' => 'hispana',
        'et' => 'estona',
        'eu' => 'eŭska',
        'ewo' => 'eunda',
        'fa' => 'persa',
        'ff' => 'fula',
        'fi' => 'finna',
        'fil' => 'filipina',
        'fj' => 'fiĝia',
        'fo' => 'feroa',
        'fon' => 'fonua',
        'fr' => 'franca',
        'frc' => 'kaĵun-franca',
        'frr' => 'nord-frisa',
        'fur' => 'friula',
        'fy' => 'okcident-frisa',
        'ga' => 'irlanda',
        'gd' => 'skot-gaela',
        'gez' => 'geeza',
        'gil' => 'kiribata',
        'gl' => 'galega',
        'gn' => 'gvarania',
        'gor' => 'gorontala',
        'gsw' => 'svisgermana',
        'gu' => 'guĝarata',
        'guz' => 'gusia',
        'gv' => 'manksa',
        'gwi' => 'gviĉina',
        'ha' => 'haŭsa',
        'hai' => 'haida',
        'haw' => 'havaja',
        'hax' => 'sud-haida',
        'he' => 'hebrea',
        'hi' => 'hindia',
        'hil' => 'hiligajnona',
        'hmn' => 'hmonga',
        'hnj' => 'verd-hmonga',
        'hr' => 'kroata',
        'hsb' => 'suprasoraba',
        'ht' => 'haitia kreola',
        'hu' => 'hungara',
        'hup' => 'hupa',
        'hur' => 'halkomelema',
        'hy' => 'armena',
        'hz' => 'herera',
        'ia' => 'Interlingvao',
        'iba' => 'ibana',
        'ibb' => 'ibibia',
        'id' => 'indonezia',
        'ie' => 'Interlingveo',
        'ig' => 'igba',
        'ii' => 'jia',
        'ik' => 'injupiaka',
        'ikt' => 'inuvialuktuna',
        'ilo' => 'iloka',
        'inh' => 'inguŝa',
        'io' => 'Ido',
        'is' => 'islanda',
        'it' => 'itala',
        'iu' => 'inuktituta',
        'ja' => 'japana',
        'jbo' => 'Loĵbano',
        'jmc' => 'ĉaga (Kimaĉame)',
        'jv' => 'java',
        'ka' => 'kartvela',
        'kaa' => 'karakalpaka',
        'kab' => 'kabila',
        'kac' => 'kaĉina',
        'kam' => 'kambaa',
        'kbd' => 'kabarda',
        'kde' => 'makonda',
        'kea' => 'kaboverda kreola',
        'kek' => 'kekĉia',
        'kfo' => 'malinka (Koro)',
        'kgp' => 'kainganga',
        'ki' => 'kikuja',
        'kj' => 'kuanjama',
        'kk' => 'kazaĥa',
        'kl' => 'gronlanda',
        'kln' => 'kalenĝina',
        'km' => 'kmera',
        'kmb' => 'kimbunda',
        'kn' => 'kanara',
        'ko' => 'korea',
        'kok' => 'konkana',
        'kpe' => 'kpelea',
        'kr' => 'kanura',
        'krc' => 'karaĉaj-balkara',
        'krl' => 'karela',
        'kru' => 'kuruksa',
        'ks' => 'kaŝmira',
        'ksb' => 'ŝambaa',
        'ksh' => 'kolonja',
        'ku' => 'kurda',
        'kum' => 'kumika',
        'kv' => 'komia',
        'kw' => 'kornvala',
        'ky' => 'kirgiza',
        'la' => 'Latino',
        'lad' => 'judhispana',
        'lag' => 'rangia',
        'lb' => 'luksemburga',
        'lez' => 'lezga',
        'lg' => 'ganda',
        'li' => 'limburga',
        'lij' => 'ligura',
        'lil' => 'lilueta',
        'lkt' => 'lakota',
        'lld' => 'ladina',
        'lmo' => 'lombarda',
        'ln' => 'lingala',
        'lo' => 'laŭa',
        'lou' => 'luiziana kreola',
        'loz' => 'lozia',
        'lrc' => 'nord-lura',
        'lt' => 'litova',
        'ltg' => 'latgala',
        'lu' => 'katanga-luba',
        'lua' => 'kasaja-luba',
        'lun' => 'lundaa',
        'luo' => 'lua',
        'luy' => 'luhia',
        'lv' => 'latva',
        'lzz' => 'laza',
        'mad' => 'madura',
        'mag' => 'magaha',
        'mai' => 'majtila',
        'mak' => 'makasara',
        'mas' => 'masaja',
        'mdf' => 'mokŝa',
        'men' => 'mendea',
        'mer' => 'merua',
        'mfe' => 'maŭricia kreola',
        'mg' => 'malagasa',
        'mgh' => 'makua (Meetto)',
        'mh' => 'marŝala',
        'mi' => 'maoria',
        'mic' => 'mikmaka',
        'min' => 'minankabaŭa',
        'mk' => 'makedona',
        'ml' => 'malajalama',
        'mn' => 'mongola',
        'mni' => 'manipura',
        'moe' => 'inua',
        'moh' => 'mohoka',
        'mos' => 'mosia',
        'mr' => 'marata',
        'ms' => 'malaja',
        'mt' => 'malta',
        'mua' => 'mundanga',
        'mus' => 'krika',
        'mwl' => 'miranda',
        'mww' => 'blank-hmonga',
        'my' => 'birma',
        'myv' => 'erzja',
        'mzn' => 'mazandarana',
        'na' => 'naura',
        'nap' => 'napola',
        'naq' => 'nama',
        'nb' => 'dannorvega',
        'nd' => 'nord-matabela',
        'nds' => 'platgermana',
        'ne' => 'nepala',
        'new' => 'nevara',
        'ng' => 'ndonga',
        'nia' => 'niasa',
        'niu' => 'niua',
        'nl' => 'nederlanda',
        'nn' => 'novnorvega',
        'no' => 'norvega',
        'nog' => 'nogaja',
        'nqo' => 'N’Ko',
        'nr' => 'sud-matabela',
        'nso' => 'nord-sota',
        'nus' => 'nuera',
        'nv' => 'navaha',
        'ny' => 'njanĝa',
        'nyn' => 'njankora',
        'oc' => 'okcitana',
        'ojb' => 'oĝibva nordokcidenta',
        'ojc' => 'oĝibva centra',
        'ojw' => 'oĝibva okcidenta',
        'oka' => 'okanagana',
        'om' => 'oroma',
        'or' => 'Orijo',
        'os' => 'oseta',
        'pa' => 'panĝaba',
        'pag' => 'pangasina',
        'pam' => 'pampanga',
        'pap' => 'Papiamento',
        'pau' => 'palaŭa',
        'pcm' => 'niĝeria piĝino',
        'pi' => 'palia',
        'pis' => 'Piĵino',
        'pl' => 'pola',
        'pms' => 'piemonta',
        'prg' => 'prusa',
        'ps' => 'paŝtua',
        'pt' => 'portugala',
        'qu' => 'keĉua',
        'quc' => 'kiĉea',
        'raj' => 'raĝastana',
        'rap' => 'rapanuia',
        'rar' => 'maoria kukinsula',
        'rhg' => 'rohinĝa',
        'rif' => 'rifa',
        'rm' => 'romanĉa',
        'rn' => 'burunda',
        'ro' => 'rumana',
        'rof' => 'ĉaga (Kirombo)',
        'ru' => 'rusa',
        'rup' => 'arumana',
        'rw' => 'ruanda',
        'rwk' => 'ĉaga (Rwa)',
        'sa' => 'Sanskrito',
        'sad' => 'sandavea',
        'sah' => 'jakuta',
        'saq' => 'samburua',
        'sat' => 'santala',
        'sba' => 'gambaja',
        'sbp' => 'sangua',
        'sc' => 'sarda',
        'scn' => 'sicilia',
        'sco' => 'skota',
        'sd' => 'sinda',
        'sdh' => 'sud-kurda',
        'se' => 'nord-samea',
        'sg' => 'sangoa',
        'sgs' => 'ĵemajtia',
        'sh' => 'serbokroata',
        'shi' => 'ŝelha',
        'shn' => 'ŝana',
        'si' => 'sinhala',
        'sid' => 'sidama',
        'sk' => 'slovaka',
        'skr' => 'saraika',
        'sl' => 'slovena',
        'slh' => 'sud-laŝucida',
        'sm' => 'samoa',
        'sma' => 'sud-samea',
        'smj' => 'lule-samea',
        'smn' => 'anar-samea',
        'sms' => 'skolt-samea',
        'sn' => 'ŝona',
        'snk' => 'soninka',
        'so' => 'somala',
        'sq' => 'albana',
        'sr' => 'serba',
        'srn' => 'surinama',
        'ss' => 'svazia',
        'ssy' => 'saha',
        'st' => 'sota',
        'str' => 'saliŝa nord-markola',
        'su' => 'sunda',
        'suk' => 'sukuma',
        'sv' => 'sveda',
        'sw' => 'svahila',
        'swb' => 'komora',
        'syr' => 'siria',
        'szl' => 'silezi-pola',
        'ta' => 'tamila',
        'tce' => 'sud-tuĉona',
        'te' => 'telugua',
        'tem' => 'temna',
        'teo' => 'tesa',
        'tet' => 'tetuna',
        'tg' => 'taĝika',
        'tgx' => 'tagiŝa',
        'th' => 'taja',
        'tht' => 'taltana',
        'ti' => 'tigraja',
        'tig' => 'tigrea',
        'tk' => 'turkmena',
        'tl' => 'tagaloga',
        'tlh' => 'klingona',
        'tli' => 'tlingita',
        'tn' => 'cvana',
        'to' => 'tonga',
        'tok' => 'Tokipono',
        'tpi' => 'Tokpisino',
        'tr' => 'turka',
        'trv' => 'sedeka',
        'trw' => 'torvalia',
        'ts' => 'conga',
        'tt' => 'tatara',
        'ttm' => 'nord-tuĉona',
        'tum' => 'tumbuka',
        'tvl' => 'tuvala',
        'ty' => 'tahitia',
        'tyv' => 'tuva',
        'tzm' => 'tamaziĥta mez-atlasa',
        'udm' => 'udmurta',
        'ug' => 'ujgura',
        'uk' => 'ukraina',
        'umb' => 'ovimbunda',
        'ur' => 'Urduo',
        'uz' => 'uzbeka',
        'vai' => 'vaja',
        've' => 'vendaa',
        'vec' => 'venecia',
        'vi' => 'vjetnama',
        'vmw' => 'makua',
        'vo' => 'Volapuko',
        'vun' => 'ĉaga (Kivunjo)',
        'wa' => 'valona',
        'wae' => 'germana valza',
        'wal' => 'velajtaa',
        'war' => 'varaja',
        'wo' => 'volofa',
        'wuu' => 'vua',
        'xal' => 'kalmuka',
        'xh' => 'ksosa',
        'xnr' => 'kangra',
        'yi' => 'judgermana',
        'yo' => 'joruba',
        'yrl' => 'nengatua',
        'yue' => 'kantona',
        'za' => 'ĝuanga',
        'zgh' => 'tamaziĥta maroka norma',
        'zh' => 'ĉina',
        'zu' => 'zulua',
        'zun' => 'zunjia',
        'zza' => 'zazaa',
    ],
    'LocalizedNames' => [
        'ar_001' => 'araba moderna norma',
        'de_AT' => 'germana aŭstra',
        'de_CH' => 'germana svisa',
        'en_AU' => 'angla aŭstralia',
        'en_CA' => 'angla kanada',
        'en_GB' => 'angla brita',
        'en_US' => 'angla usona',
        'es_419' => 'hispana amerika',
        'es_ES' => 'hispana eŭropa',
        'es_MX' => 'hispana meksika',
        'fr_CA' => 'franca kanada',
        'fr_CH' => 'franca svisa',
        'hi_Latn' => 'hindia (latina)',
        'nl_BE' => 'flandra',
        'pt_BR' => 'portugala brazila',
        'pt_PT' => 'portugala eŭropa',
        'ro_MD' => 'moldava',
        'zh_Hans' => 'ĉina simpligita',
        'zh_Hant' => 'ĉina tradicia',
    ],
];
