<?php

return [
    'Names' => [
        'aa' => 'Afar',
        'ab' => 'Abchasesch',
        'ace' => 'Aceh-Sprooch',
        'ach' => 'Acholi-Sprooch',
        'ada' => 'Adangme',
        'ady' => 'Adygéiesch',
        'ae' => 'Avestesch',
        'aeb' => 'Tunesescht Arabesch',
        'af' => 'Afrikaans',
        'afh' => 'Afrihili',
        'agq' => 'Aghem',
        'ain' => 'Ainu-Sprooch',
        'ak' => 'Akan',
        'akk' => 'Akkadesch',
        'akz' => 'Alabama',
        'ale' => 'Aleutesch',
        'aln' => 'Gegesch',
        'alt' => 'Süd-Alaesch',
        'am' => 'Amharesch',
        'an' => 'Aragonesesch',
        'ang' => 'Alenglesch',
        'anp' => 'Angika',
        'ar' => 'Arabesch',
        'arc' => 'Aramäesch',
        'arn' => 'Mapudungun',
        'aro' => 'Araona',
        'arp' => 'Arapaho-Sprooch',
        'arq' => 'Algerescht Arabesch',
        'arw' => 'Arawak-Sprooch',
        'ary' => 'Marokkanescht Arabesch',
        'arz' => 'Egyptescht Arabesch',
        'as' => 'Assamesesch',
        'asa' => 'Asu (Tanzania)',
        'ase' => 'Amerikanesch Zeechesprooch',
        'ast' => 'Asturianesch',
        'av' => 'Awaresch',
        'avk' => 'Kotava',
        'awa' => 'Awadhi',
        'ay' => 'Aymara',
        'az' => 'Aserbaidschanesch',
        'ba' => 'Baschkiresch',
        'bal' => 'Belutschesch',
        'ban' => 'Balinesesch',
        'bar' => 'Bairesch',
        'bas' => 'Basaa-Sprooch',
        'bax' => 'Bamun',
        'bbc' => 'Batak Toba',
        'bbj' => 'Ghomálá’',
        'be' => 'Wäissrussesch',
        'bej' => 'Bedauye',
        'bem' => 'Bemba-Sprooch',
        'bew' => 'Betawi',
        'bez' => 'Bena',
        'bfd' => 'Bafut',
        'bfq' => 'Badaga',
        'bg' => 'Bulgaresch',
        'bho' => 'Bhodschpuri',
        'bi' => 'Bislama',
        'bik' => 'Bikol-Sprooch',
        'bin' => 'Bini-Sprooch',
        'bjn' => 'Banjaresesch',
        'bkm' => 'Kom',
        'bla' => 'Blackfoot-Sprooch',
        'bm' => 'Bambara-Sprooch',
        'bn' => 'Bengalesch',
        'bo' => 'Tibetesch',
        'bpy' => 'Bishnupriya',
        'bqi' => 'Bachtiaresch',
        'br' => 'Bretonesch',
        'bra' => 'Braj-Bhakha',
        'brh' => 'Brahui',
        'brx' => 'Bodo',
        'bs' => 'Bosnesch',
        'bss' => 'Akoose',
        'bua' => 'Burjatesch',
        'bug' => 'Buginesesch',
        'bum' => 'Bulu',
        'byn' => 'Blin',
        'byv' => 'Medumba',
        'ca' => 'Katalanesch',
        'cad' => 'Caddo',
        'car' => 'Karibesch',
        'cay' => 'Cayuga',
        'cch' => 'Atsam',
        'ce' => 'Tschetschenesch',
        'ceb' => 'Cebuano',
        'cgg' => 'Kiga',
        'ch' => 'Chamorro-Sprooch',
        'chb' => 'Chibcha-Sprooch',
        'chg' => 'Tschagataesch',
        'chk' => 'Trukesesch',
        'chm' => 'Mari',
        'chn' => 'Chinook',
        'cho' => 'Choctaw',
        'chp' => 'Chipewyan',
        'chr' => 'Cherokee',
        'chy' => 'Cheyenne',
        'ckb' => 'Sorani',
        'co' => 'Korsesch',
        'cop' => 'Koptesch',
        'cps' => 'Capiznon',
        'cr' => 'Cree',
        'crh' => 'Krimtataresch',
        'cs' => 'Tschechesch',
        'csb' => 'Kaschubesch',
        'cu' => 'Kiercheslawesch',
        'cv' => 'Tschuwaschesch',
        'cy' => 'Walisesch',
        'da' => 'Dänesch',
        'dak' => 'Dakota-Sprooch',
        'dar' => 'Darginesch',
        'dav' => 'Taita',
        'de' => 'Däitsch',
        'del' => 'Delaware-Sprooch',
        'den' => 'Slave',
        'dgr' => 'Dogrib',
        'din' => 'Dinka-Sprooch',
        'dje' => 'Zarma',
        'doi' => 'Dogri',
        'dsb' => 'Niddersorbesch',
        'dtp' => 'Zentral-Dusun',
        'dua' => 'Duala',
        'dum' => 'Mëttelhollännesch',
        'dv' => 'Maldivesch',
        'dyo' => 'Jola-Fonyi',
        'dyu' => 'Dyula-Sprooch',
        'dz' => 'Bhutanesch',
        'dzg' => 'Dazaga',
        'ebu' => 'Kiembu',
        'ee' => 'Ewe-Sprooch',
        'efi' => 'Efik',
        'egl' => 'Emilianesch',
        'egy' => 'Egyptesch',
        'eka' => 'Ekajuk',
        'el' => 'Griichesch',
        'elx' => 'Elamesch',
        'en' => 'Englesch',
        'enm' => 'Mëttelenglesch',
        'eo' => 'Esperanto',
        'es' => 'Spuenesch',
        'esu' => 'Yup’ik',
        'et' => 'Estnesch',
        'eu' => 'Baskesch',
        'ewo' => 'Ewondo',
        'ext' => 'Extremaduresch',
        'fa' => 'Persesch',
        'fan' => 'Pangwe-Sprooch',
        'fat' => 'Fanti-Sprooch',
        'ff' => 'Ful',
        'fi' => 'Finnesch',
        'fil' => 'Filipino',
        'fit' => 'Meänkieli',
        'fj' => 'Fidschianesch',
        'fo' => 'Färöesch',
        'fon' => 'Fon-Sprooch',
        'fr' => 'Franséisch',
        'frc' => 'Cajun',
        'frm' => 'Mëttelfranséisch',
        'fro' => 'Alfranséisch',
        'frp' => 'Frankoprovenzalesch',
        'frr' => 'Nordfriesesch',
        'frs' => 'Ostfriesesch',
        'fur' => 'Friulesch',
        'fy' => 'Westfriesesch',
        'ga' => 'Iresch',
        'gaa' => 'Ga-Sprooch',
        'gag' => 'Gagausesch',
        'gan' => 'Gan-Chinesesch',
        'gay' => 'Gayo',
        'gba' => 'Gbaya-Sprooch',
        'gbz' => 'Zoroastrianescht Dari',
        'gd' => 'Schottescht Gällesch',
        'gez' => 'Geez',
        'gil' => 'Gilbertesesch',
        'gl' => 'Galizesch',
        'glk' => 'Gilaki',
        'gmh' => 'Mëttelhéichdäitsch',
        'gn' => 'Guarani',
        'goh' => 'Alhéichdäitsch',
        'gon' => 'Gondi-Sprooch',
        'gor' => 'Mongondou',
        'got' => 'Gotesch',
        'grb' => 'Grebo-Sprooch',
        'grc' => 'Algriichesch',
        'gsw' => 'Schwäizerdäitsch',
        'gu' => 'Gujarati',
        'guc' => 'Wayuu',
        'gur' => 'Farefare',
        'guz' => 'Gusii-Sprooch',
        'gv' => 'Manx',
        'gwi' => 'Kutchin-Sprooch',
        'ha' => 'Hausa',
        'hai' => 'Haida-Sprooch',
        'hak' => 'Hakka-Chinesesch',
        'haw' => 'Hawaiesch',
        'he' => 'Hebräesch',
        'hi' => 'Hindi',
        'hif' => 'Fidschi-Hindi',
        'hil' => 'Hiligaynon-Sprooch',
        'hit' => 'Hethitesch',
        'hmn' => 'Miao-Sprooch',
        'ho' => 'Hiri-Motu',
        'hr' => 'Kroatesch',
        'hsb' => 'Uewersorbesch',
        'hsn' => 'Xiang-Chinesesch',
        'ht' => 'Haitianesch',
        'hu' => 'Ungaresch',
        'hup' => 'Hupa',
        'hy' => 'Armenesch',
        'hz' => 'Herero-Sprooch',
        'ia' => 'Interlingua',
        'iba' => 'Iban',
        'ibb' => 'Ibibio',
        'id' => 'Indonesesch',
        'ie' => 'Interlingue',
        'ig' => 'Igbo-Sprooch',
        'ii' => 'Sichuan Yi',
        'ik' => 'Inupiak',
        'ilo' => 'Ilokano-Sprooch',
        'inh' => 'Inguschesch',
        'io' => 'Ido-Sprooch',
        'is' => 'Islännesch',
        'it' => 'Italienesch',
        'iu' => 'Inukitut',
        'izh' => 'Ischoresch',
        'ja' => 'Japanesch',
        'jam' => 'Jamaikanesch-Kreolesch',
        'jbo' => 'Lojban',
        'jgo' => 'Ngomba',
        'jmc' => 'Machame',
        'jpr' => 'Jiddesch-Persesch',
        'jrb' => 'Jiddesch-Arabesch',
        'jut' => 'Jütesch',
        'jv' => 'Javanesch',
        'ka' => 'Georgesch',
        'kaa' => 'Karakalpakesch',
        'kab' => 'Kabylesch',
        'kac' => 'Kachin-Sprooch',
        'kaj' => 'Jju',
        'kam' => 'Kamba',
        'kaw' => 'Kawi',
        'kbd' => 'Kabardinesch',
        'kbl' => 'Kanembu',
        'kcg' => 'Tyap',
        'kde' => 'Makonde',
        'kea' => 'Kabuverdianu',
        'ken' => 'Kenyang',
        'kfo' => 'Koro',
        'kg' => 'Kongolesesch',
        'kgp' => 'Kaingang',
        'kha' => 'Khasi-Sprooch',
        'kho' => 'Sakesch',
        'khq' => 'Koyra Chiini',
        'khw' => 'Khowar',
        'ki' => 'Kikuyu-Sprooch',
        'kiu' => 'Kirmanjki',
        'kj' => 'Kwanyama',
        'kk' => 'Kasachesch',
        'kkj' => 'Kako',
        'kl' => 'Grönlännesch',
        'kln' => 'Kalenjin',
        'km' => 'Kambodschanesch',
        'kmb' => 'Kimbundu-Sprooch',
        'kn' => 'Kannada',
        'ko' => 'Koreanesch',
        'koi' => 'Komi-Permiak',
        'kok' => 'Konkani',
        'kos' => 'Kosraeanesch',
        'kpe' => 'Kpelle-Sprooch',
        'kr' => 'Kanuri-Sprooch',
        'krc' => 'Karatschaiesch-Balkaresch',
        'kri' => 'Krio',
        'krj' => 'Kinaray-a',
        'krl' => 'Karelesch',
        'kru' => 'Oraon-Sprooch',
        'ks' => 'Kaschmiresch',
        'ksb' => 'Shambala',
        'ksf' => 'Bafia',
        'ksh' => 'Kölsch',
        'ku' => 'Kurdesch',
        'kum' => 'Kumükesch',
        'kut' => 'Kutenai-Sprooch',
        'kv' => 'Komi-Sprooch',
        'kw' => 'Kornesch',
        'ky' => 'Kirgisesch',
        'la' => 'Latäin',
        'lad' => 'Ladino',
        'lag' => 'Langi',
        'lah' => 'Lahnda',
        'lam' => 'Lamba-Sprooch',
        'lb' => 'Lëtzebuergesch',
        'lez' => 'Lesgesch',
        'lfn' => 'Lingua Franca Nova',
        'lg' => 'Ganda-Sprooch',
        'li' => 'Limburgesch',
        'lij' => 'Liguresch',
        'liv' => 'Livesch',
        'lkt' => 'Lakota-Sprooch',
        'lmo' => 'Lombardesch',
        'ln' => 'Lingala',
        'lo' => 'Laotesch',
        'lol' => 'Mongo',
        'loz' => 'Rotse-Sprooch',
        'lt' => 'Litauesch',
        'ltg' => 'Lettgallesch',
        'lu' => 'Luba-Katanga',
        'lua' => 'Luba-Lulua',
        'lui' => 'Luiseno-Sprooch',
        'lun' => 'Lunda-Sprooch',
        'luo' => 'Luo-Sprooch',
        'lus' => 'Lushai-Sprooch',
        'luy' => 'Olulujia',
        'lv' => 'Lettesch',
        'lzh' => 'Klassescht Chinesesch',
        'lzz' => 'Lasesch Sprooch',
        'mad' => 'Maduresesch',
        'maf' => 'Mafa',
        'mag' => 'Khotta',
        'mai' => 'Maithili',
        'mak' => 'Makassaresch',
        'man' => 'Manding-Sprooch',
        'mas' => 'Massai-Sprooch',
        'mde' => 'Maba',
        'mdf' => 'Moksha',
        'mdr' => 'Mandaresesch',
        'men' => 'Mende-Sprooch',
        'mer' => 'Meru-Sprooch',
        'mfe' => 'Morisyen',
        'mg' => 'Malagassi-Sprooch',
        'mga' => 'Mëtteliresch',
        'mgh' => 'Makhuwa-Meetto',
        'mgo' => 'Meta’',
        'mh' => 'Marschallesesch',
        'mi' => 'Maori',
        'mic' => 'Micmac-Sprooch',
        'min' => 'Minangkabau-Sprooch',
        'mk' => 'Mazedonesch',
        'ml' => 'Malayalam',
        'mn' => 'Mongolesch',
        'mnc' => 'Mandschuresch',
        'mni' => 'Meithei-Sprooch',
        'moh' => 'Mohawk-Sprooch',
        'mos' => 'Mossi-Sprooch',
        'mr' => 'Marathi',
        'mrj' => 'West-Mari',
        'ms' => 'Malaiesch',
        'mt' => 'Maltesesch',
        'mua' => 'Mundang',
        'mus' => 'Muskogee-Sprooch',
        'mwl' => 'Mirandesesch',
        'mwr' => 'Marwari',
        'mwv' => 'Mentawai',
        'my' => 'Birmanesch',
        'mye' => 'Myene',
        'myv' => 'Ersja-Mordwinesch',
        'mzn' => 'Mazandarani',
        'na' => 'Nauruesch',
        'nan' => 'Min-Nan-Chinesesch',
        'nap' => 'Neapolitanesch',
        'naq' => 'Nama',
        'nb' => 'Norwegesch Bokmål',
        'nd' => 'Nord-Ndebele-Sprooch',
        'nds' => 'Nidderdäitsch',
        'ne' => 'Nepalesesch',
        'new' => 'Newari',
        'ng' => 'Ndonga',
        'nia' => 'Nias-Sprooch',
        'niu' => 'Niue-Sprooch',
        'njo' => 'Ao Naga',
        'nl' => 'Hollännesch',
        'nmg' => 'Kwasio',
        'nn' => 'Norwegesch Nynorsk',
        'nnh' => 'Ngiemboon',
        'no' => 'Norwegesch',
        'nog' => 'Nogai',
        'non' => 'Alnordesch',
        'nov' => 'Novial',
        'nqo' => 'N’Ko',
        'nr' => 'Süd-Ndebele-Sprooch',
        'nso' => 'Nord-Sotho-Sprooch',
        'nus' => 'Nuer',
        'nv' => 'Navajo',
        'nwc' => 'Al-Newari',
        'ny' => 'Nyanja-Sprooch',
        'nym' => 'Nyamwezi-Sprooch',
        'nyn' => 'Nyankole',
        'nyo' => 'Nyoro',
        'nzi' => 'Nzima',
        'oc' => 'Okzitanesch',
        'oj' => 'Ojibwa-Sprooch',
        'om' => 'Oromo',
        'or' => 'Orija',
        'os' => 'Ossetesch',
        'osa' => 'Osage-Sprooch',
        'ota' => 'Osmanesch',
        'pa' => 'Pandschabesch',
        'pag' => 'Pangasinan-Sprooch',
        'pal' => 'Mëttelpersesch',
        'pam' => 'Pampanggan-Sprooch',
        'pap' => 'Papiamento',
        'pau' => 'Palau',
        'pcd' => 'Picardesch',
        'pdc' => 'Pennsylvaniadäitsch',
        'pdt' => 'Plattdäitsch',
        'peo' => 'Alpersesch',
        'pfl' => 'Pfälzesch Däitsch',
        'phn' => 'Phönikesch',
        'pi' => 'Pali',
        'pl' => 'Polnesch',
        'pms' => 'Piemontesesch',
        'pnt' => 'Pontesch',
        'pon' => 'Ponapeanesch',
        'prg' => 'Preisesch',
        'pro' => 'Alprovenzalesch',
        'ps' => 'Paschtu',
        'pt' => 'Portugisesch',
        'qu' => 'Quechua',
        'quc' => 'Quiché-Sprooch',
        'qug' => 'Kichwa (Chimborazo-Gebidder)',
        'raj' => 'Rajasthani',
        'rap' => 'Ouschterinsel-Sprooch',
        'rar' => 'Rarotonganesch',
        'rgn' => 'Romagnol',
        'rif' => 'Tarifit',
        'rm' => 'Rätoromanesch',
        'rn' => 'Rundi-Sprooch',
        'ro' => 'Rumänesch',
        'rof' => 'Rombo',
        'rom' => 'Romani',
        'rtm' => 'Rotumanesch',
        'ru' => 'Russesch',
        'rue' => 'Russinesch',
        'rug' => 'Roviana',
        'rup' => 'Aromunesch',
        'rw' => 'Ruandesch',
        'rwk' => 'Rwa',
        'sa' => 'Sanskrit',
        'sad' => 'Sandawe-Sprooch',
        'sah' => 'Jakutesch',
        'sam' => 'Samaritanesch',
        'saq' => 'Samburu',
        'sas' => 'Sasak',
        'sat' => 'Santali',
        'saz' => 'Saurashtra',
        'sba' => 'Ngambay',
        'sbp' => 'Sangu',
        'sc' => 'Sardesch',
        'scn' => 'Sizilianesch',
        'sco' => 'Schottesch',
        'sd' => 'Sindhi',
        'sdc' => 'Sassaresesch',
        'se' => 'Nordsamesch',
        'see' => 'Seneca',
        'seh' => 'Sena',
        'sei' => 'Seri',
        'sel' => 'Selkupesch',
        'ses' => 'Koyra Senni',
        'sg' => 'Sango',
        'sga' => 'Aliresch',
        'sgs' => 'Samogitesch',
        'sh' => 'Serbo-Kroatesch',
        'shi' => 'Taschelhit',
        'shn' => 'Schan-Sprooch',
        'shu' => 'Tschadesch-Arabesch',
        'si' => 'Singhalesesch',
        'sid' => 'Sidamo',
        'sk' => 'Slowakesch',
        'sl' => 'Slowenesch',
        'sli' => 'Nidderschlesesch',
        'sly' => 'Selayar',
        'sm' => 'Samoanesch',
        'sma' => 'Südsamesch',
        'smj' => 'Lule-Lappesch',
        'smn' => 'Inari-Lappesch',
        'sms' => 'Skolt-Lappesch',
        'sn' => 'Shona',
        'snk' => 'Soninke-Sprooch',
        'so' => 'Somali',
        'sog' => 'Sogdesch',
        'sq' => 'Albanesch',
        'sr' => 'Serbesch',
        'srn' => 'Srananesch',
        'srr' => 'Serer-Sprooch',
        'ss' => 'Swazi',
        'ssy' => 'Saho',
        'st' => 'Süd-Sotho-Sprooch',
        'stq' => 'Saterfriesesch',
        'su' => 'Sundanesesch',
        'suk' => 'Sukuma-Sprooch',
        'sus' => 'Susu',
        'sux' => 'Sumeresch',
        'sv' => 'Schwedesch',
        'sw' => 'Suaheli',
        'swb' => 'Komoresch',
        'syc' => 'Alsyresch',
        'syr' => 'Syresch',
        'szl' => 'Schlesesch',
        'ta' => 'Tamilesch',
        'tcy' => 'Tulu',
        'te' => 'Telugu',
        'tem' => 'Temne',
        'teo' => 'Teso',
        'ter' => 'Tereno-Sprooch',
        'tet' => 'Tetum-Sprooch',
        'tg' => 'Tadschikesch',
        'th' => 'Thailännesch',
        'ti' => 'Tigrinja',
        'tig' => 'Tigre',
        'tiv' => 'Tiv-Sprooch',
        'tk' => 'Turkmenesch',
        'tkl' => 'Tokelauanesch',
        'tkr' => 'Tsachuresch',
        'tl' => 'Dagalog',
        'tlh' => 'Klingonesch',
        'tli' => 'Tlingit-Sprooch',
        'tly' => 'Talesch',
        'tmh' => 'Tamaseq',
        'tn' => 'Tswana-Sprooch',
        'to' => 'Tongaesch',
        'tog' => 'Tsonga-Sprooch',
        'tpi' => 'Neimelanesesch',
        'tr' => 'Tierkesch',
        'tru' => 'Turoyo',
        'trv' => 'Seediq',
        'ts' => 'Tsonga',
        'tsd' => 'Tsakonesch',
        'tsi' => 'Tsimshian-Sprooch',
        'tt' => 'Tataresch',
        'ttt' => 'Tatesch',
        'tum' => 'Tumbuka-Sprooch',
        'tvl' => 'Elliceanesch',
        'tw' => 'Twi',
        'twq' => 'Tasawaq',
        'ty' => 'Tahitesch',
        'tyv' => 'Tuwinesch',
        'tzm' => 'Mëttlert-Atlas-Tamazight',
        'udm' => 'Udmurtesch',
        'ug' => 'Uiguresch',
        'uga' => 'Ugaritesch',
        'uk' => 'Ukrainesch',
        'umb' => 'Mbundu-Sprooch',
        'ur' => 'Urdu',
        'uz' => 'Usbekesch',
        'vai' => 'Vai-Sprooch',
        've' => 'Venda-Sprooch',
        'vec' => 'Venezesch',
        'vep' => 'Wepsesch',
        'vi' => 'Vietnamesesch',
        'vls' => 'Westflämesch',
        'vmf' => 'Mainfränkesch',
        'vo' => 'Volapük',
        'vot' => 'Wotesch',
        'vro' => 'Voro',
        'vun' => 'Vunjo',
        'wa' => 'Wallounesch',
        'wae' => 'Walliserdäitsch',
        'wal' => 'Walamo-Sprooch',
        'war' => 'Waray',
        'was' => 'Washo-Sprooch',
        'wo' => 'Wolof',
        'wuu' => 'Wu-Chinesesch',
        'xal' => 'Kalmückesch',
        'xh' => 'Xhosa',
        'xmf' => 'Mingrelesch Sprooch',
        'xog' => 'Soga',
        'yao' => 'Yao-Sprooch',
        'yap' => 'Yapesesch',
        'yav' => 'Yangben',
        'ybb' => 'Yemba',
        'yi' => 'Jiddesch',
        'yo' => 'Yoruba',
        'yrl' => 'Nheengatu',
        'yue' => 'Kantonesesch',
        'za' => 'Zhuang',
        'zap' => 'Zapotekesch',
        'zbl' => 'Bliss-Symboler',
        'zea' => 'Seelännesch',
        'zen' => 'Zenaga',
        'zgh' => 'Marokkanescht Standard-Tamazight',
        'zh' => 'Chinesesch',
        'zu' => 'Zulu',
        'zun' => 'Zuni-Sprooch',
        'zza' => 'Zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Modernt Héicharabesch',
        'de_AT' => 'Éisträichescht Däitsch',
        'de_CH' => 'Schwäizer Héichdäitsch',
        'en_AU' => 'Australescht Englesch',
        'en_CA' => 'Kanadescht Englesch',
        'en_GB' => 'Britescht Englesch',
        'en_US' => 'Amerikanescht Englesch',
        'es_419' => 'Latäinamerikanescht Spuenesch',
        'es_ES' => 'Europäescht Spuenesch',
        'es_MX' => 'Mexikanescht Spuenesch',
        'fr_CA' => 'Kanadescht Franséisch',
        'fr_CH' => 'Schwäizer Franséisch',
        'nl_BE' => 'Flämesch',
        'pt_BR' => 'Brasilianescht Portugisesch',
        'pt_PT' => 'Europäescht Portugisesch',
        'ro_MD' => 'Moldawesch',
        'sw_CD' => 'Kongo-Swahili',
        'zh_Hans' => 'Chinesesch (vereinfacht)',
        'zh_Hant' => 'Chinesesch (traditionell)',
    ],
];
