<?php

return [
    'Names' => [
        'ace' => 'acehgiella',
        'af' => 'afrikánsagiella',
        'an' => 'aragoniagiella',
        'ang' => 'boares eaŋgalasgiella',
        'ar' => 'arábagiella',
        'ast' => 'asturiagiella',
        'be' => 'vilges-ruoššagiella',
        'bg' => 'bulgáriagiella',
        'bn' => 'bengalgiella',
        'bo' => 'tibetagiella',
        'br' => 'bretonagiella',
        'bs' => 'bosniagiella',
        'ca' => 'katalánagiella',
        'chm' => 'marigiella',
        'co' => 'corsicagiella',
        'cs' => 'čeahkagiella',
        'cy' => 'kymragiella',
        'da' => 'dánskkagiella',
        'de' => 'duiskkagiella',
        'dv' => 'divehigiella',
        'dz' => 'dzongkhagiella',
        'el' => 'greikkagiella',
        'en' => 'eaŋgalsgiella',
        'es' => 'spánskkagiella',
        'et' => 'esttegiella',
        'fa' => 'persijagiella',
        'fi' => 'suomagiella',
        'fil' => 'filippiinnagiella',
        'fj' => 'fidjigiella',
        'fo' => 'fearagiella',
        'fr' => 'fránskkagiella',
        'fy' => 'oarjifriisagiella',
        'ga' => 'iirragiella',
        'gu' => 'gujaratagiella',
        'gv' => 'manksgiella',
        'ha' => 'haussagiella',
        'haw' => 'hawaiigiella',
        'hi' => 'hindigiella',
        'hr' => 'kroátiagiella',
        'ht' => 'haitigiella',
        'hu' => 'ungárgiella',
        'hy' => 'armeenagiella',
        'id' => 'indonesiagiella',
        'is' => 'islánddagiella',
        'it' => 'itáliagiella',
        'ja' => 'japánagiella',
        'jv' => 'javagiella',
        'ka' => 'georgiagiella',
        'kk' => 'kazakgiella',
        'km' => 'kambodiagiella',
        'ko' => 'koreagiella',
        'krl' => 'gárjilgiella',
        'ku' => 'kurdigiella',
        'kv' => 'komigiella',
        'kw' => 'kornagiella',
        'la' => 'láhtengiella',
        'lb' => 'luxemburggagiella',
        'lo' => 'laogiella',
        'lt' => 'liettuvagiella',
        'lv' => 'látviagiella',
        'mdf' => 'mokšagiella',
        'mi' => 'maorigiella',
        'mk' => 'makedoniagiella',
        'mn' => 'mongoliagiella',
        'mt' => 'maltagiella',
        'my' => 'burmagiella',
        'myv' => 'ersagiella',
        'nb' => 'girjedárogiella',
        'ne' => 'nepaligiella',
        'nl' => 'hollánddagiella',
        'nn' => 'ođđadárogiella',
        'no' => 'dárogiella',
        'oc' => 'oksitánagiella',
        'pa' => 'panjabigiella',
        'pl' => 'polskkagiella',
        'pt' => 'portugálagiella',
        'rm' => 'romanšgiella',
        'ro' => 'romániagiella',
        'ru' => 'ruoššagiella',
        'sc' => 'sardigiella',
        'scn' => 'sisiliagiella',
        'se' => 'davvisámegiella',
        'sel' => 'selkupagiella',
        'sh' => 'serbokroatiagiella',
        'sk' => 'slovákiagiella',
        'sl' => 'slovenagiella',
        'sm' => 'samoagiella',
        'sma' => 'lullisámegiella',
        'smj' => 'julevsámegiella',
        'smn' => 'anárašgiella',
        'sms' => 'nuortalašgiella',
        'sq' => 'albánagiella',
        'sr' => 'serbiagiella',
        'sv' => 'ruoŧagiella',
        'swb' => 'shimaorigiella',
        'th' => 'ŧaigiella',
        'tr' => 'durkagiella',
        'ty' => 'tahitigiella',
        'udm' => 'udmurtagiella',
        'uk' => 'ukrainagiella',
        'ur' => 'urdugiella',
        'vi' => 'vietnamgiella',
        'wa' => 'vallonagiella',
        'yue' => 'kantongiella',
        'zh' => 'kiinnágiella',
    ],
    'LocalizedNames' => [
        'zh_Hans' => 'álki kiinágiella',
        'zh_Hant' => 'árbevirolaš kiinnágiella',
    ],
];
