<?php

return [
    'Names' => [
        'aa' => 'Tiếng Afar',
        'ab' => 'Tiếng Abkhazia',
        'ace' => 'Tiếng Achinese',
        'ach' => 'Tiếng Acoli',
        'ada' => 'Tiếng Adangme',
        'ady' => 'Tiếng Adyghe',
        'ae' => 'Tiếng Avestan',
        'af' => 'Tiếng Hà Lan (Nam Phi)',
        'afh' => 'Tiếng Afrihili',
        'agq' => 'Tiếng Aghem',
        'ain' => 'Tiếng Ainu',
        'ak' => 'Tiếng Akan',
        'akk' => 'Tiếng Akkadia',
        'akz' => 'Tiếng Alabama',
        'ale' => 'Tiếng Aleut',
        'aln' => 'Tiếng Gheg Albani',
        'alt' => 'Tiếng Altai Miền Nam',
        'am' => 'Tiếng Amharic',
        'an' => 'Tiếng Aragon',
        'ang' => 'Tiếng Anh cổ',
        'ann' => 'Tiếng Obolo',
        'anp' => 'Tiếng Angika',
        'ar' => 'Tiếng Ả Rập',
        'arc' => 'Tiếng Aramaic',
        'arn' => 'Tiếng Mapuche',
        'aro' => 'Tiếng Araona',
        'arp' => 'Tiếng Arapaho',
        'arq' => 'Tiếng Ả Rập Algeria',
        'ars' => 'Tiếng Ả Rập Najdi',
        'arw' => 'Tiếng Arawak',
        'arz' => 'Tiếng Ả Rập Ai Cập',
        'as' => 'Tiếng Assam',
        'asa' => 'Tiếng Asu',
        'ase' => 'Ngôn ngữ Ký hiệu Mỹ',
        'ast' => 'Tiếng Asturias',
        'atj' => 'Tiếng Atikamekw',
        'av' => 'Tiếng Avaric',
        'awa' => 'Tiếng Awadhi',
        'ay' => 'Tiếng Aymara',
        'az' => 'Tiếng Azerbaijan',
        'ba' => 'Tiếng Bashkir',
        'bal' => 'Tiếng Baloch',
        'ban' => 'Tiếng Bali',
        'bar' => 'Tiếng Bavaria',
        'bas' => 'Tiếng Basaa',
        'bax' => 'Tiếng Bamun',
        'bbc' => 'Tiếng Batak Toba',
        'bbj' => 'Tiếng Ghomala',
        'be' => 'Tiếng Belarus',
        'bej' => 'Tiếng Beja',
        'bem' => 'Tiếng Bemba',
        'bew' => 'Tiếng Betawi',
        'bez' => 'Tiếng Bena',
        'bfd' => 'Tiếng Bafut',
        'bfq' => 'Tiếng Badaga',
        'bg' => 'Tiếng Bulgaria',
        'bgc' => 'Tiếng Haryana',
        'bgn' => 'Tiếng Tây Balochi',
        'bho' => 'Tiếng Bhojpuri',
        'bi' => 'Tiếng Bislama',
        'bik' => 'Tiếng Bikol',
        'bin' => 'Tiếng Bini',
        'bjn' => 'Tiếng Banjar',
        'bkm' => 'Tiếng Kom',
        'bla' => 'Tiếng Siksika',
        'blo' => 'Anii',
        'bm' => 'Tiếng Bambara',
        'bn' => 'Tiếng Bangla',
        'bo' => 'Tiếng Tây Tạng',
        'bpy' => 'Tiếng Bishnupriya',
        'bqi' => 'Tiếng Bakhtiari',
        'br' => 'Tiếng Breton',
        'bra' => 'Tiếng Braj',
        'brh' => 'Tiếng Brahui',
        'brx' => 'Tiếng Bodo',
        'bs' => 'Tiếng Bosnia',
        'bss' => 'Tiếng Akoose',
        'bua' => 'Tiếng Buriat',
        'bug' => 'Tiếng Bugin',
        'bum' => 'Tiếng Bulu',
        'byn' => 'Tiếng Blin',
        'byv' => 'Tiếng Medumba',
        'ca' => 'Tiếng Catalan',
        'cad' => 'Tiếng Caddo',
        'car' => 'Tiếng Carib',
        'cay' => 'Tiếng Cayuga',
        'cch' => 'Tiếng Atsam',
        'ccp' => 'Tiếng Chakma',
        'ce' => 'Tiếng Chechen',
        'ceb' => 'Tiếng Cebuano',
        'cgg' => 'Tiếng Chiga',
        'ch' => 'Tiếng Chamorro',
        'chb' => 'Tiếng Chibcha',
        'chg' => 'Tiếng Chagatai',
        'chk' => 'Tiếng Chuuk',
        'chm' => 'Tiếng Mari',
        'chn' => 'Biệt ngữ Chinook',
        'cho' => 'Tiếng Choctaw',
        'chp' => 'Tiếng Chipewyan',
        'chr' => 'Tiếng Cherokee',
        'chy' => 'Tiếng Cheyenne',
        'ckb' => 'Tiếng Kurd Miền Trung',
        'clc' => 'Tiếng Chilcotin',
        'co' => 'Tiếng Corsica',
        'cop' => 'Tiếng Coptic',
        'cps' => 'Tiếng Capiznon',
        'cr' => 'Tiếng Cree',
        'crg' => 'Tiếng Michif',
        'crh' => 'Tiếng Thổ Nhĩ Kỳ Crimean',
        'crj' => 'Tiếng Cree Đông Nam',
        'crk' => 'Tiếng Plains Cree',
        'crl' => 'Tiếng Cree Đông Bắc',
        'crm' => 'Tiếng Moose Cree',
        'crr' => 'Tiếng Carolina Algonquian',
        'crs' => 'Tiếng Pháp Seselwa Creole',
        'cs' => 'Tiếng Séc',
        'csb' => 'Tiếng Kashubia',
        'csw' => 'Tiếng Swampy Cree',
        'cu' => 'Tiếng Slavơ Nhà thờ',
        'cv' => 'Tiếng Chuvash',
        'cy' => 'Tiếng Wales',
        'da' => 'Tiếng Đan Mạch',
        'dak' => 'Tiếng Dakota',
        'dar' => 'Tiếng Dargwa',
        'dav' => 'Tiếng Taita',
        'de' => 'Tiếng Đức',
        'del' => 'Tiếng Delaware',
        'den' => 'Tiếng Slave',
        'dgr' => 'Tiếng Dogrib',
        'din' => 'Tiếng Dinka',
        'dje' => 'Tiếng Zarma',
        'doi' => 'Tiếng Dogri',
        'dsb' => 'Tiếng Hạ Sorbia',
        'dtp' => 'Tiếng Dusun Miền Trung',
        'dua' => 'Tiếng Duala',
        'dum' => 'Tiếng Hà Lan Trung cổ',
        'dv' => 'Tiếng Divehi',
        'dyo' => 'Tiếng Jola-Fonyi',
        'dyu' => 'Tiếng Dyula',
        'dz' => 'Tiếng Dzongkha',
        'dzg' => 'Tiếng Dazaga',
        'ebu' => 'Tiếng Embu',
        'ee' => 'Tiếng Ewe',
        'efi' => 'Tiếng Efik',
        'egl' => 'Tiếng Emilia',
        'egy' => 'Tiếng Ai Cập cổ',
        'eka' => 'Tiếng Ekajuk',
        'el' => 'Tiếng Hy Lạp',
        'elx' => 'Tiếng Elamite',
        'en' => 'Tiếng Anh',
        'enm' => 'Tiếng Anh Trung cổ',
        'eo' => 'Tiếng Quốc Tế Ngữ',
        'es' => 'Tiếng Tây Ban Nha',
        'esu' => 'Tiếng Yupik Miền Trung',
        'et' => 'Tiếng Estonia',
        'eu' => 'Tiếng Basque',
        'ewo' => 'Tiếng Ewondo',
        'ext' => 'Tiếng Extremadura',
        'fa' => 'Tiếng Ba Tư',
        'fan' => 'Tiếng Fang',
        'fat' => 'Tiếng Fanti',
        'ff' => 'Tiếng Fulah',
        'fi' => 'Tiếng Phần Lan',
        'fil' => 'Tiếng Philippines',
        'fj' => 'Tiếng Fiji',
        'fo' => 'Tiếng Faroe',
        'fon' => 'Tiếng Fon',
        'fr' => 'Tiếng Pháp',
        'frc' => 'Tiếng Pháp Cajun',
        'frm' => 'Tiếng Pháp Trung cổ',
        'fro' => 'Tiếng Pháp cổ',
        'frp' => 'Tiếng Arpitan',
        'frr' => 'Tiếng Frisia Miền Bắc',
        'frs' => 'Tiếng Frisian Miền Đông',
        'fur' => 'Tiếng Friulian',
        'fy' => 'Tiếng Frisia',
        'ga' => 'Tiếng Ireland',
        'gaa' => 'Tiếng Ga',
        'gag' => 'Tiếng Gagauz',
        'gan' => 'Tiếng Cám',
        'gay' => 'Tiếng Gayo',
        'gba' => 'Tiếng Gbaya',
        'gd' => 'Tiếng Gael Scotland',
        'gez' => 'Tiếng Geez',
        'gil' => 'Tiếng Gilbert',
        'gl' => 'Tiếng Galician',
        'glk' => 'Tiếng Gilaki',
        'gmh' => 'Tiếng Thượng Giéc-man Trung cổ',
        'gn' => 'Tiếng Guarani',
        'goh' => 'Tiếng Thượng Giéc-man cổ',
        'gon' => 'Tiếng Gondi',
        'gor' => 'Tiếng Gorontalo',
        'got' => 'Tiếng Gô-tích',
        'grb' => 'Tiếng Grebo',
        'grc' => 'Tiếng Hy Lạp cổ',
        'gsw' => 'Tiếng Đức (Thụy Sĩ)',
        'gu' => 'Tiếng Gujarati',
        'gur' => 'Tiếng Frafra',
        'guz' => 'Tiếng Gusii',
        'gv' => 'Tiếng Manx',
        'gwi' => 'Tiếng Gwichʼin',
        'ha' => 'Tiếng Hausa',
        'hai' => 'Tiếng Haida',
        'hak' => 'Tiếng Khách Gia',
        'haw' => 'Tiếng Hawaii',
        'hax' => 'Tiếng Haida miền Nam',
        'he' => 'Tiếng Do Thái',
        'hi' => 'Tiếng Hindi',
        'hif' => 'Tiếng Fiji Hindi',
        'hil' => 'Tiếng Hiligaynon',
        'hit' => 'Tiếng Hittite',
        'hmn' => 'Tiếng H’Mông',
        'ho' => 'Tiếng Hiri Motu',
        'hr' => 'Tiếng Croatia',
        'hsb' => 'Tiếng Thượng Sorbia',
        'hsn' => 'Tiếng Tương',
        'ht' => 'Tiếng Haiti',
        'hu' => 'Tiếng Hungary',
        'hup' => 'Tiếng Hupa',
        'hur' => 'Tiếng Halkomelem',
        'hy' => 'Tiếng Armenia',
        'hz' => 'Tiếng Herero',
        'ia' => 'Tiếng Khoa Học Quốc Tế',
        'iba' => 'Tiếng Iban',
        'ibb' => 'Tiếng Ibibio',
        'id' => 'Tiếng Indonesia',
        'ie' => 'Tiếng Interlingue',
        'ig' => 'Tiếng Igbo',
        'ii' => 'Tiếng Di Tứ Xuyên',
        'ik' => 'Tiếng Inupiaq',
        'ikt' => 'Tiếng Inuktitut miền Tây Canada',
        'ilo' => 'Tiếng Iloko',
        'inh' => 'Tiếng Ingush',
        'io' => 'Tiếng Ido',
        'is' => 'Tiếng Iceland',
        'it' => 'Tiếng Italy',
        'iu' => 'Tiếng Inuktitut',
        'izh' => 'Tiếng Ingria',
        'ja' => 'Tiếng Nhật',
        'jam' => 'Tiếng Anh Jamaica Creole',
        'jbo' => 'Tiếng Lojban',
        'jgo' => 'Tiếng Ngomba',
        'jmc' => 'Tiếng Machame',
        'jpr' => 'Tiếng Judeo-Ba Tư',
        'jrb' => 'Tiếng Judeo-Ả Rập',
        'jut' => 'Tiếng Jutish',
        'jv' => 'Tiếng Java',
        'ka' => 'Tiếng Georgia',
        'kaa' => 'Tiếng Kara-Kalpak',
        'kab' => 'Tiếng Kabyle',
        'kac' => 'Tiếng Kachin',
        'kaj' => 'Tiếng Jju',
        'kam' => 'Tiếng Kamba',
        'kaw' => 'Tiếng Kawi',
        'kbd' => 'Tiếng Kabardian',
        'kbl' => 'Tiếng Kanembu',
        'kcg' => 'Tiếng Tyap',
        'kde' => 'Tiếng Makonde',
        'kea' => 'Tiếng Kabuverdianu',
        'kfo' => 'Tiếng Koro',
        'kg' => 'Tiếng Kongo',
        'kgp' => 'Tiếng Kaingang',
        'kha' => 'Tiếng Khasi',
        'kho' => 'Tiếng Khotan',
        'khq' => 'Tiếng Koyra Chiini',
        'ki' => 'Tiếng Kikuyu',
        'kj' => 'Tiếng Kuanyama',
        'kk' => 'Tiếng Kazakh',
        'kkj' => 'Tiếng Kako',
        'kl' => 'Tiếng Kalaallisut',
        'kln' => 'Tiếng Kalenjin',
        'km' => 'Tiếng Khmer',
        'kmb' => 'Tiếng Kimbundu',
        'kn' => 'Tiếng Kannada',
        'ko' => 'Tiếng Hàn',
        'koi' => 'Tiếng Komi-Permyak',
        'kok' => 'Tiếng Konkani',
        'kos' => 'Tiếng Kosrae',
        'kpe' => 'Tiếng Kpelle',
        'kr' => 'Tiếng Kanuri',
        'krc' => 'Tiếng Karachay-Balkar',
        'krl' => 'Tiếng Karelian',
        'kru' => 'Tiếng Kurukh',
        'ks' => 'Tiếng Kashmir',
        'ksb' => 'Tiếng Shambala',
        'ksf' => 'Tiếng Bafia',
        'ksh' => 'Tiếng Cologne',
        'ku' => 'Tiếng Kurd',
        'kum' => 'Tiếng Kumyk',
        'kut' => 'Tiếng Kutenai',
        'kv' => 'Tiếng Komi',
        'kw' => 'Tiếng Cornwall',
        'kwk' => 'Tiếng Kwakʼwala',
        'kxv' => 'Tiếng Kuvi',
        'ky' => 'Tiếng Kyrgyz',
        'la' => 'Tiếng La-tinh',
        'lad' => 'Tiếng Ladino',
        'lag' => 'Tiếng Langi',
        'lah' => 'Tiếng Lahnda',
        'lam' => 'Tiếng Lamba',
        'lb' => 'Tiếng Luxembourg',
        'lez' => 'Tiếng Lezghian',
        'lg' => 'Tiếng Ganda',
        'li' => 'Tiếng Limburg',
        'lij' => 'Tiếng Liguria',
        'lil' => 'Tiếng Lillooet',
        'lkt' => 'Tiếng Lakota',
        'lmo' => 'Tiếng Lombard',
        'ln' => 'Tiếng Lingala',
        'lo' => 'Tiếng Lào',
        'lol' => 'Tiếng Mongo',
        'lou' => 'Tiếng Creole Louisiana',
        'loz' => 'Tiếng Lozi',
        'lrc' => 'Tiếng Bắc Luri',
        'lsm' => 'Tiếng Saamia',
        'lt' => 'Tiếng Litva',
        'lu' => 'Tiếng Luba-Katanga',
        'lua' => 'Tiếng Luba-Lulua',
        'lui' => 'Tiếng Luiseno',
        'lun' => 'Tiếng Lunda',
        'luo' => 'Tiếng Luo',
        'lus' => 'Tiếng Lushai',
        'luy' => 'Tiếng Luyia',
        'lv' => 'Tiếng Latvia',
        'mad' => 'Tiếng Madura',
        'maf' => 'Tiếng Mafa',
        'mag' => 'Tiếng Magahi',
        'mai' => 'Tiếng Maithili',
        'mak' => 'Tiếng Makasar',
        'man' => 'Tiếng Mandingo',
        'mas' => 'Tiếng Masai',
        'mde' => 'Tiếng Maba',
        'mdf' => 'Tiếng Moksha',
        'mdr' => 'Tiếng Mandar',
        'men' => 'Tiếng Mende',
        'mer' => 'Tiếng Meru',
        'mfe' => 'Tiếng Morisyen',
        'mg' => 'Tiếng Malagasy',
        'mga' => 'Tiếng Ai-len Trung cổ',
        'mgh' => 'Tiếng Makhuwa-Meetto',
        'mgo' => 'Tiếng Meta’',
        'mh' => 'Tiếng Marshall',
        'mi' => 'Tiếng Māori',
        'mic' => 'Tiếng Micmac',
        'min' => 'Tiếng Minangkabau',
        'mk' => 'Tiếng Macedonia',
        'ml' => 'Tiếng Malayalam',
        'mn' => 'Tiếng Mông Cổ',
        'mnc' => 'Tiếng Mãn Châu',
        'mni' => 'Tiếng Manipuri',
        'moe' => 'Tiếng Innu-aimun',
        'moh' => 'Tiếng Mohawk',
        'mos' => 'Tiếng Mossi',
        'mr' => 'Tiếng Marathi',
        'ms' => 'Tiếng Mã Lai',
        'mt' => 'Tiếng Malta',
        'mua' => 'Tiếng Mundang',
        'mus' => 'Tiếng Creek',
        'mwl' => 'Tiếng Miranda',
        'mwr' => 'Tiếng Marwari',
        'my' => 'Tiếng Miến Điện',
        'mye' => 'Tiếng Myene',
        'myv' => 'Tiếng Erzya',
        'mzn' => 'Tiếng Mazanderani',
        'na' => 'Tiếng Nauru',
        'nan' => 'Tiếng Mân Nam',
        'nap' => 'Tiếng Napoli',
        'naq' => 'Tiếng Nama',
        'nb' => 'Tiếng Na Uy (Bokmål)',
        'nd' => 'Tiếng Ndebele Miền Bắc',
        'nds' => 'Tiếng Hạ Đức',
        'ne' => 'Tiếng Nepal',
        'new' => 'Tiếng Newari',
        'ng' => 'Tiếng Ndonga',
        'nia' => 'Tiếng Nias',
        'niu' => 'Tiếng Niuean',
        'njo' => 'Tiếng Ao Naga',
        'nl' => 'Tiếng Hà Lan',
        'nmg' => 'Tiếng Kwasio',
        'nn' => 'Tiếng Na Uy (Nynorsk)',
        'nnh' => 'Tiếng Ngiemboon',
        'no' => 'Tiếng Na Uy',
        'nog' => 'Tiếng Nogai',
        'non' => 'Tiếng Na Uy cổ',
        'nqo' => 'Tiếng N’Ko',
        'nr' => 'Tiếng Ndebele Miền Nam',
        'nso' => 'Tiếng Bắc Sotho',
        'nus' => 'Tiếng Nuer',
        'nv' => 'Tiếng Navajo',
        'nwc' => 'Tiếng Newari cổ',
        'ny' => 'Tiếng Nyanja',
        'nym' => 'Tiếng Nyamwezi',
        'nyn' => 'Tiếng Nyankole',
        'nyo' => 'Tiếng Nyoro',
        'nzi' => 'Tiếng Nzima',
        'oc' => 'Tiếng Occitan',
        'oj' => 'Tiếng Ojibwa',
        'ojb' => 'Tiếng Ojibwe Tây Bắc',
        'ojc' => 'Tiếng Ojibwe miền Trung',
        'ojs' => 'Tiếng Oji-Cree',
        'ojw' => 'Tiếng Ojibwe miền Tây',
        'oka' => 'Tiếng Okanagan',
        'om' => 'Tiếng Oromo',
        'or' => 'Tiếng Odia',
        'os' => 'Tiếng Ossetic',
        'osa' => 'Tiếng Osage',
        'ota' => 'Tiếng Thổ Nhĩ Kỳ Ottoman',
        'pa' => 'Tiếng Punjab',
        'pag' => 'Tiếng Pangasinan',
        'pal' => 'Tiếng Pahlavi',
        'pam' => 'Tiếng Pampanga',
        'pap' => 'Tiếng Papiamento',
        'pau' => 'Tiếng Palauan',
        'pcm' => 'Pidgin Nigeria',
        'peo' => 'Tiếng Ba Tư cổ',
        'phn' => 'Tiếng Phoenicia',
        'pi' => 'Tiếng Pali',
        'pis' => 'Tiếng Pijin',
        'pl' => 'Tiếng Ba Lan',
        'pon' => 'Tiếng Pohnpeian',
        'pqm' => 'Tiếng Maliseet-Passamaquoddy',
        'prg' => 'Tiếng Prussia',
        'pro' => 'Tiếng Provençal cổ',
        'ps' => 'Tiếng Pashto',
        'pt' => 'Tiếng Bồ Đào Nha',
        'qu' => 'Tiếng Quechua',
        'quc' => 'Tiếng Kʼicheʼ',
        'qug' => 'Tiếng Quechua ở Cao nguyên Chimborazo',
        'raj' => 'Tiếng Rajasthani',
        'rap' => 'Tiếng Rapanui',
        'rar' => 'Tiếng Rarotongan',
        'rhg' => 'Tiếng Rohingya',
        'rm' => 'Tiếng Romansh',
        'rn' => 'Tiếng Rundi',
        'ro' => 'Tiếng Romania',
        'rof' => 'Tiếng Rombo',
        'rom' => 'Tiếng Romany',
        'ru' => 'Tiếng Nga',
        'rup' => 'Tiếng Aromania',
        'rw' => 'Tiếng Kinyarwanda',
        'rwk' => 'Tiếng Rwa',
        'sa' => 'Tiếng Phạn',
        'sad' => 'Tiếng Sandawe',
        'sah' => 'Tiếng Sakha',
        'sam' => 'Tiếng Samaritan Aramaic',
        'saq' => 'Tiếng Samburu',
        'sas' => 'Tiếng Sasak',
        'sat' => 'Tiếng Santali',
        'sba' => 'Tiếng Ngambay',
        'sbp' => 'Tiếng Sangu',
        'sc' => 'Tiếng Sardinia',
        'scn' => 'Tiếng Sicilia',
        'sco' => 'Tiếng Scots',
        'sd' => 'Tiếng Sindhi',
        'sdh' => 'Tiếng Kurd Miền Nam',
        'se' => 'Tiếng Sami Miền Bắc',
        'see' => 'Tiếng Seneca',
        'seh' => 'Tiếng Sena',
        'sel' => 'Tiếng Selkup',
        'ses' => 'Tiếng Koyraboro Senni',
        'sg' => 'Tiếng Sango',
        'sga' => 'Tiếng Ai-len cổ',
        'sh' => 'Tiếng Serbo-Croatia',
        'shi' => 'Tiếng Tachelhit',
        'shn' => 'Tiếng Shan',
        'shu' => 'Tiếng Ả-Rập Chad',
        'si' => 'Tiếng Sinhala',
        'sid' => 'Tiếng Sidamo',
        'sk' => 'Tiếng Slovak',
        'sl' => 'Tiếng Slovenia',
        'slh' => 'Tiếng Lushootseed miền Nam',
        'sm' => 'Tiếng Samoa',
        'sma' => 'Tiếng Sami Miền Nam',
        'smj' => 'Tiếng Lule Sami',
        'smn' => 'Tiếng Inari Sami',
        'sms' => 'Tiếng Skolt Sami',
        'sn' => 'Tiếng Shona',
        'snk' => 'Tiếng Soninke',
        'so' => 'Tiếng Somali',
        'sog' => 'Tiếng Sogdien',
        'sq' => 'Tiếng Albania',
        'sr' => 'Tiếng Serbia',
        'srn' => 'Tiếng Sranan Tongo',
        'srr' => 'Tiếng Serer',
        'ss' => 'Tiếng Swati',
        'ssy' => 'Tiếng Saho',
        'st' => 'Tiếng Nam Sotho',
        'str' => 'Tiếng Straits Salish',
        'su' => 'Tiếng Sunda',
        'suk' => 'Tiếng Sukuma',
        'sus' => 'Tiếng Susu',
        'sux' => 'Tiếng Sumeria',
        'sv' => 'Tiếng Thụy Điển',
        'sw' => 'Tiếng Swahili',
        'swb' => 'Tiếng Cômo',
        'syc' => 'Tiếng Syriac cổ',
        'syr' => 'Tiếng Syriac',
        'szl' => 'Tiếng Silesia',
        'ta' => 'Tiếng Tamil',
        'tce' => 'Tiếng Tutchone miền Nam',
        'te' => 'Tiếng Telugu',
        'tem' => 'Tiếng Timne',
        'teo' => 'Tiếng Teso',
        'ter' => 'Tiếng Tereno',
        'tet' => 'Tiếng Tetum',
        'tg' => 'Tiếng Tajik',
        'tgx' => 'Tiếng Tagish',
        'th' => 'Tiếng Thái',
        'tht' => 'Tiếng Tahltan',
        'ti' => 'Tiếng Tigrinya',
        'tig' => 'Tiếng Tigre',
        'tiv' => 'Tiếng Tiv',
        'tk' => 'Tiếng Turkmen',
        'tkl' => 'Tiếng Tokelau',
        'tl' => 'Tiếng Tagalog',
        'tlh' => 'Tiếng Klingon',
        'tli' => 'Tiếng Tlingit',
        'tmh' => 'Tiếng Tamashek',
        'tn' => 'Tiếng Tswana',
        'to' => 'Tiếng Tonga',
        'tog' => 'Tiếng Nyasa Tonga',
        'tok' => 'Tiếng Toki Pona',
        'tpi' => 'Tiếng Tok Pisin',
        'tr' => 'Tiếng Thổ Nhĩ Kỳ',
        'trv' => 'Tiếng Taroko',
        'ts' => 'Tiếng Tsonga',
        'tsi' => 'Tiếng Tsimshian',
        'tt' => 'Tiếng Tatar',
        'ttm' => 'Tiếng Tutchone miền Bắc',
        'tum' => 'Tiếng Tumbuka',
        'tvl' => 'Tiếng Tuvalu',
        'tw' => 'Tiếng Twi',
        'twq' => 'Tiếng Tasawaq',
        'ty' => 'Tiếng Tahiti',
        'tyv' => 'Tiếng Tuvinian',
        'tzm' => 'Tiếng Tamazight Miền Trung Ma-rốc',
        'udm' => 'Tiếng Udmurt',
        'ug' => 'Tiếng Uyghur',
        'uga' => 'Tiếng Ugaritic',
        'uk' => 'Tiếng Ukraina',
        'umb' => 'Tiếng Umbundu',
        'ur' => 'Tiếng Urdu',
        'uz' => 'Tiếng Uzbek',
        'vai' => 'Tiếng Vai',
        've' => 'Tiếng Venda',
        'vec' => 'Tiếng Veneto',
        'vi' => 'Tiếng Việt',
        'vmw' => 'Tiếng Makhuwa',
        'vo' => 'Tiếng Volapük',
        'vot' => 'Tiếng Votic',
        'vun' => 'Tiếng Vunjo',
        'wa' => 'Tiếng Walloon',
        'wae' => 'Tiếng Walser',
        'wal' => 'Tiếng Walamo',
        'war' => 'Tiếng Waray',
        'was' => 'Tiếng Washo',
        'wbp' => 'Tiếng Warlpiri',
        'wo' => 'Tiếng Wolof',
        'wuu' => 'Tiếng Ngô',
        'xal' => 'Tiếng Kalmyk',
        'xh' => 'Tiếng Xhosa',
        'xnr' => 'Tiếng Kangri',
        'xog' => 'Tiếng Soga',
        'yao' => 'Tiếng Yao',
        'yap' => 'Tiếng Yap',
        'yav' => 'Tiếng Yangben',
        'ybb' => 'Tiếng Yemba',
        'yi' => 'Tiếng Yiddish',
        'yo' => 'Tiếng Yoruba',
        'yrl' => 'Tiếng Nheengatu',
        'yue' => 'Tiếng Quảng Đông',
        'za' => 'Tiếng Choang',
        'zap' => 'Tiếng Zapotec',
        'zbl' => 'Ký hiệu Blissymbols',
        'zen' => 'Tiếng Zenaga',
        'zgh' => 'Tiếng Tamazight Chuẩn của Ma-rốc',
        'zh' => 'Tiếng Trung',
        'zu' => 'Tiếng Zulu',
        'zun' => 'Tiếng Zuni',
        'zza' => 'Tiếng Zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Tiếng Ả Rập Hiện đại',
        'de_CH' => 'Tiếng Thượng Giéc-man (Thụy Sĩ)',
        'en_GB' => 'Tiếng Anh (Anh)',
        'en_US' => 'Tiếng Anh (Mỹ)',
        'es_419' => 'Tiếng Tây Ban Nha (Mỹ La tinh)',
        'es_ES' => 'Tiếng Tây Ban Nha (Châu Âu)',
        'fa_AF' => 'Tiếng Dari',
        'nds_NL' => 'Tiếng Hạ Saxon',
        'pt_PT' => 'Tiếng Bồ Đào Nha (Châu Âu)',
        'ro_MD' => 'Tiếng Moldova',
        'sw_CD' => 'Tiếng Swahili Congo',
    ],
];
