<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'арабын нэгдсэн эмиратын дирхам',
        ],
        'AFN' => [
            'AFN',
            'Афганистаны афгани',
        ],
        'ALL' => [
            'ALL',
            'Албанийн лек',
        ],
        'AMD' => [
            'AMD',
            'Арменийн драм',
        ],
        'ANG' => [
            'ANG',
            'Нидерландын Антиллийн гулдер',
        ],
        'AOA' => [
            'AOA',
            'Анголын кванза',
        ],
        'ARS' => [
            'ARS',
            'Аргентины песо',
        ],
        'AUD' => [
            'A$',
            'Австралийн доллар',
        ],
        'AWG' => [
            'AWG',
            'Арубын флорин',
        ],
        'AZN' => [
            'AZN',
            'Азербайжаны манат',
        ],
        'BAM' => [
            'BAM',
            'Босни-Герцеговины хөрвөгч марк',
        ],
        'BBD' => [
            'BBD',
            'барбадос доллар',
        ],
        'BDT' => [
            'BDT',
            'Бангладешийн така',
        ],
        'BGN' => [
            'BGN',
            'Болгарын лев',
        ],
        'BHD' => [
            'BHD',
            'Бахрейн динар',
        ],
        'BIF' => [
            'BIF',
            'Бурундийн франк',
        ],
        'BMD' => [
            'BMD',
            'Бермудын доллар',
        ],
        'BND' => [
            'BND',
            'Брунейн доллар',
        ],
        'BOB' => [
            'BOB',
            'Боливийн боливиано',
        ],
        'BRL' => [
            'R$',
            'Бразилийн реал',
        ],
        'BSD' => [
            'BSD',
            'Багамын доллар',
        ],
        'BTN' => [
            'BTN',
            'Бутаны нгултрум',
        ],
        'BWP' => [
            'BWP',
            'Ботсванийн пула',
        ],
        'BYN' => [
            'BYN',
            'Беларусийн рубль',
        ],
        'BYR' => [
            'BYR',
            'беларусь рубль (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Белизийн доллар',
        ],
        'CAD' => [
            'CA$',
            'канад доллар',
        ],
        'CDF' => [
            'CDF',
            'Конгогийн франк',
        ],
        'CHF' => [
            'CHF',
            'Швейцарийн франк',
        ],
        'CLP' => [
            'CLP',
            'Чилийн песо',
        ],
        'CNH' => [
            'CNH',
            'Хятадын юань (офшор)',
        ],
        'CNY' => [
            'CN¥',
            'Хятадын юань',
        ],
        'COP' => [
            'COP',
            'Колумбын песо',
        ],
        'CRC' => [
            'CRC',
            'Коста-Рикагийн колон',
        ],
        'CUC' => [
            'CUC',
            'Кубын хөрвөгч песо',
        ],
        'CUP' => [
            'CUP',
            'Кубын песо',
        ],
        'CVE' => [
            'CVE',
            'Кабо-Вердийн эскудо',
        ],
        'CZK' => [
            'CZK',
            'Чехийн крон',
        ],
        'DJF' => [
            'DJF',
            'Жибутийн франк',
        ],
        'DKK' => [
            'DKK',
            'Данийн крон',
        ],
        'DOP' => [
            'DOP',
            'Доминиканы песо',
        ],
        'DZD' => [
            'DZD',
            'Алжирийн доллар',
        ],
        'EGP' => [
            'EGP',
            'Египетийн фунт',
        ],
        'ERN' => [
            'ERN',
            'Эритрейн накфа',
        ],
        'ETB' => [
            'ETB',
            'Этиопын бирр',
        ],
        'EUR' => [
            '€',
            'евро',
        ],
        'FJD' => [
            'FJD',
            'Фижигийн доллар',
        ],
        'FKP' => [
            'FKP',
            'Фолклендийн арлуудын паунд',
        ],
        'GBP' => [
            '£',
            'Британийн фунт',
        ],
        'GEL' => [
            'GEL',
            'Гүржийн лари',
        ],
        'GHS' => [
            'GHS',
            'Ганагийн седи',
        ],
        'GIP' => [
            'GIP',
            'Гибралтарын фунт',
        ],
        'GMD' => [
            'GMD',
            'Гамбийн даласи',
        ],
        'GNF' => [
            'GNF',
            'Гвинейн франк',
        ],
        'GTQ' => [
            'GTQ',
            'Гватемалын кецал',
        ],
        'GYD' => [
            'GYD',
            'Гайанын доллар',
        ],
        'HKD' => [
            'HK$',
            'Хонг Конгийн доллар',
        ],
        'HNL' => [
            'HNL',
            'Гондурасын лемпира',
        ],
        'HRK' => [
            'HRK',
            'Хорватын куна',
        ],
        'HTG' => [
            'HTG',
            'Гаитийн гурд',
        ],
        'HUF' => [
            'HUF',
            'Унгарын форинт',
        ],
        'IDR' => [
            'IDR',
            'Индонезийн рупи',
        ],
        'ILS' => [
            '₪',
            'Израилийн шинэ шекел',
        ],
        'INR' => [
            '₹',
            'Энэтхэгийн рупи',
        ],
        'IQD' => [
            'IQD',
            'Иракийн динар',
        ],
        'IRR' => [
            'IRR',
            'Ираны риял',
        ],
        'ISK' => [
            'ISK',
            'Исландын крон',
        ],
        'JMD' => [
            'JMD',
            'Ямайкийн доллар',
        ],
        'JOD' => [
            'JOD',
            'Йорданы динар',
        ],
        'JPY' => [
            'JP¥',
            'Японы иен',
        ],
        'KES' => [
            'KES',
            'Кенийн шиллинг',
        ],
        'KGS' => [
            'KGS',
            'Кыргызын сом',
        ],
        'KHR' => [
            'KHR',
            'Камбожийн риел',
        ],
        'KMF' => [
            'KMF',
            'Коморын франк',
        ],
        'KPW' => [
            'KPW',
            'Хойд Солонгосын вон',
        ],
        'KRW' => [
            '₩',
            'Өмнөд Солонгосын вон',
        ],
        'KWD' => [
            'KWD',
            'Кувейтийн динар',
        ],
        'KYD' => [
            'KYD',
            'Кайманы арлуудын доллар',
        ],
        'KZT' => [
            'KZT',
            'Казахстаны тэнгэ',
        ],
        'LAK' => [
            'LAK',
            'Лаосын кип',
        ],
        'LBP' => [
            'LBP',
            'Ливаны фунт',
        ],
        'LKR' => [
            'LKR',
            'Шри-Ланкийн рупи',
        ],
        'LRD' => [
            'LRD',
            'Либерийн доллар',
        ],
        'LSL' => [
            'LSL',
            'Лесото лоти',
        ],
        'LTL' => [
            'LTL',
            'литвийн литас',
        ],
        'LVL' => [
            'LVL',
            'латвийн лац',
        ],
        'LYD' => [
            'LYD',
            'Ливийн доллар',
        ],
        'MAD' => [
            'MAD',
            'Мороккогийн дирхэм',
        ],
        'MDL' => [
            'MDL',
            'Молдовын лей',
        ],
        'MGA' => [
            'MGA',
            'Малагасийн ариари',
        ],
        'MKD' => [
            'MKD',
            'Македонийн динар',
        ],
        'MMK' => [
            'MMK',
            'Мьянмарын киат',
        ],
        'MNT' => [
            '₮',
            'Монгол төгрөг',
        ],
        'MOP' => [
            'MOP',
            'Макаогийн патака',
        ],
        'MRO' => [
            'MRO',
            'мавритан угия (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Мавританийн угия',
        ],
        'MUR' => [
            'MUR',
            'Маврикийн рупи',
        ],
        'MVR' => [
            'MVR',
            'Мальдивийн руфия',
        ],
        'MWK' => [
            'MWK',
            'Малавийн квача',
        ],
        'MXN' => [
            'MX$',
            'Мексикийн песо',
        ],
        'MYR' => [
            'MYR',
            'Малайзын рингит',
        ],
        'MZN' => [
            'MZN',
            'Мозамбикийн метикал',
        ],
        'NAD' => [
            'NAD',
            'Намибийн доллар',
        ],
        'NGN' => [
            'NGN',
            'Нигерийн найра',
        ],
        'NIO' => [
            'NIO',
            'Никарагуагийн кордоба',
        ],
        'NOK' => [
            'NOK',
            'Норвегийн крон',
        ],
        'NPR' => [
            'NPR',
            'Балбын рупи',
        ],
        'NZD' => [
            'NZ$',
            'Шинэ Зеландын доллар',
        ],
        'OMR' => [
            'OMR',
            'Оманийн риал',
        ],
        'PAB' => [
            'PAB',
            'Панамын бальбоа',
        ],
        'PEN' => [
            'PEN',
            'Перугийн соль',
        ],
        'PGK' => [
            'PGK',
            'Папуа-Шинэ Гвинейн кина',
        ],
        'PHP' => [
            'PHP',
            'Филиппиний песо',
        ],
        'PKR' => [
            'PKR',
            'Пакистаны рупи',
        ],
        'PLN' => [
            'PLN',
            'Польшийн злот',
        ],
        'PYG' => [
            'PYG',
            'Парагвайн гуарани',
        ],
        'QAR' => [
            'QAR',
            'Катарын риал',
        ],
        'RON' => [
            'RON',
            'Румыны лей',
        ],
        'RSD' => [
            'RSD',
            'Сербийн динар',
        ],
        'RUB' => [
            'RUB',
            'Оросын рубль',
        ],
        'RWF' => [
            'RWF',
            'Руандагийн франк',
        ],
        'SAR' => [
            'SAR',
            'Саудын риял',
        ],
        'SBD' => [
            'SBD',
            'Соломоны арлуудын доллар',
        ],
        'SCR' => [
            'SCR',
            'Сейшелийн рупи',
        ],
        'SDG' => [
            'SDG',
            'Суданы фунт',
        ],
        'SEK' => [
            'SEK',
            'Шведийн крон',
        ],
        'SGD' => [
            'SGD',
            'Сингапурын доллар',
        ],
        'SHP' => [
            'SHP',
            'Сент Хеленагийн фунт',
        ],
        'SLE' => [
            'SLE',
            'Сьерра-Леоны леон',
        ],
        'SLL' => [
            'SLL',
            'Сьерра-Леоны леон (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Сомалийн шиллинг',
        ],
        'SRD' => [
            'SRD',
            'Суринамын доллар',
        ],
        'SSP' => [
            'SSP',
            'Өмнөд Суданы фунт',
        ],
        'STD' => [
            'STD',
            'сан-томе ба принсипи добра (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Сан-Томе ба Принсипигийн добра',
        ],
        'SYP' => [
            'SYP',
            'Сирийн фунт',
        ],
        'SZL' => [
            'SZL',
            'Свазиландын лилангени',
        ],
        'THB' => [
            '฿',
            'Тайландын бат',
        ],
        'TJS' => [
            'TJS',
            'Тажикийн сомон',
        ],
        'TMT' => [
            'TMT',
            'Туркмены манат',
        ],
        'TND' => [
            'TND',
            'Тунисын доллар',
        ],
        'TOP' => [
            'TOP',
            'Тонгагийн панга',
        ],
        'TRY' => [
            'TRY',
            'Туркийн лира',
        ],
        'TTD' => [
            'TTD',
            'Тринидад ба Тобагогийн доллар',
        ],
        'TWD' => [
            'NT$',
            'Шинэ Тайванийн доллар',
        ],
        'TZS' => [
            'TZS',
            'Танзанийн шиллинг',
        ],
        'UAH' => [
            'UAH',
            'Украины гривна',
        ],
        'UGX' => [
            'UGX',
            'Угандагийн шиллинг',
        ],
        'USD' => [
            '$',
            'америк доллар',
        ],
        'UYU' => [
            'UYU',
            'Уругвайн песо',
        ],
        'UZS' => [
            'UZS',
            'Узбекийн сом',
        ],
        'VEF' => [
            'VEF',
            'венесуэлийн боливар (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Венесуэлийн боливар',
        ],
        'VND' => [
            '₫',
            'Вьетнамын донг',
        ],
        'VUV' => [
            'VUV',
            'Вануатугийн вату',
        ],
        'WST' => [
            'WST',
            'Самоагийн тала',
        ],
        'XAF' => [
            'FCFA',
            'Төв Африкийн франк',
        ],
        'XCD' => [
            'EC$',
            'Зүүн Карибийн доллар',
        ],
        'XCG' => [
            'Cg.',
            'Карибын гулдер',
        ],
        'XOF' => [
            'F CFA',
            'Баруун Африкийн франк',
        ],
        'XPF' => [
            'CFPF',
            'Францын колонийн франк',
        ],
        'YER' => [
            'YER',
            'Йемений риял',
        ],
        'ZAR' => [
            'ZAR',
            'Өмнөд Африкийн ранд',
        ],
        'ZMK' => [
            'ZMK',
            'Замби квача (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Замбийн квача',
        ],
        'ZWG' => [
            'ZWG',
            'Зимбабвегийн гоулд',
        ],
    ],
];
