<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Андорра песи',
        ],
        'AED' => [
            'AED',
            'Пӗрлешнӗ Араб Эмирачӗсен дирхамӗ',
        ],
        'AFA' => [
            'AFA',
            'Афганистан афганийӗ (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'Афганистан афганийӗ',
        ],
        'ALK' => [
            'ALK',
            'Албани лекӗ (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'Албани лекӗ',
        ],
        'AMD' => [
            'AMD',
            'Армени драмӗ',
        ],
        'ANG' => [
            'ANG',
            'Нидерланд Антилӗн гульденӗ',
        ],
        'AOA' => [
            'AOA',
            'Ангола кванзи',
        ],
        'AOK' => [
            'AOK',
            'Ангола кванзи (1977–1991)',
        ],
        'AON' => [
            'AON',
            'Ангола ҫӗнӗ кванзи (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Ангола реюстадо кванзӗ (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Аргентина аустралӗ',
        ],
        'ARL' => [
            'ARL',
            'Аргентина песо-лейӗ (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'Аргентина песи (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'Аргентина песи (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'Аргентина песи',
        ],
        'ATS' => [
            'ATS',
            'Австри шиллингӗ',
        ],
        'AUD' => [
            'A$',
            'Австрали долларӗ',
        ],
        'AWG' => [
            'AWG',
            'Аруба флоринӗ',
        ],
        'AZM' => [
            'AZM',
            'Азербайджан маначӗ (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'Азербайджан маначӗ',
        ],
        'BAD' => [
            'BAD',
            'Боснипе Герцеговина динарӗ (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'Боснипе Герцеговина конверсиленекен марки',
        ],
        'BAN' => [
            'BAN',
            'Боснипе Герцеговина ҫӗнӗ динарӗ (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'Барбадос долларӗ',
        ],
        'BDT' => [
            'BDT',
            'Бангладеш таки',
        ],
        'BEC' => [
            'BEC',
            'Бельги конверсиленекен франкӗ',
        ],
        'BEF' => [
            'BEF',
            'Бельги франкӗ',
        ],
        'BEL' => [
            'BEL',
            'Бельги франкӗ (финанс)',
        ],
        'BGL' => [
            'BGL',
            'Болгари хытӑ левӗ',
        ],
        'BGM' => [
            'BGM',
            'Болгари социалистсен левӗ',
        ],
        'BGN' => [
            'BGN',
            'Болгари левӗ',
        ],
        'BGO' => [
            'BGO',
            'Болгари левӗ (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'Бахрейн динарӗ',
        ],
        'BIF' => [
            'BIF',
            'Бурунди франкӗ',
        ],
        'BMD' => [
            'BMD',
            'Бермуд долларӗ',
        ],
        'BND' => [
            'BND',
            'Бруней долларӗ',
        ],
        'BOB' => [
            'BOB',
            'Боливи боливианӗ',
        ],
        'BOL' => [
            'BOL',
            'Боливи боливианӗ (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'Боливи песи',
        ],
        'BOV' => [
            'BOV',
            'Боливи мвдолӗ',
        ],
        'BRB' => [
            'BRB',
            'Бразили ҫӗнӗ крузейри (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Бразили крузади (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'Бразили крузейри (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'Бразили реалӗ',
        ],
        'BRN' => [
            'BRN',
            'Бразили ҫӗнӗ крузади (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'Бразили крузейри (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'Бразили крузейри (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'Багама долларӗ',
        ],
        'BTN' => [
            'BTN',
            'Бутан нгултрумӗ',
        ],
        'BUK' => [
            'BUK',
            'Бирман кьячӗ',
        ],
        'BWP' => [
            'BWP',
            'Ботсвана пули',
        ],
        'BYB' => [
            'BYB',
            'Беларусь рублӗ (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'Беларусь рублӗ',
        ],
        'BYR' => [
            'BYR',
            'Беларусь рублӗ (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Белиз долларӗ',
        ],
        'CAD' => [
            'CA$',
            'Канада долларӗ',
        ],
        'CDF' => [
            'CDF',
            'Конго франкӗ',
        ],
        'CHE' => [
            'CHE',
            'WIR еври',
        ],
        'CHF' => [
            'CHF',
            'Швейцари франкӗ',
        ],
        'CHW' => [
            'CHW',
            'WIR франкӗ',
        ],
        'CLE' => [
            'CLE',
            'Чили эскуди',
        ],
        'CLF' => [
            'CLF',
            'Чили татӑлу единици (UF)',
        ],
        'CLP' => [
            'CLP',
            'Чили песи',
        ],
        'CNH' => [
            'CNH',
            'Китай юанӗ (офшор)',
        ],
        'CNX' => [
            'CNX',
            'Китай халӑх банкӗн долларӗ',
        ],
        'CNY' => [
            'CN¥',
            'Китай юанӗ',
        ],
        'COP' => [
            'COP',
            'Колумби песи',
        ],
        'COU' => [
            'COU',
            'Колумби чӑн хаклӑх единици',
        ],
        'CRC' => [
            'CRC',
            'Коста-Рика колонӗ',
        ],
        'CSD' => [
            'CSD',
            'Серби динарӗ (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'Чехословаки хытӑ кронӗ',
        ],
        'CUC' => [
            'CUC',
            'Куба конверсиленекен песи',
        ],
        'CUP' => [
            'CUP',
            'Куба песи',
        ],
        'CVE' => [
            'CVE',
            'Кабо-Верде эскуди',
        ],
        'CYP' => [
            'CYP',
            'Кипр фунчӗ',
        ],
        'CZK' => [
            'CZK',
            'Чехи крони',
        ],
        'DDM' => [
            'DDM',
            'Тухӑҫ Германи марки',
        ],
        'DEM' => [
            'DEM',
            'Германи марки',
        ],
        'DJF' => [
            'DJF',
            'Джибути франкӗ',
        ],
        'DKK' => [
            'DKK',
            'Дани крони',
        ],
        'DOP' => [
            'DOP',
            'Доминика песи',
        ],
        'DZD' => [
            'DZD',
            'Алжир динарӗ',
        ],
        'ECS' => [
            'ECS',
            'Эквадор сукри',
        ],
        'ECV' => [
            'ECV',
            'Эквадор яланхи хаклӑх единици',
        ],
        'EEK' => [
            'EEK',
            'Эстон крони',
        ],
        'EGP' => [
            'EGP',
            'Египет фунчӗ',
        ],
        'ERN' => [
            'ERN',
            'Эритрей накфи',
        ],
        'ESA' => [
            'ESA',
            'Испани песети (А)',
        ],
        'ESB' => [
            'ESB',
            'Испани конверсиленекен песети',
        ],
        'ESP' => [
            'ESP',
            'Испани песети',
        ],
        'ETB' => [
            'ETB',
            'Эфиопи бырӗ',
        ],
        'EUR' => [
            '€',
            'евро',
        ],
        'FIM' => [
            'FIM',
            'Финлянди марки',
        ],
        'FJD' => [
            'FJD',
            'Фиджи долларӗ',
        ],
        'FKP' => [
            'FKP',
            'Фолкленд утравӗсен фунчӗ',
        ],
        'FRF' => [
            'FRF',
            'Франци франкӗ',
        ],
        'GBP' => [
            '£',
            'Британи фунчӗ',
        ],
        'GEK' => [
            'GEK',
            'Грузи купонӗ',
        ],
        'GEL' => [
            'GEL',
            'Грузи ларийӗ',
        ],
        'GHC' => [
            'GHC',
            'Гана седийӗ (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'Гана седийӗ',
        ],
        'GIP' => [
            'GIP',
            'Гибралтар фунчӗ',
        ],
        'GMD' => [
            'GMD',
            'Гамби даласийӗ',
        ],
        'GNF' => [
            'GNF',
            'Гвиней франкӗ',
        ],
        'GNS' => [
            'GNS',
            'Гвиней силийӗ',
        ],
        'GQE' => [
            'GQE',
            'Экваторти Гвиней эквелӗ',
        ],
        'GRD' => [
            'GRD',
            'Греци драхми',
        ],
        'GTQ' => [
            'GTQ',
            'Гватемала кетцалӗ',
        ],
        'GWE' => [
            'GWE',
            'Гвиней-Бисау эскуди',
        ],
        'GWP' => [
            'GWP',
            'Гвиней-Бисау песи',
        ],
        'GYD' => [
            'GYD',
            'Гайана долларӗ',
        ],
        'HKD' => [
            'HK$',
            'Гонконг долларӗ',
        ],
        'HNL' => [
            'HNL',
            'Гондурас лемпири',
        ],
        'HRD' => [
            'HRD',
            'Хорвати динарӗ',
        ],
        'HRK' => [
            'HRK',
            'Хорвати куни',
        ],
        'HTG' => [
            'HTG',
            'Гаити гурдӗ',
        ],
        'HUF' => [
            'HUF',
            'Венгри форинчӗ',
        ],
        'IDR' => [
            'IDR',
            'Индонези рупийӗ',
        ],
        'IEP' => [
            'IEP',
            'Ирланди фунчӗ',
        ],
        'ILP' => [
            'ILP',
            'Израиль фунчӗ',
        ],
        'ILR' => [
            'ILR',
            'Израиль шекелӗ (1980–1985)',
        ],
        'ILS' => [
            '₪',
            'Израиль ҫӗнӗ шекелӗ',
        ],
        'INR' => [
            '₹',
            'Инди рупийӗ',
        ],
        'IQD' => [
            'IQD',
            'Ирак динарӗ',
        ],
        'IRR' => [
            'IRR',
            'Иран риалӗ',
        ],
        'ISJ' => [
            'ISJ',
            'Исланди крони (1918–1981)',
        ],
        'ISK' => [
            'ISK',
            'Исланди крони',
        ],
        'ITL' => [
            'ITL',
            'Итали лири',
        ],
        'JMD' => [
            'JMD',
            'Ямайка долларӗ',
        ],
        'JOD' => [
            'JOD',
            'Иордан динарӗ',
        ],
        'JPY' => [
            'JP¥',
            'Япони иени',
        ],
        'KES' => [
            'KES',
            'Кени шиллингӗ',
        ],
        'KGS' => [
            'KGS',
            'Кӑркӑсстан сомӗ',
        ],
        'KHR' => [
            'KHR',
            'Камбоджа риелӗ',
        ],
        'KMF' => [
            'KMF',
            'Комор франкӗ',
        ],
        'KPW' => [
            'KPW',
            'Ҫур ҫӗр Корей вони',
        ],
        'KRH' => [
            'KRH',
            'Кӑнтӑр Корея хванӗ (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'Кӑнтӑр Корей вони (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'Кӑнтӑр Корей вони',
        ],
        'KWD' => [
            'KWD',
            'Кувейт динарӗ',
        ],
        'KYD' => [
            'KYD',
            'Кайман утравӗсен долларӗ',
        ],
        'KZT' => [
            'KZT',
            'Казахстан тенги',
        ],
        'LAK' => [
            'LAK',
            'Лаос кипӗ',
        ],
        'LBP' => [
            'LBP',
            'Ливан фунчӗ',
        ],
        'LKR' => [
            'LKR',
            'Шри-Ланка рупийӗ',
        ],
        'LRD' => [
            'LRD',
            'Либери долларӗ',
        ],
        'LSL' => [
            'LSL',
            'Лесото лотийӗ',
        ],
        'LTL' => [
            'LTL',
            'Литва личӗ',
        ],
        'LTT' => [
            'LTT',
            'Литва талонӗ',
        ],
        'LUC' => [
            'LUC',
            'Люксембург конверсиленекен франкӗ',
        ],
        'LUF' => [
            'LUF',
            'Люксембург франкӗ',
        ],
        'LUL' => [
            'LUL',
            'Люксембург финанс франкӗ',
        ],
        'LVL' => [
            'LVL',
            'Латви лачӗ',
        ],
        'LVR' => [
            'LVR',
            'Латви рублӗ',
        ],
        'LYD' => [
            'LYD',
            'Ливи динарӗ',
        ],
        'MAD' => [
            'MAD',
            'Марокко дирхамӗ',
        ],
        'MAF' => [
            'MAF',
            'Марокко франкӗ',
        ],
        'MCF' => [
            'MCF',
            'Монако франкӗ',
        ],
        'MDC' => [
            'MDC',
            'Молдова купонӗ',
        ],
        'MDL' => [
            'MDL',
            'Молдова лайӗ',
        ],
        'MGA' => [
            'MGA',
            'Мадагаскар ариарийӗ',
        ],
        'MGF' => [
            'MGF',
            'Мадагаскар франкӗ',
        ],
        'MKD' => [
            'MKD',
            'Македони денарӗ',
        ],
        'MKN' => [
            'MKN',
            'Македони денарӗ (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'Мали франкӗ',
        ],
        'MMK' => [
            'MMK',
            'Мьянма кьячӗ',
        ],
        'MNT' => [
            'MNT',
            'Монголи тугрикӗ',
        ],
        'MOP' => [
            'MOP',
            'Макао патаки',
        ],
        'MRO' => [
            'MRO',
            'Мавритани угийӗ (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Мавритани угийӗ',
        ],
        'MTL' => [
            'MTL',
            'Мальта лири',
        ],
        'MTP' => [
            'MTP',
            'Мальта фунчӗ',
        ],
        'MUR' => [
            'MUR',
            'Маврики рупийӗ',
        ],
        'MVP' => [
            'MVP',
            'Мальдив рупийӗ (1947–1981)',
        ],
        'MVR' => [
            'MVR',
            'Мальдив руфийӗ',
        ],
        'MWK' => [
            'MWK',
            'Малави квачи',
        ],
        'MXN' => [
            'MX$',
            'Мексика песи',
        ],
        'MXP' => [
            'MXP',
            'Мексика кӗмӗл песи (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Мексика инвестици единици',
        ],
        'MYR' => [
            'MYR',
            'Малайзи ринггичӗ',
        ],
        'MZE' => [
            'MZE',
            'Мозамбик эскуди',
        ],
        'MZM' => [
            'MZM',
            'Мозамбик метикалӗ (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'Мозамбик метикалӗ',
        ],
        'NAD' => [
            'NAD',
            'Намиби долларӗ',
        ],
        'NGN' => [
            'NGN',
            'Нигери найри',
        ],
        'NIC' => [
            'NIC',
            'Никарагуа кордоби (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'Никарагуа кордоби',
        ],
        'NLG' => [
            'NLG',
            'Нидерланд гульденӗ',
        ],
        'NOK' => [
            'NOK',
            'Норвеги крони',
        ],
        'NPR' => [
            'NPR',
            'Непал рупийӗ',
        ],
        'NZD' => [
            'NZ$',
            'Ҫӗнӗ Зеланди долларӗ',
        ],
        'OMR' => [
            'OMR',
            'Оман риалӗ',
        ],
        'PAB' => [
            'PAB',
            'Панама бальбойи',
        ],
        'PEI' => [
            'PEI',
            'Перу интийӗ',
        ],
        'PEN' => [
            'PEN',
            'Перу солӗ',
        ],
        'PES' => [
            'PES',
            'Перу солӗ (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'Папуа – Ҫӗнӗ Гвинея кини',
        ],
        'PHP' => [
            '₱',
            'Филиппин песи',
        ],
        'PKR' => [
            'PKR',
            'Пакистан рупийӗ',
        ],
        'PLN' => [
            'PLN',
            'Польша злотӑйӗ',
        ],
        'PLZ' => [
            'PLZ',
            'Польша злотӑйӗ (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'Португали эскуди',
        ],
        'PYG' => [
            'PYG',
            'Парагвай гуаранӗ',
        ],
        'QAR' => [
            'QAR',
            'Катар риалӗ',
        ],
        'RHD' => [
            'RHD',
            'Родези долларӗ',
        ],
        'ROL' => [
            'ROL',
            'Румыни лейӗ (1952–2006)',
        ],
        'RON' => [
            'RON',
            'Румыни лейӗ',
        ],
        'RSD' => [
            'RSD',
            'Серби динарӗ',
        ],
        'RUB' => [
            '₽',
            'Раҫҫей рублӗ',
        ],
        'RUR' => [
            'RUR',
            'Раҫҫей рублӗ (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'Руанда франкӗ',
        ],
        'SAR' => [
            'SAR',
            'Сауд Аравийӗ риялӗ',
        ],
        'SBD' => [
            'SBD',
            'Соломон утравӗсен долларӗ',
        ],
        'SCR' => [
            'SCR',
            'Сейшел рупийӗ',
        ],
        'SDD' => [
            'SDD',
            'Судан динарӗ (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'Судан фунчӗ',
        ],
        'SDP' => [
            'SDP',
            'Судан фунчӗ (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'Швеци крони',
        ],
        'SGD' => [
            'SGD',
            'Сингапур долларӗ',
        ],
        'SHP' => [
            'SHP',
            'Сӑваплӑ Елена утравӗн фунчӗ',
        ],
        'SIT' => [
            'SIT',
            'Словени толарӗ',
        ],
        'SKK' => [
            'SKK',
            'Словаки крони',
        ],
        'SLE' => [
            'SLE',
            'Сьерра-Леоне леони',
        ],
        'SLL' => [
            'SLL',
            'Сьерра-Леоне леони (1964–2022)',
        ],
        'SOS' => [
            'SOS',
            'Сомали шиллингӗ',
        ],
        'SRD' => [
            'SRD',
            'Суринам долларӗ',
        ],
        'SRG' => [
            'SRG',
            'Суринам гульденӗ',
        ],
        'SSP' => [
            'SSP',
            'Кӑнтӑр Судан фунчӗ',
        ],
        'STD' => [
            'STD',
            'Сан-Томепе Принсипи добри (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Сан-Томепе Принсипи добри',
        ],
        'SUR' => [
            'SUR',
            'ССРП рублӗ',
        ],
        'SVC' => [
            'SVC',
            'Сальвадор колонӗ',
        ],
        'SYP' => [
            'SYP',
            'Сири фунчӗ',
        ],
        'SZL' => [
            'SZL',
            'Эсватини лилангенийӗ',
        ],
        'THB' => [
            'THB',
            'Таиланд бачӗ',
        ],
        'TJR' => [
            'TJR',
            'Таджикистан рублӗ',
        ],
        'TJS' => [
            'TJS',
            'Таджикистан сомонийӗ',
        ],
        'TMM' => [
            'TMM',
            'Туркменистан маначӗ (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'Туркменистан маначӗ',
        ],
        'TND' => [
            'TND',
            'Тунис динарӗ',
        ],
        'TOP' => [
            'TOP',
            'Тонга паанги',
        ],
        'TPE' => [
            'TPE',
            'Тимор эскуди',
        ],
        'TRL' => [
            'TRL',
            'Турци лири (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'Турци лири',
        ],
        'TTD' => [
            'TTD',
            'Тринидадпа Тобаго долларӗ',
        ],
        'TWD' => [
            'NT$',
            'Тайвань ҫӗнӗ долларӗ',
        ],
        'TZS' => [
            'TZS',
            'Танзани шиллингӗ',
        ],
        'UAH' => [
            'UAH',
            'Украина гривни',
        ],
        'UAK' => [
            'UAK',
            'Украина карбованецӗ',
        ],
        'UGS' => [
            'UGS',
            'Уганда шиллингӗ (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'Уганда шиллингӗ',
        ],
        'USD' => [
            '$',
            'АПШ долларӗ',
        ],
        'USN' => [
            'USN',
            'АПШ долларӗ (ҫитес кун)',
        ],
        'USS' => [
            'USS',
            'АПШ долларӗ (ҫак кун)',
        ],
        'UYI' => [
            'UYI',
            'Уругвай песи (индексациленӗ единица)',
        ],
        'UYP' => [
            'UYP',
            'Уругвай песи (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'Уругвай песи',
        ],
        'UYW' => [
            'UYW',
            'Уругвай номинал ӗҫ хакӗн индексӗн единици',
        ],
        'UZS' => [
            'UZS',
            'Узбекистан сумӗ',
        ],
        'VEB' => [
            'VEB',
            'Венесуэла боливарӗ (1871–2008)',
        ],
        'VED' => [
            'VED',
            'Венесуэла суверенлӑ боливарӗ',
        ],
        'VEF' => [
            'VEF',
            'Венесуэла боливарӗ (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Венесуэла боливарӗ',
        ],
        'VND' => [
            '₫',
            'Вьетнам донгӗ',
        ],
        'VNN' => [
            'VNN',
            'Вьетнам донгӗ (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'Вануату ватувӗ',
        ],
        'WST' => [
            'WST',
            'Самоа тали',
        ],
        'XAF' => [
            'FCFA',
            'Вӑта Африка КФА франкӗ',
        ],
        'XCD' => [
            'EC$',
            'Тухӑҫ Кариб долларӗ',
        ],
        'XCG' => [
            'Cg.',
            'Кариб гульденӗ',
        ],
        'XEU' => [
            'XEU',
            'Европа валюта единици',
        ],
        'XFO' => [
            'XFO',
            'Франци ылтӑн франкӗ',
        ],
        'XFU' => [
            'XFU',
            'Франци UIC франкӗ',
        ],
        'XOF' => [
            'F CFA',
            'Анӑҫ Африка КФА франкӗ',
        ],
        'XPF' => [
            'CFPF',
            'КФП франкӗ',
        ],
        'XRE' => [
            'XRE',
            'RINET фонд единици',
        ],
        'YDD' => [
            'YDD',
            'Йемен динарӗ',
        ],
        'YER' => [
            'YER',
            'Йемен риалӗ',
        ],
        'YUD' => [
            'YUD',
            'Югослави хытӑ динарӗ (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'Югослави ҫӗнӗ динарӗ (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'Югослави конверсиленекен динарӗ (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'Югослави реформӑланӑ динарӗ (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'Кӑнтӑр Африка рэнчӗ (финанс)',
        ],
        'ZAR' => [
            'ZAR',
            'Кӑнтӑр Африка рэнчӗ',
        ],
        'ZMK' => [
            'ZMK',
            'Замби квачи (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Замби квачи',
        ],
        'ZRN' => [
            'ZRN',
            'Заир ҫӗнӗ заирӗ (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'Заир заирӗ (1971–1993)',
        ],
        'ZWD' => [
            'ZWD',
            'Зимбабве долларӗ (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'Зимбабве ылтӑнӗ',
        ],
        'ZWL' => [
            'ZWL',
            'Зимбабве долларӗ (2009–2024)',
        ],
        'ZWR' => [
            'ZWR',
            'Зимбабве долларӗ (2008)',
        ],
    ],
];
