<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гринвич буйынса уртаса ваҡыт (Абиджан)',
        'Africa/Accra' => 'Гринвич буйынса уртаса ваҡыт (Аккра)',
        'Africa/Addis_Ababa' => 'Көнсығыш Африка ваҡыты (Аддис-Абеба)',
        'Africa/Algiers' => 'Үҙәк Европа ваҡыты (Алжир)',
        'Africa/Asmera' => 'Көнсығыш Африка ваҡыты (Асмэра)',
        'Africa/Asmara' => 'Көнсығыш Африка ваҡыты (Асмэра)',
        'Africa/Bamako' => 'Гринвич буйынса уртаса ваҡыт (Бамако)',
        'Africa/Bangui' => 'Көнбайыш Африка ваҡыты (Банги)',
        'Africa/Banjul' => 'Гринвич буйынса уртаса ваҡыт (Банжул)',
        'Africa/Bissau' => 'Гринвич буйынса уртаса ваҡыт (Бисау)',
        'Africa/Blantyre' => 'Үҙәк Африка ваҡыты (Блантайр)',
        'Africa/Brazzaville' => 'Көнбайыш Африка ваҡыты (Браззавиль)',
        'Africa/Bujumbura' => 'Үҙәк Африка ваҡыты (Бужумбура)',
        'Africa/Cairo' => 'Көнсығыш Европа ваҡыты (Ҡаһирә)',
        'Africa/Casablanca' => 'Көнбайыш Европа ваҡыты (Касабланка)',
        'Africa/Ceuta' => 'Үҙәк Европа ваҡыты (Сеута)',
        'Africa/Conakry' => 'Гринвич буйынса уртаса ваҡыт (Конакри)',
        'Africa/Dakar' => 'Гринвич буйынса уртаса ваҡыт (Дакар)',
        'Africa/Dar_es_Salaam' => 'Көнсығыш Африка ваҡыты (Дар-эс-Салам)',
        'Africa/Djibouti' => 'Көнсығыш Африка ваҡыты (Джибути)',
        'Africa/Douala' => 'Көнбайыш Африка ваҡыты (Дуала)',
        'Africa/El_Aaiun' => 'Көнбайыш Европа ваҡыты (Эль-Аюн)',
        'Africa/Freetown' => 'Гринвич буйынса уртаса ваҡыт (Фритаун)',
        'Africa/Gaborone' => 'Үҙәк Африка ваҡыты (Габороне)',
        'Africa/Harare' => 'Үҙәк Африка ваҡыты (Хараре)',
        'Africa/Johannesburg' => 'Көньяҡ Африка стандарт ваҡыты (Йоханнесбург)',
        'Africa/Juba' => 'Үҙәк Африка ваҡыты (Джуба)',
        'Africa/Kampala' => 'Көнсығыш Африка ваҡыты (Кампала)',
        'Africa/Khartoum' => 'Үҙәк Африка ваҡыты (Хартум)',
        'Africa/Kigali' => 'Үҙәк Африка ваҡыты (Кигали)',
        'Africa/Kinshasa' => 'Көнбайыш Африка ваҡыты (Киншаса)',
        'Africa/Lagos' => 'Көнбайыш Африка ваҡыты (Лагос)',
        'Africa/Libreville' => 'Көнбайыш Африка ваҡыты (Либревиль)',
        'Africa/Lome' => 'Гринвич буйынса уртаса ваҡыт (Ломе)',
        'Africa/Luanda' => 'Көнбайыш Африка ваҡыты (Луанда)',
        'Africa/Lubumbashi' => 'Үҙәк Африка ваҡыты (Лубумбаши)',
        'Africa/Lusaka' => 'Үҙәк Африка ваҡыты (Лусака)',
        'Africa/Malabo' => 'Көнбайыш Африка ваҡыты (Малабо)',
        'Africa/Maputo' => 'Үҙәк Африка ваҡыты (Мапуту)',
        'Africa/Maseru' => 'Көньяҡ Африка стандарт ваҡыты (Масеру)',
        'Africa/Mbabane' => 'Көньяҡ Африка стандарт ваҡыты (Мбабане)',
        'Africa/Mogadishu' => 'Көнсығыш Африка ваҡыты (Могадишо)',
        'Africa/Monrovia' => 'Гринвич буйынса уртаса ваҡыт (Монровия)',
        'Africa/Nairobi' => 'Көнсығыш Африка ваҡыты (Найроби)',
        'Africa/Ndjamena' => 'Көнбайыш Африка ваҡыты (Нджамена)',
        'Africa/Niamey' => 'Көнбайыш Африка ваҡыты (Ниамей)',
        'Africa/Nouakchott' => 'Гринвич буйынса уртаса ваҡыт (Нуакшот)',
        'Africa/Ouagadougou' => 'Гринвич буйынса уртаса ваҡыт (Уагадугу)',
        'Africa/Porto-Novo' => 'Көнбайыш Африка ваҡыты (Порто-Ново)',
        'Africa/Sao_Tome' => 'Гринвич буйынса уртаса ваҡыт (Сан-Томе)',
        'Africa/Tripoli' => 'Көнсығыш Европа ваҡыты (Триполи)',
        'Africa/Tunis' => 'Үҙәк Европа ваҡыты (Тунис)',
        'Africa/Windhoek' => 'Үҙәк Африка ваҡыты (Виндхук)',
        'America/Adak' => 'Гавай-Алеут ваҡыты (Адак)',
        'America/Anchorage' => 'Аляска ваҡыты (Анкоридж)',
        'America/Anguilla' => 'Атлантик ваҡыты (Ангилья)',
        'America/Antigua' => 'Атлантик ваҡыты (Антигуа)',
        'America/Araguaina' => 'Бразилия ваҡыты (Арагуаина)',
        'America/Argentina/La_Rioja' => 'Аргентина ваҡыты (Ла-Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина ваҡыты (Рио-Гальегос)',
        'America/Argentina/Salta' => 'Аргентина ваҡыты (Сальта)',
        'America/Argentina/San_Juan' => 'Аргентина ваҡыты (Сан-Хуан)',
        'America/Argentina/San_Luis' => 'Аргентина ваҡыты (Сан-Луис)',
        'America/Argentina/Tucuman' => 'Аргентина ваҡыты (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргентина ваҡыты (Ушуая)',
        'America/Aruba' => 'Атлантик ваҡыты (Аруба)',
        'America/Asuncion' => 'Парагвай ваҡыты (Асунсьон)',
        'America/Bahia' => 'Бразилия ваҡыты (Баия)',
        'America/Bahia_Banderas' => 'Үҙәк Америка ваҡыты (Баия-де-Бандерас)',
        'America/Barbados' => 'Атлантик ваҡыты (Барбадос)',
        'America/Belem' => 'Бразилия ваҡыты (Белен)',
        'America/Belize' => 'Үҙәк Америка ваҡыты (Белиз)',
        'America/Blanc-Sablon' => 'Атлантик ваҡыты (Блан-Саблон)',
        'America/Boa_Vista' => 'Амазон ваҡыты (Боа-Виста)',
        'America/Bogota' => 'Колумбия ваҡыты (Богота)',
        'America/Boise' => 'Төньяҡ Америка Тау ваҡыты (Бойсе)',
        'America/Buenos_Aires' => 'Аргентина ваҡыты (Буэнос-Айрес)',
        'America/Argentina/Buenos_Aires' => 'Аргентина ваҡыты (Буэнос-Айрес)',
        'America/Cambridge_Bay' => 'Төньяҡ Америка Тау ваҡыты (Кеймбридж-Бей)',
        'America/Campo_Grande' => 'Амазон ваҡыты (Кампу-Гранди)',
        'America/Cancun' => 'Көнсығыш Америка ваҡыты (Канкун)',
        'America/Caracas' => 'Венесуэла ваҡыты (Каракас)',
        'America/Catamarca' => 'Аргентина ваҡыты (Катамарка)',
        'America/Argentina/Catamarca' => 'Аргентина ваҡыты (Катамарка)',
        'America/Cayenne' => 'Француз Гвианаһы ваҡыты (Кайенна)',
        'America/Cayman' => 'Көнсығыш Америка ваҡыты (Кайман утрауҙары)',
        'America/Chicago' => 'Үҙәк Америка ваҡыты (Чикаго)',
        'America/Chihuahua' => 'Үҙәк Америка ваҡыты (Чиуауа)',
        'America/Ciudad_Juarez' => 'Төньяҡ Америка Тау ваҡыты (Сьюдад-Хуарес)',
        'America/Coral_Harbour' => 'Көнсығыш Америка ваҡыты (Атикокан)',
        'America/Atikokan' => 'Көнсығыш Америка ваҡыты (Атикокан)',
        'America/Cordoba' => 'Аргентина ваҡыты (Кордова)',
        'America/Argentina/Cordoba' => 'Аргентина ваҡыты (Кордова)',
        'America/Costa_Rica' => 'Үҙәк Америка ваҡыты (Коста-Рика)',
        'America/Coyhaique' => 'Чили ваҡыты (Койхайке)',
        'America/Creston' => 'Төньяҡ Америка Тау ваҡыты (Крестон)',
        'America/Cuiaba' => 'Амазон ваҡыты (Куяба)',
        'America/Curacao' => 'Атлантик ваҡыты (Кюрасао)',
        'America/Danmarkshavn' => 'Гринвич буйынса уртаса ваҡыт (Денмарксхавн)',
        'America/Dawson' => 'Юкон ваҡыты (Доусон)',
        'America/Dawson_Creek' => 'Төньяҡ Америка Тау ваҡыты (Доусон-Крик)',
        'America/Denver' => 'Төньяҡ Америка Тау ваҡыты (Денвер)',
        'America/Detroit' => 'Көнсығыш Америка ваҡыты (Детройт)',
        'America/Dominica' => 'Атлантик ваҡыты (Доминика)',
        'America/Edmonton' => 'Төньяҡ Америка Тау ваҡыты (Эдмонтон)',
        'America/Eirunepe' => 'Акри ваҡыты (Эйрунепе)',
        'America/El_Salvador' => 'Үҙәк Америка ваҡыты (Сальвадор)',
        'America/Fort_Nelson' => 'Төньяҡ Америка Тау ваҡыты (Форт Нельсон)',
        'America/Fortaleza' => 'Бразилия ваҡыты (Форталеза)',
        'America/Glace_Bay' => 'Атлантик ваҡыты (Глейс-Бей)',
        'America/Godthab' => 'Гренландия ваҡыты (Нуук)',
        'America/Nuuk' => 'Гренландия ваҡыты (Нуук)',
        'America/Goose_Bay' => 'Атлантик ваҡыты (Гус-Бей)',
        'America/Grand_Turk' => 'Көнсығыш Америка ваҡыты (Гранд-Терк)',
        'America/Grenada' => 'Атлантик ваҡыты (Гренада)',
        'America/Guadeloupe' => 'Атлантик ваҡыты (Гваделупа)',
        'America/Guatemala' => 'Үҙәк Америка ваҡыты (Гватемала)',
        'America/Guayaquil' => 'Эквадор ваҡыты (Гуаякиль)',
        'America/Guyana' => 'Гайана ваҡыты',
        'America/Halifax' => 'Атлантик ваҡыты (Галифакс)',
        'America/Havana' => 'Куба ваҡыты (Гавана)',
        'America/Hermosillo' => 'Мексика Тымыҡ океан ваҡыты (Эрмосильо)',
        'America/Indiana/Knox' => 'Үҙәк Америка ваҡыты (Нокс, Индиана)',
        'America/Indiana/Marengo' => 'Көнсығыш Америка ваҡыты (Маренго, Индиана)',
        'America/Indiana/Petersburg' => 'Көнсығыш Америка ваҡыты (Питерсберг, Индиана)',
        'America/Indiana/Tell_City' => 'Үҙәк Америка ваҡыты (Телл-Сити)',
        'America/Indiana/Vevay' => 'Көнсығыш Америка ваҡыты (Вевей, Индиана)',
        'America/Indiana/Vincennes' => 'Көнсығыш Америка ваҡыты (Винсеннес, Индиана)',
        'America/Indiana/Winamac' => 'Көнсығыш Америка ваҡыты (Уинамак, Индиана)',
        'America/Indianapolis' => 'Көнсығыш Америка ваҡыты (Индианаполис)',
        'America/Indiana/Indianapolis' => 'Көнсығыш Америка ваҡыты (Индианаполис)',
        'America/Inuvik' => 'Төньяҡ Америка Тау ваҡыты (Инувик)',
        'America/Iqaluit' => 'Көнсығыш Америка ваҡыты (Икалуит)',
        'America/Jamaica' => 'Көнсығыш Америка ваҡыты (Ямайка)',
        'America/Jujuy' => 'Аргентина ваҡыты (Жужуй)',
        'America/Argentina/Jujuy' => 'Аргентина ваҡыты (Жужуй)',
        'America/Juneau' => 'Аляска ваҡыты (Джуно)',
        'America/Kentucky/Monticello' => 'Көнсығыш Америка ваҡыты (Монтиселло, Кентукки)',
        'America/Kralendijk' => 'Атлантик ваҡыты (Кралендейк)',
        'America/La_Paz' => 'Боливия ваҡыты (Ла-Пас)',
        'America/Lima' => 'Перу ваҡыты (Лима)',
        'America/Los_Angeles' => 'Тымыҡ океан ваҡыты (Лос-Анджелес)',
        'America/Louisville' => 'Көнсығыш Америка ваҡыты (Луисвилл)',
        'America/Kentucky/Louisville' => 'Көнсығыш Америка ваҡыты (Луисвилл)',
        'America/Lower_Princes' => 'Атлантик ваҡыты (Лоуэр-Принс-Куотер)',
        'America/Maceio' => 'Бразилия ваҡыты (Масейо)',
        'America/Managua' => 'Үҙәк Америка ваҡыты (Манагуа)',
        'America/Manaus' => 'Амазон ваҡыты (Манаус)',
        'America/Marigot' => 'Атлантик ваҡыты (Мариго)',
        'America/Martinique' => 'Атлантик ваҡыты (Мартиника)',
        'America/Matamoros' => 'Үҙәк Америка ваҡыты (Матаморос)',
        'America/Mazatlan' => 'Мексика Тымыҡ океан ваҡыты (Масатлан)',
        'America/Mendoza' => 'Аргентина ваҡыты (Мендоса)',
        'America/Argentina/Mendoza' => 'Аргентина ваҡыты (Мендоса)',
        'America/Menominee' => 'Үҙәк Америка ваҡыты (Меномини)',
        'America/Merida' => 'Үҙәк Америка ваҡыты (Мерида)',
        'America/Metlakatla' => 'Аляска ваҡыты (Метлакатла)',
        'America/Mexico_City' => 'Үҙәк Америка ваҡыты (Мехико)',
        'America/Miquelon' => 'Сен-Пьер һәм Микелон ваҡыты',
        'America/Moncton' => 'Атлантик ваҡыты (Монктон)',
        'America/Monterrey' => 'Үҙәк Америка ваҡыты (Монтеррей)',
        'America/Montevideo' => 'Уругвай ваҡыты (Монтевидео)',
        'America/Montserrat' => 'Атлантик ваҡыты (Монтсеррат)',
        'America/Nassau' => 'Көнсығыш Америка ваҡыты (Нассау)',
        'America/New_York' => 'Көнсығыш Америка ваҡыты (Нью-Йорк)',
        'America/Nome' => 'Аляска ваҡыты (Ном)',
        'America/Noronha' => 'Фернанду-ди-Норонья ваҡыты',
        'America/North_Dakota/Beulah' => 'Үҙәк Америка ваҡыты (Бойла, Төньяҡ Дакота)',
        'America/North_Dakota/Center' => 'Үҙәк Америка ваҡыты (Үҙәк, Төньяҡ Дакота)',
        'America/North_Dakota/New_Salem' => 'Үҙәк Америка ваҡыты (Нью-Салем, Төньяк Дакота)',
        'America/Ojinaga' => 'Үҙәк Америка ваҡыты (Охинага)',
        'America/Panama' => 'Көнсығыш Америка ваҡыты (Панама)',
        'America/Paramaribo' => 'Суринам ваҡыты (Парамарибо)',
        'America/Phoenix' => 'Төньяҡ Америка Тау ваҡыты (Финикс)',
        'America/Port-au-Prince' => 'Көнсығыш Америка ваҡыты (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'Атлантик ваҡыты (Порт-оф-Спейн)',
        'America/Porto_Velho' => 'Амазон ваҡыты (Порту-Велью)',
        'America/Puerto_Rico' => 'Атлантик ваҡыты (Пуэрто-Рико)',
        'America/Punta_Arenas' => 'Чили ваҡыты (Пунта-Аренас)',
        'America/Rankin_Inlet' => 'Үҙәк Америка ваҡыты (Ранкин-Инлет)',
        'America/Recife' => 'Бразилия ваҡыты (Ресифи)',
        'America/Regina' => 'Үҙәк Америка ваҡыты (Регина)',
        'America/Resolute' => 'Үҙәк Америка ваҡыты (Резольют)',
        'America/Rio_Branco' => 'Акри ваҡыты (Риу-Бранку)',
        'America/Santarem' => 'Бразилия ваҡыты (Сантарен)',
        'America/Santiago' => 'Чили ваҡыты (Сантьяго)',
        'America/Santo_Domingo' => 'Атлантик ваҡыты (Санто-Доминго)',
        'America/Sao_Paulo' => 'Бразилия ваҡыты (Сан-Паулу)',
        'America/Scoresbysund' => 'Гренландия ваҡыты (Скорсбисунн)',
        'America/Sitka' => 'Аляска ваҡыты (Ситка)',
        'America/St_Barthelemy' => 'Атлантик ваҡыты (Сен-Бартелеми)',
        'America/St_Johns' => 'Ньюфаундленд ваҡыты (Сент-Джонс)',
        'America/St_Kitts' => 'Атлантик ваҡыты (Сент-Китс)',
        'America/St_Lucia' => 'Атлантик ваҡыты (Сент-Люсия)',
        'America/St_Thomas' => 'Атлантик ваҡыты (Сент-Томас)',
        'America/St_Vincent' => 'Атлантик ваҡыты (Сент-Винсент)',
        'America/Swift_Current' => 'Үҙәк Америка ваҡыты (Свифт-Керрент)',
        'America/Tegucigalpa' => 'Үҙәк Америка ваҡыты (Тегусигальпа)',
        'America/Thule' => 'Атлантик ваҡыты (Туле)',
        'America/Tijuana' => 'Тымыҡ океан ваҡыты (Тихуана)',
        'America/Toronto' => 'Көнсығыш Америка ваҡыты (Торонто)',
        'America/Tortola' => 'Атлантик ваҡыты (Тортола)',
        'America/Vancouver' => 'Тымыҡ океан ваҡыты (Ванкувер)',
        'America/Whitehorse' => 'Юкон ваҡыты (Уайтхорс)',
        'America/Winnipeg' => 'Үҙәк Америка ваҡыты (Виннипег)',
        'America/Yakutat' => 'Аляска ваҡыты (Якутат)',
        'Antarctica/Casey' => 'Көнбайыш Австралия ваҡыты (Кейси станцияһы)',
        'Antarctica/Davis' => 'Дейвис ваҡыты',
        'Antarctica/DumontDUrville' => 'Дюмон-д’Юрвиль ваҡыты (Дюмон-д’Юрвиль станцияһы)',
        'Antarctica/Macquarie' => 'Көнсығыш Австралия ваҡыты (Маккуори утрауы)',
        'Antarctica/Mawson' => 'Моусон ваҡыты (Моусон станцияһы)',
        'Antarctica/McMurdo' => 'Яңы Зеландия ваҡыты (Мак-Мердо станцияһы)',
        'Antarctica/Palmer' => 'Чили ваҡыты (Палмер)',
        'Antarctica/Rothera' => 'Ротера ваҡыты (Ротера станцияһы)',
        'Antarctica/Syowa' => 'Сёва ваҡыты (Сёва станцияһы)',
        'Antarctica/Troll' => 'Гринвич буйынса уртаса ваҡыт (Тролль станцияһы)',
        'Antarctica/Vostok' => 'Восток ваҡыты (Восток станцияһы)',
        'Arctic/Longyearbyen' => 'Үҙәк Европа ваҡыты (Лонгйир)',
        'Asia/Aden' => 'Сәғүд Ғәрәбстаны ваҡыты (Аден)',
        'Asia/Almaty' => 'Ҡаҙағстан ваҡыты (Алматы)',
        'Asia/Amman' => 'Көнсығыш Европа ваҡыты (Амман)',
        'Asia/Anadyr' => 'Камчатка ваҡыты (Анадырь)',
        'Asia/Aqtau' => 'Ҡаҙағстан ваҡыты (Аҡтау)',
        'Asia/Aqtobe' => 'Ҡаҙағстан ваҡыты (Аҡтүбә)',
        'Asia/Ashgabat' => 'Төркмәнстан ваҡыты (Ашхабад)',
        'Asia/Atyrau' => 'Ҡаҙағстан ваҡыты (Атырау)',
        'Asia/Baghdad' => 'Сәғүд Ғәрәбстаны ваҡыты (Бағдад)',
        'Asia/Bahrain' => 'Сәғүд Ғәрәбстаны ваҡыты (Бәхрәйн)',
        'Asia/Baku' => 'Әзербайжан ваҡыты (Баҡы)',
        'Asia/Bangkok' => 'Һинд-Ҡытай ваҡыты (Бангкок)',
        'Asia/Barnaul' => 'Красноярск ваҡыты (Барнаул)',
        'Asia/Beirut' => 'Көнсығыш Европа ваҡыты (Бейрут)',
        'Asia/Bishkek' => 'Ҡырғыҙстан ваҡыты (Бешкәк)',
        'Asia/Brunei' => 'Бруней ваҡыты',
        'Asia/Calcutta' => 'Һиндостан стандарт ваҡыты (Калькутта)',
        'Asia/Kolkata' => 'Һиндостан стандарт ваҡыты (Калькутта)',
        'Asia/Chita' => 'Якутск ваҡыты (Чита)',
        'Asia/Colombo' => 'Һиндостан стандарт ваҡыты (Коломбо)',
        'Asia/Damascus' => 'Көнсығыш Европа ваҡыты (Дәмәшк)',
        'Asia/Dhaka' => 'Бангладеш ваҡыты (Дакка)',
        'Asia/Dili' => 'Көнсығыш Тимор ваҡыты (Дили)',
        'Asia/Dubai' => 'Фарсы ҡултығы стандарт ваҡыты (Дубай)',
        'Asia/Dushanbe' => 'Тажикстан ваҡыты (Дүшәнбе)',
        'Asia/Famagusta' => 'Көнсығыш Европа ваҡыты (Фамагуста)',
        'Asia/Gaza' => 'Көнсығыш Европа ваҡыты (Газа)',
        'Asia/Hebron' => 'Көнсығыш Европа ваҡыты (Хеврон)',
        'Asia/Hong_Kong' => 'Гонконг ваҡыты',
        'Asia/Hovd' => 'Ховд ваҡыты',
        'Asia/Irkutsk' => 'Иркутск ваҡыты',
        'Asia/Jakarta' => 'Көнбайыш Индонезия (Джакарта)',
        'Asia/Jayapura' => 'Көнсығыш Индонезия (Джаяпура)',
        'Asia/Jerusalem' => 'Израиль ваҡыты (Иерусалим)',
        'Asia/Kabul' => 'Афғанстан ваҡыты (Кабул)',
        'Asia/Kamchatka' => 'Камчатка ваҡыты',
        'Asia/Karachi' => 'Пакистан ваҡыты (Карачи)',
        'Asia/Katmandu' => 'Непал ваҡыты (Катманду)',
        'Asia/Kathmandu' => 'Непал ваҡыты (Катманду)',
        'Asia/Khandyga' => 'Якутск ваҡыты (Хандыга)',
        'Asia/Krasnoyarsk' => 'Красноярск ваҡыты',
        'Asia/Kuala_Lumpur' => 'Малайзия ваҡыты (Куала-Лумпур)',
        'Asia/Kuching' => 'Малайзия ваҡыты (Кучинг)',
        'Asia/Kuwait' => 'Сәғүд Ғәрәбстаны ваҡыты (Кувейт)',
        'Asia/Macau' => 'Ҡытай ваҡыты (Макао)',
        'Asia/Magadan' => 'Магадан ваҡыты',
        'Asia/Makassar' => 'Үҙәк Индонезия ваҡыты (Макасар)',
        'Asia/Manila' => 'Филиппин ваҡыты (Манила)',
        'Asia/Muscat' => 'Фарсы ҡултығы стандарт ваҡыты (Маскат)',
        'Asia/Nicosia' => 'Көнсығыш Европа ваҡыты (Никосия)',
        'Asia/Novokuznetsk' => 'Красноярск ваҡыты (Новокузнецк)',
        'Asia/Novosibirsk' => 'Красноярск ваҡыты (Новосибирск)',
        'Asia/Omsk' => 'Омск ваҡыты',
        'Asia/Oral' => 'Ҡаҙағстан ваҡыты (Уральск)',
        'Asia/Phnom_Penh' => 'Һинд-Ҡытай ваҡыты (Пномпень)',
        'Asia/Pontianak' => 'Көнбайыш Индонезия (Понтианак)',
        'Asia/Pyongyang' => 'Корея ваҡыты (Пхеньян)',
        'Asia/Qatar' => 'Сәғүд Ғәрәбстаны ваҡыты (Катар)',
        'Asia/Qostanay' => 'Ҡаҙағстан ваҡыты (Ҡостанай)',
        'Asia/Qyzylorda' => 'Ҡаҙағстан ваҡыты (Ҡыҙылурҙа)',
        'Asia/Rangoon' => 'Мьянма ваҡыты (Янгон)',
        'Asia/Yangon' => 'Мьянма ваҡыты (Янгон)',
        'Asia/Riyadh' => 'Сәғүд Ғәрәбстаны ваҡыты (Эр-Рияд)',
        'Asia/Saigon' => 'Һинд-Ҡытай ваҡыты (Хошимин)',
        'Asia/Ho_Chi_Minh' => 'Һинд-Ҡытай ваҡыты (Хошимин)',
        'Asia/Sakhalin' => 'Магадан ваҡыты (Сахалин)',
        'Asia/Samarkand' => 'Үзбәкстан ваҡыты (Сәмәрҡәнд)',
        'Asia/Seoul' => 'Корея ваҡыты (Сеул)',
        'Asia/Shanghai' => 'Ҡытай ваҡыты (Шанхай)',
        'Asia/Singapore' => 'Сингапур стандарт ваҡыты',
        'Asia/Srednekolymsk' => 'Магадан ваҡыты (Среднеколымск)',
        'Asia/Taipei' => 'Тайвань ваҡыты (Тайпей)',
        'Asia/Tashkent' => 'Үзбәкстан ваҡыты (Ташкент)',
        'Asia/Tbilisi' => 'Грузия ваҡыты (Тбилиси)',
        'Asia/Tehran' => 'Иран ваҡыты (Тәһран)',
        'Asia/Thimphu' => 'Бутан ваҡыты (Тхимпху)',
        'Asia/Tokyo' => 'Япония ваҡыты (Токио)',
        'Asia/Tomsk' => 'Красноярск ваҡыты (Томск)',
        'Asia/Ulaanbaatar' => 'Улан-Батор ваҡыты',
        'Asia/Urumqi' => 'Ҡытай ваҡыты (Өрөмсө)',
        'Asia/Ust-Nera' => 'Владивосток ваҡыты (Усть-Нера)',
        'Asia/Vientiane' => 'Һинд-Ҡытай ваҡыты (Вьентьян)',
        'Asia/Vladivostok' => 'Владивосток ваҡыты',
        'Asia/Yakutsk' => 'Якутск ваҡыты',
        'Asia/Yekaterinburg' => 'Екатеринбург ваҡыты',
        'Asia/Yerevan' => 'Әрмәнстан ваҡыты (Ереван)',
        'Atlantic/Azores' => 'Азор утрауҙары ваҡыты',
        'Atlantic/Bermuda' => 'Атлантик ваҡыты (Бермуд)',
        'Atlantic/Canary' => 'Көнбайыш Европа ваҡыты (Канар утрауҙары)',
        'Atlantic/Cape_Verde' => 'Кабо-Верде ваҡыты',
        'Atlantic/Faeroe' => 'Көнбайыш Европа ваҡыты (Фарер утрауҙары)',
        'Atlantic/Faroe' => 'Көнбайыш Европа ваҡыты (Фарер утрауҙары)',
        'Atlantic/Madeira' => 'Көнбайыш Европа ваҡыты (Мадейра)',
        'Atlantic/Reykjavik' => 'Гринвич буйынса уртаса ваҡыт (Рейкьявик)',
        'Atlantic/South_Georgia' => 'Көньяҡ Георгия ваҡыты',
        'Atlantic/St_Helena' => 'Гринвич буйынса уртаса ваҡыт (Изге Елена утрауы)',
        'Atlantic/Stanley' => 'Фолкленд утрауҙары ваҡыты (Стэнли)',
        'Australia/Adelaide' => 'Үҙәк Австралия ваҡыты (Аделаида)',
        'Australia/Brisbane' => 'Көнсығыш Австралия ваҡыты (Брисбен)',
        'Australia/Broken_Hill' => 'Үҙәк Австралия ваҡыты (Брокен-Хилл)',
        'Australia/Darwin' => 'Үҙәк Австралия ваҡыты (Дарвин)',
        'Australia/Eucla' => 'Үҙәк Австралия көнбайыш ваҡыты (Юкла)',
        'Australia/Hobart' => 'Көнсығыш Австралия ваҡыты (Хобарт)',
        'Australia/Lindeman' => 'Көнсығыш Австралия ваҡыты (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд-Хау ваҡыты (Лорд-Хау утрауы)',
        'Australia/Melbourne' => 'Көнсығыш Австралия ваҡыты (Мельбурн)',
        'Australia/Perth' => 'Көнбайыш Австралия ваҡыты (Перт)',
        'Australia/Sydney' => 'Көнсығыш Австралия ваҡыты (Сидней)',
        'Etc/GMT' => 'Гринвич буйынса уртаса ваҡыт',
        'Etc/UTC' => 'Координацияланған универсаль ваҡыт',
        'Europe/Amsterdam' => 'Үҙәк Европа ваҡыты (Амстердам)',
        'Europe/Andorra' => 'Үҙәк Европа ваҡыты (Андорра)',
        'Europe/Astrakhan' => 'Һамар ваҡыты (Әстерхан)',
        'Europe/Athens' => 'Көнсығыш Европа ваҡыты (Афина)',
        'Europe/Belgrade' => 'Үҙәк Европа ваҡыты (Белград)',
        'Europe/Berlin' => 'Үҙәк Европа ваҡыты (Берлин)',
        'Europe/Bratislava' => 'Үҙәк Европа ваҡыты (Братислава)',
        'Europe/Brussels' => 'Үҙәк Европа ваҡыты (Брюссель)',
        'Europe/Bucharest' => 'Көнсығыш Европа ваҡыты (Бухарест)',
        'Europe/Budapest' => 'Үҙәк Европа ваҡыты (Будапешт)',
        'Europe/Busingen' => 'Үҙәк Европа ваҡыты (Бүзинген)',
        'Europe/Chisinau' => 'Көнсығыш Европа ваҡыты (Кишинев)',
        'Europe/Copenhagen' => 'Үҙәк Европа ваҡыты (Копенгаген)',
        'Europe/Dublin' => 'Гринвич буйынса уртаса ваҡыт (Дублин)',
        'Europe/Gibraltar' => 'Үҙәк Европа ваҡыты (Гибралтар)',
        'Europe/Guernsey' => 'Гринвич буйынса уртаса ваҡыт (Гернси)',
        'Europe/Helsinki' => 'Көнсығыш Европа ваҡыты (Хельсинки)',
        'Europe/Isle_of_Man' => 'Гринвич буйынса уртаса ваҡыт (Мэн утрауы)',
        'Europe/Istanbul' => 'Төркиә ваҡыты (Истанбул)',
        'Europe/Jersey' => 'Гринвич буйынса уртаса ваҡыт (Джерси)',
        'Europe/Kaliningrad' => 'Көнсығыш Европа ваҡыты (Калининград)',
        'Europe/Kiev' => 'Көнсығыш Европа ваҡыты (Киев)',
        'Europe/Kyiv' => 'Көнсығыш Европа ваҡыты (Киев)',
        'Europe/Kirov' => 'Мәскәү ваҡыты (Киров)',
        'Europe/Lisbon' => 'Көнбайыш Европа ваҡыты (Лиссабон)',
        'Europe/Ljubljana' => 'Үҙәк Европа ваҡыты (Любляна)',
        'Europe/London' => 'Гринвич буйынса уртаса ваҡыт (Лондон)',
        'Europe/Luxembourg' => 'Үҙәк Европа ваҡыты (Люксембург)',
        'Europe/Madrid' => 'Үҙәк Европа ваҡыты (Мадрид)',
        'Europe/Malta' => 'Үҙәк Европа ваҡыты (Мальта)',
        'Europe/Mariehamn' => 'Көнсығыш Европа ваҡыты (Мариехамн)',
        'Europe/Minsk' => 'Мәскәү ваҡыты (Минск)',
        'Europe/Monaco' => 'Үҙәк Европа ваҡыты (Монако)',
        'Europe/Moscow' => 'Мәскәү ваҡыты',
        'Europe/Oslo' => 'Үҙәк Европа ваҡыты (Осло)',
        'Europe/Paris' => 'Үҙәк Европа ваҡыты (Париж)',
        'Europe/Podgorica' => 'Үҙәк Европа ваҡыты (Подгорица)',
        'Europe/Prague' => 'Үҙәк Европа ваҡыты (Прага)',
        'Europe/Riga' => 'Көнсығыш Европа ваҡыты (Рига)',
        'Europe/Rome' => 'Үҙәк Европа ваҡыты (Рим)',
        'Europe/Samara' => 'Һамар ваҡыты',
        'Europe/San_Marino' => 'Үҙәк Европа ваҡыты (Сан-Марино)',
        'Europe/Sarajevo' => 'Үҙәк Европа ваҡыты (Сараево)',
        'Europe/Saratov' => 'Һамар ваҡыты (Һарытау)',
        'Europe/Simferopol' => 'Мәскәү ваҡыты (Симферополь)',
        'Europe/Skopje' => 'Үҙәк Европа ваҡыты (Скопье)',
        'Europe/Sofia' => 'Көнсығыш Европа ваҡыты (София)',
        'Europe/Stockholm' => 'Үҙәк Европа ваҡыты (Стокгольм)',
        'Europe/Tallinn' => 'Көнсығыш Европа ваҡыты (Таллин)',
        'Europe/Tirane' => 'Үҙәк Европа ваҡыты (Тирана)',
        'Europe/Ulyanovsk' => 'Һамар ваҡыты (Ульяновск)',
        'Europe/Vaduz' => 'Үҙәк Европа ваҡыты (Вадуц)',
        'Europe/Vatican' => 'Үҙәк Европа ваҡыты (Ватикан)',
        'Europe/Vienna' => 'Үҙәк Европа ваҡыты (Вена)',
        'Europe/Vilnius' => 'Көнсығыш Европа ваҡыты (Вильнюс)',
        'Europe/Volgograd' => 'Мәскәү ваҡыты (Волгоград)',
        'Europe/Warsaw' => 'Үҙәк Европа ваҡыты (Варшава)',
        'Europe/Zagreb' => 'Үҙәк Европа ваҡыты (Загреб)',
        'Europe/Zurich' => 'Үҙәк Европа ваҡыты (Цюрих)',
        'Indian/Antananarivo' => 'Көнсығыш Африка ваҡыты (Антананариву)',
        'Indian/Chagos' => 'Һинд океаны ваҡыты (Чагос)',
        'Indian/Christmas' => 'Раштыуа утрауы ваҡыты',
        'Indian/Cocos' => 'Кокос утрауҙары ваҡыты',
        'Indian/Comoro' => 'Көнсығыш Африка ваҡыты (Комор утрауҙары)',
        'Indian/Kerguelen' => 'Француз Көньяҡ һәм Антарктика ваҡыты (Кергулен утрауҙары)',
        'Indian/Mahe' => 'Сейшел утрауҙары ваҡыты (Маэ)',
        'Indian/Maldives' => 'Мальдив утрауҙары ваҡыты',
        'Indian/Mauritius' => 'Маврикий ваҡыты',
        'Indian/Mayotte' => 'Көнсығыш Африка ваҡыты (Майотта)',
        'Indian/Reunion' => 'Реюньон ваҡыты',
        'Pacific/Apia' => 'Самоа ваҡыты (Апиа)',
        'Pacific/Auckland' => 'Яңы Зеландия ваҡыты (Окленд)',
        'Pacific/Bougainville' => 'Папуа – Яңы Гвинея (Бугенвиль)',
        'Pacific/Chatham' => 'Чатем ваҡыты (Чатем утрауҙары)',
        'Pacific/Easter' => 'Пасха утрауы ваҡыты',
        'Pacific/Efate' => 'Вануату ваҡыты (Эфате)',
        'Pacific/Enderbury' => 'Феникс утрауҙары ваҡыты (Кантон утрауы)',
        'Pacific/Kanton' => 'Феникс утрауҙары ваҡыты (Кантон утрауы)',
        'Pacific/Fakaofo' => 'Токелау ваҡыты (Факаофо)',
        'Pacific/Fiji' => 'Фиджи ваҡыты',
        'Pacific/Funafuti' => 'Тувалу ваҡыты (Фунафути)',
        'Pacific/Galapagos' => 'Галапагос ваҡыты (Галапагос утрауҙары)',
        'Pacific/Gambier' => 'Гамбье ваҡыты (Гамбье утрауҙары)',
        'Pacific/Guadalcanal' => 'Соломон утрауҙары ваҡыты (Гуадалканал)',
        'Pacific/Guam' => 'Чаморро стандарт ваҡыты (Гуам)',
        'Pacific/Honolulu' => 'Гавай-Алеут стандарт ваҡыты (Honolulu)',
        'Pacific/Kiritimati' => 'Лайн утрауҙары ваҡыты (Киритимати)',
        'Pacific/Kosrae' => 'Косрае ваҡыты',
        'Pacific/Kwajalein' => 'Маршалл Утрауҙары ваҡыты (Кваджалейн)',
        'Pacific/Majuro' => 'Маршалл Утрауҙары ваҡыты (Маджуро)',
        'Pacific/Marquesas' => 'Маркиз утрауҙары ваҡыты',
        'Pacific/Midway' => 'Америка Самоаһы ваҡыты (Мидуэй атоллы)',
        'Pacific/Nauru' => 'Науру ваҡыты',
        'Pacific/Niue' => 'Ниуэ ваҡыты',
        'Pacific/Norfolk' => 'Норфолк ваҡыты (Норфолк утрауы)',
        'Pacific/Noumea' => 'Яңы Каледония ваҡыты (Нумеа)',
        'Pacific/Pago_Pago' => 'Америка Самоаһы ваҡыты (Паго-Паго)',
        'Pacific/Palau' => 'Палау ваҡыты',
        'Pacific/Pitcairn' => 'Питкэрн ваҡыты (Питкэрн утрауҙары)',
        'Pacific/Ponape' => 'Понпеи ваҡыты',
        'Pacific/Pohnpei' => 'Понпеи ваҡыты',
        'Pacific/Port_Moresby' => 'Папуа – Яңы Гвинея (Порт-Морсби)',
        'Pacific/Rarotonga' => 'Кук утрауҙары ваҡыты (Раротонга)',
        'Pacific/Saipan' => 'Чаморро стандарт ваҡыты (Сайпан)',
        'Pacific/Tahiti' => 'Таити ваҡыты',
        'Pacific/Tarawa' => 'Гилберт утрауҙары ваҡыты (Тарава)',
        'Pacific/Tongatapu' => 'Тонга ваҡыты (Тонгатапу)',
        'Pacific/Truk' => 'Чуук ваҡыты (Трук)',
        'Pacific/Chuuk' => 'Чуук ваҡыты (Трук)',
        'Pacific/Wake' => 'Уэйк утрауы ваҡыты',
        'Pacific/Wallis' => 'Уоллис һәм Футуна ваҡыты',
    ],
    'Meta' => [],
];
