<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Afak' => 'Afaka',
        'Aghb' => 'Caucasian Albanian',
        'Ahom' => 'Ahom',
        'Arab' => 'Arabic',
        'Aran' => 'Nastaliq',
        'Armi' => 'Imperial Aramaic',
        'Armn' => 'Armenian',
        'Avst' => 'Avestan',
        'Bali' => 'Balinese',
        'Bamu' => 'Bamum',
        'Bass' => 'Bassa Vah',
        'Batk' => 'Batak',
        'Beng' => 'Bangla',
        'Berf' => 'Beria Erfe',
        'Bhks' => 'Bhaiksuki',
        'Blis' => 'Blissymbols',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brahmi',
        'Brai' => 'Braille',
        'Bugi' => 'Buginese',
        'Buhd' => 'Buhid',
        'Cakm' => 'Chakma',
        'Cans' => 'Unified Canadian Aboriginal Syllabics',
        'Cari' => 'Carian',
        'Cham' => 'Cham',
        'Cher' => 'Cherokee',
        'Chrs' => 'Chorasmian',
        'Cirt' => 'Cirth',
        'Copt' => 'Coptic',
        'Cpmn' => 'Cypro-Minoan',
        'Cprt' => 'Cypriot',
        'Cyrl' => 'Cyrillic',
        'Cyrs' => 'Old Church Slavonic Cyrillic',
        'Deva' => 'Devanagari',
        'Diak' => 'Dives Akuru',
        'Dogr' => 'Dogra',
        'Dsrt' => 'Deseret',
        'Dupl' => 'Duployan shorthand',
        'Egyd' => 'Egyptian demotic',
        'Egyh' => 'Egyptian hieratic',
        'Egyp' => 'Egyptian hieroglyphs',
        'Elba' => 'Elbasan',
        'Elym' => 'Elymaic',
        'Ethi' => 'Ethiopic',
        'Gara' => 'Garay',
        'Geok' => 'Georgian Khutsuri',
        'Geor' => 'Georgian',
        'Glag' => 'Glagolitic',
        'Gong' => 'Gunjala Gondi',
        'Gonm' => 'Masaram Gondi',
        'Goth' => 'Gothic',
        'Gran' => 'Grantha',
        'Grek' => 'Greek',
        'Gujr' => 'Gujarati',
        'Gukh' => 'Gurung Khema',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han with Bopomofo',
        'Hang' => 'Hangul',
        'Hani' => 'Han',
        'Hano' => 'Hanunoo',
        'Hans' => 'Simplified',
        'Hant' => 'Traditional',
        'Hatr' => 'Hatran',
        'Hebr' => 'Hebrew',
        'Hira' => 'Hiragana',
        'Hluw' => 'Anatolian Hieroglyphs',
        'Hmng' => 'Pahawh Hmong',
        'Hmnp' => 'Nyiakeng Puachue Hmong',
        'Hrkt' => 'Japanese syllabaries',
        'Hung' => 'Old Hungarian',
        'Inds' => 'Indus',
        'Ital' => 'Old Italic',
        'Jamo' => 'Jamo',
        'Java' => 'Javanese',
        'Jpan' => 'Japanese',
        'Jurc' => 'Jurchen',
        'Kali' => 'Kayah Li',
        'Kana' => 'Katakana',
        'Kawi' => 'Kawi',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Khmer',
        'Khoj' => 'Khojki',
        'Kits' => 'Khitan small script',
        'Knda' => 'Kannada',
        'Kore' => 'Korean',
        'Kpel' => 'Kpelle',
        'Krai' => 'Kirat Rai',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Lao',
        'Latf' => 'Fraktur Latin',
        'Latg' => 'Gaelic Latin',
        'Latn' => 'Latin',
        'Lepc' => 'Lepcha',
        'Limb' => 'Limbu',
        'Lina' => 'Linear A',
        'Linb' => 'Linear B',
        'Lisu' => 'Fraser',
        'Loma' => 'Loma',
        'Lyci' => 'Lycian',
        'Lydi' => 'Lydian',
        'Mahj' => 'Mahajani',
        'Maka' => 'Makasar',
        'Mand' => 'Mandaean',
        'Mani' => 'Manichaean',
        'Marc' => 'Marchen',
        'Maya' => 'Mayan hieroglyphs',
        'Medf' => 'Medefaidrin',
        'Mend' => 'Mende',
        'Merc' => 'Meroitic Cursive',
        'Mero' => 'Meroitic',
        'Mlym' => 'Malayalam',
        'Modi' => 'Modi',
        'Mong' => 'Mongolian',
        'Moon' => 'Moon',
        'Mroo' => 'Mro',
        'Mtei' => 'Meitei Mayek',
        'Mult' => 'Multani',
        'Mymr' => 'Myanmar',
        'Nagm' => 'Nag Mundari',
        'Nand' => 'Nandinagari',
        'Narb' => 'Old North Arabian',
        'Nbat' => 'Nabataean',
        'Newa' => 'Newa',
        'Nkgb' => 'Naxi Geba',
        'Nkoo' => 'N’Ko',
        'Nshu' => 'Nüshu',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Onao' => 'Ol Onal',
        'Orkh' => 'Orkhon',
        'Orya' => 'Odia',
        'Osge' => 'Osage',
        'Osma' => 'Osmanya',
        'Ougr' => 'Old Uyghur',
        'Palm' => 'Palmyrene',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'Old Permic',
        'Phag' => 'Phags-pa',
        'Phli' => 'Inscriptional Pahlavi',
        'Phlp' => 'Psalter Pahlavi',
        'Phlv' => 'Book Pahlavi',
        'Phnx' => 'Phoenician',
        'Plrd' => 'Pollard Phonetic',
        'Prti' => 'Inscriptional Parthian',
        'Qaag' => 'Zawgyi',
        'Rjng' => 'Rejang',
        'Rohg' => 'Hanifi',
        'Roro' => 'Rongorongo',
        'Runr' => 'Runic',
        'Samr' => 'Samaritan',
        'Sara' => 'Sarati',
        'Sarb' => 'Old South Arabian',
        'Saur' => 'Sourashtra',
        'Sgnw' => 'SignWriting',
        'Shaw' => 'Shavian',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sidt' => 'Sidetic',
        'Sind' => 'Khudawadi',
        'Sinh' => 'Sinhala',
        'Sogd' => 'Sogdian',
        'Sogo' => 'Old Sogdian',
        'Sora' => 'Sora Sompeng',
        'Soyo' => 'Soyombo',
        'Sund' => 'Sundanese',
        'Sunu' => 'Sunuwar',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Syriac',
        'Syre' => 'Estrangelo Syriac',
        'Syrj' => 'Western Syriac',
        'Syrn' => 'Eastern Syriac',
        'Tagb' => 'Tagbanwa',
        'Takr' => 'Takri',
        'Tale' => 'Tai Le',
        'Talu' => 'New Tai Lue',
        'Taml' => 'Tamil',
        'Tang' => 'Tangut',
        'Tavt' => 'Tai Viet',
        'Tayo' => 'Tai Yo',
        'Telu' => 'Telugu',
        'Teng' => 'Tengwar',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Tagalog',
        'Thaa' => 'Thaana',
        'Thai' => 'Thai',
        'Tibt' => 'Tibetan',
        'Tirh' => 'Tirhuta',
        'Tnsa' => 'Tangsa',
        'Todr' => 'Todhri',
        'Tols' => 'Tolong Siki',
        'Toto' => 'Toto',
        'Tutg' => 'Tulu-Tigalari',
        'Ugar' => 'Ugaritic',
        'Vaii' => 'Vai',
        'Visp' => 'Visible Speech',
        'Vith' => 'Vithkuqi',
        'Wara' => 'Varang Kshiti',
        'Wcho' => 'Wancho',
        'Wole' => 'Woleai',
        'Xpeo' => 'Old Persian',
        'Xsux' => 'Sumero-Akkadian Cuneiform',
        'Yezi' => 'Yezidi',
        'Yiii' => 'Yi',
        'Zanb' => 'Zanabazar Square',
        'Zinh' => 'Inherited',
        'Zmth' => 'Mathematical Notation',
        'Zsye' => 'Emoji',
        'Zsym' => 'Symbols',
        'Zxxx' => 'Unwritten',
        'Zyyy' => 'Common',
    ],
];
