<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Peseta Andóra',
        ],
        'AED' => [
            'AED',
            'Dirham Aontas na nÉimíríochtaí Arabacha',
        ],
        'AFA' => [
            'AFA',
            'Afgainí (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'Afghani na hAfganastáine',
        ],
        'ALK' => [
            'ALK',
            'Lek na hAlbáine (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'Lek na hAlbáine',
        ],
        'AMD' => [
            'AMD',
            'Dram na hAirméine',
        ],
        'ANG' => [
            'ANG',
            'Gildear Aintillí na hÍsiltíre',
        ],
        'AOA' => [
            'AOA',
            'Kwanza Angóla',
        ],
        'AOK' => [
            'AOK',
            'Kwanza Angólach (1977–1990)',
        ],
        'AON' => [
            'AON',
            'Kwanza Nua Angólach (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Kwanza Reajustado Angólach (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Austral Airgintíneach',
        ],
        'ARL' => [
            'ARL',
            'Peso Ley na hAirgintíne (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'Peso na hAirgintíne (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'Peso na hAirgintíne (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'Peso na hAirgintíne',
        ],
        'ATS' => [
            'ATS',
            'Scilling na hOstaire',
        ],
        'AUD' => [
            'A$',
            'Dollar na hAstráile',
        ],
        'AWG' => [
            'AWG',
            'Flóirín Arúba',
        ],
        'AZM' => [
            'AZM',
            'Manat na hAsarbaiseáine (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'Manat na hAsarbaiseáine',
        ],
        'BAD' => [
            'BAD',
            'Dínear Bhoisnia-Heirseagaivéin (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'Marg Inmhalartaithe na Boisnia-Heirseagaivéine',
        ],
        'BBD' => [
            'BBD',
            'Dollar Bharbadós',
        ],
        'BDT' => [
            'BDT',
            'Taka na Banglaidéise',
        ],
        'BEC' => [
            'BEC',
            'Franc na Beilge (inmhalartaithe)',
        ],
        'BEF' => [
            'BEF',
            'Franc Beilgeach',
        ],
        'BEL' => [
            'BEL',
            'Franc na Beilge (airgeadais)',
        ],
        'BGL' => [
            'BGL',
            'Lev Crua na Bulgáire',
        ],
        'BGN' => [
            'BGN',
            'Lev na Bulgáire',
        ],
        'BGO' => [
            'BGO',
            'Lev na Bulgáire (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'Dinar Bhairéin',
        ],
        'BIF' => [
            'BIF',
            'Franc na Burúine',
        ],
        'BMD' => [
            'BMD',
            'Dollar Bheirmiúda',
        ],
        'BND' => [
            'BND',
            'Dollar Bhrúiné',
        ],
        'BOB' => [
            'BOB',
            'Boliviano',
        ],
        'BOP' => [
            'BOP',
            'Peso na Bolaive',
        ],
        'BOV' => [
            'BOV',
            'Mvdol na Bolaive',
        ],
        'BRB' => [
            'BRB',
            'Cruzeiro Nua na Brasaíle (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Cruzado na Brasaíle (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'Cruzeiro na Brasaíle (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'Real na Brasaíle',
        ],
        'BRN' => [
            'BRN',
            'Cruzado Nua na Brasaíle (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'Cruzeiro na Brasaíle (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'Cruzeiro na Brasaíle (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'Dollar na mBahámaí',
        ],
        'BTN' => [
            'BTN',
            'Ngultrum na Bútáine',
        ],
        'BUK' => [
            'BUK',
            'Kyat Bhurma',
        ],
        'BWP' => [
            'BWP',
            'Pula na Botsuáine',
        ],
        'BYB' => [
            'BYB',
            'Rúbal Nua na Bealarúise (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'Rúbal na Bealarúise',
        ],
        'BYR' => [
            'BYR',
            'Rúbal na Bealarúise (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Dollar na Beilíse',
        ],
        'CAD' => [
            'CA$',
            'Dollar Cheanada',
        ],
        'CDF' => [
            'CDF',
            'Franc an Chongó',
        ],
        'CHE' => [
            'CHE',
            'Euro WIR',
        ],
        'CHF' => [
            'CHF',
            'Franc na hEilvéise',
        ],
        'CHW' => [
            'CHW',
            'Franc WIR',
        ],
        'CLE' => [
            'CLE',
            'Escudo na Sile',
        ],
        'CLF' => [
            'CLF',
            'Unidades de Fomento na Sile',
        ],
        'CLP' => [
            'CLP',
            'Peso na Sile',
        ],
        'CNH' => [
            'CNH',
            'Yuan na Síne (seachairgeadra)',
        ],
        'CNY' => [
            'CN¥',
            'Yuan na Síne',
        ],
        'COP' => [
            'COP',
            'Peso na Colóime',
        ],
        'CRC' => [
            'CRC',
            'Colón Chósta Ríce',
        ],
        'CSD' => [
            'CSD',
            'Dinar na Seirbia (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'Koruna Crua na Seicslóvaice',
        ],
        'CUC' => [
            'CUC',
            'Peso Inmhalartaithe Chúba',
        ],
        'CUP' => [
            'CUP',
            'Peso Chúba',
        ],
        'CVE' => [
            'CVE',
            'Escudo Rinn Verde',
        ],
        'CYP' => [
            'CYP',
            'Punt na Cipire',
        ],
        'CZK' => [
            'CZK',
            'Koruna Phoblacht na Seice',
        ],
        'DDM' => [
            'DDM',
            'Marc Ghearmáin an Oirthir',
        ],
        'DEM' => [
            'DEM',
            'Deutsche Mark',
        ],
        'DJF' => [
            'DJF',
            'Franc Djibouti',
        ],
        'DKK' => [
            'DKK',
            'Coróin na Danmhairge',
        ],
        'DOP' => [
            'DOP',
            'Peso na Poblachta Doiminicí',
        ],
        'DZD' => [
            'DZD',
            'Dinar na hAilgéire',
        ],
        'ECS' => [
            'ECS',
            'Sucre Eacuadóir',
        ],
        'ECV' => [
            'ECV',
            'Unidad de Valor Constante (UVC) Eacuadóir',
        ],
        'EEK' => [
            'EEK',
            'Kroon na hEastóine',
        ],
        'EGP' => [
            'EGP',
            'Punt na hÉigipte',
        ],
        'ERN' => [
            'ERN',
            'Nakfa na hEiritré',
        ],
        'ESP' => [
            'ESP',
            'Peseta na Spáinne',
        ],
        'ETB' => [
            'ETB',
            'Birr na hAetóipe',
        ],
        'EUR' => [
            '€',
            'Euro',
        ],
        'FIM' => [
            'FIM',
            'Markka Fionnlannach',
        ],
        'FJD' => [
            'FJD',
            'Dollar Fhidsí',
        ],
        'FKP' => [
            'FKP',
            'Punt Oileáin Fháclainne',
        ],
        'FRF' => [
            'FRF',
            'Franc na Fraince',
        ],
        'GBP' => [
            '£',
            'Punt Steirling',
        ],
        'GEK' => [
            'GEK',
            'Kupon Larit na Grúise',
        ],
        'GEL' => [
            'GEL',
            'Lari na Seoirsia',
        ],
        'GHC' => [
            'GHC',
            'Cedi Ghána (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'Cedi Ghána',
        ],
        'GIP' => [
            'GIP',
            'Punt Ghiobráltar',
        ],
        'GMD' => [
            'GMD',
            'Dalasi na Gaimbia',
        ],
        'GNF' => [
            'GNF',
            'Franc na Guine',
        ],
        'GNS' => [
            'GNS',
            'Syli Guine',
        ],
        'GQE' => [
            'GQE',
            'Ekwele Guineana na Guine Meánchiorclaí',
        ],
        'GRD' => [
            'GRD',
            'Drachma Gréagach',
        ],
        'GTQ' => [
            'GTQ',
            'Quetzal Ghuatamala',
        ],
        'GWE' => [
            'GWE',
            'Escudo na Guine Portaingéalaí',
        ],
        'GWP' => [
            'GWP',
            'Peso Guine-Bhissau',
        ],
        'GYD' => [
            'GYD',
            'Dollar na Guáine',
        ],
        'HKD' => [
            'HK$',
            'Dollar Hong Cong',
        ],
        'HNL' => [
            'HNL',
            'Lempira Hondúras',
        ],
        'HRD' => [
            'HRD',
            'Dínear na Cróite',
        ],
        'HRK' => [
            'HRK',
            'Kuna na Cróite',
        ],
        'HTG' => [
            'HTG',
            'Gourde Háítí',
        ],
        'HUF' => [
            'HUF',
            'Forint na hUngáire',
        ],
        'IDR' => [
            'IDR',
            'Rupiah na hIndinéise',
        ],
        'IEP' => [
            'IEP',
            'Punt Éireannach',
        ],
        'ILP' => [
            'ILP',
            'Punt Iosraelach',
        ],
        'ILS' => [
            '₪',
            'Seiceal Nua Iosrael',
        ],
        'INR' => [
            '₹',
            'Rúipí na hIndia',
        ],
        'IQD' => [
            'IQD',
            'Dinar na hIaráice',
        ],
        'IRR' => [
            'IRR',
            'Rial na hIaráine',
        ],
        'ISK' => [
            'ISK',
            'Króna na hÍoslainne',
        ],
        'ITL' => [
            'ITL',
            'Lira na hIodáile',
        ],
        'JMD' => [
            'JMD',
            'Dollar na hIamáice',
        ],
        'JOD' => [
            'JOD',
            'Dinar na hIordáine',
        ],
        'JPY' => [
            '¥',
            'Yen na Seapáine',
        ],
        'KES' => [
            'KES',
            'Scilling na Céinia',
        ],
        'KGS' => [
            'KGS',
            'Som na Cirgeastáine',
        ],
        'KHR' => [
            'KHR',
            'Riel na Cambóide',
        ],
        'KMF' => [
            'KMF',
            'Franc Oileáin Chomóra',
        ],
        'KPW' => [
            'KPW',
            'Won na Cóiré Thuaidh',
        ],
        'KRW' => [
            '₩',
            'Won na Cóiré Theas',
        ],
        'KWD' => [
            'KWD',
            'Dinar Chuáit',
        ],
        'KYD' => [
            'KYD',
            'Dollar Oileáin Cayman',
        ],
        'KZT' => [
            'KZT',
            'Tenge na Casacstáine',
        ],
        'LAK' => [
            'LAK',
            'Kip Laos',
        ],
        'LBP' => [
            'LBP',
            'Punt na Liobáine',
        ],
        'LKR' => [
            'LKR',
            'Rúipí Shrí Lanca',
        ],
        'LRD' => [
            'LRD',
            'Dollar na Libéire',
        ],
        'LSL' => [
            'LSL',
            'Loti Leosóta',
        ],
        'LTL' => [
            'LTL',
            'Litas na Liotuáine',
        ],
        'LTT' => [
            'LTT',
            'Talonas Liotuánach',
        ],
        'LUC' => [
            'LUC',
            'Franc Inmhalartach Lucsamburgach',
        ],
        'LUF' => [
            'LUF',
            'Franc Lucsamburg',
        ],
        'LVL' => [
            'LVL',
            'Lats na Laitvia',
        ],
        'LVR' => [
            'LVR',
            'Rúbal na Laitvia',
        ],
        'LYD' => [
            'LYD',
            'Dinar na Libia',
        ],
        'MAD' => [
            'MAD',
            'Dirham Mharacó',
        ],
        'MAF' => [
            'MAF',
            'Franc Mharacó',
        ],
        'MDL' => [
            'MDL',
            'Leu na Moldóive',
        ],
        'MGA' => [
            'MGA',
            'Ariary Mhadagascar',
        ],
        'MGF' => [
            'MGF',
            'Franc Madagascar',
        ],
        'MKD' => [
            'MKD',
            'Denar na Macadóine',
        ],
        'MLF' => [
            'MLF',
            'Franc Mhailí',
        ],
        'MMK' => [
            'MMK',
            'Kyat Mhaenmar',
        ],
        'MNT' => [
            'MNT',
            'Tugrik na Mongóile',
        ],
        'MOP' => [
            'MOP',
            'Pataca Mhacao',
        ],
        'MRO' => [
            'MRO',
            'Ouguiya na Máratáine (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Ouguiya na Máratáine',
        ],
        'MTL' => [
            'MTL',
            'Lira Mhálta',
        ],
        'MTP' => [
            'MTP',
            'Punt Mhálta',
        ],
        'MUR' => [
            'MUR',
            'Rúipí Oileán Mhuirís',
        ],
        'MVP' => [
            'MVP',
            'Rúipí Oileáin Mhaildíve',
        ],
        'MVR' => [
            'MVR',
            'Rufiyaa Oileáin Mhaildíve',
        ],
        'MWK' => [
            'MWK',
            'Kwacha na Maláive',
        ],
        'MXN' => [
            'MX$',
            'Peso Mheicsiceo',
        ],
        'MXP' => [
            'MXP',
            'Peso Airgid Mheicsiceo (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Aonad Infheistíochta Meicsiceach',
        ],
        'MYR' => [
            'MYR',
            'Ringgit na Malaeisia',
        ],
        'MZE' => [
            'MZE',
            'Escudo Mósaimbíce',
        ],
        'MZM' => [
            'MZM',
            'Metical Mósaimbíce',
        ],
        'MZN' => [
            'MZN',
            'Metical Mhósaimbíc',
        ],
        'NAD' => [
            'NAD',
            'Dollar na Namaibe',
        ],
        'NGN' => [
            'NGN',
            'Naira na Nigéire',
        ],
        'NIC' => [
            'NIC',
            'Córdoba Nicearagua (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'Córdoba Nicearagua',
        ],
        'NLG' => [
            'NLG',
            'Guilder Ísiltíreach',
        ],
        'NOK' => [
            'NOK',
            'Coróin na hIorua',
        ],
        'NPR' => [
            'NPR',
            'Rúipí Neipeal',
        ],
        'NZD' => [
            'NZ$',
            'Dollar na Nua-Shéalainne',
        ],
        'OMR' => [
            'OMR',
            'Rial Óman',
        ],
        'PAB' => [
            'PAB',
            'Balboa Phanama',
        ],
        'PEI' => [
            'PEI',
            'Inti Pheiriú',
        ],
        'PEN' => [
            'PEN',
            'Sol Pheiriú',
        ],
        'PES' => [
            'PES',
            'Sol Pheiriú (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'Kina Nua-Ghuine Phapua',
        ],
        'PHP' => [
            '₱',
            'Peso na nOileán Filipíneach',
        ],
        'PKR' => [
            'PKR',
            'Rúipí na Pacastáine',
        ],
        'PLN' => [
            'PLN',
            'Zloty na Polainne',
        ],
        'PLZ' => [
            'PLZ',
            'Zloty Polannach (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'Escudo na Portaingéile',
        ],
        'PYG' => [
            'PYG',
            'Guaraní Pharagua',
        ],
        'QAR' => [
            'QAR',
            'Riyal Chatar',
        ],
        'ROL' => [
            'ROL',
            'Leu na Rómáine (1952–2006)',
        ],
        'RON' => [
            'RON',
            'Leu na Rómáine',
        ],
        'RSD' => [
            'RSD',
            'Dinar na Seirbia',
        ],
        'RUB' => [
            'RUB',
            'Rúbal na Rúise',
        ],
        'RUR' => [
            'RUR',
            'Rúbal na Rúise (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'Franc Ruanda',
        ],
        'SAR' => [
            'SAR',
            'Riyal na hAraibe Sádaí',
        ],
        'SBD' => [
            'SBD',
            'Dollar Oileáin Sholomón',
        ],
        'SCR' => [
            'SCR',
            'Rúipí na Séiséal',
        ],
        'SDD' => [
            'SDD',
            'Dinar na Súdáine (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'Punt na Súdáine',
        ],
        'SDP' => [
            'SDP',
            'Punt na Súdáine (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'Coróin na Sualainne',
        ],
        'SGD' => [
            'SGD',
            'Dollar Shingeapór',
        ],
        'SHP' => [
            'SHP',
            'Punt San Héilin',
        ],
        'SIT' => [
            'SIT',
            'Tolar na Slóivéine',
        ],
        'SKK' => [
            'SKK',
            'Koruna na Slóvaice',
        ],
        'SLE' => [
            'SLE',
            'Leone Shiarra Leon',
        ],
        'SLL' => [
            'SLL',
            'Leone Shiarra Leon (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Scilling na Somáile',
        ],
        'SRD' => [
            'SRD',
            'Dollar Shuranam',
        ],
        'SRG' => [
            'SRG',
            'Gildear Shuranam',
        ],
        'SSP' => [
            'SSP',
            'Punt na Súdáine Theas',
        ],
        'STD' => [
            'STD',
            'Dobra São Tomé agus Príncipe (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Dobra São Tomé agus Príncipe',
        ],
        'SUR' => [
            'SUR',
            'Rúbal an Aontais Shóivéadaigh',
        ],
        'SVC' => [
            'SVC',
            'Colón na Salvadóire',
        ],
        'SYP' => [
            'SYP',
            'Punt na Siria',
        ],
        'SZL' => [
            'SZL',
            'Lilangeni na Suasalainne',
        ],
        'THB' => [
            '฿',
            'Baht na Téalainne',
        ],
        'TJR' => [
            'TJR',
            'Rúbal na Táidsíceastáine',
        ],
        'TJS' => [
            'TJS',
            'Somoni na Táidsíceastáine',
        ],
        'TMM' => [
            'TMM',
            'Manat na Tuircméanastáine (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'Manat na Tuircméanastáine',
        ],
        'TND' => [
            'TND',
            'Dinar na Túinéise',
        ],
        'TOP' => [
            'TOP',
            'Paʻanga Thonga',
        ],
        'TPE' => [
            'TPE',
            'Escudo Tíomóir',
        ],
        'TRL' => [
            'TRL',
            'Lira na Tuirce (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'Lira na Tuirce',
        ],
        'TTD' => [
            'TTD',
            'Dollar Oileán na Tríonóide agus Tobága',
        ],
        'TWD' => [
            'NT$',
            'Dollar Nua na Téaváine',
        ],
        'TZS' => [
            'TZS',
            'Scilling na Tansáine',
        ],
        'UAH' => [
            'UAH',
            'Hryvnia na hÚcráine',
        ],
        'UAK' => [
            'UAK',
            'Karbovanets Úcránach',
        ],
        'UGS' => [
            'UGS',
            'Scilling Uganda (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'Scilling Uganda',
        ],
        'USD' => [
            '$',
            'Dollar S.A.M.',
        ],
        'USN' => [
            'USN',
            'Dollar S.A.M. (an chéad lá eile)',
        ],
        'USS' => [
            'USS',
            'Dollar S.A.M. (an lá céanna)',
        ],
        'UYP' => [
            'UYP',
            'Peso Uragua (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'Peso Uragua',
        ],
        'UZS' => [
            'UZS',
            'Sum na hÚisbéiceastáine',
        ],
        'VEB' => [
            'VEB',
            'Bolívar Veiniséala (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'Bolívar Veiniséala (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Bolívar Veiniséala',
        ],
        'VND' => [
            '₫',
            'Dong Vítneam',
        ],
        'VNN' => [
            'VNN',
            'Dong Vítneam (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'Vatu Vanuatú',
        ],
        'WST' => [
            'WST',
            'Tala Shamó',
        ],
        'XAF' => [
            'FCFA',
            'Franc CFA na hAfraice Láir',
        ],
        'XCD' => [
            'EC$',
            'Dollar na Cairibe Thoir',
        ],
        'XCG' => [
            'Cg.',
            'gildear Chairib',
        ],
        'XEU' => [
            'XEU',
            'Aonad Airgeadra Eorpach',
        ],
        'XFO' => [
            'XFO',
            'Franc Ór Francach',
        ],
        'XFU' => [
            'XFU',
            'UIC-Franc Francach',
        ],
        'XOF' => [
            'F CFA',
            'Franc CFA Iarthar na hAfraice',
        ],
        'XPF' => [
            'CFPF',
            'Franc CFP',
        ],
        'YDD' => [
            'YDD',
            'Dínear Éimin',
        ],
        'YER' => [
            'YER',
            'Rial Éimin',
        ],
        'YUD' => [
            'YUD',
            'Dínear Crua Iúgslavach (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'Dínear Nua Iúgslavach (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'Dinar Inmhalartaithe Iúgslavach (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'Dinar Leasaithe na hIúgsláive (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'Rand na hAfraice Theas (airgeadúil)',
        ],
        'ZAR' => [
            'ZAR',
            'Rand na hAfraice Theas',
        ],
        'ZMK' => [
            'ZMK',
            'Kwacha Saimbiach (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Kwacha na Saimbia',
        ],
        'ZRN' => [
            'ZRN',
            'Zaire Nua Sáíreach',
        ],
        'ZRZ' => [
            'ZRZ',
            'Zaire Sáíreach',
        ],
        'ZWD' => [
            'ZWD',
            'Dollar Siombábach (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'ór na Siombáibe',
        ],
        'ZWL' => [
            'ZWL',
            'Dollar na Siombáibe (2009)',
        ],
    ],
];
