<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ग्रीनविच मीन टाइम (अबिदजान)',
        'Africa/Accra' => 'ग्रीनविच मीन टाइम (एक्रा)',
        'Africa/Addis_Ababa' => 'पूर्वी अफ़्रीका समय (अदीस अबाबा)',
        'Africa/Algiers' => 'मध्य यूरोपीय समय (अल्जीयर्स)',
        'Africa/Asmera' => 'पूर्वी अफ़्रीका समय (अस्मारा)',
        'Africa/Asmara' => 'पूर्वी अफ़्रीका समय (अस्मारा)',
        'Africa/Bamako' => 'ग्रीनविच मीन टाइम (बामाको)',
        'Africa/Bangui' => 'पश्चिम अफ़्रीका समय (बांगुइ)',
        'Africa/Banjul' => 'ग्रीनविच मीन टाइम (बैंजुल)',
        'Africa/Bissau' => 'ग्रीनविच मीन टाइम (बिसाऊ)',
        'Africa/Blantyre' => 'मध्य अफ़्रीका समय (ब्लांटायर)',
        'Africa/Brazzaville' => 'पश्चिम अफ़्रीका समय (ब्राज़ाविले)',
        'Africa/Bujumbura' => 'मध्य अफ़्रीका समय (बुजुंबूरा)',
        'Africa/Cairo' => 'पूर्वी यूरोपीय समय (कायरो)',
        'Africa/Casablanca' => 'पश्चिमी यूरोपीय समय (कासाब्लांका)',
        'Africa/Ceuta' => 'मध्य यूरोपीय समय (सेउटा)',
        'Africa/Conakry' => 'ग्रीनविच मीन टाइम (कोनाक्री)',
        'Africa/Dakar' => 'ग्रीनविच मीन टाइम (डकार)',
        'Africa/Dar_es_Salaam' => 'पूर्वी अफ़्रीका समय (दार अस सलाम)',
        'Africa/Djibouti' => 'पूर्वी अफ़्रीका समय (जिबूती)',
        'Africa/Douala' => 'पश्चिम अफ़्रीका समय (डूआला)',
        'Africa/El_Aaiun' => 'पश्चिमी यूरोपीय समय (अल आइयून)',
        'Africa/Freetown' => 'ग्रीनविच मीन टाइम (फ़्रीटाउन)',
        'Africa/Gaborone' => 'मध्य अफ़्रीका समय (गाबोरोन)',
        'Africa/Harare' => 'मध्य अफ़्रीका समय (हरारे)',
        'Africa/Johannesburg' => 'दक्षिण अफ़्रीका मानक समय (जोहांसबर्ग)',
        'Africa/Juba' => 'मध्य अफ़्रीका समय (जुबा)',
        'Africa/Kampala' => 'पूर्वी अफ़्रीका समय (कंपाला)',
        'Africa/Khartoum' => 'मध्य अफ़्रीका समय (खार्तूम)',
        'Africa/Kigali' => 'मध्य अफ़्रीका समय (किगाली)',
        'Africa/Kinshasa' => 'पश्चिम अफ़्रीका समय (किंशासा)',
        'Africa/Lagos' => 'पश्चिम अफ़्रीका समय (लागोस)',
        'Africa/Libreville' => 'पश्चिम अफ़्रीका समय (लिब्रेविले)',
        'Africa/Lome' => 'ग्रीनविच मीन टाइम (लोम)',
        'Africa/Luanda' => 'पश्चिम अफ़्रीका समय (लुआंडा)',
        'Africa/Lubumbashi' => 'मध्य अफ़्रीका समय (लुबुमबाशी)',
        'Africa/Lusaka' => 'मध्य अफ़्रीका समय (लुसाका)',
        'Africa/Malabo' => 'पश्चिम अफ़्रीका समय (मलाबो)',
        'Africa/Maputo' => 'मध्य अफ़्रीका समय (मापुटो)',
        'Africa/Maseru' => 'दक्षिण अफ़्रीका मानक समय (मासेरू)',
        'Africa/Mbabane' => 'दक्षिण अफ़्रीका मानक समय (एमबाबेन)',
        'Africa/Mogadishu' => 'पूर्वी अफ़्रीका समय (मोगादिशु)',
        'Africa/Monrovia' => 'ग्रीनविच मीन टाइम (मोनरोविया)',
        'Africa/Nairobi' => 'पूर्वी अफ़्रीका समय (नैरोबी)',
        'Africa/Ndjamena' => 'पश्चिम अफ़्रीका समय (नेद्जामीना)',
        'Africa/Niamey' => 'पश्चिम अफ़्रीका समय (नियामी)',
        'Africa/Nouakchott' => 'ग्रीनविच मीन टाइम (नौआकशॉट)',
        'Africa/Ouagadougou' => 'ग्रीनविच मीन टाइम (औगाडोगू)',
        'Africa/Porto-Novo' => 'पश्चिम अफ़्रीका समय (पोर्टो-नोवो)',
        'Africa/Sao_Tome' => 'ग्रीनविच मीन टाइम (साओ टोम)',
        'Africa/Tripoli' => 'पूर्वी यूरोपीय समय (त्रिपोली)',
        'Africa/Tunis' => 'मध्य यूरोपीय समय (ट्यूनिस)',
        'Africa/Windhoek' => 'मध्य अफ़्रीका समय (विंडहोक)',
        'America/Adak' => 'हवाई–आल्यूशन समय (अडक)',
        'America/Anchorage' => 'अलास्का समय (एंकरेज)',
        'America/Anguilla' => 'अटलांटिक समय (एंग्विला)',
        'America/Antigua' => 'अटलांटिक समय (एंटीगुआ)',
        'America/Araguaina' => 'ब्राज़ीलिया समय (आराग्वेना)',
        'America/Argentina/La_Rioja' => 'अर्जेंटीना समय (ला रिओजा)',
        'America/Argentina/Rio_Gallegos' => 'अर्जेंटीना समय (रियो गालेगोस)',
        'America/Argentina/Salta' => 'अर्जेंटीना समय (साल्टा)',
        'America/Argentina/San_Juan' => 'अर्जेंटीना समय (सैन ह्वान)',
        'America/Argentina/San_Luis' => 'अर्जेंटीना समय (सैन लूई)',
        'America/Argentina/Tucuman' => 'अर्जेंटीना समय (टोकूमन)',
        'America/Argentina/Ushuaia' => 'अर्जेंटीना समय (उशुआइया)',
        'America/Aruba' => 'अटलांटिक समय (अरूबा)',
        'America/Asuncion' => 'पैराग्वे समय (एसनशियॉन)',
        'America/Bahia' => 'ब्राज़ीलिया समय (बहिया)',
        'America/Bahia_Banderas' => 'उत्तरी अमेरिकी केंद्रीय समय (बेहिया बांडेरास)',
        'America/Barbados' => 'अटलांटिक समय (बारबाडोस)',
        'America/Belem' => 'ब्राज़ीलिया समय (बेलेम)',
        'America/Belize' => 'उत्तरी अमेरिकी केंद्रीय समय (बेलीज़)',
        'America/Blanc-Sablon' => 'अटलांटिक समय (ब्लांक-सेबलोन)',
        'America/Boa_Vista' => 'अमेज़न समय (बोआ विस्ता)',
        'America/Bogota' => 'कोलंबिया समय (बोगोटा)',
        'America/Boise' => 'उत्तरी अमेरिकी माउंटेन समय (बॉइसी)',
        'America/Buenos_Aires' => 'अर्जेंटीना समय (ब्यूनस आयरस)',
        'America/Argentina/Buenos_Aires' => 'अर्जेंटीना समय (ब्यूनस आयरस)',
        'America/Cambridge_Bay' => 'उत्तरी अमेरिकी माउंटेन समय (कैम्ब्रिज खाड़ी)',
        'America/Campo_Grande' => 'अमेज़न समय (कैंपो ग्रांडे)',
        'America/Cancun' => 'उत्तरी अमेरिकी पूर्वी समय (कैनकुन)',
        'America/Caracas' => 'वेनेज़ुएला समय (काराकस)',
        'America/Catamarca' => 'अर्जेंटीना समय (काटामार्का)',
        'America/Argentina/Catamarca' => 'अर्जेंटीना समय (काटामार्का)',
        'America/Cayenne' => 'फ़्रेंच गुयाना समय (कायेन)',
        'America/Cayman' => 'उत्तरी अमेरिकी पूर्वी समय (कैमेन)',
        'America/Chicago' => 'उत्तरी अमेरिकी केंद्रीय समय (शिकागो)',
        'America/Chihuahua' => 'उत्तरी अमेरिकी केंद्रीय समय (चिहुआहुआ)',
        'America/Ciudad_Juarez' => 'उत्तरी अमेरिकी माउंटेन समय (स्युदाद ह्वारेज़)',
        'America/Coral_Harbour' => 'उत्तरी अमेरिकी पूर्वी समय (अटिकोकान)',
        'America/Atikokan' => 'उत्तरी अमेरिकी पूर्वी समय (अटिकोकान)',
        'America/Cordoba' => 'अर्जेंटीना समय (कोर्डोबा)',
        'America/Argentina/Cordoba' => 'अर्जेंटीना समय (कोर्डोबा)',
        'America/Costa_Rica' => 'उत्तरी अमेरिकी केंद्रीय समय (कोस्टा रिका)',
        'America/Coyhaique' => 'चिली समय (कॉयहेक)',
        'America/Creston' => 'उत्तरी अमेरिकी माउंटेन समय (क्रेस्टन)',
        'America/Cuiaba' => 'अमेज़न समय (क्यूआबा)',
        'America/Curacao' => 'अटलांटिक समय (कुराकाओ)',
        'America/Danmarkshavn' => 'ग्रीनविच मीन टाइम (डेनमार्कशॉन)',
        'America/Dawson' => 'युकॉन समय (डॉसन)',
        'America/Dawson_Creek' => 'उत्तरी अमेरिकी माउंटेन समय (डॉसन क्रीक)',
        'America/Denver' => 'उत्तरी अमेरिकी माउंटेन समय (डेनवर)',
        'America/Detroit' => 'उत्तरी अमेरिकी पूर्वी समय (डेट्रॉयट)',
        'America/Dominica' => 'अटलांटिक समय (डोमिनिका)',
        'America/Edmonton' => 'उत्तरी अमेरिकी माउंटेन समय (एडमंटन)',
        'America/Eirunepe' => 'ब्राज़ील समय (ईरुनेपे)',
        'America/El_Salvador' => 'उत्तरी अमेरिकी केंद्रीय समय (अल सल्वाडोर)',
        'America/Fort_Nelson' => 'उत्तरी अमेरिकी माउंटेन समय (फ़ोर्ट नेल्सन)',
        'America/Fortaleza' => 'ब्राज़ीलिया समय (फ़ोर्टालेज़ा)',
        'America/Glace_Bay' => 'अटलांटिक समय (ग्लेस खाड़ी)',
        'America/Godthab' => 'ग्रीनलैंड समय (नुक)',
        'America/Nuuk' => 'ग्रीनलैंड समय (नुक)',
        'America/Goose_Bay' => 'अटलांटिक समय (गूस खाड़ी)',
        'America/Grand_Turk' => 'उत्तरी अमेरिकी पूर्वी समय (ग्रांड टर्क)',
        'America/Grenada' => 'अटलांटिक समय (ग्रेनाडा)',
        'America/Guadeloupe' => 'अटलांटिक समय (ग्वाडेलोप)',
        'America/Guatemala' => 'उत्तरी अमेरिकी केंद्रीय समय (ग्वाटेमाला)',
        'America/Guayaquil' => 'इक्वाडोर समय (ग्वायाकील)',
        'America/Guyana' => 'गुयाना समय (गयाना)',
        'America/Halifax' => 'अटलांटिक समय (हेलिफ़ैक्स)',
        'America/Havana' => 'क्यूबा समय (हवाना)',
        'America/Hermosillo' => 'मेक्सिकन प्रशांत समय (हर्मोसिल्लो)',
        'America/Indiana/Knox' => 'उत्तरी अमेरिकी केंद्रीय समय (नौक्स, इंडियाना)',
        'America/Indiana/Marengo' => 'उत्तरी अमेरिकी पूर्वी समय (मारेंगो, इंडियाना)',
        'America/Indiana/Petersburg' => 'उत्तरी अमेरिकी पूर्वी समय (पीटर्सबर्ग, इंडियाना)',
        'America/Indiana/Tell_City' => 'उत्तरी अमेरिकी केंद्रीय समय (टेल सिटी, इंडियाना)',
        'America/Indiana/Vevay' => 'उत्तरी अमेरिकी पूर्वी समय (वेवे, इंडियाना)',
        'America/Indiana/Vincennes' => 'उत्तरी अमेरिकी पूर्वी समय (विंसेनेस, इंडियाना)',
        'America/Indiana/Winamac' => 'उत्तरी अमेरिकी पूर्वी समय (विनामेक, इंडियाना)',
        'America/Indianapolis' => 'उत्तरी अमेरिकी पूर्वी समय (इंडियानापोलिस)',
        'America/Indiana/Indianapolis' => 'उत्तरी अमेरिकी पूर्वी समय (इंडियानापोलिस)',
        'America/Inuvik' => 'उत्तरी अमेरिकी माउंटेन समय (इनूविक)',
        'America/Iqaluit' => 'उत्तरी अमेरिकी पूर्वी समय (इकालुईट)',
        'America/Jamaica' => 'उत्तरी अमेरिकी पूर्वी समय (जमैका)',
        'America/Jujuy' => 'अर्जेंटीना समय (जुजोए)',
        'America/Argentina/Jujuy' => 'अर्जेंटीना समय (जुजोए)',
        'America/Juneau' => 'अलास्का समय (ज्यूनाउ)',
        'America/Kentucky/Monticello' => 'उत्तरी अमेरिकी पूर्वी समय (मोंटीसेलो, केंटकी)',
        'America/Kralendijk' => 'अटलांटिक समय (क्रालैंडिजिक)',
        'America/La_Paz' => 'बोलीविया समय (ला पाज़)',
        'America/Lima' => 'पेरू समय (लीमा)',
        'America/Los_Angeles' => 'उत्तरी अमेरिकी प्रशांत समय (लॉस एंजिल्स)',
        'America/Louisville' => 'उत्तरी अमेरिकी पूर्वी समय (लुइसविले)',
        'America/Kentucky/Louisville' => 'उत्तरी अमेरिकी पूर्वी समय (लुइसविले)',
        'America/Lower_Princes' => 'अटलांटिक समय (लोअर प्रिंसेस क्वार्टर)',
        'America/Maceio' => 'ब्राज़ीलिया समय (मेसीओ)',
        'America/Managua' => 'उत्तरी अमेरिकी केंद्रीय समय (मानागुआ)',
        'America/Manaus' => 'अमेज़न समय (मनौस)',
        'America/Marigot' => 'अटलांटिक समय (मैरीगोट)',
        'America/Martinique' => 'अटलांटिक समय (मार्टिनिक)',
        'America/Matamoros' => 'उत्तरी अमेरिकी केंद्रीय समय (माटामोरोस)',
        'America/Mazatlan' => 'मेक्सिकन प्रशांत समय (माज़ाटलान)',
        'America/Mendoza' => 'अर्जेंटीना समय (मेंडोज़ा)',
        'America/Argentina/Mendoza' => 'अर्जेंटीना समय (मेंडोज़ा)',
        'America/Menominee' => 'उत्तरी अमेरिकी केंद्रीय समय (मेनोमिनी)',
        'America/Merida' => 'उत्तरी अमेरिकी केंद्रीय समय (मेरिडा)',
        'America/Metlakatla' => 'अलास्का समय (मेट्लेकाट्ला)',
        'America/Mexico_City' => 'उत्तरी अमेरिकी केंद्रीय समय (मेक्सिको सिटी)',
        'America/Miquelon' => 'सेंट पिएरे और मिक्वेलान समय (मिकेलॉन)',
        'America/Moncton' => 'अटलांटिक समय (मोंकटन)',
        'America/Monterrey' => 'उत्तरी अमेरिकी केंद्रीय समय (मोंटेरेरी)',
        'America/Montevideo' => 'उरुग्वे समय (मोंटेवीडियो)',
        'America/Montserrat' => 'अटलांटिक समय (मोंटसेरात)',
        'America/Nassau' => 'उत्तरी अमेरिकी पूर्वी समय (नासाउ)',
        'America/New_York' => 'उत्तरी अमेरिकी पूर्वी समय (न्यूयॉर्क)',
        'America/Nome' => 'अलास्का समय (नोम)',
        'America/Noronha' => 'फ़र्नांर्डो डे नोरोन्हा समय',
        'America/North_Dakota/Beulah' => 'उत्तरी अमेरिकी केंद्रीय समय (ब्यूला, उत्तरी डकोटा)',
        'America/North_Dakota/Center' => 'उत्तरी अमेरिकी केंद्रीय समय (मध्य, उत्तरी दाकोता)',
        'America/North_Dakota/New_Salem' => 'उत्तरी अमेरिकी केंद्रीय समय (न्यू सालेम, उत्तरी डकोटा)',
        'America/Ojinaga' => 'उत्तरी अमेरिकी केंद्रीय समय (ओखाजीनागा)',
        'America/Panama' => 'उत्तरी अमेरिकी पूर्वी समय (पनामा)',
        'America/Paramaribo' => 'सूरीनाम समय (पारामारिबो)',
        'America/Phoenix' => 'उत्तरी अमेरिकी माउंटेन समय (फ़ीनिक्स)',
        'America/Port-au-Prince' => 'उत्तरी अमेरिकी पूर्वी समय (पोर्ट-ऑ-प्रिंस)',
        'America/Port_of_Spain' => 'अटलांटिक समय (पोर्ट ऑफ़ स्पेन)',
        'America/Porto_Velho' => 'अमेज़न समय (पोर्टो वेल्हो)',
        'America/Puerto_Rico' => 'अटलांटिक समय (पोर्टो रिको)',
        'America/Punta_Arenas' => 'चिली समय (पुंटा एरिनास)',
        'America/Rankin_Inlet' => 'उत्तरी अमेरिकी केंद्रीय समय (रेंकिन इनलेट)',
        'America/Recife' => 'ब्राज़ीलिया समय (रेसाइफ़)',
        'America/Regina' => 'उत्तरी अमेरिकी केंद्रीय समय (रेजिना)',
        'America/Resolute' => 'उत्तरी अमेरिकी केंद्रीय समय (रिसोल्यूट)',
        'America/Rio_Branco' => 'ब्राज़ील समय (रियो ब्रांको)',
        'America/Santarem' => 'ब्राज़ीलिया समय (सैंटारेम)',
        'America/Santiago' => 'चिली समय (सैंटियागो)',
        'America/Santo_Domingo' => 'अटलांटिक समय (सेंटो डोमिंगो)',
        'America/Sao_Paulo' => 'ब्राज़ीलिया समय (साओ पाउलो)',
        'America/Scoresbysund' => 'ग्रीनलैंड समय (इटोकोर्टोरमिट)',
        'America/Sitka' => 'अलास्का समय (सिट्का)',
        'America/St_Barthelemy' => 'अटलांटिक समय (सेंट बार्थेलेमी)',
        'America/St_Johns' => 'न्यूफ़ाउंडलैंड समय (सेंट जोंस)',
        'America/St_Kitts' => 'अटलांटिक समय (सेंट किट्स)',
        'America/St_Lucia' => 'अटलांटिक समय (सेंट लूसिया)',
        'America/St_Thomas' => 'अटलांटिक समय (सेंट थॉमस)',
        'America/St_Vincent' => 'अटलांटिक समय (सेंट विंसेंट)',
        'America/Swift_Current' => 'उत्तरी अमेरिकी केंद्रीय समय (स्विफ़्ट करंट)',
        'America/Tegucigalpa' => 'उत्तरी अमेरिकी केंद्रीय समय (टेगुसिगल्पा)',
        'America/Thule' => 'अटलांटिक समय (थ्यूले)',
        'America/Tijuana' => 'उत्तरी अमेरिकी प्रशांत समय (तिजुआना)',
        'America/Toronto' => 'उत्तरी अमेरिकी पूर्वी समय (टोरंटो)',
        'America/Tortola' => 'अटलांटिक समय (टोर्टोला)',
        'America/Vancouver' => 'उत्तरी अमेरिकी प्रशांत समय (वैंकूवर)',
        'America/Whitehorse' => 'युकॉन समय (व्हाइटहोर्स)',
        'America/Winnipeg' => 'उत्तरी अमेरिकी केंद्रीय समय (विनीपेग)',
        'America/Yakutat' => 'अलास्का समय (याकूटाट)',
        'Antarctica/Casey' => 'पश्चिमी ऑस्ट्रेलिया समय (केसी)',
        'Antarctica/Davis' => 'डेविस समय',
        'Antarctica/DumontDUrville' => 'ड्यूमोंट डी अर्विले समय',
        'Antarctica/Macquarie' => 'पूर्वी ऑस्ट्रेलिया समय (मक्वारी)',
        'Antarctica/Mawson' => 'माव्सन समय (मॉसन)',
        'Antarctica/McMurdo' => 'न्यूज़ीलैंड समय (मैकमुर्डो)',
        'Antarctica/Palmer' => 'चिली समय (पॉमर)',
        'Antarctica/Rothera' => 'रोथेरा समय',
        'Antarctica/Syowa' => 'स्योवा समय',
        'Antarctica/Troll' => 'ग्रीनविच मीन टाइम (ट्रोल)',
        'Antarctica/Vostok' => 'वोस्तोक समय',
        'Arctic/Longyearbyen' => 'मध्य यूरोपीय समय (लॉन्गईयरबायेन)',
        'Asia/Aden' => 'अरब समय (आदेन)',
        'Asia/Almaty' => 'कज़ाखस्तान समय (अल्माटी)',
        'Asia/Amman' => 'पूर्वी यूरोपीय समय (अम्मान)',
        'Asia/Anadyr' => 'पेट्रोपेवलास्क-कैमचात्सकी समय (अनाडिर)',
        'Asia/Aqtau' => 'कज़ाखस्तान समय (अक्ताउ)',
        'Asia/Aqtobe' => 'कज़ाखस्तान समय (अक्तोब)',
        'Asia/Ashgabat' => 'तुर्कमेनिस्तान समय (अश्गाबात)',
        'Asia/Atyrau' => 'कज़ाखस्तान समय (एतराउ)',
        'Asia/Baghdad' => 'अरब समय (बगदाद)',
        'Asia/Bahrain' => 'अरब समय (बहरीन)',
        'Asia/Baku' => 'अज़रबैजान समय (बाकु)',
        'Asia/Bangkok' => 'इंडोचाइना समय (बैंकॉक)',
        'Asia/Barnaul' => 'क्रास्नोयार्स्क समय (बर्नोल)',
        'Asia/Beirut' => 'पूर्वी यूरोपीय समय (बेरुत)',
        'Asia/Bishkek' => 'किर्गिस्‍तान समय (बिश्केक)',
        'Asia/Brunei' => 'ब्रूनेई दारूस्सलम समय',
        'Asia/Calcutta' => 'भारतीय मानक समय (कोलकाता)',
        'Asia/Kolkata' => 'भारतीय मानक समय (कोलकाता)',
        'Asia/Chita' => 'याकुत्स्क समय (त्शिता)',
        'Asia/Colombo' => 'भारतीय मानक समय (कोलंबो)',
        'Asia/Damascus' => 'पूर्वी यूरोपीय समय (दमास्कस)',
        'Asia/Dhaka' => 'बांग्लादेश समय (ढाका)',
        'Asia/Dili' => 'पूर्वी तिमोर समय (डिलि)',
        'Asia/Dubai' => 'खाड़ी मानक समय (दुबई)',
        'Asia/Dushanbe' => 'ताजिकिस्तान समय (दुशांबे)',
        'Asia/Famagusta' => 'पूर्वी यूरोपीय समय (फ़ामागुस्ता)',
        'Asia/Gaza' => 'पूर्वी यूरोपीय समय (गाज़ा)',
        'Asia/Hebron' => 'पूर्वी यूरोपीय समय (हेब्रोन)',
        'Asia/Hong_Kong' => 'हाँग काँग समय',
        'Asia/Hovd' => 'होव्ड समय',
        'Asia/Irkutsk' => 'इर्कुत्स्क समय',
        'Asia/Jakarta' => 'पश्चिमी इंडोनेशिया समय (जकार्ता)',
        'Asia/Jayapura' => 'पूर्वी इंडोनेशिया समय (जयापुरा)',
        'Asia/Jerusalem' => 'इज़राइल समय (यरूशलम)',
        'Asia/Kabul' => 'अफ़गानिस्तान समय (काबुल)',
        'Asia/Kamchatka' => 'पेट्रोपेवलास्क-कैमचात्सकी समय (कमचत्का)',
        'Asia/Karachi' => 'पाकिस्तान समय (कराची)',
        'Asia/Katmandu' => 'नेपाल समय (काठमांडू)',
        'Asia/Kathmandu' => 'नेपाल समय (काठमांडू)',
        'Asia/Khandyga' => 'याकुत्स्क समय (खांडिगा)',
        'Asia/Krasnoyarsk' => 'क्रास्नोयार्स्क समय',
        'Asia/Kuala_Lumpur' => 'मलेशिया समय (कुआलालंपुर)',
        'Asia/Kuching' => 'मलेशिया समय (कूचिंग)',
        'Asia/Kuwait' => 'अरब समय (कुवैत)',
        'Asia/Macau' => 'चीन समय (मकाऊ)',
        'Asia/Magadan' => 'मागादान समय',
        'Asia/Makassar' => 'मध्य इंडोनेशिया समय (मकस्सर)',
        'Asia/Manila' => 'फ़िलिपीन समय (मनीला)',
        'Asia/Muscat' => 'खाड़ी मानक समय (मस्कट)',
        'Asia/Nicosia' => 'पूर्वी यूरोपीय समय (निकोसिया)',
        'Asia/Novokuznetsk' => 'क्रास्नोयार्स्क समय (नोवोकुज़्नेत्स्क)',
        'Asia/Novosibirsk' => 'क्रास्नोयार्स्क समय (नोवोसिबिर्स्क)',
        'Asia/Omsk' => 'ओम्स्क समय',
        'Asia/Oral' => 'कज़ाखस्तान समय (ओरल)',
        'Asia/Phnom_Penh' => 'इंडोचाइना समय (नॉम पेन्ह)',
        'Asia/Pontianak' => 'पश्चिमी इंडोनेशिया समय (पोंटीयांक)',
        'Asia/Pyongyang' => 'कोरियाई समय (प्योंगयांग)',
        'Asia/Qatar' => 'अरब समय (कतर)',
        'Asia/Qostanay' => 'कज़ाखस्तान समय (कोस्टाने)',
        'Asia/Qyzylorda' => 'कज़ाखस्तान समय (केज़ेलोर्डा)',
        'Asia/Rangoon' => 'म्यांमार समय (रंगून)',
        'Asia/Yangon' => 'म्यांमार समय (रंगून)',
        'Asia/Riyadh' => 'अरब समय (रियाद)',
        'Asia/Saigon' => 'इंडोचाइना समय (हो ची मिन्ह सिटी)',
        'Asia/Ho_Chi_Minh' => 'इंडोचाइना समय (हो ची मिन्ह सिटी)',
        'Asia/Sakhalin' => 'मागादान समय (सखालिन)',
        'Asia/Samarkand' => 'उज़्बेकिस्तान समय (समरकंद)',
        'Asia/Seoul' => 'कोरियाई समय (सिओल)',
        'Asia/Shanghai' => 'चीन समय (शंघाई)',
        'Asia/Singapore' => 'सिंगापुर समय',
        'Asia/Srednekolymsk' => 'मागादान समय (स्रेद्निकोलिमस्क)',
        'Asia/Taipei' => 'ताइपे समय (ताईपेई)',
        'Asia/Tashkent' => 'उज़्बेकिस्तान समय (ताशकंद)',
        'Asia/Tbilisi' => 'जॉर्जिया समय (टबिलिसी)',
        'Asia/Tehran' => 'ईरान समय (तेहरान)',
        'Asia/Thimphu' => 'भूटान समय (थिंपू)',
        'Asia/Tokyo' => 'जापान समय (टोक्यो)',
        'Asia/Tomsk' => 'क्रास्नोयार्स्क समय (तोम्स्क)',
        'Asia/Ulaanbaatar' => 'उलान बटोर समय (उलानबातर)',
        'Asia/Urumqi' => 'चीन समय (उरूम्की)',
        'Asia/Ust-Nera' => 'व्लादिवोस्तोक समय (यूस्ट–नेरा)',
        'Asia/Vientiane' => 'इंडोचाइना समय (विएनतियान)',
        'Asia/Vladivostok' => 'व्लादिवोस्तोक समय',
        'Asia/Yakutsk' => 'याकुत्स्क समय (याकूत्स्क)',
        'Asia/Yekaterinburg' => 'येकातेरिनबर्ग समय',
        'Asia/Yerevan' => 'आर्मेनिया समय (येरेवान)',
        'Atlantic/Azores' => 'अज़ोरेस समय',
        'Atlantic/Bermuda' => 'अटलांटिक समय (बरमूडा)',
        'Atlantic/Canary' => 'पश्चिमी यूरोपीय समय (कैनेरी)',
        'Atlantic/Cape_Verde' => 'केप वर्ड समय',
        'Atlantic/Faeroe' => 'पश्चिमी यूरोपीय समय (फ़ैरो)',
        'Atlantic/Faroe' => 'पश्चिमी यूरोपीय समय (फ़ैरो)',
        'Atlantic/Madeira' => 'पश्चिमी यूरोपीय समय (मडेरा)',
        'Atlantic/Reykjavik' => 'ग्रीनविच मीन टाइम (रेक्याविक)',
        'Atlantic/South_Georgia' => 'दक्षिणी जॉर्जिया समय (दक्षिण जॉर्जिया)',
        'Atlantic/St_Helena' => 'ग्रीनविच मीन टाइम (सेंट हेलेना)',
        'Atlantic/Stanley' => 'फ़ॉकलैंड द्वीपसमूह समय (स्टैनली)',
        'Australia/Adelaide' => 'मध्य ऑस्ट्रेलियाई समय (एडिलेड)',
        'Australia/Brisbane' => 'पूर्वी ऑस्ट्रेलिया समय (ब्रिस्बन)',
        'Australia/Broken_Hill' => 'मध्य ऑस्ट्रेलियाई समय (ब्रोकन हिल)',
        'Australia/Darwin' => 'मध्य ऑस्ट्रेलियाई समय (डार्विन)',
        'Australia/Eucla' => 'ऑस्‍ट्रेलियाई केंद्रीय पश्चिमी समय (यूक्ला)',
        'Australia/Hobart' => 'पूर्वी ऑस्ट्रेलिया समय (होबार्ट)',
        'Australia/Lindeman' => 'पूर्वी ऑस्ट्रेलिया समय (लिंडेमान)',
        'Australia/Lord_Howe' => 'लॉर्ड होवे समय',
        'Australia/Melbourne' => 'पूर्वी ऑस्ट्रेलिया समय (मेलबोर्न)',
        'Australia/Perth' => 'पश्चिमी ऑस्ट्रेलिया समय (पर्थ)',
        'Australia/Sydney' => 'पूर्वी ऑस्ट्रेलिया समय (सिडनी)',
        'Etc/GMT' => 'ग्रीनविच मीन टाइम',
        'Etc/UTC' => 'समन्वित वैश्विक समय',
        'Europe/Amsterdam' => 'मध्य यूरोपीय समय (एम्स्टर्डम)',
        'Europe/Andorra' => 'मध्य यूरोपीय समय (अंडोरा)',
        'Europe/Astrakhan' => 'समारा समय (आस्ट्राखान)',
        'Europe/Athens' => 'पूर्वी यूरोपीय समय (एथेंस)',
        'Europe/Belgrade' => 'मध्य यूरोपीय समय (बेलग्रेड)',
        'Europe/Berlin' => 'मध्य यूरोपीय समय (बर्लिन)',
        'Europe/Bratislava' => 'मध्य यूरोपीय समय (ब्रातिस्लावा)',
        'Europe/Brussels' => 'मध्य यूरोपीय समय (ब्रूसेल्स)',
        'Europe/Bucharest' => 'पूर्वी यूरोपीय समय (बुख़ारेस्ट)',
        'Europe/Budapest' => 'मध्य यूरोपीय समय (बुडापेस्ट)',
        'Europe/Busingen' => 'मध्य यूरोपीय समय (ब्यूसिनजेन)',
        'Europe/Chisinau' => 'पूर्वी यूरोपीय समय (चिसीनाउ)',
        'Europe/Copenhagen' => 'मध्य यूरोपीय समय (कोपेनहेगन)',
        'Europe/Dublin' => 'ग्रीनविच मीन टाइम (डबलिन)',
        'Europe/Gibraltar' => 'मध्य यूरोपीय समय (जिब्राल्टर)',
        'Europe/Guernsey' => 'ग्रीनविच मीन टाइम (गर्नसी)',
        'Europe/Helsinki' => 'पूर्वी यूरोपीय समय (हेलसिंकी)',
        'Europe/Isle_of_Man' => 'ग्रीनविच मीन टाइम (आइल ऑफ़ मैन)',
        'Europe/Istanbul' => 'तुर्किये समय (इस्तांबुल)',
        'Europe/Jersey' => 'ग्रीनविच मीन टाइम (जर्सी)',
        'Europe/Kaliningrad' => 'पूर्वी यूरोपीय समय (कालीनिनग्राड)',
        'Europe/Kiev' => 'पूर्वी यूरोपीय समय (कीव)',
        'Europe/Kyiv' => 'पूर्वी यूरोपीय समय (कीव)',
        'Europe/Kirov' => 'मॉस्को समय (किरोव)',
        'Europe/Lisbon' => 'पश्चिमी यूरोपीय समय (लिस्बन)',
        'Europe/Ljubljana' => 'मध्य यूरोपीय समय (ल्यूबेलजाना)',
        'Europe/London' => 'ग्रीनविच मीन टाइम (लंदन)',
        'Europe/Luxembourg' => 'मध्य यूरोपीय समय (लक्ज़मबर्ग)',
        'Europe/Madrid' => 'मध्य यूरोपीय समय (मैड्रिड)',
        'Europe/Malta' => 'मध्य यूरोपीय समय (माल्टा)',
        'Europe/Mariehamn' => 'पूर्वी यूरोपीय समय (मारियाहैम)',
        'Europe/Minsk' => 'मॉस्को समय (मिंस्क)',
        'Europe/Monaco' => 'मध्य यूरोपीय समय (मोनाको)',
        'Europe/Moscow' => 'मॉस्को समय',
        'Europe/Oslo' => 'मध्य यूरोपीय समय (ओस्लो)',
        'Europe/Paris' => 'मध्य यूरोपीय समय (पेरिस)',
        'Europe/Podgorica' => 'मध्य यूरोपीय समय (पोड्गोरिका)',
        'Europe/Prague' => 'मध्य यूरोपीय समय (प्राग)',
        'Europe/Riga' => 'पूर्वी यूरोपीय समय (रीगा)',
        'Europe/Rome' => 'मध्य यूरोपीय समय (रोम)',
        'Europe/Samara' => 'समारा समय',
        'Europe/San_Marino' => 'मध्य यूरोपीय समय (सैन मारीनो)',
        'Europe/Sarajevo' => 'मध्य यूरोपीय समय (साराजेवो)',
        'Europe/Saratov' => 'समारा समय (सारातोव)',
        'Europe/Simferopol' => 'मॉस्को समय (सिम्फ़ेरोपोल)',
        'Europe/Skopje' => 'मध्य यूरोपीय समय (स्कोप्जे)',
        'Europe/Sofia' => 'पूर्वी यूरोपीय समय (सोफ़िया)',
        'Europe/Stockholm' => 'मध्य यूरोपीय समय (स्टॉकहोम)',
        'Europe/Tallinn' => 'पूर्वी यूरोपीय समय (तेलिन)',
        'Europe/Tirane' => 'मध्य यूरोपीय समय (टाइरेन)',
        'Europe/Ulyanovsk' => 'समारा समय (उल्यानोव्स्क)',
        'Europe/Vaduz' => 'मध्य यूरोपीय समय (वादुज़)',
        'Europe/Vatican' => 'मध्य यूरोपीय समय (वेटिकन)',
        'Europe/Vienna' => 'मध्य यूरोपीय समय (विएना)',
        'Europe/Vilnius' => 'पूर्वी यूरोपीय समय (विल्नियस)',
        'Europe/Volgograd' => 'मॉस्को समय (वोल्गोग्राड)',
        'Europe/Warsaw' => 'मध्य यूरोपीय समय (वॉरसॉ)',
        'Europe/Zagreb' => 'मध्य यूरोपीय समय (ज़ाग्रेब)',
        'Europe/Zurich' => 'मध्य यूरोपीय समय (ज़्यूरिख़)',
        'Indian/Antananarivo' => 'पूर्वी अफ़्रीका समय (एंटानानरीवो)',
        'Indian/Chagos' => 'हिंद महासागर समय (शागोस)',
        'Indian/Christmas' => 'क्रिसमस द्वीप समय',
        'Indian/Cocos' => 'कोकोस द्वीपसमूह समय',
        'Indian/Comoro' => 'पूर्वी अफ़्रीका समय (कोमोरो)',
        'Indian/Kerguelen' => 'दक्षिणी फ़्रांस और अंटार्कटिक समय (करगुलेन)',
        'Indian/Mahe' => 'सेशेल्स समय (माहे)',
        'Indian/Maldives' => 'मालदीव समय',
        'Indian/Mauritius' => 'मॉरीशस समय',
        'Indian/Mayotte' => 'पूर्वी अफ़्रीका समय (मायोत्ते)',
        'Indian/Reunion' => 'रीयूनियन समय',
        'Pacific/Apia' => 'एपिआ समय (एपिया)',
        'Pacific/Auckland' => 'न्यूज़ीलैंड समय (ऑकलैंड)',
        'Pacific/Bougainville' => 'पापुआ न्यू गिनी समय (बोगनविले)',
        'Pacific/Chatham' => 'चैथम समय',
        'Pacific/Easter' => 'ईस्टर द्वीप समय',
        'Pacific/Efate' => 'वनुआतू समय (एफ़ेट)',
        'Pacific/Enderbury' => 'फ़ीनिक्स द्वीपसमूह समय (कैंटन)',
        'Pacific/Kanton' => 'फ़ीनिक्स द्वीपसमूह समय (कैंटन)',
        'Pacific/Fakaofo' => 'टोकेलाऊ समय (फ़ाकाओफ़ो)',
        'Pacific/Fiji' => 'फ़िजी समय',
        'Pacific/Funafuti' => 'तुवालू समय (फ़्यूनाफ़ुटी)',
        'Pacific/Galapagos' => 'गैलापेगोस का समय (गेलापागोस)',
        'Pacific/Gambier' => 'गैंबियर समय',
        'Pacific/Guadalcanal' => 'सोलोमन द्वीपसमूह समय (ग्वाडलकनाल)',
        'Pacific/Guam' => 'चामोरो मानक समय (गुआम)',
        'Pacific/Honolulu' => 'हवाई–आल्यूशन मानक समय (होनोलुलु)',
        'Pacific/Kiritimati' => 'लाइन द्वीपसमूह समय (किरीतिमाति)',
        'Pacific/Kosrae' => 'कोसराए समय',
        'Pacific/Kwajalein' => 'मार्शल द्वीपसमूह समय (क्वाज़ालीन)',
        'Pacific/Majuro' => 'मार्शल द्वीपसमूह समय (माजुरो)',
        'Pacific/Marquesas' => 'मार्केसस समय',
        'Pacific/Midway' => 'समोआ समय (मिडवे)',
        'Pacific/Nauru' => 'नौरू समय (नौरु)',
        'Pacific/Niue' => 'नीयू समय',
        'Pacific/Norfolk' => 'नॉरफ़ॉक द्वीप समय',
        'Pacific/Noumea' => 'न्यू कैलेडोनिया समय (नौमिया)',
        'Pacific/Pago_Pago' => 'समोआ समय (पागो पागो)',
        'Pacific/Palau' => 'पलाउ समय (पलाऊ)',
        'Pacific/Pitcairn' => 'पिटकैर्न समय',
        'Pacific/Ponape' => 'पोनापे समय (पोनपेई)',
        'Pacific/Pohnpei' => 'पोनापे समय (पोनपेई)',
        'Pacific/Port_Moresby' => 'पापुआ न्यू गिनी समय (पोर्ट मोरेस्बी)',
        'Pacific/Rarotonga' => 'कुक द्वीपसमूह समय (रारोटोंगा)',
        'Pacific/Saipan' => 'चामोरो मानक समय (सायपान)',
        'Pacific/Tahiti' => 'ताहिती समय',
        'Pacific/Tarawa' => 'गिल्बर्ट द्वीपसमूह समय (टारावा)',
        'Pacific/Tongatapu' => 'टोंगा समय (टोंगाटापू)',
        'Pacific/Truk' => 'चुक समय (चक)',
        'Pacific/Chuuk' => 'चुक समय (चक)',
        'Pacific/Wake' => 'वेक द्वीप समय',
        'Pacific/Wallis' => 'वालिस और फ़्यूचूना समय',
    ],
    'Meta' => [],
];
