<?php

return [
    'Names' => [
        'af' => 'Afrikoota',
        'am' => 'Afaan Amaaraa',
        'ar' => 'Arabiffaa',
        'as' => 'Assamese',
        'ast' => 'Astuuriyaan',
        'az' => 'Afaan Azerbaijani',
        'be' => 'Afaan Belarusia',
        'bg' => 'Afaan Bulgariya',
        'bgc' => 'Haryanvi',
        'bho' => 'Bihoojpuurii',
        'blo' => 'Anii',
        'bn' => 'Afaan Baangladeshi',
        'br' => 'Bireetoon',
        'brx' => 'Bodo',
        'bs' => 'Afaan Bosniyaa',
        'ca' => 'Afaan Katalaa',
        'ceb' => 'Kubuwanoo',
        'chr' => 'Cherokee',
        'cs' => 'Afaan Czech',
        'cv' => 'Chuvash',
        'cy' => 'Welishiffaa',
        'da' => 'Afaan Deenmaark',
        'de' => 'Afaan Jarmanii',
        'doi' => 'Dogri',
        'el' => 'Afaan Giriiki',
        'en' => 'Afaan Ingilizii',
        'eo' => 'Afaan Esperantoo',
        'es' => 'Afaan Ispeen',
        'et' => 'Afaan Istooniya',
        'eu' => 'Afaan Baskuu',
        'fa' => 'Afaan Persia',
        'ff' => 'Fula',
        'fi' => 'Afaan Fiilaandi',
        'fil' => 'Afaan Filippinii',
        'fo' => 'Afaan Faroese',
        'fr' => 'Afaan Faransaayii',
        'fy' => 'Afaan Firisiyaani',
        'ga' => 'Afaan Ayirishii',
        'gd' => 'Scots Gaelic',
        'gl' => 'Afaan Galishii',
        'gn' => 'Afaan Guarani',
        'gu' => 'Afaan Gujarati',
        'ha' => 'Hawusaa',
        'he' => 'Afaan Hebrew',
        'hi' => 'Afaan Hindii',
        'hr' => 'Afaan Croatian',
        'hu' => 'Afaan Hangaari',
        'hy' => 'Armeeniyaa',
        'ia' => 'Interlingua',
        'id' => 'Afaan Indoneziya',
        'is' => 'Ayiislandiffaa',
        'it' => 'Afaan Xaaliyaani',
        'ja' => 'Afaan Japanii',
        'jv' => 'Afaan Java',
        'ka' => 'Afaan Georgian',
        'kn' => 'Afaan Kannada',
        'ko' => 'Afaan Korea',
        'la' => 'Afaan Laatini',
        'lt' => 'Afaan Liituniyaa',
        'lv' => 'Afaan Lativiyaa',
        'mk' => 'Afaan Macedooniyaa',
        'ml' => 'Malayaalamiffaa',
        'mr' => 'Afaan Maratii',
        'ms' => 'Malaayiffaa',
        'mt' => 'Afaan Maltesii',
        'my' => 'Burmeesee',
        'ne' => 'Afaan Nepalii',
        'nl' => 'Afaan Dachii',
        'nn' => 'Afaan Norwegian',
        'no' => 'Afaan Norweyii',
        'oc' => 'Afaan Occit',
        'om' => 'Oromoo',
        'pa' => 'Afaan Punjabii',
        'pl' => 'Afaan Polandii',
        'pt' => 'Afaan Porchugaal',
        'ro' => 'Afaan Romaniyaa',
        'ru' => 'Afaan Rushiyaa',
        'si' => 'Afaan Sinhalese',
        'sk' => 'Afaan Slovak',
        'sl' => 'Afaan Islovaniyaa',
        'sq' => 'Afaan Albaniyaa',
        'sr' => 'Afaan Serbiya',
        'su' => 'Afaan Sudaanii',
        'sv' => 'Afaan Suwidiin',
        'sw' => 'Suwahilii',
        'ta' => 'Afaan Tamilii',
        'te' => 'Afaan Telugu',
        'th' => 'Afaan Tayii',
        'ti' => 'Afaan Tigiree',
        'tk' => 'Lammii Turkii',
        'tlh' => 'Afaan Kilingon',
        'tr' => 'Afaan Turkii',
        'uk' => 'Afaan Ukreenii',
        'ur' => 'Afaan Urdu',
        'uz' => 'Afaan Uzbek',
        'vi' => 'Afaan Veetinam',
        'xh' => 'Afaan Xhosa',
        'yue' => 'Kantonoosee',
        'zh' => 'Chinese',
        'zu' => 'Afaan Zuulu',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Arabiffa Istaandaardii Ammayyaa',
        'de_AT' => 'Jarmanii Awustiriyaa',
        'de_CH' => 'Jarmanii Siwiiz Haay',
        'en_AU' => 'Ingiliffa Awustiraaliyaa',
        'en_CA' => 'Ingiliffa Kanaadaa',
        'en_GB' => 'Ingliffa Biritishii',
        'en_US' => 'Ingliffa Ameekiraa',
        'es_419' => 'Laatinii Ispaanishii Ameerikaa',
        'es_ES' => 'Ispaanishii Awurooppaa',
        'es_MX' => 'Ispaanishii Meeksiikoo',
        'hi_Latn' => 'Hindii (Laatiin)',
        'nl_BE' => 'Flemish',
        'pt_BR' => 'Afaan Portugali (Braazil)',
        'pt_PT' => 'Afaan Protuguese',
        'zh_Hans' => 'Chinese Salphifame',
        'zh_Hant' => 'Chinese Durii',
    ],
];
