<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'گىرىنۋىچ ۋاقتى (Abidjan)',
        'Africa/Accra' => 'گىرىنۋىچ ۋاقتى (Accra)',
        'Africa/Addis_Ababa' => 'شەرقىي ئافرىقا ۋاقتى (Addis Ababa)',
        'Africa/Algiers' => 'ئوتتۇرا ياۋروپا ۋاقتى (Algiers)',
        'Africa/Asmera' => 'شەرقىي ئافرىقا ۋاقتى (Asmara)',
        'Africa/Asmara' => 'شەرقىي ئافرىقا ۋاقتى (Asmara)',
        'Africa/Bamako' => 'گىرىنۋىچ ۋاقتى (Bamako)',
        'Africa/Bangui' => 'غەربىي ئافرىقا ۋاقتى (Bangui)',
        'Africa/Banjul' => 'گىرىنۋىچ ۋاقتى (Banjul)',
        'Africa/Bissau' => 'گىرىنۋىچ ۋاقتى (Bissau)',
        'Africa/Blantyre' => 'ئوتتۇرا ئافرىقا ۋاقتى (Blantyre)',
        'Africa/Brazzaville' => 'غەربىي ئافرىقا ۋاقتى (Brazzaville)',
        'Africa/Bujumbura' => 'ئوتتۇرا ئافرىقا ۋاقتى (Bujumbura)',
        'Africa/Cairo' => 'شەرقىي ياۋروپا ۋاقتى (Cairo)',
        'Africa/Casablanca' => 'غەربىي ياۋروپا ۋاقتى (Casablanca)',
        'Africa/Ceuta' => 'ئوتتۇرا ياۋروپا ۋاقتى (Ceuta)',
        'Africa/Conakry' => 'گىرىنۋىچ ۋاقتى (Conakry)',
        'Africa/Dakar' => 'گىرىنۋىچ ۋاقتى (Dakar)',
        'Africa/Dar_es_Salaam' => 'شەرقىي ئافرىقا ۋاقتى (Dar es Salaam)',
        'Africa/Djibouti' => 'شەرقىي ئافرىقا ۋاقتى (Djibouti)',
        'Africa/Douala' => 'غەربىي ئافرىقا ۋاقتى (Douala)',
        'Africa/El_Aaiun' => 'غەربىي ياۋروپا ۋاقتى (El Aaiún)',
        'Africa/Freetown' => 'گىرىنۋىچ ۋاقتى (Freetown)',
        'Africa/Gaborone' => 'ئوتتۇرا ئافرىقا ۋاقتى (Gaborone)',
        'Africa/Harare' => 'ئوتتۇرا ئافرىقا ۋاقتى (Harare)',
        'Africa/Johannesburg' => 'جەنۇبىي ئافرىقا ئۆلچەملىك ۋاقتى (Johannesburg)',
        'Africa/Juba' => 'ئوتتۇرا ئافرىقا ۋاقتى (Juba)',
        'Africa/Kampala' => 'شەرقىي ئافرىقا ۋاقتى (Kampala)',
        'Africa/Khartoum' => 'ئوتتۇرا ئافرىقا ۋاقتى (Khartoum)',
        'Africa/Kigali' => 'ئوتتۇرا ئافرىقا ۋاقتى (Kigali)',
        'Africa/Kinshasa' => 'غەربىي ئافرىقا ۋاقتى (Kinshasa)',
        'Africa/Lagos' => 'غەربىي ئافرىقا ۋاقتى (Lagos)',
        'Africa/Libreville' => 'غەربىي ئافرىقا ۋاقتى (Libreville)',
        'Africa/Lome' => 'گىرىنۋىچ ۋاقتى (Lomé)',
        'Africa/Luanda' => 'غەربىي ئافرىقا ۋاقتى (Luanda)',
        'Africa/Lubumbashi' => 'ئوتتۇرا ئافرىقا ۋاقتى (Lubumbashi)',
        'Africa/Lusaka' => 'ئوتتۇرا ئافرىقا ۋاقتى (Lusaka)',
        'Africa/Malabo' => 'غەربىي ئافرىقا ۋاقتى (Malabo)',
        'Africa/Maputo' => 'ئوتتۇرا ئافرىقا ۋاقتى (Maputo)',
        'Africa/Maseru' => 'جەنۇبىي ئافرىقا ئۆلچەملىك ۋاقتى (Maseru)',
        'Africa/Mbabane' => 'جەنۇبىي ئافرىقا ئۆلچەملىك ۋاقتى (Mbabane)',
        'Africa/Mogadishu' => 'شەرقىي ئافرىقا ۋاقتى (Mogadishu)',
        'Africa/Monrovia' => 'گىرىنۋىچ ۋاقتى (Monrovia)',
        'Africa/Nairobi' => 'شەرقىي ئافرىقا ۋاقتى (Nairobi)',
        'Africa/Ndjamena' => 'غەربىي ئافرىقا ۋاقتى (N’Djamena)',
        'Africa/Niamey' => 'غەربىي ئافرىقا ۋاقتى (Niamey)',
        'Africa/Nouakchott' => 'گىرىنۋىچ ۋاقتى (Nouakchott)',
        'Africa/Ouagadougou' => 'گىرىنۋىچ ۋاقتى (Ouagadougou)',
        'Africa/Porto-Novo' => 'غەربىي ئافرىقا ۋاقتى (Porto-Novo)',
        'Africa/Sao_Tome' => 'گىرىنۋىچ ۋاقتى (سان-تومې)',
        'Africa/Tripoli' => 'شەرقىي ياۋروپا ۋاقتى (Tripoli)',
        'Africa/Tunis' => 'ئوتتۇرا ياۋروپا ۋاقتى (Tunis)',
        'Africa/Windhoek' => 'ئوتتۇرا ئافرىقا ۋاقتى (Windhoek)',
        'America/Adak' => 'ھاۋاي-ئالېيۇت ۋاقتى (Adak)',
        'America/Anchorage' => 'ئالياسكا ۋاقتى (Anchorage)',
        'America/Anguilla' => 'ئاتلانتىك ئوكيان ۋاقتى (Anguilla)',
        'America/Antigua' => 'ئاتلانتىك ئوكيان ۋاقتى (Antigua)',
        'America/Araguaina' => 'بىرازىلىيە ۋاقتى (Araguaína)',
        'America/Argentina/La_Rioja' => 'ئارگېنتىنا ۋاقتى (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'ئارگېنتىنا ۋاقتى (Río Gallegos)',
        'America/Argentina/Salta' => 'ئارگېنتىنا ۋاقتى (Salta)',
        'America/Argentina/San_Juan' => 'ئارگېنتىنا ۋاقتى (San Juan)',
        'America/Argentina/San_Luis' => 'ئارگېنتىنا ۋاقتى (San Luis)',
        'America/Argentina/Tucuman' => 'ئارگېنتىنا ۋاقتى (Tucumán)',
        'America/Argentina/Ushuaia' => 'ئارگېنتىنا ۋاقتى (Ushuaia)',
        'America/Aruba' => 'ئاتلانتىك ئوكيان ۋاقتى (Aruba)',
        'America/Asuncion' => 'پاراگۋاي ۋاقتى (ئاسۇنسىيون)',
        'America/Bahia' => 'بىرازىلىيە ۋاقتى (Bahia)',
        'America/Bahia_Banderas' => 'ئوتتۇرا قىسىم ۋاقتى (Bahía de Banderas)',
        'America/Barbados' => 'ئاتلانتىك ئوكيان ۋاقتى (Barbados)',
        'America/Belem' => 'بىرازىلىيە ۋاقتى (Belém)',
        'America/Belize' => 'ئوتتۇرا قىسىم ۋاقتى (Belize)',
        'America/Blanc-Sablon' => 'ئاتلانتىك ئوكيان ۋاقتى (Blanc-Sablon)',
        'America/Boa_Vista' => 'ئامازون ۋاقتى (Boa Vista)',
        'America/Bogota' => 'كولومبىيە ۋاقتى (Bogotá)',
        'America/Boise' => 'تاغ ۋاقتى (Boise)',
        'America/Buenos_Aires' => 'ئارگېنتىنا ۋاقتى (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'ئارگېنتىنا ۋاقتى (Buenos Aires)',
        'America/Cambridge_Bay' => 'تاغ ۋاقتى (Cambridge Bay)',
        'America/Campo_Grande' => 'ئامازون ۋاقتى (Campo Grande)',
        'America/Cancun' => 'شەرقىي قىسىم ۋاقتى (Cancún)',
        'America/Caracas' => 'ۋېنېزۇئېلا ۋاقتى (Caracas)',
        'America/Catamarca' => 'ئارگېنتىنا ۋاقتى (Catamarca)',
        'America/Argentina/Catamarca' => 'ئارگېنتىنا ۋاقتى (Catamarca)',
        'America/Cayenne' => 'فىرانسىيەگە قاراشلىق گىۋىيانا ۋاقتى (Cayenne)',
        'America/Cayman' => 'شەرقىي قىسىم ۋاقتى (Cayman)',
        'America/Chicago' => 'ئوتتۇرا قىسىم ۋاقتى (Chicago)',
        'America/Chihuahua' => 'ئوتتۇرا قىسىم ۋاقتى (Chihuahua)',
        'America/Ciudad_Juarez' => 'تاغ ۋاقتى (Ciudad Juárez)',
        'America/Coral_Harbour' => 'شەرقىي قىسىم ۋاقتى (Atikokan)',
        'America/Atikokan' => 'شەرقىي قىسىم ۋاقتى (Atikokan)',
        'America/Cordoba' => 'ئارگېنتىنا ۋاقتى (Córdoba)',
        'America/Argentina/Cordoba' => 'ئارگېنتىنا ۋاقتى (Córdoba)',
        'America/Costa_Rica' => 'ئوتتۇرا قىسىم ۋاقتى (Costa Rica)',
        'America/Coyhaique' => 'چىلى ۋاقتى (Coyhaique)',
        'America/Creston' => 'تاغ ۋاقتى (Creston)',
        'America/Cuiaba' => 'ئامازون ۋاقتى (Cuiabá)',
        'America/Curacao' => 'ئاتلانتىك ئوكيان ۋاقتى (كۇراسو)',
        'America/Danmarkshavn' => 'گىرىنۋىچ ۋاقتى (Danmarkshavn)',
        'America/Dawson' => 'كانادا ۋاقتى (Dawson)',
        'America/Dawson_Creek' => 'تاغ ۋاقتى (Dawson Creek)',
        'America/Denver' => 'تاغ ۋاقتى (Denver)',
        'America/Detroit' => 'شەرقىي قىسىم ۋاقتى (Detroit)',
        'America/Dominica' => 'ئاتلانتىك ئوكيان ۋاقتى (Dominica)',
        'America/Edmonton' => 'تاغ ۋاقتى (Edmonton)',
        'America/Eirunepe' => 'ئاكرې ۋاقتى (Eirunepé)',
        'America/El_Salvador' => 'ئوتتۇرا قىسىم ۋاقتى (El Salvador)',
        'America/Fort_Nelson' => 'تاغ ۋاقتى (Fort Nelson)',
        'America/Fortaleza' => 'بىرازىلىيە ۋاقتى (Fortaleza)',
        'America/Glace_Bay' => 'ئاتلانتىك ئوكيان ۋاقتى (Glace Bay)',
        'America/Godthab' => 'گىرېنلاندىيە ۋاقتى (Nuuk)',
        'America/Nuuk' => 'گىرېنلاندىيە ۋاقتى (Nuuk)',
        'America/Goose_Bay' => 'ئاتلانتىك ئوكيان ۋاقتى (Goose Bay)',
        'America/Grand_Turk' => 'شەرقىي قىسىم ۋاقتى (Grand Turk)',
        'America/Grenada' => 'ئاتلانتىك ئوكيان ۋاقتى (Grenada)',
        'America/Guadeloupe' => 'ئاتلانتىك ئوكيان ۋاقتى (Guadeloupe)',
        'America/Guatemala' => 'ئوتتۇرا قىسىم ۋاقتى (Guatemala)',
        'America/Guayaquil' => 'ئېكۋادور ۋاقتى (Guayaquil)',
        'America/Guyana' => 'گىۋىيانا ۋاقتى (Guyana)',
        'America/Halifax' => 'ئاتلانتىك ئوكيان ۋاقتى (Halifax)',
        'America/Havana' => 'كۇبا ۋاقتى (Havana)',
        'America/Hermosillo' => 'مېكسىكا تىنچ ئوكيان ۋاقتى (Hermosillo)',
        'America/Indiana/Knox' => 'ئوتتۇرا قىسىم ۋاقتى (Knox, Indiana)',
        'America/Indiana/Marengo' => 'شەرقىي قىسىم ۋاقتى (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'شەرقىي قىسىم ۋاقتى (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'ئوتتۇرا قىسىم ۋاقتى (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'شەرقىي قىسىم ۋاقتى (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'شەرقىي قىسىم ۋاقتى (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'شەرقىي قىسىم ۋاقتى (Winamac, Indiana)',
        'America/Indianapolis' => 'شەرقىي قىسىم ۋاقتى (Indianapolis)',
        'America/Indiana/Indianapolis' => 'شەرقىي قىسىم ۋاقتى (Indianapolis)',
        'America/Inuvik' => 'تاغ ۋاقتى (Inuvik)',
        'America/Iqaluit' => 'شەرقىي قىسىم ۋاقتى (Iqaluit)',
        'America/Jamaica' => 'شەرقىي قىسىم ۋاقتى (Jamaica)',
        'America/Jujuy' => 'ئارگېنتىنا ۋاقتى (Jujuy)',
        'America/Argentina/Jujuy' => 'ئارگېنتىنا ۋاقتى (Jujuy)',
        'America/Juneau' => 'ئالياسكا ۋاقتى (Juneau)',
        'America/Kentucky/Monticello' => 'شەرقىي قىسىم ۋاقتى (Monticello, Kentucky)',
        'America/Kralendijk' => 'ئاتلانتىك ئوكيان ۋاقتى (Kralendijk)',
        'America/La_Paz' => 'بولىۋىيە ۋاقتى (La Paz)',
        'America/Lima' => 'پېرۇ ۋاقتى (Lima)',
        'America/Los_Angeles' => 'تىنچ ئوكيان ۋاقتى (Los Angeles)',
        'America/Louisville' => 'شەرقىي قىسىم ۋاقتى (Louisville)',
        'America/Kentucky/Louisville' => 'شەرقىي قىسىم ۋاقتى (Louisville)',
        'America/Lower_Princes' => 'ئاتلانتىك ئوكيان ۋاقتى (Lower Prince’s Quarter)',
        'America/Maceio' => 'بىرازىلىيە ۋاقتى (Maceió)',
        'America/Managua' => 'ئوتتۇرا قىسىم ۋاقتى (Managua)',
        'America/Manaus' => 'ئامازون ۋاقتى (Manaus)',
        'America/Marigot' => 'ئاتلانتىك ئوكيان ۋاقتى (Marigot)',
        'America/Martinique' => 'ئاتلانتىك ئوكيان ۋاقتى (Martinique)',
        'America/Matamoros' => 'ئوتتۇرا قىسىم ۋاقتى (Matamoros)',
        'America/Mazatlan' => 'مېكسىكا تىنچ ئوكيان ۋاقتى (Mazatlán)',
        'America/Mendoza' => 'ئارگېنتىنا ۋاقتى (Mendoza)',
        'America/Argentina/Mendoza' => 'ئارگېنتىنا ۋاقتى (Mendoza)',
        'America/Menominee' => 'ئوتتۇرا قىسىم ۋاقتى (Menominee)',
        'America/Merida' => 'ئوتتۇرا قىسىم ۋاقتى (Mérida)',
        'America/Metlakatla' => 'ئالياسكا ۋاقتى (Metlakatla)',
        'America/Mexico_City' => 'ئوتتۇرا قىسىم ۋاقتى (Ciudad de México)',
        'America/Miquelon' => 'ساينىت پىئېر ۋە مىكېلون ۋاقتى (Saint-Pierre)',
        'America/Moncton' => 'ئاتلانتىك ئوكيان ۋاقتى (Moncton)',
        'America/Monterrey' => 'ئوتتۇرا قىسىم ۋاقتى (Monterrey)',
        'America/Montevideo' => 'ئۇرۇگۋاي ۋاقتى (Montevideo)',
        'America/Montserrat' => 'ئاتلانتىك ئوكيان ۋاقتى (Montserrat)',
        'America/Nassau' => 'شەرقىي قىسىم ۋاقتى (Nassau)',
        'America/New_York' => 'شەرقىي قىسىم ۋاقتى (New York)',
        'America/Nome' => 'ئالياسكا ۋاقتى (Nome)',
        'America/Noronha' => 'فېرناندو-نورونخا ۋاقتى (Fernando de Noronha)',
        'America/North_Dakota/Beulah' => 'ئوتتۇرا قىسىم ۋاقتى (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'ئوتتۇرا قىسىم ۋاقتى (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'ئوتتۇرا قىسىم ۋاقتى (New Salem, North Dakota)',
        'America/Ojinaga' => 'ئوتتۇرا قىسىم ۋاقتى (Ojinaga)',
        'America/Panama' => 'شەرقىي قىسىم ۋاقتى (Panama)',
        'America/Paramaribo' => 'سۇرىنام ۋاقتى (Paramaribo)',
        'America/Phoenix' => 'تاغ ۋاقتى (Phoenix)',
        'America/Port-au-Prince' => 'شەرقىي قىسىم ۋاقتى (Port-au-Prince)',
        'America/Port_of_Spain' => 'ئاتلانتىك ئوكيان ۋاقتى (Port of Spain)',
        'America/Porto_Velho' => 'ئامازون ۋاقتى (Porto Velho)',
        'America/Puerto_Rico' => 'ئاتلانتىك ئوكيان ۋاقتى (Puerto Rico)',
        'America/Punta_Arenas' => 'چىلى ۋاقتى (Punta Arenas)',
        'America/Rankin_Inlet' => 'ئوتتۇرا قىسىم ۋاقتى (Rankin Inlet)',
        'America/Recife' => 'بىرازىلىيە ۋاقتى (Recife)',
        'America/Regina' => 'ئوتتۇرا قىسىم ۋاقتى (Regina)',
        'America/Resolute' => 'ئوتتۇرا قىسىم ۋاقتى (Resolute)',
        'America/Rio_Branco' => 'ئاكرې ۋاقتى (Rio Branco)',
        'America/Santarem' => 'بىرازىلىيە ۋاقتى (Santarém)',
        'America/Santiago' => 'چىلى ۋاقتى (Santiago)',
        'America/Santo_Domingo' => 'ئاتلانتىك ئوكيان ۋاقتى (Santo Domingo)',
        'America/Sao_Paulo' => 'بىرازىلىيە ۋاقتى (São Paulo)',
        'America/Scoresbysund' => 'گىرېنلاندىيە ۋاقتى (Ittoqqortoormiit)',
        'America/Sitka' => 'ئالياسكا ۋاقتى (Sitka)',
        'America/St_Barthelemy' => 'ئاتلانتىك ئوكيان ۋاقتى (ساينىت-بارتھېلەمىي)',
        'America/St_Johns' => 'نىۋفوئۇنلاند ۋاقتى (St. John’s)',
        'America/St_Kitts' => 'ئاتلانتىك ئوكيان ۋاقتى (St. Kitts)',
        'America/St_Lucia' => 'ئاتلانتىك ئوكيان ۋاقتى (St. Lucia)',
        'America/St_Thomas' => 'ئاتلانتىك ئوكيان ۋاقتى (St. Thomas)',
        'America/St_Vincent' => 'ئاتلانتىك ئوكيان ۋاقتى (St. Vincent)',
        'America/Swift_Current' => 'ئوتتۇرا قىسىم ۋاقتى (Swift Current)',
        'America/Tegucigalpa' => 'ئوتتۇرا قىسىم ۋاقتى (Tegucigalpa)',
        'America/Thule' => 'ئاتلانتىك ئوكيان ۋاقتى (Thule)',
        'America/Tijuana' => 'تىنچ ئوكيان ۋاقتى (Tijuana)',
        'America/Toronto' => 'شەرقىي قىسىم ۋاقتى (Toronto)',
        'America/Tortola' => 'ئاتلانتىك ئوكيان ۋاقتى (Tortola)',
        'America/Vancouver' => 'تىنچ ئوكيان ۋاقتى (Vancouver)',
        'America/Whitehorse' => 'كانادا ۋاقتى (Whitehorse)',
        'America/Winnipeg' => 'ئوتتۇرا قىسىم ۋاقتى (Winnipeg)',
        'America/Yakutat' => 'ئالياسكا ۋاقتى (Yakutat)',
        'Antarctica/Casey' => 'ئاۋسترالىيە غەربىي قىسىم ۋاقتى (Casey)',
        'Antarctica/Davis' => 'داۋىس ۋاقتى (Davis)',
        'Antarctica/DumontDUrville' => 'دۇمونت-دۇرۋىل ۋاقتى (دۇمونت دۇرۋىللې)',
        'Antarctica/Macquarie' => 'ئاۋسترالىيە شەرقىي قىسىم ۋاقتى (Macquarie)',
        'Antarctica/Mawson' => 'ماۋسون ۋاقتى (Mawson)',
        'Antarctica/McMurdo' => 'يېڭى زېلاندىيە ۋاقتى (McMurdo)',
        'Antarctica/Palmer' => 'چىلى ۋاقتى (Palmer)',
        'Antarctica/Rothera' => 'روتېرا ۋاقتى (Rothera)',
        'Antarctica/Syowa' => 'شوۋا ۋاقتى (Showa)',
        'Antarctica/Troll' => 'گىرىنۋىچ ۋاقتى (Troll)',
        'Antarctica/Vostok' => 'ۋوستوك ۋاقتى (Vostok)',
        'Arctic/Longyearbyen' => 'ئوتتۇرا ياۋروپا ۋاقتى (Longyearbyen)',
        'Asia/Aden' => 'ئەرەب ۋاقتى (Aden)',
        'Asia/Almaty' => 'قازاقىستان ۋاقتى (Almaty)',
        'Asia/Amman' => 'شەرقىي ياۋروپا ۋاقتى (Amman)',
        'Asia/Anadyr' => 'پېتروپاۋلوۋسك-كامچاتكسكى ۋاقتى (Anadyr)',
        'Asia/Aqtau' => 'قازاقىستان ۋاقتى (Aqtau)',
        'Asia/Aqtobe' => 'قازاقىستان ۋاقتى (Aqtobe)',
        'Asia/Ashgabat' => 'تۈركمەنىستان ۋاقتى (Ashgabat)',
        'Asia/Atyrau' => 'قازاقىستان ۋاقتى (Atyrau)',
        'Asia/Baghdad' => 'ئەرەب ۋاقتى (Baghdad)',
        'Asia/Bahrain' => 'ئەرەب ۋاقتى (Bahrain)',
        'Asia/Baku' => 'ئەزەربەيجان ۋاقتى (Baku)',
        'Asia/Bangkok' => 'ھىندى چىنى ۋاقتى (Bangkok)',
        'Asia/Barnaul' => 'كىراسنويارسك ۋاقتى (Barnaul)',
        'Asia/Beirut' => 'شەرقىي ياۋروپا ۋاقتى (Beirut)',
        'Asia/Bishkek' => 'قىرغىزىستان ۋاقتى (Bishkek)',
        'Asia/Brunei' => 'بىرۇنىي دارۇسسالام ۋاقتى (Brunei)',
        'Asia/Calcutta' => 'ھىندىستان ئۆلچەملىك ۋاقتى (Kolkata)',
        'Asia/Kolkata' => 'ھىندىستان ئۆلچەملىك ۋاقتى (Kolkata)',
        'Asia/Chita' => 'ياكۇتسك ۋاقتى (Chita)',
        'Asia/Colombo' => 'ھىندىستان ئۆلچەملىك ۋاقتى (Colombo)',
        'Asia/Damascus' => 'شەرقىي ياۋروپا ۋاقتى (Damascus)',
        'Asia/Dhaka' => 'باڭلادىش ۋاقتى (Dhaka)',
        'Asia/Dili' => 'شەرقىي تىمور ۋاقتى (Dili)',
        'Asia/Dubai' => 'گۇلف ئۆلچەملىك ۋاقتى (Dubai)',
        'Asia/Dushanbe' => 'تاجىكىستان ۋاقتى (Dushanbe)',
        'Asia/Famagusta' => 'شەرقىي ياۋروپا ۋاقتى (Famagusta)',
        'Asia/Gaza' => 'شەرقىي ياۋروپا ۋاقتى (Gaza)',
        'Asia/Hebron' => 'شەرقىي ياۋروپا ۋاقتى (Hebron)',
        'Asia/Hong_Kong' => 'شياڭگاڭ ۋاقتى (Hong Kong)',
        'Asia/Hovd' => 'خوۋد ۋاقتى (Khovd)',
        'Asia/Irkutsk' => 'ئىركۇتسك ۋاقتى (Irkutsk)',
        'Asia/Jakarta' => 'غەربىي ھىندونېزىيە ۋاقتى (Jakarta)',
        'Asia/Jayapura' => 'شەرقىي ھىندونېزىيە ۋاقتى (Jayapura)',
        'Asia/Jerusalem' => 'ئىسرائىلىيە ۋاقتى (Jerusalem)',
        'Asia/Kabul' => 'ئافغانىستان ۋاقتى (Kabul)',
        'Asia/Kamchatka' => 'پېتروپاۋلوۋسك-كامچاتكسكى ۋاقتى (Kamchatka)',
        'Asia/Karachi' => 'پاكىستان ۋاقتى (Karachi)',
        'Asia/Katmandu' => 'نېپال ۋاقتى (Kathmandu)',
        'Asia/Kathmandu' => 'نېپال ۋاقتى (Kathmandu)',
        'Asia/Khandyga' => 'ياكۇتسك ۋاقتى (Khandyga)',
        'Asia/Krasnoyarsk' => 'كىراسنويارسك ۋاقتى (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'مالايشىيا ۋاقتى (Kuala Lumpur)',
        'Asia/Kuching' => 'مالايشىيا ۋاقتى (Kuching)',
        'Asia/Kuwait' => 'ئەرەب ۋاقتى (Kuwait)',
        'Asia/Macau' => 'جۇڭگو ۋاقتى (Macao)',
        'Asia/Magadan' => 'ماگادان ۋاقتى (Magadan)',
        'Asia/Makassar' => 'ئوتتۇرا ھىندونېزىيە ۋاقتى (Makassar)',
        'Asia/Manila' => 'فىلىپپىن ۋاقتى (Manila)',
        'Asia/Muscat' => 'گۇلف ئۆلچەملىك ۋاقتى (Muscat)',
        'Asia/Nicosia' => 'شەرقىي ياۋروپا ۋاقتى (Nicosia)',
        'Asia/Novokuznetsk' => 'كىراسنويارسك ۋاقتى (Novokuznetsk)',
        'Asia/Novosibirsk' => 'كىراسنويارسك ۋاقتى (Novosibirsk)',
        'Asia/Omsk' => 'ئومسك ۋاقتى (Omsk)',
        'Asia/Oral' => 'قازاقىستان ۋاقتى (Oral)',
        'Asia/Phnom_Penh' => 'ھىندى چىنى ۋاقتى (Phnom Penh)',
        'Asia/Pontianak' => 'غەربىي ھىندونېزىيە ۋاقتى (Pontianak)',
        'Asia/Pyongyang' => 'كورىيە ۋاقتى (Pyongyang)',
        'Asia/Qatar' => 'ئەرەب ۋاقتى (Qatar)',
        'Asia/Qostanay' => 'قازاقىستان ۋاقتى (Qostanay)',
        'Asia/Qyzylorda' => 'قازاقىستان ۋاقتى (Qyzylorda)',
        'Asia/Rangoon' => 'بىرما ۋاقتى (Yangon)',
        'Asia/Yangon' => 'بىرما ۋاقتى (Yangon)',
        'Asia/Riyadh' => 'ئەرەب ۋاقتى (Riyadh)',
        'Asia/Saigon' => 'ھىندى چىنى ۋاقتى (خوچىمىن شەھىرى)',
        'Asia/Ho_Chi_Minh' => 'ھىندى چىنى ۋاقتى (خوچىمىن شەھىرى)',
        'Asia/Sakhalin' => 'ماگادان ۋاقتى (Sakhalin)',
        'Asia/Samarkand' => 'ئۆزبېكىستان ۋاقتى (Samarkand)',
        'Asia/Seoul' => 'كورىيە ۋاقتى (Seoul)',
        'Asia/Shanghai' => 'جۇڭگو ۋاقتى (Shanghai)',
        'Asia/Singapore' => 'سىنگاپور ۋاقتى (Singapore)',
        'Asia/Srednekolymsk' => 'ماگادان ۋاقتى (Srednekolymsk)',
        'Asia/Taipei' => 'تەيبېي ۋاقتى (Taipei)',
        'Asia/Tashkent' => 'ئۆزبېكىستان ۋاقتى (Tashkent)',
        'Asia/Tbilisi' => 'گىرۇزىيە ۋاقتى (Tbilisi)',
        'Asia/Tehran' => 'ئىران ۋاقتى (Tehran)',
        'Asia/Thimphu' => 'بۇتان ۋاقتى (Thimphu)',
        'Asia/Tokyo' => 'ياپونىيە ۋاقتى (Tokyo)',
        'Asia/Tomsk' => 'كىراسنويارسك ۋاقتى (Tomsk)',
        'Asia/Ulaanbaatar' => 'ئۇلانباتور ۋاقتى (Ulaanbaatar)',
        'Asia/Urumqi' => 'جۇڭگو ۋاقتى (Ürümqi)',
        'Asia/Ust-Nera' => 'ۋىلادىۋوستوك ۋاقتى (Ust-Nera)',
        'Asia/Vientiane' => 'ھىندى چىنى ۋاقتى (Vientiane)',
        'Asia/Vladivostok' => 'ۋىلادىۋوستوك ۋاقتى (Vladivostok)',
        'Asia/Yakutsk' => 'ياكۇتسك ۋاقتى (Yakutsk)',
        'Asia/Yekaterinburg' => 'يېكاتېرىنبۇرگ ۋاقتى (Yekaterinburg)',
        'Asia/Yerevan' => 'ئەرمېنىيە ۋاقتى (Yerevan)',
        'Atlantic/Azores' => 'ئازور ۋاقتى (Azores)',
        'Atlantic/Bermuda' => 'ئاتلانتىك ئوكيان ۋاقتى (Bermuda)',
        'Atlantic/Canary' => 'غەربىي ياۋروپا ۋاقتى (Canarias)',
        'Atlantic/Cape_Verde' => 'يېشىل تۇمشۇق ۋاقتى (Cape Verde)',
        'Atlantic/Faeroe' => 'غەربىي ياۋروپا ۋاقتى (Faroe)',
        'Atlantic/Faroe' => 'غەربىي ياۋروپا ۋاقتى (Faroe)',
        'Atlantic/Madeira' => 'غەربىي ياۋروپا ۋاقتى (Madeira)',
        'Atlantic/Reykjavik' => 'گىرىنۋىچ ۋاقتى (Reykjavik)',
        'Atlantic/South_Georgia' => 'جەنۇبىي جورجىيە ۋاقتى (South Georgia)',
        'Atlantic/St_Helena' => 'گىرىنۋىچ ۋاقتى (St. Helena)',
        'Atlantic/Stanley' => 'فالكلاند ئاراللىرى ۋاقتى (Stanley)',
        'Australia/Adelaide' => 'ئاۋسترالىيە ئوتتۇرا قىسىم ۋاقتى (Adelaide)',
        'Australia/Brisbane' => 'ئاۋسترالىيە شەرقىي قىسىم ۋاقتى (Brisbane)',
        'Australia/Broken_Hill' => 'ئاۋسترالىيە ئوتتۇرا قىسىم ۋاقتى (Broken Hill)',
        'Australia/Darwin' => 'ئاۋسترالىيە ئوتتۇرا قىسىم ۋاقتى (Darwin)',
        'Australia/Eucla' => 'ئاۋسترالىيە ئوتتۇرا غەربىي قىسىم ۋاقتى (Eucla)',
        'Australia/Hobart' => 'ئاۋسترالىيە شەرقىي قىسىم ۋاقتى (Hobart)',
        'Australia/Lindeman' => 'ئاۋسترالىيە شەرقىي قىسىم ۋاقتى (Lindeman)',
        'Australia/Lord_Howe' => 'لورد-خاي ۋاقتى (Lord Howe)',
        'Australia/Melbourne' => 'ئاۋسترالىيە شەرقىي قىسىم ۋاقتى (Melbourne)',
        'Australia/Perth' => 'ئاۋسترالىيە غەربىي قىسىم ۋاقتى (Perth)',
        'Australia/Sydney' => 'ئاۋسترالىيە شەرقىي قىسىم ۋاقتى (Sydney)',
        'Etc/GMT' => 'گىرىنۋىچ ۋاقتى',
        'Europe/Amsterdam' => 'ئوتتۇرا ياۋروپا ۋاقتى (Amsterdam)',
        'Europe/Andorra' => 'ئوتتۇرا ياۋروپا ۋاقتى (Andorra)',
        'Europe/Astrakhan' => 'سامارا ۋاقتى (Astrakhan)',
        'Europe/Athens' => 'شەرقىي ياۋروپا ۋاقتى (Athens)',
        'Europe/Belgrade' => 'ئوتتۇرا ياۋروپا ۋاقتى (Belgrade)',
        'Europe/Berlin' => 'ئوتتۇرا ياۋروپا ۋاقتى (Berlin)',
        'Europe/Bratislava' => 'ئوتتۇرا ياۋروپا ۋاقتى (Bratislava)',
        'Europe/Brussels' => 'ئوتتۇرا ياۋروپا ۋاقتى (Brussels)',
        'Europe/Bucharest' => 'شەرقىي ياۋروپا ۋاقتى (Bucharest)',
        'Europe/Budapest' => 'ئوتتۇرا ياۋروپا ۋاقتى (Budapest)',
        'Europe/Busingen' => 'ئوتتۇرا ياۋروپا ۋاقتى (Büsingen)',
        'Europe/Chisinau' => 'شەرقىي ياۋروپا ۋاقتى (Chișinău)',
        'Europe/Copenhagen' => 'ئوتتۇرا ياۋروپا ۋاقتى (Copenhagen)',
        'Europe/Dublin' => 'گىرىنۋىچ ۋاقتى (Dublin)',
        'Europe/Gibraltar' => 'ئوتتۇرا ياۋروپا ۋاقتى (Gibraltar)',
        'Europe/Guernsey' => 'گىرىنۋىچ ۋاقتى (Guernsey)',
        'Europe/Helsinki' => 'شەرقىي ياۋروپا ۋاقتى (Helsinki)',
        'Europe/Isle_of_Man' => 'گىرىنۋىچ ۋاقتى (Isle of Man)',
        'Europe/Istanbul' => 'تۈركىيە ۋاقتى (Istanbul)',
        'Europe/Jersey' => 'گىرىنۋىچ ۋاقتى (Jersey)',
        'Europe/Kaliningrad' => 'شەرقىي ياۋروپا ۋاقتى (Kaliningrad)',
        'Europe/Kiev' => 'شەرقىي ياۋروپا ۋاقتى (Kyiv)',
        'Europe/Kyiv' => 'شەرقىي ياۋروپا ۋاقتى (Kyiv)',
        'Europe/Kirov' => 'موسكۋا ۋاقتى (Kirov)',
        'Europe/Lisbon' => 'غەربىي ياۋروپا ۋاقتى (Lisbon)',
        'Europe/Ljubljana' => 'ئوتتۇرا ياۋروپا ۋاقتى (Ljubljana)',
        'Europe/London' => 'گىرىنۋىچ ۋاقتى (London)',
        'Europe/Luxembourg' => 'ئوتتۇرا ياۋروپا ۋاقتى (Luxembourg)',
        'Europe/Madrid' => 'ئوتتۇرا ياۋروپا ۋاقتى (Madrid)',
        'Europe/Malta' => 'ئوتتۇرا ياۋروپا ۋاقتى (Malta)',
        'Europe/Mariehamn' => 'شەرقىي ياۋروپا ۋاقتى (Mariehamn)',
        'Europe/Minsk' => 'موسكۋا ۋاقتى (Minsk)',
        'Europe/Monaco' => 'ئوتتۇرا ياۋروپا ۋاقتى (Monaco)',
        'Europe/Moscow' => 'موسكۋا ۋاقتى (Moscow)',
        'Europe/Oslo' => 'ئوتتۇرا ياۋروپا ۋاقتى (Oslo)',
        'Europe/Paris' => 'ئوتتۇرا ياۋروپا ۋاقتى (Paris)',
        'Europe/Podgorica' => 'ئوتتۇرا ياۋروپا ۋاقتى (Podgorica)',
        'Europe/Prague' => 'ئوتتۇرا ياۋروپا ۋاقتى (Prague)',
        'Europe/Riga' => 'شەرقىي ياۋروپا ۋاقتى (Riga)',
        'Europe/Rome' => 'ئوتتۇرا ياۋروپا ۋاقتى (Rome)',
        'Europe/Samara' => 'سامارا ۋاقتى (Samara)',
        'Europe/San_Marino' => 'ئوتتۇرا ياۋروپا ۋاقتى (San Marino)',
        'Europe/Sarajevo' => 'ئوتتۇرا ياۋروپا ۋاقتى (Sarajevo)',
        'Europe/Saratov' => 'سامارا ۋاقتى (Saratov)',
        'Europe/Simferopol' => 'موسكۋا ۋاقتى (Simferopol)',
        'Europe/Skopje' => 'ئوتتۇرا ياۋروپا ۋاقتى (Skopje)',
        'Europe/Sofia' => 'شەرقىي ياۋروپا ۋاقتى (Sofia)',
        'Europe/Stockholm' => 'ئوتتۇرا ياۋروپا ۋاقتى (Stockholm)',
        'Europe/Tallinn' => 'شەرقىي ياۋروپا ۋاقتى (Tallinn)',
        'Europe/Tirane' => 'ئوتتۇرا ياۋروپا ۋاقتى (Tirana)',
        'Europe/Ulyanovsk' => 'سامارا ۋاقتى (Ulyanovsk)',
        'Europe/Vaduz' => 'ئوتتۇرا ياۋروپا ۋاقتى (Vaduz)',
        'Europe/Vatican' => 'ئوتتۇرا ياۋروپا ۋاقتى (Vatican)',
        'Europe/Vienna' => 'ئوتتۇرا ياۋروپا ۋاقتى (Vienna)',
        'Europe/Vilnius' => 'شەرقىي ياۋروپا ۋاقتى (Vilnius)',
        'Europe/Volgograd' => 'موسكۋا ۋاقتى (Volgograd)',
        'Europe/Warsaw' => 'ئوتتۇرا ياۋروپا ۋاقتى (Warsaw)',
        'Europe/Zagreb' => 'ئوتتۇرا ياۋروپا ۋاقتى (Zagreb)',
        'Europe/Zurich' => 'ئوتتۇرا ياۋروپا ۋاقتى (Zurich)',
        'Indian/Antananarivo' => 'شەرقىي ئافرىقا ۋاقتى (Antananarivo)',
        'Indian/Chagos' => 'ھىندى ئوكيان ۋاقتى (Chagos)',
        'Indian/Christmas' => 'روژدېستۋو ئارىلى ۋاقتى (Christmas)',
        'Indian/Cocos' => 'كوكۇس ئارىلى ۋاقتى (Cocos)',
        'Indian/Comoro' => 'شەرقىي ئافرىقا ۋاقتى (Comores)',
        'Indian/Kerguelen' => 'فىرانسىيەگە قاراشلىق جەنۇبىي ۋە ئانتاركتىكا ۋاقتى (Kerguelen)',
        'Indian/Mahe' => 'سېيشېل ۋاقتى (Mahé)',
        'Indian/Maldives' => 'مالدىۋې ۋاقتى (Maldives)',
        'Indian/Mauritius' => 'ماۋرىتىئۇس ۋاقتى (Mauritius)',
        'Indian/Mayotte' => 'شەرقىي ئافرىقا ۋاقتى (Mayotte)',
        'Indian/Reunion' => 'رېئونىيون ۋاقتى',
        'Pacific/Apia' => 'ساموئا ۋاقتى (Apia)',
        'Pacific/Auckland' => 'يېڭى زېلاندىيە ۋاقتى (Auckland)',
        'Pacific/Bougainville' => 'پاپۇئا يېڭى گىۋىنېيەسى ۋاقتى (Bougainville)',
        'Pacific/Chatham' => 'چاتام ۋاقتى (Chatham)',
        'Pacific/Easter' => 'ئېستېر ئارىلى ۋاقتى (Easter)',
        'Pacific/Efate' => 'ۋانۇئاتۇ ۋاقتى (Efate)',
        'Pacific/Enderbury' => 'فېنىكس ئاراللىرى ۋاقتى (Canton)',
        'Pacific/Kanton' => 'فېنىكس ئاراللىرى ۋاقتى (Canton)',
        'Pacific/Fakaofo' => 'توكېلاۋ ۋاقتى (Fakaofo)',
        'Pacific/Fiji' => 'فىجى ۋاقتى (Fiji)',
        'Pacific/Funafuti' => 'تۇۋالۇ ۋاقتى (Funafuti)',
        'Pacific/Galapagos' => 'گالاپاگوس ۋاقتى (Galápagos)',
        'Pacific/Gambier' => 'گامبىيېر ۋاقتى (Gambier)',
        'Pacific/Guadalcanal' => 'سولومون ئاراللىرى ۋاقتى (Guadalcanal)',
        'Pacific/Guam' => 'چاموررو ئۆلچەملىك ۋاقتى (Guam)',
        'Pacific/Honolulu' => 'ھاۋاي-ئالېيۇت ئۆلچەملىك ۋاقتى (Honolulu)',
        'Pacific/Kiritimati' => 'لاين ئاراللىرى ۋاقتى (Kiritimati)',
        'Pacific/Kosrae' => 'كوسرائې ۋاقتى (Kosrae)',
        'Pacific/Kwajalein' => 'مارشال ئاراللىرى ۋاقتى (Kwajalein)',
        'Pacific/Majuro' => 'مارشال ئاراللىرى ۋاقتى (Majuro)',
        'Pacific/Marquesas' => 'ماركىز ۋاقتى (Marquesas)',
        'Pacific/Midway' => 'ساموئا ۋاقتى (Midway)',
        'Pacific/Nauru' => 'ناۋرۇ ۋاقتى (Nauru)',
        'Pacific/Niue' => 'نىيۇئې ۋاقتى (Niue)',
        'Pacific/Norfolk' => 'نورفولك ئاراللىرى ۋاقتى (Norfolk)',
        'Pacific/Noumea' => 'يېڭى كالېدونىيە ۋاقتى (Nouméa)',
        'Pacific/Pago_Pago' => 'ساموئا ۋاقتى (Pago Pago)',
        'Pacific/Palau' => 'پالاۋ ۋاقتى (Palau)',
        'Pacific/Pitcairn' => 'پىتكاير ۋاقتى (Pitcairn)',
        'Pacific/Ponape' => 'پونپېي ۋاقتى (Pohnpei)',
        'Pacific/Pohnpei' => 'پونپېي ۋاقتى (Pohnpei)',
        'Pacific/Port_Moresby' => 'پاپۇئا يېڭى گىۋىنېيەسى ۋاقتى (Port Moresby)',
        'Pacific/Rarotonga' => 'كۇك ئاراللىرى ۋاقتى (Rarotonga)',
        'Pacific/Saipan' => 'چاموررو ئۆلچەملىك ۋاقتى (Saipan)',
        'Pacific/Tahiti' => 'تايتى ۋاقتى (Tahiti)',
        'Pacific/Tarawa' => 'گىلبېرت ئاراللىرى ۋاقتى (Tarawa)',
        'Pacific/Tongatapu' => 'تونگا ۋاقتى (Tongatapu)',
        'Pacific/Truk' => 'چۇك ۋاقتى (Chuuk)',
        'Pacific/Chuuk' => 'چۇك ۋاقتى (Chuuk)',
        'Pacific/Wake' => 'ۋېيك ئارىلى ۋاقتى (Wake)',
        'Pacific/Wallis' => 'ۋاللىس ۋە فۇتۇنا ۋاقتى (Wallis & Futuna)',
    ],
    'Meta' => [],
];
