<?php

return [
    'Names' => [
        'as_IN' => 'آسامي (भारत)',
        'az_Cyrl' => 'آزربائيجاني (सिरिलिक)',
        'az_Cyrl_AZ' => 'آزربائيجاني (सिरिलिक, آذربائيجان)',
        'az_Latn' => 'آزربائيجاني (लैटिन)',
        'az_Latn_AZ' => 'آزربائيجاني (लैटिन, آذربائيجان)',
        'ba_RU' => 'ڪينيڊا (रशिया)',
        'bn_IN' => 'بنگلا (भारत)',
        'bo_CN' => 'تبيتائي (चीन)',
        'bo_IN' => 'تبيتائي (भारत)',
        'br_FR' => 'بريٽن (फ़्रांस)',
        'bs_Cyrl' => 'بوسنيائي (सिरिलिक)',
        'bs_Cyrl_BA' => 'بوسنيائي (सिरिलिक, بوسنيا ۽ هرزيگووينا)',
        'bs_Latn' => 'بوسنيائي (लैटिन)',
        'bs_Latn_BA' => 'بوسنيائي (लैटिन, بوسنيا ۽ هرزيگووينا)',
        'ca_FR' => 'ڪيٽالان (फ़्रांस)',
        'ca_IT' => 'ڪيٽالان (इटली)',
        'ce_RU' => 'چیچن (रशिया)',
        'cv_RU' => 'چو واش (रशिया)',
        'cy_GB' => 'ويلش (बरतानी)',
        'de' => 'जर्मन',
        'de_AT' => 'जर्मन (آسٽريا)',
        'de_BE' => 'जर्मन (بيلجيم)',
        'de_CH' => 'जर्मन (سوئزرلينڊ)',
        'de_DE' => 'जर्मन (जर्मनी)',
        'de_IT' => 'जर्मन (इटली)',
        'de_LI' => 'जर्मन (لچي ٽينسٽين)',
        'de_LU' => 'जर्मन (لگزمبرگ)',
        'en' => 'अंगरेज़ी',
        'en_001' => 'अंगरेज़ी (دنيا)',
        'en_150' => 'अंगरेज़ी (يورپ)',
        'en_AE' => 'अंगरेज़ी (متحده عرب امارات)',
        'en_AG' => 'अंगरेज़ी (اينٽيگا ۽ باربوڊا)',
        'en_AI' => 'अंगरेज़ी (انگويلا)',
        'en_AS' => 'अंगरेज़ी (آمريڪي ساموا)',
        'en_AT' => 'अंगरेज़ी (آسٽريا)',
        'en_AU' => 'अंगरेज़ी (آسٽريليا)',
        'en_BB' => 'अंगरेज़ी (باربڊوس)',
        'en_BE' => 'अंगरेज़ी (بيلجيم)',
        'en_BI' => 'अंगरेज़ी (برونڊي)',
        'en_BM' => 'अंगरेज़ी (برمودا)',
        'en_BS' => 'अंगरेज़ी (باهاماس)',
        'en_BW' => 'अंगरेज़ी (بوٽسوانا)',
        'en_BZ' => 'अंगरेज़ी (بيليز)',
        'en_CA' => 'अंगरेज़ी (ڪينيڊا)',
        'en_CC' => 'अंगरेज़ी (ڪوڪوس ٻيٽ)',
        'en_CH' => 'अंगरेज़ी (سوئزرلينڊ)',
        'en_CK' => 'अंगरेज़ी (ڪوڪ ٻيٽ)',
        'en_CM' => 'अंगरेज़ी (ڪيمرون)',
        'en_CX' => 'अंगरेज़ी (ڪرسمس ٻيٽ)',
        'en_CY' => 'अंगरेज़ी (سائپرس)',
        'en_CZ' => 'अंगरेज़ी (چيڪيا)',
        'en_DE' => 'अंगरेज़ी (जर्मनी)',
        'en_DK' => 'अंगरेज़ी (ڊينمارڪ)',
        'en_DM' => 'अंगरेज़ी (ڊومينيڪا)',
        'en_EE' => 'अंगरेज़ी (ايسٽونيا)',
        'en_ER' => 'अंगरेज़ी (ايريٽيريا)',
        'en_ES' => 'अंगरेज़ी (اسپين)',
        'en_FI' => 'अंगरेज़ी (فن لينڊ)',
        'en_FJ' => 'अंगरेज़ी (فجي)',
        'en_FK' => 'अंगरेज़ी (فاڪ لينڊ ٻيٽ)',
        'en_FM' => 'अंगरेज़ी (مائڪرونيشيا)',
        'en_FR' => 'अंगरेज़ी (फ़्रांस)',
        'en_GB' => 'अंगरेज़ी (बरतानी)',
        'en_GD' => 'अंगरेज़ी (گريناڊا)',
        'en_GE' => 'अंगरेज़ी (جارجيا)',
        'en_GG' => 'अंगरेज़ी (گورنسي)',
        'en_GH' => 'अंगरेज़ी (گهانا)',
        'en_GI' => 'अंगरेज़ी (جبرالٽر)',
        'en_GM' => 'अंगरेज़ी (گيمبيا)',
        'en_GS' => 'अंगरेज़ी (ڏکڻ جارجيا ۽ ڏکڻ سينڊوچ ٻيٽ)',
        'en_GU' => 'अंगरेज़ी (گوام)',
        'en_GY' => 'अंगरेज़ी (گيانا)',
        'en_HK' => 'अंगरेज़ी (هانگ ڪانگ SAR چين)',
        'en_HU' => 'अंगरेज़ी (هنگري)',
        'en_ID' => 'अंगरेज़ी (انڊونيشيا)',
        'en_IE' => 'अंगरेज़ी (آئرلينڊ)',
        'en_IL' => 'अंगरेज़ी (اسرائيل)',
        'en_IM' => 'अंगरेज़ी (انسانن جو ٻيٽ)',
        'en_IN' => 'अंगरेज़ी (भारत)',
        'en_IO' => 'अंगरेज़ी (برطانوي هندي سمنڊ خطو)',
        'en_IT' => 'अंगरेज़ी (इटली)',
        'en_JE' => 'अंगरेज़ी (جرسي)',
        'en_JM' => 'अंगरेज़ी (جميڪا)',
        'en_JP' => 'अंगरेज़ी (जापान)',
        'en_KE' => 'अंगरेज़ी (ڪينيا)',
        'en_KI' => 'अंगरेज़ी (ڪرباتي)',
        'en_KN' => 'अंगरेज़ी (سينٽ ڪٽس و نيوس)',
        'en_KY' => 'अंगरेज़ी (ڪي مين ٻيٽ)',
        'en_LC' => 'अंगरेज़ी (سينٽ لوسيا)',
        'en_LR' => 'अंगरेज़ी (لائبیریا)',
        'en_LS' => 'अंगरेज़ी (ليسوٿو)',
        'en_LT' => 'अंगरेज़ी (لٿونيا)',
        'en_LV' => 'अंगरेज़ी (لاتويا)',
        'en_MG' => 'अंगरेज़ी (مدگاسڪر)',
        'en_MH' => 'अंगरेज़ी (مارشل ٻيٽ)',
        'en_MO' => 'अंगरेज़ी (مڪائو SAR چين)',
        'en_MP' => 'अंगरेज़ी (اتريان ماريانا ٻيٽ)',
        'en_MS' => 'अंगरेज़ी (مونٽسراٽ)',
        'en_MT' => 'अंगरेज़ी (مالٽا)',
        'en_MU' => 'अंगरेज़ी (موريشس)',
        'en_MV' => 'अंगरेज़ी (مالديپ)',
        'en_MW' => 'अंगरेज़ी (مالاوي)',
        'en_MY' => 'अंगरेज़ी (ملائيشيا)',
        'en_NA' => 'अंगरेज़ी (نيميبيا)',
        'en_NF' => 'अंगरेज़ी (نورفوڪ ٻيٽ)',
        'en_NG' => 'अंगरेज़ी (نائيجيريا)',
        'en_NL' => 'अंगरेज़ी (نيدرلينڊ)',
        'en_NO' => 'अंगरेज़ी (ناروي)',
        'en_NR' => 'अंगरेज़ी (نائورو)',
        'en_NU' => 'अंगरेज़ी (نووي)',
        'en_NZ' => 'अंगरेज़ी (نيو زيلينڊ)',
        'en_PG' => 'अंगरेज़ी (پاپوا نیو گني)',
        'en_PH' => 'अंगरेज़ी (فلپائن)',
        'en_PK' => 'अंगरेज़ी (पाकिस्तान)',
        'en_PL' => 'अंगरेज़ी (پولينڊ)',
        'en_PN' => 'अंगरेज़ी (پٽڪئرن ٻيٽ)',
        'en_PR' => 'अंगरेज़ी (پيوئرٽو ريڪو)',
        'en_PT' => 'अंगरेज़ी (پرتگال)',
        'en_PW' => 'अंगरेज़ी (پلائو)',
        'en_RO' => 'अंगरेज़ी (رومانيا)',
        'en_RW' => 'अंगरेज़ी (روانڊا)',
        'en_SB' => 'अंगरेज़ी (سولومون ٻيٽَ)',
        'en_SC' => 'अंगरेज़ी (شي شلز)',
        'en_SD' => 'अंगरेज़ी (سوڊان)',
        'en_SE' => 'अंगरेज़ी (سوئيڊن)',
        'en_SG' => 'अंगरेज़ी (سنگاپور)',
        'en_SH' => 'अंगरेज़ी (سينٽ ھيلينا)',
        'en_SI' => 'अंगरेज़ी (سلوینیا)',
        'en_SK' => 'अंगरेज़ी (سلوواڪيا)',
        'en_SL' => 'अंगरेज़ी (سيرا ليون)',
        'en_SS' => 'अंगरेज़ी (ڏکڻ سوڊان)',
        'en_SX' => 'अंगरेज़ी (سنٽ مارٽن)',
        'en_SZ' => 'अंगरेज़ी (ايسواٽني)',
        'en_TC' => 'अंगरेज़ी (ترڪ ۽ ڪيڪوس ٻيٽ)',
        'en_TK' => 'अंगरेज़ी (ٽوڪلائو)',
        'en_TO' => 'अंगरेज़ी (ٽونگا)',
        'en_TT' => 'अंगरेज़ी (ٽرينيڊاڊ ۽ ٽوباگو)',
        'en_TV' => 'अंगरेज़ी (توالو)',
        'en_TZ' => 'अंगरेज़ी (تنزانيا)',
        'en_UA' => 'अंगरेज़ी (يوڪرين)',
        'en_UG' => 'अंगरेज़ी (يوگنڊا)',
        'en_UM' => 'अंगरेज़ी (آمريڪي خارجي ٻيٽ)',
        'en_US' => 'अंगरेज़ी (अमेरिका)',
        'en_VC' => 'अंगरेज़ी (سینٽ ونسنت ۽ گریناڊینز)',
        'en_VG' => 'अंगरेज़ी (برطانوي ورجن ٻيٽ)',
        'en_VI' => 'अंगरेज़ी (آمريڪي ورجن ٻيٽ)',
        'en_VU' => 'अंगरेज़ी (وينيٽيو)',
        'en_WS' => 'अंगरेज़ी (ساموا)',
        'en_ZA' => 'अंगरेज़ी (ڏکڻ آفريقا)',
        'en_ZM' => 'अंगरेज़ी (زيمبيا)',
        'en_ZW' => 'अंगरेज़ी (زمبابوي)',
        'es' => 'स्पेनिश',
        'es_419' => 'स्पेनिश (لاطيني آمريڪا)',
        'es_AR' => 'स्पेनिश (ارجنٽينا)',
        'es_BO' => 'स्पेनिश (بوليويا)',
        'es_BR' => 'स्पेनिश (ब्राज़ील)',
        'es_BZ' => 'स्पेनिश (بيليز)',
        'es_CL' => 'स्पेनिश (چلي)',
        'es_CO' => 'स्पेनिश (ڪولمبيا)',
        'es_CR' => 'स्पेनिश (ڪوسٽا ريڪا)',
        'es_CU' => 'स्पेनिश (ڪيوبا)',
        'es_DO' => 'स्पेनिश (ڊومينيڪن جمهوريه)',
        'es_EC' => 'स्पेनिश (ايڪواڊور)',
        'es_ES' => 'स्पेनिश (اسپين)',
        'es_GQ' => 'स्पेनिश (ايڪوٽوريل گائينا)',
        'es_GT' => 'स्पेनिश (گوئٽي مالا)',
        'es_HN' => 'स्पेनिश (هنڊورس)',
        'es_MX' => 'स्पेनिश (ميڪسيڪو)',
        'es_NI' => 'स्पेनिश (نڪراگوا)',
        'es_PA' => 'स्पेनिश (پناما)',
        'es_PE' => 'स्पेनिश (پيرو)',
        'es_PH' => 'स्पेनिश (فلپائن)',
        'es_PR' => 'स्पेनिश (پيوئرٽو ريڪو)',
        'es_PY' => 'स्पेनिश (پيراگوءِ)',
        'es_SV' => 'स्पेनिश (ال سلواڊور)',
        'es_US' => 'स्पेनिश (अमेरिका)',
        'es_UY' => 'स्पेनिश (يوروگوءِ)',
        'es_VE' => 'स्पेनिश (وينزويلا)',
        'ff_Latn' => 'فلاهه (लैटिन)',
        'ff_Latn_BF' => 'فلاهه (लैटिन, برڪينا فاسو)',
        'ff_Latn_CM' => 'فلاهه (लैटिन, ڪيمرون)',
        'ff_Latn_GH' => 'فلاهه (लैटिन, گهانا)',
        'ff_Latn_GM' => 'فلاهه (लैटिन, گيمبيا)',
        'ff_Latn_GN' => 'فلاهه (लैटिन, گني)',
        'ff_Latn_GW' => 'فلاهه (लैटिन, گني بسائو)',
        'ff_Latn_LR' => 'فلاهه (लैटिन, لائبیریا)',
        'ff_Latn_MR' => 'فلاهه (लैटिन, موريتانيا)',
        'ff_Latn_NE' => 'فلاهه (लैटिन, نائيجر)',
        'ff_Latn_NG' => 'فلاهه (लैटिन, نائيجيريا)',
        'ff_Latn_SL' => 'فلاهه (लैटिन, سيرا ليون)',
        'ff_Latn_SN' => 'فلاهه (लैटिन, سينيگال)',
        'fr' => 'फ्रेंच',
        'fr_BE' => 'फ्रेंच (بيلجيم)',
        'fr_BF' => 'फ्रेंच (برڪينا فاسو)',
        'fr_BI' => 'फ्रेंच (برونڊي)',
        'fr_BJ' => 'फ्रेंच (بينن)',
        'fr_BL' => 'फ्रेंच (سینٽ برٿلیمی)',
        'fr_CA' => 'फ्रेंच (ڪينيڊا)',
        'fr_CD' => 'फ्रेंच (ڪانگو -ڪنشاسا)',
        'fr_CF' => 'फ्रेंच (وچ آفريقي جمهوريه)',
        'fr_CG' => 'फ्रेंच (ڪانگو - برازاویل)',
        'fr_CH' => 'फ्रेंच (سوئزرلينڊ)',
        'fr_CI' => 'फ्रेंच (ڪوٽي ويرا)',
        'fr_CM' => 'फ्रेंच (ڪيمرون)',
        'fr_DJ' => 'फ्रेंच (ڊجبيوتي)',
        'fr_DZ' => 'फ्रेंच (الجيريا)',
        'fr_FR' => 'फ्रेंच (फ़्रांस)',
        'fr_GA' => 'फ्रेंच (گبون)',
        'fr_GF' => 'फ्रेंच (فرانسيسي گيانا)',
        'fr_GN' => 'फ्रेंच (گني)',
        'fr_GP' => 'फ्रेंच (گواڊیلوپ)',
        'fr_GQ' => 'फ्रेंच (ايڪوٽوريل گائينا)',
        'fr_HT' => 'फ्रेंच (هيٽي)',
        'fr_KM' => 'फ्रेंच (ڪوموروس)',
        'fr_LU' => 'फ्रेंच (لگزمبرگ)',
        'fr_MA' => 'फ्रेंच (مراڪش)',
        'fr_MC' => 'फ्रेंच (موناڪو)',
        'fr_MF' => 'फ्रेंच (سينٽ مارٽن)',
        'fr_MG' => 'फ्रेंच (مدگاسڪر)',
        'fr_ML' => 'फ्रेंच (مالي)',
        'fr_MQ' => 'फ्रेंच (مارتينڪ)',
        'fr_MR' => 'फ्रेंच (موريتانيا)',
        'fr_MU' => 'फ्रेंच (موريشس)',
        'fr_NC' => 'फ्रेंच (نیو ڪالیڊونیا)',
        'fr_NE' => 'फ्रेंच (نائيجر)',
        'fr_PF' => 'फ्रेंच (فرانسيسي پولينيشيا)',
        'fr_PM' => 'फ्रेंच (سينٽ پيئر ۽ ميڪيلون)',
        'fr_RE' => 'फ्रेंच (ري يونين)',
        'fr_RW' => 'फ्रेंच (روانڊا)',
        'fr_SC' => 'फ्रेंच (شي شلز)',
        'fr_SN' => 'फ्रेंच (سينيگال)',
        'fr_SY' => 'फ्रेंच (شام)',
        'fr_TD' => 'फ्रेंच (چاڊ)',
        'fr_TG' => 'फ्रेंच (ٽوگو)',
        'fr_TN' => 'फ्रेंच (تيونيسيا)',
        'fr_VU' => 'फ्रेंच (وينيٽيو)',
        'fr_WF' => 'फ्रेंच (والس ۽ فتونا)',
        'fr_YT' => 'फ्रेंच (مياتي)',
        'ga_GB' => 'آئرش (बरतानी)',
        'gd_GB' => 'اسڪاٽش گيلڪ (बरतानी)',
        'gu_IN' => 'گجراتي (भारत)',
        'hi_IN' => 'هندي (भारत)',
        'hi_Latn' => 'هندي (लैटिन)',
        'hi_Latn_IN' => 'هندي (लैटिन, भारत)',
        'ii_CN' => 'سچوان يي (चीन)',
        'it' => 'इटालियनु',
        'it_CH' => 'इटालियनु (سوئزرلينڊ)',
        'it_IT' => 'इटालियनु (इटली)',
        'it_SM' => 'इटालियनु (سان مرینو)',
        'it_VA' => 'इटालियनु (ويٽڪين سٽي)',
        'ja' => 'जापानी',
        'ja_JP' => 'जापानी (जापान)',
        'kk_Arab' => 'قازق (अरबी)',
        'kk_Arab_CN' => 'قازق (अरबी, चीन)',
        'kk_Cyrl' => 'قازق (सिरिलिक)',
        'kk_Cyrl_KZ' => 'قازق (सिरिलिक, قازقستان)',
        'kn_IN' => 'ڪناڊا (भारत)',
        'ko_CN' => 'ڪوريائي (चीन)',
        'ks_Arab' => 'ڪشميري (अरबी)',
        'ks_Arab_IN' => 'ڪشميري (अरबी, भारत)',
        'ks_Deva' => 'ڪشميري (देवनागिरी)',
        'ks_Deva_IN' => 'ڪشميري (देवनागिरी, भारत)',
        'ks_IN' => 'ڪشميري (भारत)',
        'ku_Latn' => 'ڪردي (लैटिन)',
        'ku_Latn_IQ' => 'ڪردي (लैटिन, عراق)',
        'ku_Latn_SY' => 'ڪردي (लैटिन, شام)',
        'ku_Latn_TR' => 'ڪردي (लैटिन, ترڪييي)',
        'kw_GB' => 'ڪورنش (बरतानी)',
        'ml_IN' => 'مليالم (भारत)',
        'mr_IN' => 'مراٺي (भारत)',
        'ne_IN' => 'نيپالي (भारत)',
        'oc_FR' => 'آڪسيٽن (फ़्रांस)',
        'or_IN' => 'اوڊيا (भारत)',
        'os_RU' => 'اوسيٽڪ (रशिया)',
        'pa_Arab' => 'پنجابي (अरबी)',
        'pa_Arab_PK' => 'پنجابي (अरबी, पाकिस्तान)',
        'pa_Guru_IN' => 'پنجابي (گرمکي, भारत)',
        'pa_IN' => 'پنجابي (भारत)',
        'pa_PK' => 'پنجابي (पाकिस्तान)',
        'ps_PK' => 'پشتو (पाकिस्तान)',
        'pt' => 'पुर्तगाली',
        'pt_AO' => 'पुर्तगाली (انگولا)',
        'pt_BR' => 'पुर्तगाली (ब्राज़ील)',
        'pt_CH' => 'पुर्तगाली (سوئزرلينڊ)',
        'pt_CV' => 'पुर्तगाली (ڪيپ وردي)',
        'pt_GQ' => 'पुर्तगाली (ايڪوٽوريل گائينا)',
        'pt_GW' => 'पुर्तगाली (گني بسائو)',
        'pt_LU' => 'पुर्तगाली (لگزمبرگ)',
        'pt_MO' => 'पुर्तगाली (مڪائو SAR چين)',
        'pt_MZ' => 'पुर्तगाली (موزمبیق)',
        'pt_PT' => 'पुर्तगाली (پرتگال)',
        'pt_ST' => 'पुर्तगाली (سائو ٽومي ۽ پرنسپیي)',
        'pt_TL' => 'पुर्तगाली (تيمور ليستي)',
        'ru' => 'रशियनु',
        'ru_BY' => 'रशियनु (بيلاروس)',
        'ru_KG' => 'रशियनु (ڪرغستان)',
        'ru_KZ' => 'रशियनु (قازقستان)',
        'ru_MD' => 'रशियनु (مالدووا)',
        'ru_RU' => 'रशियनु (रशिया)',
        'ru_UA' => 'रशियनु (يوڪرين)',
        'sa_IN' => 'سنسڪرت (भारत)',
        'sc_IT' => 'سارڊيني (इटली)',
        'sd' => 'सिन्धी',
        'sd_Arab' => 'सिन्धी (अरबी)',
        'sd_Arab_PK' => 'सिन्धी (अरबी, पाकिस्तान)',
        'sd_Deva' => 'सिन्धी (देवनागिरी)',
        'sd_Deva_IN' => 'सिन्धी (देवनागिरी, भारत)',
        'sd_IN' => 'सिन्धी (भारत)',
        'sd_PK' => 'सिन्धी (पाकिस्तान)',
        'sr_Cyrl' => 'سربيائي (सिरिलिक)',
        'sr_Cyrl_BA' => 'سربيائي (सिरिलिक, بوسنيا ۽ هرزيگووينا)',
        'sr_Cyrl_ME' => 'سربيائي (सिरिलिक, مونٽي نيگرو)',
        'sr_Cyrl_RS' => 'سربيائي (सिरिलिक, سربيا)',
        'sr_Latn' => 'سربيائي (लैटिन)',
        'sr_Latn_BA' => 'سربيائي (लैटिन, بوسنيا ۽ هرزيگووينا)',
        'sr_Latn_ME' => 'سربيائي (लैटिन, مونٽي نيگرو)',
        'sr_Latn_RS' => 'سربيائي (लैटिन, سربيا)',
        'su_Latn' => 'سوڊاني (लैटिन)',
        'su_Latn_ID' => 'سوڊاني (लैटिन, انڊونيشيا)',
        'ta_IN' => 'تامل (भारत)',
        'te_IN' => 'تلگو (भारत)',
        'tt_RU' => 'تاتار (रशिया)',
        'ug_CN' => 'يوغور (चीन)',
        'ur_IN' => 'اردو (भारत)',
        'ur_PK' => 'اردو (पाकिस्तान)',
        'uz_Arab' => 'ازبڪ (अरबी)',
        'uz_Arab_AF' => 'ازبڪ (अरबी, افغانستان)',
        'uz_Cyrl' => 'ازبڪ (सिरिलिक)',
        'uz_Cyrl_UZ' => 'ازبڪ (सिरिलिक, ازبڪستان)',
        'uz_Latn' => 'ازبڪ (लैटिन)',
        'uz_Latn_UZ' => 'ازبڪ (लैटिन, ازبڪستان)',
        'za_CN' => 'جوئنگ (चीन)',
        'zh' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी]',
        'zh_CN' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (चीन)',
        'zh_HK' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (هانگ ڪانگ SAR چين)',
        'zh_Hans' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे])',
        'zh_Hans_CN' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], चीन)',
        'zh_Hans_HK' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], هانگ ڪانگ SAR چين)',
        'zh_Hans_MO' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], مڪائو SAR چين)',
        'zh_Hans_MY' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], ملائيشيا)',
        'zh_Hans_SG' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (सादी थियल [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], سنگاپور)',
        'zh_Hant' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे])',
        'zh_Hant_HK' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], هانگ ڪانگ SAR چين)',
        'zh_Hant_MO' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], مڪائو SAR چين)',
        'zh_Hant_MY' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], ملائيشيا)',
        'zh_Hant_TW' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (रवायती [तरजुमे जो द॒स : लिखत जे नाले जे हिन बयानु खे चीनीअ लाए भाषा जे नाले सां गद॒ मिलाए करे इस्तेमाल कयो वेंदो आहे], تائیوان)',
        'zh_MO' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (مڪائو SAR چين)',
        'zh_SG' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (سنگاپور)',
        'zh_TW' => 'चीनी [तर्जुमे जो द॒स :खास करे, मैन्डरिन चीनी] (تائیوان)',
    ],
];
