<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Aghb' => 'albanesu caucàsicu',
        'Ahom' => 'ahom',
        'Arab' => 'àrabu',
        'Aran' => 'nastaʿlīq',
        'Armi' => 'aramàicu imperiale',
        'Armn' => 'armenu',
        'Avst' => 'avèsticu',
        'Bali' => 'balinesu',
        'Bamu' => 'bamum',
        'Bass' => 'bassa vah',
        'Batk' => 'batak',
        'Beng' => 'bengalesu',
        'Bhks' => 'bhaiksuki',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille',
        'Bugi' => 'buginesu',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'sillabàriu aborìgenu canadesu unificadu',
        'Cari' => 'carian',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Chrs' => 'coràsmiu',
        'Copt' => 'coptu',
        'Cpmn' => 'tzipro-minòicu',
        'Cprt' => 'tzipriotu',
        'Cyrl' => 'tzirìllicu',
        'Deva' => 'devanagari',
        'Diak' => 'dives akuru',
        'Dogr' => 'dogra',
        'Dsrt' => 'deseret',
        'Dupl' => 'istenografia duployan',
        'Egyp' => 'geroglìficos egitzianos',
        'Elba' => 'elbasan',
        'Elym' => 'elimàicu',
        'Ethi' => 'etìope',
        'Geor' => 'georgianu',
        'Glag' => 'glagolìticu',
        'Gong' => 'gunjala gondi',
        'Gonm' => 'gondi de Masaram',
        'Goth' => 'gòticu',
        'Gran' => 'grantha',
        'Grek' => 'grecu',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'han cun bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'semplificadu',
        'Hant' => 'traditzionale',
        'Hatr' => 'hatran',
        'Hebr' => 'ebràicu',
        'Hira' => 'hiragana',
        'Hluw' => 'geroglìficos anatòlicos',
        'Hmng' => 'pahawn hmong',
        'Hmnp' => 'nyiakeng puachue hmong',
        'Hrkt' => 'sillabàrios giaponesos',
        'Hung' => 'ungheresu antigu',
        'Ital' => 'itàlicu antigu',
        'Jamo' => 'jamo',
        'Java' => 'giavanesu',
        'Jpan' => 'giaponesu',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Kawi' => 'kawi',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmer',
        'Khoj' => 'khojki',
        'Kits' => 'iscritura khitan minore',
        'Knda' => 'kannada',
        'Kore' => 'coreanu',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'laotianu',
        'Latn' => 'latinu',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'lineare A',
        'Linb' => 'lineare B',
        'Lisu' => 'lisu',
        'Lyci' => 'lìtziu',
        'Lydi' => 'lìdiu',
        'Mahj' => 'mahajani',
        'Maka' => 'makasar',
        'Mand' => 'mandàicu',
        'Mani' => 'manicheu',
        'Marc' => 'marchen',
        'Medf' => 'medefaidrin',
        'Mend' => 'mende',
        'Merc' => 'corsivu meroìticu',
        'Mero' => 'meroìticu',
        'Mlym' => 'malayalam',
        'Modi' => 'modi',
        'Mong' => 'mòngolu',
        'Mroo' => 'mro',
        'Mtei' => 'meitei mayek',
        'Mult' => 'multani',
        'Mymr' => 'birmanu',
        'Nagm' => 'nag mundari',
        'Nand' => 'nandinagari',
        'Narb' => 'àrabu setentrionale antigu',
        'Nbat' => 'nabateu',
        'Newa' => 'newa',
        'Nkoo' => 'n’ko',
        'Nshu' => 'nüshu',
        'Ogam' => 'ogham',
        'Olck' => 'ol chiki',
        'Orkh' => 'orkhon',
        'Orya' => 'odia',
        'Osge' => 'osage',
        'Osma' => 'osmanya',
        'Ougr' => 'uiguru antigu',
        'Palm' => 'palmirenu',
        'Pauc' => 'pau cin hau',
        'Perm' => 'pèrmicu antigu',
        'Phag' => 'phags-pa',
        'Phli' => 'pahlavi de sas iscritziones',
        'Phlp' => 'psalter pahlavi',
        'Phnx' => 'fenìtziu',
        'Plrd' => 'pollard miao',
        'Prti' => 'pàrticu de sas iscritziones',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifi rohingya',
        'Runr' => 'rùnicu',
        'Samr' => 'samaritanu',
        'Sarb' => 'àrabu meridionale antigu',
        'Saur' => 'saurashtra',
        'Sgnw' => 'limba de sos sinnos',
        'Shaw' => 'shavianu',
        'Shrd' => 'sharada',
        'Sidd' => 'siddham',
        'Sind' => 'khudawadi',
        'Sinh' => 'singalesu',
        'Sogd' => 'sogdianu',
        'Sogo' => 'sogdianu antigu',
        'Sora' => 'sora sompeng',
        'Soyo' => 'soyombo',
        'Sund' => 'sundanesu',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'sirìacu',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takri',
        'Tale' => 'tai le',
        'Talu' => 'tai lue nou',
        'Taml' => 'tamil',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalog',
        'Thaa' => 'thaana',
        'Thai' => 'tailandesu',
        'Tibt' => 'tibetanu',
        'Tirh' => 'tirhuta',
        'Tnsa' => 'tangsa',
        'Toto' => 'toto',
        'Ugar' => 'ugarìticu',
        'Vaii' => 'vai',
        'Vith' => 'vithkuqi',
        'Wara' => 'varang kshiti',
        'Wcho' => 'wancho',
        'Xpeo' => 'persianu antigu',
        'Xsux' => 'cuneiforme sumero-acàdicu',
        'Yezi' => 'yezidi',
        'Yiii' => 'yi',
        'Zanb' => 'zanabar cuadradu',
        'Zinh' => 'eredadu',
        'Zmth' => 'notatzione matemàtica',
        'Zsye' => 'emoji',
        'Zsym' => 'sìmbulos',
        'Zxxx' => 'no iscritu',
        'Zyyy' => 'comune',
    ],
];
