<?php

return [
    'UserAssignedNames' => [
        'XK' => 'EKosovo',
    ],
    'Names' => [
        'AD' => 'E-Andorra',
        'AE' => 'E-United Arab Emirates',
        'AF' => 'E-Afghanistan',
        'AG' => 'E-Antigua & Barbuda',
        'AI' => 'E-Anguilla',
        'AL' => 'E-Albania',
        'AM' => 'E-Armenia',
        'AO' => 'E-Angola',
        'AQ' => 'E-Antarctica',
        'AR' => 'E-Argentina',
        'AS' => 'E-American Samoa',
        'AT' => 'E-Austria',
        'AU' => 'E-Australia',
        'AW' => 'E-Aruba',
        'AX' => 'E-Åland Islands',
        'AZ' => 'E-Azerbaijan',
        'BA' => 'EBosnia & Herzegovina',
        'BB' => 'EBarbados',
        'BD' => 'EBangladesh',
        'BE' => 'EBelgium',
        'BF' => 'EBurkina Faso',
        'BG' => 'EBulgaria',
        'BH' => 'EBahrain',
        'BI' => 'EBurundi',
        'BJ' => 'EBenin',
        'BL' => 'ESt. Barthélemy',
        'BM' => 'EBermuda',
        'BN' => 'eBrunei',
        'BO' => 'EBolivia',
        'BQ' => 'ECaribbean Netherlands',
        'BR' => 'EBrazil',
        'BS' => 'EBahamas',
        'BT' => 'EBhutan',
        'BV' => 'EBouvet Island',
        'BW' => 'EBotswana',
        'BY' => 'EBelarus',
        'BZ' => 'EBelize',
        'CA' => 'EKhanada',
        'CC' => 'ECocos (Keeling) Islands',
        'CD' => 'ECongo -Kinshasa',
        'CF' => 'ECentral African Republic',
        'CG' => 'ECongo - Brazzaville',
        'CH' => 'ESwitzerland',
        'CI' => 'ECôte d’Ivoire',
        'CK' => 'ECook Islands',
        'CL' => 'EChile',
        'CM' => 'ECameroon',
        'CN' => 'ETshayina',
        'CO' => 'EColombia',
        'CR' => 'ECosta Rica',
        'CU' => 'ECuba',
        'CV' => 'ECape Verde',
        'CW' => 'ECuraçao',
        'CX' => 'EChristmas Island',
        'CY' => 'ECyprus',
        'CZ' => 'ECzechia',
        'DE' => 'EJamani',
        'DJ' => 'EDjibouti',
        'DK' => 'EDenmark',
        'DM' => 'EDominica',
        'DO' => 'EDominican Republic',
        'DZ' => 'E-Algeria',
        'EC' => 'EEcuador',
        'EE' => 'E-Estonia',
        'EG' => 'IYiputa',
        'EH' => 'EWestern Sahara',
        'ER' => 'E-Eritrea',
        'ES' => 'ESpain',
        'ET' => 'E-Ethiopia',
        'FI' => 'EFinland',
        'FJ' => 'EFiji',
        'FK' => 'EFalkland Islands',
        'FM' => 'EMicronesia',
        'FO' => 'EFaroe Islands',
        'FR' => 'EFrance',
        'GA' => 'EGabon',
        'GB' => 'E-United Kingdom',
        'GD' => 'EGrenada',
        'GE' => 'EGeorgia',
        'GF' => 'EFrench Guiana',
        'GG' => 'EGuernsey',
        'GH' => 'EGhana',
        'GI' => 'EGibraltar',
        'GL' => 'EGreenland',
        'GM' => 'EGambia',
        'GN' => 'EGuinea',
        'GP' => 'EGuadeloupe',
        'GQ' => 'E-Equatorial Guinea',
        'GR' => 'EGreece',
        'GS' => 'ESouth Georgia & South Sandwich Islands',
        'GT' => 'EGuatemala',
        'GU' => 'EGuam',
        'GW' => 'EGuinea-Bissau',
        'GY' => 'EGuyana',
        'HK' => 'EHong Kong SAR China',
        'HM' => 'EHeard & McDonald Islands',
        'HN' => 'EHonduras',
        'HR' => 'ECroatia',
        'HT' => 'EHaiti',
        'HU' => 'EHungary',
        'ID' => 'E-Indonesia',
        'IE' => 'E-Ireland',
        'IL' => 'E-Israel',
        'IM' => 'E-Isle of Man',
        'IN' => 'E-Indiya',
        'IO' => 'EBritish Indian Ocean Territory',
        'IQ' => 'E-Iraq',
        'IR' => 'E-Iran',
        'IS' => 'E-Iceland',
        'IT' => 'E-Italy',
        'JE' => 'EJersey',
        'JM' => 'EJamaica',
        'JO' => 'EJordan',
        'JP' => 'EJapan',
        'KE' => 'EKenya',
        'KG' => 'EKyrgyzstan',
        'KH' => 'ECambodia',
        'KI' => 'EKiribati',
        'KM' => 'EComoros',
        'KN' => 'ESt. Kitts & Nevis',
        'KP' => 'EMntla Korea',
        'KR' => 'EMzantsi Korea',
        'KW' => 'EKuwait',
        'KY' => 'ECayman Islands',
        'KZ' => 'EKazakhstan',
        'LA' => 'ELaos',
        'LB' => 'ELebanon',
        'LC' => 'ESt. Lucia',
        'LI' => 'ELiechtenstein',
        'LK' => 'ESri Lanka',
        'LR' => 'ELiberia',
        'LS' => 'ELesotho',
        'LT' => 'ELithuania',
        'LU' => 'ELuxembourg',
        'LV' => 'ELatvia',
        'LY' => 'ELibya',
        'MA' => 'EMorocco',
        'MC' => 'EMonaco',
        'MD' => 'EMoldova',
        'ME' => 'EMontenegro',
        'MF' => 'ESt. Martin',
        'MG' => 'EMadagascar',
        'MH' => 'EMarshall Islands',
        'MK' => 'EMntla Macedonia',
        'ML' => 'EMali',
        'MM' => 'EMyanmar (Burma)',
        'MN' => 'EMongolia',
        'MO' => 'EMacao SAR China',
        'MP' => 'ENorthern Mariana Islands',
        'MQ' => 'EMartinique',
        'MR' => 'EMauritania',
        'MS' => 'EMontserrat',
        'MT' => 'EMalta',
        'MU' => 'EMauritius',
        'MV' => 'EMaldives',
        'MW' => 'EMalawi',
        'MX' => 'EMexico',
        'MY' => 'EMalaysia',
        'MZ' => 'EMozambique',
        'NA' => 'ENamibia',
        'NC' => 'ENew Caledonia',
        'NE' => 'ENiger',
        'NF' => 'ENorfolk Island',
        'NG' => 'ENigeria',
        'NI' => 'ENicaragua',
        'NL' => 'ENetherlands',
        'NO' => 'ENorway',
        'NP' => 'ENepal',
        'NR' => 'ENauru',
        'NU' => 'ENiue',
        'NZ' => 'ENew Zealand',
        'OM' => 'E-Oman',
        'PA' => 'EPanama',
        'PE' => 'EPeru',
        'PF' => 'EFrench Polynesia',
        'PG' => 'EPapua New Guinea',
        'PH' => 'EPhilippines',
        'PK' => 'EPakistan',
        'PL' => 'EPoland',
        'PM' => 'ESt. Pierre & Miquelon',
        'PN' => 'EPitcairn Islands',
        'PR' => 'EPuerto Rico',
        'PS' => 'IPalestinian Territories',
        'PT' => 'EPortugal',
        'PW' => 'EPalau',
        'PY' => 'EParaguay',
        'QA' => 'EQatar',
        'RE' => 'ERéunion',
        'RO' => 'ERomania',
        'RS' => 'ESerbia',
        'RU' => 'ERashiya',
        'RW' => 'ERwanda',
        'SA' => 'ESaudi Arabia',
        'SB' => 'ESolomon Islands',
        'SC' => 'ESeychelles',
        'SD' => 'ESudan',
        'SE' => 'ESweden',
        'SG' => 'ESingapore',
        'SH' => 'ESt. Helena',
        'SI' => 'ESlovenia',
        'SJ' => 'ESvalbard & Jan Mayen',
        'SK' => 'ESlovakia',
        'SL' => 'ESierra Leone',
        'SM' => 'ESan Marino',
        'SN' => 'ESenegal',
        'SO' => 'ESomalia',
        'SR' => 'ESuriname',
        'SS' => 'ESouth Sudan',
        'ST' => 'ESão Tomé & Príncipe',
        'SV' => 'E-El Salvador',
        'SX' => 'ESint Maarten',
        'SY' => 'ESiriya',
        'SZ' => 'ESwatini',
        'TC' => 'ETurks & Caicos Islands',
        'TD' => 'EChad',
        'TF' => 'EFrench Southern Territories',
        'TG' => 'ETogo',
        'TH' => 'EThailand',
        'TJ' => 'ETajikistan',
        'TK' => 'ETokelau',
        'TL' => 'ETimor-Leste',
        'TM' => 'ETurkmenistan',
        'TN' => 'ETunisia',
        'TO' => 'ETonga',
        'TR' => 'ETurkey',
        'TT' => 'ETrinidad & Tobago',
        'TV' => 'ETuvalu',
        'TW' => 'ETaiwan',
        'TZ' => 'ETanzania',
        'UA' => 'E-Ukraine',
        'UG' => 'E-Uganda',
        'UM' => 'I-U.S. Outlying Islands',
        'US' => 'EMelika',
        'UY' => 'E-Uruguay',
        'UZ' => 'E-Uzbekistan',
        'VA' => 'EVatican City',
        'VC' => 'ESt. Vincent & Grenadines',
        'VE' => 'EVenezuela',
        'VG' => 'EBritish Virgin Islands',
        'VI' => 'E-U.S. Virgin Islands',
        'VN' => 'EVietnam',
        'VU' => 'EVanuatu',
        'WF' => 'EWallis & Futuna',
        'WS' => 'ESamoa',
        'YE' => 'EYemen',
        'YT' => 'EMayotte',
        'ZA' => 'EMzantsi Afrika',
        'ZM' => 'EZambia',
        'ZW' => 'EZimbabwe',
    ],
];
