<?php

return [
    'UserAssignedNames' => [
        'XK' => 'קאסאווא',
    ],
    'Names' => [
        'AD' => 'אַנדארע',
        'AF' => 'אַפֿגהאַניסטאַן',
        'AG' => 'אַנטיגוע און באַרבודע',
        'AL' => 'אַלבאַניע',
        'AM' => 'אַרמעניע',
        'AO' => 'אַנגאלע',
        'AQ' => 'אַנטאַרקטיקע',
        'AR' => 'אַרגענטינע',
        'AT' => 'עסטרייך',
        'AU' => 'אויסטראַליע',
        'AW' => 'אַרובאַ',
        'BA' => 'באסניע הערצעגאווינע',
        'BB' => 'באַרבאַדאס',
        'BD' => 'באַנגלאַדעש',
        'BE' => 'בעלגיע',
        'BF' => 'בורקינע פֿאַסא',
        'BG' => 'בולגאַריע',
        'BI' => 'בורונדי',
        'BJ' => 'בענין',
        'BM' => 'בערמודע',
        'BN' => 'ברוניי',
        'BO' => 'באליוויע',
        'BR' => 'בראַזיל',
        'BS' => 'באַהאַמאַס',
        'BT' => 'בהוטאַן',
        'BW' => 'באצוואַנע',
        'BY' => 'בעלאַרוס',
        'BZ' => 'בעליז',
        'CA' => 'קאַנאַדע',
        'CD' => 'קאנגא־קינשאַזע',
        'CF' => 'צענטראַל־אַפֿריקאַנישע רעפּובליק',
        'CH' => 'שווייץ',
        'CI' => 'העלפֿאַ נדביין בארטן',
        'CK' => 'קוק אינזלען',
        'CL' => 'טשילע',
        'CM' => 'קאַמערון',
        'CN' => 'כינע',
        'CO' => 'קאלאמביע',
        'CR' => 'קאסטאַ ריקאַ',
        'CU' => 'קובאַ',
        'CV' => 'קאַפּווערדישע אינזלען',
        'CW' => 'קוראַסאַא',
        'CZ' => 'טשעכיי',
        'DE' => 'דייטשלאַנד',
        'DJ' => 'דזשיבוטי',
        'DK' => 'דענמאַרק',
        'DM' => 'דאמיניקע',
        'DO' => 'דאמיניקאַנישע רעפּובליק',
        'EC' => 'עקוואַדאר',
        'EE' => 'עסטלאַנד',
        'EG' => 'עגיפּטן',
        'ER' => 'עריטרעע',
        'ES' => 'שפּאַניע',
        'ET' => 'עטיאפּיע',
        'FI' => 'פֿינלאַנד',
        'FJ' => 'פֿידזשי',
        'FK' => 'פֿאַלקלאַנד אינזלען',
        'FM' => 'מיקראנעזיע',
        'FO' => 'פֿאַרא אינזלען',
        'FR' => 'פֿראַנקרייך',
        'GA' => 'גאַבאן',
        'GB' => 'פֿאַראייניגטע קעניגרייך',
        'GD' => 'גרענאַדאַ',
        'GE' => 'גרוזיע',
        'GF' => 'פֿראַנצויזישע גויאַנע',
        'GG' => 'גערנזי',
        'GH' => 'גהאַנע',
        'GI' => 'גיבראַלטאַר',
        'GL' => 'גרינלאַנד',
        'GM' => 'גאַמביע',
        'GN' => 'גינע',
        'GP' => 'גוואַדעלופ',
        'GQ' => 'עקוואַטארישע גינע',
        'GR' => 'גריכנלאַנד',
        'GT' => 'גוואַטעמאַלע',
        'GU' => 'גוואַם',
        'GW' => 'גינע־ביסאַו',
        'GY' => 'גויאַנע',
        'HN' => 'האנדוראַס',
        'HR' => 'קראאַטיע',
        'HT' => 'האַיטי',
        'HU' => 'אונגערן',
        'ID' => 'אינדאנעזיע',
        'IE' => 'אירלאַנד',
        'IL' => 'ישראל',
        'IN' => 'אינדיע',
        'IR' => 'איראַן',
        'IS' => 'איסלאַנד',
        'IT' => 'איטאַליע',
        'JE' => 'דזשערזי',
        'JM' => 'דזשאַמייקע',
        'JP' => 'יאַפּאַן',
        'KE' => 'קעניע',
        'KH' => 'קאַמבאדיע',
        'KI' => 'קיריבאַטי',
        'KM' => 'קאמאראס',
        'KY' => 'קיימאַן אינזלען',
        'LA' => 'לאַאס',
        'LB' => 'לבנון',
        'LI' => 'ליכטנשטיין',
        'LK' => 'סרי־לאַנקאַ',
        'LR' => 'ליבעריע',
        'LS' => 'לעסאטא',
        'LT' => 'ליטע',
        'LU' => 'לוקסעמבורג',
        'LV' => 'לעטלאַנד',
        'LY' => 'ליביע',
        'MA' => 'מאַראקא',
        'MC' => 'מאנאַקא',
        'MD' => 'מאלדאווע',
        'ME' => 'מאנטענעגרא',
        'MG' => 'מאַדאַגאַסקאַר',
        'MH' => 'מאַרשאַל אינזלען',
        'ML' => 'מאַלי',
        'MM' => 'מיאַנמאַר',
        'MN' => 'מאנגאליי',
        'MQ' => 'מאַרטיניק',
        'MR' => 'מאַריטאַניע',
        'MS' => 'מאנטסעראַט',
        'MT' => 'מאַלטאַ',
        'MU' => 'מאריציוס',
        'MV' => 'מאַלדיוון',
        'MW' => 'מאַלאַווי',
        'MX' => 'מעקסיקע',
        'MY' => 'מאַלייזיע',
        'MZ' => 'מאזאַמביק',
        'NA' => 'נאַמיביע',
        'NC' => 'נײַ קאַלעדאניע',
        'NE' => 'ניזשער',
        'NF' => 'נארפֿאלק אינזל',
        'NG' => 'ניגעריע',
        'NI' => 'ניקאַראַגוע',
        'NL' => 'האלאַנד',
        'NO' => 'נארוועגיע',
        'NP' => 'נעפּאַל',
        'NZ' => 'ניו זילאַנד',
        'PA' => 'פּאַנאַמאַ',
        'PE' => 'פּערו',
        'PF' => 'פֿראַנצויזישע פּאלינעזיע',
        'PG' => 'פּאַפּואַ נײַ גינע',
        'PH' => 'פֿיליפּינען',
        'PK' => 'פּאַקיסטאַן',
        'PL' => 'פּוילן',
        'PN' => 'פּיטקערן אינזלען',
        'PR' => 'פּארטא־ריקא',
        'PT' => 'פּארטוגאַל',
        'PY' => 'פּאַראַגווײַ',
        'QA' => 'קאַטאַר',
        'RE' => 'רעאוניאן',
        'RO' => 'רומעניע',
        'RS' => 'סערביע',
        'RU' => 'רוסלאַנד',
        'RW' => 'רוואַנדע',
        'SB' => 'סאלאמאן אינזלען',
        'SC' => 'סיישעל',
        'SD' => 'סודאַן',
        'SE' => 'שוועדן',
        'SG' => 'סינגאַפּור',
        'SH' => 'סט העלענע',
        'SI' => 'סלאוועניע',
        'SK' => 'סלאוואַקיי',
        'SL' => 'סיערע לעאנע',
        'SM' => 'סאַן מאַרינא',
        'SN' => 'סענעגאַל',
        'SO' => 'סאמאַליע',
        'SR' => 'סורינאַם',
        'SS' => 'דרום־סודאַן',
        'ST' => 'סאַא טאמע און פּרינסיפּע',
        'SV' => 'על סאַלוואַדאר',
        'SY' => 'סיריע',
        'SZ' => 'סוואַזילאַנד',
        'TD' => 'טשאַד',
        'TG' => 'טאגא',
        'TH' => 'טיילאַנד',
        'TL' => 'מזרח טימאר',
        'TM' => 'טורקמעניסטאַן',
        'TN' => 'טוניסיע',
        'TO' => 'טאנגאַ',
        'TR' => 'טערקיי',
        'TT' => 'טרינידאַד און טאבאַגא',
        'TV' => 'טואוואַלו',
        'TZ' => 'טאַנזאַניע',
        'UA' => 'אוקראַינע',
        'UG' => 'אוגאַנדע',
        'US' => 'פֿאַראייניגטע שטאַטן',
        'UY' => 'אורוגוויי',
        'VA' => 'וואַטיקאַן שטאָט',
        'VE' => 'ווענעזועלע',
        'VN' => 'וויעטנאַם',
        'VU' => 'וואַנואַטו',
        'WS' => 'סאַמאאַ',
        'YE' => 'תימן',
        'YT' => 'מאַיאט',
        'ZA' => 'דרום־אַפֿריקע',
        'ZM' => 'זאַמביע',
        'ZW' => 'זימבאַבווע',
    ],
];
