<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'פזטה אנדורית',
        ],
        'AED' => [
            'AED',
            'דירהם של איחוד הנסיכויות הערביות',
        ],
        'AFN' => [
            'AFN',
            'אפגני אפגני',
        ],
        'ALL' => [
            'ALL',
            'לק אלבני',
        ],
        'AMD' => [
            'AMD',
            'דראם ארמני',
        ],
        'ANG' => [
            'ANG',
            'גילדר של האנטילים ההולנדיים',
        ],
        'AOA' => [
            'AOA',
            'קואנזה אנגולי',
        ],
        'AON' => [
            'AON',
            'קואנזה חדש אנגולי (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'קואנזה רג׳וסטדו אנגולי (1995–1999)',
        ],
        'ARP' => [
            'ARP',
            'פזו ארגנטינאי (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'פסו ארגנטינאי',
        ],
        'ATS' => [
            'ATS',
            'שילינג אוסטרי',
        ],
        'AUD' => [
            'A$',
            'דולר אוסטרלי',
        ],
        'AWG' => [
            'AWG',
            'פלורין של ארובה',
        ],
        'AZM' => [
            'AZM',
            'מנאט אזרביג׳אני (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'מאנאט אזרבייג׳ני',
        ],
        'BAD' => [
            'BAD',
            'דינר של בוסניה־הרצגובינה',
        ],
        'BAM' => [
            'BAM',
            'מארק סחיר של בוסניה והרצגובינה',
        ],
        'BBD' => [
            'BBD',
            'דולר ברבדיאני',
        ],
        'BDT' => [
            'BDT',
            'טאקה בנגלדשי',
        ],
        'BEC' => [
            'BEC',
            'פרנק בלגי (בר המרה)',
        ],
        'BEF' => [
            'BEF',
            'פרנק בלגי',
        ],
        'BGL' => [
            'BGL',
            'לב בולגרי ישן',
        ],
        'BGN' => [
            'BGN',
            'לב בולגרי',
        ],
        'BHD' => [
            'BHD',
            'דינר בחרייני',
        ],
        'BIF' => [
            'BIF',
            'פרנק בורונדי',
        ],
        'BMD' => [
            'BMD',
            'דולר ברמודה',
        ],
        'BND' => [
            'BND',
            'דולר ברוניי',
        ],
        'BOB' => [
            'BOB',
            'בוליביאנו',
        ],
        'BOP' => [
            'BOP',
            'פזו בוליבי',
        ],
        'BRB' => [
            'BRB',
            'קרוזיארו חדש ברזילאי (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'קרוזדו ברזילאי',
        ],
        'BRL' => [
            'R$',
            'ריאל ברזילאי',
        ],
        'BSD' => [
            'BSD',
            'דולר בהאמי',
        ],
        'BTN' => [
            'BTN',
            'נגולטרום בהוטני',
        ],
        'BWP' => [
            'BWP',
            'פולה בוטסואני',
        ],
        'BYN' => [
            'BYN',
            'רובל בלרוסי',
        ],
        'BYR' => [
            'BYR',
            'רובל בלרוסי (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'דולר בליזי',
        ],
        'CAD' => [
            'CA$',
            'דולר קנדי',
        ],
        'CDF' => [
            'CDF',
            'פרנק קונגולזי',
        ],
        'CHF' => [
            'CHF',
            'פרנק שוויצרי',
        ],
        'CLP' => [
            'CLP',
            'פסו צ׳ילאני',
        ],
        'CNH' => [
            'CNH',
            'יואן סיני (CNH)',
        ],
        'CNY' => [
            '‎CN¥‎',
            'יואן סיני',
        ],
        'COP' => [
            'COP',
            'פסו קולומביאני',
        ],
        'CRC' => [
            'CRC',
            'קולון קוסטה־ריקני',
        ],
        'CSD' => [
            'CSD',
            'דינר סרבי ישן',
        ],
        'CUC' => [
            'CUC',
            'פסו קובני להמרה',
        ],
        'CUP' => [
            'CUP',
            'פסו קובני',
        ],
        'CVE' => [
            'CVE',
            'אסקודו כף ורדה',
        ],
        'CYP' => [
            'CYP',
            'לירה קפריסאית',
        ],
        'CZK' => [
            'CZK',
            'קורונה צ׳כית',
        ],
        'DDM' => [
            'DDM',
            'מרק מזרח גרמני',
        ],
        'DEM' => [
            'DEM',
            'מרק גרמני',
        ],
        'DJF' => [
            'DJF',
            'פרנק ג׳יבוטי',
        ],
        'DKK' => [
            'DKK',
            'כתר דני',
        ],
        'DOP' => [
            'DOP',
            'פסו דומיניקני',
        ],
        'DZD' => [
            'DZD',
            'דינר אלג׳ירי',
        ],
        'ECS' => [
            'ECS',
            'סוקר אקואדורי',
        ],
        'EEK' => [
            'EEK',
            'קרון אסטוני',
        ],
        'EGP' => [
            'EGP',
            'לירה מצרית',
        ],
        'ERN' => [
            'ERN',
            'נאקפה אריתראי',
        ],
        'ESP' => [
            'ESP',
            'פסטה ספרדי',
        ],
        'ETB' => [
            'ETB',
            'ביר אתיופי',
        ],
        'EUR' => [
            '€',
            'אירו',
        ],
        'FIM' => [
            'FIM',
            'מרק פיני',
        ],
        'FJD' => [
            'FJD',
            'דולר פיג׳י',
        ],
        'FKP' => [
            'FKP',
            'לירה של איי פוקלנד',
        ],
        'FRF' => [
            'FRF',
            'פרנק צרפתי',
        ],
        'GBP' => [
            '£',
            'לירה שטרלינג',
        ],
        'GEL' => [
            'GEL',
            'לארי גאורגי',
        ],
        'GHS' => [
            'GHS',
            'סדי גאני',
        ],
        'GIP' => [
            'GIP',
            'פאונד גיברלטר',
        ],
        'GMD' => [
            'GMD',
            'דלסי גמבי',
        ],
        'GNF' => [
            'GNF',
            'פרנק גינאי',
        ],
        'GRD' => [
            'GRD',
            'דרכמה',
        ],
        'GTQ' => [
            'GTQ',
            'קצאל גואטמלי',
        ],
        'GWP' => [
            'GWP',
            'פזו גינאי',
        ],
        'GYD' => [
            'GYD',
            'דולר גיאני',
        ],
        'HKD' => [
            'HK$',
            'דולר הונג קונגי',
        ],
        'HNL' => [
            'HNL',
            'למפירה הונדורי',
        ],
        'HRK' => [
            'HRK',
            'קונה קרואטי',
        ],
        'HTG' => [
            'HTG',
            'גורד האיטי',
        ],
        'HUF' => [
            'HUF',
            'פורינט הונגרי',
        ],
        'IDR' => [
            'IDR',
            'רופיה אינדונזית',
        ],
        'IEP' => [
            'IEP',
            'לירה אירית',
        ],
        'ILP' => [
            'ל״י',
            'לירה ישראלית',
        ],
        'ILS' => [
            '₪',
            'שקל חדש',
        ],
        'INR' => [
            '₹',
            'רופי הודי',
        ],
        'IQD' => [
            'IQD',
            'דינר עיראקי',
        ],
        'IRR' => [
            'IRR',
            'ריאל איראני',
        ],
        'ISK' => [
            'ISK',
            'כתר איסלנדי',
        ],
        'ITL' => [
            'ITL',
            'לירה איטלקית',
        ],
        'JMD' => [
            'JMD',
            'דולר ג׳מייקני',
        ],
        'JOD' => [
            'JOD',
            'דינר ירדני',
        ],
        'JPY' => [
            '¥',
            'ין יפני',
        ],
        'KES' => [
            'KES',
            'שילינג קנייתי',
        ],
        'KGS' => [
            'KGS',
            'סום קירגיזי',
        ],
        'KHR' => [
            'KHR',
            'ריל קמבודי',
        ],
        'KMF' => [
            'KMF',
            'פרנק קומורואי',
        ],
        'KPW' => [
            'KPW',
            'וון צפון קוריאני',
        ],
        'KRW' => [
            '₩',
            'וון דרום קוריאני',
        ],
        'KWD' => [
            'KWD',
            'דינר כוויתי',
        ],
        'KYD' => [
            'KYD',
            'דולר קיימני',
        ],
        'KZT' => [
            'KZT',
            'טנגה קזחסטני',
        ],
        'LAK' => [
            'LAK',
            'קיפ לאי',
        ],
        'LBP' => [
            'LBP',
            'לירה לבנונית',
        ],
        'LKR' => [
            'LKR',
            'רופי סרי לנקי',
        ],
        'LRD' => [
            'LRD',
            'דולר ליברי',
        ],
        'LSL' => [
            'LSL',
            'לוטי לסותי',
        ],
        'LTL' => [
            'LTL',
            'ליטא ליטאי',
        ],
        'LUF' => [
            'LUF',
            'פרנק לוקסמבורגי',
        ],
        'LVL' => [
            'LVL',
            'לט לטבי',
        ],
        'LYD' => [
            'LYD',
            'דינר לובי',
        ],
        'MAD' => [
            'MAD',
            'דירהם מרוקאי',
        ],
        'MAF' => [
            'MAF',
            'פרנק מרוקאי',
        ],
        'MDL' => [
            'MDL',
            'לאו מולדובני',
        ],
        'MGA' => [
            'MGA',
            'אריארי מלגשי',
        ],
        'MGF' => [
            'MGF',
            'פרנק מדגסקארי',
        ],
        'MKD' => [
            'MKD',
            'דינר מקדוני',
        ],
        'MMK' => [
            'MMK',
            'קיאט מיאנמרי',
        ],
        'MNT' => [
            'MNT',
            'טוגרוג מונגולי',
        ],
        'MOP' => [
            'MOP',
            'פטקה של מקאו',
        ],
        'MRO' => [
            'MRO',
            'אואוגויה מאוריטני (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'אואוגויה מאוריטני',
        ],
        'MTL' => [
            'MTL',
            'לירה מלטית',
        ],
        'MUR' => [
            'MUR',
            'רופי מאוריציני',
        ],
        'MVR' => [
            'MVR',
            'רופיה מלדיבית',
        ],
        'MWK' => [
            'MWK',
            'קואצ׳ה מלאווי',
        ],
        'MXN' => [
            'MX$',
            'פסו מקסיקני',
        ],
        'MXP' => [
            'MXP',
            'פזו מקסיקני (1861 – 1992)',
        ],
        'MXV' => [
            'MXV',
            'יחידת השקעות מקסיקנית',
        ],
        'MYR' => [
            'MYR',
            'רינגיט מלזי',
        ],
        'MZE' => [
            'MZE',
            'אסקודו מוזמביקי',
        ],
        'MZM' => [
            'MZM',
            'מטיקל',
        ],
        'MZN' => [
            'MZN',
            'מטיקל מוזמביני',
        ],
        'NAD' => [
            'NAD',
            'דולר נמיבי',
        ],
        'NGN' => [
            'NGN',
            'נאירה ניגרי',
        ],
        'NIC' => [
            'NIC',
            'קורדובה (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'קורדובה ניקרגואה',
        ],
        'NLG' => [
            'NLG',
            'גילדן הולנדי',
        ],
        'NOK' => [
            'NOK',
            'כתר נורווגי',
        ],
        'NPR' => [
            'NPR',
            'רופי נפאלי',
        ],
        'NZD' => [
            'NZ$',
            'דולר ניו זילנדי',
        ],
        'OMR' => [
            'OMR',
            'ריאל עומאני',
        ],
        'PAB' => [
            'PAB',
            'בלבואה פנמי',
        ],
        'PEN' => [
            'PEN',
            'סול פרואני',
        ],
        'PGK' => [
            'PGK',
            'קינה של פפואה גינאה החדשה',
        ],
        'PHP' => [
            'PHP',
            'פסו פיליפיני',
        ],
        'PKR' => [
            'PKR',
            'רופי פקיסטני',
        ],
        'PLN' => [
            'PLN',
            'זלוטי פולני',
        ],
        'PTE' => [
            'PTE',
            'אסקודו פורטוגלי',
        ],
        'PYG' => [
            'PYG',
            'גוארני פרגוואי',
        ],
        'QAR' => [
            'QAR',
            'ריאל קטארי',
        ],
        'ROL' => [
            'ROL',
            'לאו רומני ישן',
        ],
        'RON' => [
            'RON',
            'לאו רומני',
        ],
        'RSD' => [
            'RSD',
            'דינר סרבי',
        ],
        'RUB' => [
            'RUB',
            'רובל רוסי',
        ],
        'RUR' => [
            'RUR',
            'רובל רוסי (1991 – 1998)',
        ],
        'RWF' => [
            'RWF',
            'פרנק רואנדי',
        ],
        'SAR' => [
            'SAR',
            'ריאל סעודי',
        ],
        'SBD' => [
            'SBD',
            'דולר איי שלמה',
        ],
        'SCR' => [
            'SCR',
            'רופי סיישלי',
        ],
        'SDD' => [
            'SDD',
            'דינר סודני',
        ],
        'SDG' => [
            'SDG',
            'לירה סודנית',
        ],
        'SDP' => [
            'SDP',
            'לירה סודנית (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'כתר שוודי',
        ],
        'SGD' => [
            'SGD',
            'דולר סינגפורי',
        ],
        'SHP' => [
            'SHP',
            'פאונד סנט הלני',
        ],
        'SIT' => [
            'SIT',
            'טולאר סלובני',
        ],
        'SKK' => [
            'SKK',
            'קורונה סלובקי',
        ],
        'SLE' => [
            'SLE',
            'ליאון סיירה לאוני',
        ],
        'SLL' => [
            'SLL',
            'ליאון סיירה לאוני - 1964-2022',
        ],
        'SOS' => [
            'SOS',
            'שילינג סומלי',
        ],
        'SRD' => [
            'SRD',
            'דולר סורינאמי',
        ],
        'SRG' => [
            'SRG',
            'גילדר סורינאמי',
        ],
        'SSP' => [
            'SSP',
            'לירה דרום-סודנית',
        ],
        'STD' => [
            'STD',
            'דוברה של סן טומה ופרינסיפה (1977–2017)',
        ],
        'STN' => [
            'STN',
            'דוברה של סאו טומה ופרינסיפה',
        ],
        'SUR' => [
            'SUR',
            'רובל סובייטי',
        ],
        'SVC' => [
            'SVC',
            'קולון סלבדורי',
        ],
        'SYP' => [
            'SYP',
            'לירה סורית',
        ],
        'SZL' => [
            'SZL',
            'לילנגני סווזילנדי',
        ],
        'THB' => [
            '฿',
            'בהט תאילנדי',
        ],
        'TJS' => [
            'TJS',
            'סומוני טג׳קיסטני',
        ],
        'TMM' => [
            'TMM',
            'מנאט טורקמאני',
        ],
        'TMT' => [
            'TMT',
            'מאנאט טורקמני',
        ],
        'TND' => [
            'TND',
            'דינר טוניסאי',
        ],
        'TOP' => [
            'TOP',
            'פאנגה טונגי',
        ],
        'TPE' => [
            'TPE',
            'אסקודו טימוראי',
        ],
        'TRL' => [
            'TRL',
            'לירה טורקית',
        ],
        'TRY' => [
            'TRY',
            'לירה טורקית חדשה',
        ],
        'TTD' => [
            'TTD',
            'דולר טרינידדי',
        ],
        'TWD' => [
            'NT$',
            'דולר טייוואני חדש',
        ],
        'TZS' => [
            'TZS',
            'שילינג טנזני',
        ],
        'UAH' => [
            'UAH',
            'הריבנה אוקראיני',
        ],
        'UGS' => [
            'UGS',
            'שילינג אוגנדי (1966 – 1987)',
        ],
        'UGX' => [
            'UGX',
            'שילינג אוגנדי',
        ],
        'USD' => [
            '$',
            'דולר אמריקאי',
        ],
        'USN' => [
            'USN',
            'דולר אמריקאי (היום הבא)',
        ],
        'USS' => [
            'USS',
            'דולר אמריקאי (היום הזה)',
        ],
        'UYU' => [
            'UYU',
            'פסו אורוגוואי',
        ],
        'UZS' => [
            'UZS',
            'סום אוזבקי',
        ],
        'VEB' => [
            'VEB',
            'בוליבר ונצואלי (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'בוליבר ונצואלי (2008–2018)',
        ],
        'VES' => [
            'VES',
            'בוליבר ונצואלי',
        ],
        'VND' => [
            '₫',
            'דונג וייטנאמי',
        ],
        'VUV' => [
            'VUV',
            'ואטו של ונואטו',
        ],
        'WST' => [
            'WST',
            'טאלה סמואי',
        ],
        'XAF' => [
            'FCFA',
            'פרנק CFA מרכז אפריקני',
        ],
        'XCD' => [
            'EC$',
            'דולר מזרח קריבי',
        ],
        'XCG' => [
            'Cg.',
            'גילדר של הקריביים',
        ],
        'XFO' => [
            'XFO',
            'פרנק זהב',
        ],
        'XOF' => [
            'F CFA',
            'פרנק CFA מערב אפריקני',
        ],
        'XPF' => [
            'CFPF',
            'פרנק פולינזיה הצרפתית',
        ],
        'YDD' => [
            'YDD',
            'דינר תימני',
        ],
        'YER' => [
            'YER',
            'ריאל תימני',
        ],
        'ZAL' => [
            'ZAL',
            'ראנד דרום אפריקאי (כספי)',
        ],
        'ZAR' => [
            'ZAR',
            'ראנד דרום אפריקאי',
        ],
        'ZMK' => [
            'ZMK',
            'קוואצ׳ה זמבית (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'קוואצ׳ה זמבי',
        ],
        'ZRN' => [
            'ZRN',
            'זאיר חדש',
        ],
        'ZWD' => [
            'ZWD',
            'דולר זימבבואי',
        ],
        'ZWG' => [
            'ZWG',
            'זהב של זימבבואה',
        ],
    ],
];
