<?php

return [
    'Names' => [
        'agq' => 'Èdè Ágɛ̀ɛ̀mù',
        'bal' => 'Èdè Belúshì',
        'bez' => 'Èdè Bɛ́nà',
        'chr' => 'Èdè Shɛ́rókiì',
        'cu' => 'Èdè Síláfííkì Ilé Ìjɔ́sìn',
        'cv' => 'Èdè Shufasi',
        'dje' => 'Shárúmà',
        'dsb' => 'Shóbíánù Apá Ìshàlɛ̀',
        'ebu' => 'Èdè Ɛmbù',
        'en' => 'Èdè Gɛ̀ɛ́sì',
        'es' => 'Èdè Sípáníìshì',
        'gez' => 'Ede Gɛ́sì',
        'id' => 'Èdè Indonéshíà',
        'ie' => 'Èdè àtɔwɔ́dá',
        'ii' => 'Shíkuán Yì',
        'jmc' => 'Máshámè',
        'khq' => 'Koira Shíínì',
        'kk' => 'Kashakì',
        'kln' => 'Kálɛnjín',
        'ks' => 'Kashímirì',
        'ksb' => 'Sháńbálà',
        'ku' => 'Kɔdishì',
        'kw' => 'Èdè Kɔ́nììshì',
        'lb' => 'Lùshɛ́mbɔ́ɔ̀gì',
        'nb' => 'Nɔ́ɔ́wè Bokímàl',
        'nds' => 'Jámánì ìpìlɛ̀',
        'nl' => 'Èdè Dɔ́ɔ̀shì',
        'nmg' => 'Kíwáshíò',
        'nn' => 'Nɔ́ɔ́wè Nínɔ̀sìkì',
        'nus' => 'Núɛ̀',
        'nyn' => 'Ńyákɔ́lè',
        'oc' => 'Èdè Ɔ̀kísítáànì',
        'om' => 'Òròmɔ́',
        'os' => 'Ɔshɛ́tíìkì',
        'prg' => 'Púrúshíànù',
        'pt' => 'Èdè Pɔtogí',
        'qu' => 'Kúɛ́ńjùà',
        'rm' => 'Rómáǹshì',
        'ru' => 'Èdè Rɔ́shíà',
        'seh' => 'Shɛnà',
        'shi' => 'Tashelíìtì',
        'sn' => 'Shɔnà',
        'szl' => 'Silìshíànì',
        'teo' => 'Tɛ́sò',
        'tr' => 'Èdè Tɔɔkisi',
        'ug' => 'Yúgɔ̀',
        'vec' => 'Fènéshìànì',
        'vo' => 'Fɔ́lápùùkù',
        'wae' => 'Wɔsà',
        'wo' => 'Wɔ́lɔ́ɔ̀fù',
        'xog' => 'Shógà',
        'yav' => 'Yangbɛn',
        'za' => 'Shúwáànù',
        'zgh' => 'Àfɛnùkò Támásáìtì ti Mòrókò',
        'zh' => 'Edè Sháínà',
        'zu' => 'Èdè Shulu',
    ],
    'LocalizedNames' => [
        'de_AT' => 'Èdè Jámánì (Ɔ́síríà )',
        'de_CH' => 'Èdè Ilɛ̀ Jámánì (Orílɛ́ède swítsàlandì)',
        'en_AU' => 'Èdè Gɛ̀ɛ́sì (órílɛ̀-èdè Ɔsirélíà)',
        'en_CA' => 'Èdè Gɛ̀ɛ́sì (Orílɛ̀-èdè Kánádà)',
        'en_GB' => 'Èdè òyìnbó Gɛ̀ɛ́sì',
        'es_419' => 'Èdè Sípáníìshì (orílɛ̀-èdè Látìn-Amɛ́ríkà)',
        'es_ES' => 'Èdè Sípáníìshì (orílɛ̀-èdè Yúróòpù)',
        'es_MX' => 'Èdè Sípáníìshì (orílɛ̀-èdè Mɛ́síkò)',
        'fr_CA' => 'Èdè Faransé (orílɛ̀-èdè Kánádà)',
        'fr_CH' => 'Èdè Faranshé (Súwísàlaǹdì)',
        'nl_BE' => 'Èdè Flemishi',
        'pt_BR' => 'Èdè Pɔtogí (Orilɛ̀-èdè Bràsíl)',
        'pt_PT' => 'Èdè Pɔtogí (orílɛ̀-èdè Yúróòpù)',
        'zh_Hans' => 'Ɛdè Sháínà Onírɔ̀rùn',
        'zh_Hant' => 'Èdè Sháínà Ìbílɛ̀',
    ],
];
