<?php

return [
    'Names' => [
        'af' => '南非荷兰语',
        'af_NA' => '南非荷兰语（纳米比亚）',
        'af_ZA' => '南非荷兰语（南非）',
        'ak' => '阿肯语',
        'ak_GH' => '阿肯语（加纳）',
        'am' => '阿姆哈拉语',
        'am_ET' => '阿姆哈拉语（埃塞俄比亚）',
        'ar' => '阿拉伯语',
        'ar_001' => '阿拉伯语（世界）',
        'ar_AE' => '阿拉伯语（阿拉伯联合酋长国）',
        'ar_BH' => '阿拉伯语（巴林）',
        'ar_DJ' => '阿拉伯语（吉布提）',
        'ar_DZ' => '阿拉伯语（阿尔及利亚）',
        'ar_EG' => '阿拉伯语（埃及）',
        'ar_EH' => '阿拉伯语（西撒哈拉）',
        'ar_ER' => '阿拉伯语（厄立特里亚）',
        'ar_IL' => '阿拉伯语（以色列）',
        'ar_IQ' => '阿拉伯语（伊拉克）',
        'ar_JO' => '阿拉伯语（约旦）',
        'ar_KM' => '阿拉伯语（科摩罗）',
        'ar_KW' => '阿拉伯语（科威特）',
        'ar_LB' => '阿拉伯语（黎巴嫩）',
        'ar_LY' => '阿拉伯语（利比亚）',
        'ar_MA' => '阿拉伯语（摩洛哥）',
        'ar_MR' => '阿拉伯语（毛里塔尼亚）',
        'ar_OM' => '阿拉伯语（阿曼）',
        'ar_PS' => '阿拉伯语（巴勒斯坦领土）',
        'ar_QA' => '阿拉伯语（卡塔尔）',
        'ar_SA' => '阿拉伯语（沙特阿拉伯）',
        'ar_SD' => '阿拉伯语（苏丹）',
        'ar_SO' => '阿拉伯语（索马里）',
        'ar_SS' => '阿拉伯语（南苏丹）',
        'ar_SY' => '阿拉伯语（叙利亚）',
        'ar_TD' => '阿拉伯语（乍得）',
        'ar_TN' => '阿拉伯语（突尼斯）',
        'ar_YE' => '阿拉伯语（也门）',
        'as' => '阿萨姆语',
        'as_IN' => '阿萨姆语（印度）',
        'az' => '阿塞拜疆语',
        'az_AZ' => '阿塞拜疆语（阿塞拜疆）',
        'az_Cyrl' => '阿塞拜疆语（西里尔文）',
        'az_Cyrl_AZ' => '阿塞拜疆语（西里尔文，阿塞拜疆）',
        'az_Latn' => '阿塞拜疆语（拉丁文）',
        'az_Latn_AZ' => '阿塞拜疆语（拉丁文，阿塞拜疆）',
        'ba' => '巴什基尔语',
        'ba_RU' => '巴什基尔语（俄罗斯）',
        'be' => '白俄罗斯语',
        'be_BY' => '白俄罗斯语（白俄罗斯）',
        'bg' => '保加利亚语',
        'bg_BG' => '保加利亚语（保加利亚）',
        'bm' => '班巴拉语',
        'bm_ML' => '班巴拉语（马里）',
        'bn' => '孟加拉语',
        'bn_BD' => '孟加拉语（孟加拉国）',
        'bn_IN' => '孟加拉语（印度）',
        'bo' => '藏语',
        'bo_CN' => '藏语（中国）',
        'bo_IN' => '藏语（印度）',
        'br' => '布列塔尼语',
        'br_FR' => '布列塔尼语（法国）',
        'bs' => '波斯尼亚语',
        'bs_BA' => '波斯尼亚语（波斯尼亚和黑塞哥维那）',
        'bs_Cyrl' => '波斯尼亚语（西里尔文）',
        'bs_Cyrl_BA' => '波斯尼亚语（西里尔文，波斯尼亚和黑塞哥维那）',
        'bs_Latn' => '波斯尼亚语（拉丁文）',
        'bs_Latn_BA' => '波斯尼亚语（拉丁文，波斯尼亚和黑塞哥维那）',
        'ca' => '加泰罗尼亚语',
        'ca_AD' => '加泰罗尼亚语（安道尔）',
        'ca_ES' => '加泰罗尼亚语（西班牙）',
        'ca_FR' => '加泰罗尼亚语（法国）',
        'ca_IT' => '加泰罗尼亚语（意大利）',
        'ce' => '车臣语',
        'ce_RU' => '车臣语（俄罗斯）',
        'cs' => '捷克语',
        'cs_CZ' => '捷克语（捷克）',
        'cv' => '楚瓦什语',
        'cv_RU' => '楚瓦什语（俄罗斯）',
        'cy' => '威尔士语',
        'cy_GB' => '威尔士语（英国）',
        'da' => '丹麦语',
        'da_DK' => '丹麦语（丹麦）',
        'da_GL' => '丹麦语（格陵兰）',
        'de' => '德语',
        'de_AT' => '德语（奥地利）',
        'de_BE' => '德语（比利时）',
        'de_CH' => '德语（瑞士）',
        'de_DE' => '德语（德国）',
        'de_IT' => '德语（意大利）',
        'de_LI' => '德语（列支敦士登）',
        'de_LU' => '德语（卢森堡）',
        'dz' => '宗卡语',
        'dz_BT' => '宗卡语（不丹）',
        'ee' => '埃维语',
        'ee_GH' => '埃维语（加纳）',
        'ee_TG' => '埃维语（多哥）',
        'el' => '希腊语',
        'el_CY' => '希腊语（塞浦路斯）',
        'el_GR' => '希腊语（希腊）',
        'en' => '英语',
        'en_001' => '英语（世界）',
        'en_150' => '英语（欧洲）',
        'en_AE' => '英语（阿拉伯联合酋长国）',
        'en_AG' => '英语（安提瓜和巴布达）',
        'en_AI' => '英语（安圭拉）',
        'en_AS' => '英语（美属萨摩亚）',
        'en_AT' => '英语（奥地利）',
        'en_AU' => '英语（澳大利亚）',
        'en_BB' => '英语（巴巴多斯）',
        'en_BE' => '英语（比利时）',
        'en_BI' => '英语（布隆迪）',
        'en_BM' => '英语（百慕大）',
        'en_BS' => '英语（巴哈马）',
        'en_BW' => '英语（博茨瓦纳）',
        'en_BZ' => '英语（伯利兹）',
        'en_CA' => '英语（加拿大）',
        'en_CC' => '英语（科科斯（基林）群岛）',
        'en_CH' => '英语（瑞士）',
        'en_CK' => '英语（库克群岛）',
        'en_CM' => '英语（喀麦隆）',
        'en_CX' => '英语（圣诞岛）',
        'en_CY' => '英语（塞浦路斯）',
        'en_CZ' => '英语（捷克）',
        'en_DE' => '英语（德国）',
        'en_DK' => '英语（丹麦）',
        'en_DM' => '英语（多米尼克）',
        'en_EE' => '英语（爱沙尼亚）',
        'en_ER' => '英语（厄立特里亚）',
        'en_ES' => '英语（西班牙）',
        'en_FI' => '英语（芬兰）',
        'en_FJ' => '英语（斐济）',
        'en_FK' => '英语（福克兰群岛）',
        'en_FM' => '英语（密克罗尼西亚）',
        'en_FR' => '英语（法国）',
        'en_GB' => '英语（英国）',
        'en_GD' => '英语（格林纳达）',
        'en_GE' => '英语（格鲁吉亚）',
        'en_GG' => '英语（根西岛）',
        'en_GH' => '英语（加纳）',
        'en_GI' => '英语（直布罗陀）',
        'en_GM' => '英语（冈比亚）',
        'en_GS' => '英语（南乔治亚和南桑威奇群岛）',
        'en_GU' => '英语（关岛）',
        'en_GY' => '英语（圭亚那）',
        'en_HK' => '英语（中国香港特别行政区）',
        'en_HU' => '英语（匈牙利）',
        'en_ID' => '英语（印度尼西亚）',
        'en_IE' => '英语（爱尔兰）',
        'en_IL' => '英语（以色列）',
        'en_IM' => '英语（马恩岛）',
        'en_IN' => '英语（印度）',
        'en_IO' => '英语（英属印度洋领地）',
        'en_IT' => '英语（意大利）',
        'en_JE' => '英语（泽西岛）',
        'en_JM' => '英语（牙买加）',
        'en_JP' => '英语（日本）',
        'en_KE' => '英语（肯尼亚）',
        'en_KI' => '英语（基里巴斯）',
        'en_KN' => '英语（圣基茨和尼维斯）',
        'en_KY' => '英语（开曼群岛）',
        'en_LC' => '英语（圣卢西亚）',
        'en_LR' => '英语（利比里亚）',
        'en_LS' => '英语（莱索托）',
        'en_LT' => '英语（立陶宛）',
        'en_LV' => '英语（拉脱维亚）',
        'en_MG' => '英语（马达加斯加）',
        'en_MH' => '英语（马绍尔群岛）',
        'en_MO' => '英语（中国澳门特别行政区）',
        'en_MP' => '英语（北马里亚纳群岛）',
        'en_MS' => '英语（蒙特塞拉特）',
        'en_MT' => '英语（马耳他）',
        'en_MU' => '英语（毛里求斯）',
        'en_MV' => '英语（马尔代夫）',
        'en_MW' => '英语（马拉维）',
        'en_MY' => '英语（马来西亚）',
        'en_NA' => '英语（纳米比亚）',
        'en_NF' => '英语（诺福克岛）',
        'en_NG' => '英语（尼日利亚）',
        'en_NL' => '英语（荷兰）',
        'en_NO' => '英语（挪威）',
        'en_NR' => '英语（瑙鲁）',
        'en_NU' => '英语（纽埃）',
        'en_NZ' => '英语（新西兰）',
        'en_PG' => '英语（巴布亚新几内亚）',
        'en_PH' => '英语（菲律宾）',
        'en_PK' => '英语（巴基斯坦）',
        'en_PL' => '英语（波兰）',
        'en_PN' => '英语（皮特凯恩群岛）',
        'en_PR' => '英语（波多黎各）',
        'en_PT' => '英语（葡萄牙）',
        'en_PW' => '英语（帕劳）',
        'en_RO' => '英语（罗马尼亚）',
        'en_RW' => '英语（卢旺达）',
        'en_SB' => '英语（所罗门群岛）',
        'en_SC' => '英语（塞舌尔）',
        'en_SD' => '英语（苏丹）',
        'en_SE' => '英语（瑞典）',
        'en_SG' => '英语（新加坡）',
        'en_SH' => '英语（圣赫勒拿）',
        'en_SI' => '英语（斯洛文尼亚）',
        'en_SK' => '英语（斯洛伐克）',
        'en_SL' => '英语（塞拉利昂）',
        'en_SS' => '英语（南苏丹）',
        'en_SX' => '英语（荷属圣马丁）',
        'en_SZ' => '英语（斯威士兰）',
        'en_TC' => '英语（特克斯和凯科斯群岛）',
        'en_TK' => '英语（托克劳）',
        'en_TO' => '英语（汤加）',
        'en_TT' => '英语（特立尼达和多巴哥）',
        'en_TV' => '英语（图瓦卢）',
        'en_TZ' => '英语（坦桑尼亚）',
        'en_UA' => '英语（乌克兰）',
        'en_UG' => '英语（乌干达）',
        'en_UM' => '英语（美国本土外小岛屿）',
        'en_US' => '英语（美国）',
        'en_VC' => '英语（圣文森特和格林纳丁斯）',
        'en_VG' => '英语（英属维尔京群岛）',
        'en_VI' => '英语（美属维尔京群岛）',
        'en_VU' => '英语（瓦努阿图）',
        'en_WS' => '英语（萨摩亚）',
        'en_ZA' => '英语（南非）',
        'en_ZM' => '英语（赞比亚）',
        'en_ZW' => '英语（津巴布韦）',
        'eo' => '世界语',
        'eo_001' => '世界语（世界）',
        'es' => '西班牙语',
        'es_419' => '西班牙语（拉丁美洲）',
        'es_AR' => '西班牙语（阿根廷）',
        'es_BO' => '西班牙语（玻利维亚）',
        'es_BR' => '西班牙语（巴西）',
        'es_BZ' => '西班牙语（伯利兹）',
        'es_CL' => '西班牙语（智利）',
        'es_CO' => '西班牙语（哥伦比亚）',
        'es_CR' => '西班牙语（哥斯达黎加）',
        'es_CU' => '西班牙语（古巴）',
        'es_DO' => '西班牙语（多米尼加共和国）',
        'es_EC' => '西班牙语（厄瓜多尔）',
        'es_ES' => '西班牙语（西班牙）',
        'es_GQ' => '西班牙语（赤道几内亚）',
        'es_GT' => '西班牙语（危地马拉）',
        'es_HN' => '西班牙语（洪都拉斯）',
        'es_MX' => '西班牙语（墨西哥）',
        'es_NI' => '西班牙语（尼加拉瓜）',
        'es_PA' => '西班牙语（巴拿马）',
        'es_PE' => '西班牙语（秘鲁）',
        'es_PH' => '西班牙语（菲律宾）',
        'es_PR' => '西班牙语（波多黎各）',
        'es_PY' => '西班牙语（巴拉圭）',
        'es_SV' => '西班牙语（萨尔瓦多）',
        'es_US' => '西班牙语（美国）',
        'es_UY' => '西班牙语（乌拉圭）',
        'es_VE' => '西班牙语（委内瑞拉）',
        'et' => '爱沙尼亚语',
        'et_EE' => '爱沙尼亚语（爱沙尼亚）',
        'eu' => '巴斯克语',
        'eu_ES' => '巴斯克语（西班牙）',
        'fa' => '波斯语',
        'fa_AF' => '波斯语（阿富汗）',
        'fa_IR' => '波斯语（伊朗）',
        'ff' => '富拉语',
        'ff_Adlm' => '富拉语（阿德拉姆文）',
        'ff_Adlm_BF' => '富拉语（阿德拉姆文，布基纳法索）',
        'ff_Adlm_CM' => '富拉语（阿德拉姆文，喀麦隆）',
        'ff_Adlm_GH' => '富拉语（阿德拉姆文，加纳）',
        'ff_Adlm_GM' => '富拉语（阿德拉姆文，冈比亚）',
        'ff_Adlm_GN' => '富拉语（阿德拉姆文，几内亚）',
        'ff_Adlm_GW' => '富拉语（阿德拉姆文，几内亚比绍）',
        'ff_Adlm_LR' => '富拉语（阿德拉姆文，利比里亚）',
        'ff_Adlm_MR' => '富拉语（阿德拉姆文，毛里塔尼亚）',
        'ff_Adlm_NE' => '富拉语（阿德拉姆文，尼日尔）',
        'ff_Adlm_NG' => '富拉语（阿德拉姆文，尼日利亚）',
        'ff_Adlm_SL' => '富拉语（阿德拉姆文，塞拉利昂）',
        'ff_Adlm_SN' => '富拉语（阿德拉姆文，塞内加尔）',
        'ff_CM' => '富拉语（喀麦隆）',
        'ff_GN' => '富拉语（几内亚）',
        'ff_Latn' => '富拉语（拉丁文）',
        'ff_Latn_BF' => '富拉语（拉丁文，布基纳法索）',
        'ff_Latn_CM' => '富拉语（拉丁文，喀麦隆）',
        'ff_Latn_GH' => '富拉语（拉丁文，加纳）',
        'ff_Latn_GM' => '富拉语（拉丁文，冈比亚）',
        'ff_Latn_GN' => '富拉语（拉丁文，几内亚）',
        'ff_Latn_GW' => '富拉语（拉丁文，几内亚比绍）',
        'ff_Latn_LR' => '富拉语（拉丁文，利比里亚）',
        'ff_Latn_MR' => '富拉语（拉丁文，毛里塔尼亚）',
        'ff_Latn_NE' => '富拉语（拉丁文，尼日尔）',
        'ff_Latn_NG' => '富拉语（拉丁文，尼日利亚）',
        'ff_Latn_SL' => '富拉语（拉丁文，塞拉利昂）',
        'ff_Latn_SN' => '富拉语（拉丁文，塞内加尔）',
        'ff_MR' => '富拉语（毛里塔尼亚）',
        'ff_SN' => '富拉语（塞内加尔）',
        'fi' => '芬兰语',
        'fi_FI' => '芬兰语（芬兰）',
        'fo' => '法罗语',
        'fo_DK' => '法罗语（丹麦）',
        'fo_FO' => '法罗语（法罗群岛）',
        'fr' => '法语',
        'fr_BE' => '法语（比利时）',
        'fr_BF' => '法语（布基纳法索）',
        'fr_BI' => '法语（布隆迪）',
        'fr_BJ' => '法语（贝宁）',
        'fr_BL' => '法语（圣巴泰勒米）',
        'fr_CA' => '法语（加拿大）',
        'fr_CD' => '法语（刚果（金））',
        'fr_CF' => '法语（中非共和国）',
        'fr_CG' => '法语（刚果（布））',
        'fr_CH' => '法语（瑞士）',
        'fr_CI' => '法语（科特迪瓦）',
        'fr_CM' => '法语（喀麦隆）',
        'fr_DJ' => '法语（吉布提）',
        'fr_DZ' => '法语（阿尔及利亚）',
        'fr_FR' => '法语（法国）',
        'fr_GA' => '法语（加蓬）',
        'fr_GF' => '法语（法属圭亚那）',
        'fr_GN' => '法语（几内亚）',
        'fr_GP' => '法语（瓜德罗普）',
        'fr_GQ' => '法语（赤道几内亚）',
        'fr_HT' => '法语（海地）',
        'fr_KM' => '法语（科摩罗）',
        'fr_LU' => '法语（卢森堡）',
        'fr_MA' => '法语（摩洛哥）',
        'fr_MC' => '法语（摩纳哥）',
        'fr_MF' => '法语（法属圣马丁）',
        'fr_MG' => '法语（马达加斯加）',
        'fr_ML' => '法语（马里）',
        'fr_MQ' => '法语（马提尼克）',
        'fr_MR' => '法语（毛里塔尼亚）',
        'fr_MU' => '法语（毛里求斯）',
        'fr_NC' => '法语（新喀里多尼亚）',
        'fr_NE' => '法语（尼日尔）',
        'fr_PF' => '法语（法属波利尼西亚）',
        'fr_PM' => '法语（圣皮埃尔和密克隆群岛）',
        'fr_RE' => '法语（留尼汪）',
        'fr_RW' => '法语（卢旺达）',
        'fr_SC' => '法语（塞舌尔）',
        'fr_SN' => '法语（塞内加尔）',
        'fr_SY' => '法语（叙利亚）',
        'fr_TD' => '法语（乍得）',
        'fr_TG' => '法语（多哥）',
        'fr_TN' => '法语（突尼斯）',
        'fr_VU' => '法语（瓦努阿图）',
        'fr_WF' => '法语（瓦利斯和富图纳）',
        'fr_YT' => '法语（马约特）',
        'fy' => '西弗里西亚语',
        'fy_NL' => '西弗里西亚语（荷兰）',
        'ga' => '爱尔兰语',
        'ga_GB' => '爱尔兰语（英国）',
        'ga_IE' => '爱尔兰语（爱尔兰）',
        'gd' => '苏格兰盖尔语',
        'gd_GB' => '苏格兰盖尔语（英国）',
        'gl' => '加利西亚语',
        'gl_ES' => '加利西亚语（西班牙）',
        'gu' => '古吉拉特语',
        'gu_IN' => '古吉拉特语（印度）',
        'gv' => '马恩语',
        'gv_IM' => '马恩语（马恩岛）',
        'ha' => '豪萨语',
        'ha_GH' => '豪萨语（加纳）',
        'ha_NE' => '豪萨语（尼日尔）',
        'ha_NG' => '豪萨语（尼日利亚）',
        'he' => '希伯来语',
        'he_IL' => '希伯来语（以色列）',
        'hi' => '印地语',
        'hi_IN' => '印地语（印度）',
        'hi_Latn' => '印地语（拉丁文）',
        'hi_Latn_IN' => '印地语（拉丁文，印度）',
        'hr' => '克罗地亚语',
        'hr_BA' => '克罗地亚语（波斯尼亚和黑塞哥维那）',
        'hr_HR' => '克罗地亚语（克罗地亚）',
        'hu' => '匈牙利语',
        'hu_HU' => '匈牙利语（匈牙利）',
        'hy' => '亚美尼亚语',
        'hy_AM' => '亚美尼亚语（亚美尼亚）',
        'ia' => '国际语',
        'ia_001' => '国际语（世界）',
        'id' => '印度尼西亚语',
        'id_ID' => '印度尼西亚语（印度尼西亚）',
        'ie' => '国际文字（E）',
        'ie_EE' => '国际文字（E）（爱沙尼亚）',
        'ig' => '伊博语',
        'ig_NG' => '伊博语（尼日利亚）',
        'ii' => '凉山彝语',
        'ii_CN' => '凉山彝语（中国）',
        'is' => '冰岛语',
        'is_IS' => '冰岛语（冰岛）',
        'it' => '意大利语',
        'it_CH' => '意大利语（瑞士）',
        'it_IT' => '意大利语（意大利）',
        'it_SM' => '意大利语（圣马力诺）',
        'it_VA' => '意大利语（梵蒂冈）',
        'ja' => '日语',
        'ja_JP' => '日语（日本）',
        'jv' => '爪哇语',
        'jv_ID' => '爪哇语（印度尼西亚）',
        'ka' => '格鲁吉亚语',
        'ka_GE' => '格鲁吉亚语（格鲁吉亚）',
        'ki' => '吉库尤语',
        'ki_KE' => '吉库尤语（肯尼亚）',
        'kk' => '哈萨克语',
        'kk_Arab' => '哈萨克语（阿拉伯文）',
        'kk_Arab_CN' => '哈萨克语（阿拉伯文，中国）',
        'kk_Cyrl' => '哈萨克语（西里尔文）',
        'kk_Cyrl_KZ' => '哈萨克语（西里尔文，哈萨克斯坦）',
        'kk_KZ' => '哈萨克语（哈萨克斯坦）',
        'kl' => '格陵兰语',
        'kl_GL' => '格陵兰语（格陵兰）',
        'km' => '高棉语',
        'km_KH' => '高棉语（柬埔寨）',
        'kn' => '卡纳达语',
        'kn_IN' => '卡纳达语（印度）',
        'ko' => '韩语',
        'ko_CN' => '韩语（中国）',
        'ko_KP' => '韩语（朝鲜）',
        'ko_KR' => '韩语（韩国）',
        'ks' => '克什米尔语',
        'ks_Arab' => '克什米尔语（阿拉伯文）',
        'ks_Arab_IN' => '克什米尔语（阿拉伯文，印度）',
        'ks_Deva' => '克什米尔语（天城文）',
        'ks_Deva_IN' => '克什米尔语（天城文，印度）',
        'ks_IN' => '克什米尔语（印度）',
        'ku' => '库尔德语',
        'ku_Latn' => '库尔德语（拉丁文）',
        'ku_Latn_IQ' => '库尔德语（拉丁文，伊拉克）',
        'ku_Latn_SY' => '库尔德语（拉丁文，叙利亚）',
        'ku_Latn_TR' => '库尔德语（拉丁文，土耳其）',
        'ku_SY' => '库尔德语（叙利亚）',
        'ku_TR' => '库尔德语（土耳其）',
        'kw' => '康沃尔语',
        'kw_GB' => '康沃尔语（英国）',
        'ky' => '吉尔吉斯语',
        'ky_KG' => '吉尔吉斯语（吉尔吉斯斯坦）',
        'lb' => '卢森堡语',
        'lb_LU' => '卢森堡语（卢森堡）',
        'lg' => '卢干达语',
        'lg_UG' => '卢干达语（乌干达）',
        'ln' => '林加拉语',
        'ln_AO' => '林加拉语（安哥拉）',
        'ln_CD' => '林加拉语（刚果（金））',
        'ln_CF' => '林加拉语（中非共和国）',
        'ln_CG' => '林加拉语（刚果（布））',
        'lo' => '老挝语',
        'lo_LA' => '老挝语（老挝）',
        'lt' => '立陶宛语',
        'lt_LT' => '立陶宛语（立陶宛）',
        'lu' => '鲁巴加丹加语',
        'lu_CD' => '鲁巴加丹加语（刚果（金））',
        'lv' => '拉脱维亚语',
        'lv_LV' => '拉脱维亚语（拉脱维亚）',
        'mg' => '马拉加斯语',
        'mg_MG' => '马拉加斯语（马达加斯加）',
        'mi' => '毛利语',
        'mi_NZ' => '毛利语（新西兰）',
        'mk' => '马其顿语',
        'mk_MK' => '马其顿语（北马其顿）',
        'ml' => '马拉雅拉姆语',
        'ml_IN' => '马拉雅拉姆语（印度）',
        'mn' => '蒙古语',
        'mn_MN' => '蒙古语（蒙古）',
        'mr' => '马拉地语',
        'mr_IN' => '马拉地语（印度）',
        'ms' => '马来语',
        'ms_BN' => '马来语（文莱）',
        'ms_ID' => '马来语（印度尼西亚）',
        'ms_MY' => '马来语（马来西亚）',
        'ms_SG' => '马来语（新加坡）',
        'mt' => '马耳他语',
        'mt_MT' => '马耳他语（马耳他）',
        'my' => '缅甸语',
        'my_MM' => '缅甸语（缅甸）',
        'nb' => '书面挪威语',
        'nb_NO' => '书面挪威语（挪威）',
        'nb_SJ' => '书面挪威语（斯瓦尔巴和扬马延）',
        'nd' => '北恩德贝勒语',
        'nd_ZW' => '北恩德贝勒语（津巴布韦）',
        'ne' => '尼泊尔语',
        'ne_IN' => '尼泊尔语（印度）',
        'ne_NP' => '尼泊尔语（尼泊尔）',
        'nl' => '荷兰语',
        'nl_AW' => '荷兰语（阿鲁巴）',
        'nl_BE' => '荷兰语（比利时）',
        'nl_BQ' => '荷兰语（荷属加勒比区）',
        'nl_CW' => '荷兰语（库拉索）',
        'nl_NL' => '荷兰语（荷兰）',
        'nl_SR' => '荷兰语（苏里南）',
        'nl_SX' => '荷兰语（荷属圣马丁）',
        'nn' => '挪威尼诺斯克语',
        'nn_NO' => '挪威尼诺斯克语（挪威）',
        'no' => '挪威语',
        'no_NO' => '挪威语（挪威）',
        'oc' => '奥克语',
        'oc_ES' => '奥克语（西班牙）',
        'oc_FR' => '奥克语（法国）',
        'om' => '奥罗莫语',
        'om_ET' => '奥罗莫语（埃塞俄比亚）',
        'om_KE' => '奥罗莫语（肯尼亚）',
        'or' => '奥里亚语',
        'or_IN' => '奥里亚语（印度）',
        'os' => '奥塞梯语',
        'os_GE' => '奥塞梯语（格鲁吉亚）',
        'os_RU' => '奥塞梯语（俄罗斯）',
        'pa' => '旁遮普语',
        'pa_Arab' => '旁遮普语（阿拉伯文）',
        'pa_Arab_PK' => '旁遮普语（阿拉伯文，巴基斯坦）',
        'pa_Guru' => '旁遮普语（果鲁穆奇文）',
        'pa_Guru_IN' => '旁遮普语（果鲁穆奇文，印度）',
        'pa_IN' => '旁遮普语（印度）',
        'pa_PK' => '旁遮普语（巴基斯坦）',
        'pl' => '波兰语',
        'pl_PL' => '波兰语（波兰）',
        'ps' => '普什图语',
        'ps_AF' => '普什图语（阿富汗）',
        'ps_PK' => '普什图语（巴基斯坦）',
        'pt' => '葡萄牙语',
        'pt_AO' => '葡萄牙语（安哥拉）',
        'pt_BR' => '葡萄牙语（巴西）',
        'pt_CH' => '葡萄牙语（瑞士）',
        'pt_CV' => '葡萄牙语（佛得角）',
        'pt_GQ' => '葡萄牙语（赤道几内亚）',
        'pt_GW' => '葡萄牙语（几内亚比绍）',
        'pt_LU' => '葡萄牙语（卢森堡）',
        'pt_MO' => '葡萄牙语（中国澳门特别行政区）',
        'pt_MZ' => '葡萄牙语（莫桑比克）',
        'pt_PT' => '葡萄牙语（葡萄牙）',
        'pt_ST' => '葡萄牙语（圣多美和普林西比）',
        'pt_TL' => '葡萄牙语（东帝汶）',
        'qu' => '克丘亚语',
        'qu_BO' => '克丘亚语（玻利维亚）',
        'qu_EC' => '克丘亚语（厄瓜多尔）',
        'qu_PE' => '克丘亚语（秘鲁）',
        'rm' => '罗曼什语',
        'rm_CH' => '罗曼什语（瑞士）',
        'rn' => '隆迪语',
        'rn_BI' => '隆迪语（布隆迪）',
        'ro' => '罗马尼亚语',
        'ro_MD' => '罗马尼亚语（摩尔多瓦）',
        'ro_RO' => '罗马尼亚语（罗马尼亚）',
        'ru' => '俄语',
        'ru_BY' => '俄语（白俄罗斯）',
        'ru_KG' => '俄语（吉尔吉斯斯坦）',
        'ru_KZ' => '俄语（哈萨克斯坦）',
        'ru_MD' => '俄语（摩尔多瓦）',
        'ru_RU' => '俄语（俄罗斯）',
        'ru_UA' => '俄语（乌克兰）',
        'rw' => '卢旺达语',
        'rw_RW' => '卢旺达语（卢旺达）',
        'sa' => '梵语',
        'sa_IN' => '梵语（印度）',
        'sc' => '萨丁语',
        'sc_IT' => '萨丁语（意大利）',
        'sd' => '信德语',
        'sd_Arab' => '信德语（阿拉伯文）',
        'sd_Arab_PK' => '信德语（阿拉伯文，巴基斯坦）',
        'sd_Deva' => '信德语（天城文）',
        'sd_Deva_IN' => '信德语（天城文，印度）',
        'sd_IN' => '信德语（印度）',
        'sd_PK' => '信德语（巴基斯坦）',
        'se' => '北方萨米语',
        'se_FI' => '北方萨米语（芬兰）',
        'se_NO' => '北方萨米语（挪威）',
        'se_SE' => '北方萨米语（瑞典）',
        'sg' => '桑戈语',
        'sg_CF' => '桑戈语（中非共和国）',
        'sh' => '塞尔维亚-克罗地亚语',
        'sh_BA' => '塞尔维亚-克罗地亚语（波斯尼亚和黑塞哥维那）',
        'si' => '僧伽罗语',
        'si_LK' => '僧伽罗语（斯里兰卡）',
        'sk' => '斯洛伐克语',
        'sk_SK' => '斯洛伐克语（斯洛伐克）',
        'sl' => '斯洛文尼亚语',
        'sl_SI' => '斯洛文尼亚语（斯洛文尼亚）',
        'sn' => '绍纳语',
        'sn_ZW' => '绍纳语（津巴布韦）',
        'so' => '索马里语',
        'so_DJ' => '索马里语（吉布提）',
        'so_ET' => '索马里语（埃塞俄比亚）',
        'so_KE' => '索马里语（肯尼亚）',
        'so_SO' => '索马里语（索马里）',
        'sq' => '阿尔巴尼亚语',
        'sq_AL' => '阿尔巴尼亚语（阿尔巴尼亚）',
        'sq_MK' => '阿尔巴尼亚语（北马其顿）',
        'sr' => '塞尔维亚语',
        'sr_BA' => '塞尔维亚语（波斯尼亚和黑塞哥维那）',
        'sr_Cyrl' => '塞尔维亚语（西里尔文）',
        'sr_Cyrl_BA' => '塞尔维亚语（西里尔文，波斯尼亚和黑塞哥维那）',
        'sr_Cyrl_ME' => '塞尔维亚语（西里尔文，黑山）',
        'sr_Cyrl_RS' => '塞尔维亚语（西里尔文，塞尔维亚）',
        'sr_Latn' => '塞尔维亚语（拉丁文）',
        'sr_Latn_BA' => '塞尔维亚语（拉丁文，波斯尼亚和黑塞哥维那）',
        'sr_Latn_ME' => '塞尔维亚语（拉丁文，黑山）',
        'sr_Latn_RS' => '塞尔维亚语（拉丁文，塞尔维亚）',
        'sr_ME' => '塞尔维亚语（黑山）',
        'sr_RS' => '塞尔维亚语（塞尔维亚）',
        'st' => '南索托语',
        'st_LS' => '南索托语（莱索托）',
        'st_ZA' => '南索托语（南非）',
        'su' => '巽他语',
        'su_ID' => '巽他语（印度尼西亚）',
        'su_Latn' => '巽他语（拉丁文）',
        'su_Latn_ID' => '巽他语（拉丁文，印度尼西亚）',
        'sv' => '瑞典语',
        'sv_AX' => '瑞典语（奥兰群岛）',
        'sv_FI' => '瑞典语（芬兰）',
        'sv_SE' => '瑞典语（瑞典）',
        'sw' => '斯瓦希里语',
        'sw_CD' => '斯瓦希里语（刚果（金））',
        'sw_KE' => '斯瓦希里语（肯尼亚）',
        'sw_TZ' => '斯瓦希里语（坦桑尼亚）',
        'sw_UG' => '斯瓦希里语（乌干达）',
        'ta' => '泰米尔语',
        'ta_IN' => '泰米尔语（印度）',
        'ta_LK' => '泰米尔语（斯里兰卡）',
        'ta_MY' => '泰米尔语（马来西亚）',
        'ta_SG' => '泰米尔语（新加坡）',
        'te' => '泰卢固语',
        'te_IN' => '泰卢固语（印度）',
        'tg' => '塔吉克语',
        'tg_TJ' => '塔吉克语（塔吉克斯坦）',
        'th' => '泰语',
        'th_TH' => '泰语（泰国）',
        'ti' => '提格利尼亚语',
        'ti_ER' => '提格利尼亚语（厄立特里亚）',
        'ti_ET' => '提格利尼亚语（埃塞俄比亚）',
        'tk' => '土库曼语',
        'tk_TM' => '土库曼语（土库曼斯坦）',
        'tl' => '他加禄语',
        'tl_PH' => '他加禄语（菲律宾）',
        'tn' => '茨瓦纳语',
        'tn_BW' => '茨瓦纳语（博茨瓦纳）',
        'tn_ZA' => '茨瓦纳语（南非）',
        'to' => '汤加语',
        'to_TO' => '汤加语（汤加）',
        'tr' => '土耳其语',
        'tr_CY' => '土耳其语（塞浦路斯）',
        'tr_TR' => '土耳其语（土耳其）',
        'tt' => '鞑靼语',
        'tt_RU' => '鞑靼语（俄罗斯）',
        'ug' => '维吾尔语',
        'ug_CN' => '维吾尔语（中国）',
        'uk' => '乌克兰语',
        'uk_UA' => '乌克兰语（乌克兰）',
        'ur' => '乌尔都语',
        'ur_IN' => '乌尔都语（印度）',
        'ur_PK' => '乌尔都语（巴基斯坦）',
        'uz' => '乌兹别克语',
        'uz_AF' => '乌兹别克语（阿富汗）',
        'uz_Arab' => '乌兹别克语（阿拉伯文）',
        'uz_Arab_AF' => '乌兹别克语（阿拉伯文，阿富汗）',
        'uz_Cyrl' => '乌兹别克语（西里尔文）',
        'uz_Cyrl_UZ' => '乌兹别克语（西里尔文，乌兹别克斯坦）',
        'uz_Latn' => '乌兹别克语（拉丁文）',
        'uz_Latn_UZ' => '乌兹别克语（拉丁文，乌兹别克斯坦）',
        'uz_UZ' => '乌兹别克语（乌兹别克斯坦）',
        'vi' => '越南语',
        'vi_VN' => '越南语（越南）',
        'wo' => '沃洛夫语',
        'wo_SN' => '沃洛夫语（塞内加尔）',
        'xh' => '科萨语',
        'xh_ZA' => '科萨语（南非）',
        'yi' => '意第绪语',
        'yi_UA' => '意第绪语（乌克兰）',
        'yo' => '约鲁巴语',
        'yo_BJ' => '约鲁巴语（贝宁）',
        'yo_NG' => '约鲁巴语（尼日利亚）',
        'za' => '壮语',
        'za_CN' => '壮语（中国）',
        'zh' => '中文',
        'zh_CN' => '中文（中国）',
        'zh_HK' => '中文（中国香港特别行政区）',
        'zh_Hans' => '中文（简体）',
        'zh_Hans_CN' => '中文（简体，中国）',
        'zh_Hans_HK' => '中文（简体，中国香港特别行政区）',
        'zh_Hans_MO' => '中文（简体，中国澳门特别行政区）',
        'zh_Hans_MY' => '中文（简体，马来西亚）',
        'zh_Hans_SG' => '中文（简体，新加坡）',
        'zh_Hant' => '中文（繁体）',
        'zh_Hant_HK' => '中文（繁体，中国香港特别行政区）',
        'zh_Hant_MO' => '中文（繁体，中国澳门特别行政区）',
        'zh_Hant_MY' => '中文（繁体，马来西亚）',
        'zh_Hant_TW' => '中文（繁体，台湾）',
        'zh_MO' => '中文（中国澳门特别行政区）',
        'zh_SG' => '中文（新加坡）',
        'zh_TW' => '中文（台湾）',
        'zu' => '祖鲁语',
        'zu_ZA' => '祖鲁语（南非）',
    ],
];
