<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibia)',
        'af_ZA' => 'afrikaans (Africa dal Sid)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amaric',
        'am_ET' => 'amaric (Etiopia)',
        'ar' => 'arab',
        'ar_001' => 'arab (mund)',
        'ar_AE' => 'arab (Emirats Arabs Unids)',
        'ar_BH' => 'arab (Bahrain)',
        'ar_DJ' => 'arab (Dschibuti)',
        'ar_DZ' => 'arab (Algeria)',
        'ar_EG' => 'arab (Egipta)',
        'ar_EH' => 'arab (Sahara Occidentala)',
        'ar_ER' => 'arab (Eritrea)',
        'ar_IL' => 'arab (Israel)',
        'ar_IQ' => 'arab (Irac)',
        'ar_JO' => 'arab (Jordania)',
        'ar_KM' => 'arab (Comoras)',
        'ar_KW' => 'arab (Kuwait)',
        'ar_LB' => 'arab (Libanon)',
        'ar_LY' => 'arab (Libia)',
        'ar_MA' => 'arab (Maroc)',
        'ar_MR' => 'arab (Mauretania)',
        'ar_OM' => 'arab (Oman)',
        'ar_PS' => 'arab (Territori Palestinais)',
        'ar_QA' => 'arab (Qatar)',
        'ar_SA' => 'arab (Arabia Saudita)',
        'ar_SD' => 'arab (Sudan)',
        'ar_SO' => 'arab (Somalia)',
        'ar_SS' => 'arab (Sudan dal Sid)',
        'ar_SY' => 'arab (Siria)',
        'ar_TD' => 'arab (Tschad)',
        'ar_TN' => 'arab (Tunesia)',
        'ar_YE' => 'arab (Jemen)',
        'as' => 'assami',
        'as_IN' => 'assami (India)',
        'az' => 'lingua aserbaidschana',
        'az_AZ' => 'lingua aserbaidschana (Aserbaidschan)',
        'az_Cyrl' => 'lingua aserbaidschana (cirillic)',
        'az_Cyrl_AZ' => 'lingua aserbaidschana (cirillic, Aserbaidschan)',
        'az_Latn' => 'lingua aserbaidschana (latin)',
        'az_Latn_AZ' => 'lingua aserbaidschana (latin, Aserbaidschan)',
        'ba' => 'baschkir',
        'ba_RU' => 'baschkir (Russia)',
        'be' => 'lingua bielorussa',
        'be_BY' => 'lingua bielorussa (Belarus)',
        'bg' => 'bulgar',
        'bg_BG' => 'bulgar (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'lingua bengala',
        'bn_BD' => 'lingua bengala (Bangladesch)',
        'bn_IN' => 'lingua bengala (India)',
        'bo' => 'tibetan',
        'bo_CN' => 'tibetan (China)',
        'bo_IN' => 'tibetan (India)',
        'br' => 'breton',
        'br_FR' => 'breton (Frantscha)',
        'bs' => 'bosniac',
        'bs_BA' => 'bosniac (Bosnia ed Erzegovina)',
        'bs_Cyrl' => 'bosniac (cirillic)',
        'bs_Cyrl_BA' => 'bosniac (cirillic, Bosnia ed Erzegovina)',
        'bs_Latn' => 'bosniac (latin)',
        'bs_Latn_BA' => 'bosniac (latin, Bosnia ed Erzegovina)',
        'ca' => 'catalan',
        'ca_AD' => 'catalan (Andorra)',
        'ca_ES' => 'catalan (Spagna)',
        'ca_FR' => 'catalan (Frantscha)',
        'ca_IT' => 'catalan (Italia)',
        'ce' => 'tschetschen',
        'ce_RU' => 'tschetschen (Russia)',
        'cs' => 'tschec',
        'cs_CZ' => 'tschec (Tschechia)',
        'cv' => 'tschuvasch',
        'cv_RU' => 'tschuvasch (Russia)',
        'cy' => 'valisic',
        'cy_GB' => 'valisic (Reginavel Unì)',
        'da' => 'danais',
        'da_DK' => 'danais (Danemarc)',
        'da_GL' => 'danais (Grönlanda)',
        'de' => 'tudestg',
        'de_AT' => 'tudestg (Austria)',
        'de_BE' => 'tudestg (Belgia)',
        'de_CH' => 'tudestg (Svizra)',
        'de_DE' => 'tudestg (Germania)',
        'de_IT' => 'tudestg (Italia)',
        'de_LI' => 'tudestg (Liechtenstein)',
        'de_LU' => 'tudestg (Luxemburg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Butan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'grec',
        'el_CY' => 'grec (Cipra)',
        'el_GR' => 'grec (Grezia)',
        'en' => 'englais',
        'en_001' => 'englais (mund)',
        'en_150' => 'englais (Europa)',
        'en_AE' => 'englais (Emirats Arabs Unids)',
        'en_AG' => 'englais (Antigua e Barbuda)',
        'en_AI' => 'englais (Anguilla)',
        'en_AS' => 'englais (Samoa Americana)',
        'en_AT' => 'englais (Austria)',
        'en_AU' => 'englais (Australia)',
        'en_BB' => 'englais (Barbados)',
        'en_BE' => 'englais (Belgia)',
        'en_BI' => 'englais (Burundi)',
        'en_BM' => 'englais (Bermudas)',
        'en_BS' => 'englais (Bahamas)',
        'en_BW' => 'englais (Botsuana)',
        'en_BZ' => 'englais (Belize)',
        'en_CA' => 'englais (Canada)',
        'en_CC' => 'englais (Inslas Cocos)',
        'en_CH' => 'englais (Svizra)',
        'en_CK' => 'englais (Inslas Cook)',
        'en_CM' => 'englais (Camerun)',
        'en_CX' => 'englais (Insla da Nadal)',
        'en_CY' => 'englais (Cipra)',
        'en_CZ' => 'englais (Tschechia)',
        'en_DE' => 'englais (Germania)',
        'en_DK' => 'englais (Danemarc)',
        'en_DM' => 'englais (Dominica)',
        'en_EE' => 'englais (Estonia)',
        'en_ER' => 'englais (Eritrea)',
        'en_ES' => 'englais (Spagna)',
        'en_FI' => 'englais (Finlanda)',
        'en_FJ' => 'englais (Fidschi)',
        'en_FK' => 'englais (Inslas Falkland)',
        'en_FM' => 'englais (Micronesia)',
        'en_FR' => 'englais (Frantscha)',
        'en_GB' => 'englais (Reginavel Unì)',
        'en_GD' => 'englais (Grenada)',
        'en_GE' => 'englais (Georgia)',
        'en_GG' => 'englais (Guernsey)',
        'en_GH' => 'englais (Ghana)',
        'en_GI' => 'englais (Gibraltar)',
        'en_GM' => 'englais (Gambia)',
        'en_GS' => 'englais (Georgia dal Sid e las Inslas Sandwich dal Sid)',
        'en_GU' => 'englais (Guam)',
        'en_GY' => 'englais (Guyana)',
        'en_HK' => 'englais (Regiun d’administraziun speziala Hongkong, China)',
        'en_HU' => 'englais (Ungaria)',
        'en_ID' => 'englais (Indonesia)',
        'en_IE' => 'englais (Irlanda)',
        'en_IL' => 'englais (Israel)',
        'en_IM' => 'englais (Insla da Man)',
        'en_IN' => 'englais (India)',
        'en_IO' => 'englais (Territori Britannic da l’Ocean Indic)',
        'en_IT' => 'englais (Italia)',
        'en_JE' => 'englais (Jersey)',
        'en_JM' => 'englais (Giamaica)',
        'en_JP' => 'englais (Giapun)',
        'en_KE' => 'englais (Kenia)',
        'en_KI' => 'englais (Kiribati)',
        'en_KN' => 'englais (Son Cristof e Nevis)',
        'en_KY' => 'englais (Inslas Cayman)',
        'en_LC' => 'englais (Sontga Lucia)',
        'en_LR' => 'englais (Liberia)',
        'en_LS' => 'englais (Lesotho)',
        'en_LT' => 'englais (Lituania)',
        'en_LV' => 'englais (Lettonia)',
        'en_MG' => 'englais (Madagascar)',
        'en_MH' => 'englais (Inslas da Marshall)',
        'en_MO' => 'englais (Regiun d’administraziun speziala Macao, China)',
        'en_MP' => 'englais (Inslas Mariannas dal Nord)',
        'en_MS' => 'englais (Montserrat)',
        'en_MT' => 'englais (Malta)',
        'en_MU' => 'englais (Mauritius)',
        'en_MV' => 'englais (Maledivas)',
        'en_MW' => 'englais (Malawi)',
        'en_MY' => 'englais (Malaisia)',
        'en_NA' => 'englais (Namibia)',
        'en_NF' => 'englais (Insla Norfolk)',
        'en_NG' => 'englais (Nigeria)',
        'en_NL' => 'englais (Pajais Bass)',
        'en_NO' => 'englais (Norvegia)',
        'en_NR' => 'englais (Nauru)',
        'en_NU' => 'englais (Niue)',
        'en_NZ' => 'englais (Nova Zelanda)',
        'en_PG' => 'englais (Papua Nova Guinea)',
        'en_PH' => 'englais (Filippinas)',
        'en_PK' => 'englais (Pakistan)',
        'en_PL' => 'englais (Pologna)',
        'en_PN' => 'englais (Pitcairn)',
        'en_PR' => 'englais (Puerto Rico)',
        'en_PT' => 'englais (Portugal)',
        'en_PW' => 'englais (Palau)',
        'en_RO' => 'englais (Rumenia)',
        'en_RW' => 'englais (Ruanda)',
        'en_SB' => 'englais (Inslas da Salomon)',
        'en_SC' => 'englais (Seychellas)',
        'en_SD' => 'englais (Sudan)',
        'en_SE' => 'englais (Svezia)',
        'en_SG' => 'englais (Singapur)',
        'en_SH' => 'englais (Sontg’Elena)',
        'en_SI' => 'englais (Slovenia)',
        'en_SK' => 'englais (Slovachia)',
        'en_SL' => 'englais (Sierra Leone)',
        'en_SS' => 'englais (Sudan dal Sid)',
        'en_SX' => 'englais (Sint Maarten)',
        'en_SZ' => 'englais (Eswatini)',
        'en_TC' => 'englais (Inslas Turks e Caicos)',
        'en_TK' => 'englais (Tokelau)',
        'en_TO' => 'englais (Tonga)',
        'en_TT' => 'englais (Trinidad e Tobago)',
        'en_TV' => 'englais (Tuvalu)',
        'en_TZ' => 'englais (Tansania)',
        'en_UA' => 'englais (Ucraina)',
        'en_UG' => 'englais (Uganda)',
        'en_UM' => 'englais (Inslas Pitschnas Perifericas dals Stadis Unids da l’America)',
        'en_US' => 'englais (Stadis Unids da l’America)',
        'en_VC' => 'englais (Son Vincenz e las Grenadinas)',
        'en_VG' => 'englais (Inslas Virginas Britannicas)',
        'en_VI' => 'englais (Inslas Virginas Americanas)',
        'en_VU' => 'englais (Vanuatu)',
        'en_WS' => 'englais (Samoa)',
        'en_ZA' => 'englais (Africa dal Sid)',
        'en_ZM' => 'englais (Sambia)',
        'en_ZW' => 'englais (Simbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (mund)',
        'es' => 'spagnol',
        'es_419' => 'spagnol (America latina)',
        'es_AR' => 'spagnol (Argentina)',
        'es_BO' => 'spagnol (Bolivia)',
        'es_BR' => 'spagnol (Brasilia)',
        'es_BZ' => 'spagnol (Belize)',
        'es_CL' => 'spagnol (Chile)',
        'es_CO' => 'spagnol (Columbia)',
        'es_CR' => 'spagnol (Costa Rica)',
        'es_CU' => 'spagnol (Cuba)',
        'es_DO' => 'spagnol (Republica Dominicana)',
        'es_EC' => 'spagnol (Ecuador)',
        'es_ES' => 'spagnol (Spagna)',
        'es_GQ' => 'spagnol (Guinea Equatoriala)',
        'es_GT' => 'spagnol (Guatemala)',
        'es_HN' => 'spagnol (Honduras)',
        'es_MX' => 'spagnol (Mexico)',
        'es_NI' => 'spagnol (Nicaragua)',
        'es_PA' => 'spagnol (Panama)',
        'es_PE' => 'spagnol (Peru)',
        'es_PH' => 'spagnol (Filippinas)',
        'es_PR' => 'spagnol (Puerto Rico)',
        'es_PY' => 'spagnol (Paraguai)',
        'es_SV' => 'spagnol (El Salvador)',
        'es_US' => 'spagnol (Stadis Unids da l’America)',
        'es_UY' => 'spagnol (Uruguai)',
        'es_VE' => 'spagnol (Venezuela)',
        'et' => 'eston',
        'et_EE' => 'eston (Estonia)',
        'eu' => 'basc',
        'eu_ES' => 'basc (Spagna)',
        'fa' => 'persian',
        'fa_AF' => 'persian (Afganistan)',
        'fa_IR' => 'persian (Iran)',
        'ff' => 'fulah',
        'ff_Adlm' => 'fulah (adlam)',
        'ff_Adlm_BF' => 'fulah (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulah (adlam, Camerun)',
        'ff_Adlm_GH' => 'fulah (adlam, Ghana)',
        'ff_Adlm_GM' => 'fulah (adlam, Gambia)',
        'ff_Adlm_GN' => 'fulah (adlam, Guinea)',
        'ff_Adlm_GW' => 'fulah (adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'fulah (adlam, Liberia)',
        'ff_Adlm_MR' => 'fulah (adlam, Mauretania)',
        'ff_Adlm_NE' => 'fulah (adlam, Niger)',
        'ff_Adlm_NG' => 'fulah (adlam, Nigeria)',
        'ff_Adlm_SL' => 'fulah (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'fulah (adlam, Senegal)',
        'ff_CM' => 'fulah (Camerun)',
        'ff_GN' => 'fulah (Guinea)',
        'ff_Latn' => 'fulah (latin)',
        'ff_Latn_BF' => 'fulah (latin, Burkina Faso)',
        'ff_Latn_CM' => 'fulah (latin, Camerun)',
        'ff_Latn_GH' => 'fulah (latin, Ghana)',
        'ff_Latn_GM' => 'fulah (latin, Gambia)',
        'ff_Latn_GN' => 'fulah (latin, Guinea)',
        'ff_Latn_GW' => 'fulah (latin, Guinea-Bissau)',
        'ff_Latn_LR' => 'fulah (latin, Liberia)',
        'ff_Latn_MR' => 'fulah (latin, Mauretania)',
        'ff_Latn_NE' => 'fulah (latin, Niger)',
        'ff_Latn_NG' => 'fulah (latin, Nigeria)',
        'ff_Latn_SL' => 'fulah (latin, Sierra Leone)',
        'ff_Latn_SN' => 'fulah (latin, Senegal)',
        'ff_MR' => 'fulah (Mauretania)',
        'ff_SN' => 'fulah (Senegal)',
        'fi' => 'finlandais',
        'fi_FI' => 'finlandais (Finlanda)',
        'fo' => 'feroais',
        'fo_DK' => 'feroais (Danemarc)',
        'fo_FO' => 'feroais (Inslas Feroe)',
        'fr' => 'franzos',
        'fr_BE' => 'franzos (Belgia)',
        'fr_BF' => 'franzos (Burkina Faso)',
        'fr_BI' => 'franzos (Burundi)',
        'fr_BJ' => 'franzos (Benin)',
        'fr_BL' => 'franzos (Son Barthélemy)',
        'fr_CA' => 'franzos (Canada)',
        'fr_CD' => 'franzos (Congo-Kinshasa)',
        'fr_CF' => 'franzos (Republica Centralafricana)',
        'fr_CG' => 'franzos (Congo-Brazzaville)',
        'fr_CH' => 'franzos (Svizra)',
        'fr_CI' => 'franzos (Costa d’Ivur)',
        'fr_CM' => 'franzos (Camerun)',
        'fr_DJ' => 'franzos (Dschibuti)',
        'fr_DZ' => 'franzos (Algeria)',
        'fr_FR' => 'franzos (Frantscha)',
        'fr_GA' => 'franzos (Gabun)',
        'fr_GF' => 'franzos (Guyana Franzosa)',
        'fr_GN' => 'franzos (Guinea)',
        'fr_GP' => 'franzos (Guadalupa)',
        'fr_GQ' => 'franzos (Guinea Equatoriala)',
        'fr_HT' => 'franzos (Haiti)',
        'fr_KM' => 'franzos (Comoras)',
        'fr_LU' => 'franzos (Luxemburg)',
        'fr_MA' => 'franzos (Maroc)',
        'fr_MC' => 'franzos (Monaco)',
        'fr_MF' => 'franzos (Saint Martin)',
        'fr_MG' => 'franzos (Madagascar)',
        'fr_ML' => 'franzos (Mali)',
        'fr_MQ' => 'franzos (Martinica)',
        'fr_MR' => 'franzos (Mauretania)',
        'fr_MU' => 'franzos (Mauritius)',
        'fr_NC' => 'franzos (Nova Caledonia)',
        'fr_NE' => 'franzos (Niger)',
        'fr_PF' => 'franzos (Polinesia Franzosa)',
        'fr_PM' => 'franzos (Saint Pierre e Miquelon)',
        'fr_RE' => 'franzos (Réunion)',
        'fr_RW' => 'franzos (Ruanda)',
        'fr_SC' => 'franzos (Seychellas)',
        'fr_SN' => 'franzos (Senegal)',
        'fr_SY' => 'franzos (Siria)',
        'fr_TD' => 'franzos (Tschad)',
        'fr_TG' => 'franzos (Togo)',
        'fr_TN' => 'franzos (Tunesia)',
        'fr_VU' => 'franzos (Vanuatu)',
        'fr_WF' => 'franzos (Wallis e Futuna)',
        'fr_YT' => 'franzos (Mayotte)',
        'fy' => 'fris occidental',
        'fy_NL' => 'fris occidental (Pajais Bass)',
        'ga' => 'irlandais',
        'ga_GB' => 'irlandais (Reginavel Unì)',
        'ga_IE' => 'irlandais (Irlanda)',
        'gd' => 'gaelic scot',
        'gd_GB' => 'gaelic scot (Reginavel Unì)',
        'gl' => 'galizian',
        'gl_ES' => 'galizian (Spagna)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (India)',
        'gv' => 'manx',
        'gv_IM' => 'manx (Insla da Man)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'ebraic',
        'he_IL' => 'ebraic (Israel)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (India)',
        'hi_Latn' => 'hindi (latin)',
        'hi_Latn_IN' => 'hindi (latin, India)',
        'hr' => 'croat',
        'hr_BA' => 'croat (Bosnia ed Erzegovina)',
        'hr_HR' => 'croat (Croazia)',
        'hu' => 'ungarais',
        'hu_HU' => 'ungarais (Ungaria)',
        'hy' => 'armen',
        'hy_AM' => 'armen (Armenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (mund)',
        'id' => 'indonais',
        'id_ID' => 'indonais (Indonesia)',
        'ie' => 'interlingue',
        'ie_EE' => 'interlingue (Estonia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeria)',
        'ii' => 'sichuan yi',
        'ii_CN' => 'sichuan yi (China)',
        'is' => 'islandais',
        'is_IS' => 'islandais (Islanda)',
        'it' => 'talian',
        'it_CH' => 'talian (Svizra)',
        'it_IT' => 'talian (Italia)',
        'it_SM' => 'talian (Son Marin)',
        'it_VA' => 'talian (Citad dal Vatican)',
        'ja' => 'giapunais',
        'ja_JP' => 'giapunais (Giapun)',
        'jv' => 'javanais',
        'jv_ID' => 'javanais (Indonesia)',
        'ka' => 'georgian',
        'ka_GE' => 'georgian (Georgia)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenia)',
        'kk' => 'kasac',
        'kk_Arab' => 'kasac (arab)',
        'kk_Arab_CN' => 'kasac (arab, China)',
        'kk_Cyrl' => 'kasac (cirillic)',
        'kk_Cyrl_KZ' => 'kasac (cirillic, Kasachstan)',
        'kk_KZ' => 'kasac (Kasachstan)',
        'kl' => 'grönlandais',
        'kl_GL' => 'grönlandais (Grönlanda)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Cambodscha)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (India)',
        'ko' => 'corean',
        'ko_CN' => 'corean (China)',
        'ko_KP' => 'corean (Corea dal Nord)',
        'ko_KR' => 'corean (Corea dal Sid)',
        'ks' => 'kashmiri',
        'ks_Arab' => 'kashmiri (arab)',
        'ks_Arab_IN' => 'kashmiri (arab, India)',
        'ks_Deva' => 'kashmiri (devanagari)',
        'ks_Deva_IN' => 'kashmiri (devanagari, India)',
        'ks_IN' => 'kashmiri (India)',
        'ku' => 'curd',
        'ku_Latn' => 'curd (latin)',
        'ku_Latn_IQ' => 'curd (latin, Irac)',
        'ku_Latn_SY' => 'curd (latin, Siria)',
        'ku_Latn_TR' => 'curd (latin, Tirchia)',
        'ku_SY' => 'curd (Siria)',
        'ku_TR' => 'curd (Tirchia)',
        'kw' => 'cornic',
        'kw_GB' => 'cornic (Reginavel Unì)',
        'ky' => 'kirghis',
        'ky_KG' => 'kirghis (Kirghistan)',
        'lb' => 'luxemburgais',
        'lb_LU' => 'luxemburgais (Luxemburg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Congo-Kinshasa)',
        'ln_CF' => 'lingala (Republica Centralafricana)',
        'ln_CG' => 'lingala (Congo-Brazzaville)',
        'lo' => 'laot',
        'lo_LA' => 'laot (Laos)',
        'lt' => 'lituan',
        'lt_LT' => 'lituan (Lituania)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Congo-Kinshasa)',
        'lv' => 'letton',
        'lv_LV' => 'letton (Lettonia)',
        'mg' => 'malagassi',
        'mg_MG' => 'malagassi (Madagascar)',
        'mi' => 'māori',
        'mi_NZ' => 'māori (Nova Zelanda)',
        'mk' => 'macedon',
        'mk_MK' => 'macedon (Macedonia dal Nord)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (India)',
        'mn' => 'mongol',
        'mn_MN' => 'mongol (Mongolia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (India)',
        'ms' => 'malaic',
        'ms_BN' => 'malaic (Brunei)',
        'ms_ID' => 'malaic (Indonesia)',
        'ms_MY' => 'malaic (Malaisia)',
        'ms_SG' => 'malaic (Singapur)',
        'mt' => 'maltais',
        'mt_MT' => 'maltais (Malta)',
        'my' => 'birman',
        'my_MM' => 'birman (Myanmar [Burma])',
        'nb' => 'norvegais bokmål',
        'nb_NO' => 'norvegais bokmål (Norvegia)',
        'nb_SJ' => 'norvegais bokmål (Svalbard e Jan Mayen)',
        'nd' => 'ndebele dal nord',
        'nd_ZW' => 'ndebele dal nord (Simbabwe)',
        'ne' => 'nepalais',
        'ne_IN' => 'nepalais (India)',
        'ne_NP' => 'nepalais (Nepal)',
        'nl' => 'neerlandais',
        'nl_AW' => 'neerlandais (Aruba)',
        'nl_BE' => 'neerlandais (Belgia)',
        'nl_BQ' => 'neerlandais (Pajais Bass caribics)',
        'nl_CW' => 'neerlandais (Curaçao)',
        'nl_NL' => 'neerlandais (Pajais Bass)',
        'nl_SR' => 'neerlandais (Surinam)',
        'nl_SX' => 'neerlandais (Sint Maarten)',
        'nn' => 'norvegiais nynorsk',
        'nn_NO' => 'norvegiais nynorsk (Norvegia)',
        'no' => 'norvegiais',
        'no_NO' => 'norvegiais (Norvegia)',
        'oc' => 'occitan',
        'oc_ES' => 'occitan (Spagna)',
        'oc_FR' => 'occitan (Frantscha)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiopia)',
        'om_KE' => 'oromo (Kenia)',
        'or' => 'oriya',
        'or_IN' => 'oriya (India)',
        'os' => 'ossetic',
        'os_GE' => 'ossetic (Georgia)',
        'os_RU' => 'ossetic (Russia)',
        'pa' => 'punjabi',
        'pa_Arab' => 'punjabi (arab)',
        'pa_Arab_PK' => 'punjabi (arab, Pakistan)',
        'pa_Guru' => 'punjabi (gurmukhi)',
        'pa_Guru_IN' => 'punjabi (gurmukhi, India)',
        'pa_IN' => 'punjabi (India)',
        'pa_PK' => 'punjabi (Pakistan)',
        'pl' => 'polac',
        'pl_PL' => 'polac (Pologna)',
        'ps' => 'paschto',
        'ps_AF' => 'paschto (Afganistan)',
        'ps_PK' => 'paschto (Pakistan)',
        'pt' => 'portugais',
        'pt_AO' => 'portugais (Angola)',
        'pt_BR' => 'portugais (Brasilia)',
        'pt_CH' => 'portugais (Svizra)',
        'pt_CV' => 'portugais (Cap Verd)',
        'pt_GQ' => 'portugais (Guinea Equatoriala)',
        'pt_GW' => 'portugais (Guinea-Bissau)',
        'pt_LU' => 'portugais (Luxemburg)',
        'pt_MO' => 'portugais (Regiun d’administraziun speziala Macao, China)',
        'pt_MZ' => 'portugais (Mosambic)',
        'pt_PT' => 'portugais (Portugal)',
        'pt_ST' => 'portugais (São Tomé e Príncipe)',
        'pt_TL' => 'portugais (Timor da l’Ost)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolivia)',
        'qu_EC' => 'quechua (Ecuador)',
        'qu_PE' => 'quechua (Peru)',
        'rm' => 'rumantsch',
        'rm_CH' => 'rumantsch (Svizra)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'rumen',
        'ro_MD' => 'rumen (Moldavia)',
        'ro_RO' => 'rumen (Rumenia)',
        'ru' => 'russ',
        'ru_BY' => 'russ (Belarus)',
        'ru_KG' => 'russ (Kirghistan)',
        'ru_KZ' => 'russ (Kasachstan)',
        'ru_MD' => 'russ (Moldavia)',
        'ru_RU' => 'russ (Russia)',
        'ru_UA' => 'russ (Ucraina)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Ruanda)',
        'sa' => 'sanscrit',
        'sa_IN' => 'sanscrit (India)',
        'sc' => 'sard',
        'sc_IT' => 'sard (Italia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arab)',
        'sd_Arab_PK' => 'sindhi (arab, Pakistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, India)',
        'sd_IN' => 'sindhi (India)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'sami dal nord',
        'se_FI' => 'sami dal nord (Finlanda)',
        'se_NO' => 'sami dal nord (Norvegia)',
        'se_SE' => 'sami dal nord (Svezia)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Republica Centralafricana)',
        'sh' => 'serbo-croat',
        'sh_BA' => 'serbo-croat (Bosnia ed Erzegovina)',
        'si' => 'singalais',
        'si_LK' => 'singalais (Sri Lanka)',
        'sk' => 'slovac',
        'sk_SK' => 'slovac (Slovachia)',
        'sl' => 'sloven',
        'sl_SI' => 'sloven (Slovenia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Simbabwe)',
        'so' => 'somali',
        'so_DJ' => 'somali (Dschibuti)',
        'so_ET' => 'somali (Etiopia)',
        'so_KE' => 'somali (Kenia)',
        'so_SO' => 'somali (Somalia)',
        'sq' => 'albanais',
        'sq_AL' => 'albanais (Albania)',
        'sq_MK' => 'albanais (Macedonia dal Nord)',
        'sr' => 'serb',
        'sr_BA' => 'serb (Bosnia ed Erzegovina)',
        'sr_Cyrl' => 'serb (cirillic)',
        'sr_Cyrl_BA' => 'serb (cirillic, Bosnia ed Erzegovina)',
        'sr_Cyrl_ME' => 'serb (cirillic, Montenegro)',
        'sr_Cyrl_RS' => 'serb (cirillic, Serbia)',
        'sr_Latn' => 'serb (latin)',
        'sr_Latn_BA' => 'serb (latin, Bosnia ed Erzegovina)',
        'sr_Latn_ME' => 'serb (latin, Montenegro)',
        'sr_Latn_RS' => 'serb (latin, Serbia)',
        'sr_ME' => 'serb (Montenegro)',
        'sr_RS' => 'serb (Serbia)',
        'st' => 'sotho dal sid',
        'st_LS' => 'sotho dal sid (Lesotho)',
        'st_ZA' => 'sotho dal sid (Africa dal Sid)',
        'su' => 'sundanais',
        'su_ID' => 'sundanais (Indonesia)',
        'su_Latn' => 'sundanais (latin)',
        'su_Latn_ID' => 'sundanais (latin, Indonesia)',
        'sv' => 'svedais',
        'sv_AX' => 'svedais (Inslas Aland)',
        'sv_FI' => 'svedais (Finlanda)',
        'sv_SE' => 'svedais (Svezia)',
        'sw' => 'suaheli',
        'sw_CD' => 'suaheli (Congo-Kinshasa)',
        'sw_KE' => 'suaheli (Kenia)',
        'sw_TZ' => 'suaheli (Tansania)',
        'sw_UG' => 'suaheli (Uganda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (India)',
        'ta_LK' => 'tamil (Sri Lanka)',
        'ta_MY' => 'tamil (Malaisia)',
        'ta_SG' => 'tamil (Singapur)',
        'te' => 'telugu',
        'te_IN' => 'telugu (India)',
        'tg' => 'tadschic',
        'tg_TJ' => 'tadschic (Tadschikistan)',
        'th' => 'tailandais',
        'th_TH' => 'tailandais (Tailanda)',
        'ti' => 'tigrinya',
        'ti_ER' => 'tigrinya (Eritrea)',
        'ti_ET' => 'tigrinya (Etiopia)',
        'tk' => 'turkmen',
        'tk_TM' => 'turkmen (Turkmenistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filippinas)',
        'tn' => 'tswana',
        'tn_BW' => 'tswana (Botsuana)',
        'tn_ZA' => 'tswana (Africa dal Sid)',
        'to' => 'tonga',
        'to_TO' => 'tonga (Tonga)',
        'tr' => 'tirc',
        'tr_CY' => 'tirc (Cipra)',
        'tr_TR' => 'tirc (Tirchia)',
        'tt' => 'tatar',
        'tt_RU' => 'tatar (Russia)',
        'ug' => 'uiguric',
        'ug_CN' => 'uiguric (China)',
        'uk' => 'ucranais',
        'uk_UA' => 'ucranais (Ucraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (India)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'usbec',
        'uz_AF' => 'usbec (Afganistan)',
        'uz_Arab' => 'usbec (arab)',
        'uz_Arab_AF' => 'usbec (arab, Afganistan)',
        'uz_Cyrl' => 'usbec (cirillic)',
        'uz_Cyrl_UZ' => 'usbec (cirillic, Usbekistan)',
        'uz_Latn' => 'usbec (latin)',
        'uz_Latn_UZ' => 'usbec (latin, Usbekistan)',
        'uz_UZ' => 'usbec (Usbekistan)',
        'vi' => 'vietnamais',
        'vi_VN' => 'vietnamais (Vietnam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Africa dal Sid)',
        'yi' => 'jiddic',
        'yi_UA' => 'jiddic (Ucraina)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benin)',
        'yo_NG' => 'yoruba (Nigeria)',
        'za' => 'zhuang',
        'za_CN' => 'zhuang (China)',
        'zh' => 'chinais',
        'zh_CN' => 'chinais (China)',
        'zh_HK' => 'chinais (Regiun d’administraziun speziala Hongkong, China)',
        'zh_Hans' => 'chinais (simplifitgà)',
        'zh_Hans_CN' => 'chinais (simplifitgà, China)',
        'zh_Hans_HK' => 'chinais (simplifitgà, Regiun d’administraziun speziala Hongkong, China)',
        'zh_Hans_MO' => 'chinais (simplifitgà, Regiun d’administraziun speziala Macao, China)',
        'zh_Hans_MY' => 'chinais (simplifitgà, Malaisia)',
        'zh_Hans_SG' => 'chinais (simplifitgà, Singapur)',
        'zh_Hant' => 'chinais (tradiziunal)',
        'zh_Hant_HK' => 'chinais (tradiziunal, Regiun d’administraziun speziala Hongkong, China)',
        'zh_Hant_MO' => 'chinais (tradiziunal, Regiun d’administraziun speziala Macao, China)',
        'zh_Hant_MY' => 'chinais (tradiziunal, Malaisia)',
        'zh_Hant_TW' => 'chinais (tradiziunal, Taiwan)',
        'zh_MO' => 'chinais (Regiun d’administraziun speziala Macao, China)',
        'zh_SG' => 'chinais (Singapur)',
        'zh_TW' => 'chinais (Taiwan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Africa dal Sid)',
    ],
];
