<?php

return [
    'Names' => [
        'en' => 'Sekgoa',
        'en_BW' => 'Sekgoa (Botswana)',
        'en_ZA' => 'Sekgoa (Aforika Borwa)',
        'tn' => 'Setswana',
        'tn_BW' => 'Setswana (Botswana)',
        'tn_ZA' => 'Setswana (Aforika Borwa)',
    ],
];
