<?php

return [
    'Names' => [
        'af' => 'afrikaansa',
        'af_NA' => 'afrikaansa (Namibia)',
        'af_ZA' => 'afrikaansa (Hegoafrika)',
        'ak' => 'akanera',
        'ak_GH' => 'akanera (Ghana)',
        'am' => 'amharera',
        'am_ET' => 'amharera (Etiopia)',
        'ar' => 'arabiera',
        'ar_001' => 'arabiera (Mundua)',
        'ar_AE' => 'arabiera (Arabiar Emirerri Batuak)',
        'ar_BH' => 'arabiera (Bahrain)',
        'ar_DJ' => 'arabiera (Djibuti)',
        'ar_DZ' => 'arabiera (Aljeria)',
        'ar_EG' => 'arabiera (Egipto)',
        'ar_EH' => 'arabiera (Mendebaldeko Sahara)',
        'ar_ER' => 'arabiera (Eritrea)',
        'ar_IL' => 'arabiera (Israel)',
        'ar_IQ' => 'arabiera (Irak)',
        'ar_JO' => 'arabiera (Jordania)',
        'ar_KM' => 'arabiera (Komoreak)',
        'ar_KW' => 'arabiera (Kuwait)',
        'ar_LB' => 'arabiera (Libano)',
        'ar_LY' => 'arabiera (Libia)',
        'ar_MA' => 'arabiera (Maroko)',
        'ar_MR' => 'arabiera (Mauritania)',
        'ar_OM' => 'arabiera (Oman)',
        'ar_PS' => 'arabiera (Palestinar Lurralde Okupatuak)',
        'ar_QA' => 'arabiera (Qatar)',
        'ar_SA' => 'arabiera (Saudi Arabia)',
        'ar_SD' => 'arabiera (Sudan)',
        'ar_SO' => 'arabiera (Somalia)',
        'ar_SS' => 'arabiera (Hego Sudan)',
        'ar_SY' => 'arabiera (Siria)',
        'ar_TD' => 'arabiera (Txad)',
        'ar_TN' => 'arabiera (Tunisia)',
        'ar_YE' => 'arabiera (Yemen)',
        'as' => 'assamera',
        'as_IN' => 'assamera (India)',
        'az' => 'azerbaijanera',
        'az_AZ' => 'azerbaijanera (Azerbaijan)',
        'az_Cyrl' => 'azerbaijanera (zirilikoa)',
        'az_Cyrl_AZ' => 'azerbaijanera (zirilikoa, Azerbaijan)',
        'az_Latn' => 'azerbaijanera (latinoa)',
        'az_Latn_AZ' => 'azerbaijanera (latinoa, Azerbaijan)',
        'ba' => 'baxkirera',
        'ba_RU' => 'baxkirera (Errusia)',
        'be' => 'bielorrusiera',
        'be_BY' => 'bielorrusiera (Bielorrusia)',
        'bg' => 'bulgariera',
        'bg_BG' => 'bulgariera (Bulgaria)',
        'bm' => 'bambarera',
        'bm_ML' => 'bambarera (Mali)',
        'bn' => 'bengalera',
        'bn_BD' => 'bengalera (Bangladesh)',
        'bn_IN' => 'bengalera (India)',
        'bo' => 'tibetera',
        'bo_CN' => 'tibetera (Txina)',
        'bo_IN' => 'tibetera (India)',
        'br' => 'bretoiera',
        'br_FR' => 'bretoiera (Frantzia)',
        'bs' => 'bosniera',
        'bs_BA' => 'bosniera (Bosnia-Herzegovina)',
        'bs_Cyrl' => 'bosniera (zirilikoa)',
        'bs_Cyrl_BA' => 'bosniera (zirilikoa, Bosnia-Herzegovina)',
        'bs_Latn' => 'bosniera (latinoa)',
        'bs_Latn_BA' => 'bosniera (latinoa, Bosnia-Herzegovina)',
        'ca' => 'katalana',
        'ca_AD' => 'katalana (Andorra)',
        'ca_ES' => 'katalana (Espainia)',
        'ca_FR' => 'katalana (Frantzia)',
        'ca_IT' => 'katalana (Italia)',
        'ce' => 'txetxenera',
        'ce_RU' => 'txetxenera (Errusia)',
        'cs' => 'txekiera',
        'cs_CZ' => 'txekiera (Txekia)',
        'cv' => 'txuvaxera',
        'cv_RU' => 'txuvaxera (Errusia)',
        'cy' => 'galesa',
        'cy_GB' => 'galesa (Erresuma Batua)',
        'da' => 'daniera',
        'da_DK' => 'daniera (Danimarka)',
        'da_GL' => 'daniera (Groenlandia)',
        'de' => 'alemana',
        'de_AT' => 'alemana (Austria)',
        'de_BE' => 'alemana (Belgika)',
        'de_CH' => 'alemana (Suitza)',
        'de_DE' => 'alemana (Alemania)',
        'de_IT' => 'alemana (Italia)',
        'de_LI' => 'alemana (Liechtenstein)',
        'de_LU' => 'alemana (Luxenburgo)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhutan)',
        'ee' => 'eweera',
        'ee_GH' => 'eweera (Ghana)',
        'ee_TG' => 'eweera (Togo)',
        'el' => 'greziera',
        'el_CY' => 'greziera (Zipre)',
        'el_GR' => 'greziera (Grezia)',
        'en' => 'ingelesa',
        'en_001' => 'ingelesa (Mundua)',
        'en_150' => 'ingelesa (Europa)',
        'en_AE' => 'ingelesa (Arabiar Emirerri Batuak)',
        'en_AG' => 'ingelesa (Antigua eta Barbuda)',
        'en_AI' => 'ingelesa (Aingira)',
        'en_AS' => 'ingelesa (Samoa Estatubatuarra)',
        'en_AT' => 'ingelesa (Austria)',
        'en_AU' => 'ingelesa (Australia)',
        'en_BB' => 'ingelesa (Barbados)',
        'en_BE' => 'ingelesa (Belgika)',
        'en_BI' => 'ingelesa (Burundi)',
        'en_BM' => 'ingelesa (Bermuda)',
        'en_BS' => 'ingelesa (Bahamak)',
        'en_BW' => 'ingelesa (Botswana)',
        'en_BZ' => 'ingelesa (Belize)',
        'en_CA' => 'ingelesa (Kanada)',
        'en_CC' => 'ingelesa (Cocos [Keeling] uharteak)',
        'en_CH' => 'ingelesa (Suitza)',
        'en_CK' => 'ingelesa (Cook uharteak)',
        'en_CM' => 'ingelesa (Kamerun)',
        'en_CX' => 'ingelesa (Christmas uhartea)',
        'en_CY' => 'ingelesa (Zipre)',
        'en_CZ' => 'ingelesa (Txekia)',
        'en_DE' => 'ingelesa (Alemania)',
        'en_DK' => 'ingelesa (Danimarka)',
        'en_DM' => 'ingelesa (Dominika)',
        'en_EE' => 'ingelesa (Estonia)',
        'en_ER' => 'ingelesa (Eritrea)',
        'en_ES' => 'ingelesa (Espainia)',
        'en_FI' => 'ingelesa (Finlandia)',
        'en_FJ' => 'ingelesa (Fiji)',
        'en_FK' => 'ingelesa (Falklandak)',
        'en_FM' => 'ingelesa (Mikronesia)',
        'en_FR' => 'ingelesa (Frantzia)',
        'en_GB' => 'ingelesa (Erresuma Batua)',
        'en_GD' => 'ingelesa (Grenada)',
        'en_GE' => 'ingelesa (Georgia)',
        'en_GG' => 'ingelesa (Guernesey)',
        'en_GH' => 'ingelesa (Ghana)',
        'en_GI' => 'ingelesa (Gibraltar)',
        'en_GM' => 'ingelesa (Gambia)',
        'en_GS' => 'ingelesa (Hegoaldeko Georgia eta Hegoaldeko Sandwich uharteak)',
        'en_GU' => 'ingelesa (Guam)',
        'en_GY' => 'ingelesa (Guyana)',
        'en_HK' => 'ingelesa (Hong Kong Txinako AEB)',
        'en_HU' => 'ingelesa (Hungaria)',
        'en_ID' => 'ingelesa (Indonesia)',
        'en_IE' => 'ingelesa (Irlanda)',
        'en_IL' => 'ingelesa (Israel)',
        'en_IM' => 'ingelesa (Man uhartea)',
        'en_IN' => 'ingelesa (India)',
        'en_IO' => 'ingelesa (Indiako Ozeanoko lurralde britainiarra)',
        'en_IT' => 'ingelesa (Italia)',
        'en_JE' => 'ingelesa (Jersey)',
        'en_JM' => 'ingelesa (Jamaika)',
        'en_JP' => 'ingelesa (Japonia)',
        'en_KE' => 'ingelesa (Kenya)',
        'en_KI' => 'ingelesa (Kiribati)',
        'en_KN' => 'ingelesa (Saint Kitts eta Nevis)',
        'en_KY' => 'ingelesa (Kaiman uharteak)',
        'en_LC' => 'ingelesa (Santa Luzia)',
        'en_LR' => 'ingelesa (Liberia)',
        'en_LS' => 'ingelesa (Lesotho)',
        'en_LT' => 'ingelesa (Lituania)',
        'en_LV' => 'ingelesa (Letonia)',
        'en_MG' => 'ingelesa (Madagaskar)',
        'en_MH' => 'ingelesa (Marshall Uharteak)',
        'en_MO' => 'ingelesa (Macau Txinako AEB)',
        'en_MP' => 'ingelesa (Ipar Mariana uharteak)',
        'en_MS' => 'ingelesa (Montserrat)',
        'en_MT' => 'ingelesa (Malta)',
        'en_MU' => 'ingelesa (Maurizio)',
        'en_MV' => 'ingelesa (Maldivak)',
        'en_MW' => 'ingelesa (Malawi)',
        'en_MY' => 'ingelesa (Malaysia)',
        'en_NA' => 'ingelesa (Namibia)',
        'en_NF' => 'ingelesa (Norfolk uhartea)',
        'en_NG' => 'ingelesa (Nigeria)',
        'en_NL' => 'ingelesa (Herbehereak)',
        'en_NO' => 'ingelesa (Norvegia)',
        'en_NR' => 'ingelesa (Nauru)',
        'en_NU' => 'ingelesa (Niue)',
        'en_NZ' => 'ingelesa (Zeelanda Berria)',
        'en_PG' => 'ingelesa (Papua Ginea Berria)',
        'en_PH' => 'ingelesa (Filipinak)',
        'en_PK' => 'ingelesa (Pakistan)',
        'en_PL' => 'ingelesa (Polonia)',
        'en_PN' => 'ingelesa (Pitcairn uharteak)',
        'en_PR' => 'ingelesa (Puerto Rico)',
        'en_PT' => 'ingelesa (Portugal)',
        'en_PW' => 'ingelesa (Palau)',
        'en_RO' => 'ingelesa (Errumania)',
        'en_RW' => 'ingelesa (Ruanda)',
        'en_SB' => 'ingelesa (Salomon Uharteak)',
        'en_SC' => 'ingelesa (Seychelleak)',
        'en_SD' => 'ingelesa (Sudan)',
        'en_SE' => 'ingelesa (Suedia)',
        'en_SG' => 'ingelesa (Singapur)',
        'en_SH' => 'ingelesa (Santa Helena)',
        'en_SI' => 'ingelesa (Eslovenia)',
        'en_SK' => 'ingelesa (Eslovakia)',
        'en_SL' => 'ingelesa (Sierra Leona)',
        'en_SS' => 'ingelesa (Hego Sudan)',
        'en_SX' => 'ingelesa (Sint Maarten)',
        'en_SZ' => 'ingelesa (Swazilandia)',
        'en_TC' => 'ingelesa (Turk eta Caico uharteak)',
        'en_TK' => 'ingelesa (Tokelau)',
        'en_TO' => 'ingelesa (Tonga)',
        'en_TT' => 'ingelesa (Trinidad eta Tobago)',
        'en_TV' => 'ingelesa (Tuvalu)',
        'en_TZ' => 'ingelesa (Tanzania)',
        'en_UA' => 'ingelesa (Ukraina)',
        'en_UG' => 'ingelesa (Uganda)',
        'en_UM' => 'ingelesa (Ameriketako Estatu Batuetako Kanpoaldeko Uharte Txikiak)',
        'en_US' => 'ingelesa (Ameriketako Estatu Batuak)',
        'en_VC' => 'ingelesa (Saint Vincent eta Grenadinak)',
        'en_VG' => 'ingelesa (Birjina uharte britainiarrak)',
        'en_VI' => 'ingelesa (Birjina uharte amerikarrak)',
        'en_VU' => 'ingelesa (Vanuatu)',
        'en_WS' => 'ingelesa (Samoa)',
        'en_ZA' => 'ingelesa (Hegoafrika)',
        'en_ZM' => 'ingelesa (Zambia)',
        'en_ZW' => 'ingelesa (Zimbabwe)',
        'eo' => 'esperantoa',
        'eo_001' => 'esperantoa (Mundua)',
        'es' => 'gaztelania',
        'es_419' => 'gaztelania (Latinoamerika)',
        'es_AR' => 'gaztelania (Argentina)',
        'es_BO' => 'gaztelania (Bolivia)',
        'es_BR' => 'gaztelania (Brasil)',
        'es_BZ' => 'gaztelania (Belize)',
        'es_CL' => 'gaztelania (Txile)',
        'es_CO' => 'gaztelania (Kolonbia)',
        'es_CR' => 'gaztelania (Costa Rica)',
        'es_CU' => 'gaztelania (Kuba)',
        'es_DO' => 'gaztelania (Dominikar Errepublika)',
        'es_EC' => 'gaztelania (Ekuador)',
        'es_ES' => 'gaztelania (Espainia)',
        'es_GQ' => 'gaztelania (Ekuatore Ginea)',
        'es_GT' => 'gaztelania (Guatemala)',
        'es_HN' => 'gaztelania (Honduras)',
        'es_MX' => 'gaztelania (Mexiko)',
        'es_NI' => 'gaztelania (Nikaragua)',
        'es_PA' => 'gaztelania (Panama)',
        'es_PE' => 'gaztelania (Peru)',
        'es_PH' => 'gaztelania (Filipinak)',
        'es_PR' => 'gaztelania (Puerto Rico)',
        'es_PY' => 'gaztelania (Paraguai)',
        'es_SV' => 'gaztelania (El Salvador)',
        'es_US' => 'gaztelania (Ameriketako Estatu Batuak)',
        'es_UY' => 'gaztelania (Uruguai)',
        'es_VE' => 'gaztelania (Venezuela)',
        'et' => 'estoniera',
        'et_EE' => 'estoniera (Estonia)',
        'eu' => 'euskara',
        'eu_ES' => 'euskara (Espainia)',
        'fa' => 'persiera',
        'fa_AF' => 'persiera (Afganistan)',
        'fa_IR' => 'persiera (Iran)',
        'ff' => 'fula',
        'ff_Adlm' => 'fula (adlama)',
        'ff_Adlm_BF' => 'fula (adlama, Burkina Faso)',
        'ff_Adlm_CM' => 'fula (adlama, Kamerun)',
        'ff_Adlm_GH' => 'fula (adlama, Ghana)',
        'ff_Adlm_GM' => 'fula (adlama, Gambia)',
        'ff_Adlm_GN' => 'fula (adlama, Ginea)',
        'ff_Adlm_GW' => 'fula (adlama, Ginea Bissau)',
        'ff_Adlm_LR' => 'fula (adlama, Liberia)',
        'ff_Adlm_MR' => 'fula (adlama, Mauritania)',
        'ff_Adlm_NE' => 'fula (adlama, Niger)',
        'ff_Adlm_NG' => 'fula (adlama, Nigeria)',
        'ff_Adlm_SL' => 'fula (adlama, Sierra Leona)',
        'ff_Adlm_SN' => 'fula (adlama, Senegal)',
        'ff_CM' => 'fula (Kamerun)',
        'ff_GN' => 'fula (Ginea)',
        'ff_Latn' => 'fula (latinoa)',
        'ff_Latn_BF' => 'fula (latinoa, Burkina Faso)',
        'ff_Latn_CM' => 'fula (latinoa, Kamerun)',
        'ff_Latn_GH' => 'fula (latinoa, Ghana)',
        'ff_Latn_GM' => 'fula (latinoa, Gambia)',
        'ff_Latn_GN' => 'fula (latinoa, Ginea)',
        'ff_Latn_GW' => 'fula (latinoa, Ginea Bissau)',
        'ff_Latn_LR' => 'fula (latinoa, Liberia)',
        'ff_Latn_MR' => 'fula (latinoa, Mauritania)',
        'ff_Latn_NE' => 'fula (latinoa, Niger)',
        'ff_Latn_NG' => 'fula (latinoa, Nigeria)',
        'ff_Latn_SL' => 'fula (latinoa, Sierra Leona)',
        'ff_Latn_SN' => 'fula (latinoa, Senegal)',
        'ff_MR' => 'fula (Mauritania)',
        'ff_SN' => 'fula (Senegal)',
        'fi' => 'finlandiera',
        'fi_FI' => 'finlandiera (Finlandia)',
        'fo' => 'faroera',
        'fo_DK' => 'faroera (Danimarka)',
        'fo_FO' => 'faroera (Faroe uharteak)',
        'fr' => 'frantsesa',
        'fr_BE' => 'frantsesa (Belgika)',
        'fr_BF' => 'frantsesa (Burkina Faso)',
        'fr_BI' => 'frantsesa (Burundi)',
        'fr_BJ' => 'frantsesa (Benin)',
        'fr_BL' => 'frantsesa (Saint Barthélemy)',
        'fr_CA' => 'frantsesa (Kanada)',
        'fr_CD' => 'frantsesa (Kongoko Errepublika Demokratikoa)',
        'fr_CF' => 'frantsesa (Afrika Erdiko Errepublika)',
        'fr_CG' => 'frantsesa (Kongo)',
        'fr_CH' => 'frantsesa (Suitza)',
        'fr_CI' => 'frantsesa (Boli Kosta)',
        'fr_CM' => 'frantsesa (Kamerun)',
        'fr_DJ' => 'frantsesa (Djibuti)',
        'fr_DZ' => 'frantsesa (Aljeria)',
        'fr_FR' => 'frantsesa (Frantzia)',
        'fr_GA' => 'frantsesa (Gabon)',
        'fr_GF' => 'frantsesa (Guyana Frantsesa)',
        'fr_GN' => 'frantsesa (Ginea)',
        'fr_GP' => 'frantsesa (Guadalupe)',
        'fr_GQ' => 'frantsesa (Ekuatore Ginea)',
        'fr_HT' => 'frantsesa (Haiti)',
        'fr_KM' => 'frantsesa (Komoreak)',
        'fr_LU' => 'frantsesa (Luxenburgo)',
        'fr_MA' => 'frantsesa (Maroko)',
        'fr_MC' => 'frantsesa (Monako)',
        'fr_MF' => 'frantsesa (San Martin)',
        'fr_MG' => 'frantsesa (Madagaskar)',
        'fr_ML' => 'frantsesa (Mali)',
        'fr_MQ' => 'frantsesa (Martinika)',
        'fr_MR' => 'frantsesa (Mauritania)',
        'fr_MU' => 'frantsesa (Maurizio)',
        'fr_NC' => 'frantsesa (Kaledonia Berria)',
        'fr_NE' => 'frantsesa (Niger)',
        'fr_PF' => 'frantsesa (Polinesia Frantsesa)',
        'fr_PM' => 'frantsesa (Saint-Pierre eta Mikelune)',
        'fr_RE' => 'frantsesa (Reunion)',
        'fr_RW' => 'frantsesa (Ruanda)',
        'fr_SC' => 'frantsesa (Seychelleak)',
        'fr_SN' => 'frantsesa (Senegal)',
        'fr_SY' => 'frantsesa (Siria)',
        'fr_TD' => 'frantsesa (Txad)',
        'fr_TG' => 'frantsesa (Togo)',
        'fr_TN' => 'frantsesa (Tunisia)',
        'fr_VU' => 'frantsesa (Vanuatu)',
        'fr_WF' => 'frantsesa (Wallis eta Futuna)',
        'fr_YT' => 'frantsesa (Mayotte)',
        'fy' => 'mendebaldeko frisiera',
        'fy_NL' => 'mendebaldeko frisiera (Herbehereak)',
        'ga' => 'irlandera',
        'ga_GB' => 'irlandera (Erresuma Batua)',
        'ga_IE' => 'irlandera (Irlanda)',
        'gd' => 'Eskoziako gaelikoa',
        'gd_GB' => 'Eskoziako gaelikoa (Erresuma Batua)',
        'gl' => 'galiziera',
        'gl_ES' => 'galiziera (Espainia)',
        'gu' => 'gujaratera',
        'gu_IN' => 'gujaratera (India)',
        'gv' => 'manxera',
        'gv_IM' => 'manxera (Man uhartea)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'hebreera',
        'he_IL' => 'hebreera (Israel)',
        'hi' => 'hindia',
        'hi_IN' => 'hindia (India)',
        'hi_Latn' => 'hindia (latinoa)',
        'hi_Latn_IN' => 'hindia (latinoa, India)',
        'hr' => 'kroaziera',
        'hr_BA' => 'kroaziera (Bosnia-Herzegovina)',
        'hr_HR' => 'kroaziera (Kroazia)',
        'hu' => 'hungariera',
        'hu_HU' => 'hungariera (Hungaria)',
        'hy' => 'armeniera',
        'hy_AM' => 'armeniera (Armenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (Mundua)',
        'id' => 'indonesiera',
        'id_ID' => 'indonesiera (Indonesia)',
        'ie' => 'interlinguea',
        'ie_EE' => 'interlinguea (Estonia)',
        'ig' => 'igboera',
        'ig_NG' => 'igboera (Nigeria)',
        'ii' => 'Sichuango yiera',
        'ii_CN' => 'Sichuango yiera (Txina)',
        'is' => 'islandiera',
        'is_IS' => 'islandiera (Islandia)',
        'it' => 'italiera',
        'it_CH' => 'italiera (Suitza)',
        'it_IT' => 'italiera (Italia)',
        'it_SM' => 'italiera (San Marino)',
        'it_VA' => 'italiera (Vatikano Hiria)',
        'ja' => 'japoniera',
        'ja_JP' => 'japoniera (Japonia)',
        'jv' => 'javera',
        'jv_ID' => 'javera (Indonesia)',
        'ka' => 'georgiera',
        'ka_GE' => 'georgiera (Georgia)',
        'ki' => 'kikuyuera',
        'ki_KE' => 'kikuyuera (Kenya)',
        'kk' => 'kazakhera',
        'kk_Arab' => 'kazakhera (arabiarra)',
        'kk_Arab_CN' => 'kazakhera (arabiarra, Txina)',
        'kk_Cyrl' => 'kazakhera (zirilikoa)',
        'kk_Cyrl_KZ' => 'kazakhera (zirilikoa, Kazakhstan)',
        'kk_KZ' => 'kazakhera (Kazakhstan)',
        'kl' => 'groenlandiera',
        'kl_GL' => 'groenlandiera (Groenlandia)',
        'km' => 'khemerera',
        'km_KH' => 'khemerera (Kanbodia)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (India)',
        'ko' => 'koreera',
        'ko_CN' => 'koreera (Txina)',
        'ko_KP' => 'koreera (Ipar Korea)',
        'ko_KR' => 'koreera (Hego Korea)',
        'ks' => 'kaxmirera',
        'ks_Arab' => 'kaxmirera (arabiarra)',
        'ks_Arab_IN' => 'kaxmirera (arabiarra, India)',
        'ks_Deva' => 'kaxmirera (devanagaria)',
        'ks_Deva_IN' => 'kaxmirera (devanagaria, India)',
        'ks_IN' => 'kaxmirera (India)',
        'ku' => 'kurduera',
        'ku_Latn' => 'kurduera (latinoa)',
        'ku_Latn_IQ' => 'kurduera (latinoa, Irak)',
        'ku_Latn_SY' => 'kurduera (latinoa, Siria)',
        'ku_Latn_TR' => 'kurduera (latinoa, Turkia)',
        'ku_SY' => 'kurduera (Siria)',
        'ku_TR' => 'kurduera (Turkia)',
        'kw' => 'kornubiera',
        'kw_GB' => 'kornubiera (Erresuma Batua)',
        'ky' => 'kirgizera',
        'ky_KG' => 'kirgizera (Kirgizistan)',
        'lb' => 'luxenburgera',
        'lb_LU' => 'luxenburgera (Luxenburgo)',
        'lg' => 'luganda',
        'lg_UG' => 'luganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongoko Errepublika Demokratikoa)',
        'ln_CF' => 'lingala (Afrika Erdiko Errepublika)',
        'ln_CG' => 'lingala (Kongo)',
        'lo' => 'laosera',
        'lo_LA' => 'laosera (Laos)',
        'lt' => 'lituaniera',
        'lt_LT' => 'lituaniera (Lituania)',
        'lu' => 'Katangako lubera',
        'lu_CD' => 'Katangako lubera (Kongoko Errepublika Demokratikoa)',
        'lv' => 'letoniera',
        'lv_LV' => 'letoniera (Letonia)',
        'mg' => 'malgaxea',
        'mg_MG' => 'malgaxea (Madagaskar)',
        'mi' => 'maoriera',
        'mi_NZ' => 'maoriera (Zeelanda Berria)',
        'mk' => 'mazedoniera',
        'mk_MK' => 'mazedoniera (Ipar Mazedonia)',
        'ml' => 'malabarera',
        'ml_IN' => 'malabarera (India)',
        'mn' => 'mongoliera',
        'mn_MN' => 'mongoliera (Mongolia)',
        'mr' => 'marathera',
        'mr_IN' => 'marathera (India)',
        'ms' => 'malaysiera',
        'ms_BN' => 'malaysiera (Brunei)',
        'ms_ID' => 'malaysiera (Indonesia)',
        'ms_MY' => 'malaysiera (Malaysia)',
        'ms_SG' => 'malaysiera (Singapur)',
        'mt' => 'maltera',
        'mt_MT' => 'maltera (Malta)',
        'my' => 'birmaniera',
        'my_MM' => 'birmaniera (Myanmar [Birmania])',
        'nb' => 'bokmål [norvegiera]',
        'nb_NO' => 'bokmål [norvegiera] (Norvegia)',
        'nb_SJ' => 'bokmål [norvegiera] (Svalbard eta Jan Mayen uharteak)',
        'nd' => 'iparraldeko ndebeleera',
        'nd_ZW' => 'iparraldeko ndebeleera (Zimbabwe)',
        'ne' => 'nepalera',
        'ne_IN' => 'nepalera (India)',
        'ne_NP' => 'nepalera (Nepal)',
        'nl' => 'nederlandera',
        'nl_AW' => 'nederlandera (Aruba)',
        'nl_BE' => 'nederlandera (Belgika)',
        'nl_BQ' => 'nederlandera (Karibeko Herbehereak)',
        'nl_CW' => 'nederlandera (Curaçao)',
        'nl_NL' => 'nederlandera (Herbehereak)',
        'nl_SR' => 'nederlandera (Surinam)',
        'nl_SX' => 'nederlandera (Sint Maarten)',
        'nn' => 'nynorsk [norvegiera]',
        'nn_NO' => 'nynorsk [norvegiera] (Norvegia)',
        'no' => 'norvegiera',
        'no_NO' => 'norvegiera (Norvegia)',
        'oc' => 'okzitaniera',
        'oc_ES' => 'okzitaniera (Espainia)',
        'oc_FR' => 'okzitaniera (Frantzia)',
        'om' => 'oromoera',
        'om_ET' => 'oromoera (Etiopia)',
        'om_KE' => 'oromoera (Kenya)',
        'or' => 'oriya',
        'or_IN' => 'oriya (India)',
        'os' => 'osetiera',
        'os_GE' => 'osetiera (Georgia)',
        'os_RU' => 'osetiera (Errusia)',
        'pa' => 'punjabera',
        'pa_Arab' => 'punjabera (arabiarra)',
        'pa_Arab_PK' => 'punjabera (arabiarra, Pakistan)',
        'pa_Guru' => 'punjabera (gurmukhia)',
        'pa_Guru_IN' => 'punjabera (gurmukhia, India)',
        'pa_IN' => 'punjabera (India)',
        'pa_PK' => 'punjabera (Pakistan)',
        'pl' => 'poloniera',
        'pl_PL' => 'poloniera (Polonia)',
        'ps' => 'paxtunera',
        'ps_AF' => 'paxtunera (Afganistan)',
        'ps_PK' => 'paxtunera (Pakistan)',
        'pt' => 'portugesa',
        'pt_AO' => 'portugesa (Angola)',
        'pt_BR' => 'portugesa (Brasil)',
        'pt_CH' => 'portugesa (Suitza)',
        'pt_CV' => 'portugesa (Cabo Verde)',
        'pt_GQ' => 'portugesa (Ekuatore Ginea)',
        'pt_GW' => 'portugesa (Ginea Bissau)',
        'pt_LU' => 'portugesa (Luxenburgo)',
        'pt_MO' => 'portugesa (Macau Txinako AEB)',
        'pt_MZ' => 'portugesa (Mozambike)',
        'pt_PT' => 'portugesa (Portugal)',
        'pt_ST' => 'portugesa (Sao Tome eta Principe)',
        'pt_TL' => 'portugesa (Ekialdeko Timor)',
        'qu' => 'kitxua',
        'qu_BO' => 'kitxua (Bolivia)',
        'qu_EC' => 'kitxua (Ekuador)',
        'qu_PE' => 'kitxua (Peru)',
        'rm' => 'erretorromaniera',
        'rm_CH' => 'erretorromaniera (Suitza)',
        'rn' => 'rundiera',
        'rn_BI' => 'rundiera (Burundi)',
        'ro' => 'errumaniera',
        'ro_MD' => 'errumaniera (Moldavia)',
        'ro_RO' => 'errumaniera (Errumania)',
        'ru' => 'errusiera',
        'ru_BY' => 'errusiera (Bielorrusia)',
        'ru_KG' => 'errusiera (Kirgizistan)',
        'ru_KZ' => 'errusiera (Kazakhstan)',
        'ru_MD' => 'errusiera (Moldavia)',
        'ru_RU' => 'errusiera (Errusia)',
        'ru_UA' => 'errusiera (Ukraina)',
        'rw' => 'kinyaruanda',
        'rw_RW' => 'kinyaruanda (Ruanda)',
        'sa' => 'sanskritoa',
        'sa_IN' => 'sanskritoa (India)',
        'sc' => 'sardiniera',
        'sc_IT' => 'sardiniera (Italia)',
        'sd' => 'sindhia',
        'sd_Arab' => 'sindhia (arabiarra)',
        'sd_Arab_PK' => 'sindhia (arabiarra, Pakistan)',
        'sd_Deva' => 'sindhia (devanagaria)',
        'sd_Deva_IN' => 'sindhia (devanagaria, India)',
        'sd_IN' => 'sindhia (India)',
        'sd_PK' => 'sindhia (Pakistan)',
        'se' => 'iparraldeko samiera',
        'se_FI' => 'iparraldeko samiera (Finlandia)',
        'se_NO' => 'iparraldeko samiera (Norvegia)',
        'se_SE' => 'iparraldeko samiera (Suedia)',
        'sg' => 'sangoa',
        'sg_CF' => 'sangoa (Afrika Erdiko Errepublika)',
        'sh' => 'serbokroaziera',
        'sh_BA' => 'serbokroaziera (Bosnia-Herzegovina)',
        'si' => 'sinhala',
        'si_LK' => 'sinhala (Sri Lanka)',
        'sk' => 'eslovakiera',
        'sk_SK' => 'eslovakiera (Eslovakia)',
        'sl' => 'esloveniera',
        'sl_SI' => 'esloveniera (Eslovenia)',
        'sn' => 'shonera',
        'sn_ZW' => 'shonera (Zimbabwe)',
        'so' => 'somaliera',
        'so_DJ' => 'somaliera (Djibuti)',
        'so_ET' => 'somaliera (Etiopia)',
        'so_KE' => 'somaliera (Kenya)',
        'so_SO' => 'somaliera (Somalia)',
        'sq' => 'albaniera',
        'sq_AL' => 'albaniera (Albania)',
        'sq_MK' => 'albaniera (Ipar Mazedonia)',
        'sr' => 'serbiera',
        'sr_BA' => 'serbiera (Bosnia-Herzegovina)',
        'sr_Cyrl' => 'serbiera (zirilikoa)',
        'sr_Cyrl_BA' => 'serbiera (zirilikoa, Bosnia-Herzegovina)',
        'sr_Cyrl_ME' => 'serbiera (zirilikoa, Montenegro)',
        'sr_Cyrl_RS' => 'serbiera (zirilikoa, Serbia)',
        'sr_Latn' => 'serbiera (latinoa)',
        'sr_Latn_BA' => 'serbiera (latinoa, Bosnia-Herzegovina)',
        'sr_Latn_ME' => 'serbiera (latinoa, Montenegro)',
        'sr_Latn_RS' => 'serbiera (latinoa, Serbia)',
        'sr_ME' => 'serbiera (Montenegro)',
        'sr_RS' => 'serbiera (Serbia)',
        'st' => 'hegoaldeko sothoera',
        'st_LS' => 'hegoaldeko sothoera (Lesotho)',
        'st_ZA' => 'hegoaldeko sothoera (Hegoafrika)',
        'su' => 'sundanera',
        'su_ID' => 'sundanera (Indonesia)',
        'su_Latn' => 'sundanera (latinoa)',
        'su_Latn_ID' => 'sundanera (latinoa, Indonesia)',
        'sv' => 'suediera',
        'sv_AX' => 'suediera (Åland)',
        'sv_FI' => 'suediera (Finlandia)',
        'sv_SE' => 'suediera (Suedia)',
        'sw' => 'swahilia',
        'sw_CD' => 'swahilia (Kongoko Errepublika Demokratikoa)',
        'sw_KE' => 'swahilia (Kenya)',
        'sw_TZ' => 'swahilia (Tanzania)',
        'sw_UG' => 'swahilia (Uganda)',
        'ta' => 'tamilera',
        'ta_IN' => 'tamilera (India)',
        'ta_LK' => 'tamilera (Sri Lanka)',
        'ta_MY' => 'tamilera (Malaysia)',
        'ta_SG' => 'tamilera (Singapur)',
        'te' => 'telugua',
        'te_IN' => 'telugua (India)',
        'tg' => 'tajikera',
        'tg_TJ' => 'tajikera (Tajikistan)',
        'th' => 'thailandiera',
        'th_TH' => 'thailandiera (Thailandia)',
        'ti' => 'tigrinyera',
        'ti_ER' => 'tigrinyera (Eritrea)',
        'ti_ET' => 'tigrinyera (Etiopia)',
        'tk' => 'turkmenera',
        'tk_TM' => 'turkmenera (Turkmenistan)',
        'tl' => 'tagaloa',
        'tl_PH' => 'tagaloa (Filipinak)',
        'tn' => 'tswanera',
        'tn_BW' => 'tswanera (Botswana)',
        'tn_ZA' => 'tswanera (Hegoafrika)',
        'to' => 'tongera',
        'to_TO' => 'tongera (Tonga)',
        'tr' => 'turkiera',
        'tr_CY' => 'turkiera (Zipre)',
        'tr_TR' => 'turkiera (Turkia)',
        'tt' => 'tatarera',
        'tt_RU' => 'tatarera (Errusia)',
        'ug' => 'uigurrera',
        'ug_CN' => 'uigurrera (Txina)',
        'uk' => 'ukrainera',
        'uk_UA' => 'ukrainera (Ukraina)',
        'ur' => 'urdua',
        'ur_IN' => 'urdua (India)',
        'ur_PK' => 'urdua (Pakistan)',
        'uz' => 'uzbekera',
        'uz_AF' => 'uzbekera (Afganistan)',
        'uz_Arab' => 'uzbekera (arabiarra)',
        'uz_Arab_AF' => 'uzbekera (arabiarra, Afganistan)',
        'uz_Cyrl' => 'uzbekera (zirilikoa)',
        'uz_Cyrl_UZ' => 'uzbekera (zirilikoa, Uzbekistan)',
        'uz_Latn' => 'uzbekera (latinoa)',
        'uz_Latn_UZ' => 'uzbekera (latinoa, Uzbekistan)',
        'uz_UZ' => 'uzbekera (Uzbekistan)',
        'vi' => 'vietnamera',
        'vi_VN' => 'vietnamera (Vietnam)',
        'wo' => 'wolofera',
        'wo_SN' => 'wolofera (Senegal)',
        'xh' => 'xhosera',
        'xh_ZA' => 'xhosera (Hegoafrika)',
        'yi' => 'yiddisha',
        'yi_UA' => 'yiddisha (Ukraina)',
        'yo' => 'jorubera',
        'yo_BJ' => 'jorubera (Benin)',
        'yo_NG' => 'jorubera (Nigeria)',
        'za' => 'zhuangera',
        'za_CN' => 'zhuangera (Txina)',
        'zh' => 'txinera',
        'zh_CN' => 'txinera (Txina)',
        'zh_HK' => 'txinera (Hong Kong Txinako AEB)',
        'zh_Hans' => 'txinera (sinplifikatua)',
        'zh_Hans_CN' => 'txinera (sinplifikatua, Txina)',
        'zh_Hans_HK' => 'txinera (sinplifikatua, Hong Kong Txinako AEB)',
        'zh_Hans_MO' => 'txinera (sinplifikatua, Macau Txinako AEB)',
        'zh_Hans_MY' => 'txinera (sinplifikatua, Malaysia)',
        'zh_Hans_SG' => 'txinera (sinplifikatua, Singapur)',
        'zh_Hant' => 'txinera (tradizionala)',
        'zh_Hant_HK' => 'txinera (tradizionala, Hong Kong Txinako AEB)',
        'zh_Hant_MO' => 'txinera (tradizionala, Macau Txinako AEB)',
        'zh_Hant_MY' => 'txinera (tradizionala, Malaysia)',
        'zh_Hant_TW' => 'txinera (tradizionala, Taiwan)',
        'zh_MO' => 'txinera (Macau Txinako AEB)',
        'zh_SG' => 'txinera (Singapur)',
        'zh_TW' => 'txinera (Taiwan)',
        'zu' => 'zuluera',
        'zu_ZA' => 'zuluera (Hegoafrika)',
    ],
];
