<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Гринвич уақыты (Абиджан)',
        'Africa/Accra' => 'Гринвич уақыты (Аккра)',
        'Africa/Addis_Ababa' => 'Шығыс Африка уақыты (Аддис-Абеба)',
        'Africa/Algiers' => 'Орталық Еуропа уақыты (Алжир)',
        'Africa/Asmera' => 'Шығыс Африка уақыты (Асмара)',
        'Africa/Asmara' => 'Шығыс Африка уақыты (Асмара)',
        'Africa/Bamako' => 'Гринвич уақыты (Бамако)',
        'Africa/Bangui' => 'Батыс Африка уақыты (Банги)',
        'Africa/Banjul' => 'Гринвич уақыты (Банжул)',
        'Africa/Bissau' => 'Гринвич уақыты (Бисау)',
        'Africa/Blantyre' => 'Орталық Африка уақыты (Блантайр)',
        'Africa/Brazzaville' => 'Батыс Африка уақыты (Браззавиль)',
        'Africa/Bujumbura' => 'Орталық Африка уақыты (Бужумбура)',
        'Africa/Cairo' => 'Шығыс Еуропа уақыты (Каир)',
        'Africa/Casablanca' => 'Батыс Еуропа уақыты (Касабланка)',
        'Africa/Ceuta' => 'Орталық Еуропа уақыты (Сеута)',
        'Africa/Conakry' => 'Гринвич уақыты (Конакри)',
        'Africa/Dakar' => 'Гринвич уақыты (Дакар)',
        'Africa/Dar_es_Salaam' => 'Шығыс Африка уақыты (Дар-эс-Салам)',
        'Africa/Djibouti' => 'Шығыс Африка уақыты (Джибути)',
        'Africa/Douala' => 'Батыс Африка уақыты (Дуала)',
        'Africa/El_Aaiun' => 'Батыс Еуропа уақыты (Эль-Аюн)',
        'Africa/Freetown' => 'Гринвич уақыты (Фритаун)',
        'Africa/Gaborone' => 'Орталық Африка уақыты (Габороне)',
        'Africa/Harare' => 'Орталық Африка уақыты (Хараре)',
        'Africa/Johannesburg' => 'Оңтүстік Африка стандартты уақыты (Йоханнесбург)',
        'Africa/Juba' => 'Орталық Африка уақыты (Джуба)',
        'Africa/Kampala' => 'Шығыс Африка уақыты (Кампала)',
        'Africa/Khartoum' => 'Орталық Африка уақыты (Хартум)',
        'Africa/Kigali' => 'Орталық Африка уақыты (Кигали)',
        'Africa/Kinshasa' => 'Батыс Африка уақыты (Киншаса)',
        'Africa/Lagos' => 'Батыс Африка уақыты (Лагос)',
        'Africa/Libreville' => 'Батыс Африка уақыты (Либревиль)',
        'Africa/Lome' => 'Гринвич уақыты (Ломе)',
        'Africa/Luanda' => 'Батыс Африка уақыты (Луанда)',
        'Africa/Lubumbashi' => 'Орталық Африка уақыты (Лубумбаши)',
        'Africa/Lusaka' => 'Орталық Африка уақыты (Лусака)',
        'Africa/Malabo' => 'Батыс Африка уақыты (Малабо)',
        'Africa/Maputo' => 'Орталық Африка уақыты (Мапуту)',
        'Africa/Maseru' => 'Оңтүстік Африка стандартты уақыты (Масеру)',
        'Africa/Mbabane' => 'Оңтүстік Африка стандартты уақыты (Мбабане)',
        'Africa/Mogadishu' => 'Шығыс Африка уақыты (Могадишо)',
        'Africa/Monrovia' => 'Гринвич уақыты (Монровия)',
        'Africa/Nairobi' => 'Шығыс Африка уақыты (Найроби)',
        'Africa/Ndjamena' => 'Батыс Африка уақыты (Нджамена)',
        'Africa/Niamey' => 'Батыс Африка уақыты (Ниамей)',
        'Africa/Nouakchott' => 'Гринвич уақыты (Нуакшот)',
        'Africa/Ouagadougou' => 'Гринвич уақыты (Уагадугу)',
        'Africa/Porto-Novo' => 'Батыс Африка уақыты (Порто-Ново)',
        'Africa/Sao_Tome' => 'Гринвич уақыты (Сан-Томе)',
        'Africa/Tripoli' => 'Шығыс Еуропа уақыты (Триполи)',
        'Africa/Tunis' => 'Орталық Еуропа уақыты (Тунис)',
        'Africa/Windhoek' => 'Орталық Африка уақыты (Виндхук)',
        'America/Adak' => 'Гавай және Алеут аралдары уақыты (Адак)',
        'America/Anchorage' => 'Аляска уақыты (Анкоридж)',
        'America/Anguilla' => 'Атлантика уақыты (Ангилья)',
        'America/Antigua' => 'Атлантика уақыты (Антигуа)',
        'America/Araguaina' => 'Бразилия уақыты (Арагуаина)',
        'America/Argentina/La_Rioja' => 'Аргентина уақыты (Ла-Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина уақыты (Рио-Гальегос)',
        'America/Argentina/Salta' => 'Аргентина уақыты (Сальта)',
        'America/Argentina/San_Juan' => 'Аргентина уақыты (Сан-Хуан)',
        'America/Argentina/San_Luis' => 'Аргентина уақыты (Сан-Луис)',
        'America/Argentina/Tucuman' => 'Аргентина уақыты (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргентина уақыты (Ушуайя)',
        'America/Aruba' => 'Атлантика уақыты (Аруба)',
        'America/Asuncion' => 'Парагвай уақыты (Асунсьон)',
        'America/Bahia' => 'Бразилия уақыты (Баия)',
        'America/Bahia_Banderas' => 'Солтүстік Америка орталық уақыты (Баия-де-Бандерас)',
        'America/Barbados' => 'Атлантика уақыты (Барбадос)',
        'America/Belem' => 'Бразилия уақыты (Белен)',
        'America/Belize' => 'Солтүстік Америка орталық уақыты (Белиз)',
        'America/Blanc-Sablon' => 'Атлантика уақыты (Бланк-Саблон)',
        'America/Boa_Vista' => 'Амазонка уақыты (Боа-Виста)',
        'America/Bogota' => 'Колумбия уақыты (Богота)',
        'America/Boise' => 'Солтүстік Америка тау уақыты (Бойсе)',
        'America/Buenos_Aires' => 'Аргентина уақыты (Буэнос-Айрес)',
        'America/Argentina/Buenos_Aires' => 'Аргентина уақыты (Буэнос-Айрес)',
        'America/Cambridge_Bay' => 'Солтүстік Америка тау уақыты (Кембридж-Бей)',
        'America/Campo_Grande' => 'Амазонка уақыты (Кампу-Гранди)',
        'America/Cancun' => 'Солтүстік Америка шығыс уақыты (Канкун)',
        'America/Caracas' => 'Венесуэла уақыты (Каракас)',
        'America/Catamarca' => 'Аргентина уақыты (Катамарка)',
        'America/Argentina/Catamarca' => 'Аргентина уақыты (Катамарка)',
        'America/Cayenne' => 'Француз Гвианасы уақыты (Кайенна)',
        'America/Cayman' => 'Солтүстік Америка шығыс уақыты (Кайман аралдары)',
        'America/Chicago' => 'Солтүстік Америка орталық уақыты (Чикаго)',
        'America/Chihuahua' => 'Солтүстік Америка орталық уақыты (Чиуауа)',
        'America/Ciudad_Juarez' => 'Солтүстік Америка тау уақыты (Сьюдад-Хуарес)',
        'America/Coral_Harbour' => 'Солтүстік Америка шығыс уақыты (Атикокан)',
        'America/Atikokan' => 'Солтүстік Америка шығыс уақыты (Атикокан)',
        'America/Cordoba' => 'Аргентина уақыты (Кордова)',
        'America/Argentina/Cordoba' => 'Аргентина уақыты (Кордова)',
        'America/Costa_Rica' => 'Солтүстік Америка орталық уақыты (Коста-Рика)',
        'America/Coyhaique' => 'Чили уақыты (Койайке)',
        'America/Creston' => 'Солтүстік Америка тау уақыты (Крестон)',
        'America/Cuiaba' => 'Амазонка уақыты (Куяба)',
        'America/Curacao' => 'Атлантика уақыты (Кюрасао)',
        'America/Danmarkshavn' => 'Гринвич уақыты (Данмарксхавн)',
        'America/Dawson' => 'Юкон уақыты (Доусон)',
        'America/Dawson_Creek' => 'Солтүстік Америка тау уақыты (Досон-Крик)',
        'America/Denver' => 'Солтүстік Америка тау уақыты (Денвер)',
        'America/Detroit' => 'Солтүстік Америка шығыс уақыты (Детройт)',
        'America/Dominica' => 'Атлантика уақыты (Доминика)',
        'America/Edmonton' => 'Солтүстік Америка тау уақыты (Эдмонтон)',
        'America/Eirunepe' => 'Бразилия уақыты (Эйрунепе)',
        'America/El_Salvador' => 'Солтүстік Америка орталық уақыты (Сальвадор)',
        'America/Fort_Nelson' => 'Солтүстік Америка тау уақыты (Форт-Нельсон)',
        'America/Fortaleza' => 'Бразилия уақыты (Форталеза)',
        'America/Glace_Bay' => 'Атлантика уақыты (Глейс-Бей)',
        'America/Godthab' => 'Гренландия уақыты (Нуук)',
        'America/Nuuk' => 'Гренландия уақыты (Нуук)',
        'America/Goose_Bay' => 'Атлантика уақыты (Гус-Бей)',
        'America/Grand_Turk' => 'Солтүстік Америка шығыс уақыты (Гранд-Терк)',
        'America/Grenada' => 'Атлантика уақыты (Гренада)',
        'America/Guadeloupe' => 'Атлантика уақыты (Гваделупа)',
        'America/Guatemala' => 'Солтүстік Америка орталық уақыты (Гватемала)',
        'America/Guayaquil' => 'Эквадор уақыты (Гуаякиль)',
        'America/Guyana' => 'Гайана уақыты',
        'America/Halifax' => 'Атлантика уақыты (Галифакс)',
        'America/Havana' => 'Куба уақыты (Гавана)',
        'America/Hermosillo' => 'Мексика Тынық мұхит уақыты (Эрмосильо)',
        'America/Indiana/Knox' => 'Солтүстік Америка орталық уақыты (Нокс, Индиана)',
        'America/Indiana/Marengo' => 'Солтүстік Америка шығыс уақыты (Маренго, Индиана)',
        'America/Indiana/Petersburg' => 'Солтүстік Америка шығыс уақыты (Питерсберг, Индиана)',
        'America/Indiana/Tell_City' => 'Солтүстік Америка орталық уақыты (Телл-Сити, Индиана)',
        'America/Indiana/Vevay' => 'Солтүстік Америка шығыс уақыты (Вивей, Индиана)',
        'America/Indiana/Vincennes' => 'Солтүстік Америка шығыс уақыты (Винсеннес, Индиана)',
        'America/Indiana/Winamac' => 'Солтүстік Америка шығыс уақыты (Уинамак, Индиана)',
        'America/Indianapolis' => 'Солтүстік Америка шығыс уақыты (Индианаполис)',
        'America/Indiana/Indianapolis' => 'Солтүстік Америка шығыс уақыты (Индианаполис)',
        'America/Inuvik' => 'Солтүстік Америка тау уақыты (Инувик)',
        'America/Iqaluit' => 'Солтүстік Америка шығыс уақыты (Икалуит)',
        'America/Jamaica' => 'Солтүстік Америка шығыс уақыты (Ямайка)',
        'America/Jujuy' => 'Аргентина уақыты (Жужуй)',
        'America/Argentina/Jujuy' => 'Аргентина уақыты (Жужуй)',
        'America/Juneau' => 'Аляска уақыты (Джуно)',
        'America/Kentucky/Monticello' => 'Солтүстік Америка шығыс уақыты (Монтиселло, Кентукки)',
        'America/Kralendijk' => 'Атлантика уақыты (Кралендейк)',
        'America/La_Paz' => 'Боливия уақыты (Ла-Пас)',
        'America/Lima' => 'Перу уақыты (Лима)',
        'America/Los_Angeles' => 'Солтүстік Америка Тынық мұхиты уақыты (Лос-Анджелес)',
        'America/Louisville' => 'Солтүстік Америка шығыс уақыты (Луисвилл)',
        'America/Kentucky/Louisville' => 'Солтүстік Америка шығыс уақыты (Луисвилл)',
        'America/Lower_Princes' => 'Атлантика уақыты (Лоуэр-Принс-Куотер)',
        'America/Maceio' => 'Бразилия уақыты (Масейо)',
        'America/Managua' => 'Солтүстік Америка орталық уақыты (Манагуа)',
        'America/Manaus' => 'Амазонка уақыты (Манаус)',
        'America/Marigot' => 'Атлантика уақыты (Мариго)',
        'America/Martinique' => 'Атлантика уақыты (Мартиника)',
        'America/Matamoros' => 'Солтүстік Америка орталық уақыты (Матаморос)',
        'America/Mazatlan' => 'Мексика Тынық мұхит уақыты (Масатлан)',
        'America/Mendoza' => 'Аргентина уақыты (Мендоса)',
        'America/Argentina/Mendoza' => 'Аргентина уақыты (Мендоса)',
        'America/Menominee' => 'Солтүстік Америка орталық уақыты (Меномини)',
        'America/Merida' => 'Солтүстік Америка орталық уақыты (Мерида)',
        'America/Metlakatla' => 'Аляска уақыты (Метлакатла)',
        'America/Mexico_City' => 'Солтүстік Америка орталық уақыты (Мехико)',
        'America/Miquelon' => 'Сен-Пьер және Микелон уақыты',
        'America/Moncton' => 'Атлантика уақыты (Монктон)',
        'America/Monterrey' => 'Солтүстік Америка орталық уақыты (Монтеррей)',
        'America/Montevideo' => 'Уругвай уақыты (Монтевидео)',
        'America/Montserrat' => 'Атлантика уақыты (Монтсеррат)',
        'America/Nassau' => 'Солтүстік Америка шығыс уақыты (Нассау)',
        'America/New_York' => 'Солтүстік Америка шығыс уақыты (Нью-Йорк)',
        'America/Nome' => 'Аляска уақыты (Ном)',
        'America/Noronha' => 'Фернанду-ди-Норонья уақыты',
        'America/North_Dakota/Beulah' => 'Солтүстік Америка орталық уақыты (Бойла, Солтүстік Дакота)',
        'America/North_Dakota/Center' => 'Солтүстік Америка орталық уақыты (Сентер, Солтүстік Дакота)',
        'America/North_Dakota/New_Salem' => 'Солтүстік Америка орталық уақыты (Нью Сейлем, Солтүстік Дакота)',
        'America/Ojinaga' => 'Солтүстік Америка орталық уақыты (Охинага)',
        'America/Panama' => 'Солтүстік Америка шығыс уақыты (Панама)',
        'America/Paramaribo' => 'Суринам уақыты (Парамарибо)',
        'America/Phoenix' => 'Солтүстік Америка тау уақыты (Финикс)',
        'America/Port-au-Prince' => 'Солтүстік Америка шығыс уақыты (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'Атлантика уақыты (Порт-оф-Спейн)',
        'America/Porto_Velho' => 'Амазонка уақыты (Порту-Велью)',
        'America/Puerto_Rico' => 'Атлантика уақыты (Пуэрто-Рико)',
        'America/Punta_Arenas' => 'Чили уақыты (Пунта-Аренас)',
        'America/Rankin_Inlet' => 'Солтүстік Америка орталық уақыты (Ранкин-Инлет)',
        'America/Recife' => 'Бразилия уақыты (Ресифи)',
        'America/Regina' => 'Солтүстік Америка орталық уақыты (Реджайна)',
        'America/Resolute' => 'Солтүстік Америка орталық уақыты (Резольют)',
        'America/Rio_Branco' => 'Бразилия уақыты (Риу-Бранку)',
        'America/Santarem' => 'Бразилия уақыты (Сантарен)',
        'America/Santiago' => 'Чили уақыты (Сантьяго)',
        'America/Santo_Domingo' => 'Атлантика уақыты (Санто-Доминго)',
        'America/Sao_Paulo' => 'Бразилия уақыты (Сан-Паулу)',
        'America/Scoresbysund' => 'Гренландия уақыты (Иллоккортоормиут)',
        'America/Sitka' => 'Аляска уақыты (Ситка)',
        'America/St_Barthelemy' => 'Атлантика уақыты (Сен-Бартелеми)',
        'America/St_Johns' => 'Ньюфаундленд уақыты (Сент-Джонс)',
        'America/St_Kitts' => 'Атлантика уақыты (Сент-Китс)',
        'America/St_Lucia' => 'Атлантика уақыты (Сент-Люсия)',
        'America/St_Thomas' => 'Атлантика уақыты (Сент-Томас)',
        'America/St_Vincent' => 'Атлантика уақыты (Сент-Винсент)',
        'America/Swift_Current' => 'Солтүстік Америка орталық уақыты (Суифт-Каррент)',
        'America/Tegucigalpa' => 'Солтүстік Америка орталық уақыты (Тегусигальпа)',
        'America/Thule' => 'Атлантика уақыты (Туле)',
        'America/Tijuana' => 'Солтүстік Америка Тынық мұхиты уақыты (Тихуана)',
        'America/Toronto' => 'Солтүстік Америка шығыс уақыты (Торонто)',
        'America/Tortola' => 'Атлантика уақыты (Тортола)',
        'America/Vancouver' => 'Солтүстік Америка Тынық мұхиты уақыты (Ванкувер)',
        'America/Whitehorse' => 'Юкон уақыты (Уайтхорс)',
        'America/Winnipeg' => 'Солтүстік Америка орталық уақыты (Виннипег)',
        'America/Yakutat' => 'Аляска уақыты (Якутат)',
        'Antarctica/Casey' => 'Батыс Аустралия уақыты (Кейси)',
        'Antarctica/Davis' => 'Дейвис уақыты (Дэйвис)',
        'Antarctica/DumontDUrville' => 'Дюмон-д’Юрвиль уақыты',
        'Antarctica/Macquarie' => 'Шығыс Аустралия уақыты (Маккуори)',
        'Antarctica/Mawson' => 'Моусон уақыты',
        'Antarctica/McMurdo' => 'Жаңа Зеландия уақыты (Мак-Мердо)',
        'Antarctica/Palmer' => 'Чили уақыты (Палмер)',
        'Antarctica/Rothera' => 'Ротера уақыты',
        'Antarctica/Syowa' => 'Сёва уақыты',
        'Antarctica/Troll' => 'Гринвич уақыты (Тролль)',
        'Antarctica/Vostok' => 'Восток уақыты',
        'Arctic/Longyearbyen' => 'Орталық Еуропа уақыты (Лонгйир)',
        'Asia/Aden' => 'Сауд Арабиясы уақыты (Аден)',
        'Asia/Almaty' => 'Қазақстан уақыты (Алматы)',
        'Asia/Amman' => 'Шығыс Еуропа уақыты (Амман)',
        'Asia/Anadyr' => 'Ресей уақыты (Анадыр)',
        'Asia/Aqtau' => 'Қазақстан уақыты (Ақтау)',
        'Asia/Aqtobe' => 'Қазақстан уақыты (Ақтөбе)',
        'Asia/Ashgabat' => 'Түрікменстан уақыты (Ашхабад)',
        'Asia/Atyrau' => 'Қазақстан уақыты (Атырау)',
        'Asia/Baghdad' => 'Сауд Арабиясы уақыты (Бағдат)',
        'Asia/Bahrain' => 'Сауд Арабиясы уақыты (Бахрейн)',
        'Asia/Baku' => 'Әзірбайжан уақыты (Баку)',
        'Asia/Bangkok' => 'Үндіқытай уақыты (Бангкок)',
        'Asia/Barnaul' => 'Красноярск уақыты (Барнауыл)',
        'Asia/Beirut' => 'Шығыс Еуропа уақыты (Бейрут)',
        'Asia/Bishkek' => 'Қырғызстан уақыты (Бішкек)',
        'Asia/Brunei' => 'Бруней-Даруссалам уақыты',
        'Asia/Calcutta' => 'Үндістан стандартты уақыты (Калькутта)',
        'Asia/Kolkata' => 'Үндістан стандартты уақыты (Калькутта)',
        'Asia/Chita' => 'Якутск уақыты (Чита)',
        'Asia/Colombo' => 'Үндістан стандартты уақыты (Коломбо)',
        'Asia/Damascus' => 'Шығыс Еуропа уақыты (Дамаск)',
        'Asia/Dhaka' => 'Бангладеш уақыты (Дакка)',
        'Asia/Dili' => 'Шығыс Тимор уақыты (Дили)',
        'Asia/Dubai' => 'Парсы шығанағы стандартты уақыты (Дубай)',
        'Asia/Dushanbe' => 'Тәжікстан уақыты (Душанбе)',
        'Asia/Famagusta' => 'Шығыс Еуропа уақыты (Фамагуста)',
        'Asia/Gaza' => 'Шығыс Еуропа уақыты (Газа)',
        'Asia/Hebron' => 'Шығыс Еуропа уақыты (Хеврон)',
        'Asia/Hong_Kong' => 'Гонконг уақыты',
        'Asia/Hovd' => 'Ховд уақыты',
        'Asia/Irkutsk' => 'Иркутск уақыты',
        'Asia/Jakarta' => 'Батыс Индонезия уақыты (Джакарта)',
        'Asia/Jayapura' => 'Шығыс Индонезия уақыты (Джаяпура)',
        'Asia/Jerusalem' => 'Израиль уақыты (Иерусалим)',
        'Asia/Kabul' => 'Ауғанстан уақыты (Кабул)',
        'Asia/Kamchatka' => 'Ресей уақыты (Камчатка)',
        'Asia/Karachi' => 'Пәкістан уақыты (Карачи)',
        'Asia/Katmandu' => 'Непал уақыты (Катманду)',
        'Asia/Kathmandu' => 'Непал уақыты (Катманду)',
        'Asia/Khandyga' => 'Якутск уақыты (Хандыга)',
        'Asia/Krasnoyarsk' => 'Красноярск уақыты',
        'Asia/Kuala_Lumpur' => 'Малайзия уақыты (Куала-Лумпур)',
        'Asia/Kuching' => 'Малайзия уақыты (Кучинг)',
        'Asia/Kuwait' => 'Сауд Арабиясы уақыты (Кувейт)',
        'Asia/Macau' => 'Қытай уақыты (Макао)',
        'Asia/Magadan' => 'Магадан уақыты',
        'Asia/Makassar' => 'Орталық Индонезия уақыты (Макасар)',
        'Asia/Manila' => 'Филиппин аралдары уақыты (Манила)',
        'Asia/Muscat' => 'Парсы шығанағы стандартты уақыты (Маскат)',
        'Asia/Nicosia' => 'Шығыс Еуропа уақыты (Никосия)',
        'Asia/Novokuznetsk' => 'Красноярск уақыты (Новокузнецк)',
        'Asia/Novosibirsk' => 'Красноярск уақыты (Новосібір)',
        'Asia/Omsk' => 'Омбы уақыты',
        'Asia/Oral' => 'Қазақстан уақыты (Орал)',
        'Asia/Phnom_Penh' => 'Үндіқытай уақыты (Пномпень)',
        'Asia/Pontianak' => 'Батыс Индонезия уақыты (Понтианак)',
        'Asia/Pyongyang' => 'Корея уақыты (Пхеньян)',
        'Asia/Qatar' => 'Сауд Арабиясы уақыты (Катар)',
        'Asia/Qostanay' => 'Қазақстан уақыты (Қостанай)',
        'Asia/Qyzylorda' => 'Қазақстан уақыты (Қызылорда)',
        'Asia/Rangoon' => 'Мьянма уақыты (Янгон)',
        'Asia/Yangon' => 'Мьянма уақыты (Янгон)',
        'Asia/Riyadh' => 'Сауд Арабиясы уақыты (Эр-Рияд)',
        'Asia/Saigon' => 'Үндіқытай уақыты (Хошимин)',
        'Asia/Ho_Chi_Minh' => 'Үндіқытай уақыты (Хошимин)',
        'Asia/Sakhalin' => 'Магадан уақыты (Сахалин)',
        'Asia/Samarkand' => 'Өзбекстан уақыты (Самарқанд)',
        'Asia/Seoul' => 'Корея уақыты (Сеул)',
        'Asia/Shanghai' => 'Қытай уақыты (Шанхай)',
        'Asia/Singapore' => 'Сингапур стандартты уақыты',
        'Asia/Srednekolymsk' => 'Магадан уақыты (Среднеколымск)',
        'Asia/Taipei' => 'Тайбэй уақыты',
        'Asia/Tashkent' => 'Өзбекстан уақыты (Ташкент)',
        'Asia/Tbilisi' => 'Грузия уақыты (Тбилиси)',
        'Asia/Tehran' => 'Иран уақыты (Тегеран)',
        'Asia/Thimphu' => 'Бутан уақыты (Тхимпху)',
        'Asia/Tokyo' => 'Жапония уақыты (Токио)',
        'Asia/Tomsk' => 'Красноярск уақыты (Томск)',
        'Asia/Ulaanbaatar' => 'Ұланбатыр уақыты',
        'Asia/Urumqi' => 'Қытай уақыты (Үрімші)',
        'Asia/Ust-Nera' => 'Владивосток уақыты (Усть-Нера)',
        'Asia/Vientiane' => 'Үндіқытай уақыты (Вьентьян)',
        'Asia/Vladivostok' => 'Владивосток уақыты',
        'Asia/Yakutsk' => 'Якутск уақыты',
        'Asia/Yekaterinburg' => 'Екатеринбург уақыты',
        'Asia/Yerevan' => 'Армения уақыты (Ереван)',
        'Atlantic/Azores' => 'Азор аралдары уақыты',
        'Atlantic/Bermuda' => 'Атлантика уақыты (Бермуд аралдары)',
        'Atlantic/Canary' => 'Батыс Еуропа уақыты (Канар аралдары)',
        'Atlantic/Cape_Verde' => 'Кабо-Верде уақыты',
        'Atlantic/Faeroe' => 'Батыс Еуропа уақыты (Фарер аралдары)',
        'Atlantic/Faroe' => 'Батыс Еуропа уақыты (Фарер аралдары)',
        'Atlantic/Madeira' => 'Батыс Еуропа уақыты (Мадейра)',
        'Atlantic/Reykjavik' => 'Гринвич уақыты (Рейкьявик)',
        'Atlantic/South_Georgia' => 'Оңтүстік Георгия уақыты',
        'Atlantic/St_Helena' => 'Гринвич уақыты (Әулие Елена аралы)',
        'Atlantic/Stanley' => 'Фолкленд аралдары уақыты (Стэнли)',
        'Australia/Adelaide' => 'Орталық Аустралия уақыты (Аделаида)',
        'Australia/Brisbane' => 'Шығыс Аустралия уақыты (Брисбен)',
        'Australia/Broken_Hill' => 'Орталық Аустралия уақыты (Брокен-Хилл)',
        'Australia/Darwin' => 'Орталық Аустралия уақыты (Дарвин)',
        'Australia/Eucla' => 'Аустралия орталық-батыс уақыты (Юкла)',
        'Australia/Hobart' => 'Шығыс Аустралия уақыты (Хобарт)',
        'Australia/Lindeman' => 'Шығыс Аустралия уақыты (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд-Хау уақыты',
        'Australia/Melbourne' => 'Шығыс Аустралия уақыты (Мельбурн)',
        'Australia/Perth' => 'Батыс Аустралия уақыты (Перт)',
        'Australia/Sydney' => 'Шығыс Аустралия уақыты (Сидней)',
        'Etc/GMT' => 'Гринвич уақыты',
        'Etc/UTC' => 'Дүниежүзілік үйлестірілген уақыт',
        'Europe/Amsterdam' => 'Орталық Еуропа уақыты (Амстердам)',
        'Europe/Andorra' => 'Орталық Еуропа уақыты (Андорра)',
        'Europe/Astrakhan' => 'Ресей уақыты (Астрахан)',
        'Europe/Athens' => 'Шығыс Еуропа уақыты (Афина)',
        'Europe/Belgrade' => 'Орталық Еуропа уақыты (Белград)',
        'Europe/Berlin' => 'Орталық Еуропа уақыты (Берлин)',
        'Europe/Bratislava' => 'Орталық Еуропа уақыты (Братислава)',
        'Europe/Brussels' => 'Орталық Еуропа уақыты (Брюссель)',
        'Europe/Bucharest' => 'Шығыс Еуропа уақыты (Бухарест)',
        'Europe/Budapest' => 'Орталық Еуропа уақыты (Будапешт)',
        'Europe/Busingen' => 'Орталық Еуропа уақыты (Бюзинген-ам-Хохрайн)',
        'Europe/Chisinau' => 'Шығыс Еуропа уақыты (Кишинев)',
        'Europe/Copenhagen' => 'Орталық Еуропа уақыты (Копенгаген)',
        'Europe/Dublin' => 'Гринвич уақыты (Дублин)',
        'Europe/Gibraltar' => 'Орталық Еуропа уақыты (Гибралтар)',
        'Europe/Guernsey' => 'Гринвич уақыты (Гернси)',
        'Europe/Helsinki' => 'Шығыс Еуропа уақыты (Хельсинки)',
        'Europe/Isle_of_Man' => 'Гринвич уақыты (Мэн аралы)',
        'Europe/Istanbul' => 'Түркия уақыты (Стамбұл)',
        'Europe/Jersey' => 'Гринвич уақыты (Джерси)',
        'Europe/Kaliningrad' => 'Шығыс Еуропа уақыты (Калининград)',
        'Europe/Kiev' => 'Шығыс Еуропа уақыты (Киев)',
        'Europe/Kyiv' => 'Шығыс Еуропа уақыты (Киев)',
        'Europe/Kirov' => 'Мәскеу уақыты (Киров)',
        'Europe/Lisbon' => 'Батыс Еуропа уақыты (Лиссабон)',
        'Europe/Ljubljana' => 'Орталық Еуропа уақыты (Любляна)',
        'Europe/London' => 'Гринвич уақыты (Лондон)',
        'Europe/Luxembourg' => 'Орталық Еуропа уақыты (Люксембург)',
        'Europe/Madrid' => 'Орталық Еуропа уақыты (Мадрид)',
        'Europe/Malta' => 'Орталық Еуропа уақыты (Мальта)',
        'Europe/Mariehamn' => 'Шығыс Еуропа уақыты (Мариехамн)',
        'Europe/Minsk' => 'Мәскеу уақыты (Минск)',
        'Europe/Monaco' => 'Орталық Еуропа уақыты (Монако)',
        'Europe/Moscow' => 'Мәскеу уақыты',
        'Europe/Oslo' => 'Орталық Еуропа уақыты (Осло)',
        'Europe/Paris' => 'Орталық Еуропа уақыты (Париж)',
        'Europe/Podgorica' => 'Орталық Еуропа уақыты (Подгорица)',
        'Europe/Prague' => 'Орталық Еуропа уақыты (Прага)',
        'Europe/Riga' => 'Шығыс Еуропа уақыты (Рига)',
        'Europe/Rome' => 'Орталық Еуропа уақыты (Рим)',
        'Europe/Samara' => 'Ресей уақыты (Самара)',
        'Europe/San_Marino' => 'Орталық Еуропа уақыты (Сан-Марино)',
        'Europe/Sarajevo' => 'Орталық Еуропа уақыты (Сараево)',
        'Europe/Saratov' => 'Ресей уақыты (Саратов)',
        'Europe/Simferopol' => 'Мәскеу уақыты (Симферополь)',
        'Europe/Skopje' => 'Орталық Еуропа уақыты (Скопье)',
        'Europe/Sofia' => 'Шығыс Еуропа уақыты (София)',
        'Europe/Stockholm' => 'Орталық Еуропа уақыты (Стокгольм)',
        'Europe/Tallinn' => 'Шығыс Еуропа уақыты (Таллин)',
        'Europe/Tirane' => 'Орталық Еуропа уақыты (Тирана)',
        'Europe/Ulyanovsk' => 'Ресей уақыты (Ульяновск)',
        'Europe/Vaduz' => 'Орталық Еуропа уақыты (Вадуц)',
        'Europe/Vatican' => 'Орталық Еуропа уақыты (Ватикан)',
        'Europe/Vienna' => 'Орталық Еуропа уақыты (Вена)',
        'Europe/Vilnius' => 'Шығыс Еуропа уақыты (Вильнюс)',
        'Europe/Volgograd' => 'Мәскеу уақыты (Волгоград)',
        'Europe/Warsaw' => 'Орталық Еуропа уақыты (Варшава)',
        'Europe/Zagreb' => 'Орталық Еуропа уақыты (Загреб)',
        'Europe/Zurich' => 'Орталық Еуропа уақыты (Цюрих)',
        'Indian/Antananarivo' => 'Шығыс Африка уақыты (Антананариву)',
        'Indian/Chagos' => 'Үнді мұхиты уақыты (Чагос)',
        'Indian/Christmas' => 'Рождество аралының уақыты',
        'Indian/Cocos' => 'Кокос аралдарының уақыты',
        'Indian/Comoro' => 'Шығыс Африка уақыты (Комор аралдары)',
        'Indian/Kerguelen' => 'Францияның оңтүстік аймағы және Антарктика уақыты (Кергелен)',
        'Indian/Mahe' => 'Сейшель аралдары уақыты (Маэ)',
        'Indian/Maldives' => 'Мальдив аралдары уақыты',
        'Indian/Mauritius' => 'Маврикий уақыты',
        'Indian/Mayotte' => 'Шығыс Африка уақыты (Майотта)',
        'Indian/Reunion' => 'Реюньон уақыты',
        'Pacific/Apia' => 'Апиа уақыты',
        'Pacific/Auckland' => 'Жаңа Зеландия уақыты (Окленд)',
        'Pacific/Bougainville' => 'Папуа – Жаңа Гвинея уақыты (Бугенвиль)',
        'Pacific/Chatham' => 'Чатем уақыты',
        'Pacific/Easter' => 'Пасха аралы уақыты',
        'Pacific/Efate' => 'Вануату уақыты (Эфате)',
        'Pacific/Enderbury' => 'Феникс аралдары уақыты (Кантон)',
        'Pacific/Kanton' => 'Феникс аралдары уақыты (Кантон)',
        'Pacific/Fakaofo' => 'Токелау уақыты (Факаофо)',
        'Pacific/Fiji' => 'Фиджи уақыты',
        'Pacific/Funafuti' => 'Тувалу уақыты (Фунафути)',
        'Pacific/Galapagos' => 'Галапагос уақыты',
        'Pacific/Gambier' => 'Гамбье уақыты',
        'Pacific/Guadalcanal' => 'Соломон аралдары уақыты (Гуадалканал)',
        'Pacific/Guam' => 'Чаморро стандартты уақыты (Гуам)',
        'Pacific/Honolulu' => 'Гавай және Алеут аралдары стандартты уақыты (Гонолулу)',
        'Pacific/Kiritimati' => 'Лайн аралдары уақыты (Киритимати)',
        'Pacific/Kosrae' => 'Кусаие уақыты',
        'Pacific/Kwajalein' => 'Маршалл аралдары уақыты (Кваджалейн)',
        'Pacific/Majuro' => 'Маршалл аралдары уақыты (Маджуро)',
        'Pacific/Marquesas' => 'Маркиз аралдары уақыты',
        'Pacific/Midway' => 'Самоа уақыты (Мидуэй)',
        'Pacific/Nauru' => 'Науру уақыты',
        'Pacific/Niue' => 'Ниуэ уақыты',
        'Pacific/Norfolk' => 'Норфолк аралы уақыты',
        'Pacific/Noumea' => 'Жаңа Каледония уақыты (Нумеа)',
        'Pacific/Pago_Pago' => 'Самоа уақыты (Паго-Паго)',
        'Pacific/Palau' => 'Палау уақыты',
        'Pacific/Pitcairn' => 'Питкэрн уақыты',
        'Pacific/Ponape' => 'Понпеи уақыты (Понапе)',
        'Pacific/Pohnpei' => 'Понпеи уақыты (Понапе)',
        'Pacific/Port_Moresby' => 'Папуа – Жаңа Гвинея уақыты (Порт-Морсби)',
        'Pacific/Rarotonga' => 'Кук аралдарының уақыты (Раротонга)',
        'Pacific/Saipan' => 'Чаморро стандартты уақыты (Сайпан)',
        'Pacific/Tahiti' => 'Таити уақыты',
        'Pacific/Tarawa' => 'Гилберт аралдарының уақыты (Тарава)',
        'Pacific/Tongatapu' => 'Тонга уақыты (Тонгатапу)',
        'Pacific/Truk' => 'Трук уақыты',
        'Pacific/Chuuk' => 'Трук уақыты',
        'Pacific/Wake' => 'Уэйк аралы уақыты',
        'Pacific/Wallis' => 'Уоллис және Футуна уақыты',
    ],
    'Meta' => [],
];
