<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'pesetă andorrană',
        ],
        'AED' => [
            'AED',
            'dirham din Emiratele Arabe Unite',
        ],
        'AFN' => [
            'AFN',
            'afgani afgan',
        ],
        'ALL' => [
            'ALL',
            'lek',
        ],
        'AMD' => [
            'AMD',
            'dram armenesc',
        ],
        'ANG' => [
            'ANG',
            'gulden neerlandez antilez',
        ],
        'AOA' => [
            'AOA',
            'kwanza angoleză',
        ],
        'ARP' => [
            'ARP',
            'peso argentinian (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'peso argentinian',
        ],
        'ATS' => [
            'ATS',
            'șiling austriac',
        ],
        'AUD' => [
            'AUD',
            'dolar australian',
        ],
        'AWG' => [
            'AWG',
            'florin aruban',
        ],
        'AZM' => [
            'AZM',
            'manat azer (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'manat azer',
        ],
        'BAD' => [
            'BAD',
            'dinar Bosnia-Herțegovina (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'marcă convertibilă',
        ],
        'BBD' => [
            'BBD',
            'dolar din Barbados',
        ],
        'BDT' => [
            'BDT',
            'taka din Bangladesh',
        ],
        'BEC' => [
            'BEC',
            'franc belgian (convertibil)',
        ],
        'BEF' => [
            'BEF',
            'franc belgian',
        ],
        'BEL' => [
            'BEL',
            'franc belgian (financiar)',
        ],
        'BGN' => [
            'BGN',
            'leva',
        ],
        'BHD' => [
            'BHD',
            'dinar din Bahrain',
        ],
        'BIF' => [
            'BIF',
            'franc burundez',
        ],
        'BMD' => [
            'BMD',
            'dolar din Bermuda',
        ],
        'BND' => [
            'BND',
            'dolar din Brunei',
        ],
        'BOB' => [
            'BOB',
            'boliviano',
        ],
        'BOP' => [
            'BOP',
            'peso bolivian',
        ],
        'BOV' => [
            'BOV',
            'mvdol bolivian',
        ],
        'BRE' => [
            'BRE',
            'cruzeiro brazilian (1990–1993)',
        ],
        'BRL' => [
            'BRL',
            'real',
        ],
        'BRR' => [
            'BRR',
            'cruzeiro brazilian (1993–1994)',
        ],
        'BSD' => [
            'BSD',
            'dolar din Bahamas',
        ],
        'BTN' => [
            'BTN',
            'ngultrum din Bhutan',
        ],
        'BUK' => [
            'BUK',
            'kyat birman',
        ],
        'BWP' => [
            'BWP',
            'pula Botswana',
        ],
        'BYN' => [
            'BYN',
            'rublă belarusă',
        ],
        'BYR' => [
            'BYR',
            'rublă belarusă (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'dolar din Belize',
        ],
        'CAD' => [
            'CAD',
            'dolar canadian',
        ],
        'CDF' => [
            'CDF',
            'franc congolez',
        ],
        'CHF' => [
            'CHF',
            'franc elvețian',
        ],
        'CLP' => [
            'CLP',
            'peso chilian',
        ],
        'CNH' => [
            'CNH',
            'yuan chinezesc (offshore)',
        ],
        'CNY' => [
            'CNY',
            'yuan chinezesc',
        ],
        'COP' => [
            'COP',
            'peso columbian',
        ],
        'CRC' => [
            'CRC',
            'colón costarican',
        ],
        'CSD' => [
            'CSD',
            'dinar Serbia și Muntenegru (2002–2006)',
        ],
        'CUC' => [
            'CUC',
            'peso cubanez convertibil',
        ],
        'CUP' => [
            'CUP',
            'peso cubanez',
        ],
        'CVE' => [
            'CVE',
            'escudo caboverdian',
        ],
        'CYP' => [
            'CYP',
            'liră cipriotă',
        ],
        'CZK' => [
            'CZK',
            'coroană cehă',
        ],
        'DDM' => [
            'DDM',
            'marcă est-germană',
        ],
        'DEM' => [
            'DEM',
            'marcă germană',
        ],
        'DJF' => [
            'DJF',
            'franc djiboutian',
        ],
        'DKK' => [
            'DKK',
            'coroană daneză',
        ],
        'DOP' => [
            'DOP',
            'peso dominican',
        ],
        'DZD' => [
            'DZD',
            'dinar algerian',
        ],
        'ECS' => [
            'ECS',
            'sucre Ecuador',
        ],
        'EEK' => [
            'EEK',
            'coroană estoniană',
        ],
        'EGP' => [
            'EGP',
            'liră egipteană',
        ],
        'ERN' => [
            'ERN',
            'nakfa eritreeană',
        ],
        'ESA' => [
            'ESA',
            'peseta spaniolă (cont A)',
        ],
        'ESB' => [
            'ESB',
            'peseta spaniolă (cont convertibil)',
        ],
        'ESP' => [
            'ESP',
            'pesetă spaniolă',
        ],
        'ETB' => [
            'ETB',
            'birr etiopian',
        ],
        'EUR' => [
            'EUR',
            'euro',
        ],
        'FIM' => [
            'FIM',
            'marcă finlandeză',
        ],
        'FJD' => [
            'FJD',
            'dolar fijian',
        ],
        'FKP' => [
            'FKP',
            'liră din Insulele Falkland',
        ],
        'FRF' => [
            'FRF',
            'franc francez',
        ],
        'GBP' => [
            'GBP',
            'liră sterlină',
        ],
        'GEL' => [
            'GEL',
            'lari georgian',
        ],
        'GHC' => [
            'GHC',
            'cedi Ghana (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'cedi ghanez',
        ],
        'GIP' => [
            'GIP',
            'liră din Gibraltar',
        ],
        'GMD' => [
            'GMD',
            'dalasi din Gambia',
        ],
        'GNF' => [
            'GNF',
            'franc guineean',
        ],
        'GRD' => [
            'GRD',
            'drahmă grecească',
        ],
        'GTQ' => [
            'GTQ',
            'quetzal guatemalez',
        ],
        'GWP' => [
            'GWP',
            'peso Guineea-Bissau',
        ],
        'GYD' => [
            'GYD',
            'dolar guyanez',
        ],
        'HKD' => [
            'HKD',
            'dolar din Hong Kong',
        ],
        'HNL' => [
            'HNL',
            'lempira honduriană',
        ],
        'HRD' => [
            'HRD',
            'dinar croat',
        ],
        'HRK' => [
            'HRK',
            'kuna',
        ],
        'HTG' => [
            'HTG',
            'gourde din Haiti',
        ],
        'HUF' => [
            'HUF',
            'forint',
        ],
        'IDR' => [
            'IDR',
            'rupie indoneziană',
        ],
        'IEP' => [
            'IEP',
            'liră irlandeză',
        ],
        'ILP' => [
            'ILP',
            'liră israeliană',
        ],
        'ILS' => [
            'ILS',
            'shekel israelian nou',
        ],
        'INR' => [
            'INR',
            'rupie indiană',
        ],
        'IQD' => [
            'IQD',
            'dinar irakian',
        ],
        'IRR' => [
            'IRR',
            'rial iranian',
        ],
        'ISK' => [
            'ISK',
            'coroană islandeză',
        ],
        'ITL' => [
            'ITL',
            'liră italiană',
        ],
        'JMD' => [
            'JMD',
            'dolar jamaican',
        ],
        'JOD' => [
            'JOD',
            'dinar iordanian',
        ],
        'JPY' => [
            'JPY',
            'yen japonez',
        ],
        'KES' => [
            'KES',
            'șiling kenyan',
        ],
        'KGS' => [
            'KGS',
            'som kârgâz',
        ],
        'KHR' => [
            'KHR',
            'riel cambodgian',
        ],
        'KMF' => [
            'KMF',
            'franc comorian',
        ],
        'KPW' => [
            'KPW',
            'won nord-coreean',
        ],
        'KRW' => [
            'KRW',
            'won sud-coreean',
        ],
        'KWD' => [
            'KWD',
            'dinar kuweitian',
        ],
        'KYD' => [
            'KYD',
            'dolar din Insulele Cayman',
        ],
        'KZT' => [
            'KZT',
            'tenge kazahă',
        ],
        'LAK' => [
            'LAK',
            'kip laoțian',
        ],
        'LBP' => [
            'LBP',
            'liră libaneză',
        ],
        'LKR' => [
            'LKR',
            'rupie srilankeză',
        ],
        'LRD' => [
            'LRD',
            'dolar liberian',
        ],
        'LSL' => [
            'LSL',
            'loti lesothian',
        ],
        'LTL' => [
            'LTL',
            'litu lituanian',
        ],
        'LUC' => [
            'LUC',
            'franc convertibil luxemburghez',
        ],
        'LUF' => [
            'LUF',
            'franc luxemburghez',
        ],
        'LUL' => [
            'LUL',
            'franc financiar luxemburghez',
        ],
        'LVL' => [
            'LVL',
            'lats letonian',
        ],
        'LVR' => [
            'LVR',
            'rublă Letonia',
        ],
        'LYD' => [
            'LYD',
            'dinar libian',
        ],
        'MAD' => [
            'MAD',
            'dirham marocan',
        ],
        'MAF' => [
            'MAF',
            'franc marocan',
        ],
        'MDL' => [
            'MDL',
            'leu moldovenesc',
        ],
        'MGA' => [
            'MGA',
            'ariary malgaș',
        ],
        'MGF' => [
            'MGF',
            'franc Madagascar',
        ],
        'MKD' => [
            'MKD',
            'denar',
        ],
        'MLF' => [
            'MLF',
            'franc Mali',
        ],
        'MMK' => [
            'MMK',
            'kyat din Myanmar',
        ],
        'MNT' => [
            'MNT',
            'tugrik mongol',
        ],
        'MOP' => [
            'MOP',
            'pataca din Macao',
        ],
        'MRO' => [
            'MRO',
            'ouguiya mauritană (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'ouguiya mauritană',
        ],
        'MTL' => [
            'MTL',
            'liră malteză',
        ],
        'MUR' => [
            'MUR',
            'rupie mauritiană',
        ],
        'MVR' => [
            'MVR',
            'rufiyaa maldiviană',
        ],
        'MWK' => [
            'MWK',
            'kwacha malawiană',
        ],
        'MXN' => [
            'MXN',
            'peso mexican',
        ],
        'MXP' => [
            'MXP',
            'peso mexican de argint (1861–1992)',
        ],
        'MYR' => [
            'MYR',
            'ringgit malaiezian',
        ],
        'MZE' => [
            'MZE',
            'escudo Mozambic',
        ],
        'MZM' => [
            'MZM',
            'metical Mozambic vechi',
        ],
        'MZN' => [
            'MZN',
            'metical mozambican',
        ],
        'NAD' => [
            'NAD',
            'dolar namibian',
        ],
        'NGN' => [
            'NGN',
            'naira nigeriană',
        ],
        'NIC' => [
            'NIC',
            'cordoba nicaraguană (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'córdoba oro',
        ],
        'NLG' => [
            'NLG',
            'gulden olandez',
        ],
        'NOK' => [
            'NOK',
            'coroană norvegiană',
        ],
        'NPR' => [
            'NPR',
            'rupie nepaleză',
        ],
        'NZD' => [
            'NZD',
            'dolar neozeelandez',
        ],
        'OMR' => [
            'OMR',
            'rial omanez',
        ],
        'PAB' => [
            'PAB',
            'balboa panameză',
        ],
        'PEI' => [
            'PEI',
            'inti peruvian',
        ],
        'PEN' => [
            'PEN',
            'sol',
        ],
        'PES' => [
            'PES',
            'sol peruvian (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'kina din Papua-Noua Guinee',
        ],
        'PHP' => [
            'PHP',
            'peso filipinez',
        ],
        'PKR' => [
            'PKR',
            'rupie pakistaneză',
        ],
        'PLN' => [
            'PLN',
            'zlot',
        ],
        'PLZ' => [
            'PLZ',
            'zlot polonez (1950–1995)',
        ],
        'PYG' => [
            'PYG',
            'guarani',
        ],
        'QAR' => [
            'QAR',
            'rial qatarian',
        ],
        'RHD' => [
            'RHD',
            'dolar rhodesian',
        ],
        'ROL' => [
            'ROL',
            'leu românesc (1952–2006)',
        ],
        'RON' => [
            'RON',
            'leu românesc',
        ],
        'RSD' => [
            'RSD',
            'dinar sârbesc',
        ],
        'RUB' => [
            'RUB',
            'rublă rusească',
        ],
        'RWF' => [
            'RWF',
            'franc rwandez',
        ],
        'SAR' => [
            'SAR',
            'rial saudit',
        ],
        'SBD' => [
            'SBD',
            'dolar din Insulele Solomon',
        ],
        'SCR' => [
            'SCR',
            'rupie seychelleză',
        ],
        'SDD' => [
            'SDD',
            'dinar sudanez',
        ],
        'SDG' => [
            'SDG',
            'liră sudaneză',
        ],
        'SDP' => [
            'SDP',
            'liră sudaneză (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'coroană suedeză',
        ],
        'SGD' => [
            'SGD',
            'dolar singaporez',
        ],
        'SHP' => [
            'SHP',
            'liră din Sfânta Elena (Sfânta Elena și Ascension)',
        ],
        'SIT' => [
            'SIT',
            'tolar sloven',
        ],
        'SKK' => [
            'SKK',
            'coroană slovacă',
        ],
        'SLE' => [
            'SLE',
            'leone din Sierra Leone',
        ],
        'SLL' => [
            'SLL',
            'leone din Sierra Leone (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'șiling somalez',
        ],
        'SRD' => [
            'SRD',
            'dolar surinamez',
        ],
        'SRG' => [
            'SRG',
            'gulden Surinam',
        ],
        'SSP' => [
            'SSP',
            'liră din Sudanul de Sud',
        ],
        'STD' => [
            'STD',
            'dobra Sao Tome și Principe (1977–2017)',
        ],
        'STN' => [
            'STN',
            'dobra din São Tomé și Príncipe',
        ],
        'SUR' => [
            'SUR',
            'rublă sovietică',
        ],
        'SVC' => [
            'SVC',
            'colon El Salvador',
        ],
        'SYP' => [
            'SYP',
            'liră siriană',
        ],
        'SZL' => [
            'SZL',
            'lilangeni din Swaziland',
        ],
        'THB' => [
            'THB',
            'baht thailandez',
        ],
        'TJR' => [
            'TJR',
            'rublă Tadjikistan',
        ],
        'TJS' => [
            'TJS',
            'somoni tadjic',
        ],
        'TMM' => [
            'TMM',
            'manat turkmen (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'manat turkmen',
        ],
        'TND' => [
            'TND',
            'dinar tunisian',
        ],
        'TOP' => [
            'TOP',
            'pa’anga tongană',
        ],
        'TRL' => [
            'TRL',
            'liră turcească (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'liră turcească',
        ],
        'TTD' => [
            'TTD',
            'dolar din Trinidad și Tobago',
        ],
        'TWD' => [
            'TWD',
            'dolar nou din Taiwan',
        ],
        'TZS' => [
            'TZS',
            'șiling tanzanian',
        ],
        'UAH' => [
            'UAH',
            'grivnă',
        ],
        'UAK' => [
            'UAK',
            'carboavă ucraineană',
        ],
        'UGS' => [
            'UGS',
            'șiling ugandez (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'șiling ugandez',
        ],
        'USD' => [
            'USD',
            'dolar american',
        ],
        'USN' => [
            'USN',
            'dolar american (ziua următoare)',
        ],
        'USS' => [
            'USS',
            'dolar american (aceeași zi)',
        ],
        'UYP' => [
            'UYP',
            'peso Uruguay (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'peso uruguayan',
        ],
        'UZS' => [
            'UZS',
            'sum Uzbekistan',
        ],
        'VEB' => [
            'VEB',
            'bolivar Venezuela (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'bolivar venezuelean (2008–2018)',
        ],
        'VES' => [
            'VES',
            'bolívar soberano',
        ],
        'VND' => [
            'VND',
            'dong vietnamez',
        ],
        'VUV' => [
            'VUV',
            'vatu din Vanuatu',
        ],
        'WST' => [
            'WST',
            'tala samoană',
        ],
        'XAF' => [
            'FCFA',
            'franc CFA BEAC',
        ],
        'XCD' => [
            'XCD',
            'dolar est-caraib',
        ],
        'XCG' => [
            'Cg.',
            'gulden caraib',
        ],
        'XEU' => [
            'XEU',
            'unitate de monedă europeană',
        ],
        'XFO' => [
            'XFO',
            'franc francez de aur',
        ],
        'XFU' => [
            'XFU',
            'franc UIC francez',
        ],
        'XOF' => [
            'F CFA',
            'franc CFA BCEAO',
        ],
        'XPF' => [
            'CFPF',
            'franc CFP',
        ],
        'YDD' => [
            'YDD',
            'dinar Yemen',
        ],
        'YER' => [
            'YER',
            'rial yemenit',
        ],
        'YUD' => [
            'YUD',
            'dinar iugoslav greu',
        ],
        'YUM' => [
            'YUM',
            'dinar iugoslav nou',
        ],
        'YUN' => [
            'YUN',
            'dinar iugoslav convertibil',
        ],
        'ZAL' => [
            'ZAL',
            'rand sud-african (financiar)',
        ],
        'ZAR' => [
            'ZAR',
            'rand sud-african',
        ],
        'ZMK' => [
            'ZMK',
            'kwacha zambian (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'kwacha zambian',
        ],
        'ZRN' => [
            'ZRN',
            'zair nou',
        ],
        'ZWD' => [
            'ZWD',
            'dolar Zimbabwe (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'Zimbabwe Gold',
        ],
        'ZWL' => [
            'ZWL',
            'dolar Zimbabwe (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'dolar Zimbabwe (2008)',
        ],
    ],
];
