<?php

return [
    'Names' => [
        'ak' => 'Igikani',
        'am' => 'Ikimuhariki',
        'ar' => 'Icarabu',
        'be' => 'Ikibelarusiya',
        'bg' => 'Ikinyabuligariya',
        'bn' => 'Ikibengali',
        'cs' => 'Igiceke',
        'de' => 'Ikidage',
        'el' => 'Ikigereki',
        'en' => 'Icongereza',
        'es' => 'Icesipanyolo',
        'fa' => 'Igiperisi',
        'fr' => 'Igifaransa',
        'ha' => 'Igihawusa',
        'hi' => 'Igihindi',
        'hu' => 'Ikinyahongiriya',
        'id' => 'Ikinyendoziya',
        'ig' => 'Ikigubo',
        'it' => 'Igitaliyani',
        'ja' => 'Ikiyapani',
        'jv' => 'Ikinyejava',
        'km' => 'Igikambodiya',
        'ko' => 'Ikinyakoreya',
        'ms' => 'Ikinyamaleziya',
        'my' => 'Ikinyabirimaniya',
        'ne' => 'Ikinepali',
        'nl' => 'Igiholandi',
        'pa' => 'Igipunjabi',
        'pl' => 'Ikinyapolonye',
        'pt' => 'Igiporutugari',
        'rn' => 'Ikirundi',
        'ro' => 'Ikinyarumaniya',
        'ru' => 'Ikirusiya',
        'rw' => 'Ikinyarwanda',
        'so' => 'Igisomali',
        'sv' => 'Igisuweduwa',
        'ta' => 'Igitamili',
        'th' => 'Ikinyatayilandi',
        'tr' => 'Igiturukiya',
        'uk' => 'Ikinyayukereni',
        'ur' => 'Inyeyurudu',
        'vi' => 'Ikinyaviyetinamu',
        'yo' => 'Ikiyoruba',
        'zh' => 'Igishinwa',
        'zu' => 'Ikizulu',
    ],
    'LocalizedNames' => [],
];
