<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'heure moyenne de Greenwich (Abidjan)',
        'Africa/Accra' => 'heure moyenne de Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'heure normale d’Afrique de l’Est (Addis-Abeba)',
        'Africa/Algiers' => 'heure d’Europe centrale (Alger)',
        'Africa/Asmera' => 'heure normale d’Afrique de l’Est (Asmara)',
        'Africa/Asmara' => 'heure normale d’Afrique de l’Est (Asmara)',
        'Africa/Bamako' => 'heure moyenne de Greenwich (Bamako)',
        'Africa/Bangui' => 'heure d’Afrique de l’Ouest (Bangui)',
        'Africa/Banjul' => 'heure moyenne de Greenwich (Banjul)',
        'Africa/Bissau' => 'heure moyenne de Greenwich (Bissau)',
        'Africa/Blantyre' => 'heure normale d’Afrique centrale (Blantyre)',
        'Africa/Brazzaville' => 'heure d’Afrique de l’Ouest (Brazzaville)',
        'Africa/Bujumbura' => 'heure normale d’Afrique centrale (Bujumbura)',
        'Africa/Cairo' => 'heure d’Europe de l’Est (Le Caire)',
        'Africa/Casablanca' => 'heure d’Europe de l’Ouest (Casablanca)',
        'Africa/Ceuta' => 'heure d’Europe centrale (Ceuta)',
        'Africa/Conakry' => 'heure moyenne de Greenwich (Conakry)',
        'Africa/Dakar' => 'heure moyenne de Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'heure normale d’Afrique de l’Est (Dar es Salaam)',
        'Africa/Djibouti' => 'heure normale d’Afrique de l’Est (Djibouti)',
        'Africa/Douala' => 'heure d’Afrique de l’Ouest (Douala)',
        'Africa/El_Aaiun' => 'heure d’Europe de l’Ouest (Laâyoune)',
        'Africa/Freetown' => 'heure moyenne de Greenwich (Freetown)',
        'Africa/Gaborone' => 'heure normale d’Afrique centrale (Gaborone)',
        'Africa/Harare' => 'heure normale d’Afrique centrale (Harare)',
        'Africa/Johannesburg' => 'heure normale d’Afrique méridionale (Johannesburg)',
        'Africa/Juba' => 'heure normale d’Afrique centrale (Juba)',
        'Africa/Kampala' => 'heure normale d’Afrique de l’Est (Kampala)',
        'Africa/Khartoum' => 'heure normale d’Afrique centrale (Khartoum)',
        'Africa/Kigali' => 'heure normale d’Afrique centrale (Kigali)',
        'Africa/Kinshasa' => 'heure d’Afrique de l’Ouest (Kinshasa)',
        'Africa/Lagos' => 'heure d’Afrique de l’Ouest (Lagos)',
        'Africa/Libreville' => 'heure d’Afrique de l’Ouest (Libreville)',
        'Africa/Lome' => 'heure moyenne de Greenwich (Lomé)',
        'Africa/Luanda' => 'heure d’Afrique de l’Ouest (Luanda)',
        'Africa/Lubumbashi' => 'heure normale d’Afrique centrale (Lubumbashi)',
        'Africa/Lusaka' => 'heure normale d’Afrique centrale (Lusaka)',
        'Africa/Malabo' => 'heure d’Afrique de l’Ouest (Malabo)',
        'Africa/Maputo' => 'heure normale d’Afrique centrale (Maputo)',
        'Africa/Maseru' => 'heure normale d’Afrique méridionale (Maseru)',
        'Africa/Mbabane' => 'heure normale d’Afrique méridionale (Mbabane)',
        'Africa/Mogadishu' => 'heure normale d’Afrique de l’Est (Mogadiscio)',
        'Africa/Monrovia' => 'heure moyenne de Greenwich (Monrovia)',
        'Africa/Nairobi' => 'heure normale d’Afrique de l’Est (Nairobi)',
        'Africa/Ndjamena' => 'heure d’Afrique de l’Ouest (N’Djamena)',
        'Africa/Niamey' => 'heure d’Afrique de l’Ouest (Niamey)',
        'Africa/Nouakchott' => 'heure moyenne de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'heure moyenne de Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'heure d’Afrique de l’Ouest (Porto-Novo)',
        'Africa/Sao_Tome' => 'heure moyenne de Greenwich (São Tomé)',
        'Africa/Tripoli' => 'heure d’Europe de l’Est (Tripoli (Libye))',
        'Africa/Tunis' => 'heure d’Europe centrale (Tunis)',
        'Africa/Windhoek' => 'heure normale d’Afrique centrale (Windhoek)',
        'America/Adak' => 'heure d’Hawaï - Aléoutiennes (Adak)',
        'America/Anchorage' => 'heure de l’Alaska (Anchorage)',
        'America/Anguilla' => 'heure de l’Atlantique (Anguilla)',
        'America/Antigua' => 'heure de l’Atlantique (Antigua)',
        'America/Araguaina' => 'heure de Brasilia (Araguaína)',
        'America/Argentina/La_Rioja' => 'heure de l’Argentine (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'heure de l’Argentine (Río Gallegos)',
        'America/Argentina/Salta' => 'heure de l’Argentine (Salta)',
        'America/Argentina/San_Juan' => 'heure de l’Argentine (San Juan)',
        'America/Argentina/San_Luis' => 'heure de l’Argentine (San Luis)',
        'America/Argentina/Tucuman' => 'heure de l’Argentine (Tucumán)',
        'America/Argentina/Ushuaia' => 'heure de l’Argentine (Ushuaïa)',
        'America/Aruba' => 'heure de l’Atlantique (Aruba)',
        'America/Asuncion' => 'heure du Paraguay (Asunción)',
        'America/Bahia' => 'heure de Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'heure du centre nord-américain (Bahia de Banderas)',
        'America/Barbados' => 'heure de l’Atlantique (La Barbade)',
        'America/Belem' => 'heure de Brasilia (Belém)',
        'America/Belize' => 'heure du centre nord-américain (Belize)',
        'America/Blanc-Sablon' => 'heure de l’Atlantique (Blanc-Sablon)',
        'America/Boa_Vista' => 'heure de l’Amazonie (Boa Vista)',
        'America/Bogota' => 'heure de Colombie (Bogotá)',
        'America/Boise' => 'heure des Rocheuses (Boise)',
        'America/Buenos_Aires' => 'heure de l’Argentine (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'heure de l’Argentine (Buenos Aires)',
        'America/Cambridge_Bay' => 'heure des Rocheuses (Cambridge Bay)',
        'America/Campo_Grande' => 'heure de l’Amazonie (Campo Grande)',
        'America/Cancun' => 'heure de l’Est nord-américain (Cancún)',
        'America/Caracas' => 'heure du Venezuela (Caracas)',
        'America/Catamarca' => 'heure de l’Argentine (Catamarca)',
        'America/Argentina/Catamarca' => 'heure de l’Argentine (Catamarca)',
        'America/Cayenne' => 'heure de la Guyane française (Cayenne)',
        'America/Cayman' => 'heure de l’Est nord-américain (Caïmans)',
        'America/Chicago' => 'heure du centre nord-américain (Chicago)',
        'America/Chihuahua' => 'heure du centre nord-américain (Chihuahua)',
        'America/Ciudad_Juarez' => 'heure des Rocheuses (Ciudad Juárez)',
        'America/Coral_Harbour' => 'heure de l’Est nord-américain (Atikokan)',
        'America/Atikokan' => 'heure de l’Est nord-américain (Atikokan)',
        'America/Cordoba' => 'heure de l’Argentine (Córdoba)',
        'America/Argentina/Cordoba' => 'heure de l’Argentine (Córdoba)',
        'America/Costa_Rica' => 'heure du centre nord-américain (Costa Rica)',
        'America/Coyhaique' => 'heure du Chili (Coyhaique)',
        'America/Creston' => 'heure des Rocheuses (Creston)',
        'America/Cuiaba' => 'heure de l’Amazonie (Cuiabá)',
        'America/Curacao' => 'heure de l’Atlantique (Curaçao)',
        'America/Danmarkshavn' => 'heure moyenne de Greenwich (Danmarkshavn)',
        'America/Dawson' => 'heure normale du Yukon (Dawson)',
        'America/Dawson_Creek' => 'heure des Rocheuses (Dawson Creek)',
        'America/Denver' => 'heure des Rocheuses (Denver)',
        'America/Detroit' => 'heure de l’Est nord-américain (Détroit)',
        'America/Dominica' => 'heure de l’Atlantique (Dominique)',
        'America/Edmonton' => 'heure des Rocheuses (Edmonton)',
        'America/Eirunepe' => 'heure de l’Acre (Eirunepé)',
        'America/El_Salvador' => 'heure du centre nord-américain (El Salvador)',
        'America/Fort_Nelson' => 'heure des Rocheuses (Fort Nelson)',
        'America/Fortaleza' => 'heure de Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'heure de l’Atlantique (Glace Bay)',
        'America/Godthab' => 'heure : Groenland (Nuuk)',
        'America/Nuuk' => 'heure : Groenland (Nuuk)',
        'America/Goose_Bay' => 'heure de l’Atlantique (Goose Bay)',
        'America/Grand_Turk' => 'heure de l’Est nord-américain (Grand Turk)',
        'America/Grenada' => 'heure de l’Atlantique (Grenade)',
        'America/Guadeloupe' => 'heure de l’Atlantique (Guadeloupe)',
        'America/Guatemala' => 'heure du centre nord-américain (Guatemala)',
        'America/Guayaquil' => 'heure de l’Équateur (Guayaquil)',
        'America/Guyana' => 'heure du Guyana',
        'America/Halifax' => 'heure de l’Atlantique (Halifax)',
        'America/Havana' => 'heure de Cuba (La Havane)',
        'America/Hermosillo' => 'heure du Pacifique mexicain (Hermosillo)',
        'America/Indiana/Knox' => 'heure du centre nord-américain (Knox [Indiana])',
        'America/Indiana/Marengo' => 'heure de l’Est nord-américain (Marengo [Indiana])',
        'America/Indiana/Petersburg' => 'heure de l’Est nord-américain (Petersburg [Indiana])',
        'America/Indiana/Tell_City' => 'heure du centre nord-américain (Tell City [Indiana])',
        'America/Indiana/Vevay' => 'heure de l’Est nord-américain (Vevay [Indiana])',
        'America/Indiana/Vincennes' => 'heure de l’Est nord-américain (Vincennes [Indiana])',
        'America/Indiana/Winamac' => 'heure de l’Est nord-américain (Winamac [Indiana])',
        'America/Indianapolis' => 'heure de l’Est nord-américain (Indianapolis)',
        'America/Indiana/Indianapolis' => 'heure de l’Est nord-américain (Indianapolis)',
        'America/Inuvik' => 'heure des Rocheuses (Inuvik)',
        'America/Iqaluit' => 'heure de l’Est nord-américain (Iqaluit)',
        'America/Jamaica' => 'heure de l’Est nord-américain (Jamaïque)',
        'America/Jujuy' => 'heure de l’Argentine (Jujuy)',
        'America/Argentina/Jujuy' => 'heure de l’Argentine (Jujuy)',
        'America/Juneau' => 'heure de l’Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'heure de l’Est nord-américain (Monticello [Kentucky])',
        'America/Kralendijk' => 'heure de l’Atlantique (Kralendijk)',
        'America/La_Paz' => 'heure de Bolivie (La Paz)',
        'America/Lima' => 'heure du Pérou (Lima)',
        'America/Los_Angeles' => 'heure du Pacifique nord-américain (Los Angeles)',
        'America/Louisville' => 'heure de l’Est nord-américain (Louisville)',
        'America/Kentucky/Louisville' => 'heure de l’Est nord-américain (Louisville)',
        'America/Lower_Princes' => 'heure de l’Atlantique (Lower Prince’s Quarter)',
        'America/Maceio' => 'heure de Brasilia (Maceió)',
        'America/Managua' => 'heure du centre nord-américain (Managua)',
        'America/Manaus' => 'heure de l’Amazonie (Manaos)',
        'America/Marigot' => 'heure de l’Atlantique (Marigot)',
        'America/Martinique' => 'heure de l’Atlantique (Martinique)',
        'America/Matamoros' => 'heure du centre nord-américain (Matamoros)',
        'America/Mazatlan' => 'heure du Pacifique mexicain (Mazatlán)',
        'America/Mendoza' => 'heure de l’Argentine (Mendoza)',
        'America/Argentina/Mendoza' => 'heure de l’Argentine (Mendoza)',
        'America/Menominee' => 'heure du centre nord-américain (Menominee)',
        'America/Merida' => 'heure du centre nord-américain (Mérida)',
        'America/Metlakatla' => 'heure de l’Alaska (Metlakatla)',
        'America/Mexico_City' => 'heure du centre nord-américain (Mexico)',
        'America/Miquelon' => 'heure de Saint-Pierre-et-Miquelon',
        'America/Moncton' => 'heure de l’Atlantique (Moncton)',
        'America/Monterrey' => 'heure du centre nord-américain (Monterrey)',
        'America/Montevideo' => 'heure de l’Uruguay (Montevideo)',
        'America/Montserrat' => 'heure de l’Atlantique (Montserrat)',
        'America/Nassau' => 'heure de l’Est nord-américain (Nassau)',
        'America/New_York' => 'heure de l’Est nord-américain (New York)',
        'America/Nome' => 'heure de l’Alaska (Nome)',
        'America/Noronha' => 'heure de Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'heure du centre nord-américain (Beulah (Dakota du Nord))',
        'America/North_Dakota/Center' => 'heure du centre nord-américain (Center (Dakota du Nord))',
        'America/North_Dakota/New_Salem' => 'heure du centre nord-américain (New Salem (Dakota du Nord))',
        'America/Ojinaga' => 'heure du centre nord-américain (Ojinaga)',
        'America/Panama' => 'heure de l’Est nord-américain (Panama)',
        'America/Paramaribo' => 'heure du Suriname (Paramaribo)',
        'America/Phoenix' => 'heure des Rocheuses (Phoenix)',
        'America/Port-au-Prince' => 'heure de l’Est nord-américain (Port-au-Prince)',
        'America/Port_of_Spain' => 'heure de l’Atlantique (Port-d’Espagne)',
        'America/Porto_Velho' => 'heure de l’Amazonie (Porto Velho)',
        'America/Puerto_Rico' => 'heure de l’Atlantique (Porto Rico)',
        'America/Punta_Arenas' => 'heure du Chili (Punta Arenas)',
        'America/Rankin_Inlet' => 'heure du centre nord-américain (Rankin Inlet)',
        'America/Recife' => 'heure de Brasilia (Recife)',
        'America/Regina' => 'heure du centre nord-américain (Regina)',
        'America/Resolute' => 'heure du centre nord-américain (Resolute)',
        'America/Rio_Branco' => 'heure de l’Acre (Rio Branco)',
        'America/Santarem' => 'heure de Brasilia (Santarém)',
        'America/Santiago' => 'heure du Chili (Santiago)',
        'America/Santo_Domingo' => 'heure de l’Atlantique (Saint-Domingue)',
        'America/Sao_Paulo' => 'heure de Brasilia (São Paulo)',
        'America/Scoresbysund' => 'heure : Groenland (Ittoqqortoormiit)',
        'America/Sitka' => 'heure de l’Alaska (Sitka)',
        'America/St_Barthelemy' => 'heure de l’Atlantique (Saint-Barthélemy)',
        'America/St_Johns' => 'heure de Terre-Neuve (Saint-Jean de Terre-Neuve)',
        'America/St_Kitts' => 'heure de l’Atlantique (Saint-Christophe)',
        'America/St_Lucia' => 'heure de l’Atlantique (Sainte-Lucie)',
        'America/St_Thomas' => 'heure de l’Atlantique (Saint-Thomas)',
        'America/St_Vincent' => 'heure de l’Atlantique (Saint-Vincent)',
        'America/Swift_Current' => 'heure du centre nord-américain (Swift Current)',
        'America/Tegucigalpa' => 'heure du centre nord-américain (Tegucigalpa)',
        'America/Thule' => 'heure de l’Atlantique (Thulé)',
        'America/Tijuana' => 'heure du Pacifique nord-américain (Tijuana)',
        'America/Toronto' => 'heure de l’Est nord-américain (Toronto)',
        'America/Tortola' => 'heure de l’Atlantique (Tortola)',
        'America/Vancouver' => 'heure du Pacifique nord-américain (Vancouver)',
        'America/Whitehorse' => 'heure normale du Yukon (Whitehorse)',
        'America/Winnipeg' => 'heure du centre nord-américain (Winnipeg)',
        'America/Yakutat' => 'heure de l’Alaska (Yakutat)',
        'Antarctica/Casey' => 'heure de l’Ouest de l’Australie (Casey)',
        'Antarctica/Davis' => 'heure de Davis',
        'Antarctica/DumontDUrville' => 'heure de Dumont-d’Urville',
        'Antarctica/Macquarie' => 'heure de l’Est de l’Australie (Macquarie)',
        'Antarctica/Mawson' => 'heure de Mawson',
        'Antarctica/McMurdo' => 'heure de la Nouvelle-Zélande (McMurdo)',
        'Antarctica/Palmer' => 'heure du Chili (Palmer)',
        'Antarctica/Rothera' => 'heure de Rothera',
        'Antarctica/Syowa' => 'heure de Syowa (Showa)',
        'Antarctica/Troll' => 'heure moyenne de Greenwich (Troll)',
        'Antarctica/Vostok' => 'heure de Vostok',
        'Arctic/Longyearbyen' => 'heure d’Europe centrale (Longyearbyen)',
        'Asia/Aden' => 'heure de l’Arabie (Aden)',
        'Asia/Almaty' => 'heure du Kazakhstan (Alma Ata)',
        'Asia/Amman' => 'heure d’Europe de l’Est (Amman)',
        'Asia/Anadyr' => 'heure de Petropavlovsk-Kamchatski (Anadyr)',
        'Asia/Aqtau' => 'heure du Kazakhstan (Aktaou)',
        'Asia/Aqtobe' => 'heure du Kazakhstan (Aktioubinsk)',
        'Asia/Ashgabat' => 'heure du Turkménistan (Achgabat)',
        'Asia/Atyrau' => 'heure du Kazakhstan (Atyraou)',
        'Asia/Baghdad' => 'heure de l’Arabie (Bagdad)',
        'Asia/Bahrain' => 'heure de l’Arabie (Bahreïn)',
        'Asia/Baku' => 'heure de l’Azerbaïdjan (Bakou)',
        'Asia/Bangkok' => 'heure d’Indochine (Bangkok)',
        'Asia/Barnaul' => 'heure de Krasnoïarsk (Barnaul)',
        'Asia/Beirut' => 'heure d’Europe de l’Est (Beyrouth)',
        'Asia/Bishkek' => 'heure du Kirghizistan (Bichkek)',
        'Asia/Brunei' => 'heure du Brunei',
        'Asia/Calcutta' => 'heure de l’Inde (Calcutta)',
        'Asia/Kolkata' => 'heure de l’Inde (Calcutta)',
        'Asia/Chita' => 'heure de Iakoutsk (Tchita)',
        'Asia/Colombo' => 'heure de l’Inde (Colombo)',
        'Asia/Damascus' => 'heure d’Europe de l’Est (Damas)',
        'Asia/Dhaka' => 'heure du Bangladesh (Dhaka)',
        'Asia/Dili' => 'heure du Timor oriental (Dili)',
        'Asia/Dubai' => 'heure du Golfe (Dubaï)',
        'Asia/Dushanbe' => 'heure du Tadjikistan (Douchanbé)',
        'Asia/Famagusta' => 'heure d’Europe de l’Est (Famagouste)',
        'Asia/Gaza' => 'heure d’Europe de l’Est (Gaza)',
        'Asia/Hebron' => 'heure d’Europe de l’Est (Hébron)',
        'Asia/Hong_Kong' => 'heure de Hong Kong',
        'Asia/Hovd' => 'heure de Hovd (Khovd)',
        'Asia/Irkutsk' => 'heure d’Irkoutsk',
        'Asia/Jakarta' => 'heure de l’Ouest indonésien (Jakarta)',
        'Asia/Jayapura' => 'heure de l’Est indonésien (Jayapura)',
        'Asia/Jerusalem' => 'heure d’Israël (Jérusalem)',
        'Asia/Kabul' => 'heure de l’Afghanistan (Kaboul)',
        'Asia/Kamchatka' => 'heure de Petropavlovsk-Kamchatski (Kamtchatka)',
        'Asia/Karachi' => 'heure du Pakistan (Karachi)',
        'Asia/Katmandu' => 'heure du Népal (Katmandou)',
        'Asia/Kathmandu' => 'heure du Népal (Katmandou)',
        'Asia/Khandyga' => 'heure de Iakoutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'heure de Krasnoïarsk',
        'Asia/Kuala_Lumpur' => 'heure de la Malaisie (Kuala Lumpur)',
        'Asia/Kuching' => 'heure de la Malaisie (Kuching)',
        'Asia/Kuwait' => 'heure de l’Arabie (Koweït)',
        'Asia/Macau' => 'heure de la Chine (Macao)',
        'Asia/Magadan' => 'heure de Magadan',
        'Asia/Makassar' => 'heure du Centre indonésien (Macassar)',
        'Asia/Manila' => 'heure des Philippines (Manille)',
        'Asia/Muscat' => 'heure du Golfe (Mascate)',
        'Asia/Nicosia' => 'heure d’Europe de l’Est (Nicosie)',
        'Asia/Novokuznetsk' => 'heure de Krasnoïarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'heure de Krasnoïarsk (Novossibirsk)',
        'Asia/Omsk' => 'heure de Omsk',
        'Asia/Oral' => 'heure du Kazakhstan (Ouralsk)',
        'Asia/Phnom_Penh' => 'heure d’Indochine (Phnom Penh)',
        'Asia/Pontianak' => 'heure de l’Ouest indonésien (Pontianak)',
        'Asia/Pyongyang' => 'heure de la Corée (Pyongyang)',
        'Asia/Qatar' => 'heure de l’Arabie (Qatar)',
        'Asia/Qostanay' => 'heure du Kazakhstan (Kostanaï)',
        'Asia/Qyzylorda' => 'heure du Kazakhstan (Kzyl Orda)',
        'Asia/Rangoon' => 'heure du Myanmar (Rangoun)',
        'Asia/Yangon' => 'heure du Myanmar (Rangoun)',
        'Asia/Riyadh' => 'heure de l’Arabie (Riyad)',
        'Asia/Saigon' => 'heure d’Indochine (Hô-Chi-Minh-Ville)',
        'Asia/Ho_Chi_Minh' => 'heure d’Indochine (Hô-Chi-Minh-Ville)',
        'Asia/Sakhalin' => 'heure de Magadan (Sakhaline)',
        'Asia/Samarkand' => 'heure de l’Ouzbékistan (Samarcande)',
        'Asia/Seoul' => 'heure de la Corée (Séoul)',
        'Asia/Shanghai' => 'heure de la Chine (Shanghai)',
        'Asia/Singapore' => 'heure de Singapour',
        'Asia/Srednekolymsk' => 'heure de Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'heure de Taipei',
        'Asia/Tashkent' => 'heure de l’Ouzbékistan (Tachkent)',
        'Asia/Tbilisi' => 'heure de la Géorgie (Tbilissi)',
        'Asia/Tehran' => 'heure de l’Iran (Téhéran)',
        'Asia/Thimphu' => 'heure du Bhoutan (Thimphu)',
        'Asia/Tokyo' => 'heure du Japon (Tokyo)',
        'Asia/Tomsk' => 'heure de Krasnoïarsk (Tomsk)',
        'Asia/Ulaanbaatar' => 'heure d’Oulan-Bator',
        'Asia/Urumqi' => 'heure : Chine (Ürümqi)',
        'Asia/Ust-Nera' => 'heure de Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'heure d’Indochine (Vientiane)',
        'Asia/Vladivostok' => 'heure de Vladivostok',
        'Asia/Yakutsk' => 'heure de Iakoutsk',
        'Asia/Yekaterinburg' => 'heure d’Ekaterinbourg',
        'Asia/Yerevan' => 'heure de l’Arménie (Erevan)',
        'Atlantic/Azores' => 'heure des Açores',
        'Atlantic/Bermuda' => 'heure de l’Atlantique (Bermudes)',
        'Atlantic/Canary' => 'heure d’Europe de l’Ouest (Îles Canaries)',
        'Atlantic/Cape_Verde' => 'heure du Cap-Vert',
        'Atlantic/Faeroe' => 'heure d’Europe de l’Ouest (Îles Féroé)',
        'Atlantic/Faroe' => 'heure d’Europe de l’Ouest (Îles Féroé)',
        'Atlantic/Madeira' => 'heure d’Europe de l’Ouest (Madère)',
        'Atlantic/Reykjavik' => 'heure moyenne de Greenwich (Reykjavik)',
        'Atlantic/South_Georgia' => 'heure de Géorgie du Sud',
        'Atlantic/St_Helena' => 'heure moyenne de Greenwich (Sainte-Hélène)',
        'Atlantic/Stanley' => 'heure des îles Malouines (Stanley)',
        'Australia/Adelaide' => 'heure du centre de l’Australie (Adélaïde)',
        'Australia/Brisbane' => 'heure de l’Est de l’Australie (Brisbane)',
        'Australia/Broken_Hill' => 'heure du centre de l’Australie (Broken Hill)',
        'Australia/Darwin' => 'heure du centre de l’Australie (Darwin)',
        'Australia/Eucla' => 'heure du centre-ouest de l’Australie (Eucla)',
        'Australia/Hobart' => 'heure de l’Est de l’Australie (Hobart)',
        'Australia/Lindeman' => 'heure de l’Est de l’Australie (Lindeman)',
        'Australia/Lord_Howe' => 'heure de Lord Howe',
        'Australia/Melbourne' => 'heure de l’Est de l’Australie (Melbourne)',
        'Australia/Perth' => 'heure de l’Ouest de l’Australie (Perth)',
        'Australia/Sydney' => 'heure de l’Est de l’Australie (Sydney)',
        'Etc/GMT' => 'heure moyenne de Greenwich',
        'Etc/UTC' => 'temps universel coordonné',
        'Europe/Amsterdam' => 'heure d’Europe centrale (Amsterdam)',
        'Europe/Andorra' => 'heure d’Europe centrale (Andorre)',
        'Europe/Astrakhan' => 'heure de Samara (Astrakhan)',
        'Europe/Athens' => 'heure d’Europe de l’Est (Athènes)',
        'Europe/Belgrade' => 'heure d’Europe centrale (Belgrade)',
        'Europe/Berlin' => 'heure d’Europe centrale (Berlin)',
        'Europe/Bratislava' => 'heure d’Europe centrale (Bratislava)',
        'Europe/Brussels' => 'heure d’Europe centrale (Bruxelles)',
        'Europe/Bucharest' => 'heure d’Europe de l’Est (Bucarest)',
        'Europe/Budapest' => 'heure d’Europe centrale (Budapest)',
        'Europe/Busingen' => 'heure d’Europe centrale (Büsingen)',
        'Europe/Chisinau' => 'heure d’Europe de l’Est (Chișinău)',
        'Europe/Copenhagen' => 'heure d’Europe centrale (Copenhague)',
        'Europe/Dublin' => 'heure moyenne de Greenwich (Dublin)',
        'Europe/Gibraltar' => 'heure d’Europe centrale (Gibraltar)',
        'Europe/Guernsey' => 'heure moyenne de Greenwich (Guernesey)',
        'Europe/Helsinki' => 'heure d’Europe de l’Est (Helsinki)',
        'Europe/Isle_of_Man' => 'heure moyenne de Greenwich (Île de Man)',
        'Europe/Istanbul' => 'heure de Turquie (Istanbul)',
        'Europe/Jersey' => 'heure moyenne de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'heure d’Europe de l’Est (Kaliningrad)',
        'Europe/Kiev' => 'heure d’Europe de l’Est (Kiev)',
        'Europe/Kyiv' => 'heure d’Europe de l’Est (Kiev)',
        'Europe/Kirov' => 'heure de Moscou (Kirov)',
        'Europe/Lisbon' => 'heure d’Europe de l’Ouest (Lisbonne)',
        'Europe/Ljubljana' => 'heure d’Europe centrale (Ljubljana)',
        'Europe/London' => 'heure moyenne de Greenwich (Londres)',
        'Europe/Luxembourg' => 'heure d’Europe centrale (Luxembourg)',
        'Europe/Madrid' => 'heure d’Europe centrale (Madrid)',
        'Europe/Malta' => 'heure d’Europe centrale (Malte)',
        'Europe/Mariehamn' => 'heure d’Europe de l’Est (Mariehamn)',
        'Europe/Minsk' => 'heure de Moscou (Minsk)',
        'Europe/Monaco' => 'heure d’Europe centrale (Monaco)',
        'Europe/Moscow' => 'heure de Moscou',
        'Europe/Oslo' => 'heure d’Europe centrale (Oslo)',
        'Europe/Paris' => 'heure d’Europe centrale (Paris)',
        'Europe/Podgorica' => 'heure d’Europe centrale (Podgorica)',
        'Europe/Prague' => 'heure d’Europe centrale (Prague)',
        'Europe/Riga' => 'heure d’Europe de l’Est (Riga)',
        'Europe/Rome' => 'heure d’Europe centrale (Rome)',
        'Europe/Samara' => 'heure de Samara',
        'Europe/San_Marino' => 'heure d’Europe centrale (Saint-Marin)',
        'Europe/Sarajevo' => 'heure d’Europe centrale (Sarajevo)',
        'Europe/Saratov' => 'heure de Samara (Saratov)',
        'Europe/Simferopol' => 'heure de Moscou (Simferopol)',
        'Europe/Skopje' => 'heure d’Europe centrale (Skopje)',
        'Europe/Sofia' => 'heure d’Europe de l’Est (Sofia)',
        'Europe/Stockholm' => 'heure d’Europe centrale (Stockholm)',
        'Europe/Tallinn' => 'heure d’Europe de l’Est (Tallinn)',
        'Europe/Tirane' => 'heure d’Europe centrale (Tirana)',
        'Europe/Ulyanovsk' => 'heure de Samara (Oulianovsk)',
        'Europe/Vaduz' => 'heure d’Europe centrale (Vaduz)',
        'Europe/Vatican' => 'heure d’Europe centrale (Le Vatican)',
        'Europe/Vienna' => 'heure d’Europe centrale (Vienne)',
        'Europe/Vilnius' => 'heure d’Europe de l’Est (Vilnius)',
        'Europe/Volgograd' => 'heure de Moscou (Volgograd)',
        'Europe/Warsaw' => 'heure d’Europe centrale (Varsovie)',
        'Europe/Zagreb' => 'heure d’Europe centrale (Zagreb)',
        'Europe/Zurich' => 'heure d’Europe centrale (Zurich)',
        'Indian/Antananarivo' => 'heure normale d’Afrique de l’Est (Antananarivo)',
        'Indian/Chagos' => 'heure de l’Océan Indien (Chagos)',
        'Indian/Christmas' => 'heure de l’île Christmas',
        'Indian/Cocos' => 'heure des îles Cocos',
        'Indian/Comoro' => 'heure normale d’Afrique de l’Est (Comores)',
        'Indian/Kerguelen' => 'heure des Terres australes et antarctiques françaises (Kerguelen)',
        'Indian/Mahe' => 'heure des Seychelles (Mahé)',
        'Indian/Maldives' => 'heure des Maldives',
        'Indian/Mauritius' => 'heure de Maurice',
        'Indian/Mayotte' => 'heure normale d’Afrique de l’Est (Mayotte)',
        'Indian/Reunion' => 'heure de La Réunion',
        'Pacific/Apia' => 'heure d’Apia',
        'Pacific/Auckland' => 'heure de la Nouvelle-Zélande (Auckland)',
        'Pacific/Bougainville' => 'heure de la Papouasie-Nouvelle-Guinée (Bougainville)',
        'Pacific/Chatham' => 'heure des îles Chatham',
        'Pacific/Easter' => 'heure de l’île de Pâques',
        'Pacific/Efate' => 'heure du Vanuatu (Éfaté)',
        'Pacific/Enderbury' => 'heure des îles Phoenix (Canton)',
        'Pacific/Kanton' => 'heure des îles Phoenix (Canton)',
        'Pacific/Fakaofo' => 'heure de Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'heure des îles Fidji',
        'Pacific/Funafuti' => 'heure des Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'heure des îles Galápagos',
        'Pacific/Gambier' => 'heure des îles Gambier',
        'Pacific/Guadalcanal' => 'heure des îles Salomon (Guadalcanal)',
        'Pacific/Guam' => 'heure des Chamorro (Guam)',
        'Pacific/Honolulu' => 'heure normale d’Hawaï - Aléoutiennes (Honolulu)',
        'Pacific/Kiritimati' => 'heure des îles de la Ligne (Kiritimati)',
        'Pacific/Kosrae' => 'heure de Kosrae',
        'Pacific/Kwajalein' => 'heure des îles Marshall (Kwajalein)',
        'Pacific/Majuro' => 'heure des îles Marshall (Majuro)',
        'Pacific/Marquesas' => 'heure des îles Marquises',
        'Pacific/Midway' => 'heure des Samoa (Midway)',
        'Pacific/Nauru' => 'heure de Nauru',
        'Pacific/Niue' => 'heure de Niue',
        'Pacific/Norfolk' => 'heure de l’île Norfolk',
        'Pacific/Noumea' => 'heure de la Nouvelle-Calédonie (Nouméa)',
        'Pacific/Pago_Pago' => 'heure des Samoa (Pago Pago)',
        'Pacific/Palau' => 'heure des Palaos',
        'Pacific/Pitcairn' => 'heure des îles Pitcairn',
        'Pacific/Ponape' => 'heure de l’île de Pohnpei',
        'Pacific/Pohnpei' => 'heure de l’île de Pohnpei',
        'Pacific/Port_Moresby' => 'heure de la Papouasie-Nouvelle-Guinée (Port Moresby)',
        'Pacific/Rarotonga' => 'heure des îles Cook (Rarotonga)',
        'Pacific/Saipan' => 'heure des Chamorro (Saipan)',
        'Pacific/Tahiti' => 'heure de Tahiti',
        'Pacific/Tarawa' => 'heure des îles Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'heure des Tonga (Tongatapu)',
        'Pacific/Truk' => 'heure de Chuuk',
        'Pacific/Chuuk' => 'heure de Chuuk',
        'Pacific/Wake' => 'heure de l’île Wake',
        'Pacific/Wallis' => 'heure de Wallis-et-Futuna (Wallis & Futuna)',
    ],
    'Meta' => [
        'GmtFormat' => 'UTC%s',
        'HourFormatNeg' => '−%02d:%02d',
    ],
];
