<?php

return [
    'Names' => [
        'ANG' => [
            'ANG',
            'Голланд Антил гульдени',
        ],
        'ARS' => [
            'ARS',
            'Аргентина песоси',
        ],
        'AWG' => [
            'AWG',
            'Аруба флорини',
        ],
        'BBD' => [
            'BBD',
            'Барбадос доллари',
        ],
        'BMD' => [
            'BMD',
            'Бермуда доллари',
        ],
        'BOB' => [
            'BOB',
            'Боливия болвиани',
        ],
        'BRL' => [
            'R$',
            'Бразил реали',
        ],
        'BSD' => [
            'BSD',
            'Багама доллари',
        ],
        'BZD' => [
            'BZD',
            'Белиз доллари',
        ],
        'CAD' => [
            'CA$',
            'Канада доллари',
        ],
        'CLP' => [
            'CLP',
            'Чили песоси',
        ],
        'CNY' => [
            'CN¥',
            'Хитой юани',
        ],
        'COP' => [
            'COP',
            'Колумбия песоси',
        ],
        'CRC' => [
            'CRC',
            'Коста-Рика колони',
        ],
        'CUC' => [
            'CUC',
            'Куба Айирбошлаш песоси',
        ],
        'CUP' => [
            'CUP',
            'Куба песоси',
        ],
        'DOP' => [
            'DOP',
            'Доминикан песоси',
        ],
        'DZD' => [
            'DZD',
            'Жазоир динори',
        ],
        'EGP' => [
            'EGP',
            'Миср фунти',
        ],
        'EUR' => [
            '€',
            'Евро',
        ],
        'FKP' => [
            'FKP',
            'Фолькленд ороли фунти',
        ],
        'GBP' => [
            '£',
            'Инглиз фунт',
        ],
        'GTQ' => [
            'GTQ',
            'Гватемала кветзали',
        ],
        'GYD' => [
            'GYD',
            'Гаяна доллари',
        ],
        'HNL' => [
            'HNL',
            'Гондурас лемпираси',
        ],
        'HTG' => [
            'HTG',
            'Гаити гурдаси',
        ],
        'INR' => [
            '₹',
            'Ҳинд рупияси',
        ],
        'JMD' => [
            'JMD',
            'Ямайка доллари',
        ],
        'JPY' => [
            'JP¥',
            'Япон йенаси',
        ],
        'KYD' => [
            'KYD',
            'Кайман ороли Доллари',
        ],
        'LYD' => [
            'LYD',
            'Ливия динори',
        ],
        'MAD' => [
            'MAD',
            'Марокаш дирҳами',
        ],
        'MXN' => [
            'MX$',
            'Мексика песоси',
        ],
        'NIO' => [
            'NIO',
            'Никарагуа кордобаси',
        ],
        'PAB' => [
            'PAB',
            'Панама бальбоаси',
        ],
        'PEN' => [
            'PEN',
            'Перу сол',
        ],
        'PYG' => [
            'PYG',
            'Парагвай гуарани',
        ],
        'RUB' => [
            'RUB',
            'Рус рубли',
        ],
        'SRD' => [
            'SRD',
            'Суринам доллари',
        ],
        'THB' => [
            '฿',
            'THB',
        ],
        'TTD' => [
            'TTD',
            'Тринидад ва Тобаго доллари',
        ],
        'USD' => [
            'US$',
            'АҚШ доллари',
        ],
        'UYU' => [
            'UYU',
            'Уругвай песоси',
        ],
        'UZS' => [
            'сўм',
            'Ўзбекистон сўм',
        ],
        'VEF' => [
            'VEF',
            'Венесуэла боливари (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Венесуэла боливари',
        ],
        'XCD' => [
            'EC$',
            'Шарқий Кариб доллари',
        ],
    ],
];
