<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Peseta Andorrach',
        ],
        'AED' => [
            'AED',
            'Dirham nan Iomaratan Arabach Aonaichte',
        ],
        'AFA' => [
            'AFA',
            'Afghani Afghanach (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'Afghani Afghanach',
        ],
        'ALK' => [
            'ALK',
            'Lek Albàineach (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'Lek Albàineach',
        ],
        'AMD' => [
            'AMD',
            'Dram Airmeineach',
        ],
        'ANG' => [
            'ANG',
            'Gulden Eileanan Aintilia nan Tìrean Ìsle',
        ],
        'AOA' => [
            'AOA',
            'Kwanza Angòlach',
        ],
        'AOK' => [
            'AOK',
            'Kwanza Angòlach (1977–1991)',
        ],
        'AON' => [
            'AON',
            'Kwanza ùr Angòlach (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Kwanza ath-ghleusaichte Angòlach (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Austral Argantaineach',
        ],
        'ARL' => [
            'ARL',
            'Peso ley Argantaineach (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'Peso Argantaineach (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'Peso Argantaineach (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'Peso Argantaineach',
        ],
        'ATS' => [
            'ATS',
            'Schilling Ostaireach',
        ],
        'AUD' => [
            'A$',
            'Dolar Astràilianach',
        ],
        'AWG' => [
            'AWG',
            'Florin Arùbach',
        ],
        'AZM' => [
            'AZM',
            'Manat Asarbaideànach (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'Manat Asarbaideànach',
        ],
        'BAD' => [
            'BAD',
            'Dinar Bhosna agus Hearsagobhana (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'Mark iompachail Bhosna agus Hearsagobhana',
        ],
        'BAN' => [
            'BAN',
            'Dinar ùr Bhosna agus Hearsagobhana (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'Dolar Barbadach',
        ],
        'BDT' => [
            'BDT',
            'Taka Bangladaiseach',
        ],
        'BEC' => [
            'BEC',
            'Franc Beilgeach (iompachail)',
        ],
        'BEF' => [
            'BEF',
            'Franc Beilgeach',
        ],
        'BEL' => [
            'BEL',
            'Franc Beilgeach (ionmhasail)',
        ],
        'BGL' => [
            'BGL',
            'Lev cruaidh Bulgarach',
        ],
        'BGM' => [
            'BGM',
            'Lev sòisealach Bulgarach',
        ],
        'BGN' => [
            'BGN',
            'Lev Bulgarach',
        ],
        'BGO' => [
            'BGO',
            'Lev Bulgarach (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'Dinar Bachraineach',
        ],
        'BIF' => [
            'BIF',
            'Franc Burundaidheach',
        ],
        'BMD' => [
            'BMD',
            'Dolar Bearmùdach',
        ],
        'BND' => [
            'BND',
            'Dolar Brùnaigheach',
        ],
        'BOB' => [
            'BOB',
            'Boliviano Boilibhiach',
        ],
        'BOL' => [
            'BOL',
            'Boliviano Boilibhiach (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'Peso Boilibhiach',
        ],
        'BOV' => [
            'BOV',
            'Mvdol Boilibhiach',
        ],
        'BRB' => [
            'BRB',
            'Cruzeiro ùr Braisileach (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Cruzado Braisileach (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'Cruzeiro Braisileach (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'Real Braisileach',
        ],
        'BRN' => [
            'BRN',
            'Cruzado ùr Braisileach (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'Cruzeiro Braisileach (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'Cruzeiro Braisileach (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'Dolar Bathamach',
        ],
        'BTN' => [
            'BTN',
            'Ngultrum Butànach',
        ],
        'BUK' => [
            'BUK',
            'Kyat Burmach',
        ],
        'BWP' => [
            'BWP',
            'Pula Botsuanach',
        ],
        'BYB' => [
            'BYB',
            'Rùbal ùr Bealaruiseach (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'Rùbal Bealaruiseach',
        ],
        'BYR' => [
            'BYR',
            'Rùbal Bealaruiseach (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Dolar Beilìseach',
        ],
        'CAD' => [
            'CA$',
            'Dolar Canadach',
        ],
        'CDF' => [
            'CDF',
            'Franc Congothach',
        ],
        'CHE' => [
            'CHE',
            'Eòro WIR',
        ],
        'CHF' => [
            'CHF',
            'Franc Eilbheiseach',
        ],
        'CHW' => [
            'CHW',
            'Franc WIR',
        ],
        'CLE' => [
            'CLE',
            'Escudo Sileach',
        ],
        'CLF' => [
            'CLF',
            'Aonad cunntasachd Sileach (UF)',
        ],
        'CLP' => [
            'CLP',
            'Peso Sileach',
        ],
        'CNH' => [
            'CNH',
            'Yuan Sìneach (far-thìreach)',
        ],
        'CNX' => [
            'CNX',
            'Dolar an t-sluagh-bhanca Shìnich',
        ],
        'CNY' => [
            'CN¥',
            'Yuan Sìneach',
        ],
        'COP' => [
            'COP',
            'Peso Coloimbeach',
        ],
        'COU' => [
            'COU',
            'Aonad fìor-luach Coloimbeach',
        ],
        'CRC' => [
            'CRC',
            'Colón Costa Rìceach',
        ],
        'CSD' => [
            'CSD',
            'Dinar Sèirbeach (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'Koruna cruaidh Seic-Slòbhacach',
        ],
        'CUC' => [
            'CUC',
            'Peso iompachail Cùbach',
        ],
        'CUP' => [
            'CUP',
            'Peso Cùbach',
        ],
        'CVE' => [
            'CVE',
            'Escudo a’ Chip Uaine',
        ],
        'CYP' => [
            'CYP',
            'Punnd Cìoprasach',
        ],
        'CZK' => [
            'CZK',
            'Koruna Seiceach',
        ],
        'DDM' => [
            'DDM',
            'Mark na Gearmailte an Ear',
        ],
        'DEM' => [
            'DEM',
            'Mark Gearmailteach',
        ],
        'DJF' => [
            'DJF',
            'Franc Diobùtaidheach',
        ],
        'DKK' => [
            'DKK',
            'Krone Danmhairgeach',
        ],
        'DOP' => [
            'DOP',
            'Peso Doiminiceach',
        ],
        'DZD' => [
            'DZD',
            'Dinar Aildireach',
        ],
        'ECS' => [
            'ECS',
            'Sucre Eacuadorach',
        ],
        'ECV' => [
            'ECV',
            'Aonad luach chunbhalaich Eacuadorach',
        ],
        'EEK' => [
            'EEK',
            'Kroon Eastoineach',
        ],
        'EGP' => [
            'EGP',
            'Punnd Èipheiteach',
        ],
        'ERN' => [
            'ERN',
            'Nakfa Eartrach',
        ],
        'ESA' => [
            'ESA',
            'Peseta Spàinnteach (cunntas A)',
        ],
        'ESB' => [
            'ESB',
            'Peseta Spàinnteach (cunntas iompachail)',
        ],
        'ESP' => [
            'ESP',
            'Peseta Spàinnteach',
        ],
        'ETB' => [
            'ETB',
            'Birr Itiopach',
        ],
        'EUR' => [
            '€',
            'Eòro',
        ],
        'FIM' => [
            'FIM',
            'Markka Fionnlannach',
        ],
        'FJD' => [
            'FJD',
            'Dolar Fìditheach',
        ],
        'FKP' => [
            'FKP',
            'Punnd Fàclannach',
        ],
        'FRF' => [
            'FRF',
            'Franc Frangach',
        ],
        'GBP' => [
            '£',
            'Punnd Sasannach',
        ],
        'GEK' => [
            'GEK',
            'Kupon larit Cairtbheileach',
        ],
        'GEL' => [
            'GEL',
            'Lari Cairtbheileach',
        ],
        'GHC' => [
            'GHC',
            'Cedi Gànach (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'Cedi Gànach',
        ],
        'GIP' => [
            'GIP',
            'Punnd Diobraltarach',
        ],
        'GMD' => [
            'GMD',
            'Dalasi Gaimbitheach',
        ],
        'GNF' => [
            'GNF',
            'Franc Ginitheach',
        ],
        'GNS' => [
            'GNS',
            'Syli Ginitheach',
        ],
        'GQE' => [
            'GQE',
            'Ekwele Gini Meadhan-Chriosaich',
        ],
        'GRD' => [
            'GRD',
            'Drachma Greugach',
        ],
        'GTQ' => [
            'GTQ',
            'Quetzal Guatamalach',
        ],
        'GWE' => [
            'GWE',
            'Escudo Gini na Portagaile',
        ],
        'GWP' => [
            'GWP',
            'Peso Gini-Biosothach',
        ],
        'GYD' => [
            'GYD',
            'Dolar Guidheànach',
        ],
        'HKD' => [
            'HK$',
            'Dolar Hong Kong',
        ],
        'HNL' => [
            'HNL',
            'Lempira Hondùrach',
        ],
        'HRD' => [
            'HRD',
            'Dinar Cròthaiseach',
        ],
        'HRK' => [
            'HRK',
            'Kuna Cròthaiseach',
        ],
        'HTG' => [
            'HTG',
            'Gourde Haidhteach',
        ],
        'HUF' => [
            'HUF',
            'Forint Ungaireach',
        ],
        'IDR' => [
            'IDR',
            'Rupiah Innd-Innseach',
        ],
        'IEP' => [
            'IEP',
            'Punnd Èireannach',
        ],
        'ILP' => [
            'ILP',
            'Punnd Iosraeleach',
        ],
        'ILR' => [
            'ILR',
            'Secel Iosraeleach (1980–1985)',
        ],
        'ILS' => [
            '₪',
            'Secel ùr Iosraeleach',
        ],
        'INR' => [
            '₹',
            'Rupee Innseanach',
        ],
        'IQD' => [
            'IQD',
            'Dinar Ioràcach',
        ],
        'IRR' => [
            'IRR',
            'Rial Iorànach',
        ],
        'ISJ' => [
            'ISJ',
            'Króna Innis Tìleach (1918–1981)',
        ],
        'ISK' => [
            'ISK',
            'Króna Innis Tìleach',
        ],
        'ITL' => [
            'ITL',
            'Lira Eadailteach',
        ],
        'JMD' => [
            'JMD',
            'Dolar Diameugach',
        ],
        'JOD' => [
            'JOD',
            'Dinar Iòrdanach',
        ],
        'JPY' => [
            'JP¥',
            'Yen Seapanach',
        ],
        'KES' => [
            'KES',
            'Shilling Ceineach',
        ],
        'KGS' => [
            'KGS',
            'Som Cìorgasach',
        ],
        'KHR' => [
            'KHR',
            'Riel Cambuideach',
        ],
        'KMF' => [
            'KMF',
            'Franc Comorosach',
        ],
        'KPW' => [
            'KPW',
            'Won Choirèa a Tuath',
        ],
        'KRH' => [
            'KRH',
            'Hwan Choirèa a Deas (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'Won Choirèa a Deas (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'Won Choirèa a Deas',
        ],
        'KWD' => [
            'KWD',
            'Dinar Cuibhèiteach',
        ],
        'KYD' => [
            'KYD',
            'Dolar Caimeanach',
        ],
        'KZT' => [
            'KZT',
            'Tenge Casachach',
        ],
        'LAK' => [
            'LAK',
            'Kip Làthosach',
        ],
        'LBP' => [
            'LBP',
            'Punnd Leabanach',
        ],
        'LKR' => [
            'LKR',
            'Rupee Sri Lancach',
        ],
        'LRD' => [
            'LRD',
            'Dolar Libèireach',
        ],
        'LSL' => [
            'LSL',
            'Loti Leasotach',
        ],
        'LTL' => [
            'LTL',
            'Litas Liotuaineach',
        ],
        'LTT' => [
            'LTT',
            'Talonas Liotuaineach',
        ],
        'LUC' => [
            'LUC',
            'Franc iompachail Lugsamburgach',
        ],
        'LUF' => [
            'LUF',
            'Franc Lugsamburgach',
        ],
        'LUL' => [
            'LUL',
            'Franc ionmhasail Lugsamburgach',
        ],
        'LVL' => [
            'LVL',
            'Lats Laitbheach',
        ],
        'LVR' => [
            'LVR',
            'Rùbal Laitbheach',
        ],
        'LYD' => [
            'LYD',
            'Dinar Libitheach',
        ],
        'MAD' => [
            'MAD',
            'Dirham Morocach',
        ],
        'MAF' => [
            'MAF',
            'Franc Morocach',
        ],
        'MCF' => [
            'MCF',
            'Franc Monacach',
        ],
        'MDC' => [
            'MDC',
            'Cupon Moldobhach',
        ],
        'MDL' => [
            'MDL',
            'Leu Moldobhach',
        ],
        'MGA' => [
            'MGA',
            'Ariary Madagasgarach',
        ],
        'MGF' => [
            'MGF',
            'Franc Madagasgarach',
        ],
        'MKD' => [
            'MKD',
            'Denar Masadonach',
        ],
        'MKN' => [
            'MKN',
            'Denar Masadonach (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'Franc Màilitheach',
        ],
        'MMK' => [
            'MMK',
            'Kyat Miànmarach',
        ],
        'MNT' => [
            'MNT',
            'Tugrik Mongolach',
        ],
        'MOP' => [
            'MOP',
            'Pataca Macàthuach',
        ],
        'MRO' => [
            'MRO',
            'Ouguiya Moratàineach (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Ouguiya Moratàineach',
        ],
        'MTL' => [
            'MTL',
            'Lira Maltach',
        ],
        'MTP' => [
            'MTP',
            'Punnd Maltach',
        ],
        'MUR' => [
            'MUR',
            'Rupee Moiriseasach',
        ],
        'MVP' => [
            'MVP',
            'Rupee Maladaibheach',
        ],
        'MVR' => [
            'MVR',
            'Rufiyaa Maladaibheach',
        ],
        'MWK' => [
            'MWK',
            'Kwacha Malabhaidheach',
        ],
        'MXN' => [
            'MX$',
            'Peso Meagsagach',
        ],
        'MXP' => [
            'MXP',
            'Peso airgid Meagsagach (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Aonad inbheistidh Meagsagach',
        ],
        'MYR' => [
            'MYR',
            'Ringgit Malaidheach',
        ],
        'MZE' => [
            'MZE',
            'Escudo Mòsaimbiceach',
        ],
        'MZM' => [
            'MZM',
            'Metical Mòsaimbiceach (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'Metical Mòsaimbiceach',
        ],
        'NAD' => [
            'NAD',
            'Dolar Naimibitheach',
        ],
        'NGN' => [
            'NGN',
            'Naira Nigèiriach',
        ],
        'NIC' => [
            'NIC',
            'Córdoba Niocaragach (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'Córdoba Niocaragach',
        ],
        'NLG' => [
            'NLG',
            'Gulden Duitseach',
        ],
        'NOK' => [
            'NOK',
            'Krone Nirribheach',
        ],
        'NPR' => [
            'NPR',
            'Rupee Neapàlach',
        ],
        'NZD' => [
            'NZ$',
            'Dolar Shealainn Nuaidh',
        ],
        'OMR' => [
            'OMR',
            'Rial Omànach',
        ],
        'PAB' => [
            'PAB',
            'Balboa Panamach',
        ],
        'PEI' => [
            'PEI',
            'Inti Pearùthach',
        ],
        'PEN' => [
            'PEN',
            'Sol Pearùthach',
        ],
        'PES' => [
            'PES',
            'Sol Pearùthach (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'Kina Ghini Nuaidh Paputhaiche',
        ],
        'PHP' => [
            'PHP',
            'Peso Filipineach',
        ],
        'PKR' => [
            'PKR',
            'Rupee Pagastànach',
        ],
        'PLN' => [
            'PLN',
            'Złoty Pòlainneach',
        ],
        'PLZ' => [
            'PLZ',
            'Złoty Pòlainneach (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'Escudo Portagaileach',
        ],
        'PYG' => [
            'PYG',
            'Guaraní Paraguaidheach',
        ],
        'QAR' => [
            'QAR',
            'Rial Catarach',
        ],
        'RHD' => [
            'RHD',
            'Dolar Rhodesiach',
        ],
        'ROL' => [
            'ROL',
            'Leu Romàineach (1952–2006)',
        ],
        'RON' => [
            'RON',
            'Leu Romàineach',
        ],
        'RSD' => [
            'RSD',
            'Dinar Sèirbeach',
        ],
        'RUB' => [
            'RUB',
            'Rùbal Ruiseach',
        ],
        'RUR' => [
            'RUR',
            'Rùbal Ruiseach (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'Franc Rubhandach',
        ],
        'SAR' => [
            'SAR',
            'Riyal Sabhdach',
        ],
        'SBD' => [
            'SBD',
            'Dolar Eileanan Sholaimh',
        ],
        'SCR' => [
            'SCR',
            'Rupee Seiseallach',
        ],
        'SDD' => [
            'SDD',
            'Dinar Sudànach (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'Punnd Sudànach',
        ],
        'SDP' => [
            'SDP',
            'Punnd Sudànach (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'Krona Suaineach',
        ],
        'SGD' => [
            'SGD',
            'Dolar Singeapòrach',
        ],
        'SHP' => [
            'SHP',
            'Punnd Eilean Naomh Eilidh',
        ],
        'SIT' => [
            'SIT',
            'Tolar Slòbhaineach',
        ],
        'SKK' => [
            'SKK',
            'Koruna Slòbhacach',
        ],
        'SLE' => [
            'SLE',
            'Leone Siarra Leòmhannach ùr',
        ],
        'SLL' => [
            'SLL',
            'Leone Siarra Leòmhannach',
        ],
        'SOS' => [
            'SOS',
            'Shilling Somàilitheach',
        ],
        'SRD' => [
            'SRD',
            'Dolar Suranamach',
        ],
        'SRG' => [
            'SRG',
            'Gulden Suranamach',
        ],
        'SSP' => [
            'SSP',
            'Punnd Sudàin a Deas',
        ],
        'STD' => [
            'STD',
            'Dobra São Tomé agus Príncipe (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Dobra São Tomé agus Príncipe',
        ],
        'SUR' => [
            'SUR',
            'Rùbal Sovietach',
        ],
        'SVC' => [
            'SVC',
            'Colón Salbhadorach',
        ],
        'SYP' => [
            'SYP',
            'Punnd Siridheach',
        ],
        'SZL' => [
            'SZL',
            'Lilangeni Suasaidheach',
        ],
        'THB' => [
            '฿',
            'Baht Tàidheach',
        ],
        'TJR' => [
            'TJR',
            'Rùbal Taidigeach',
        ],
        'TJS' => [
            'TJS',
            'Somoni Taidigeach',
        ],
        'TMM' => [
            'TMM',
            'Manat Turcmanach (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'Manat Turcmanach',
        ],
        'TND' => [
            'TND',
            'Dinar Tuiniseach',
        ],
        'TOP' => [
            'TOP',
            'Paʻanga Tongach',
        ],
        'TPE' => [
            'TPE',
            'Escudo Tìomorach',
        ],
        'TRL' => [
            'TRL',
            'Lira Turcach (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'Lira Turcach',
        ],
        'TTD' => [
            'TTD',
            'Dolar Thrianaid agus Thobago',
        ],
        'TWD' => [
            'NT$',
            'Dolar ùr Taidh-Bhànach',
        ],
        'TZS' => [
            'TZS',
            'Shilling Tansanaidheach',
        ],
        'UAH' => [
            'UAH',
            'Hryvnia Ucràineach',
        ],
        'UAK' => [
            'UAK',
            'Karbovanets Ucràineach',
        ],
        'UGS' => [
            'UGS',
            'Shilling Ugandach (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'Shilling Ugandach',
        ],
        'USD' => [
            '$',
            'Dolar nan Stàitean Aonaichte',
        ],
        'USN' => [
            'USN',
            'Dolar nan SA (an ath–latha)',
        ],
        'USS' => [
            'USS',
            'Dolar nan SA (an aon latha)',
        ],
        'UYI' => [
            'UYI',
            'Peso Uruguaidheach (aonadan inneacsaichte)',
        ],
        'UYP' => [
            'UYP',
            'Peso Uruguaidheach (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'Peso Uruguaidheach',
        ],
        'UYW' => [
            'UYW',
            'Aonad inneacs tuarastail ainmeach Uruguaidh',
        ],
        'UZS' => [
            'UZS',
            'Som Usbagach',
        ],
        'VEB' => [
            'VEB',
            'Bolívar Bheinisealach (1871–2008)',
        ],
        'VED' => [
            'VED',
            'Bolívar Soberano',
        ],
        'VEF' => [
            'VEF',
            'Bolívar Bheinisealach (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Bolívar Bheinisealach',
        ],
        'VND' => [
            '₫',
            'Dong Bhiet-Namach',
        ],
        'VNN' => [
            'VNN',
            'Dong Bhiet-Namach (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'Vatu Vanuatuthach',
        ],
        'WST' => [
            'WST',
            'Tala Samothach',
        ],
        'XAF' => [
            'FCFA',
            'Franc CFA Meadhan-Afragach',
        ],
        'XCD' => [
            'EC$',
            'Dolar Caraibeach earach',
        ],
        'XCG' => [
            'Cg.',
            'Gulden Caraibeach',
        ],
        'XEU' => [
            'XEU',
            'Aonad airgeadra Eòrpach',
        ],
        'XFO' => [
            'XFO',
            'Franc òir Frangach',
        ],
        'XFU' => [
            'XFU',
            'Franc UIC Frangach',
        ],
        'XOF' => [
            'F CFA',
            'Franc CFA Afraga an Iar',
        ],
        'XPF' => [
            'CFPF',
            'Franc CFP',
        ],
        'XRE' => [
            'XRE',
            'Aonad maoine RINET',
        ],
        'YDD' => [
            'YDD',
            'Dinar Eamanach',
        ],
        'YER' => [
            'YER',
            'Rial Eamanach',
        ],
        'YUD' => [
            'YUD',
            'Dinar cruaidh Iùgoslabhach (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'Dinar ùr Iùgoslabhach (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'Dinar iompachail Iùgoslabhach (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'Dinar ath-leasaichte Iùgoslabhach (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'Rand Afraga a Deas (ionmhasail)',
        ],
        'ZAR' => [
            'ZAR',
            'Rand Afraga a Deas',
        ],
        'ZMK' => [
            'ZMK',
            'Kwacha Sàimbitheach (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Kwacha Sàimbitheach',
        ],
        'ZRN' => [
            'ZRN',
            'Zaïre ùr Zaïreach (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'Zaïre Zaïreach (1971–1993)',
        ],
        'ZWD' => [
            'ZWD',
            'Dolar Sìombabuthach (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'Òr Sìombabuthach',
        ],
        'ZWL' => [
            'ZWL',
            'Dolar Sìombabuthach (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'Dolar Sìombabuthach (2008)',
        ],
    ],
];
