<?php

return [
    'Names' => [
        'aa' => 'афарски',
        'ab' => 'абхазки',
        'ace' => 'ачешки',
        'ach' => 'аколи',
        'ada' => 'адангме',
        'ady' => 'адигейски',
        'ae' => 'авестски',
        'af' => 'африканс',
        'afh' => 'африхили',
        'agq' => 'агем',
        'ain' => 'айну',
        'ak' => 'акан',
        'akk' => 'акадски',
        'ale' => 'алеутски',
        'alt' => 'южноалтайски',
        'am' => 'амхарски',
        'an' => 'арагонски',
        'ang' => 'староанглийски',
        'ann' => 'оболо',
        'anp' => 'ангика',
        'ar' => 'арабски',
        'arc' => 'арамейски',
        'arn' => 'мапуче',
        'arp' => 'арапахо',
        'ars' => 'найди арабски',
        'arw' => 'аравак',
        'as' => 'асамски',
        'asa' => 'асу',
        'ast' => 'астурски',
        'atj' => 'атикамеку',
        'av' => 'аварски',
        'awa' => 'авади',
        'ay' => 'аймара',
        'az' => 'азербайджански',
        'ba' => 'башкирски',
        'bal' => 'балучи',
        'ban' => 'балийски',
        'bas' => 'баса',
        'be' => 'беларуски',
        'bej' => 'бея',
        'bem' => 'бемба',
        'bez' => 'бена',
        'bg' => 'български',
        'bgc' => 'харианви',
        'bgn' => 'западен балочи',
        'bho' => 'боджпури',
        'bi' => 'бислама',
        'bik' => 'биколски',
        'bin' => 'бини',
        'bla' => 'сиксика',
        'blo' => 'ании',
        'bm' => 'бамбара',
        'bn' => 'бенгалски',
        'bo' => 'тибетски',
        'br' => 'бретонски',
        'bra' => 'брадж',
        'brx' => 'бодо',
        'bs' => 'босненски',
        'bua' => 'бурятски',
        'bug' => 'бугински',
        'byn' => 'биленски',
        'ca' => 'каталонски',
        'cad' => 'каддо',
        'car' => 'карибски',
        'cay' => 'каюга',
        'cch' => 'атсам',
        'ccp' => 'чакма',
        'ce' => 'чеченски',
        'ceb' => 'себуански',
        'cgg' => 'чига',
        'ch' => 'чаморо',
        'chb' => 'чибча',
        'chg' => 'чагатай',
        'chk' => 'чуук',
        'chm' => 'марийски',
        'chn' => 'жаргон чинуук',
        'cho' => 'чокто',
        'chp' => 'чипеуански',
        'chr' => 'черокски',
        'chy' => 'шайенски',
        'ckb' => 'кюрдски (централен)',
        'clc' => 'чилкотин',
        'co' => 'корсикански',
        'cop' => 'коптски',
        'cr' => 'крии',
        'crg' => 'мичиф',
        'crh' => 'кримскотатарски',
        'crj' => 'югоизточен крий',
        'crk' => 'плейнс крий',
        'crl' => 'североизточен крий',
        'crm' => 'муус крее',
        'crr' => 'каролински алгонкин',
        'crs' => 'сеселва, креолски френски',
        'cs' => 'чешки',
        'csb' => 'кашубски',
        'csw' => 'суампи крий',
        'cu' => 'църковнославянски',
        'cv' => 'чувашки',
        'cy' => 'уелски',
        'da' => 'датски',
        'dak' => 'дакотски',
        'dar' => 'даргински',
        'dav' => 'таита',
        'de' => 'немски',
        'del' => 'делауер',
        'den' => 'слейви',
        'dgr' => 'догриб',
        'din' => 'динка',
        'dje' => 'зарма',
        'doi' => 'догри',
        'dsb' => 'долнолужишки',
        'dua' => 'дуала',
        'dum' => 'средновековен холандски',
        'dv' => 'дивехи',
        'dyo' => 'диола-фони',
        'dyu' => 'диула',
        'dz' => 'дзонгкха',
        'dzg' => 'дазага',
        'ebu' => 'ембу',
        'ee' => 'еве',
        'efi' => 'ефик',
        'egy' => 'древноегипетски',
        'eka' => 'екажук',
        'el' => 'гръцки',
        'elx' => 'еламитски',
        'en' => 'английски',
        'enm' => 'средновековен английски',
        'eo' => 'есперанто',
        'es' => 'испански',
        'et' => 'естонски',
        'eu' => 'баски',
        'ewo' => 'евондо',
        'fa' => 'персийски',
        'fan' => 'фанг',
        'fat' => 'фанти',
        'ff' => 'фула',
        'fi' => 'фински',
        'fil' => 'филипински',
        'fj' => 'фиджийски',
        'fo' => 'фарьорски',
        'fon' => 'фон',
        'fr' => 'френски',
        'frc' => 'каджунски френски',
        'frm' => 'средновековен френски',
        'fro' => 'старофренски',
        'frr' => 'северен фризийски',
        'frs' => 'източнофризийски',
        'fur' => 'фриулски',
        'fy' => 'западнофризийски',
        'ga' => 'ирландски',
        'gaa' => 'га',
        'gag' => 'гагаузки',
        'gay' => 'гайо',
        'gba' => 'гбая',
        'gd' => 'шотландски келтски',
        'gez' => 'гииз',
        'gil' => 'гилбертски',
        'gl' => 'галисийски',
        'gmh' => 'средновисоконемски',
        'gn' => 'гуарани',
        'goh' => 'старовисоконемски',
        'gon' => 'гонди',
        'gor' => 'горонтало',
        'got' => 'готически',
        'grb' => 'гребо',
        'grc' => 'древногръцки',
        'gsw' => 'швейцарски немски',
        'gu' => 'гуджарати',
        'guz' => 'гусии',
        'gv' => 'манкски',
        'gwi' => 'гвичин',
        'ha' => 'хауса',
        'hai' => 'хайда',
        'haw' => 'хавайски',
        'hax' => 'южен хайда',
        'he' => 'иврит',
        'hi' => 'хинди',
        'hil' => 'хилигайнон',
        'hit' => 'хитски',
        'hmn' => 'хмонг',
        'ho' => 'хири моту',
        'hr' => 'хърватски',
        'hsb' => 'горнолужишки',
        'ht' => 'хаитянски креолски',
        'hu' => 'унгарски',
        'hup' => 'хупа',
        'hur' => 'халкомелем',
        'hy' => 'арменски',
        'hz' => 'хереро',
        'ia' => 'интерлингва',
        'iba' => 'ибан',
        'ibb' => 'ибибио',
        'id' => 'индонезийски',
        'ie' => 'интерлингве',
        'ig' => 'игбо',
        'ii' => 'съчуански йи',
        'ik' => 'инупиак',
        'ikt' => 'западноканадски инуктитут',
        'ilo' => 'илоко',
        'inh' => 'ингушетски',
        'io' => 'идо',
        'is' => 'исландски',
        'it' => 'италиански',
        'iu' => 'инуктитут',
        'ja' => 'японски',
        'jbo' => 'ложбан',
        'jgo' => 'нгомба',
        'jmc' => 'мачаме',
        'jpr' => 'юдео-персийски',
        'jrb' => 'юдео-арабски',
        'jv' => 'явански',
        'ka' => 'грузински',
        'kaa' => 'каракалпашки',
        'kab' => 'кабилски',
        'kac' => 'качински',
        'kaj' => 'жжу',
        'kam' => 'камба',
        'kaw' => 'кави',
        'kbd' => 'кабардски',
        'kcg' => 'туап',
        'kde' => 'маконде',
        'kea' => 'кабовердиански',
        'kfo' => 'коро',
        'kg' => 'конгоански',
        'kgp' => 'кайнганг',
        'kha' => 'кхаси',
        'kho' => 'котски',
        'khq' => 'койра чиини',
        'ki' => 'кикую',
        'kj' => 'кваняма',
        'kk' => 'казахски',
        'kkj' => 'како',
        'kl' => 'гренландски',
        'kln' => 'календжин',
        'km' => 'кхмерски',
        'kmb' => 'кимбунду',
        'kn' => 'каннада',
        'ko' => 'корейски',
        'koi' => 'коми-пермякски',
        'kok' => 'конкани',
        'kos' => 'косраен',
        'kpe' => 'кпеле',
        'kr' => 'канури',
        'krc' => 'карачай-балкарски',
        'krl' => 'карелски',
        'kru' => 'курук',
        'ks' => 'кашмирски',
        'ksb' => 'шамбала',
        'ksf' => 'бафия',
        'ksh' => 'кьолнски',
        'ku' => 'кюрдски',
        'kum' => 'кумикски',
        'kut' => 'кутенай',
        'kv' => 'коми',
        'kw' => 'корнуолски',
        'kwk' => 'куак’уала',
        'kxv' => 'кови',
        'ky' => 'киргизки',
        'la' => 'латински',
        'lad' => 'ладино',
        'lag' => 'ланги',
        'lah' => 'лахнда',
        'lam' => 'ламба',
        'lb' => 'люксембургски',
        'lez' => 'лезгински',
        'lg' => 'ганда',
        'li' => 'лимбургски',
        'lij' => 'лигурски',
        'lil' => 'лилоует',
        'lkt' => 'лакота',
        'lmo' => 'ломбардски',
        'ln' => 'лингала',
        'lo' => 'лаоски',
        'lol' => 'монго',
        'lou' => 'луизиански креолски',
        'loz' => 'лози',
        'lrc' => 'северен лури',
        'lsm' => 'саамски',
        'lt' => 'литовски',
        'lu' => 'луба-катанга',
        'lua' => 'луба-лулуа',
        'lui' => 'луисеньо',
        'lun' => 'лунда',
        'luo' => 'луо',
        'lus' => 'мизо',
        'luy' => 'лухя',
        'lv' => 'латвийски',
        'mad' => 'мадурски',
        'mag' => 'магахи',
        'mai' => 'майтхили',
        'mak' => 'макасар',
        'man' => 'мандинго',
        'mas' => 'масайски',
        'mdf' => 'мокша',
        'mdr' => 'мандар',
        'men' => 'менде',
        'mer' => 'меру',
        'mfe' => 'морисиен',
        'mg' => 'малгашки',
        'mga' => 'средновековен ирландски',
        'mgh' => 'макуа мето',
        'mgo' => 'мета',
        'mh' => 'маршалезе',
        'mi' => 'маорски',
        'mic' => 'микмак',
        'min' => 'минангкабау',
        'mk' => 'македонски',
        'ml' => 'малаялам',
        'mn' => 'монголски',
        'mnc' => 'манджурски',
        'mni' => 'манипурски',
        'moe' => 'инну-аймун',
        'moh' => 'мохоук',
        'mos' => 'моси',
        'mr' => 'марати',
        'ms' => 'малайски',
        'mt' => 'малтийски',
        'mua' => 'мунданг',
        'mus' => 'мускогски',
        'mwl' => 'мирандийски',
        'mwr' => 'марвари',
        'my' => 'бирмански',
        'myv' => 'ерзиа',
        'mzn' => 'мазандерански',
        'na' => 'науру',
        'nap' => 'неаполитански',
        'naq' => 'нама',
        'nb' => 'норвежки (букмол)',
        'nd' => 'северен ндебеле',
        'nds' => 'долнонемски',
        'ne' => 'непалски',
        'new' => 'неварски',
        'ng' => 'ндонга',
        'nia' => 'ниас',
        'niu' => 'ниуеан',
        'nl' => 'нидерландски',
        'nmg' => 'квасио',
        'nn' => 'норвежки (нюношк)',
        'nnh' => 'нгиембун',
        'no' => 'норвежки',
        'nog' => 'ногаи',
        'non' => 'старонорвежки',
        'nqo' => 'нко',
        'nr' => 'южен ндебеле',
        'nso' => 'северен сото',
        'nus' => 'нуер',
        'nv' => 'навахо',
        'nwc' => 'класически невари',
        'ny' => 'нянджа',
        'nym' => 'ниамвези',
        'nyn' => 'нянколе',
        'nyo' => 'нуоро',
        'nzi' => 'нзима',
        'oc' => 'окситански',
        'oj' => 'оджибва',
        'ojb' => 'северозападен оджибве',
        'ojc' => 'централен оджибва',
        'ojs' => 'оджи крий',
        'ojw' => 'западен оджибва',
        'oka' => 'оканаган',
        'om' => 'оромо',
        'or' => 'ория',
        'os' => 'осетински',
        'osa' => 'осейджи',
        'ota' => 'отомански турски',
        'pa' => 'пенджабски',
        'pag' => 'пангасинан',
        'pal' => 'пахлави',
        'pam' => 'пампанга',
        'pap' => 'папиаменто',
        'pau' => 'палауан',
        'pcm' => 'нигерийски пиджин',
        'peo' => 'староперсийски',
        'phn' => 'финикийски',
        'pi' => 'пали',
        'pis' => 'пиджин',
        'pl' => 'полски',
        'pon' => 'понапеан',
        'pqm' => 'малисеет-пасамакуоди',
        'prg' => 'пруски',
        'pro' => 'старопровансалски',
        'ps' => 'пущу',
        'pt' => 'португалски',
        'qu' => 'кечуа',
        'quc' => 'киче',
        'raj' => 'раджастански',
        'rap' => 'рапа нуи',
        'rar' => 'раротонга',
        'rhg' => 'рохинга',
        'rm' => 'реторомански',
        'rn' => 'рунди',
        'ro' => 'румънски',
        'rof' => 'ромбо',
        'rom' => 'ромски',
        'ru' => 'руски',
        'rup' => 'арумънски',
        'rw' => 'киняруанда',
        'rwk' => 'рва',
        'sa' => 'санскрит',
        'sad' => 'сандаве',
        'sah' => 'саха',
        'sam' => 'самаритански арамейски',
        'saq' => 'самбуру',
        'sas' => 'сасак',
        'sat' => 'сантали',
        'sba' => 'нгамбай',
        'sbp' => 'сангу',
        'sc' => 'сардински',
        'scn' => 'сицилиански',
        'sco' => 'шотландски',
        'sd' => 'синдхи',
        'sdh' => 'южнокюрдски',
        'se' => 'северносаамски',
        'seh' => 'сена',
        'sel' => 'селкуп',
        'ses' => 'койраборо сени',
        'sg' => 'санго',
        'sga' => 'староирландски',
        'sh' => 'сърбохърватски',
        'shi' => 'ташелхит',
        'shn' => 'шан',
        'si' => 'синхалски',
        'sid' => 'сидамо',
        'sk' => 'словашки',
        'sl' => 'словенски',
        'slh' => 'южен лашутсийд',
        'sm' => 'самоански',
        'sma' => 'южносаамски',
        'smj' => 'луле-саамски',
        'smn' => 'инари-саамски',
        'sms' => 'сколт-саамски',
        'sn' => 'шона',
        'snk' => 'сонинке',
        'so' => 'сомалийски',
        'sog' => 'согдийски',
        'sq' => 'албански',
        'sr' => 'сръбски',
        'srn' => 'сранан тонго',
        'srr' => 'серер',
        'ss' => 'свати',
        'ssy' => 'сахо',
        'st' => 'сото',
        'str' => 'стрейтс салиш',
        'su' => 'сундански',
        'suk' => 'сукума',
        'sus' => 'сусу',
        'sux' => 'шумерски',
        'sv' => 'шведски',
        'sw' => 'суахили',
        'swb' => 'коморски',
        'syc' => 'класически сирийски',
        'syr' => 'сирийски',
        'szl' => 'силезийски',
        'ta' => 'тамилски',
        'tce' => 'южен тучоне',
        'te' => 'телугу',
        'tem' => 'темне',
        'teo' => 'тесо',
        'ter' => 'терено',
        'tet' => 'тетум',
        'tg' => 'таджикски',
        'tgx' => 'тагиш',
        'th' => 'тайски',
        'tht' => 'талтан',
        'ti' => 'тигриня',
        'tig' => 'тигре',
        'tiv' => 'тив',
        'tk' => 'туркменски',
        'tkl' => 'токелайски',
        'tl' => 'тагалог',
        'tlh' => 'клингонски',
        'tli' => 'тлингит',
        'tmh' => 'тамашек',
        'tn' => 'тсвана',
        'to' => 'тонгански',
        'tog' => 'нианса тонга',
        'tok' => 'токи пона',
        'tpi' => 'ток писин',
        'tr' => 'турски',
        'trv' => 'тароко',
        'ts' => 'цонга',
        'tsi' => 'цимшиански',
        'tt' => 'татарски',
        'ttm' => 'северен тучоне',
        'tum' => 'тумбука',
        'tvl' => 'тувалуански',
        'tw' => 'туи',
        'twq' => 'тасавак',
        'ty' => 'таитянски',
        'tyv' => 'тувински',
        'tzm' => 'централноатласки тамазигт',
        'udm' => 'удмуртски',
        'ug' => 'уйгурски',
        'uga' => 'угаритски',
        'uk' => 'украински',
        'umb' => 'умбунду',
        'ur' => 'урду',
        'uz' => 'узбекски',
        'vai' => 'ваи',
        've' => 'венда',
        'vec' => 'венециански',
        'vi' => 'виетнамски',
        'vmw' => 'макува',
        'vo' => 'волапюк',
        'vot' => 'вотик',
        'vun' => 'вунджо',
        'wa' => 'валонски',
        'wae' => 'валзерски немски',
        'wal' => 'валамо',
        'war' => 'варай',
        'was' => 'уашо',
        'wbp' => 'валпири',
        'wo' => 'волоф',
        'wuu' => 'ву китайски',
        'xal' => 'калмик',
        'xh' => 'кхоса',
        'xnr' => 'кангри',
        'xog' => 'сога',
        'yao' => 'яо',
        'yap' => 'япезе',
        'yav' => 'янгбен',
        'ybb' => 'йемба',
        'yi' => 'идиш',
        'yo' => 'йоруба',
        'yrl' => 'ненгату',
        'yue' => 'кантонски',
        'za' => 'зуанг',
        'zap' => 'запотек',
        'zbl' => 'блис символи',
        'zen' => 'зенага',
        'zgh' => 'стандартен марокански тамазигт',
        'zh' => 'китайски',
        'zu' => 'зулуски',
        'zun' => 'зуни',
        'zza' => 'заза',
    ],
    'LocalizedNames' => [
        'ar_001' => 'съвременен стандартен арабски',
        'en_AU' => 'австралийски английски',
        'en_CA' => 'канадски английски',
        'en_GB' => 'британски английски',
        'en_US' => 'американски английски',
        'fa_AF' => 'дари',
        'nds_NL' => 'долносаксонски',
        'nl_BE' => 'фламандски',
        'ro_MD' => 'молдовски',
        'sw_CD' => 'конгоански суахили',
        'zh_Hans' => 'китайски (опростен)',
        'zh_Hant' => 'китайски (традиционен)',
    ],
];
