<?php

return [
    'Names' => [
        'GNF' => [
            'GNF',
            '𞤊𞤢𞤪𞤢𞤲 𞤘𞤭𞤲𞤫𞤲𞤳𞤮',
        ],
        'NGN' => [
            '₦',
            '𞤐𞤢𞤴𞤪𞤢 𞤐𞤢𞤶𞤭𞤪𞤢𞤴𞤢𞤲𞤳𞤮',
        ],
    ],
];
