<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Андорска пезета',
        ],
        'AED' => [
            'AED',
            'дирхам УАЕ',
        ],
        'AFA' => [
            'AFA',
            'Авганистански авгани (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'авганистански авгани',
        ],
        'ALL' => [
            'ALL',
            'албански лек',
        ],
        'AMD' => [
            'AMD',
            'јерменски драм',
        ],
        'ANG' => [
            'ANG',
            'холандскоантилски гулден',
        ],
        'AOA' => [
            'AOA',
            'анголска кванза',
        ],
        'AOK' => [
            'AOK',
            'Анголијска кванза (1977–1990)',
        ],
        'AON' => [
            'AON',
            'Анголијска нова кванза (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Анголијска кванза реађустадо (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Аргентински аустрал',
        ],
        'ARP' => [
            'ARP',
            'Аргентински пезо (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'аргентински пезос',
        ],
        'ATS' => [
            'ATS',
            'Аустријски шилинг',
        ],
        'AUD' => [
            'AUD',
            'аустралијски долар',
        ],
        'AWG' => [
            'AWG',
            'арубански флорин',
        ],
        'AZM' => [
            'AZM',
            'Азербејџански манат (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'азербејџански манат',
        ],
        'BAD' => [
            'BAD',
            'Босанско-Херцеговачки динар',
        ],
        'BAM' => [
            'КМ',
            'босанскохерцеговачка конвертибилна марка',
        ],
        'BBD' => [
            'BBD',
            'барбадошки долар',
        ],
        'BDT' => [
            'BDT',
            'бангладешка така',
        ],
        'BEC' => [
            'BEC',
            'Белгијски франак (конвертибилни)',
        ],
        'BEF' => [
            'BEF',
            'Белгијски франак',
        ],
        'BEL' => [
            'BEL',
            'Белгијски франак (финансијски)',
        ],
        'BGL' => [
            'BGL',
            'Бугарски тврди лев',
        ],
        'BGN' => [
            'BGN',
            'бугарски лев',
        ],
        'BHD' => [
            'BHD',
            'бахреински динар',
        ],
        'BIF' => [
            'BIF',
            'бурундски франак',
        ],
        'BMD' => [
            'BMD',
            'бермудски долар',
        ],
        'BND' => [
            'BND',
            'брунејски долар',
        ],
        'BOB' => [
            'BOB',
            'боливијски боливијано',
        ],
        'BOP' => [
            'BOP',
            'Боливијски пезо',
        ],
        'BOV' => [
            'BOV',
            'Боливијски мвдол',
        ],
        'BRB' => [
            'BRB',
            'Бразилски нови крузеиро (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Бразилијски крузадо',
        ],
        'BRE' => [
            'BRE',
            'Бразилски крузеиро (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'бразилски реал',
        ],
        'BRN' => [
            'BRN',
            'Бразилијски нови крузадо',
        ],
        'BRR' => [
            'BRR',
            'Бразилски крузеиро',
        ],
        'BSD' => [
            'BSD',
            'бахамски долар',
        ],
        'BTN' => [
            'BTN',
            'бутански нгултрум',
        ],
        'BUK' => [
            'BUK',
            'Бурмански кјат',
        ],
        'BWP' => [
            'BWP',
            'боцванска пула',
        ],
        'BYB' => [
            'BYB',
            'Белоруска нова рубља (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'белоруска рубља',
        ],
        'BYR' => [
            'BYR',
            'Белоруска рубља (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'белиски долар',
        ],
        'CAD' => [
            'CA$',
            'канадски долар',
        ],
        'CDF' => [
            'CDF',
            'конгоански франак',
        ],
        'CHE' => [
            'CHE',
            'WIR евро',
        ],
        'CHF' => [
            'CHF',
            'швајцарски франак',
        ],
        'CHW' => [
            'CHW',
            'WIR франак',
        ],
        'CLF' => [
            'CLF',
            'Чилеовски унидадес се фоменто',
        ],
        'CLP' => [
            'CLP',
            'чилеански пезос',
        ],
        'CNH' => [
            'CNH',
            'кинески јуан (острвски)',
        ],
        'CNY' => [
            'CN¥',
            'кинески јуан',
        ],
        'COP' => [
            'COP',
            'колумбијски пезос',
        ],
        'COU' => [
            'COU',
            'Унидад де валоршки реал',
        ],
        'CRC' => [
            'CRC',
            'костарикански колон',
        ],
        'CSD' => [
            'CSD',
            'Стари српски динар',
        ],
        'CSK' => [
            'CSK',
            'Чехословачка тврда круна',
        ],
        'CUC' => [
            'CUC',
            'кубански конвертибилни пезос',
        ],
        'CUP' => [
            'CUP',
            'кубански пезос',
        ],
        'CVE' => [
            'CVE',
            'зеленортски ескудо',
        ],
        'CYP' => [
            'CYP',
            'Кипарска фунта',
        ],
        'CZK' => [
            'CZK',
            'чешка круна',
        ],
        'DDM' => [
            'DDM',
            'Источно-немачка марка',
        ],
        'DEM' => [
            'DEM',
            'Немачка марка',
        ],
        'DJF' => [
            'DJF',
            'џибутски франак',
        ],
        'DKK' => [
            'DKK',
            'данска круна',
        ],
        'DOP' => [
            'DOP',
            'доминикански пезос',
        ],
        'DZD' => [
            'DZD',
            'алжирски динар',
        ],
        'ECS' => [
            'ECS',
            'Еквадорски сакр',
        ],
        'ECV' => [
            'ECV',
            'Еквадорски унидад де валор константе',
        ],
        'EEK' => [
            'EEK',
            'Естонска кроон',
        ],
        'EGP' => [
            'EGP',
            'египатска фунта',
        ],
        'ERN' => [
            'ERN',
            'еритрејска накфа',
        ],
        'ESA' => [
            'ESA',
            'Шпанска пезета (рачун)',
        ],
        'ESB' => [
            'ESB',
            'Шпанска пезета (конвертибилнирачун)',
        ],
        'ESP' => [
            'ESP',
            'Шпанска пезета',
        ],
        'ETB' => [
            'ETB',
            'етиопијски бир',
        ],
        'EUR' => [
            '€',
            'евро',
        ],
        'FIM' => [
            'FIM',
            'Финска марка',
        ],
        'FJD' => [
            'FJD',
            'фиџијски долар',
        ],
        'FKP' => [
            'FKP',
            'фолкландска фунта',
        ],
        'FRF' => [
            'FRF',
            'Француски франак',
        ],
        'GBP' => [
            '£',
            'британска фунта',
        ],
        'GEK' => [
            'GEK',
            'Грузијски купон ларит',
        ],
        'GEL' => [
            'GEL',
            'грузијски лари',
        ],
        'GHC' => [
            'GHC',
            'Гански цеди (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'гански седи',
        ],
        'GIP' => [
            'GIP',
            'гибралтарска фунта',
        ],
        'GMD' => [
            'GMD',
            'гамбијски даласи',
        ],
        'GNF' => [
            'GNF',
            'гвинејски франак',
        ],
        'GNS' => [
            'GNS',
            'Гвинејски сили',
        ],
        'GQE' => [
            'GQE',
            'Екваторијално-гвинејски еквеле',
        ],
        'GRD' => [
            'GRD',
            'Грчка драхма',
        ],
        'GTQ' => [
            'GTQ',
            'гватемалски кецал',
        ],
        'GWE' => [
            'GWE',
            'Португалска гвинеја ескудо',
        ],
        'GWP' => [
            'GWP',
            'Гвинеја Бисао Пезо',
        ],
        'GYD' => [
            'GYD',
            'гвајански долар',
        ],
        'HKD' => [
            'HK$',
            'хонгконшки долар',
        ],
        'HNL' => [
            'HNL',
            'хондурашка лемпира',
        ],
        'HRD' => [
            'HRD',
            'Хрватски динар',
        ],
        'HRK' => [
            'HRK',
            'хрватска куна',
        ],
        'HTG' => [
            'HTG',
            'хаићански гурд',
        ],
        'HUF' => [
            'HUF',
            'мађарска форинта',
        ],
        'IDR' => [
            'IDR',
            'индонежанска рупија',
        ],
        'IEP' => [
            'IEP',
            'Ирска фунта',
        ],
        'ILP' => [
            'ILP',
            'Израелска фунта',
        ],
        'ILR' => [
            'ILR',
            'Стари израелски шекели',
        ],
        'ILS' => [
            '₪',
            'израелски нови шекел',
        ],
        'INR' => [
            '₹',
            'индијска рупија',
        ],
        'IQD' => [
            'IQD',
            'ирачки динар',
        ],
        'IRR' => [
            'IRR',
            'ирански ријал',
        ],
        'ISJ' => [
            'ISJ',
            'Стара исландска круна',
        ],
        'ISK' => [
            'ISK',
            'исландска круна',
        ],
        'ITL' => [
            'ITL',
            'Италијанска лира',
        ],
        'JMD' => [
            'JMD',
            'јамајчански долар',
        ],
        'JOD' => [
            'JOD',
            'јордански динар',
        ],
        'JPY' => [
            '¥',
            'јапански јен',
        ],
        'KES' => [
            'KES',
            'кенијски шилинг',
        ],
        'KGS' => [
            'KGS',
            'киргистански сом',
        ],
        'KHR' => [
            'KHR',
            'камбоџански ријел',
        ],
        'KMF' => [
            'KMF',
            'коморски франак',
        ],
        'KPW' => [
            'KPW',
            'севернокорејски вон',
        ],
        'KRW' => [
            'KRW',
            'јужнокорејски вон',
        ],
        'KWD' => [
            'KWD',
            'кувајтски динар',
        ],
        'KYD' => [
            'KYD',
            'кајмански долар',
        ],
        'KZT' => [
            'KZT',
            'казахстански тенге',
        ],
        'LAK' => [
            'LAK',
            'лаоски кип',
        ],
        'LBP' => [
            'LBP',
            'либанска фунта',
        ],
        'LKR' => [
            'LKR',
            'шриланчанска рупија',
        ],
        'LRD' => [
            'LRD',
            'либеријски долар',
        ],
        'LSL' => [
            'LSL',
            'лесотски лоти',
        ],
        'LTL' => [
            'LTL',
            'Литвански литас',
        ],
        'LTT' => [
            'LTT',
            'Литвански талонас',
        ],
        'LUC' => [
            'LUC',
            'Луксембуршки конвертибилни франак',
        ],
        'LUF' => [
            'LUF',
            'Луксембуршки франак',
        ],
        'LUL' => [
            'LUL',
            'Луксембуршки финансијски франак',
        ],
        'LVL' => [
            'LVL',
            'Латвијски лати',
        ],
        'LVR' => [
            'LVR',
            'Латвијска рубља',
        ],
        'LYD' => [
            'LYD',
            'либијски динар',
        ],
        'MAD' => [
            'MAD',
            'марокански дирхам',
        ],
        'MAF' => [
            'MAF',
            'Марокански франак',
        ],
        'MDL' => [
            'MDL',
            'молдавски леј',
        ],
        'MGA' => [
            'MGA',
            'малгашки аријари',
        ],
        'MGF' => [
            'MGF',
            'Малагасијски франак',
        ],
        'MKD' => [
            'MKD',
            'македонски денар',
        ],
        'MLF' => [
            'MLF',
            'Малијански франак',
        ],
        'MMK' => [
            'MMK',
            'мјанмарски кјат',
        ],
        'MNT' => [
            'MNT',
            'монголски тугрик',
        ],
        'MOP' => [
            'MOP',
            'макаоска патака',
        ],
        'MRO' => [
            'MRO',
            'Мауританијска oгија (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'мауританска огија',
        ],
        'MTL' => [
            'MTL',
            'Малтешка лира',
        ],
        'MTP' => [
            'MTP',
            'Малтешка фунта',
        ],
        'MUR' => [
            'MUR',
            'маурицијска рупија',
        ],
        'MVR' => [
            'MVR',
            'малдивска руфија',
        ],
        'MWK' => [
            'MWK',
            'малавијска квача',
        ],
        'MXN' => [
            'MX$',
            'мексички пезос',
        ],
        'MXP' => [
            'MXP',
            'Мексички сребрни пезо (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Мексички унидад де инверсион (UDI)',
        ],
        'MYR' => [
            'MYR',
            'малезијски рингит',
        ],
        'MZE' => [
            'MZE',
            'Мозамбијски ескудо',
        ],
        'MZM' => [
            'MZM',
            'Стари мозамбијски метикал',
        ],
        'MZN' => [
            'MZN',
            'мозамбички метикал',
        ],
        'NAD' => [
            'NAD',
            'намибијски долар',
        ],
        'NGN' => [
            'NGN',
            'нигеријска наира',
        ],
        'NIC' => [
            'NIC',
            'никарагванска кордоба (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'никарагванска кордоба',
        ],
        'NLG' => [
            'NLG',
            'Холандски гулден',
        ],
        'NOK' => [
            'NOK',
            'норвешка круна',
        ],
        'NPR' => [
            'NPR',
            'непалска рупија',
        ],
        'NZD' => [
            'NZD',
            'новозеландски долар',
        ],
        'OMR' => [
            'OMR',
            'омански ријал',
        ],
        'PAB' => [
            'PAB',
            'панамска балбоа',
        ],
        'PEI' => [
            'PEI',
            'Перуански инти',
        ],
        'PEN' => [
            'PEN',
            'перуански сол',
        ],
        'PES' => [
            'PES',
            'Перуански сол (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'папуанска кина',
        ],
        'PHP' => [
            'PHP',
            'филипински пезос',
        ],
        'PKR' => [
            'PKR',
            'пакистанска рупија',
        ],
        'PLN' => [
            'PLN',
            'пољски злот',
        ],
        'PLZ' => [
            'PLZ',
            'Пољски злоти (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'Португалски ескудо',
        ],
        'PYG' => [
            'PYG',
            'парагвајски гварани',
        ],
        'QAR' => [
            'QAR',
            'катарски ријал',
        ],
        'RHD' => [
            'RHD',
            'Родејскидолар',
        ],
        'ROL' => [
            'ROL',
            'Румунски леј (1952–2006)',
        ],
        'RON' => [
            'RON',
            'румунски леј',
        ],
        'RSD' => [
            'RSD',
            'српски динар',
        ],
        'RUB' => [
            'RUB',
            'руска рубља',
        ],
        'RUR' => [
            'RUR',
            'Руска рубља (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'руандски франак',
        ],
        'SAR' => [
            'SAR',
            'саудијски ријал',
        ],
        'SBD' => [
            'SBD',
            'соломонски долар',
        ],
        'SCR' => [
            'SCR',
            'сејшелска рупија',
        ],
        'SDD' => [
            'SDD',
            'Стари судански динар',
        ],
        'SDG' => [
            'SDG',
            'суданска фунта',
        ],
        'SDP' => [
            'SDP',
            'Стара суданска фунта',
        ],
        'SEK' => [
            'SEK',
            'шведска круна',
        ],
        'SGD' => [
            'SGD',
            'сингапурски долар',
        ],
        'SHP' => [
            'SHP',
            'фунта Свете Јелене',
        ],
        'SIT' => [
            'SIT',
            'Словеначки толар',
        ],
        'SKK' => [
            'SKK',
            'Словачка круна',
        ],
        'SLE' => [
            'SLE',
            'сијералеонски леоне',
        ],
        'SLL' => [
            'SLL',
            'сијералеонски леоне (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'сомалијски шилинг',
        ],
        'SRD' => [
            'SRD',
            'суринамски долар',
        ],
        'SRG' => [
            'SRG',
            'Суринамски гилдер',
        ],
        'SSP' => [
            'SSP',
            'јужносуданска фунта',
        ],
        'STD' => [
            'STD',
            'Саотомска добра (1977–2017)',
        ],
        'STN' => [
            'STN',
            'саотомска добра',
        ],
        'SUR' => [
            'SUR',
            'Совјетска рубља',
        ],
        'SVC' => [
            'SVC',
            'Салвадорски колон',
        ],
        'SYP' => [
            'SYP',
            'сиријска фунта',
        ],
        'SZL' => [
            'SZL',
            'свазилендски лилангени',
        ],
        'THB' => [
            'THB',
            'тајландски бат',
        ],
        'TJR' => [
            'TJR',
            'Таџихистанска рубља',
        ],
        'TJS' => [
            'TJS',
            'таџикистански сомон',
        ],
        'TMM' => [
            'TMM',
            'Туркменистански манат (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'туркменистански манат',
        ],
        'TND' => [
            'TND',
            'туниски динар',
        ],
        'TOP' => [
            'TOP',
            'тонганска панга',
        ],
        'TPE' => [
            'TPE',
            'Тиморшки ескудо',
        ],
        'TRL' => [
            'TRL',
            'Турска лира (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'турска лира',
        ],
        'TTD' => [
            'TTD',
            'тринидадскотобашки долар',
        ],
        'TWD' => [
            'NT$',
            'нови тајвански долар',
        ],
        'TZS' => [
            'TZS',
            'танзанијски шилинг',
        ],
        'UAH' => [
            'UAH',
            'украјинска гривна',
        ],
        'UAK' => [
            'UAK',
            'Украјински карбованети',
        ],
        'UGS' => [
            'UGS',
            'Угандски шилинг (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'угандски шилинг',
        ],
        'USD' => [
            'US$',
            'амерички долар',
        ],
        'USN' => [
            'USN',
            'САД долар (следећи дан)',
        ],
        'USS' => [
            'USS',
            'САД долар (исти дан)',
        ],
        'UYI' => [
            'UYI',
            'Уругвајски пезо ен унидадес индексадас',
        ],
        'UYP' => [
            'UYP',
            'Уругвајски пезо (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'уругвајски пезос',
        ],
        'UZS' => [
            'UZS',
            'узбекистански сом',
        ],
        'VEB' => [
            'VEB',
            'Венецуелански боливар (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'Венецуелански боливар (2008–2018)',
        ],
        'VES' => [
            'VES',
            'венецуелански боливар',
        ],
        'VND' => [
            'VND',
            'вијетнамски донг',
        ],
        'VNN' => [
            'VNN',
            'Вијетнамски донг (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'вануатски вату',
        ],
        'WST' => [
            'WST',
            'самоанска тала',
        ],
        'XAF' => [
            'FCFA',
            'централноафрички франак',
        ],
        'XCD' => [
            'EC$',
            'источнокарипски долар',
        ],
        'XCG' => [
            'Cg.',
            'карипски гулден',
        ],
        'XEU' => [
            'XEU',
            'Европска валутна јединица',
        ],
        'XFO' => [
            'XFO',
            'Француски златни франак',
        ],
        'XFU' => [
            'XFU',
            'Француски UIC-франак',
        ],
        'XOF' => [
            'F CFA',
            'западноафрички франак',
        ],
        'XPF' => [
            'CFPF',
            'CFP франак',
        ],
        'XRE' => [
            'XRE',
            'RINET фонд',
        ],
        'YDD' => [
            'YDD',
            'Јеменски динар',
        ],
        'YER' => [
            'YER',
            'јеменски ријал',
        ],
        'YUD' => [
            'YUD',
            'Југословенски тврди динар',
        ],
        'YUM' => [
            'YUM',
            'Југословенски нови динар',
        ],
        'YUN' => [
            'YUN',
            'Југословенски конвертибилни динар',
        ],
        'ZAL' => [
            'ZAL',
            'Јужно-афрички ранд (финансијски)',
        ],
        'ZAR' => [
            'ZAR',
            'јужноафрички ранд',
        ],
        'ZMK' => [
            'ZMK',
            'Замбијска квача (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'замбијска квача',
        ],
        'ZRN' => [
            'ZRN',
            'Заирски нови заир',
        ],
        'ZRZ' => [
            'ZRZ',
            'Заирски заир',
        ],
        'ZWD' => [
            'ZWD',
            'Зимбабвеански долар (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'зимбабвеанско злато',
        ],
        'ZWL' => [
            'ZWL',
            'Зимбабвеански долар (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'Зимбабвеански долар (2008)',
        ],
    ],
];
