<?php

declare(strict_types=1);

namespace SimpleSAML\XMLSecurity\XML\ds;

/**
 * Class representing a ds:SPKIData element.
 *
 * @package simplesaml/xml-security
 */
final class SPKIData extends AbstractSPKIDataType
{
}
