<?php

return [
    'Names' => [
        'Adlm' => '富拉文',
        'Afak' => '阿法卡文字',
        'Aghb' => '高加索阿爾巴尼亞文',
        'Ahom' => '阿洪姆文',
        'Arab' => '阿拉伯字母',
        'Aran' => '波斯體',
        'Armi' => '皇室亞美尼亞文',
        'Armn' => '亞美尼亞文',
        'Avst' => '阿維斯陀文',
        'Bali' => '峇里文',
        'Bamu' => '巴姆穆文',
        'Bass' => '巴薩文',
        'Batk' => '巴塔克文',
        'Beng' => '孟加拉文',
        'Bhks' => '梵文',
        'Blis' => '布列斯文',
        'Bopo' => '注音符號',
        'Brah' => '婆羅米文',
        'Brai' => '盲人用點字',
        'Bugi' => '布吉斯文',
        'Buhd' => '布希德文',
        'Cakm' => '查克馬文',
        'Cans' => '加拿大原住民通用字符',
        'Cari' => '卡里亞文',
        'Cham' => '占文',
        'Cher' => '柴羅基文',
        'Cirt' => '色斯文',
        'Copt' => '科普特文',
        'Cprt' => '塞浦路斯文',
        'Cyrl' => '西里爾文字',
        'Cyrs' => '西里爾文（古教會斯拉夫文變體）',
        'Deva' => '天城文',
        'Dsrt' => '德瑟雷特文',
        'Dupl' => '杜普洛伊速記',
        'Egyd' => '古埃及世俗體',
        'Egyh' => '古埃及僧侶體',
        'Egyp' => '古埃及聖書體',
        'Elba' => '愛爾巴桑文',
        'Ethi' => '衣索比亞文',
        'Geok' => '喬治亞語系（阿索他路里和努斯克胡里文）',
        'Geor' => '喬治亞文',
        'Glag' => '格拉哥里文',
        'Gonm' => '岡德文',
        'Goth' => '歌德文',
        'Gran' => '格蘭他文字',
        'Grek' => '希臘字母',
        'Gujr' => '古吉拉特文',
        'Guru' => '古魯穆奇文',
        'Hanb' => '標上注音符號的漢字',
        'Hang' => '諺文',
        'Hani' => '漢字',
        'Hano' => '哈努諾文',
        'Hans' => '簡體',
        'Hant' => '繁體',
        'Hatr' => '哈特拉文',
        'Hebr' => '希伯來文',
        'Hira' => '平假名',
        'Hluw' => '安那托利亞象形文字',
        'Hmng' => '楊松錄苗文',
        'Hrkt' => '片假名或平假名',
        'Hung' => '古匈牙利文',
        'Inds' => '印度河流域（哈拉帕文）',
        'Ital' => '古意大利文',
        'Jamo' => '韓文字母',
        'Java' => '爪哇文',
        'Jpan' => '日文',
        'Jurc' => '女真文字',
        'Kali' => '克耶李文',
        'Kana' => '片假名',
        'Khar' => '卡羅須提文',
        'Khmr' => '高棉文',
        'Khoj' => '克吉奇文字',
        'Knda' => '坎那達文',
        'Kore' => '韓文',
        'Kpel' => '克培列文',
        'Kthi' => '凱提文',
        'Lana' => '藍拿文',
        'Laoo' => '寮文',
        'Latf' => '拉丁文（尖角體活字變體）',
        'Latg' => '拉丁文（蓋爾語變體）',
        'Latn' => '拉丁字母',
        'Lepc' => '雷布查文',
        'Limb' => '林佈文',
        'Lina' => '線性文字（A）',
        'Linb' => '線性文字（B）',
        'Lisu' => '栗僳文',
        'Loma' => '洛馬文',
        'Lyci' => '呂西亞語',
        'Lydi' => '里底亞語',
        'Mahj' => '印地文',
        'Mand' => '曼底安文',
        'Mani' => '摩尼教文',
        'Marc' => '瑪欽文',
        'Maya' => '瑪雅象形文字',
        'Mend' => '門德文',
        'Merc' => '麥羅埃文（曲線字體）',
        'Mero' => '麥羅埃文',
        'Mlym' => '馬來亞拉姆文',
        'Modi' => '馬拉地文',
        'Mong' => '蒙古文',
        'Moon' => '蒙氏點字',
        'Mroo' => '謬文',
        'Mtei' => '曼尼普爾文',
        'Mult' => '木爾坦文',
        'Mymr' => '緬甸文',
        'Narb' => '古北阿拉伯文',
        'Nbat' => '納巴泰文字',
        'Newa' => 'Vote 尼瓦爾文',
        'Nkgb' => '納西格巴文',
        'Nkoo' => '西非書面語言 (N’Ko)',
        'Nshu' => '女書',
        'Ogam' => '歐甘文',
        'Olck' => '桑塔利文',
        'Orkh' => '鄂爾渾文',
        'Orya' => '歐迪亞文',
        'Osge' => '歐塞奇文',
        'Osma' => '歐斯曼亞文',
        'Palm' => '帕米瑞拉文字',
        'Pauc' => '鮑欽豪文',
        'Perm' => '古彼爾姆諸文',
        'Phag' => '八思巴文',
        'Phli' => '巴列維文（碑銘體）',
        'Phlp' => '巴列維文（聖詩體）',
        'Phlv' => '巴列維文（書體）',
        'Phnx' => '腓尼基文',
        'Plrd' => '柏格理拼音符',
        'Prti' => '帕提亞文（碑銘體）',
        'Qaag' => '佐基文',
        'Rjng' => '拉讓文',
        'Rohg' => '哈乃斐羅興亞文',
        'Roro' => '朗格朗格象形文',
        'Runr' => '古北歐文字',
        'Samr' => '撒馬利亞文',
        'Sara' => '沙拉堤文',
        'Sarb' => '古南阿拉伯文',
        'Saur' => '索拉什特拉文',
        'Sgnw' => '手語書寫符號',
        'Shaw' => '簫柏納字符',
        'Shrd' => '夏拉達文',
        'Sidd' => '悉曇文字',
        'Sind' => '信德文',
        'Sinh' => '錫蘭文',
        'Sogd' => '粟特文',
        'Sogo' => '古粟特文',
        'Sora' => '索朗桑朋文字',
        'Soyo' => '索永布文字',
        'Sund' => '巽他文',
        'Sylo' => '希洛弟納格里文',
        'Syrc' => '敘利亞文',
        'Syre' => '敘利亞文（福音體文字變體）',
        'Syrj' => '敘利亞文（西方文字變體）',
        'Syrn' => '敘利亞文（東方文字變體）',
        'Tagb' => '南島文',
        'Takr' => '塔卡里文字',
        'Tale' => '傣哪文',
        'Talu' => '西雙版納新傣文',
        'Taml' => '坦米爾文',
        'Tang' => '西夏文',
        'Tavt' => '傣擔文',
        'Telu' => '泰盧固文',
        'Teng' => '談格瓦文',
        'Tfng' => '提非納文',
        'Tglg' => '塔加拉文',
        'Thaa' => '塔安那文',
        'Thai' => '泰文',
        'Tibt' => '藏文',
        'Tirh' => '邁蒂利文',
        'Ugar' => '烏加列文',
        'Vaii' => '瓦依文',
        'Visp' => '視覺語音文字',
        'Wara' => '瓦郎奇蒂文字',
        'Wole' => '沃雷艾文',
        'Xpeo' => '古波斯文',
        'Xsux' => '蘇米魯亞甲文楔形文字',
        'Yiii' => '彞文',
        'Zanb' => '札那巴札爾文字',
        'Zinh' => '繼承文字（Unicode）',
        'Zmth' => '數學符號',
        'Zsye' => '表情符號',
        'Zsym' => '符號',
        'Zxxx' => '非書寫語言',
        'Zyyy' => '一般文字',
    ],
];
