<?php

return [
    'Names' => [
        'ak' => 'Lu-akaani',
        'ak_GH' => 'Lu-akaani (Gana)',
        'am' => 'Lu-amhariki',
        'am_ET' => 'Lu-amhariki (Esyopya)',
        'ar' => 'Luwarabu',
        'ar_AE' => 'Luwarabu (Emireeti)',
        'ar_BH' => 'Luwarabu (Baareeni)',
        'ar_DJ' => 'Luwarabu (Jjibuti)',
        'ar_DZ' => 'Luwarabu (Aligerya)',
        'ar_EG' => 'Luwarabu (Misiri)',
        'ar_ER' => 'Luwarabu (Eritureya)',
        'ar_IL' => 'Luwarabu (Yisirayeri)',
        'ar_IQ' => 'Luwarabu (Yiraaka)',
        'ar_JO' => 'Luwarabu (Yorodani)',
        'ar_KM' => 'Luwarabu (Bizinga by’eKomoro)',
        'ar_KW' => 'Luwarabu (Kuweti)',
        'ar_LB' => 'Luwarabu (Lebanoni)',
        'ar_LY' => 'Luwarabu (Libya)',
        'ar_MA' => 'Luwarabu (Moroko)',
        'ar_MR' => 'Luwarabu (Mawulitenya)',
        'ar_OM' => 'Luwarabu (Omaani)',
        'ar_PS' => 'Luwarabu (Palesitayini)',
        'ar_QA' => 'Luwarabu (Kataa)',
        'ar_SA' => 'Luwarabu (Sawudarebya - Buwarabu)',
        'ar_SD' => 'Luwarabu (Sudaani)',
        'ar_SO' => 'Luwarabu (Somaliya)',
        'ar_SY' => 'Luwarabu (Siriya)',
        'ar_TD' => 'Luwarabu (Caadi)',
        'ar_TN' => 'Luwarabu (Tunisya)',
        'ar_YE' => 'Luwarabu (Yemeni)',
        'be' => 'Lubelarusi',
        'be_BY' => 'Lubelarusi (Belarusi)',
        'bg' => 'Lubulugariya',
        'bg_BG' => 'Lubulugariya (Bulugariya)',
        'bn' => 'Lubengali',
        'bn_BD' => 'Lubengali (Bangaladesi)',
        'bn_IN' => 'Lubengali (Buyindi)',
        'cs' => 'Luceeke',
        'cs_CZ' => 'Luceeke (Lipubulika ya Ceeka)',
        'de' => 'Ludaaki',
        'de_AT' => 'Ludaaki (Awusituriya)',
        'de_BE' => 'Ludaaki (Bubirigi)',
        'de_CH' => 'Ludaaki (Switizirandi)',
        'de_DE' => 'Ludaaki (Budaaki)',
        'de_IT' => 'Ludaaki (Yitale)',
        'de_LI' => 'Ludaaki (Licitensitayini)',
        'de_LU' => 'Ludaaki (Lukisembaaga)',
        'el' => 'Lugereeki/Luyonaani',
        'el_CY' => 'Lugereeki/Luyonaani (Sipuriya)',
        'el_GR' => 'Lugereeki/Luyonaani (Bugereeki/Buyonaani)',
        'en' => 'Lungereza',
        'en_AE' => 'Lungereza (Emireeti)',
        'en_AG' => 'Lungereza (Antigwa ne Barabuda)',
        'en_AI' => 'Lungereza (Angwila)',
        'en_AS' => 'Lungereza (Samowa omumerika)',
        'en_AT' => 'Lungereza (Awusituriya)',
        'en_AU' => 'Lungereza (Awusitureliya)',
        'en_BB' => 'Lungereza (Barabadosi)',
        'en_BE' => 'Lungereza (Bubirigi)',
        'en_BI' => 'Lungereza (Burundi)',
        'en_BM' => 'Lungereza (Beremuda)',
        'en_BS' => 'Lungereza (Bahamasi)',
        'en_BW' => 'Lungereza (Botiswana)',
        'en_BZ' => 'Lungereza (Belize)',
        'en_CA' => 'Lungereza (Kanada)',
        'en_CH' => 'Lungereza (Switizirandi)',
        'en_CK' => 'Lungereza (Bizinga bya Kkuki)',
        'en_CM' => 'Lungereza (Kameruuni)',
        'en_CY' => 'Lungereza (Sipuriya)',
        'en_CZ' => 'Lungereza (Lipubulika ya Ceeka)',
        'en_DE' => 'Lungereza (Budaaki)',
        'en_DK' => 'Lungereza (Denimaaka)',
        'en_DM' => 'Lungereza (Dominika)',
        'en_EE' => 'Lungereza (Esitoniya)',
        'en_ER' => 'Lungereza (Eritureya)',
        'en_ES' => 'Lungereza (Sipeyini)',
        'en_FI' => 'Lungereza (Finilandi)',
        'en_FJ' => 'Lungereza (Fiji)',
        'en_FK' => 'Lungereza (Bizinga by’eFalikalandi)',
        'en_FM' => 'Lungereza (Mikuronezya)',
        'en_FR' => 'Lungereza (Bufalansa)',
        'en_GB' => 'Lungereza (Bungereza)',
        'en_GD' => 'Lungereza (Gurenada)',
        'en_GE' => 'Lungereza (Gyogya)',
        'en_GH' => 'Lungereza (Gana)',
        'en_GI' => 'Lungereza (Giburalita)',
        'en_GM' => 'Lungereza (Gambya)',
        'en_GU' => 'Lungereza (Gwamu)',
        'en_GY' => 'Lungereza (Gayana)',
        'en_HU' => 'Lungereza (Hangare)',
        'en_ID' => 'Lungereza (Yindonezya)',
        'en_IE' => 'Lungereza (Ayalandi)',
        'en_IL' => 'Lungereza (Yisirayeri)',
        'en_IN' => 'Lungereza (Buyindi)',
        'en_IT' => 'Lungereza (Yitale)',
        'en_JM' => 'Lungereza (Jamayika)',
        'en_JP' => 'Lungereza (Japani)',
        'en_KE' => 'Lungereza (Kenya)',
        'en_KI' => 'Lungereza (Kiribati)',
        'en_KN' => 'Lungereza (Senti Kitisi ne Nevisi)',
        'en_KY' => 'Lungereza (Bizinga ebya Kayimaani)',
        'en_LC' => 'Lungereza (Senti Luciya)',
        'en_LR' => 'Lungereza (Liberya)',
        'en_LS' => 'Lungereza (Lesoso)',
        'en_LT' => 'Lungereza (Lisuwenya)',
        'en_LV' => 'Lungereza (Lativya)',
        'en_MG' => 'Lungereza (Madagasika)',
        'en_MH' => 'Lungereza (Bizinga bya Mariso)',
        'en_MP' => 'Lungereza (Bizinga bya Mariyana eby’omumambuka)',
        'en_MS' => 'Lungereza (Monteseraati)',
        'en_MT' => 'Lungereza (Malita)',
        'en_MU' => 'Lungereza (Mawulisyasi)',
        'en_MV' => 'Lungereza (Bizinga by’eMalidive)',
        'en_MW' => 'Lungereza (Malawi)',
        'en_MY' => 'Lungereza (Malezya)',
        'en_NA' => 'Lungereza (Namibiya)',
        'en_NF' => 'Lungereza (Kizinga ky’eNorofoko)',
        'en_NG' => 'Lungereza (Nayijerya)',
        'en_NL' => 'Lungereza (Holandi)',
        'en_NO' => 'Lungereza (Nowe)',
        'en_NR' => 'Lungereza (Nawuru)',
        'en_NU' => 'Lungereza (Niyuwe)',
        'en_NZ' => 'Lungereza (Niyuziirandi)',
        'en_PG' => 'Lungereza (Papwa Nyugini)',
        'en_PH' => 'Lungereza (Bizinga bya Firipino)',
        'en_PK' => 'Lungereza (Pakisitaani)',
        'en_PL' => 'Lungereza (Polandi)',
        'en_PN' => 'Lungereza (Pitikeeni)',
        'en_PR' => 'Lungereza (Potoriko)',
        'en_PT' => 'Lungereza (Potugaali)',
        'en_PW' => 'Lungereza (Palawu)',
        'en_RO' => 'Lungereza (Lomaniya)',
        'en_RW' => 'Lungereza (Rwanda)',
        'en_SB' => 'Lungereza (Bizanga by’eSolomooni)',
        'en_SC' => 'Lungereza (Sesere)',
        'en_SD' => 'Lungereza (Sudaani)',
        'en_SE' => 'Lungereza (Swideni)',
        'en_SG' => 'Lungereza (Singapowa)',
        'en_SH' => 'Lungereza (Senti Herena)',
        'en_SI' => 'Lungereza (Sirovenya)',
        'en_SK' => 'Lungereza (Sirovakya)',
        'en_SL' => 'Lungereza (Siyeralewone)',
        'en_SZ' => 'Lungereza (Swazirandi)',
        'en_TC' => 'Lungereza (Bizinga by’eTaaka ne Kayikosi)',
        'en_TK' => 'Lungereza (Tokelawu)',
        'en_TO' => 'Lungereza (Tonga)',
        'en_TT' => 'Lungereza (Turindaadi ne Tobago)',
        'en_TV' => 'Lungereza (Tuvalu)',
        'en_TZ' => 'Lungereza (Tanzaniya)',
        'en_UA' => 'Lungereza (Yukurayine)',
        'en_UG' => 'Lungereza (Yuganda)',
        'en_US' => 'Lungereza (Amerika)',
        'en_VC' => 'Lungereza (Senti Vinsenti ne Gurendadiini)',
        'en_VG' => 'Lungereza (Bizinga ebya Virigini ebitwalibwa Bungereza)',
        'en_VI' => 'Lungereza (Bizinga bya Virigini eby’Amerika)',
        'en_VU' => 'Lungereza (Vanawuwatu)',
        'en_WS' => 'Lungereza (Samowa)',
        'en_ZA' => 'Lungereza (Sawusafirika)',
        'en_ZM' => 'Lungereza (Zambya)',
        'en_ZW' => 'Lungereza (Zimbabwe)',
        'es' => 'Lusipanya',
        'es_AR' => 'Lusipanya (Arigentina)',
        'es_BO' => 'Lusipanya (Boliviya)',
        'es_BR' => 'Lusipanya (Buraziiri)',
        'es_BZ' => 'Lusipanya (Belize)',
        'es_CL' => 'Lusipanya (Cile)',
        'es_CO' => 'Lusipanya (Kolombya)',
        'es_CR' => 'Lusipanya (Kosita Rika)',
        'es_CU' => 'Lusipanya (Cuba)',
        'es_DO' => 'Lusipanya (Lipubulika ya Dominika)',
        'es_EC' => 'Lusipanya (Ekwado)',
        'es_ES' => 'Lusipanya (Sipeyini)',
        'es_GQ' => 'Lusipanya (Gayana ey’oku ekweta)',
        'es_GT' => 'Lusipanya (Gwatemala)',
        'es_HN' => 'Lusipanya (Hundurasi)',
        'es_MX' => 'Lusipanya (Mekisiko)',
        'es_NI' => 'Lusipanya (Nikaraguwa)',
        'es_PA' => 'Lusipanya (Panama)',
        'es_PE' => 'Lusipanya (Peru)',
        'es_PH' => 'Lusipanya (Bizinga bya Firipino)',
        'es_PR' => 'Lusipanya (Potoriko)',
        'es_PY' => 'Lusipanya (Paragwayi)',
        'es_SV' => 'Lusipanya (El salivado)',
        'es_US' => 'Lusipanya (Amerika)',
        'es_UY' => 'Lusipanya (Wurugwayi)',
        'es_VE' => 'Lusipanya (Venzwera)',
        'fa' => 'Luperusi',
        'fa_AF' => 'Luperusi (Afaganisitani)',
        'fa_IR' => 'Luperusi (Yiraani)',
        'fr' => 'Lufalansa',
        'fr_BE' => 'Lufalansa (Bubirigi)',
        'fr_BF' => 'Lufalansa (Burukina Faso)',
        'fr_BI' => 'Lufalansa (Burundi)',
        'fr_BJ' => 'Lufalansa (Benini)',
        'fr_CA' => 'Lufalansa (Kanada)',
        'fr_CD' => 'Lufalansa (Kongo - Zayire)',
        'fr_CF' => 'Lufalansa (Lipubulika eya Senturafiriki)',
        'fr_CG' => 'Lufalansa (Kongo)',
        'fr_CH' => 'Lufalansa (Switizirandi)',
        'fr_CI' => 'Lufalansa (Kote Divwa)',
        'fr_CM' => 'Lufalansa (Kameruuni)',
        'fr_DJ' => 'Lufalansa (Jjibuti)',
        'fr_DZ' => 'Lufalansa (Aligerya)',
        'fr_FR' => 'Lufalansa (Bufalansa)',
        'fr_GA' => 'Lufalansa (Gaboni)',
        'fr_GF' => 'Lufalansa (Guyana enfalansa)',
        'fr_GN' => 'Lufalansa (Gini)',
        'fr_GP' => 'Lufalansa (Gwadalupe)',
        'fr_GQ' => 'Lufalansa (Gayana ey’oku ekweta)',
        'fr_HT' => 'Lufalansa (Hayiti)',
        'fr_KM' => 'Lufalansa (Bizinga by’eKomoro)',
        'fr_LU' => 'Lufalansa (Lukisembaaga)',
        'fr_MA' => 'Lufalansa (Moroko)',
        'fr_MC' => 'Lufalansa (Monako)',
        'fr_MG' => 'Lufalansa (Madagasika)',
        'fr_ML' => 'Lufalansa (Mali)',
        'fr_MQ' => 'Lufalansa (Maritiniiki)',
        'fr_MR' => 'Lufalansa (Mawulitenya)',
        'fr_MU' => 'Lufalansa (Mawulisyasi)',
        'fr_NC' => 'Lufalansa (Kaledonya mupya)',
        'fr_NE' => 'Lufalansa (Nije)',
        'fr_PF' => 'Lufalansa (Polinesiya enfalansa)',
        'fr_PM' => 'Lufalansa (Senti Piyere ne Mikeloni)',
        'fr_RE' => 'Lufalansa (Leyunyoni)',
        'fr_RW' => 'Lufalansa (Rwanda)',
        'fr_SC' => 'Lufalansa (Sesere)',
        'fr_SN' => 'Lufalansa (Senegaalo)',
        'fr_SY' => 'Lufalansa (Siriya)',
        'fr_TD' => 'Lufalansa (Caadi)',
        'fr_TG' => 'Lufalansa (Togo)',
        'fr_TN' => 'Lufalansa (Tunisya)',
        'fr_VU' => 'Lufalansa (Vanawuwatu)',
        'fr_WF' => 'Lufalansa (Walisi ne Futuna)',
        'fr_YT' => 'Lufalansa (Mayotte)',
        'ha' => 'Luhawuza',
        'ha_GH' => 'Luhawuza (Gana)',
        'ha_NE' => 'Luhawuza (Nije)',
        'ha_NG' => 'Luhawuza (Nayijerya)',
        'hi' => 'Luhindu',
        'hi_IN' => 'Luhindu (Buyindi)',
        'hu' => 'Luhangare',
        'hu_HU' => 'Luhangare (Hangare)',
        'id' => 'Luyindonezya',
        'id_ID' => 'Luyindonezya (Yindonezya)',
        'ig' => 'Luyibo',
        'ig_NG' => 'Luyibo (Nayijerya)',
        'it' => 'Luyitale',
        'it_CH' => 'Luyitale (Switizirandi)',
        'it_IT' => 'Luyitale (Yitale)',
        'it_SM' => 'Luyitale (Sanimarino)',
        'it_VA' => 'Luyitale (Vatikaani)',
        'ja' => 'Lujapani',
        'ja_JP' => 'Lujapani (Japani)',
        'jv' => 'Lunnajjava',
        'jv_ID' => 'Lunnajjava (Yindonezya)',
        'km' => 'Lukme',
        'km_KH' => 'Lukme (Kambodya)',
        'ko' => 'Lukoreya',
        'ko_CN' => 'Lukoreya (Cayina)',
        'ko_KP' => 'Lukoreya (Koreya ey’omumambuka)',
        'ko_KR' => 'Lukoreya (Koreya ey’omumaserengeta)',
        'lg' => 'Luganda',
        'lg_UG' => 'Luganda (Yuganda)',
        'ms' => 'Lumalayi',
        'ms_BN' => 'Lumalayi (Burunayi)',
        'ms_ID' => 'Lumalayi (Yindonezya)',
        'ms_MY' => 'Lumalayi (Malezya)',
        'ms_SG' => 'Lumalayi (Singapowa)',
        'my' => 'Lubbama',
        'my_MM' => 'Lubbama (Myanima)',
        'ne' => 'Lunepali',
        'ne_IN' => 'Lunepali (Buyindi)',
        'ne_NP' => 'Lunepali (Nepalo)',
        'nl' => 'Luholandi',
        'nl_AW' => 'Luholandi (Aruba)',
        'nl_BE' => 'Luholandi (Bubirigi)',
        'nl_NL' => 'Luholandi (Holandi)',
        'nl_SR' => 'Luholandi (Surinaamu)',
        'pa' => 'Lupunjabi',
        'pa_IN' => 'Lupunjabi (Buyindi)',
        'pa_PK' => 'Lupunjabi (Pakisitaani)',
        'pl' => 'Lupolandi',
        'pl_PL' => 'Lupolandi (Polandi)',
        'pt' => 'Lupotugiizi',
        'pt_AO' => 'Lupotugiizi (Angola)',
        'pt_BR' => 'Lupotugiizi (Buraziiri)',
        'pt_CH' => 'Lupotugiizi (Switizirandi)',
        'pt_CV' => 'Lupotugiizi (Bizinga by’e Kepu Veredi)',
        'pt_GQ' => 'Lupotugiizi (Gayana ey’oku ekweta)',
        'pt_GW' => 'Lupotugiizi (Gini-Bisawu)',
        'pt_LU' => 'Lupotugiizi (Lukisembaaga)',
        'pt_MZ' => 'Lupotugiizi (Mozambiiki)',
        'pt_PT' => 'Lupotugiizi (Potugaali)',
        'pt_ST' => 'Lupotugiizi (Sanitome ne Purincipe)',
        'pt_TL' => 'Lupotugiizi (Timowa)',
        'ro' => 'Lulomaniya',
        'ro_MD' => 'Lulomaniya (Molodova)',
        'ro_RO' => 'Lulomaniya (Lomaniya)',
        'ru' => 'Lulasa',
        'ru_BY' => 'Lulasa (Belarusi)',
        'ru_KG' => 'Lulasa (Kirigizisitaani)',
        'ru_KZ' => 'Lulasa (Kazakisitaani)',
        'ru_MD' => 'Lulasa (Molodova)',
        'ru_RU' => 'Lulasa (Lasa)',
        'ru_UA' => 'Lulasa (Yukurayine)',
        'rw' => 'Lunarwanda',
        'rw_RW' => 'Lunarwanda (Rwanda)',
        'so' => 'Lusomaliya',
        'so_DJ' => 'Lusomaliya (Jjibuti)',
        'so_ET' => 'Lusomaliya (Esyopya)',
        'so_KE' => 'Lusomaliya (Kenya)',
        'so_SO' => 'Lusomaliya (Somaliya)',
        'sv' => 'Luswideni',
        'sv_FI' => 'Luswideni (Finilandi)',
        'sv_SE' => 'Luswideni (Swideni)',
        'ta' => 'Lutamiiru',
        'ta_IN' => 'Lutamiiru (Buyindi)',
        'ta_LK' => 'Lutamiiru (Sirilanka)',
        'ta_MY' => 'Lutamiiru (Malezya)',
        'ta_SG' => 'Lutamiiru (Singapowa)',
        'th' => 'Luttaayi',
        'th_TH' => 'Luttaayi (Tayirandi)',
        'tr' => 'Lutake',
        'tr_CY' => 'Lutake (Sipuriya)',
        'tr_TR' => 'Lutake (Ttake)',
        'uk' => 'Luyukurayine',
        'uk_UA' => 'Luyukurayine (Yukurayine)',
        'ur' => 'Lu-urudu',
        'ur_IN' => 'Lu-urudu (Buyindi)',
        'ur_PK' => 'Lu-urudu (Pakisitaani)',
        'vi' => 'Luvyetinaamu',
        'vi_VN' => 'Luvyetinaamu (Vyetinaamu)',
        'yo' => 'Luyoruba',
        'yo_BJ' => 'Luyoruba (Benini)',
        'yo_NG' => 'Luyoruba (Nayijerya)',
        'zh' => 'Lucayina',
        'zh_CN' => 'Lucayina (Cayina)',
        'zh_SG' => 'Lucayina (Singapowa)',
        'zh_TW' => 'Lucayina (Tayiwani)',
        'zu' => 'Luzzulu',
        'zu_ZA' => 'Luzzulu (Sawusafirika)',
    ],
];
