<?php

return [
    'Names' => [
        'ak' => 'Igikani',
        'ak_GH' => 'Igikani (Gana)',
        'am' => 'Ikimuhariki',
        'am_ET' => 'Ikimuhariki (Etiyopiya)',
        'ar' => 'Icarabu',
        'ar_AE' => 'Icarabu (Leta Zunze Ubumwe z’Abarabu)',
        'ar_BH' => 'Icarabu (Bahareyini)',
        'ar_DJ' => 'Icarabu (Jibuti)',
        'ar_DZ' => 'Icarabu (Alijeriya)',
        'ar_EG' => 'Icarabu (Misiri)',
        'ar_ER' => 'Icarabu (Elitereya)',
        'ar_IL' => 'Icarabu (Isiraheli)',
        'ar_IQ' => 'Icarabu (Iraki)',
        'ar_JO' => 'Icarabu (Yorudaniya)',
        'ar_KM' => 'Icarabu (Izinga rya Komore)',
        'ar_KW' => 'Icarabu (Koweti)',
        'ar_LB' => 'Icarabu (Libani)',
        'ar_LY' => 'Icarabu (Libiya)',
        'ar_MA' => 'Icarabu (Maroke)',
        'ar_MR' => 'Icarabu (Moritaniya)',
        'ar_OM' => 'Icarabu (Omani)',
        'ar_PS' => 'Icarabu (Palesitina Wesitibanka na Gaza)',
        'ar_QA' => 'Icarabu (Katari)',
        'ar_SA' => 'Icarabu (Arabiya Sawudite)',
        'ar_SD' => 'Icarabu (Sudani)',
        'ar_SO' => 'Icarabu (Somaliya)',
        'ar_SY' => 'Icarabu (Siriya)',
        'ar_TD' => 'Icarabu (Cadi)',
        'ar_TN' => 'Icarabu (Tuniziya)',
        'ar_YE' => 'Icarabu (Yemeni)',
        'be' => 'Ikibelarusiya',
        'be_BY' => 'Ikibelarusiya (Belausi)',
        'bg' => 'Ikinyabuligariya',
        'bg_BG' => 'Ikinyabuligariya (Buligariya)',
        'bn' => 'Ikibengali',
        'bn_BD' => 'Ikibengali (Bangaladeshi)',
        'bn_IN' => 'Ikibengali (Ubuhindi)',
        'cs' => 'Igiceke',
        'cs_CZ' => 'Igiceke (Repubulika ya Ceke)',
        'de' => 'Ikidage',
        'de_AT' => 'Ikidage (Otirishe)',
        'de_BE' => 'Ikidage (Ububiligi)',
        'de_CH' => 'Ikidage (Ubusuwisi)',
        'de_DE' => 'Ikidage (Ubudage)',
        'de_IT' => 'Ikidage (Ubutaliyani)',
        'de_LI' => 'Ikidage (Lishyitenshitayini)',
        'de_LU' => 'Ikidage (Lukusamburu)',
        'el' => 'Ikigereki',
        'el_CY' => 'Ikigereki (Izinga rya Shipure)',
        'el_GR' => 'Ikigereki (Ubugereki)',
        'en' => 'Icongereza',
        'en_AE' => 'Icongereza (Leta Zunze Ubumwe z’Abarabu)',
        'en_AG' => 'Icongereza (Antigwa na Baribuda)',
        'en_AI' => 'Icongereza (Angwila)',
        'en_AS' => 'Icongereza (Samowa nyamerika)',
        'en_AT' => 'Icongereza (Otirishe)',
        'en_AU' => 'Icongereza (Ositaraliya)',
        'en_BB' => 'Icongereza (Barubadosi)',
        'en_BE' => 'Icongereza (Ububiligi)',
        'en_BI' => 'Icongereza (Uburundi)',
        'en_BM' => 'Icongereza (Berimuda)',
        'en_BS' => 'Icongereza (Bahamasi)',
        'en_BW' => 'Icongereza (Botswana)',
        'en_BZ' => 'Icongereza (Belize)',
        'en_CA' => 'Icongereza (Kanada)',
        'en_CH' => 'Icongereza (Ubusuwisi)',
        'en_CK' => 'Icongereza (Izinga rya Kuku)',
        'en_CM' => 'Icongereza (Kameruni)',
        'en_CY' => 'Icongereza (Izinga rya Shipure)',
        'en_CZ' => 'Icongereza (Repubulika ya Ceke)',
        'en_DE' => 'Icongereza (Ubudage)',
        'en_DK' => 'Icongereza (Danimariki)',
        'en_DM' => 'Icongereza (Dominika)',
        'en_EE' => 'Icongereza (Esitoniya)',
        'en_ER' => 'Icongereza (Elitereya)',
        'en_ES' => 'Icongereza (Hisipaniya)',
        'en_FI' => 'Icongereza (Finilandi)',
        'en_FJ' => 'Icongereza (Fiji)',
        'en_FK' => 'Icongereza (Izinga rya Filikilandi)',
        'en_FM' => 'Icongereza (Mikoroniziya)',
        'en_FR' => 'Icongereza (Ubufaransa)',
        'en_GB' => 'Icongereza (Ubwongereza)',
        'en_GD' => 'Icongereza (Gerenada)',
        'en_GE' => 'Icongereza (Jeworujiya)',
        'en_GH' => 'Icongereza (Gana)',
        'en_GI' => 'Icongereza (Juburalitari)',
        'en_GM' => 'Icongereza (Gambiya)',
        'en_GU' => 'Icongereza (Gwamu)',
        'en_GY' => 'Icongereza (Guyane)',
        'en_HU' => 'Icongereza (Hungariya)',
        'en_ID' => 'Icongereza (Indoneziya)',
        'en_IE' => 'Icongereza (Irilandi)',
        'en_IL' => 'Icongereza (Isiraheli)',
        'en_IN' => 'Icongereza (Ubuhindi)',
        'en_IT' => 'Icongereza (Ubutaliyani)',
        'en_JM' => 'Icongereza (Jamayika)',
        'en_JP' => 'Icongereza (Ubuyapani)',
        'en_KE' => 'Icongereza (Kenya)',
        'en_KI' => 'Icongereza (Kiribati)',
        'en_KN' => 'Icongereza (Sekitsi na Nevisi)',
        'en_KY' => 'Icongereza (Ibirwa bya Keyimani)',
        'en_LC' => 'Icongereza (Selusiya)',
        'en_LR' => 'Icongereza (Liberiya)',
        'en_LS' => 'Icongereza (Lesoto)',
        'en_LT' => 'Icongereza (Lituwaniya)',
        'en_LV' => 'Icongereza (Lativa)',
        'en_MG' => 'Icongereza (Madagasikari)',
        'en_MH' => 'Icongereza (Izinga rya Marishari)',
        'en_MP' => 'Icongereza (Amazinga ya Mariyana ryo mu majaruguru)',
        'en_MS' => 'Icongereza (Monteserati)',
        'en_MT' => 'Icongereza (Malita)',
        'en_MU' => 'Icongereza (Izinga rya Morise)',
        'en_MV' => 'Icongereza (Moludave)',
        'en_MW' => 'Icongereza (Malawi)',
        'en_MY' => 'Icongereza (Maleziya)',
        'en_NA' => 'Icongereza (Namibiya)',
        'en_NF' => 'Icongereza (izinga rya Norufoluke)',
        'en_NG' => 'Icongereza (Nijeriya)',
        'en_NL' => 'Icongereza (Ubuholandi)',
        'en_NO' => 'Icongereza (Noruveji)',
        'en_NR' => 'Icongereza (Nawuru)',
        'en_NU' => 'Icongereza (Niyuwe)',
        'en_NZ' => 'Icongereza (Nuvelizelandi)',
        'en_PG' => 'Icongereza (Papuwa Niyugineya)',
        'en_PH' => 'Icongereza (Amazinga ya Filipine)',
        'en_PK' => 'Icongereza (Pakisitani)',
        'en_PL' => 'Icongereza (Polonye)',
        'en_PN' => 'Icongereza (Pitikeyirini)',
        'en_PR' => 'Icongereza (Puwetoriko)',
        'en_PT' => 'Icongereza (Porutugali)',
        'en_PW' => 'Icongereza (Palawu)',
        'en_RO' => 'Icongereza (Rumaniya)',
        'en_RW' => 'Icongereza (u Rwanda)',
        'en_SB' => 'Icongereza (Amazinga ya Salumoni)',
        'en_SC' => 'Icongereza (Amazinga ya Seyisheli)',
        'en_SD' => 'Icongereza (Sudani)',
        'en_SE' => 'Icongereza (Suwedi)',
        'en_SG' => 'Icongereza (Singapuru)',
        'en_SH' => 'Icongereza (Sehelene)',
        'en_SI' => 'Icongereza (Siloveniya)',
        'en_SK' => 'Icongereza (Silovakiya)',
        'en_SL' => 'Icongereza (Siyeralewone)',
        'en_SZ' => 'Icongereza (Suwazilandi)',
        'en_TC' => 'Icongereza (Amazinga ya Turkisi na Cayikosi)',
        'en_TK' => 'Icongereza (Tokelawu)',
        'en_TO' => 'Icongereza (Tonga)',
        'en_TT' => 'Icongereza (Tirinidadi na Tobago)',
        'en_TV' => 'Icongereza (Tuvalu)',
        'en_TZ' => 'Icongereza (Tanzaniya)',
        'en_UA' => 'Icongereza (Ikerene)',
        'en_UG' => 'Icongereza (Ubugande)',
        'en_US' => 'Icongereza (Leta Zunze Ubumwe za Amerika)',
        'en_VC' => 'Icongereza (Sevensa na Gerenadine)',
        'en_VG' => 'Icongereza (Ibirwa by’isugi by’Abongereza)',
        'en_VI' => 'Icongereza (Amazinga y’Isugi y’Abanyamerika)',
        'en_VU' => 'Icongereza (Vanuwatu)',
        'en_WS' => 'Icongereza (Samowa)',
        'en_ZA' => 'Icongereza (Afurika y’Epfo)',
        'en_ZM' => 'Icongereza (Zambiya)',
        'en_ZW' => 'Icongereza (Zimbabwe)',
        'es' => 'Icesipanyolo',
        'es_AR' => 'Icesipanyolo (Arijantine)',
        'es_BO' => 'Icesipanyolo (Boliviya)',
        'es_BR' => 'Icesipanyolo (Burezili)',
        'es_BZ' => 'Icesipanyolo (Belize)',
        'es_CL' => 'Icesipanyolo (Shili)',
        'es_CO' => 'Icesipanyolo (Kolombiya)',
        'es_CR' => 'Icesipanyolo (Kositarika)',
        'es_CU' => 'Icesipanyolo (Kiba)',
        'es_DO' => 'Icesipanyolo (Repubulika ya Dominika)',
        'es_EC' => 'Icesipanyolo (Ekwateri)',
        'es_ES' => 'Icesipanyolo (Hisipaniya)',
        'es_GQ' => 'Icesipanyolo (Gineya Ekwatoriyali)',
        'es_GT' => 'Icesipanyolo (Gwatemala)',
        'es_HN' => 'Icesipanyolo (Hondurasi)',
        'es_MX' => 'Icesipanyolo (Migizike)',
        'es_NI' => 'Icesipanyolo (Nikaragwa)',
        'es_PA' => 'Icesipanyolo (Panama)',
        'es_PE' => 'Icesipanyolo (Peru)',
        'es_PH' => 'Icesipanyolo (Amazinga ya Filipine)',
        'es_PR' => 'Icesipanyolo (Puwetoriko)',
        'es_PY' => 'Icesipanyolo (Paragwe)',
        'es_SV' => 'Icesipanyolo (Eli Saluvatori)',
        'es_US' => 'Icesipanyolo (Leta Zunze Ubumwe za Amerika)',
        'es_UY' => 'Icesipanyolo (Irigwe)',
        'es_VE' => 'Icesipanyolo (Venezuwela)',
        'fa' => 'Igiperisi',
        'fa_AF' => 'Igiperisi (Afuganisitani)',
        'fa_IR' => 'Igiperisi (Irani)',
        'fr' => 'Igifaransa',
        'fr_BE' => 'Igifaransa (Ububiligi)',
        'fr_BF' => 'Igifaransa (Burukina Faso)',
        'fr_BI' => 'Igifaransa (Uburundi)',
        'fr_BJ' => 'Igifaransa (Bene)',
        'fr_CA' => 'Igifaransa (Kanada)',
        'fr_CD' => 'Igifaransa (Repubulika Iharanira Demokarasi ya Kongo)',
        'fr_CF' => 'Igifaransa (Repubulika ya Santarafurika)',
        'fr_CG' => 'Igifaransa (Kongo)',
        'fr_CH' => 'Igifaransa (Ubusuwisi)',
        'fr_CI' => 'Igifaransa (Kotedivuware)',
        'fr_CM' => 'Igifaransa (Kameruni)',
        'fr_DJ' => 'Igifaransa (Jibuti)',
        'fr_DZ' => 'Igifaransa (Alijeriya)',
        'fr_FR' => 'Igifaransa (Ubufaransa)',
        'fr_GA' => 'Igifaransa (Gabo)',
        'fr_GF' => 'Igifaransa (Gwayana y’Abafaransa)',
        'fr_GN' => 'Igifaransa (Guneya)',
        'fr_GP' => 'Igifaransa (Gwadelupe)',
        'fr_GQ' => 'Igifaransa (Gineya Ekwatoriyali)',
        'fr_HT' => 'Igifaransa (Hayiti)',
        'fr_KM' => 'Igifaransa (Izinga rya Komore)',
        'fr_LU' => 'Igifaransa (Lukusamburu)',
        'fr_MA' => 'Igifaransa (Maroke)',
        'fr_MC' => 'Igifaransa (Monako)',
        'fr_MG' => 'Igifaransa (Madagasikari)',
        'fr_ML' => 'Igifaransa (Mali)',
        'fr_MQ' => 'Igifaransa (Maritiniki)',
        'fr_MR' => 'Igifaransa (Moritaniya)',
        'fr_MU' => 'Igifaransa (Izinga rya Morise)',
        'fr_NC' => 'Igifaransa (Niyukaledoniya)',
        'fr_NE' => 'Igifaransa (Nijeri)',
        'fr_PF' => 'Igifaransa (Polineziya y’Abafaransa)',
        'fr_PM' => 'Igifaransa (Sempiyeri na Mikeloni)',
        'fr_RE' => 'Igifaransa (Amazinga ya Reyiniyo)',
        'fr_RW' => 'Igifaransa (u Rwanda)',
        'fr_SC' => 'Igifaransa (Amazinga ya Seyisheli)',
        'fr_SN' => 'Igifaransa (Senegali)',
        'fr_SY' => 'Igifaransa (Siriya)',
        'fr_TD' => 'Igifaransa (Cadi)',
        'fr_TG' => 'Igifaransa (Togo)',
        'fr_TN' => 'Igifaransa (Tuniziya)',
        'fr_VU' => 'Igifaransa (Vanuwatu)',
        'fr_WF' => 'Igifaransa (Walisi na Futuna)',
        'fr_YT' => 'Igifaransa (Mayote)',
        'ha' => 'Igihawusa',
        'ha_GH' => 'Igihawusa (Gana)',
        'ha_NE' => 'Igihawusa (Nijeri)',
        'ha_NG' => 'Igihawusa (Nijeriya)',
        'hi' => 'Igihindi',
        'hi_IN' => 'Igihindi (Ubuhindi)',
        'hu' => 'Ikinyahongiriya',
        'hu_HU' => 'Ikinyahongiriya (Hungariya)',
        'id' => 'Ikinyendoziya',
        'id_ID' => 'Ikinyendoziya (Indoneziya)',
        'ig' => 'Ikigubo',
        'ig_NG' => 'Ikigubo (Nijeriya)',
        'it' => 'Igitaliyani',
        'it_CH' => 'Igitaliyani (Ubusuwisi)',
        'it_IT' => 'Igitaliyani (Ubutaliyani)',
        'it_SM' => 'Igitaliyani (Sanimarino)',
        'it_VA' => 'Igitaliyani (Umurwa wa Vatikani)',
        'ja' => 'Ikiyapani',
        'ja_JP' => 'Ikiyapani (Ubuyapani)',
        'jv' => 'Ikinyejava',
        'jv_ID' => 'Ikinyejava (Indoneziya)',
        'km' => 'Igikambodiya',
        'km_KH' => 'Igikambodiya (Kamboje)',
        'ko' => 'Ikinyakoreya',
        'ko_CN' => 'Ikinyakoreya (Ubushinwa)',
        'ko_KP' => 'Ikinyakoreya (Koreya y’amajaruguru)',
        'ko_KR' => 'Ikinyakoreya (Koreya y’amajepfo)',
        'ms' => 'Ikinyamaleziya',
        'ms_BN' => 'Ikinyamaleziya (Buruneyi)',
        'ms_ID' => 'Ikinyamaleziya (Indoneziya)',
        'ms_MY' => 'Ikinyamaleziya (Maleziya)',
        'ms_SG' => 'Ikinyamaleziya (Singapuru)',
        'my' => 'Ikinyabirimaniya',
        'my_MM' => 'Ikinyabirimaniya (Birimaniya)',
        'ne' => 'Ikinepali',
        'ne_IN' => 'Ikinepali (Ubuhindi)',
        'ne_NP' => 'Ikinepali (Nepali)',
        'nl' => 'Igiholandi',
        'nl_AW' => 'Igiholandi (Aruba)',
        'nl_BE' => 'Igiholandi (Ububiligi)',
        'nl_NL' => 'Igiholandi (Ubuholandi)',
        'nl_SR' => 'Igiholandi (Suriname)',
        'pa' => 'Igipunjabi',
        'pa_IN' => 'Igipunjabi (Ubuhindi)',
        'pa_PK' => 'Igipunjabi (Pakisitani)',
        'pl' => 'Ikinyapolonye',
        'pl_PL' => 'Ikinyapolonye (Polonye)',
        'pt' => 'Igiporutugari',
        'pt_AO' => 'Igiporutugari (Angola)',
        'pt_BR' => 'Igiporutugari (Burezili)',
        'pt_CH' => 'Igiporutugari (Ubusuwisi)',
        'pt_CV' => 'Igiporutugari (Ibirwa bya Kapuveri)',
        'pt_GQ' => 'Igiporutugari (Gineya Ekwatoriyali)',
        'pt_GW' => 'Igiporutugari (Gineya Bisawu)',
        'pt_LU' => 'Igiporutugari (Lukusamburu)',
        'pt_MZ' => 'Igiporutugari (Mozambiki)',
        'pt_PT' => 'Igiporutugari (Porutugali)',
        'pt_ST' => 'Igiporutugari (Sawotome na Perensipe)',
        'pt_TL' => 'Igiporutugari (Timoru y’iburasirazuba)',
        'rn' => 'Ikirundi',
        'rn_BI' => 'Ikirundi (Uburundi)',
        'ro' => 'Ikinyarumaniya',
        'ro_MD' => 'Ikinyarumaniya (Moludavi)',
        'ro_RO' => 'Ikinyarumaniya (Rumaniya)',
        'ru' => 'Ikirusiya',
        'ru_BY' => 'Ikirusiya (Belausi)',
        'ru_KG' => 'Ikirusiya (Kirigisitani)',
        'ru_KZ' => 'Ikirusiya (Kazakisitani)',
        'ru_MD' => 'Ikirusiya (Moludavi)',
        'ru_RU' => 'Ikirusiya (Uburusiya)',
        'ru_UA' => 'Ikirusiya (Ikerene)',
        'rw' => 'Ikinyarwanda',
        'rw_RW' => 'Ikinyarwanda (u Rwanda)',
        'so' => 'Igisomali',
        'so_DJ' => 'Igisomali (Jibuti)',
        'so_ET' => 'Igisomali (Etiyopiya)',
        'so_KE' => 'Igisomali (Kenya)',
        'so_SO' => 'Igisomali (Somaliya)',
        'sv' => 'Igisuweduwa',
        'sv_FI' => 'Igisuweduwa (Finilandi)',
        'sv_SE' => 'Igisuweduwa (Suwedi)',
        'ta' => 'Igitamili',
        'ta_IN' => 'Igitamili (Ubuhindi)',
        'ta_LK' => 'Igitamili (Sirilanka)',
        'ta_MY' => 'Igitamili (Maleziya)',
        'ta_SG' => 'Igitamili (Singapuru)',
        'th' => 'Ikinyatayilandi',
        'th_TH' => 'Ikinyatayilandi (Tayilandi)',
        'tr' => 'Igiturukiya',
        'tr_CY' => 'Igiturukiya (Izinga rya Shipure)',
        'tr_TR' => 'Igiturukiya (Turukiya)',
        'uk' => 'Ikinyayukereni',
        'uk_UA' => 'Ikinyayukereni (Ikerene)',
        'ur' => 'Inyeyurudu',
        'ur_IN' => 'Inyeyurudu (Ubuhindi)',
        'ur_PK' => 'Inyeyurudu (Pakisitani)',
        'vi' => 'Ikinyaviyetinamu',
        'vi_VN' => 'Ikinyaviyetinamu (Viyetinamu)',
        'yo' => 'Ikiyoruba',
        'yo_BJ' => 'Ikiyoruba (Bene)',
        'yo_NG' => 'Ikiyoruba (Nijeriya)',
        'zh' => 'Igishinwa',
        'zh_CN' => 'Igishinwa (Ubushinwa)',
        'zh_SG' => 'Igishinwa (Singapuru)',
        'zh_TW' => 'Igishinwa (Tayiwani)',
        'zu' => 'Ikizulu',
        'zu_ZA' => 'Ikizulu (Afurika y’Epfo)',
    ],
];
