<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Andorransk peseta',
        ],
        'AED' => [
            'AED',
            'dirham fra de Forenede Arabiske Emirater',
        ],
        'AFA' => [
            'AFA',
            'Afghansk afghani (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'afghansk afghani',
        ],
        'ALL' => [
            'ALL',
            'albansk lek',
        ],
        'AMD' => [
            'AMD',
            'armensk dram',
        ],
        'ANG' => [
            'ANG',
            'Nederlandske Antiller-gylden',
        ],
        'AOA' => [
            'AOA',
            'angolansk kwanza',
        ],
        'AOK' => [
            'AOK',
            'Angolansk kwanza (1977–1990)',
        ],
        'AON' => [
            'AON',
            'Angolansk nye kwanza (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Angolansk kwanza (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Argentinsk austral',
        ],
        'ARP' => [
            'ARP',
            'Argentinsk peso (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'argentinsk peso',
        ],
        'ATS' => [
            'ATS',
            'Østrigsk schilling',
        ],
        'AUD' => [
            'AU$',
            'australsk dollar',
        ],
        'AWG' => [
            'AWG',
            'arubansk florin',
        ],
        'AZM' => [
            'AZM',
            'Aserbajdsjansk manat (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'aserbajdsjansk manat',
        ],
        'BAD' => [
            'BAD',
            'Bosnien-Hercegovinsk dinar',
        ],
        'BAM' => [
            'BAM',
            'bosnien-hercegovinsk konvertibel mark',
        ],
        'BBD' => [
            'BBD',
            'barbadisk dollar',
        ],
        'BDT' => [
            'BDT',
            'bangladeshisk taka',
        ],
        'BEC' => [
            'BEC',
            'Belgisk franc (konvertibel)',
        ],
        'BEF' => [
            'BEF',
            'Belgisk franc',
        ],
        'BEL' => [
            'BEL',
            'Belgisk franc (financial)',
        ],
        'BGL' => [
            'BGL',
            'Bulgarsk hard lev',
        ],
        'BGN' => [
            'BGN',
            'bulgarsk lev',
        ],
        'BHD' => [
            'BHD',
            'bahrainsk dinar',
        ],
        'BIF' => [
            'BIF',
            'burundisk franc',
        ],
        'BMD' => [
            'BMD',
            'bermudansk dollar',
        ],
        'BND' => [
            'BND',
            'bruneisk dollar',
        ],
        'BOB' => [
            'BOB',
            'boliviansk boliviano',
        ],
        'BOP' => [
            'BOP',
            'Boliviansk peso',
        ],
        'BOV' => [
            'BOV',
            'Boliviansk mvdol',
        ],
        'BRB' => [
            'BRB',
            'Brasiliansk cruzeiro novo (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Brasiliansk cruzado (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'Brasiliansk cruzeiro (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'brasiliansk real',
        ],
        'BRN' => [
            'BRN',
            'Brasiliansk cruzado novo (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'Brasiliansk cruzeiro (1993–1994)',
        ],
        'BSD' => [
            'BSD',
            'bahamansk dollar',
        ],
        'BTN' => [
            'BTN',
            'bhutansk ngultrum',
        ],
        'BUK' => [
            'BUK',
            'Burmesisk kyat',
        ],
        'BWP' => [
            'BWP',
            'botswansk pula',
        ],
        'BYB' => [
            'BYB',
            'Hviderussisk rubel (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'hviderussisk rubel',
        ],
        'BYR' => [
            'BYR',
            'hviderussisk rubel (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'belizisk dollar',
        ],
        'CAD' => [
            'CA$',
            'canadisk dollar',
        ],
        'CDF' => [
            'CDF',
            'congolesisk franc',
        ],
        'CHE' => [
            'CHE',
            'WIR euro',
        ],
        'CHF' => [
            'CHF',
            'schweizerfranc',
        ],
        'CHW' => [
            'CHW',
            'WIR franc',
        ],
        'CLP' => [
            'CLP',
            'chilensk peso',
        ],
        'CNH' => [
            'CNH',
            'kinesisk yuan (offshore)',
        ],
        'CNY' => [
            'CN¥',
            'kinesisk yuan',
        ],
        'COP' => [
            'COP',
            'colombiansk peso',
        ],
        'CRC' => [
            'CRC',
            'costaricansk colón',
        ],
        'CSD' => [
            'CSD',
            'Serbisk dinar (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'Tjekkoslovakisk hard koruna',
        ],
        'CUC' => [
            'CUC',
            'cubansk konvertibel peso',
        ],
        'CUP' => [
            'CUP',
            'cubansk peso',
        ],
        'CVE' => [
            'CVE',
            'kapverdisk escudo',
        ],
        'CYP' => [
            'CYP',
            'Cypriotisk pund',
        ],
        'CZK' => [
            'CZK',
            'tjekkisk koruna',
        ],
        'DDM' => [
            'DDM',
            'Østtysk mark',
        ],
        'DEM' => [
            'DEM',
            'Tysk mark',
        ],
        'DJF' => [
            'DJF',
            'djiboutisk franc',
        ],
        'DKK' => [
            'kr.',
            'dansk krone',
        ],
        'DOP' => [
            'DOP',
            'dominikansk peso',
        ],
        'DZD' => [
            'DZD',
            'algerisk dinar',
        ],
        'ECS' => [
            'ECS',
            'Ecuadoriansk sucre',
        ],
        'EEK' => [
            'EEK',
            'Estisk kroon',
        ],
        'EGP' => [
            'EGP',
            'egyptisk pund',
        ],
        'ERN' => [
            'ERN',
            'eritreisk nakfa',
        ],
        'ESA' => [
            'ESA',
            'Spansk peseta (A–konto)',
        ],
        'ESB' => [
            'ESB',
            'Spansk peseta (konvertibel konto)',
        ],
        'ESP' => [
            'ESP',
            'Spansk peseta',
        ],
        'ETB' => [
            'ETB',
            'etiopisk birr',
        ],
        'EUR' => [
            '€',
            'euro',
        ],
        'FIM' => [
            'FIM',
            'Finsk mark',
        ],
        'FJD' => [
            'FJD',
            'fijiansk dollar',
        ],
        'FKP' => [
            'FKP',
            'pund fra Falklandsøerne',
        ],
        'FRF' => [
            'FRF',
            'Fransk franc',
        ],
        'GBP' => [
            '£',
            'britisk pund',
        ],
        'GEK' => [
            'GEK',
            'Georgisk kupon larit',
        ],
        'GEL' => [
            'GEL',
            'georgisk lari',
        ],
        'GHC' => [
            'GHC',
            'Ghanesisk cedi (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'ghanesisk cedi',
        ],
        'GIP' => [
            'GIP',
            'gibraltarisk pund',
        ],
        'GMD' => [
            'GMD',
            'gambisk dalasi',
        ],
        'GNF' => [
            'GNF',
            'guineansk franc',
        ],
        'GNS' => [
            'GNS',
            'Guineansk syli',
        ],
        'GQE' => [
            'GQE',
            'Ækvatorialguineask ekwele',
        ],
        'GRD' => [
            'GRD',
            'Græsk drakme',
        ],
        'GTQ' => [
            'GTQ',
            'guatemalansk quetzal',
        ],
        'GWE' => [
            'GWE',
            'Portugisisk guinea escudo',
        ],
        'GWP' => [
            'GWP',
            'Guineansk peso',
        ],
        'GYD' => [
            'GYD',
            'guyansk dollar',
        ],
        'HKD' => [
            'HK$',
            'hongkongsk dollar',
        ],
        'HNL' => [
            'HNL',
            'honduransk lempira',
        ],
        'HRD' => [
            'HRD',
            'Kroatisk dinar',
        ],
        'HRK' => [
            'HRK',
            'kroatisk kuna',
        ],
        'HTG' => [
            'HTG',
            'haitisk gourde',
        ],
        'HUF' => [
            'HUF',
            'ungarsk forint',
        ],
        'IDR' => [
            'IDR',
            'indonesisk rupiah',
        ],
        'IEP' => [
            'IEP',
            'Irsk pund',
        ],
        'ILP' => [
            'ILP',
            'Israelsk pund',
        ],
        'ILS' => [
            '₪',
            'ny israelsk shekel',
        ],
        'INR' => [
            '₹',
            'indisk rupee',
        ],
        'IQD' => [
            'IQD',
            'irakisk dinar',
        ],
        'IRR' => [
            'IRR',
            'iransk rial',
        ],
        'ISK' => [
            'ISK',
            'islandsk krone',
        ],
        'ITL' => [
            'ITL',
            'Italiensk lire',
        ],
        'JMD' => [
            'JMD',
            'jamaicansk dollar',
        ],
        'JOD' => [
            'JOD',
            'jordansk dinar',
        ],
        'JPY' => [
            'JP¥',
            'japansk yen',
        ],
        'KES' => [
            'KES',
            'kenyansk shilling',
        ],
        'KGS' => [
            'KGS',
            'kirgisisk som',
        ],
        'KHR' => [
            'KHR',
            'cambodjansk riel',
        ],
        'KMF' => [
            'KMF',
            'comorisk franc',
        ],
        'KPW' => [
            'KPW',
            'nordkoreansk won',
        ],
        'KRW' => [
            '₩',
            'sydkoreansk won',
        ],
        'KWD' => [
            'KWD',
            'kuwaitisk dinar',
        ],
        'KYD' => [
            'KYD',
            'caymansk dollar',
        ],
        'KZT' => [
            'KZT',
            'kasakhisk tenge',
        ],
        'LAK' => [
            'LAK',
            'laotisk kip',
        ],
        'LBP' => [
            'LBP',
            'libanesisk pund',
        ],
        'LKR' => [
            'LKR',
            'srilankansk rupee',
        ],
        'LRD' => [
            'LRD',
            'liberisk dollar',
        ],
        'LSL' => [
            'LSL',
            'lesothisk loti',
        ],
        'LTL' => [
            'LTL',
            'Litauisk litas',
        ],
        'LTT' => [
            'LTT',
            'Litauisk talonas',
        ],
        'LUC' => [
            'LUC',
            'Luxembourgsk konvertibel franc',
        ],
        'LUF' => [
            'LUF',
            'Luxembourgsk franc',
        ],
        'LUL' => [
            'LUL',
            'Luxembourgsk finansiel franc',
        ],
        'LVL' => [
            'LVL',
            'Lettisk lat',
        ],
        'LVR' => [
            'LVR',
            'Lettisk rubel',
        ],
        'LYD' => [
            'LYD',
            'libysk dinar',
        ],
        'MAD' => [
            'MAD',
            'marokkansk dirham',
        ],
        'MAF' => [
            'MAF',
            'Marokkansk franc',
        ],
        'MDL' => [
            'MDL',
            'moldovisk leu',
        ],
        'MGA' => [
            'MGA',
            'madagaskisk ariary',
        ],
        'MGF' => [
            'MGF',
            'Madagaskisk franc',
        ],
        'MKD' => [
            'MKD',
            'makedonsk denar',
        ],
        'MLF' => [
            'MLF',
            'Malisk franc',
        ],
        'MMK' => [
            'MMK',
            'myanmarsk kyat',
        ],
        'MNT' => [
            'MNT',
            'mongolsk tugrik',
        ],
        'MOP' => [
            'MOP',
            'macaosk pataca',
        ],
        'MRO' => [
            'MRO',
            'mauritansk ouguiya (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'mauritansk ouguiya',
        ],
        'MTL' => [
            'MTL',
            'Maltesisk lira',
        ],
        'MTP' => [
            'MTP',
            'Maltesisk pund',
        ],
        'MUR' => [
            'MUR',
            'mauritisk rupee',
        ],
        'MVR' => [
            'MVR',
            'maldivisk rufiyaa',
        ],
        'MWK' => [
            'MWK',
            'malawisk kwacha',
        ],
        'MXN' => [
            'MX$',
            'mexicansk peso',
        ],
        'MXP' => [
            'MXP',
            'Mexicansk silver peso (1861–1992)',
        ],
        'MYR' => [
            'MYR',
            'malaysisk ringgit',
        ],
        'MZE' => [
            'MZE',
            'Mozambiquisk escudo',
        ],
        'MZM' => [
            'MZM',
            'Mozambiquisk metical (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'mozambiquisk metical',
        ],
        'NAD' => [
            'NAD',
            'namibisk dollar',
        ],
        'NGN' => [
            'NGN',
            'nigeriansk naira',
        ],
        'NIC' => [
            'NIC',
            'Nicaraguansk cordoba (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'nicaraguansk cordoba',
        ],
        'NLG' => [
            'NLG',
            'Hollandsk guilder',
        ],
        'NOK' => [
            'NOK',
            'norsk krone',
        ],
        'NPR' => [
            'NPR',
            'nepalesisk rupee',
        ],
        'NZD' => [
            'NZ$',
            'newzealandsk dollar',
        ],
        'OMR' => [
            'OMR',
            'omansk rial',
        ],
        'PAB' => [
            'PAB',
            'panamansk balboa',
        ],
        'PEI' => [
            'PEI',
            'peruviansk inti',
        ],
        'PEN' => [
            'PEN',
            'peruansk sol',
        ],
        'PES' => [
            'PES',
            'peruviansk sol (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'papuansk kina',
        ],
        'PHP' => [
            'PHP',
            'filippinsk peso',
        ],
        'PKR' => [
            'PKR',
            'pakistansk rupee',
        ],
        'PLN' => [
            'PLN',
            'polsk zloty',
        ],
        'PLZ' => [
            'PLZ',
            'Polsk zloty (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'Portugisisk escudo',
        ],
        'PYG' => [
            'PYG',
            'paraguaysk guarani',
        ],
        'QAR' => [
            'QAR',
            'qatarsk rial',
        ],
        'ROL' => [
            'ROL',
            'Rumænsk leu (1952–2006)',
        ],
        'RON' => [
            'RON',
            'rumænsk leu',
        ],
        'RSD' => [
            'RSD',
            'serbisk dinar',
        ],
        'RUB' => [
            'RUB',
            'russisk rubel',
        ],
        'RUR' => [
            'RUR',
            'Russisk rubel (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'rwandisk franc',
        ],
        'SAR' => [
            'SAR',
            'saudiarabisk riyal',
        ],
        'SBD' => [
            'SBD',
            'salomonsk dollar',
        ],
        'SCR' => [
            'SCR',
            'seychellisk rupee',
        ],
        'SDD' => [
            'SDD',
            'Sudansk dinar (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'sudansk pund',
        ],
        'SDP' => [
            'SDP',
            'Sudansk pund (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'svensk krone',
        ],
        'SGD' => [
            'SGD',
            'singaporeansk dollar',
        ],
        'SHP' => [
            'SHP',
            'pund fra Saint Helena',
        ],
        'SIT' => [
            'SIT',
            'Slovensk tolar',
        ],
        'SKK' => [
            'SKK',
            'Slovakisk koruna',
        ],
        'SLE' => [
            'SLE',
            'sierraleonsk leone',
        ],
        'SLL' => [
            'SLL',
            'sierraleonsk leone (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'somalisk shilling',
        ],
        'SRD' => [
            'SRD',
            'surinamsk dollar',
        ],
        'SRG' => [
            'SRG',
            'Surinamsk guilder',
        ],
        'SSP' => [
            'SSP',
            'sydsudansk pund',
        ],
        'STD' => [
            'STD',
            'dobra fra Sao Tome og Principe (1977–2017)',
        ],
        'STN' => [
            'STN',
            'dobra fra Sao Tome og Principe',
        ],
        'SUR' => [
            'SUR',
            'Sovjetisk rubel',
        ],
        'SVC' => [
            'SVC',
            'Salvadoransk colon',
        ],
        'SYP' => [
            'SYP',
            'syrisk pund',
        ],
        'SZL' => [
            'SZL',
            'swazilandsk lilangeni',
        ],
        'THB' => [
            '฿',
            'thailandsk baht',
        ],
        'TJR' => [
            'TJR',
            'Tadsjikisk rubel',
        ],
        'TJS' => [
            'TJS',
            'tadsjikisk somoni',
        ],
        'TMM' => [
            'TMM',
            'Turkmensk manat (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'turkmensk manat',
        ],
        'TND' => [
            'TND',
            'tunesisk dinar',
        ],
        'TOP' => [
            'TOP',
            'tongansk paʻanga',
        ],
        'TPE' => [
            'TPE',
            'Escudo fra Timor',
        ],
        'TRL' => [
            'TRL',
            'Tyrkisk lire (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'tyrkisk lira',
        ],
        'TTD' => [
            'TTD',
            'trinidadisk dollar',
        ],
        'TWD' => [
            'NT$',
            'ny taiwansk dollar',
        ],
        'TZS' => [
            'TZS',
            'tanzanisk shilling',
        ],
        'UAH' => [
            'UAH',
            'ukrainsk grynia',
        ],
        'UAK' => [
            'UAK',
            'Ukrainsk karbovanetz',
        ],
        'UGS' => [
            'UGS',
            'Ugandisk shilling (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'ugandisk shilling',
        ],
        'USD' => [
            'US$',
            'amerikansk dollar',
        ],
        'USN' => [
            'USN',
            'Amerikansk dollar (næste dag)',
        ],
        'USS' => [
            'USS',
            'Amerikansk dollar (samme dag)',
        ],
        'UYP' => [
            'UYP',
            'Uruguayansk peso (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'uruguayansk peso',
        ],
        'UZS' => [
            'UZS',
            'usbekisk sum',
        ],
        'VEB' => [
            'VEB',
            'Venezuelansk bolivar (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'venezuelansk bolivar (2008–2018)',
        ],
        'VES' => [
            'VES',
            'venezuelansk bolivar',
        ],
        'VND' => [
            '₫',
            'vietnamesisk dong',
        ],
        'VUV' => [
            'VUV',
            'vanuaisk vatu',
        ],
        'WST' => [
            'WST',
            'samoansk tala',
        ],
        'XAF' => [
            'FCFA',
            'CFA-franc (BEAC)',
        ],
        'XCD' => [
            'EC$',
            'østkaribisk dollar',
        ],
        'XCG' => [
            'Cg.',
            'caribiske gylden',
        ],
        'XEU' => [
            'XEU',
            'ECU',
        ],
        'XFO' => [
            'XFO',
            'Fransk guldfranc',
        ],
        'XFU' => [
            'XFU',
            'Fransk UIC-franc',
        ],
        'XOF' => [
            'F CFA',
            'CFA-franc BCEAO',
        ],
        'XPF' => [
            'CFPF',
            'CFP-franc',
        ],
        'XRE' => [
            'XRE',
            'RINET-fond',
        ],
        'YDD' => [
            'YDD',
            'Yemenitisk dinar',
        ],
        'YER' => [
            'YER',
            'yemenitisk rial',
        ],
        'YUD' => [
            'YUD',
            'Jugoslavisk hard dinar (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'Jugoslavisk noviy dinar (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'Jugoslavisk konvertibel dinar (1990–1992)',
        ],
        'ZAL' => [
            'ZAL',
            'Sydafrikansk rand (financial)',
        ],
        'ZAR' => [
            'ZAR',
            'sydafrikansk rand',
        ],
        'ZMK' => [
            'ZMK',
            'Zambisk kwacha (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'zambisk kwacha',
        ],
        'ZRN' => [
            'ZRN',
            'Ny zairisk zaire (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'Zairisk zaire (1971–1993)',
        ],
        'ZWD' => [
            'ZWD',
            'Zimbabwisk dollar (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'Zimbabwe Gold',
        ],
        'ZWL' => [
            'ZWL',
            'Zimbabwisk dollar (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'Zimbabwisk dollar (2008)',
        ],
    ],
];
