<?php

return [
    '👩‍❤‍💋‍👨' => '𐴀𐴝𐴂𐴧𐴥𐴗𐴝: 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👨‍❤‍💋‍👨' => '𐴀𐴝𐴂𐴧𐴥𐴗𐴝: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👩‍❤‍💋‍👩' => '𐴀𐴝𐴂𐴧𐴥𐴗𐴝: 𐴁𐴠𐴍𐴞, 𐴁𐴠𐴍𐴞',
    '👨‍👩‍👧‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴘𐴧𐴝, 𐴉𐴟𐴖𐴝',
    '👨‍👩‍👦‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴁𐴠𐴍𐴞, 𐴉𐴟𐴖𐴝, 𐴉𐴟𐴖𐴝',
    '👨‍👩‍👧‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴘𐴧𐴝, 𐴔𐴝𐴘𐴧𐴝',
    '👨‍👨‍👧‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴘𐴧𐴝, 𐴉𐴟𐴖𐴝',
    '👨‍👨‍👦‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴉𐴟𐴖𐴝, 𐴉𐴟𐴖𐴝',
    '👨‍👨‍👧‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴘𐴧𐴝, 𐴔𐴝𐴘𐴧𐴝',
    '👩‍👩‍👧‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴘𐴧𐴝, 𐴉𐴟𐴖𐴝',
    '👩‍👩‍👦‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴁𐴠𐴍𐴞, 𐴉𐴟𐴖𐴝, 𐴉𐴟𐴖𐴝',
    '👩‍👩‍👧‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴘𐴧𐴝, 𐴔𐴝𐴘𐴧𐴝',
    '🚶‍♀‍➡' => '𐴀𐴥𐴝𐴣𐴍𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🚶‍♂‍➡' => '𐴀𐴥𐴝𐴣𐴍𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🧎‍♀‍➡' => '𐴀𐴝𐴣𐴍𐴥𐴟𐴃𐴢 𐴁𐴤𐴡𐴌𐴊𐴧𐴞𐴘𐴝 𐴁𐴠𐴍𐴞: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🧎‍♂‍➡' => '𐴀𐴝𐴣𐴍𐴥𐴟𐴃𐴢 𐴁𐴤𐴡𐴌𐴊𐴧𐴞𐴘𐴝 𐴁𐴠𐴍𐴝: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🧑‍🦯‍➡' => '𐴓𐴝𐴍𐴥𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '👨‍🦯‍➡' => '𐴓𐴝𐴍𐴥𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴙𐴝 𐴁𐴠𐴍𐴝: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '👩‍🦯‍➡' => '𐴓𐴝𐴍𐴥𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴙𐴝 𐴁𐴠𐴍𐴞: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🧑‍🦼‍➡' => '𐴔𐴡𐴄𐴤𐴡𐴌 𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '👨‍🦼‍➡' => '𐴔𐴡𐴄𐴤𐴡𐴌 𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴝: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '👩‍🦼‍➡' => '𐴔𐴡𐴄𐴤𐴡𐴌 𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴞: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🧑‍🦽‍➡' => '𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '👨‍🦽‍➡' => '𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴝: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '👩‍🦽‍➡' => '𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴞: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🏃‍♀‍➡' => '𐴊𐴦𐴟𐴣𐴌𐴠𐴌𐴊𐴧𐴠 𐴁𐴠𐴍𐴞: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🏃‍♂‍➡' => '𐴊𐴦𐴟𐴣𐴌𐴠𐴌𐴊𐴧𐴠 𐴁𐴠𐴍𐴝: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '👩‍❤‍👨' => '𐴎𐴟𐴌 𐴀𐴝𐴌 𐴑𐴡𐴓𐴥𐴡𐴁𐴢: 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👨‍❤‍👨' => '𐴎𐴟𐴌 𐴀𐴝𐴌 𐴑𐴡𐴓𐴥𐴡𐴁𐴢: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👩‍❤‍👩' => '𐴎𐴟𐴌 𐴀𐴝𐴌 𐴑𐴡𐴓𐴥𐴡𐴁𐴢: 𐴁𐴠𐴍𐴞, 𐴁𐴠𐴍𐴞',
    '👨‍👩‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴁𐴠𐴍𐴞, 𐴉𐴟𐴖𐴝',
    '👨‍👩‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴘𐴧𐴝',
    '👨‍👨‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴉𐴟𐴖𐴝',
    '👨‍👨‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴘𐴧𐴝',
    '👩‍👩‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴁𐴠𐴍𐴞, 𐴉𐴟𐴖𐴝',
    '👩‍👩‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴘𐴧𐴝',
    '👨‍👦‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴉𐴟𐴖𐴝, 𐴉𐴟𐴖𐴝',
    '👨‍👧‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴘𐴧𐴝, 𐴉𐴟𐴖𐴝',
    '👨‍👧‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴘𐴧𐴝, 𐴔𐴝𐴘𐴧𐴝',
    '👩‍👦‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴉𐴟𐴖𐴝, 𐴉𐴟𐴖𐴝',
    '👩‍👧‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴘𐴧𐴝, 𐴉𐴟𐴖𐴝',
    '👩‍👧‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴘𐴧𐴝, 𐴔𐴝𐴘𐴧𐴝',
    '🧑‍🤝‍🧑' => '𐴇𐴥𐴝𐴃𐴠 𐴇𐴥𐴝𐴃𐴠 𐴊𐴤𐴡𐴙𐴅𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢 𐴀𐴥𐴡𐴑𐴧𐴡𐴓',
    '🧑‍🧒‍🧒' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞 - 𐴁𐴝𐴓𐴠𐴑 - 𐴉𐴟𐴖𐴝',
    '🚶‍➡' => '𐴀𐴥𐴝𐴣𐴍𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🧎‍➡' => '𐴀𐴝𐴣𐴍𐴥𐴟𐴃𐴢 𐴁𐴤𐴡𐴌𐴊𐴧𐴞𐴘𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '🏃‍➡' => '𐴊𐴦𐴟𐴣𐴌𐴠𐴌𐴊𐴧𐴠 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢: — 𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝',
    '👨‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴉𐴟𐴖𐴝',
    '👨‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢, 𐴔𐴝𐴘𐴧𐴝',
    '👩‍👦' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴉𐴟𐴖𐴝',
    '👩‍👧' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞: 𐴁𐴠𐴍𐴞, 𐴔𐴝𐴘𐴧𐴝',
    '🧔‍♂' => '𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢 - 𐴊𐴝𐴌𐴥𐴞',
    '👱‍♂' => '𐴁𐴠𐴍𐴝 - 𐴐𐴤𐴟𐴕𐴝 𐴌𐴡𐴚𐴒𐴙𐴝 𐴏𐴟𐴓',
    '🧔‍♀' => '𐴁𐴠𐴍𐴞 : 𐴊𐴝𐴌𐴥𐴞',
    '👱‍♀' => '𐴁𐴠𐴍𐴞 : 𐴐𐴤𐴟𐴕𐴝 𐴌𐴡𐴚𐴒𐴙𐴝 𐴏𐴟𐴓',
    '🙍‍♂' => '𐴀𐴝𐴔𐴧𐴟𐴙𐴑𐴧𐴙𐴝 𐴁𐴠𐴍𐴝',
    '🙍‍♀' => '𐴀𐴝𐴔𐴧𐴟𐴙𐴑𐴧𐴙𐴝 𐴁𐴠𐴍𐴞',
    '🙎‍♂' => '𐴉𐴥𐴟𐴓𐴝𐴘𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🙎‍♀' => '𐴉𐴥𐴟𐴓𐴝𐴘𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🙅‍♂' => '𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴕𐴡 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🙅‍♀' => '𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴕𐴡 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🙆‍♂' => '𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🙆‍♀' => '𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '💁‍♂' => '𐴀𐴠𐴑 𐴋𐴤𐴝𐴙𐴑𐴧𐴙𐴝 𐴇𐴥𐴝𐴃𐴡𐴌 𐴃𐴝𐴓𐴧𐴗𐴝 𐴊𐴞𐴘𐴝 𐴁𐴠𐴍𐴝',
    '💁‍♀' => '𐴈𐴝𐴕𐴊 𐴁𐴡𐴌𐴝𐴁𐴡𐴌 𐴃𐴠𐴏𐴧𐴝 𐴇𐴥𐴝𐴃𐴢 𐴀𐴡𐴓𐴝 𐴁𐴠𐴍𐴞',
    '🙋‍♂' => '𐴇𐴥𐴝𐴃𐴢 𐴃𐴟𐴙𐴓𐴧𐴥𐴝 𐴁𐴠𐴍𐴝',
    '🙋‍♀' => '𐴇𐴥𐴝𐴃𐴢 𐴃𐴟𐴙𐴓𐴧𐴥𐴝 𐴁𐴠𐴍𐴞',
    '🧏‍♂' => '𐴕𐴥𐴝𐴉𐴝𐴚 𐴁𐴠𐴍𐴝',
    '🧏‍♀' => '𐴕𐴥𐴝𐴉𐴝𐴚 𐴁𐴠𐴍𐴞',
    '🙇‍♂' => '𐴕𐴞𐴘𐴥𐴟𐴙𐴅𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴝',
    '🙇‍♀' => '𐴕𐴞𐴘𐴥𐴟𐴙𐴅𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴞',
    '🤦‍♂' => '𐴔𐴟𐴑 𐴏𐴞𐴁𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴝',
    '🤦‍♀' => '𐴔𐴟𐴑 𐴏𐴞𐴁𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴞',
    '🤷‍♂' => '𐴁𐴠𐴉𐴡𐴌𐴁𐴝 𐴁𐴠𐴍𐴝',
    '🤷‍♀' => '𐴁𐴠𐴉𐴡𐴌𐴁𐴝 𐴁𐴠𐴍𐴞',
    '🧑‍⚕' => '𐴏𐴠𐴇𐴥𐴠𐴃𐴡𐴌 𐴈𐴝𐴔 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝',
    '👨‍⚕' => '𐴏𐴠𐴇𐴥𐴠𐴃𐴡𐴌 𐴈𐴝𐴔 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '👩‍⚕' => '𐴏𐴠𐴇𐴥𐴠𐴃𐴡𐴌 𐴈𐴝𐴔 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🧑‍🎓' => '𐴉𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴉𐴟𐴖𐴝',
    '👨‍🎓' => '𐴉𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '👩‍🎓' => '𐴉𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🧑‍🏫' => '𐴔𐴝𐴏𐴄𐴡𐴌',
    '👨‍🏫' => '𐴁𐴠𐴍𐴝 𐴔𐴝𐴏𐴄𐴡𐴌',
    '👩‍🏫' => '𐴁𐴠𐴍𐴞 𐴔𐴝𐴏𐴄𐴡𐴌',
    '🧑‍⚖' => '𐴑𐴝𐴎𐴞',
    '👨‍⚖' => '𐴁𐴞𐴏𐴝𐴌𐴉𐴡𐴃𐴞 𐴁𐴠𐴍𐴝',
    '👩‍⚖' => '𐴁𐴞𐴏𐴝𐴌 𐴉𐴡𐴃𐴞 𐴁𐴠𐴍𐴞',
    '🧑‍🌾' => '𐴀𐴥𐴝𐴙𐴓𐴧𐴝',
    '👨‍🌾' => '𐴁𐴠𐴍𐴝 𐴀𐴥𐴝𐴙𐴓𐴧𐴝',
    '👩‍🌾' => '𐴁𐴠𐴍𐴞 𐴀𐴥𐴝𐴙𐴓𐴧𐴞',
    '🧑‍🍳' => '𐴁𐴦𐴡𐴏𐴃𐴤𐴞',
    '👨‍🍳' => '𐴁𐴠𐴍𐴝 𐴁𐴦𐴡𐴏𐴃𐴤𐴞',
    '👩‍🍳' => '𐴁𐴠𐴍𐴞 𐴁𐴦𐴡𐴏𐴃𐴤𐴞',
    '🧑‍🔧' => '𐴔𐴞𐴑𐴝𐴕𐴥𐴞𐴑',
    '👨‍🔧' => '𐴁𐴠𐴍𐴝 𐴔𐴞𐴑𐴤𐴝𐴕𐴥𐴞𐴑',
    '👩‍🔧' => '𐴁𐴠𐴍𐴞 𐴔𐴞𐴑𐴤𐴝𐴕𐴥𐴞𐴑',
    '🧑‍🏭' => '𐴉𐴥𐴠𐴑𐴄𐴠𐴌𐴥𐴞𐴌 𐴔𐴡𐴎𐴟𐴌',
    '👨‍🏭' => '𐴉𐴥𐴠𐴑𐴄𐴠𐴌𐴥𐴞𐴌 𐴁𐴠𐴍𐴝 𐴔𐴡𐴎𐴟𐴌',
    '👩‍🏭' => '𐴉𐴥𐴠𐴑𐴄𐴠𐴌𐴥𐴞𐴌 𐴁𐴠𐴍𐴞 𐴔𐴡𐴎𐴟𐴌',
    '🧑‍💼' => '𐴀𐴡𐴉𐴥𐴞𐴏𐴡𐴌 𐴏𐴦𐴡𐴙𐴅𐴧𐴙𐴝',
    '👨‍💼' => '𐴀𐴡𐴉𐴥𐴞𐴏𐴡𐴌 𐴁𐴠𐴍𐴝 𐴏𐴦𐴡𐴙𐴅𐴧𐴙𐴝',
    '👩‍💼' => '𐴀𐴡𐴉𐴥𐴞𐴏𐴡𐴌 𐴁𐴠𐴍𐴞 𐴏𐴦𐴡𐴙𐴅𐴧𐴙𐴝',
    '🧑‍🔬' => '𐴏𐴥𐴝𐴛𐴏𐴊𐴝𐴕',
    '👨‍🔬' => '𐴏𐴥𐴝𐴛𐴏𐴊𐴝𐴕 𐴁𐴠𐴍𐴝',
    '👩‍🔬' => '𐴏𐴥𐴝𐴛𐴏𐴊𐴝𐴕 𐴁𐴠𐴍𐴞',
    '🧑‍💻' => '𐴄𐴠𐴑𐴕𐴡𐴓𐴡𐴅𐴞 𐴊𐴝𐴕',
    '👨‍💻' => '𐴄𐴠𐴑𐴕𐴡𐴓𐴡𐴅𐴞𐴌 𐴔𐴝𐴇𐴥𐴠𐴌 𐴁𐴠𐴍𐴝',
    '👩‍💻' => '𐴄𐴠𐴑𐴕𐴡𐴓𐴡𐴅𐴞𐴌 𐴔𐴝𐴇𐴥𐴠𐴌 𐴁𐴠𐴍𐴞',
    '🧑‍🎤' => '𐴒𐴝𐴙𐴕',
    '👨‍🎤' => '𐴒𐴝𐴙𐴕 𐴁𐴠𐴍𐴝',
    '👩‍🎤' => '𐴒𐴝𐴙𐴕 𐴁𐴠𐴍𐴞',
    '🧑‍🎨' => '𐴀𐴦𐴝𐴌𐴄 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 -',
    '👨‍🎨' => '𐴀𐴦𐴝𐴌𐴄 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '👩‍🎨' => '𐴀𐴦𐴝𐴌𐴄 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🧑‍✈' => '𐴉𐴝𐴘𐴓𐴥𐴡𐴄',
    '👨‍✈' => '𐴁𐴠𐴍𐴝 𐴉𐴝𐴘𐴓𐴥𐴡𐴄',
    '👩‍✈' => '𐴁𐴠𐴍𐴞 - 𐴉𐴝𐴘𐴓𐴥𐴡𐴄',
    '🧑‍🚀' => '𐴇𐴥𐴝𐴁𐴝𐴃𐴢 𐴀𐴟𐴌𐴥𐴡𐴙𐴕𐴧𐴝',
    '👨‍🚀' => '𐴇𐴥𐴝𐴁𐴝𐴃𐴢 𐴀𐴟𐴌𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '👩‍🚀' => '𐴇𐴥𐴝𐴁𐴝𐴃𐴢 𐴀𐴟𐴌𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🧑‍🚒' => '𐴀𐴦𐴡𐴙𐴕 𐴕𐴞𐴉𐴡𐴀𐴡𐴙𐴕𐴧𐴝',
    '👨‍🚒' => '𐴀𐴦𐴡𐴙𐴕 𐴕𐴞𐴉𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '👩‍🚒' => '𐴀𐴦𐴡𐴙𐴕 𐴕𐴞𐴉𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '👮‍♂' => '𐴉𐴟𐴓𐴞𐴐𐴢 𐴀𐴝𐴉𐴥𐴞𐴏𐴝𐴌 𐴁𐴠𐴍𐴝',
    '👮‍♀' => '𐴉𐴟𐴓𐴞𐴐𐴢 𐴀𐴝𐴉𐴥𐴞𐴏𐴝𐴌 𐴁𐴠𐴍𐴞',
    '🕵‍♂' => '𐴃𐴝𐴇𐴑𐴞𐴑 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🕵‍♀' => '𐴃𐴝𐴇𐴑𐴞𐴑 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '💂‍♂' => '𐴁𐴠𐴍𐴝 𐴒𐴝𐴀𐴝𐴋',
    '💂‍♀' => '𐴁𐴠𐴍𐴞 𐴒𐴝𐴀𐴝𐴋',
    '👷‍♂' => '𐴒𐴤𐴡𐴌 𐴁𐴝𐴣𐴊𐴤𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '👷‍♀' => '𐴒𐴤𐴡𐴌 𐴁𐴝𐴣𐴊𐴤𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '👳‍♂' => '𐴉𐴦𐴡𐴌𐴞 𐴉𐴞𐴕𐴊𐴤𐴝 𐴁𐴠𐴍𐴝',
    '👳‍♀' => '𐴉𐴦𐴡𐴌𐴞 𐴉𐴞𐴕𐴊𐴤𐴝 𐴁𐴠𐴍𐴞',
    '🤵‍♂' => '𐴑𐴟𐴄𐴢 𐴉𐴞𐴕𐴊𐴤𐴝 𐴁𐴠𐴍𐴝',
    '🤵‍♀' => '𐴑𐴟𐴄𐴢 𐴉𐴞𐴕𐴊𐴤𐴝 𐴁𐴠𐴍𐴞',
    '👰‍♂' => '𐴁𐴞𐴘𐴥𐴝𐴌 𐴇𐴥𐴝𐴣𐴏𐴢 𐴉𐴞𐴕𐴊𐴤𐴝 𐴁𐴠𐴍𐴝',
    '👰‍♀' => '𐴁𐴞𐴘𐴥𐴝𐴌 𐴇𐴥𐴝𐴣𐴏𐴢 𐴉𐴞𐴕𐴊𐴤𐴝 𐴁𐴠𐴍𐴞',
    '👩‍🍼' => '𐴉𐴟𐴖𐴝 𐴊𐴟𐴊𐴢 𐴈𐴥𐴝𐴀𐴝𐴁𐴡𐴀𐴡𐴕 𐴁𐴠𐴍𐴞',
    '👨‍🍼' => '𐴉𐴟𐴖𐴝 𐴊𐴟𐴊𐴢 𐴈𐴥𐴝𐴀𐴝𐴁𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🧑‍🍼' => '𐴉𐴟𐴖𐴝 𐴊𐴟𐴊𐴢 𐴈𐴥𐴝𐴀𐴝𐴁𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧑‍🎄' => '𐴀𐴠𐴔 𐴀𐴥𐴠𐴑𐴏𐴢 𐴑𐴡𐴓𐴡𐴎',
    '🦸‍♂' => '𐴏𐴟𐴂𐴥𐴝𐴌 𐴇𐴥𐴞𐴌𐴟 𐴁𐴠𐴍𐴝',
    '🦸‍♀' => '𐴏𐴟𐴂𐴥𐴝𐴌 𐴇𐴥𐴞𐴌𐴟 𐴁𐴠𐴍𐴞',
    '🦹‍♂' => '𐴏𐴟𐴂𐴥𐴝𐴌 𐴁𐴞𐴓𐴥𐴝𐴕 𐴁𐴠𐴍𐴝',
    '🦹‍♀' => '𐴏𐴟𐴂𐴥𐴝𐴌 𐴁𐴞𐴓𐴥𐴝𐴕 𐴁𐴠𐴍𐴞',
    '🧙‍♂' => '𐴁𐴠𐴍𐴝 𐴅𐴝𐴊𐴟',
    '🧙‍♀' => '𐴁𐴠𐴍𐴞 𐴅𐴝𐴊𐴟',
    '🧚‍♂' => '𐴉𐴡𐴌𐴞 𐴁𐴠𐴍𐴝',
    '🧚‍♀' => '𐴉𐴡𐴌𐴞 𐴁𐴠𐴍𐴞',
    '🧛‍♂' => '𐴓𐴡𐴖 𐴉𐴞𐴘𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🧛‍♀' => '𐴓𐴡𐴖 𐴉𐴞𐴘𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🧜‍♂' => '𐴔𐴠𐴌𐴁𐴠𐴍𐴝',
    '🧜‍♀' => '𐴔𐴠𐴌𐴁𐴠𐴍𐴞',
    '🧝‍♂' => '𐴁𐴤𐴟𐴃𐴢 𐴉𐴠𐴌𐴡𐴃𐴢 𐴁𐴠𐴍𐴝',
    '🧝‍♀' => '𐴁𐴤𐴟𐴃𐴢 𐴉𐴠𐴌𐴡𐴃𐴢 𐴁𐴠𐴍𐴞',
    '🧞‍♂' => '𐴁𐴠𐴍𐴝 𐴅𐴞𐴕',
    '🧞‍♀' => '𐴁𐴠𐴍𐴞 𐴅𐴞𐴕',
    '🧟‍♂' => '𐴎𐴤𐴟𐴔𐴁𐴞 𐴁𐴠𐴍𐴝',
    '🧟‍♀' => '𐴎𐴤𐴟𐴔𐴁𐴞 𐴁𐴠𐴍𐴞',
    '💆‍♂' => '𐴔𐴝𐴎𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '💆‍♀' => '𐴔𐴝𐴎𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '💇‍♂' => '𐴏𐴟𐴓 𐴈𐴝𐴍𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '💇‍♀' => '𐴏𐴟𐴓 𐴈𐴝𐴍𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🚶‍♂' => '𐴀𐴥𐴝𐴣𐴍𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🚶‍♀' => '𐴀𐴥𐴝𐴣𐴍𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🧍‍♂' => '𐴃𐴤𐴞𐴘𐴝𐴘𐴧𐴥𐴝 𐴁𐴠𐴍𐴝',
    '🧍‍♀' => '𐴃𐴤𐴞𐴘𐴝𐴘𐴧𐴥𐴝 𐴁𐴠𐴍𐴞',
    '🧎‍♂' => '𐴀𐴝𐴣𐴍𐴥𐴟𐴃𐴢 𐴁𐴤𐴡𐴌𐴊𐴧𐴞𐴘𐴝 𐴁𐴠𐴍𐴝',
    '🧎‍♀' => '𐴀𐴝𐴣𐴍𐴥𐴟𐴃𐴢 𐴁𐴤𐴡𐴌𐴊𐴧𐴞𐴘𐴝 𐴁𐴠𐴍𐴞',
    '🧑‍🦯' => '𐴓𐴝𐴍𐴥𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👨‍🦯' => '𐴓𐴝𐴍𐴥𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴙𐴝 𐴁𐴠𐴍𐴝',
    '👩‍🦯' => '𐴓𐴝𐴍𐴥𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴙𐴝 𐴁𐴠𐴍𐴞',
    '🧑‍🦼' => '𐴔𐴡𐴄𐴤𐴡𐴌 𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👨‍🦼' => '𐴔𐴡𐴄𐴤𐴡𐴌 𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴝',
    '👩‍🦼' => '𐴔𐴡𐴄𐴤𐴡𐴌 𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴞',
    '🧑‍🦽' => '𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👨‍🦽' => '𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴝',
    '👩‍🦽' => '𐴖𐴥𐴠𐴓𐴆𐴤𐴙𐴝𐴌𐴡𐴃𐴢 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴞',
    '🏃‍♂' => '𐴊𐴦𐴟𐴣𐴌𐴠𐴌𐴊𐴧𐴠 𐴁𐴠𐴍𐴝',
    '🏃‍♀' => '𐴊𐴦𐴟𐴣𐴌𐴠𐴌𐴊𐴧𐴠 𐴁𐴠𐴍𐴞',
    '👯‍♂' => '𐴈𐴥𐴡𐴌𐴒𐴟𐴐𐴢 𐴈𐴝𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '👯‍♀' => '𐴈𐴥𐴡𐴌𐴒𐴟𐴐𐴢 𐴈𐴝𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞𐴘𐴥𐴝𐴙𐴕',
    '🧖‍♂' => '𐴁𐴤𐴝𐴉𐴢 𐴀𐴡𐴓𐴝 𐴑𐴝𐴔𐴌𐴝𐴌 𐴁𐴠𐴍𐴝',
    '🧖‍♀' => '𐴁𐴤𐴝𐴉𐴢 𐴀𐴡𐴓𐴝 𐴑𐴝𐴔𐴌𐴝𐴌 𐴁𐴠𐴍𐴞',
    '🧗‍♂' => '𐴓𐴡𐴄𐴑𐴞 𐴀𐴟𐴍𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧗‍♀' => '𐴓𐴡𐴄𐴑𐴞 𐴀𐴟𐴍𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🏌‍♂' => '𐴒𐴤𐴡𐴓𐴉𐴢 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🏌‍♀' => '𐴒𐴤𐴡𐴓𐴉𐴢 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🏄‍♂' => '𐴉𐴝𐴕𐴥𐴞𐴃𐴢 𐴏𐴡𐴏𐴧𐴡𐴌𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🏄‍♀' => '𐴉𐴝𐴕𐴥𐴞𐴃𐴢 𐴏𐴡𐴏𐴧𐴡𐴌𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🚣‍♂' => '𐴕𐴦𐴡 𐴁𐴝𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🚣‍♀' => '𐴕𐴦𐴡 𐴁𐴝𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🏊‍♂' => '𐴀𐴥𐴝𐴣𐴏𐴟𐴌𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🏊‍♀' => '𐴀𐴥𐴝𐴣𐴏𐴟𐴌𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞 -',
    '⛹‍♂' => '𐴉𐴥𐴝𐴓𐴊𐴝𐴕𐴞 𐴁𐴡𐴀𐴡𐴓 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝 - 𐴁𐴡𐴀𐴡𐴓 - 𐴁𐴠𐴍𐴝',
    '⛹‍♀' => '𐴉𐴥𐴝𐴓𐴊𐴝𐴕𐴞 𐴁𐴡𐴀𐴡𐴓 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🏋‍♂' => '𐴃𐴟𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🏋‍♀' => '𐴀𐴟𐴎𐴤𐴡𐴕 𐴃𐴟𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🚴‍♂' => '𐴏𐴝𐴙𐴌𐴑𐴤𐴠𐴓 𐴏𐴝𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🚴‍♀' => '𐴏𐴝𐴙𐴌𐴑𐴤𐴠𐴓 𐴏𐴝𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🚵‍♂' => '𐴉𐴝𐴀𐴝𐴌𐴡𐴃𐴢 𐴏𐴝𐴙𐴌𐴑𐴤𐴠𐴓 𐴏𐴝𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🚵‍♀' => '𐴉𐴝𐴀𐴝𐴌𐴡𐴃𐴢 𐴏𐴝𐴙𐴌𐴑𐴤𐴠𐴓 𐴏𐴝𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🤸‍♂' => '𐴑𐴝𐴄𐴖𐴥𐴠𐴓 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🤸‍♀' => '𐴑𐴝𐴄𐴖𐴥𐴠𐴓 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🤼‍♂' => '𐴑𐴟𐴏𐴥𐴞 𐴊𐴤𐴡𐴌𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝𐴀𐴝𐴙𐴕',
    '🤼‍♀' => '𐴑𐴟𐴏𐴥𐴞 𐴊𐴤𐴡𐴌𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🤽‍♂' => '𐴉𐴝𐴕𐴥𐴞𐴃𐴢 𐴁𐴡𐴀𐴡𐴓 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🤽‍♀' => '𐴉𐴝𐴕𐴥𐴞𐴃𐴢 𐴁𐴡𐴀𐴡𐴓 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🤾‍♂' => '𐴇𐴥𐴝𐴃𐴢 𐴁𐴡𐴀𐴡𐴓 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🤾‍♀' => '𐴇𐴥𐴝𐴃𐴢 𐴁𐴡𐴀𐴡𐴓 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🤹‍♂' => '𐴅𐴝𐴒𐴓𐴞𐴚 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴝',
    '🤹‍♀' => '𐴅𐴝𐴒𐴓𐴞𐴚 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴁𐴠𐴍𐴞',
    '🧘‍♂' => '𐴓𐴥𐴠𐴂𐴧𐴝𐴍𐴞 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢 𐴁𐴠𐴍𐴝',
    '🧘‍♀' => '𐴓𐴥𐴠𐴂𐴧𐴝𐴍𐴞 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴞',
    '🐕‍🦺' => '𐴔𐴡𐴊𐴡𐴃𐴢 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴑𐴟𐴛𐴌',
    '🐈‍⬛' => '𐴈𐴝𐴓𐴝 𐴁𐴞𐴓𐴝𐴘',
    '🐻‍❄' => '𐴊𐴤𐴡𐴓𐴝 𐴁𐴤𐴝𐴓𐴧𐴟𐴑',
    '🐦‍⬛' => '𐴈𐴝𐴓𐴝 𐴉𐴝𐴙𐴑',
    '🐦‍🔥' => '𐴀𐴦𐴡𐴙𐴕𐴞 𐴉𐴝𐴙𐴑',
    '🍋‍🟩' => '𐴑𐴠𐴣𐴍𐴝 𐴎𐴝𐴔𐴞𐴌',
    '🍄‍🟫' => '𐴈𐴡𐴃𐴢 𐴌𐴡𐴚𐴝 𐴀𐴟𐴓',
    '🔟' => '𐴑𐴞𐴑𐴤𐴠𐴂𐴢: 10',
    '👋' => '𐴇𐴥𐴝𐴃𐴠 𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴒𐴡𐴌𐴥𐴡𐴕',
    '🤚' => '𐴇𐴥𐴝𐴃𐴡𐴌 𐴉𐴞𐴏𐴢 𐴋𐴤𐴝𐴑 𐴃𐴟𐴙𐴓𐴧𐴙𐴠',
    '🖐' => '𐴏𐴥𐴠𐴌𐴝𐴘𐴧𐴝 𐴀𐴦𐴡𐴣𐴓𐴡𐴌 𐴇𐴥𐴝𐴃𐴢',
    '✋' => '𐴇𐴥𐴝𐴃𐴢 𐴃𐴟𐴙𐴓𐴧𐴙𐴠',
    '🖖' => '𐴁𐴟𐴓𐴑𐴝𐴕 𐴏𐴥𐴡𐴓𐴝𐴔',
    '🫱' => '𐴋𐴠𐴕 𐴇𐴥𐴝𐴃𐴢',
    '🫲' => '𐴁𐴝𐴕 𐴇𐴥𐴝𐴃𐴢',
    '🫳' => '𐴃𐴝𐴓𐴧𐴗𐴝 𐴕𐴠𐴏𐴡 𐴒𐴡𐴙𐴅𐴧𐴤𐴙𐴝 𐴇𐴥𐴝𐴃𐴢',
    '🫴' => '𐴃𐴝𐴓𐴧𐴗𐴝 𐴀𐴟𐴖𐴡𐴌 𐴔𐴞𐴑𐴧𐴤𐴙𐴝 𐴇𐴥𐴝𐴃𐴢',
    '🫷' => '𐴁𐴝𐴕𐴋𐴤𐴝𐴙𐴑𐴧𐴙𐴝 𐴄𐴤𐴠𐴓𐴡𐴙𐴕𐴧𐴙𐴝 𐴇𐴥𐴝𐴃𐴢',
    '🫸' => '𐴋𐴠𐴕𐴋𐴤𐴝𐴙𐴑𐴧𐴙𐴝 𐴄𐴥𐴠𐴓𐴡𐴙𐴕𐴧𐴙𐴝 𐴇𐴥𐴝𐴃𐴢',
    '👌' => '𐴀𐴡𐴑𐴠 𐴇𐴥𐴝𐴃𐴢',
    '🤌' => '𐴑𐴟𐴣𐴌𐴝𐴘𐴧𐴝 𐴀𐴦𐴡𐴣𐴓',
    '🤏' => '𐴑𐴟𐴣𐴌𐴝𐴘𐴧𐴝 𐴇𐴥𐴝𐴃𐴢',
    '✌' => '𐴑𐴝𐴔𐴞𐴘𐴝𐴁𐴞𐴌 𐴇𐴥𐴝𐴃𐴢',
    '🤞' => '𐴈𐴡𐴓 𐴊𐴞𐴘𐴝 𐴀𐴦𐴡𐴣𐴓',
    '🫰' => '𐴓𐴝𐴙𐴅𐴧𐴙𐴝 𐴀𐴦𐴡𐴣𐴓 𐴀𐴝𐴌 𐴁𐴟𐴙𐴅𐴧𐴤𐴙𐴝 𐴀𐴦𐴡𐴣𐴓 𐴈𐴡𐴓 𐴊𐴞𐴘𐴝 𐴇𐴥𐴝𐴃𐴢',
    '🤟' => '𐴃𐴟𐴣𐴖𐴥𐴝𐴣𐴌 𐴀𐴝𐴊𐴡𐴌𐴡𐴌 𐴀𐴞𐴐𐴤𐴝𐴌𐴝',
    '🤘' => '𐴇𐴥𐴡𐴌𐴡𐴕𐴡𐴌 𐴀𐴞𐴐𐴤𐴝𐴌𐴝',
    '🤙' => '𐴋𐴝𐴑𐴡𐴕𐴡𐴌 𐴀𐴞𐴐𐴤𐴝𐴌𐴝',
    '👈' => '𐴁𐴝𐴕𐴋𐴤𐴝𐴑𐴡𐴌 𐴀𐴦𐴡𐴣𐴓𐴡𐴌 𐴀𐴞𐴐𐴤𐴝𐴌𐴝',
    '👉' => '𐴋𐴠𐴕𐴋𐴤𐴝𐴑𐴡𐴌 𐴀𐴦𐴡𐴣𐴓𐴡𐴌 𐴀𐴞𐴐𐴤𐴝𐴌𐴝',
    '🖕' => '𐴔𐴝𐴙𐴅𐴧𐴤𐴙𐴝 𐴀𐴦𐴡𐴣𐴓',
    '👇' => '𐴓𐴝𐴙𐴅𐴧𐴙𐴝 𐴀𐴦𐴡𐴣𐴓 𐴓𐴡𐴘 𐴇𐴥𐴠𐴔 𐴔𐴞𐴑𐴧𐴙𐴝 𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴒𐴡𐴌𐴡𐴕',
    '☝' => '𐴓𐴝𐴙𐴅𐴧𐴙𐴝 𐴀𐴦𐴡𐴣𐴓 𐴓𐴡𐴘 𐴀𐴟𐴖𐴡𐴌 𐴔𐴞𐴑𐴧𐴤𐴙𐴝 𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴒𐴡𐴌𐴥𐴡𐴕',
    '🫵' => '𐴓𐴝𐴙𐴅𐴧𐴙𐴝 𐴀𐴦𐴡𐴣𐴓 𐴓𐴡𐴘 𐴏𐴡𐴀𐴡𐴙𐴕𐴧𐴝𐴌 𐴔𐴞𐴑𐴧𐴤𐴙𐴝 𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴒𐴡𐴌𐴥𐴡𐴕',
    '👍' => '𐴁𐴞𐴐𐴤𐴞 𐴁𐴤𐴝𐴓𐴝',
    '👎' => '𐴕𐴝𐴑𐴤𐴟𐴐𐴢',
    '✊' => '𐴔𐴥𐴟𐴄𐴢 𐴔𐴝𐴙𐴅𐴧𐴤𐴙𐴝 𐴇𐴥𐴝𐴃𐴢 𐴀𐴟𐴖𐴡𐴌 𐴔𐴞𐴑𐴧𐴤𐴙𐴝 𐴃𐴟𐴓𐴡𐴕',
    '👊' => '𐴔𐴟𐴀𐴟𐴔 𐴒𐴤𐴟𐴐𐴤𐴝',
    '🤛' => '𐴁𐴝𐴕 𐴔𐴟𐴑𐴤𐴝 𐴔𐴥𐴟𐴄𐴢',
    '🤜' => '𐴋𐴠𐴕 𐴔𐴟𐴑𐴤𐴝 𐴔𐴥𐴟𐴄𐴢',
    '👏' => '𐴃𐴝𐴓𐴞 𐴔𐴝𐴌𐴝 𐴇𐴥𐴝𐴃𐴢',
    '🙌' => '𐴃𐴟𐴙𐴓𐴧𐴝 𐴇𐴥𐴝𐴃𐴢',
    '🫶' => '𐴑𐴡𐴓𐴥𐴡𐴁𐴢 𐴐𐴡𐴑𐴤𐴡𐴓 𐴇𐴥𐴝𐴃𐴢',
    '👐' => '𐴑𐴤𐴟𐴓𐴝 𐴇𐴥𐴝𐴃𐴢',
    '🤲' => '𐴊𐴟𐴕𐴥𐴞 𐴃𐴝𐴓𐴧𐴗𐴝 𐴉𐴥𐴟𐴣𐴖𐴥𐴝𐴣𐴃𐴞 𐴃𐴟𐴓𐴥𐴡',
    '🤝' => '𐴔𐴟𐴓𐴦𐴡𐴃𐴢',
    '🙏' => '𐴊𐴟𐴕𐴥𐴞 𐴃𐴝𐴓𐴧𐴗𐴝 𐴁𐴝𐴎𐴤𐴝𐴘𐴧𐴝 𐴇𐴥𐴝𐴃𐴢',
    '✍' => '𐴓𐴠𐴑𐴤𐴠𐴊𐴠 𐴇𐴥𐴝𐴃𐴢',
    '💅' => '𐴕𐴡𐴑 𐴂𐴝𐴓𐴥𐴞𐴐𐴢',
    '🤳' => '𐴏𐴥𐴠𐴓𐴉𐴞',
    '💪' => '𐴉𐴥𐴟𐴓𐴝𐴙𐴕𐴧𐴝 𐴁𐴝𐴛𐴧𐴝𐴌𐴝',
    '🦾' => '𐴔𐴞𐴑𐴤𐴝𐴕𐴞𐴑𐴤𐴞 𐴇𐴥𐴝𐴃𐴢',
    '🦿' => '𐴔𐴞𐴑𐴤𐴝𐴕𐴌𐴑𐴤𐴞 𐴄𐴤𐴠𐴚',
    '🦶' => '𐴄𐴤𐴠𐴚',
    '👂' => '𐴈𐴝𐴕',
    '🦻' => '𐴈𐴝𐴕 𐴓𐴡𐴘 𐴉𐴥𐴟𐴕𐴝𐴌 𐴔𐴡𐴊𐴡𐴃𐴢',
    '👃' => '𐴕𐴝𐴑',
    '🧠' => '𐴊𐴠𐴔𐴝𐴒𐴢',
    '🫀' => '𐴐𐴤𐴡𐴌𐴞𐴓𐴞 𐴑𐴡𐴓𐴥𐴡𐴁𐴢',
    '🫁' => '𐴉𐴥𐴠𐴐𐴧𐴤𐴗𐴝',
    '🦷' => '𐴊𐴝𐴃𐴢',
    '🦴' => '𐴇𐴥𐴝𐴣𐴋𐴧𐴞',
    '👀' => '𐴏𐴟𐴑 𐴀𐴥𐴡𐴑𐴧𐴡𐴓',
    '👁' => '𐴏𐴟𐴑',
    '👅' => '𐴎𐴞𐴌',
    '👄' => '𐴒𐴝𐴓',
    '🫦' => '𐴊𐴝𐴃𐴠 𐴏𐴞𐴂𐴧𐴝 𐴀𐴟𐴣𐴄𐴢',
    '👶' => '𐴊𐴟𐴊𐴡𐴌 𐴉𐴟𐴖𐴝',
    '🧒' => '𐴉𐴟𐴖𐴝𐴙𐴕',
    '👦' => '𐴉𐴟𐴖𐴝',
    '👧' => '𐴔𐴝𐴘𐴧𐴝',
    '👱' => '𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢 : 𐴐𐴤𐴟𐴕𐴝 𐴌𐴡𐴚𐴒𐴙𐴝 𐴏𐴟𐴓',
    '👨' => '𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👩' => '𐴁𐴠𐴍𐴞',
    '👴' => '𐴁𐴟𐴌𐴥𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👵' => '𐴁𐴟𐴌𐴥𐴝 𐴁𐴠𐴍𐴞',
    '🙍' => '𐴀𐴝𐴔𐴧𐴟𐴙𐴑𐴧𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🙎' => '𐴉𐴥𐴟𐴓𐴝𐴘𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🙅' => '𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴕𐴡 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🙆' => '𐴀𐴞𐴐𐴤𐴝𐴌𐴝 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '💁' => '𐴀𐴠𐴑 𐴋𐴤𐴝𐴙𐴑𐴧𐴙𐴝 𐴇𐴥𐴝𐴃𐴡𐴌 𐴃𐴝𐴓𐴧𐴗𐴝 𐴊𐴞𐴘𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🙋' => '𐴇𐴥𐴝𐴃𐴢 𐴃𐴟𐴙𐴓𐴧𐴥𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧏' => '𐴕𐴥𐴝𐴉𐴝𐴚 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🙇' => '𐴕𐴞𐴘𐴥𐴟𐴙𐴅𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤦' => '𐴔𐴟𐴑 𐴏𐴞𐴁𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤷' => '𐴁𐴠𐴉𐴡𐴌𐴁𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👮' => '𐴉𐴟𐴓𐴞𐴐𐴢 𐴀𐴡𐴉𐴥𐴞𐴏𐴝𐴌',
    '🕵' => '𐴃𐴝𐴇𐴑𐴞𐴑 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝',
    '💂' => '𐴒𐴝𐴀𐴝𐴋',
    '🥷' => '𐴕𐴠𐴕𐴅𐴝',
    '👷' => '𐴒𐴤𐴡𐴌 𐴁𐴝𐴣𐴊𐴤𐴡𐴙𐴕𐴧𐴝',
    '🫅' => '𐴃𐴝𐴏𐴢 𐴉𐴞𐴕𐴊𐴤𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤴' => '𐴀𐴔𐴞𐴌',
    '👸' => '𐴌𐴝𐴎𐴑𐴟𐴔𐴝𐴌𐴞',
    '👳' => '𐴉𐴦𐴡𐴌𐴞 𐴉𐴞𐴕𐴊𐴤𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👲' => '𐴏𐴞𐴕𐴝 𐴃𐴠𐴙𐴑𐴧𐴝 𐴉𐴞𐴕𐴊𐴤𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧕' => '𐴔𐴝𐴃𐴤𐴝 𐴈𐴦𐴡𐴌 𐴉𐴞𐴕𐴊𐴤𐴝 𐴁𐴠𐴍𐴞',
    '🤵' => '𐴑𐴟𐴄𐴢 𐴉𐴞𐴕𐴊𐴤𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👰' => '𐴁𐴞𐴘𐴥𐴝𐴌 𐴇𐴥𐴝𐴣𐴏𐴢 𐴉𐴞𐴕𐴊𐴤𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤰' => '𐴇𐴦𐴝𐴔𐴠𐴓 𐴁𐴠𐴍𐴞',
    '🫃' => '𐴇𐴦𐴝𐴔𐴠𐴓 𐴁𐴠𐴍𐴝',
    '🫄' => '𐴇𐴦𐴝𐴔𐴠𐴓 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤱' => '𐴊𐴟𐴊𐴢 𐴈𐴥𐴝𐴀𐴝𐴁𐴡𐴀𐴡𐴕',
    '👼' => '𐴊𐴟𐴊𐴤𐴡𐴌 𐴉𐴟𐴖𐴝 𐴉𐴥𐴞𐴌𐴞𐴐𐴃𐴤𐴝',
    '🎅' => '𐴏𐴝𐴕𐴄𐴝 𐴑𐴡𐴓𐴡𐴎',
    '🤶' => '𐴁𐴠𐴍𐴞 𐴑𐴡𐴓𐴡𐴎',
    '🦸' => '𐴏𐴟𐴂𐴥𐴝𐴌 𐴇𐴥𐴞𐴌𐴟',
    '🦹' => '𐴏𐴟𐴂𐴥𐴝𐴌 𐴁𐴞𐴓𐴥𐴝𐴕',
    '🧙' => '𐴅𐴝𐴊𐴟',
    '🧚' => '𐴑𐴤𐴞𐴘𐴝𐴓𐴞 𐴉𐴡𐴌𐴞',
    '🧛' => '𐴓𐴡𐴖 𐴉𐴞𐴘𐴡𐴙𐴕𐴧𐴝',
    '🧜' => '𐴔𐴠𐴌𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧝' => '𐴁𐴤𐴟𐴃𐴢 𐴉𐴠𐴌𐴡𐴃𐴢',
    '🧞' => '𐴅𐴞𐴕',
    '🧟' => '𐴎𐴤𐴟𐴔𐴁𐴞',
    '🧌' => '𐴄𐴡𐴌𐴥𐴟𐴓',
    '💆' => '𐴔𐴝𐴎𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '💇' => '𐴏𐴟𐴓 𐴈𐴝𐴍𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🚶' => '𐴀𐴥𐴝𐴣𐴍𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧍' => '𐴃𐴤𐴞𐴘𐴝𐴘𐴧𐴥𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧎' => '𐴀𐴝𐴣𐴍𐴥𐴟𐴃𐴢 𐴁𐴤𐴡𐴌𐴊𐴧𐴞𐴘𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🏃' => '𐴊𐴦𐴟𐴣𐴌𐴠𐴌𐴊𐴧𐴠 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '💃' => '𐴕𐴝𐴏𐴢 𐴖𐴝𐴓𐴞',
    '🕺' => '𐴕𐴝𐴄𐴧𐴗𐴝',
    '🕴' => '𐴓𐴝𐴁𐴝𐴏𐴢 𐴉𐴞𐴕𐴊𐴤𐴝 𐴈𐴝𐴌𐴁𐴝𐴌𐴞 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👯' => '𐴈𐴥𐴡𐴌𐴒𐴟𐴐𐴢 𐴈𐴝𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧖' => '𐴁𐴤𐴝𐴉𐴢 𐴀𐴡𐴓𐴝 𐴑𐴝𐴔𐴌𐴝𐴌 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧗' => '𐴓𐴡𐴄𐴑𐴞 𐴀𐴟𐴍𐴥𐴠𐴌𐴊𐴧𐴠 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤺' => '𐴃𐴡𐴓𐴖𐴝𐴌 𐴁𐴝𐴎 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🏇' => '𐴒𐴤𐴟𐴣𐴌 𐴊𐴧𐴦𐴟𐴣𐴌',
    '⛷' => '𐴁𐴡𐴌𐴥𐴡𐴉𐴡𐴃𐴢 𐴏𐴡𐴏𐴧𐴡𐴌𐴡𐴙𐴕𐴧𐴝',
    '🏂' => '𐴏𐴡𐴏𐴧𐴡𐴌𐴝𐴕𐴞',
    '🏌' => '𐴒𐴤𐴡𐴓𐴉𐴢 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🏄' => '𐴉𐴝𐴕𐴥𐴞𐴃𐴢 𐴏𐴡𐴏𐴧𐴡𐴌𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🚣' => '𐴕𐴦𐴡 𐴁𐴝𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🏊' => '𐴀𐴥𐴝𐴣𐴏𐴟𐴌𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '⛹' => '𐴉𐴥𐴝𐴓𐴊𐴝𐴕𐴞 𐴁𐴡𐴀𐴡𐴓 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🏋' => '𐴀𐴟𐴎𐴤𐴡𐴕 𐴃𐴟𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🚴' => '𐴏𐴝𐴙𐴌𐴑𐴤𐴠𐴓 𐴏𐴝𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🚵' => '𐴉𐴝𐴀𐴝𐴌𐴡𐴃𐴢 𐴏𐴝𐴙𐴌𐴑𐴤𐴠𐴓 𐴏𐴝𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤸' => '𐴑𐴝𐴄𐴖𐴥𐴠𐴓 𐴒𐴡𐴌𐴥𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤼' => '𐴑𐴟𐴏𐴥𐴞 𐴊𐴤𐴡𐴌𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢 𐴀𐴥𐴡𐴑𐴧𐴡𐴓',
    '🤽' => '𐴉𐴝𐴕𐴥𐴞𐴃𐴢 𐴁𐴡𐴀𐴡𐴓 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤾' => '𐴇𐴥𐴝𐴃𐴢 𐴁𐴡𐴀𐴡𐴓 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🤹' => '𐴅𐴝𐴒𐴓𐴞𐴚 𐴑𐴤𐴠𐴓𐴡𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🧘' => '𐴓𐴥𐴠𐴂𐴧𐴝𐴍𐴞 𐴁𐴡𐴙𐴐𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🛀' => '𐴒𐴝𐴀𐴝 𐴊𐴤𐴟𐴖𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '🛌' => '𐴕𐴠𐴙𐴄𐴧𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢',
    '👭' => '𐴇𐴥𐴝𐴃𐴠 𐴇𐴥𐴝𐴃𐴠 𐴊𐴤𐴡𐴙𐴅𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴞𐴘𐴥𐴝𐴙𐴕',
    '👫' => '𐴁𐴠𐴍𐴝 𐴀𐴝𐴌 𐴁𐴠𐴍𐴞 𐴊𐴤𐴡𐴙𐴅𐴧𐴤𐴙𐴝 𐴇𐴥𐴝𐴃𐴢 𐴀𐴥𐴡𐴑𐴧𐴡𐴓',
    '👬' => '𐴇𐴥𐴝𐴃𐴠 𐴇𐴥𐴝𐴃𐴠 𐴊𐴤𐴡𐴙𐴅𐴧𐴤𐴙𐴝 𐴁𐴠𐴍𐴝𐴀𐴝𐴙𐴕',
    '💏' => '𐴀𐴝𐴂𐴧𐴥𐴗𐴝',
    '💑' => '𐴎𐴟𐴌 𐴀𐴝𐴌 𐴑𐴡𐴓𐴥𐴡𐴁𐴢',
    '🗣' => '𐴈𐴡𐴃𐴤𐴝 𐴈𐴡𐴀𐴡𐴙𐴕𐴧𐴙𐴝 𐴔𐴝𐴃𐴤𐴝',
    '👤' => '𐴔𐴟𐴃𐴧𐴞𐴌 𐴏𐴥𐴝𐴁𐴝',
    '👥' => '𐴔𐴟𐴃𐴧𐴞 𐴀𐴥𐴡𐴑𐴧𐴡𐴓𐴡𐴌 𐴏𐴥𐴝𐴁𐴝',
    '🫂' => '𐴀𐴝𐴣𐴎𐴝 𐴀𐴝𐴣𐴎𐴞 𐴒𐴡𐴙𐴅𐴧𐴤𐴙𐴝 𐴔𐴝𐴕𐴥𐴟𐴙𐴐𐴢 𐴀𐴥𐴡𐴑𐴧𐴡𐴓',
    '👪' => '𐴒𐴤𐴡𐴌 𐴒𐴟𐴐𐴧𐴞',
    '👣' => '𐴑𐴤𐴟𐴣𐴐𐴢',
    '🐵' => '𐴁𐴝𐴣𐴊𐴡𐴌 𐴔𐴟𐴑',
    '🐒' => '𐴁𐴝𐴣𐴊𐴡𐴌',
    '🦍' => '𐴒𐴟𐴌𐴞𐴓𐴝',
    '🦧' => '𐴀𐴡𐴌𐴝𐴚 𐴒𐴟𐴄𐴝𐴕',
    '🐶' => '𐴑𐴟𐴛𐴌 𐴔𐴟𐴑',
    '🐕' => '𐴑𐴟𐴛𐴌',
    '🦮' => '𐴌𐴝𐴏𐴧𐴝 𐴊𐴠𐴈𐴝𐴀𐴡𐴙𐴕𐴧𐴝 𐴑𐴟𐴛𐴌',
    '🐩' => '𐴂𐴟𐴋𐴡𐴓',
    '🐺' => '𐴌𐴝𐴚𐴑𐴟𐴛𐴌',
    '🦊' => '𐴐𐴤𐴞𐴘𐴝𐴓',
    '🦝' => '𐴌𐴝𐴑𐴟𐴕',
    '🐱' => '𐴁𐴞𐴓𐴝𐴘 𐴔𐴟𐴑',
    '🐈' => '𐴁𐴞𐴓𐴝𐴘',
    '🦁' => '𐴐𐴤𐴞𐴚𐴒𐴡',
    '🐯' => '𐴁𐴝𐴑 𐴔𐴟𐴑',
    '🐅' => '𐴁𐴝𐴑',
    '🐆' => '𐴐𐴞𐴃𐴝 𐴁𐴝𐴑',
    '🐴' => '𐴒𐴤𐴟𐴣𐴌𐴝 𐴔𐴟𐴑',
    '🫎' => '𐴁𐴝𐴌𐴥𐴡 𐴐𐴤𐴞𐴚𐴒𐴙𐴝',
    '🫏' => '𐴒𐴝𐴊𐴤𐴝',
    '🐎' => '𐴒𐴤𐴟𐴣𐴌𐴝',
    '🦄' => '𐴀𐴠𐴑 𐴐𐴤𐴞𐴚𐴒𐴙𐴝',
    '🦌' => '𐴇𐴥𐴡𐴌𐴞𐴕',
    '🦬' => '𐴎𐴦𐴡𐴣𐴓𐴞 𐴔𐴟𐴣𐴙𐴐𐴢',
    '🐮' => '𐴒𐴝𐴘 𐴒𐴡𐴌𐴟 𐴔𐴟𐴑',
    '🐂' => '𐴁𐴡𐴓𐴡𐴃𐴢 𐴒𐴡𐴌𐴟',
    '🐃' => '𐴉𐴝𐴕𐴥𐴞𐴌 𐴁𐴤𐴟𐴙𐴐𐴢',
    '🐄' => '𐴒𐴝𐴘 𐴒𐴡𐴌𐴟',
    '🐷' => '𐴐𐴤𐴟𐴖𐴡𐴌 - 𐴔𐴟𐴑',
    '🐖' => '𐴐𐴤𐴟𐴖𐴡𐴌',
    '🐗' => '𐴎𐴦𐴡𐴣𐴓𐴞 𐴐𐴤𐴟𐴖𐴡𐴌',
    '🐽' => '𐴐𐴤𐴟𐴖𐴡𐴌 𐴕𐴝𐴑',
    '🐏' => '𐴌𐴝𐴔',
    '🐑' => '𐴉𐴝𐴣𐴍𐴥𐴞 𐴁𐴤𐴠𐴌𐴝 𐴏𐴥𐴡𐴀𐴡𐴓',
    '🐐' => '𐴏𐴥𐴡𐴀𐴡𐴓',
    '🐪' => '𐴀𐴟𐴣𐴄𐴢',
    '🐫' => '𐴊𐴟𐴘 𐴐𐴟𐴙𐴄𐴧𐴝𐴓𐴞 𐴀𐴡𐴓𐴝 𐴀𐴟𐴣𐴄𐴢',
    '🦙' => '𐴓𐴝𐴓𐴝𐴔𐴝',
    '🦒' => '𐴎𐴞𐴌𐴝𐴉𐴢',
    '🐘' => '𐴇𐴥𐴝𐴣𐴃𐴞',
    '🦣' => '𐴔𐴝𐴔𐴟𐴃𐴢',
    '🦏' => '𐴀𐴠𐴑 𐴐𐴤𐴞𐴚𐴒𐴙𐴝 𐴎𐴝𐴕𐴖𐴝𐴌',
    '🦛' => '𐴉𐴝𐴕𐴥𐴞𐴌 𐴒𐴤𐴟𐴣𐴌𐴝',
    '🐭' => '𐴀𐴟𐴕𐴊𐴟𐴌 𐴔𐴟𐴑',
    '🐁' => '𐴀𐴟𐴕𐴊𐴟𐴌',
    '🐹' => '𐴇𐴥𐴝𐴔𐴏𐴄𐴝𐴌',
    '🐰' => '𐴈𐴥𐴡𐴌𐴒𐴟𐴐𐴢 𐴔𐴟𐴑',
    '🐇' => '𐴈𐴥𐴡𐴌𐴒𐴟𐴐𐴢',
    '🐿' => '𐴏𐴟𐴌𐴈𐴝𐴍𐴝',
    '🦫' => '𐴁𐴦𐴞𐴁𐴤𐴝𐴌',
    '🦔' => '𐴀𐴥𐴠𐴎𐴝',
    '🦇' => '𐴏𐴝𐴔𐴁𐴝 𐴁𐴝𐴣𐴊𐴡𐴌',
    '🐻' => '𐴁𐴤𐴝𐴓𐴧𐴟𐴑',
    '🐨' => '𐴑𐴡𐴀𐴝𐴓𐴝',
    '🐼' => '𐴈𐴥𐴝𐴕𐴋𐴝𐴏𐴢',
    '🦥' => '𐴏𐴡𐴓𐴥𐴡𐴃𐴢',
    '🦦' => '𐴀𐴟𐴙𐴃𐴢',
    '🦨' => '𐴀𐴠𐴏𐴑𐴤𐴟𐴚',
    '🦘' => '𐴑𐴝𐴚𐴒𐴟𐴌𐴟',
    '🦡' => '𐴁𐴠𐴎𐴞',
    '🐾' => '𐴄𐴤𐴠𐴚𐴡𐴌 𐴑𐴤𐴟𐴣𐴐𐴢',
    '🦃' => '𐴇𐴥𐴝𐴣𐴌𐴒𐴞𐴓𐴝',
    '🐔' => '𐴑𐴟𐴌𐴥𐴝',
    '🐓' => '𐴌𐴝𐴃𐴝 𐴑𐴟𐴌𐴥𐴝',
    '🐣' => '𐴏𐴥𐴡𐴀𐴡 𐴉𐴥𐴟𐴍𐴝𐴀𐴝𐴀𐴡𐴕',
    '🐤' => '𐴏𐴥𐴡𐴀𐴡 𐴑𐴟𐴌𐴥𐴝',
    '🐥' => '𐴔𐴟𐴀𐴟𐴔 𐴔𐴟𐴑𐴤𐴝 𐴑𐴟𐴌𐴥𐴝𐴌 𐴏𐴥𐴡𐴀𐴡',
    '🐦' => '𐴉𐴝𐴙𐴑',
    '🐧' => '𐴂𐴠𐴕𐴒𐴟𐴖𐴞𐴕',
    '🕊' => '𐴈𐴡𐴣𐴀𐴡𐴓',
    '🦅' => '𐴀𐴟𐴑𐴝𐴁𐴢',
    '🦢' => '𐴌𐴝𐴊𐴝 𐴇𐴥𐴝𐴣𐴐𐴢',
    '🦉' => '𐴉𐴠𐴣𐴏𐴝',
    '🦤' => '𐴋𐴟𐴋𐴟 𐴉𐴝𐴙𐴑',
    '🪶' => '𐴉𐴥𐴡𐴙𐴌',
    '🦩' => '𐴓𐴝𐴓 𐴔𐴝𐴃𐴤𐴝 𐴉𐴝𐴙𐴑',
    '🦚' => '𐴔𐴡𐴘𐴧𐴟𐴌',
    '🦜' => '𐴃𐴟𐴃𐴝',
    '🪽' => '𐴉𐴝𐴑',
    '🪿' => '𐴇𐴥𐴝𐴣𐴐𐴢',
    '🐸' => '𐴁𐴠𐴚',
    '🐊' => '𐴑𐴟𐴣𐴀𐴟𐴛𐴌',
    '🐢' => '𐴈𐴡𐴏𐴧𐴡𐴂𐴢',
    '🦎' => '𐴄𐴟𐴄𐴧𐴟𐴘',
    '🐍' => '𐴇𐴥𐴝𐴉𐴢',
    '🐲' => '𐴋𐴠𐴌𐴝𐴒𐴟𐴕 𐴔𐴟𐴑',
    '🐉' => '𐴋𐴠𐴌𐴝𐴒𐴟𐴕',
    '🦕' => '𐴏𐴝𐴌𐴡𐴂𐴡𐴋',
    '🦖' => '𐴄𐴞𐴌𐴥𐴞𐴑𐴏𐴢',
    '🐳' => '𐴉𐴥𐴟𐴖𐴥𐴝𐴌𐴝 𐴁𐴝𐴕𐴝𐴀𐴡𐴙𐴕𐴧𐴝 𐴔𐴝𐴏𐴢',
    '🐋' => '𐴏𐴥𐴟𐴏𐴟𐴔 𐴔𐴝𐴏𐴢',
    '🐬' => '𐴋𐴡𐴓𐴉𐴞𐴕',
    '🦭' => '𐴏𐴦𐴞𐴓',
    '🐟' => '𐴔𐴝𐴏𐴢',
    '🐠' => '𐴒𐴡𐴌𐴡𐴔 𐴊𐴠𐴐𐴤𐴡𐴌 𐴔𐴝𐴏𐴢',
    '🐡' => '𐴉𐴟𐴄𐴑𐴝',
    '🦈' => '𐴀𐴥𐴡𐴣𐴗𐴏𐴢',
    '🐙' => '𐴕𐴟𐴙𐴕𐴧𐴝',
    '🐚' => '𐴏𐴥𐴞𐴓𐴡𐴙𐴕',
    '🪸' => '𐴔𐴟𐴚𐴒𐴝',
    '🪼' => '𐴏𐴥𐴝𐴃𐴞 𐴕𐴟𐴙𐴕𐴧𐴝',
    '🐌' => '𐴓𐴠𐴎𐴝',
    '🦋' => '𐴈𐴡𐴊𐴧𐴝 𐴉𐴟𐴃𐴞',
    '🐛' => '𐴁𐴟𐴑',
    '🐜' => '𐴉𐴞𐴛𐴥𐴝𐴌𐴝',
    '🐝' => '𐴔𐴡𐴊𐴤𐴟 𐴉𐴟𐴑',
    '🪲' => '𐴒𐴟𐴖𐴡𐴙𐴅𐴧𐴙𐴝 𐴉𐴟𐴑',
    '🐞' => '𐴁𐴤𐴡𐴣𐴌𐴝',
    '🦗' => '𐴉𐴥𐴟𐴣𐴖𐴥𐴝𐴣',
    '🪳' => '𐴃𐴠𐴙𐴓𐴧𐴝 𐴏𐴟𐴌𐴝',
    '🕷' => '𐴔𐴦𐴡𐴣𐴐𐴧𐴝',
    '🕸' => '𐴔𐴦𐴡𐴣𐴐𐴧𐴝𐴌 𐴎𐴝𐴓',
    '🦂' => '𐴁𐴞𐴏𐴧𐴥𐴟',
    '🦟' => '𐴔𐴟𐴆𐴤𐴝',
    '🪰' => '𐴔𐴝𐴏𐴥𐴞',
    '🪱' => '𐴏𐴞𐴌',
    '🦠' => '𐴁𐴞𐴘𐴝𐴌𐴝𐴔𐴡𐴌 𐴉𐴟𐴑',
    '💐' => '𐴉𐴥𐴟𐴓𐴡𐴌 𐴁𐴟𐴣𐴊𐴝',
    '🌸' => '𐴆𐴠𐴌𐴞 𐴉𐴥𐴟𐴓',
    '💮' => '𐴊𐴤𐴡𐴓𐴝 𐴉𐴥𐴟𐴓',
    '🪷' => '𐴇𐴥𐴡𐴣𐴓𐴝 𐴉𐴥𐴟𐴓',
    '🏵' => '𐴒𐴟𐴓𐴝𐴁𐴞 𐴕𐴡𐴑𐴐𐴤𐴡',
    '🌹' => '𐴒𐴟𐴓𐴝𐴁𐴢 𐴉𐴥𐴟𐴓',
    '🥀' => '𐴔𐴡𐴙𐴎𐴧𐴙𐴝 𐴉𐴥𐴟𐴓',
    '🌺' => '𐴌𐴡𐴚 𐴁𐴡𐴌𐴡𐴚 𐴉𐴥𐴟𐴓',
    '🌻' => '𐴏𐴥𐴟𐴅𐴧𐴡 𐴔𐴟𐴑𐴤𐴞 𐴉𐴥𐴟𐴓',
    '🌼' => '𐴈𐴡𐴓𐴞',
    '🌷' => '𐴃𐴡𐴖𐴓𐴞𐴂𐴢 𐴉𐴥𐴟𐴓',
    '🪻' => '𐴘𐴝𐴑𐴟𐴃𐴞 𐴉𐴥𐴟𐴓',
    '🌱' => '𐴊𐴝𐴕𐴝 𐴉𐴥𐴟𐴍𐴝𐴀𐴡𐴕',
    '🪴' => '𐴉𐴡𐴍𐴡𐴃𐴢 𐴓𐴝𐴒𐴝𐴘𐴧𐴝 𐴏𐴝𐴌𐴝',
    '🌲' => '𐴕𐴞𐴃𐴧𐴞 𐴇𐴥𐴝𐴙𐴓 𐴒𐴝𐴏𐴢',
    '🌳' => '𐴉𐴝𐴃𐴝 𐴎𐴤𐴡𐴌𐴝 𐴒𐴝𐴏𐴢',
    '🌴' => '𐴈𐴥𐴝𐴎𐴟 𐴒𐴝𐴏𐴢',
    '🌵' => '𐴕𐴝𐴑𐴉𐴡𐴕𐴞 𐴒𐴝𐴏𐴢',
    '🌾' => '𐴊𐴤𐴝𐴕𐴡𐴌 𐴏𐴥𐴡𐴌𐴝',
    '🌿' => '𐴓𐴡𐴃𐴝 𐴒𐴝𐴏𐴢',
    '☘' => '𐴐𐴤𐴝𐴔𐴟𐴌𐴟𐴑',
    '🍀' => '𐴏𐴝𐴙𐴌 𐴉𐴝𐴃𐴝 𐴀𐴡𐴓𐴝 𐴒𐴝𐴏𐴢',
    '🍁' => '𐴔𐴟𐴙𐴕𐴧𐴝 𐴉𐴝𐴃𐴝 𐴀𐴡𐴓𐴝 𐴒𐴝𐴏𐴢',
    '🍂' => '𐴎𐴤𐴡𐴙𐴅𐴧𐴙𐴝 𐴉𐴝𐴃𐴝',
    '🍃' => '𐴁𐴡𐴘𐴧𐴝𐴌𐴠 𐴀𐴟𐴌𐴠𐴌𐴊𐴧𐴠 𐴉𐴝𐴃𐴝',
    '🪹' => '𐴈𐴥𐴝𐴓𐴞 𐴁𐴝𐴈𐴥𐴝',
    '🪺' => '𐴀𐴝𐴕𐴋𐴝 𐴀𐴡𐴓𐴝 𐴁𐴝𐴈𐴥𐴝',
    '🍄' => '𐴀𐴟𐴓',
    '🍇' => '𐴀𐴝𐴚𐴒𐴟𐴌',
    '🍈' => '𐴈𐴥𐴡𐴌𐴁𐴟𐴎𐴝',
    '🍉' => '𐴃𐴡𐴌𐴔𐴟𐴏𐴢',
    '🍊' => '𐴐𐴤𐴡𐴣𐴍𐴡 𐴈𐴦𐴡𐴣𐴓𐴝',
    '🍋' => '𐴓𐴠𐴔𐴟',
    '🍌' => '𐴑𐴠𐴓𐴝',
    '🍍' => '𐴀𐴠𐴕𐴦𐴝𐴐𐴢',
    '🥭' => '𐴀𐴝𐴔',
    '🍎' => '𐴓𐴝𐴓 𐴏𐴥𐴠𐴂𐴢',
    '🍏' => '𐴇𐴥𐴝𐴙𐴓 𐴏𐴥𐴠𐴂𐴢',
    '🍐' => '𐴕𐴝𐴐𐴉𐴡𐴃𐴞',
    '🍑' => '𐴔𐴥𐴝𐴔𐴟𐴕 𐴒𐴟𐴓𐴝',
    '🍒' => '𐴆𐴦𐴠𐴌𐴞',
    '🍓' => '𐴀𐴠𐴏𐴄𐴡𐴌𐴡 𐴁𐴝𐴌𐴞',
    '🫐' => '𐴁𐴟𐴓𐴟 𐴁𐴦𐴠𐴌𐴞',
    '🥝' => '𐴑𐴦𐴞𐴖𐴞 𐴒𐴟𐴓𐴝',
    '🍅' => '𐴄𐴝𐴘𐴧𐴡𐴕',
    '🫒' => '𐴎𐴝𐴘𐴃𐴟𐴕',
    '🥥' => '𐴕𐴝𐴙𐴅𐴧𐴡𐴓',
    '🥑' => '𐴍𐴝𐴚𐴈𐴥𐴝𐴆',
    '🍆' => '𐴁𐴝𐴘𐴧𐴡𐴕',
    '🥔' => '𐴀𐴝𐴓𐴟',
    '🥕' => '𐴒𐴝𐴎𐴡𐴌',
    '🌽' => '𐴔𐴡𐴑𐴧𐴝 𐴒𐴟𐴓𐴝𐴌 𐴁𐴝𐴈𐴡𐴓',
    '🌶' => '𐴎𐴤𐴝𐴓 𐴔𐴡𐴌𐴞𐴏𐴢',
    '🫑' => '𐴋𐴤𐴟𐴌𐴝 𐴔𐴡𐴌𐴞𐴏𐴢',
    '🥒' => '𐴉𐴥𐴡𐴓',
    '🥬' => '𐴇𐴥𐴝𐴙𐴓 𐴉𐴝𐴃𐴝 𐴀𐴡𐴓𐴝',
    '🥦' => '𐴉𐴥𐴟𐴓 𐴈𐴡𐴂𐴧𐴞',
    '🧄' => '𐴌𐴦𐴡𐴗𐴕',
    '🧅' => '𐴉𐴞𐴛𐴝𐴏𐴢',
    '🥜' => '𐴁𐴝𐴊𐴝𐴔',
    '🫘' => '𐴊𐴝𐴕𐴝 𐴀𐴥𐴡𐴑𐴧𐴡𐴓',
    '🌰' => '𐴑𐴟𐴏𐴃𐴝𐴕𐴝',
    '🫚' => '𐴀𐴝𐴊𐴝',
    '🫛' => '𐴏𐴥𐴡𐴛',
];
