<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Андорска песета',
        ],
        'AED' => [
            'AED',
            'Дирхам на Обединените арабски емирства',
        ],
        'AFA' => [
            'AFA',
            'Афганистански афган (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'Афганистански афган',
        ],
        'ALL' => [
            'ALL',
            'Албански лек',
        ],
        'AMD' => [
            'AMD',
            'Арменски драм',
        ],
        'ANG' => [
            'ANG',
            'Антилски гулден',
        ],
        'AOA' => [
            'AOA',
            'Анголска кванза',
        ],
        'AOK' => [
            'AOK',
            'Анголска кванца (1977–1990)',
        ],
        'AON' => [
            'AON',
            'Анголска нова кванца (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Анголска нова кванца (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Аржентински австрал',
        ],
        'ARP' => [
            'ARP',
            'Аржентинско песо (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'Аржентинско песо',
        ],
        'ATS' => [
            'ATS',
            'Австрийски шилинг',
        ],
        'AUD' => [
            'AUD',
            'Австралийски долар',
        ],
        'AWG' => [
            'AWG',
            'Арубски флорин',
        ],
        'AZM' => [
            'AZM',
            'Азербайджански манат (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'Азербайджански манат',
        ],
        'BAD' => [
            'BAD',
            'Босна и Херцеговина-динар',
        ],
        'BAM' => [
            'BAM',
            'Босненска конвертируема марка',
        ],
        'BBD' => [
            'BBD',
            'Барбадоски долар',
        ],
        'BDT' => [
            'BDT',
            'Бангладешка така',
        ],
        'BEC' => [
            'BEC',
            'Белгийски франк (конвертируем)',
        ],
        'BEF' => [
            'BEF',
            'Белгийски франк',
        ],
        'BEL' => [
            'BEL',
            'Белгийски франк (финансов)',
        ],
        'BGL' => [
            'BGL',
            'Български конвертируем лев (1962–1999)',
        ],
        'BGN' => [
            'лв.',
            'Български лев',
        ],
        'BHD' => [
            'BHD',
            'Бахрейнски динар',
        ],
        'BIF' => [
            'BIF',
            'Бурундийски франк',
        ],
        'BMD' => [
            'BMD',
            'Бермудски долар',
        ],
        'BND' => [
            'BND',
            'Брунейски долар',
        ],
        'BOB' => [
            'BOB',
            'Боливийско боливиано',
        ],
        'BOP' => [
            'BOP',
            'Боливийско песо',
        ],
        'BOV' => [
            'BOV',
            'Боливийски мвдол',
        ],
        'BRB' => [
            'BRB',
            'Бразилско ново крузейро (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Бразилско крозадо',
        ],
        'BRE' => [
            'BRE',
            'Бразилско крузейро (1990–1993)',
        ],
        'BRL' => [
            'BRL',
            'Бразилски реал',
        ],
        'BRN' => [
            'BRN',
            'Бразилско ново крозадо',
        ],
        'BRR' => [
            'BRR',
            'Бразилско крузейро',
        ],
        'BSD' => [
            'BSD',
            'Бахамски долар',
        ],
        'BTN' => [
            'BTN',
            'Бутански нгултрум',
        ],
        'BUK' => [
            'BUK',
            'Бирмански киат',
        ],
        'BWP' => [
            'BWP',
            'Ботсванска пула',
        ],
        'BYB' => [
            'BYB',
            'Беларуска нова рубла (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'Беларуска рубла',
        ],
        'BYR' => [
            'BYR',
            'Беларуска рубла (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Белизийски долар',
        ],
        'CAD' => [
            'CAD',
            'Канадски долар',
        ],
        'CDF' => [
            'CDF',
            'Конгоански франк',
        ],
        'CHE' => [
            'CHE',
            'WIR евро',
        ],
        'CHF' => [
            'CHF',
            'Швейцарски франк',
        ],
        'CHW' => [
            'CHW',
            'WIR франк',
        ],
        'CLF' => [
            'CLF',
            'Условна разчетна единица на Чили',
        ],
        'CLP' => [
            'CLP',
            'Чилийско песо',
        ],
        'CNH' => [
            'CNH',
            'Китайски юан (офшорен)',
        ],
        'CNY' => [
            'CNY',
            'Китайски юан',
        ],
        'COP' => [
            'COP',
            'Колумбийско песо',
        ],
        'COU' => [
            'COU',
            'Колумбийска единица на реалната стойност',
        ],
        'CRC' => [
            'CRC',
            'Костарикански колон',
        ],
        'CSD' => [
            'CSD',
            'Стар сръбски динар',
        ],
        'CSK' => [
            'CSK',
            'Чехословашка конвертируема крона',
        ],
        'CUC' => [
            'CUC',
            'Кубинско конвертируемо песо',
        ],
        'CUP' => [
            'CUP',
            'Кубинско песо',
        ],
        'CVE' => [
            'CVE',
            'Ескудо на Кабо Верде',
        ],
        'CYP' => [
            'CYP',
            'Кипърска лира',
        ],
        'CZK' => [
            'CZK',
            'Чешка крона',
        ],
        'DDM' => [
            'DDM',
            'Източногерманска марка',
        ],
        'DEM' => [
            'DEM',
            'Германска марка',
        ],
        'DJF' => [
            'DJF',
            'Джибутски франк',
        ],
        'DKK' => [
            'DKK',
            'Датска крона',
        ],
        'DOP' => [
            'DOP',
            'Доминиканско песо',
        ],
        'DZD' => [
            'DZD',
            'Алжирски динар',
        ],
        'ECS' => [
            'ECS',
            'Еквадорско сукре',
        ],
        'ECV' => [
            'ECV',
            'Еквадорска банкова единица',
        ],
        'EEK' => [
            'EEK',
            'Естонска крона',
        ],
        'EGP' => [
            'EGP',
            'Египетска лира',
        ],
        'ERN' => [
            'ERN',
            'Еритрейска накфа',
        ],
        'ESP' => [
            'ESP',
            'Испанска песета',
        ],
        'ETB' => [
            'ETB',
            'Етиопски бир',
        ],
        'EUR' => [
            '€',
            'Евро',
        ],
        'FIM' => [
            'FIM',
            'Финландска марка',
        ],
        'FJD' => [
            'FJD',
            'Фиджийски долар',
        ],
        'FKP' => [
            'FKP',
            'Фолкландска лира',
        ],
        'FRF' => [
            'FRF',
            'Френски франк',
        ],
        'GBP' => [
            'GBP',
            'Британска лира',
        ],
        'GEK' => [
            'GEK',
            'Грузински купон',
        ],
        'GEL' => [
            'GEL',
            'Грузински лари',
        ],
        'GHC' => [
            'GHC',
            'Ганайско седи (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'Ганайско седи',
        ],
        'GIP' => [
            'GIP',
            'Гибралтарска лира',
        ],
        'GMD' => [
            'GMD',
            'Гамбийско даласи',
        ],
        'GNF' => [
            'GNF',
            'Гвинейски франк',
        ],
        'GNS' => [
            'GNS',
            'Гвинейска сили',
        ],
        'GQE' => [
            'GQE',
            'Екваториално гвинейско еквеле',
        ],
        'GRD' => [
            'GRD',
            'Гръцка драхма',
        ],
        'GTQ' => [
            'GTQ',
            'Гватемалски кетцал',
        ],
        'GWE' => [
            'GWE',
            'Ескудо от Португалска Гвинея',
        ],
        'GWP' => [
            'GWP',
            'Гвинея-Бисау песо',
        ],
        'GYD' => [
            'GYD',
            'Гаянски долар',
        ],
        'HKD' => [
            'HKD',
            'Хонконгски долар',
        ],
        'HNL' => [
            'HNL',
            'Хондураска лемпира',
        ],
        'HRD' => [
            'HRD',
            'Хърватски динар',
        ],
        'HRK' => [
            'HRK',
            'Хърватска куна',
        ],
        'HTG' => [
            'HTG',
            'Хаитски гурд',
        ],
        'HUF' => [
            'HUF',
            'Унгарски форинт',
        ],
        'IDR' => [
            'IDR',
            'Индонезийска рупия',
        ],
        'IEP' => [
            'IEP',
            'Ирландска лира',
        ],
        'ILP' => [
            'ILP',
            'Израелска лира',
        ],
        'ILS' => [
            'ILS',
            'Израелски нов шекел',
        ],
        'INR' => [
            'INR',
            'Индийска рупия',
        ],
        'IQD' => [
            'IQD',
            'Иракски динар',
        ],
        'IRR' => [
            'IRR',
            'Ирански риал',
        ],
        'ISK' => [
            'ISK',
            'Исландска крона',
        ],
        'ITL' => [
            'ITL',
            'Италианска лира',
        ],
        'JMD' => [
            'JMD',
            'Ямайски долар',
        ],
        'JOD' => [
            'JOD',
            'Йордански динар',
        ],
        'JPY' => [
            'JPY',
            'Японска йена',
        ],
        'KES' => [
            'KES',
            'Кенийски шилинг',
        ],
        'KGS' => [
            'KGS',
            'Киргизстански сом',
        ],
        'KHR' => [
            'KHR',
            'Камбоджански риел',
        ],
        'KMF' => [
            'KMF',
            'Коморски франк',
        ],
        'KPW' => [
            'KPW',
            'Севернокорейски вон',
        ],
        'KRW' => [
            'KRW',
            'Южнокорейски вон',
        ],
        'KWD' => [
            'KWD',
            'Кувейтски динар',
        ],
        'KYD' => [
            'KYD',
            'Кайманов долар',
        ],
        'KZT' => [
            'KZT',
            'Казахстанско тенге',
        ],
        'LAK' => [
            'LAK',
            'Лаоски кип',
        ],
        'LBP' => [
            'LBP',
            'Ливанска лира',
        ],
        'LKR' => [
            'LKR',
            'Шриланкска рупия',
        ],
        'LRD' => [
            'LRD',
            'Либерийски долар',
        ],
        'LSL' => [
            'LSL',
            'Лесотско лоти',
        ],
        'LTL' => [
            'LTL',
            'Литовски литас',
        ],
        'LTT' => [
            'LTT',
            'Литовски талон',
        ],
        'LUF' => [
            'LUF',
            'Люксембургски франк',
        ],
        'LVL' => [
            'LVL',
            'Латвийски лат',
        ],
        'LVR' => [
            'LVR',
            'Латвийска рубла',
        ],
        'LYD' => [
            'LYD',
            'Либийски динар',
        ],
        'MAD' => [
            'MAD',
            'Марокански дирхам',
        ],
        'MAF' => [
            'MAF',
            'Марокански франк',
        ],
        'MDL' => [
            'MDL',
            'Молдовска лея',
        ],
        'MGA' => [
            'MGA',
            'Малгашко ариари',
        ],
        'MGF' => [
            'MGF',
            'Малгашки франк - Мадагаскар',
        ],
        'MKD' => [
            'MKD',
            'Македонски денар',
        ],
        'MLF' => [
            'MLF',
            'Малийски франк',
        ],
        'MMK' => [
            'MMK',
            'Мианмарски киат',
        ],
        'MNT' => [
            'MNT',
            'Монголски тугрик',
        ],
        'MOP' => [
            'MOP',
            'Патака на Макао',
        ],
        'MRO' => [
            'MRO',
            'Мавританска угия (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Мавританска угия',
        ],
        'MTL' => [
            'MTL',
            'Малтийска лира',
        ],
        'MUR' => [
            'MUR',
            'Маврицийска рупия',
        ],
        'MVR' => [
            'MVR',
            'Малдивска руфия',
        ],
        'MWK' => [
            'MWK',
            'Малавийска куача',
        ],
        'MXN' => [
            'MXN',
            'Мексиканско песо',
        ],
        'MXP' => [
            'MXP',
            'Мексиканско сребърно песо (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Мексиканска конвертируема единица (UDI)',
        ],
        'MYR' => [
            'MYR',
            'Малайзийски рингит',
        ],
        'MZE' => [
            'MZE',
            'Мозамбикско ескудо',
        ],
        'MZM' => [
            'MZM',
            'Мозамбикски метикал (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'Мозамбикски метикал',
        ],
        'NAD' => [
            'NAD',
            'Намибийски долар',
        ],
        'NGN' => [
            'NGN',
            'Нигерийска найра',
        ],
        'NIC' => [
            'NIC',
            'Никарагуанска кордоба (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'Никарагуанска кордоба',
        ],
        'NLG' => [
            'NLG',
            'Холандски гулден',
        ],
        'NOK' => [
            'NOK',
            'Норвежка крона',
        ],
        'NPR' => [
            'NPR',
            'Непалска рупия',
        ],
        'NZD' => [
            'NZD',
            'Новозеландски долар',
        ],
        'OMR' => [
            'OMR',
            'Омански риал',
        ],
        'PAB' => [
            'PAB',
            'Панамска балбоа',
        ],
        'PEI' => [
            'PEI',
            'Перуанско инти',
        ],
        'PEN' => [
            'PEN',
            'Перуански сол',
        ],
        'PES' => [
            'PES',
            'Перуански сол (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'Папуа-новогвинейска кина',
        ],
        'PHP' => [
            'PHP',
            'Филипинско песо',
        ],
        'PKR' => [
            'PKR',
            'Пакистанска рупия',
        ],
        'PLN' => [
            'PLN',
            'Полска злота',
        ],
        'PLZ' => [
            'PLZ',
            'Полска злота (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'Португалско ескудо',
        ],
        'PYG' => [
            'PYG',
            'Парагвайско гуарани',
        ],
        'QAR' => [
            'QAR',
            'Катарски риал',
        ],
        'RHD' => [
            'RHD',
            'Родезийски долар',
        ],
        'ROL' => [
            'ROL',
            'Стара румънска лея',
        ],
        'RON' => [
            'RON',
            'Румънска лея',
        ],
        'RSD' => [
            'RSD',
            'Сръбски динар',
        ],
        'RUB' => [
            'RUB',
            'Руска рубла',
        ],
        'RUR' => [
            'RUR',
            'Руска рубла (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'Руандски франк',
        ],
        'SAR' => [
            'SAR',
            'саудитски риал',
        ],
        'SBD' => [
            'SBD',
            'Долар на Соломоновите острови',
        ],
        'SCR' => [
            'SCR',
            'Сейшелска рупия',
        ],
        'SDD' => [
            'SDD',
            'Судански динар',
        ],
        'SDG' => [
            'SDG',
            'Суданска лира',
        ],
        'SEK' => [
            'SEK',
            'Шведска крона',
        ],
        'SGD' => [
            'SGD',
            'Сингапурски долар',
        ],
        'SHP' => [
            'SHP',
            'Лира на Света Елена',
        ],
        'SIT' => [
            'SIT',
            'Словенски толар',
        ],
        'SKK' => [
            'SKK',
            'Словашка крона',
        ],
        'SLE' => [
            'SLE',
            'Сиералеонско леоне',
        ],
        'SLL' => [
            'SLL',
            'Сиералеонско леоне (1964 – 2022)',
        ],
        'SOS' => [
            'SOS',
            'Сомалийски шилинг',
        ],
        'SRD' => [
            'SRD',
            'Суринамски долар',
        ],
        'SRG' => [
            'SRG',
            'Суринамски гилдер',
        ],
        'SSP' => [
            'SSP',
            'Южносуданска лира',
        ],
        'STD' => [
            'STD',
            'Добра на Сао Томе и Принсипи (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Добра на Сао Томе и Принсипи',
        ],
        'SUR' => [
            'SUR',
            'Съветска рубла',
        ],
        'SVC' => [
            'SVC',
            'Салвадорски колон',
        ],
        'SYP' => [
            'SYP',
            'Сирийска лира',
        ],
        'SZL' => [
            'SZL',
            'Свазилендски лилангени',
        ],
        'THB' => [
            'THB',
            'Тайландски бат',
        ],
        'TJR' => [
            'TJR',
            'Таджикистанска рубла',
        ],
        'TJS' => [
            'TJS',
            'Таджикистански сомони',
        ],
        'TMM' => [
            'TMM',
            'Туркменистански манат',
        ],
        'TMT' => [
            'TMT',
            'Туркменски манат',
        ],
        'TND' => [
            'TND',
            'Тунизийски динар',
        ],
        'TOP' => [
            'TOP',
            'Тонганска паанга',
        ],
        'TPE' => [
            'TPE',
            'Тиморско ескудо',
        ],
        'TRL' => [
            'TRL',
            'Турска лира (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'Турска лира',
        ],
        'TTD' => [
            'TTD',
            'Долар на Тринидад и Тобаго',
        ],
        'TWD' => [
            'TWD',
            'Тайвански долар',
        ],
        'TZS' => [
            'TZS',
            'Танзанийски шилинг',
        ],
        'UAH' => [
            'UAH',
            'Украинска гривня',
        ],
        'UAK' => [
            'UAK',
            'Украински карбованец',
        ],
        'UGS' => [
            'UGS',
            'Угандийски шилинг (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'Угандски шилинг',
        ],
        'USD' => [
            'щ.д.',
            'Щатски долар',
        ],
        'UYI' => [
            'UYI',
            'Уругвайско песо (индекс на инфлацията)',
        ],
        'UYP' => [
            'UYP',
            'Уругвайско песо (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'Уругвайско песо',
        ],
        'UZS' => [
            'UZS',
            'Узбекски сум',
        ],
        'VEB' => [
            'VEB',
            'Венецуелски боливар (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'Венецуелски боливар',
        ],
        'VES' => [
            'VES',
            'Венецуелски боливар (VES)',
        ],
        'VND' => [
            'VND',
            'Виетнамски донг',
        ],
        'VUV' => [
            'VUV',
            'Вануатско вату',
        ],
        'WST' => [
            'WST',
            'Самоанска тала',
        ],
        'XAF' => [
            'FCFA',
            'Централноафрикански франк',
        ],
        'XCD' => [
            'XCD',
            'Източнокарибски долар',
        ],
        'XCG' => [
            'Cg.',
            'Карибски гулден',
        ],
        'XEU' => [
            'XEU',
            'Еку на ЕИО',
        ],
        'XFO' => [
            'XFO',
            'Френски златен франк',
        ],
        'XOF' => [
            'F CFA',
            'Западноафрикански франк',
        ],
        'XPF' => [
            'CFPF',
            'CFP франк',
        ],
        'YDD' => [
            'YDD',
            'Йеменски динар',
        ],
        'YER' => [
            'YER',
            'Йеменски риал',
        ],
        'YUD' => [
            'YUD',
            'Югославски твърд динар',
        ],
        'YUM' => [
            'YUM',
            'Югославски динар',
        ],
        'YUN' => [
            'YUN',
            'Югославски конвертируем динар',
        ],
        'ZAL' => [
            'ZAL',
            'Южноафрикански ранд (финансов)',
        ],
        'ZAR' => [
            'ZAR',
            'Южноафрикански ранд',
        ],
        'ZMK' => [
            'ZMK',
            'Замбийска квача (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Замбийска куача',
        ],
        'ZRN' => [
            'ZRN',
            'Заирско ново зайре',
        ],
        'ZRZ' => [
            'ZRZ',
            'Заирско зайре',
        ],
        'ZWD' => [
            'ZWD',
            'Зимбабвийски долар',
        ],
        'ZWG' => [
            'ZWG',
            'Зимбабвийско злато',
        ],
        'ZWL' => [
            'ZWL',
            'Зимбабвийски долар (2009)',
        ],
    ],
];
