<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Ɛmirete Arab Nkabɔmu Deram',
        ],
        'AFN' => [
            'AFN',
            'Afghanfoɔ Afghani',
        ],
        'ALL' => [
            'ALL',
            'Albania Lek',
        ],
        'AMD' => [
            'AMD',
            'Amɛnia dram',
        ],
        'ANG' => [
            'ANG',
            'Nɛdɛlande Antɛlia guuda',
        ],
        'AOA' => [
            'AOA',
            'Angola Kwanza',
        ],
        'ARS' => [
            'ARS',
            'Agɛntina peso',
        ],
        'AUD' => [
            'A$',
            'Ɔstrelia Dɔla',
        ],
        'AWG' => [
            'AWG',
            'Aruba flɔrin',
        ],
        'AZN' => [
            'AZN',
            'Azɛbagyan manat',
        ],
        'BAM' => [
            'BAM',
            'Bɔsnia-Hɛzegɔvina nsesa maake',
        ],
        'BBD' => [
            'BBD',
            'Babadɔso dɔla',
        ],
        'BDT' => [
            'BDT',
            'Bangladehye taka',
        ],
        'BGN' => [
            'BGN',
            'Bɔɔgaria lɛv',
        ],
        'BHD' => [
            'BHD',
            'Baren Dina',
        ],
        'BIF' => [
            'BIF',
            'Burundi Frank',
        ],
        'BMD' => [
            'BMD',
            'Bɛɛmuda dɔla',
        ],
        'BND' => [
            'BND',
            'Brunei dɔla',
        ],
        'BOB' => [
            'BOB',
            'Bolivia boliviano',
        ],
        'BRL' => [
            'R$',
            'Brazil reale',
        ],
        'BSD' => [
            'BSD',
            'Bahama dɔla',
        ],
        'BTN' => [
            'BTN',
            'Butanfoɔ ngutrum',
        ],
        'BWP' => [
            'BWP',
            'Botswana Pula',
        ],
        'BYN' => [
            'BYN',
            'Bɛlaruhyia ruble',
        ],
        'BZD' => [
            'BZD',
            'Belize Dɔla',
        ],
        'CAD' => [
            'CA$',
            'Kanada Dɔla',
        ],
        'CDF' => [
            'CDF',
            'Kongo Frank',
        ],
        'CHF' => [
            'CHF',
            'Swiss Franc',
        ],
        'CLP' => [
            'CLP',
            'Kyili Peso',
        ],
        'CNH' => [
            'CNH',
            'kyaena yuan (offshore)',
        ],
        'CNY' => [
            'CN¥',
            'Kyaena yuan',
        ],
        'COP' => [
            'COP',
            'Kolombia peso',
        ],
        'CRC' => [
            'CRC',
            'Kɔsta Rika kɔlɔn',
        ],
        'CUC' => [
            'CUC',
            'Kuba nsesa peso',
        ],
        'CUP' => [
            'CUP',
            'Kuba peso',
        ],
        'CVE' => [
            'CVE',
            'Ɛskudo',
        ],
        'CZK' => [
            'CZK',
            'Kyɛk koruna',
        ],
        'DJF' => [
            'DJF',
            'Gyebuti Frank',
        ],
        'DKK' => [
            'DKK',
            'Danefoɔ krone',
        ],
        'DOP' => [
            'DOP',
            'Dɔmenika peso',
        ],
        'DZD' => [
            'DZD',
            'Ɔlgyeria Dina',
        ],
        'EGP' => [
            'EGP',
            'Egypt Pɔn',
        ],
        'ERN' => [
            'ERN',
            'Ɛretereya Nakfa',
        ],
        'ETB' => [
            'ETB',
            'Itiopia Bir',
        ],
        'EUR' => [
            '€',
            'yuro',
        ],
        'FJD' => [
            'FJD',
            'Figyi Dɔla',
        ],
        'FKP' => [
            'FKP',
            'Fɔkland Aelande Pɔn',
        ],
        'GBP' => [
            '£',
            'Breten Pɔn',
        ],
        'GEL' => [
            'GEL',
            'Gyɔɔgyia lari',
        ],
        'GHC' => [
            'GHC',
            'Ghana Sidi (1979–2007)',
        ],
        'GHS' => [
            'GH₵',
            'Ghana Sidi',
        ],
        'GIP' => [
            'GIP',
            'Gyebrotaa pɔn',
        ],
        'GMD' => [
            'GMD',
            'Gambia Dalasi',
        ],
        'GNF' => [
            'GNF',
            'Gini franke',
        ],
        'GNS' => [
            'GNS',
            'Gini Frank',
        ],
        'GTQ' => [
            'GTQ',
            'Guatemala kwɛtsaa',
        ],
        'GYD' => [
            'GYD',
            'Gayana dɔla',
        ],
        'HKD' => [
            'HK$',
            'Hɔnkɔn Dɔla',
        ],
        'HNL' => [
            'HNL',
            'Hɔndura lɛmpira',
        ],
        'HRK' => [
            'HRK',
            'Krohyia kuna',
        ],
        'HTG' => [
            'HTG',
            'Haiti gɔɔde',
        ],
        'HUF' => [
            'HUF',
            'Hangari fɔrint',
        ],
        'IDR' => [
            'IDR',
            'Indɔnihyia rupia',
        ],
        'ILS' => [
            '₪',
            'Israel hyekel foforɔ',
        ],
        'INR' => [
            '₹',
            'India Rupi',
        ],
        'IQD' => [
            'Irak dinaa',
            'Irak dinaa',
        ],
        'IRR' => [
            'IRR',
            'Yiranfoɔ rial',
        ],
        'ISK' => [
            'ISK',
            'Icelandfoɔ Króna',
        ],
        'JMD' => [
            'JMD',
            'Gyameka dɔla',
        ],
        'JOD' => [
            'JOD',
            'Gyɔɔdan dinaa',
        ],
        'JPY' => [
            'JP¥',
            'Gyapan Yɛn',
        ],
        'KES' => [
            'KES',
            'Kenya Hyelen',
        ],
        'KGS' => [
            'KGS',
            'Kagyɛstan som',
        ],
        'KHR' => [
            'KHR',
            'Kambodia riel',
        ],
        'KMF' => [
            'KMF',
            'Komoro Frank',
        ],
        'KPW' => [
            'KPW',
            'Korea Atifi won',
        ],
        'KRW' => [
            '₩',
            'Korea Anaafoɔ won',
        ],
        'KWD' => [
            'KWD',
            'Kuwait dinaa',
        ],
        'KYD' => [
            'KYD',
            'Kayemanfo Aelande dɔla',
        ],
        'KZT' => [
            'KZT',
            'Kagyastan tenge',
        ],
        'LAK' => [
            'LAK',
            'Laohyia kip',
        ],
        'LBP' => [
            'LBP',
            'Lɛbanon pɔn',
        ],
        'LKR' => [
            'LKR',
            'Sri Lankafoɔ rupee',
        ],
        'LRD' => [
            'LRD',
            'Laeberia Dɔla',
        ],
        'LSL' => [
            'LSL',
            'Lesoto Loti',
        ],
        'LYD' => [
            'LYD',
            'Libya Dina',
        ],
        'MAD' => [
            'MAD',
            'Moroko Diram',
        ],
        'MDL' => [
            'MDL',
            'Moldova Leu',
        ],
        'MGA' => [
            'MGA',
            'Madagasi Frank',
        ],
        'MKD' => [
            'MKD',
            'Masidonia denaa',
        ],
        'MMK' => [
            'MMK',
            'Mayamaa kyat',
        ],
        'MNT' => [
            'MNT',
            'Mongoliafoɔ tugrike',
        ],
        'MOP' => [
            'MOP',
            'Makaw pataka',
        ],
        'MRO' => [
            'MRO',
            'Mɔretenia Ouguiya (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Mɔretenia Ouguiya',
        ],
        'MUR' => [
            'MUR',
            'Mɔrehyeɔs Rupi',
        ],
        'MVR' => [
            'MVR',
            'Maldivefoɔ rufiyaa',
        ],
        'MWK' => [
            'MWK',
            'Malawi Kwakya',
        ],
        'MXN' => [
            'MX$',
            'Mɛksiko pɛso',
        ],
        'MYR' => [
            'MYR',
            'Malaahyia ringgit',
        ],
        'MZM' => [
            'MZM',
            'Mozambik Metical',
        ],
        'MZN' => [
            'MZN',
            'Mozambik mɛtikaa',
        ],
        'NAD' => [
            'NAD',
            'Namibia Dɔla',
        ],
        'NGN' => [
            'NGN',
            'Naegyeria Naira',
        ],
        'NIO' => [
            'NIO',
            'Nikaragua kɔɔdɔba',
        ],
        'NOK' => [
            'NOK',
            'Nɔɔwee Krone',
        ],
        'NPR' => [
            'NPR',
            'Nepalfoɔ rupee',
        ],
        'NZD' => [
            'NZ$',
            'New Zealand Dɔla',
        ],
        'OMR' => [
            'OMR',
            'Oman rial',
        ],
        'PAB' => [
            'PAB',
            'Panama baaboa',
        ],
        'PEN' => [
            'PEN',
            'Pɛruvia sol',
        ],
        'PGK' => [
            'PGK',
            'Papua New Gini kina',
        ],
        'PHP' => [
            '₱',
            'Filipine peso',
        ],
        'PKR' => [
            'PKR',
            'Pakistanfoɔ rupee',
        ],
        'PLN' => [
            'PLN',
            'Pɔlihye zloty',
        ],
        'PYG' => [
            'PYG',
            'Paragayana guarani',
        ],
        'QAR' => [
            'QAR',
            'Kata riyaa',
        ],
        'RON' => [
            'RON',
            'Romania Leu',
        ],
        'RSD' => [
            'RSD',
            'Sɛɛbia dinaa',
        ],
        'RUB' => [
            'RUB',
            'Rɔhyia rubuu',
        ],
        'RWF' => [
            'RWF',
            'Rewanda Frank',
        ],
        'SAR' => [
            'SAR',
            'Saudi Riyal',
        ],
        'SBD' => [
            'SBD',
            'Solomon Aeland Dɔla',
        ],
        'SCR' => [
            'SCR',
            'Seyhyɛls Rupi',
        ],
        'SDG' => [
            'SDG',
            'Sudan Dina',
        ],
        'SDP' => [
            'SDP',
            'Sudan Pɔn',
        ],
        'SEK' => [
            'SEK',
            'Sweden Krona',
        ],
        'SGD' => [
            'SGD',
            'Singapɔɔ dɔla',
        ],
        'SHP' => [
            'SHP',
            'St Helena Pɔn',
        ],
        'SLE' => [
            'SLE',
            'Leone',
        ],
        'SLL' => [
            'SLL',
            'Leone (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Somailia Hyelen',
        ],
        'SRD' => [
            'SRD',
            'Suriname dɔla',
        ],
        'SSP' => [
            'SSP',
            'Sudan Anaafoɔ Pɔn',
        ],
        'STD' => [
            'STD',
            'Sao Tome ne Principe Dobra (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Sao Tome ne Principe Dobra',
        ],
        'SYP' => [
            'SYP',
            'Siria pɔn',
        ],
        'SZL' => [
            'SZL',
            'Swazi lilangeni',
        ],
        'THB' => [
            'THB',
            'Tai bat',
        ],
        'TJS' => [
            'TJS',
            'Tagyikistan somoni',
        ],
        'TMT' => [
            'TMT',
            'Tɛkmɛstan manat',
        ],
        'TND' => [
            'TND',
            'Tunisia Dina',
        ],
        'TOP' => [
            'TOP',
            'Tonga Paʻanga',
        ],
        'TRY' => [
            'TRY',
            'Tɛki lira',
        ],
        'TTD' => [
            'TTD',
            'Trinidad ne Tobago dɔla',
        ],
        'TWD' => [
            'NT$',
            'Taewanfoɔ dɔla foforɔ',
        ],
        'TZS' => [
            'TZS',
            'Tanzania Hyelen',
        ],
        'UAH' => [
            'UAH',
            'Yukren hryvnia',
        ],
        'UGX' => [
            'UGX',
            'Uganda Hyelen',
        ],
        'USD' => [
            'US$',
            'Amɛrika Dɔla',
        ],
        'UYU' => [
            'UYU',
            'Yurugueɛ peso',
        ],
        'UZS' => [
            'UZS',
            'Yusbɛkistan som',
        ],
        'VES' => [
            'VES',
            'Venezuelan bolívar',
        ],
        'VND' => [
            '₫',
            'Viɛtnamfoɔ dɔn',
        ],
        'VUV' => [
            'VUV',
            'Vanuatu vatu',
        ],
        'WST' => [
            'WST',
            'Samoa Tala',
        ],
        'XAF' => [
            'FCFA',
            'Afrika Mfinimfini Sefa',
        ],
        'XCD' => [
            'EC$',
            'Karibine Apueeɛ dɔla',
        ],
        'XCG' => [
            'Cg.',
            'Karibiafoᴐ giida',
        ],
        'XOF' => [
            'AAS',
            'Afrika Atɔeɛ Sefa',
        ],
        'XPF' => [
            'CFPF',
            'CFP Franc',
        ],
        'YER' => [
            'YER',
            'Yɛmɛn rial',
        ],
        'ZAR' => [
            'ZAR',
            'Afrika Anaafo Rand',
        ],
        'ZMK' => [
            'ZMK',
            'Zambia Kwacha (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Zambia Kwakya',
        ],
        'ZWD' => [
            'ZWD',
            'Zimbabwe Dɔla',
        ],
        'ZWG' => [
            'ZWG',
            'Zimbabwe sika kᴐkᴐᴐ',
        ],
    ],
];
