<?php

return [
    'Names' => [
        'aa' => 'afar',
        'ab' => 'abchasian',
        'ace' => 'aceh',
        'ach' => 'acoli',
        'ada' => 'andangme',
        'ady' => 'adygai',
        'ae' => 'avestic',
        'af' => 'afrikaans',
        'afh' => 'afrihili',
        'agq' => 'aghem',
        'ain' => 'ainu',
        'ak' => 'akan',
        'akk' => 'accadic',
        'ale' => 'aleutic',
        'alt' => 'altaic dal sid',
        'am' => 'amaric',
        'an' => 'aragonais',
        'ang' => 'englais vegl',
        'anp' => 'angika',
        'ar' => 'arab',
        'arc' => 'arameic',
        'arn' => 'araucanic',
        'arp' => 'arapaho',
        'arw' => 'arawak',
        'as' => 'assami',
        'asa' => 'asu',
        'ast' => 'asturian',
        'av' => 'avaric',
        'awa' => 'awadhi',
        'ay' => 'aymara',
        'az' => 'lingua aserbaidschana',
        'ba' => 'baschkir',
        'bal' => 'belutschi',
        'ban' => 'balinais',
        'bas' => 'basaa',
        'be' => 'lingua bielorussa',
        'bej' => 'bedscha',
        'bem' => 'bemba',
        'bez' => 'bena',
        'bg' => 'bulgar',
        'bgc' => 'haryanvi',
        'bho' => 'bhojpuri',
        'bi' => 'bislama',
        'bik' => 'bikol',
        'bin' => 'bini',
        'bla' => 'siksika',
        'blo' => 'anii',
        'bm' => 'bambara',
        'bn' => 'lingua bengala',
        'bo' => 'tibetan',
        'br' => 'breton',
        'bra' => 'braj',
        'brx' => 'bodo',
        'bs' => 'bosniac',
        'bua' => 'buriat',
        'bug' => 'bugi',
        'byn' => 'blin',
        'ca' => 'catalan',
        'cad' => 'caddo',
        'car' => 'caribic',
        'cch' => 'atsam',
        'ccp' => 'chakma',
        'ce' => 'tschetschen',
        'ceb' => 'cebuano',
        'cgg' => 'chiga',
        'ch' => 'chamorro',
        'chb' => 'chibcha',
        'chg' => 'tschagataic',
        'chk' => 'chuukais',
        'chm' => 'mari',
        'chn' => 'patuà chinook',
        'cho' => 'choctaw',
        'chp' => 'chipewyan',
        'chr' => 'cherokee',
        'chy' => 'cheyenne',
        'ckb' => 'curd central',
        'co' => 'cors',
        'cop' => 'coptic',
        'cr' => 'cree',
        'crh' => 'tirc crimean',
        'cs' => 'tschec',
        'csb' => 'kaschubic',
        'csw' => 'swampy cree',
        'cu' => 'slav da baselgia',
        'cv' => 'tschuvasch',
        'cy' => 'valisic',
        'da' => 'danais',
        'dak' => 'dakota',
        'dar' => 'dargwa',
        'dav' => 'taita',
        'de' => 'tudestg',
        'del' => 'delaware',
        'den' => 'slavey',
        'dgr' => 'dogrib',
        'din' => 'dinka',
        'dje' => 'zarma',
        'doi' => 'dogri',
        'dsb' => 'bass sorb',
        'dua' => 'duala',
        'dum' => 'ollandais mesaun',
        'dv' => 'maledivic',
        'dyo' => 'jola-fonyi',
        'dyu' => 'diula',
        'dz' => 'dzongkha',
        'ebu' => 'embu',
        'ee' => 'ewe',
        'efi' => 'efik',
        'egy' => 'egipzian vegl',
        'eka' => 'ekajuk',
        'el' => 'grec',
        'elx' => 'elamitic',
        'en' => 'englais',
        'enm' => 'englais mesaun',
        'eo' => 'esperanto',
        'es' => 'spagnol',
        'et' => 'eston',
        'eu' => 'basc',
        'ewo' => 'ewondo',
        'fa' => 'persian',
        'fan' => 'fang',
        'fat' => 'fanti',
        'ff' => 'fulah',
        'fi' => 'finlandais',
        'fil' => 'filippino',
        'fj' => 'fidschian',
        'fo' => 'feroais',
        'fon' => 'fon',
        'fr' => 'franzos',
        'frm' => 'franzos mesaun',
        'fro' => 'franzos vegl',
        'frr' => 'fris dal nord',
        'frs' => 'fris da l’ost',
        'fur' => 'friulan',
        'fy' => 'fris occidental',
        'ga' => 'irlandais',
        'gaa' => 'ga',
        'gay' => 'gayo',
        'gba' => 'gbaya',
        'gd' => 'gaelic scot',
        'gez' => 'geez',
        'gil' => 'gilbertais',
        'gl' => 'galizian',
        'gmh' => 'tudestg mesaun',
        'gn' => 'guarani',
        'goh' => 'vegl tudestg da scrittira',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gotic',
        'grb' => 'grebo',
        'grc' => 'grec vegl',
        'gsw' => 'tudestg svizzer',
        'gu' => 'gujarati',
        'guz' => 'gusii',
        'gv' => 'manx',
        'gwi' => 'gwichʼin',
        'ha' => 'hausa',
        'hai' => 'haida',
        'haw' => 'hawaian',
        'he' => 'ebraic',
        'hi' => 'hindi',
        'hil' => 'hiligaynon',
        'hit' => 'ettitic',
        'hmn' => 'hmong',
        'ho' => 'hiri motu',
        'hr' => 'croat',
        'hsb' => 'aut sorb',
        'ht' => 'creol haitian',
        'hu' => 'ungarais',
        'hup' => 'hupa',
        'hy' => 'armen',
        'hz' => 'herero',
        'ia' => 'interlingua',
        'iba' => 'iban',
        'id' => 'indonais',
        'ie' => 'interlingue',
        'ig' => 'igbo',
        'ii' => 'sichuan yi',
        'ik' => 'inupiak',
        'ilo' => 'ilocano',
        'inh' => 'ingush',
        'io' => 'ido',
        'is' => 'islandais',
        'it' => 'talian',
        'iu' => 'inuktitut',
        'ja' => 'giapunais',
        'jbo' => 'lojban',
        'jgo' => 'ngomba',
        'jmc' => 'machame',
        'jpr' => 'giudaic-persian',
        'jrb' => 'giudaic-arab',
        'jv' => 'javanais',
        'ka' => 'georgian',
        'kaa' => 'karakalpak',
        'kab' => 'kabyle',
        'kac' => 'kachin',
        'kaj' => 'jju',
        'kam' => 'kamba',
        'kaw' => 'kawi',
        'kbd' => 'kabardic',
        'kcg' => 'tyap',
        'kde' => 'makonde',
        'kea' => 'creol dal Cap Verd',
        'kfo' => 'koro',
        'kg' => 'kongo',
        'kgp' => 'kaingang',
        'kha' => 'khasi',
        'kho' => 'khotanais',
        'khq' => 'koyra chiini',
        'ki' => 'kikuyu',
        'kj' => 'kuanyama',
        'kk' => 'kasac',
        'kkj' => 'kako',
        'kl' => 'grönlandais',
        'kln' => 'kalenjin',
        'km' => 'khmer',
        'kmb' => 'kimbundu',
        'kn' => 'kannada',
        'ko' => 'corean',
        'kok' => 'konkani',
        'kos' => 'kosraean',
        'kpe' => 'kpelle',
        'kr' => 'kanuri',
        'krc' => 'karachay-balkar',
        'krl' => 'carelian',
        'kru' => 'kurukh',
        'ks' => 'kashmiri',
        'ksb' => 'shambala',
        'ksf' => 'bafia',
        'ksh' => 'colognais',
        'ku' => 'curd',
        'kum' => 'kumuk',
        'kut' => 'kutenai',
        'kv' => 'komi',
        'kw' => 'cornic',
        'kxv' => 'kuvi',
        'ky' => 'kirghis',
        'la' => 'latin',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'lahnda',
        'lam' => 'lamba',
        'lb' => 'luxemburgais',
        'lez' => 'lezghian',
        'lg' => 'ganda',
        'li' => 'limburgais',
        'lij' => 'ligur',
        'lkt' => 'lakota',
        'lmo' => 'lumbard',
        'ln' => 'lingala',
        'lo' => 'laot',
        'lol' => 'lomongo',
        'loz' => 'lozi',
        'lrc' => 'luri dal nord',
        'lt' => 'lituan',
        'lu' => 'luba-katanga',
        'lua' => 'luba-lulua',
        'lui' => 'luiseno',
        'lun' => 'lunda',
        'luo' => 'luo',
        'lus' => 'lushai',
        'luy' => 'luyia',
        'lv' => 'letton',
        'mad' => 'madurais',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'makassar',
        'man' => 'mandingo',
        'mas' => 'masai',
        'mdf' => 'moksha',
        'mdr' => 'mandar',
        'men' => 'mende',
        'mer' => 'meru',
        'mfe' => 'morisyen',
        'mg' => 'malagassi',
        'mga' => 'irlandais mesaun',
        'mgh' => 'makhuwa-meetto',
        'mgo' => 'meta’',
        'mh' => 'marschallais',
        'mi' => 'māori',
        'mic' => 'micmac',
        'min' => 'minangkabau',
        'mk' => 'macedon',
        'ml' => 'malayalam',
        'mn' => 'mongol',
        'mnc' => 'manchu',
        'mni' => 'meitei',
        'moh' => 'mohawk',
        'mos' => 'mossi',
        'mr' => 'marathi',
        'ms' => 'malaic',
        'mt' => 'maltais',
        'mua' => 'mundang',
        'mus' => 'creek',
        'mwl' => 'mirandais',
        'mwr' => 'marwari',
        'my' => 'birman',
        'myv' => 'erzya',
        'mzn' => 'mazanderani',
        'na' => 'nauru',
        'nap' => 'neapolitan',
        'naq' => 'nama',
        'nb' => 'norvegais bokmål',
        'nd' => 'ndebele dal nord',
        'nds' => 'bass tudestg',
        'ne' => 'nepalais',
        'new' => 'newari',
        'ng' => 'ndonga',
        'nia' => 'nias',
        'niu' => 'niue',
        'nl' => 'neerlandais',
        'nmg' => 'kwasio',
        'nn' => 'norvegiais nynorsk',
        'nnh' => 'ngienboon',
        'no' => 'norvegiais',
        'nog' => 'nogai',
        'non' => 'nordic vegl',
        'nqo' => 'n’ko',
        'nr' => 'ndebele dal sid',
        'nso' => 'sotho dal nord',
        'nus' => 'nuer',
        'nv' => 'navajo',
        'nwc' => 'newari classic',
        'ny' => 'nyanja',
        'nym' => 'nyamwezi',
        'nyn' => 'nyankole',
        'nyo' => 'nyoro',
        'nzi' => 'nzima',
        'oc' => 'occitan',
        'oj' => 'ojibwa',
        'om' => 'oromo',
        'or' => 'oriya',
        'os' => 'ossetic',
        'osa' => 'osage',
        'ota' => 'tirc ottoman',
        'pa' => 'punjabi',
        'pag' => 'pangasinan',
        'pal' => 'pahlavi',
        'pam' => 'pampanga',
        'pap' => 'papiamento',
        'pau' => 'palau',
        'pcm' => 'pidgin nigerian',
        'peo' => 'persian vegl',
        'phn' => 'fenizian',
        'pi' => 'pali',
        'pl' => 'polac',
        'pon' => 'ponapean',
        'prg' => 'prussian',
        'pro' => 'provenzal vegl',
        'ps' => 'paschto',
        'pt' => 'portugais',
        'qu' => 'quechua',
        'raj' => 'rajasthani',
        'rap' => 'rapanui',
        'rar' => 'rarotonga',
        'rm' => 'rumantsch',
        'rn' => 'rundi',
        'ro' => 'rumen',
        'rof' => 'rombo',
        'rom' => 'romani',
        'ru' => 'russ',
        'rup' => 'aromunic',
        'rw' => 'kinyarwanda',
        'rwk' => 'rwa',
        'sa' => 'sanscrit',
        'sad' => 'sandawe',
        'sah' => 'jakut',
        'sam' => 'arameic samaritan',
        'saq' => 'samburu',
        'sas' => 'sasak',
        'sat' => 'santali',
        'sbp' => 'sangu',
        'sc' => 'sard',
        'scn' => 'sicilian',
        'sco' => 'scot',
        'sd' => 'sindhi',
        'se' => 'sami dal nord',
        'seh' => 'sena',
        'sel' => 'selkup',
        'ses' => 'koyraboro senni',
        'sg' => 'sango',
        'sga' => 'irlandais vegl',
        'sh' => 'serbo-croat',
        'shi' => 'tachelit',
        'shn' => 'shan',
        'si' => 'singalais',
        'sid' => 'sidamo',
        'sk' => 'slovac',
        'sl' => 'sloven',
        'sm' => 'samoan',
        'sma' => 'sami dal sid',
        'smj' => 'sami lule',
        'smn' => 'sami inari',
        'sms' => 'sami skolt',
        'sn' => 'shona',
        'snk' => 'soninke',
        'so' => 'somali',
        'sog' => 'sogdian',
        'sq' => 'albanais',
        'sr' => 'serb',
        'srn' => 'sranan tongo',
        'srr' => 'serer',
        'ss' => 'swazi',
        'st' => 'sotho dal sid',
        'su' => 'sundanais',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'sumeric',
        'sv' => 'svedais',
        'sw' => 'suaheli',
        'syc' => 'siric classic',
        'syr' => 'sirian',
        'szl' => 'silesian',
        'ta' => 'tamil',
        'te' => 'telugu',
        'tem' => 'temne',
        'teo' => 'teso',
        'ter' => 'tereno',
        'tet' => 'tetum',
        'tg' => 'tadschic',
        'th' => 'tailandais',
        'ti' => 'tigrinya',
        'tig' => 'tigre',
        'tiv' => 'tiv',
        'tk' => 'turkmen',
        'tkl' => 'tokelau',
        'tl' => 'tagalog',
        'tlh' => 'klingonic',
        'tli' => 'tlingit',
        'tmh' => 'tamasheq',
        'tn' => 'tswana',
        'to' => 'tonga',
        'tog' => 'lingua tsonga',
        'tpi' => 'tok pisin',
        'tr' => 'tirc',
        'ts' => 'tsonga',
        'tsi' => 'tsimshian',
        'tt' => 'tatar',
        'tum' => 'tumbuka',
        'tvl' => 'tuvalu',
        'tw' => 'twi',
        'twq' => 'tasawaq',
        'ty' => 'tahitian',
        'tyv' => 'tuvinian',
        'tzm' => 'tamazight',
        'udm' => 'udmurt',
        'ug' => 'uiguric',
        'uga' => 'ugaritic',
        'uk' => 'ucranais',
        'umb' => 'mbundu',
        'ur' => 'urdu',
        'uz' => 'usbec',
        'vai' => 'vai',
        've' => 'venda',
        'vec' => 'venetic',
        'vi' => 'vietnamais',
        'vmw' => 'makhuwa',
        'vo' => 'volapuk',
        'vot' => 'votic',
        'vun' => 'vunjo',
        'wa' => 'vallon',
        'wae' => 'gualser',
        'wal' => 'walamo',
        'war' => 'waray',
        'was' => 'washo',
        'wo' => 'wolof',
        'xal' => 'kalmuk',
        'xh' => 'xhosa',
        'xnr' => 'kangri',
        'xog' => 'soga',
        'yao' => 'yao',
        'yap' => 'yapais',
        'yav' => 'yangben',
        'yi' => 'jiddic',
        'yo' => 'yoruba',
        'yrl' => 'nheengatu',
        'yue' => 'cantonais',
        'za' => 'zhuang',
        'zap' => 'zapotec',
        'zbl' => 'simbols da Bliss',
        'zen' => 'zenaga',
        'zgh' => 'marocan tamazight standardisà',
        'zh' => 'chinais',
        'zu' => 'zulu',
        'zun' => 'zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arab standardisà modern',
        'de_AT' => 'tudestg austriac',
        'de_CH' => 'tudestg da scrittira svizzer',
        'en_AU' => 'englais australian',
        'en_CA' => 'englais canadais',
        'en_GB' => 'englais britannic',
        'en_US' => 'englais american',
        'es_419' => 'spagnol latinamerican',
        'es_ES' => 'spagnol europeic',
        'es_MX' => 'spagnol mexican',
        'fa_AF' => 'dari',
        'fr_CA' => 'franzos canadais',
        'fr_CH' => 'franzos svizzer',
        'nl_BE' => 'flam',
        'pt_BR' => 'portugais brasilian',
        'pt_PT' => 'portugais europeic',
        'ro_MD' => 'moldav',
        'zh_Hans' => 'chinais simplifitgà',
        'zh_Hant' => 'chinais tradiziunal',
    ],
];
