<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'ሕቡራት ኢማራት ዓረብ ዲርሃም',
        ],
        'AFN' => [
            'AFN',
            'ኣፍጋኒስታናዊ ኣፍጋን',
        ],
        'ALL' => [
            'ALL',
            'ኣልባናዊ ሌክ',
        ],
        'AMD' => [
            'AMD',
            'ኣርመንያዊ ድራም',
        ],
        'ANG' => [
            'ANG',
            'ሆላንድ ኣንቲለያን ጊልደር',
        ],
        'AOA' => [
            'AOA',
            'ኣንጎላዊ ክዋንዛ',
        ],
        'ARS' => [
            'ARS',
            'ኣርጀንቲናዊ ፔሶ',
        ],
        'AUD' => [
            'A$',
            'ኣውስትራልያዊ ዶላር',
        ],
        'AWG' => [
            'AWG',
            'ኣሩባን ፍሎሪን',
        ],
        'AZN' => [
            'AZN',
            'ኣዘርባጃናዊ ማናት',
        ],
        'BAM' => [
            'BAM',
            'ቦዝንያ-ሄርዘጎቪና ተቐያሪ ምልክት',
        ],
        'BBD' => [
            'BBD',
            'ባርባዲያን ዶላር',
        ],
        'BDT' => [
            'BDT',
            'ባንግላደሻዊ ታካ',
        ],
        'BGN' => [
            'BGN',
            'ቡልጋርያዊ ሌቭ',
        ],
        'BHD' => [
            'BHD',
            'ባሕሬናዊ ዲናር',
        ],
        'BIF' => [
            'BIF',
            'ብሩንዳዊ ፍራንክ',
        ],
        'BMD' => [
            'BMD',
            'በርሙዳን ዶላር',
        ],
        'BND' => [
            'BND',
            'ብሩነይ ዶላር',
        ],
        'BOB' => [
            'BOB',
            'ቦሊቭያዊ ቦሊቭያኖ',
        ],
        'BRL' => [
            'R$',
            'የብራዚል ሪል',
        ],
        'BSD' => [
            'BSD',
            'ባሃማዊ ዶላር',
        ],
        'BTN' => [
            'BTN',
            'ቡታናዊ ንጉልትሩም',
        ],
        'BWP' => [
            'BWP',
            'ቦትስዋናዊ ፑላ',
        ],
        'BYN' => [
            'BYN',
            'ናይ ቤላሩስ ሩብል',
        ],
        'BZD' => [
            'BZD',
            'ቤሊዝ ዶላር',
        ],
        'CAD' => [
            'CA$',
            'ካናዳ ዶላር',
        ],
        'CDF' => [
            'CDF',
            'ኮንጎ ፍራንክ',
        ],
        'CHF' => [
            'CHF',
            'ስዊስ ፍራንክ',
        ],
        'CLP' => [
            'CLP',
            'ቺለዊ ፔሶ',
        ],
        'CNH' => [
            'CNH',
            'ቻይናዊ ዩዋን (ካብ ባሕሪ ወጻኢ)',
        ],
        'CNY' => [
            'CNY',
            'ዩዋን ቻይና',
        ],
        'COP' => [
            'COP',
            'ኮሎምብያዊ ፔሶ',
        ],
        'CRC' => [
            'CRC',
            'ኮስታሪካ ኮሎን',
        ],
        'CUC' => [
            'CUC',
            'ኩባውያን ተቐያሪ ፔሶ',
        ],
        'CUP' => [
            'CUP',
            'ኩባዊ ፔሶ',
        ],
        'CVE' => [
            'CVE',
            'ናይ ኬፕ ቨርዲ ኤስኩዶ',
        ],
        'CZK' => [
            'CZK',
            'ናይ ቸክ ኮሩና',
        ],
        'DJF' => [
            'DJF',
            'ናይ ጅቡቲ ፍራንክ',
        ],
        'DKK' => [
            'DKK',
            'ናይ ዴንማርክ ክሮነር',
        ],
        'DOP' => [
            'DOP',
            'ዶሚኒካን ፔሶ',
        ],
        'DZD' => [
            'DZD',
            'ኣልጀርያዊ ዲናር',
        ],
        'EGP' => [
            'EGP',
            'ግብጻዊ ፓውንድ',
        ],
        'ERN' => [
            'ERN',
            'ኤርትራዊ ናቕፋ',
        ],
        'ETB' => [
            'Br',
            'ብር',
        ],
        'EUR' => [
            '€',
            'ዩሮ',
        ],
        'FJD' => [
            'FJD',
            'ዶላር ፊጂ',
        ],
        'FKP' => [
            'FKP',
            'ደሴታት ፎክላንድ ፓውንድ',
        ],
        'GBP' => [
            '£',
            'የእንግሊዝ ፓውንድ ስተርሊንግ',
        ],
        'GEL' => [
            'GEL',
            'ጆርጅያዊ ላሪ',
        ],
        'GHS' => [
            'GHS',
            'ጋናዊ ሴዲ',
        ],
        'GIP' => [
            'GIP',
            'ጂብራልተር ፓውንድ',
        ],
        'GMD' => [
            'GMD',
            'ጋምብያዊ ዳላሲ',
        ],
        'GNF' => [
            'GNF',
            'ናይ ጊኒ ፍራንክ',
        ],
        'GTQ' => [
            'GTQ',
            'ጓቲማላ ኲትዛል',
        ],
        'GYD' => [
            'GYD',
            'ጓያናኛ ዶላር',
        ],
        'HKD' => [
            'HK$',
            'ሆንግ ኮንግ ዶላር',
        ],
        'HNL' => [
            'HNL',
            'ሆንዱራስ ለምፒራ',
        ],
        'HRK' => [
            'HRK',
            'ክሮኤሽያዊ ኩና',
        ],
        'HTG' => [
            'HTG',
            'ናይ ሃይቲ ጎርደ',
        ],
        'HUF' => [
            'HUF',
            'ሃንጋርያዊ ፎርንት',
        ],
        'IDR' => [
            'IDR',
            'ኢንዶነዥያዊ ሩፒያ',
        ],
        'ILS' => [
            '₪',
            'እስራኤላዊ ሓድሽ ሸቃል',
        ],
        'INR' => [
            '₹',
            'ናይ ሕንድ ሩፒ',
        ],
        'IQD' => [
            'IQD',
            'ዒራቂ ዲናር',
        ],
        'IRR' => [
            'IRR',
            'ናይ ኢራን ርያል',
        ],
        'ISK' => [
            'ISK',
            'ናይ ኣይስላንድ ክሮና',
        ],
        'JMD' => [
            'JMD',
            'ጃማይካ ዶላር',
        ],
        'JOD' => [
            'JOD',
            'ዮርዳኖሳዊ ዲናር',
        ],
        'JPY' => [
            'JPY',
            'የን ጃፓን',
        ],
        'KES' => [
            'KES',
            'ኬንያዊ ሽልንግ',
        ],
        'KGS' => [
            'KGS',
            'ኪርጊስታናዊ ሶም',
        ],
        'KHR' => [
            'KHR',
            'ካምቦድያዊ ሪኤል',
        ],
        'KMF' => [
            'KMF',
            'ኮሞርያዊ ፍራንክ',
        ],
        'KPW' => [
            'KPW',
            'ሰሜን ኮርያዊ ዎን',
        ],
        'KRW' => [
            '₩',
            'ደቡብ ኮርያዊ ዎን',
        ],
        'KWD' => [
            'KWD',
            'ኩዌቲ ዲናር',
        ],
        'KYD' => [
            'KYD',
            'ደሴታት ካይመን ዶላር',
        ],
        'KZT' => [
            'KZT',
            'ካዛኪስታናዊ ተንገ',
        ],
        'LAK' => [
            'LAK',
            'ላኦስያዊ ኪፕ',
        ],
        'LBP' => [
            'LBP',
            'ሊባኖሳዊ ፓውንድ',
        ],
        'LKR' => [
            'LKR',
            'ስሪላንካ ሩፒ',
        ],
        'LRD' => [
            'LRD',
            'ላይበርያዊ ዶላር',
        ],
        'LSL' => [
            'LSL',
            'ሌሶቶ ሎቲ',
        ],
        'LYD' => [
            'LYD',
            'ናይ ሊብያ ዲናር',
        ],
        'MAD' => [
            'MAD',
            'ሞሮካዊ ዲርሃም',
        ],
        'MDL' => [
            'MDL',
            'ሞልዶቫን ሌው',
        ],
        'MGA' => [
            'MGA',
            'ማላጋሲ ኣሪያሪ',
        ],
        'MKD' => [
            'MKD',
            'ናይ መቄዶንያ ዲናር',
        ],
        'MMK' => [
            'MMK',
            'ሚያንማር ክያት',
        ],
        'MNT' => [
            'MNT',
            'ሞንጎላዊ ቱግሪክ',
        ],
        'MOP' => [
            'MOP',
            'ማካኒዝ ፓታካ',
        ],
        'MRU' => [
            'MRU',
            'ሞሪታናዊ ኡጉዋያ',
        ],
        'MUR' => [
            'MUR',
            'ሞሪሸስ ሩፒ',
        ],
        'MVR' => [
            'MVR',
            'ማልዲቭያዊ ሩፍያ',
        ],
        'MWK' => [
            'MWK',
            'ማላዊያዊ ኳቻ',
        ],
        'MXN' => [
            'MX$',
            'ሜክሲካዊ ፔሶ',
        ],
        'MXP' => [
            'MXP',
            'ሜክሲካዊ ብሩር ፔሶ (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'ኣሃዱ ወፍሪ ሜክሲኮ',
        ],
        'MYR' => [
            'MYR',
            'ማሌዥያዊ ሪንግጊት',
        ],
        'MZN' => [
            'MZN',
            'ሞዛምቢካዊ ሜቲካል',
        ],
        'NAD' => [
            'NAD',
            'ናሚብያ ዶላር',
        ],
        'NGN' => [
            'NGN',
            'ናይጀርያዊ ናይራ',
        ],
        'NIC' => [
            'NIC',
            'ኒካራጓ ካርዶባ (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'ኒካራጓ ኮርዶባ',
        ],
        'NOK' => [
            'NOK',
            'ናይ ኖርወይ ክሮነር',
        ],
        'NPR' => [
            'NPR',
            'ኔፓላዊ ሩፒ',
        ],
        'NZD' => [
            'NZ$',
            'ኒውዚላንዳዊ ዶላር',
        ],
        'OMR' => [
            'OMR',
            'ኦማን ርያል',
        ],
        'PAB' => [
            'PAB',
            'ፓናማያን ባልቦኣ',
        ],
        'PEN' => [
            'PEN',
            'ፔሩቪያን ሶል',
        ],
        'PGK' => [
            'PGK',
            'ፓፑዋ ኒው ጊኒ ኪና',
        ],
        'PHP' => [
            '₱',
            'ፊሊፒንስ ፔሶ',
        ],
        'PKR' => [
            'PKR',
            'ፓኪስታናዊ ሩፒ',
        ],
        'PLN' => [
            'PLN',
            'ፖላንዳዊ ዝሎቲ',
        ],
        'PYG' => [
            'PYG',
            'ፓራጓያዊ ጓራኒ',
        ],
        'QAR' => [
            'QAR',
            'ቀጠሪ ሪያል',
        ],
        'RON' => [
            'RON',
            'ሮማንያዊ ሌው',
        ],
        'RSD' => [
            'RSD',
            'ናይ ሰርብያን ዲናር',
        ],
        'RUB' => [
            'RUB',
            'የራሻ ሩብል',
        ],
        'RWF' => [
            'RWF',
            'ፍራንክ ሩዋንዳ',
        ],
        'SAR' => [
            'SAR',
            'ስዑዲ ዓረብ ሪያል',
        ],
        'SBD' => [
            'SBD',
            'ደሴታት ሰሎሞን ዶላር',
        ],
        'SCR' => [
            'SCR',
            'ሲሸሎ ሩፒ',
        ],
        'SDG' => [
            'SDG',
            'ሱዳናዊ ፓውንድ',
        ],
        'SEK' => [
            'SEK',
            'ሽወደናዊ ክሮና',
        ],
        'SGD' => [
            'SGD',
            'ሲንጋፖር ዶላር',
        ],
        'SHP' => [
            'SHP',
            'ቅድስቲ ሄለና ፓውንድ',
        ],
        'SLE' => [
            'SLE',
            'ሴራሊዮን ልዮን',
        ],
        'SLL' => [
            'SLL',
            'ሴራሊዮን ልዮን (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'ሶማልያዊ ሽልንግ',
        ],
        'SRD' => [
            'SRD',
            'ሱሪናማዊ ዶላር',
        ],
        'SSP' => [
            'SSP',
            'ደቡብ ሱዳን ፓውንድ',
        ],
        'STN' => [
            'STN',
            'ሳኦ ቶሜን ፕሪንሲፐ ዶብራ',
        ],
        'SVC' => [
            'SVC',
            'ሳልቫዶራን ኮሎን',
        ],
        'SYP' => [
            'SYP',
            'ሶርያዊ ፓውንድ',
        ],
        'SZL' => [
            'SZL',
            'ስዋዚ ሊላንገኒ',
        ],
        'THB' => [
            'THB',
            'ታይላንዳዊ ባህ',
        ],
        'TJS' => [
            'TJS',
            'ታጂኪስታናዊ ሶሞኒ',
        ],
        'TMT' => [
            'TMT',
            'ቱርክመኒስታናዊ ማናት',
        ],
        'TND' => [
            'TND',
            'ቱኒዝያዊ ዲናር',
        ],
        'TOP' => [
            'TOP',
            'ቶንጋዊ ፓ`ኣንጋ',
        ],
        'TRY' => [
            'TRY',
            'ቱርካዊ ሊራ',
        ],
        'TTD' => [
            'TTD',
            'ትሪኒዳድን ቶባጎ ዶላር',
        ],
        'TWD' => [
            'NT$',
            'ኒው ታይዋን ዶላር',
        ],
        'TZS' => [
            'TZS',
            'ታንዛንያዊ ሽልንግ',
        ],
        'UAH' => [
            'UAH',
            'ዩክሬናዊት ሪቭንያ',
        ],
        'UGX' => [
            'UGX',
            'ኡጋንዳዊ ሽልንግ',
        ],
        'USD' => [
            'US$',
            'ዶላር ኣመሪካ',
        ],
        'USN' => [
            'USN',
            'ዶላር ኣመሪካ (ዝቕጽል መዓልቲ)',
        ],
        'USS' => [
            'USS',
            'ዶላር ኣመሪካ (ተመሳሳሊ መዓልቲ)',
        ],
        'UYU' => [
            'UYU',
            'ኡራጋያዊ ፔሶ',
        ],
        'UZS' => [
            'UZS',
            'ኡዝቤኪስታናዊ ሶም',
        ],
        'VES' => [
            'VES',
            'ቬንዙዌላዊ ቦሊቫር',
        ],
        'VND' => [
            '₫',
            'ቬትናማዊ ዶንግ',
        ],
        'VUV' => [
            'VUV',
            'ቫኑኣቱ ቫቱ',
        ],
        'WST' => [
            'WST',
            'ሳሞኣዊ ታላ',
        ],
        'XAF' => [
            'FCFA',
            'ማእከላይ ኣፍሪቃ ሲኤፍኤ ፍራንክ',
        ],
        'XCD' => [
            'EC$',
            'ምብራቕ ካሪብያን ዶላር',
        ],
        'XCG' => [
            'Cg.',
            'ካሪብያን ጊልደር',
        ],
        'XOF' => [
            'F CFA',
            'ምዕራብ ኣፍሪቃ CFA ፍራንክ',
        ],
        'XPF' => [
            'CFPF',
            'ሲኤፍፒ ፍራንክ',
        ],
        'YER' => [
            'YER',
            'የመኒ ርያል',
        ],
        'ZAR' => [
            'ZAR',
            'ናይ ደቡብ ኣፍሪቃ ራንድ',
        ],
        'ZMW' => [
            'ZMW',
            'ዛምብያዊ ኳቻ',
        ],
        'ZWG' => [
            'ZWG',
            'ዚምባብወ ወርቂ',
        ],
    ],
];
