<?php

return [
    'Names' => [
        'Adlm' => 'адлам',
        'Arab' => 'арабска',
        'Aran' => 'aранска',
        'Armi' => 'Арамейска',
        'Armn' => 'арменска',
        'Avst' => 'Авестанска',
        'Bali' => 'Балийски',
        'Batk' => 'Батакска',
        'Beng' => 'бенгалска',
        'Blis' => 'Блис символи',
        'Bopo' => 'бопомофо',
        'Brah' => 'Брахми',
        'Brai' => 'брайлова',
        'Bugi' => 'Бугинска',
        'Buhd' => 'Бухид',
        'Cakm' => 'чакма',
        'Cans' => 'унифицирани символи на канадски аборигени',
        'Cari' => 'Карийска',
        'Cham' => 'Хамитска',
        'Cher' => 'чероки',
        'Cirt' => 'Кирт',
        'Copt' => 'Коптска',
        'Cprt' => 'Кипърска',
        'Cyrl' => 'кирилица',
        'Deva' => 'деванагари',
        'Dsrt' => 'Дезерет',
        'Egyd' => 'Египетско демотично писмо',
        'Egyh' => 'Египетско йератично писмо',
        'Egyp' => 'Египетски йероглифи',
        'Ethi' => 'етиопска',
        'Geok' => 'Грузинска хуцури',
        'Geor' => 'грузинска',
        'Glag' => 'Глаголическа',
        'Goth' => 'Готическа',
        'Grek' => 'гръцка',
        'Gujr' => 'гуджарати',
        'Guru' => 'гурмукхи',
        'Hanb' => 'ханб',
        'Hang' => 'хангъл',
        'Hani' => 'хан',
        'Hano' => 'Хануну',
        'Hans' => 'опростена',
        'Hant' => 'традиционна',
        'Hebr' => 'иврит',
        'Hira' => 'хирагана',
        'Hmng' => 'Пахау хмонг',
        'Hrkt' => 'японска сричкова',
        'Hung' => 'Староунгарска',
        'Inds' => 'Харапска',
        'Ital' => 'Древно италийска',
        'Jamo' => 'джамо',
        'Java' => 'Яванска',
        'Jpan' => 'японска',
        'Kali' => 'Кая Ли',
        'Kana' => 'катакана',
        'Khar' => 'Кхароштхи',
        'Khmr' => 'кхмерска',
        'Knda' => 'каннада',
        'Kore' => 'корейска',
        'Kthi' => 'Кайтхи',
        'Lana' => 'Ланна',
        'Laoo' => 'лаоска',
        'Latf' => 'Латинска фрактура',
        'Latg' => 'Галска латинска',
        'Latn' => 'латиница',
        'Lepc' => 'Лепча',
        'Limb' => 'Лимбу',
        'Lina' => 'Линейна А',
        'Linb' => 'Линейна Б',
        'Lyci' => 'Лицийска',
        'Lydi' => 'Лидийска',
        'Mand' => 'Мандаринска',
        'Mani' => 'Манихейска',
        'Maya' => 'Йероглифи на Маите',
        'Mero' => 'Мероитска',
        'Mlym' => 'малаялам',
        'Mong' => 'монголска',
        'Moon' => 'Мун',
        'Mtei' => 'манипури',
        'Mymr' => 'бирманска',
        'Nkoo' => 'Н’Ко',
        'Ogam' => 'Огамическа',
        'Olck' => 'Ол Чики',
        'Orkh' => 'Орхоно-енисейска',
        'Orya' => 'ория',
        'Osma' => 'Османска',
        'Perm' => 'Древно пермска',
        'Phag' => 'Фагс-па',
        'Phlv' => 'Пахлавска',
        'Phnx' => 'Финикийска',
        'Plrd' => 'Писменост Полард',
        'Rohg' => 'харифи',
        'Roro' => 'Ронго-ронго',
        'Runr' => 'Руническа',
        'Samr' => 'Самаританска',
        'Sara' => 'Сарати',
        'Saur' => 'Саураштра',
        'Sinh' => 'синхалска',
        'Sund' => 'сунданска',
        'Sylo' => 'Силоти Нагри',
        'Syrc' => 'сирийска',
        'Syre' => 'Сирийска естрангело',
        'Syrj' => 'Западна сирийска',
        'Syrn' => 'Източна сирийска',
        'Tagb' => 'Тагбанва',
        'Tale' => 'Тай Ле',
        'Talu' => 'Нова Тай Ле',
        'Taml' => 'тамилска',
        'Telu' => 'телугу',
        'Tfng' => 'тифинаг',
        'Tglg' => 'Тагалог',
        'Thaa' => 'таана',
        'Thai' => 'тайска',
        'Tibt' => 'тибетска',
        'Ugar' => 'Угаритска',
        'Vaii' => 'вайска',
        'Visp' => 'Видима реч',
        'Xpeo' => 'Староперсийска',
        'Xsux' => 'Шумеро-акадски клинопис',
        'Yiii' => 'Йи',
        'Zmth' => 'математически символи',
        'Zsye' => 'емоджи',
        'Zsym' => 'символи',
        'Zxxx' => 'без писменост',
        'Zyyy' => 'обща',
    ],
];
