<?php

return [
    'Names' => [
        'Africa/Cairo' => 'hora de Europa del Este (El Cairo)',
        'Africa/Casablanca' => 'hora de Europa del Oeste (Casablanca)',
        'Africa/Conakry' => 'hora del meridiano de Greenwich (Conakry)',
        'Africa/El_Aaiun' => 'hora de Europa del Oeste (El Aaiún)',
        'Africa/Tripoli' => 'hora de Europa del Este (Trípoli)',
        'America/Boise' => 'hora de la montaña (Boise)',
        'America/Cambridge_Bay' => 'hora de la montaña (Cambridge Bay)',
        'America/Ciudad_Juarez' => 'hora de la montaña (Ciudad Juárez)',
        'America/Creston' => 'hora de la montaña (Creston)',
        'America/Dawson_Creek' => 'hora de la montaña (Dawson Creek)',
        'America/Denver' => 'hora de la montaña (Denver)',
        'America/Edmonton' => 'hora de la montaña (Edmonton)',
        'America/Fort_Nelson' => 'hora de la montaña (Fuerte Nelson)',
        'America/Inuvik' => 'hora de la montaña (Inuvik)',
        'America/Nassau' => 'hora oriental (Nasáu)',
        'America/Phoenix' => 'hora de la montaña (Phoenix)',
        'America/Santiago' => 'hora de Chile (Santiago)',
        'America/St_Thomas' => 'hora del Atlántico (Santo Tomás)',
        'Asia/Amman' => 'hora de Europa del Este (Ammán)',
        'Asia/Beirut' => 'hora de Europa del Este (Beirut)',
        'Asia/Calcutta' => 'hora de India (Calcuta)',
        'Asia/Kolkata' => 'hora de India (Calcuta)',
        'Asia/Colombo' => 'hora de India (Colombo)',
        'Asia/Damascus' => 'hora de Europa del Este (Damasco)',
        'Asia/Famagusta' => 'hora de Europa del Este (Famagusta)',
        'Asia/Gaza' => 'hora de Europa del Este (Gaza)',
        'Asia/Hebron' => 'hora de Europa del Este (Hebrón)',
        'Asia/Khandyga' => 'hora de Yakutsk (Khandyga)',
        'Asia/Nicosia' => 'hora de Europa del Este (Nicosia)',
        'Asia/Rangoon' => 'hora de Myanmar (Birmania) (Yangón (Rangún))',
        'Asia/Yangon' => 'hora de Myanmar (Birmania) (Yangón (Rangún))',
        'Atlantic/Canary' => 'hora de Europa del Oeste (Islas Canarias)',
        'Atlantic/Faeroe' => 'hora de Europa del Oeste (Islas Feroe)',
        'Atlantic/Faroe' => 'hora de Europa del Oeste (Islas Feroe)',
        'Atlantic/Madeira' => 'hora de Europa del Oeste (Madeira)',
        'Atlantic/Stanley' => 'hora de las Islas Malvinas (Stanley)',
        'Etc/UTC' => 'hora universal coordinada',
        'Europe/Athens' => 'hora de Europa del Este (Atenas)',
        'Europe/Bucharest' => 'hora de Europa del Este (Bucarest)',
        'Europe/Chisinau' => 'hora de Europa del Este (Chisináu)',
        'Europe/Guernsey' => 'hora del meridiano de Greenwich (Guernsey)',
        'Europe/Helsinki' => 'hora de Europa del Este (Helsinki)',
        'Europe/Kaliningrad' => 'hora de Europa del Este (Kaliningrado)',
        'Europe/Kiev' => 'hora de Europa del Este (Kiev)',
        'Europe/Kyiv' => 'hora de Europa del Este (Kiev)',
        'Europe/Lisbon' => 'hora de Europa del Oeste (Lisboa)',
        'Europe/Mariehamn' => 'hora de Europa del Este (Mariehamn)',
        'Europe/Riga' => 'hora de Europa del Este (Riga)',
        'Europe/Sofia' => 'hora de Europa del Este (Sofía)',
        'Europe/Tallinn' => 'hora de Europa del Este (Tallin)',
        'Europe/Vilnius' => 'hora de Europa del Este (Vilna)',
        'Indian/Cocos' => 'hora de Islas Cocos',
        'Indian/Kerguelen' => 'hora de las Tierras Australes y Antárticas Francesas (Kerguelen)',
        'Pacific/Easter' => 'hora de la Isla de Pascua',
        'Pacific/Guadalcanal' => 'hora de Islas Salomón (Guadalcanal)',
        'Pacific/Kwajalein' => 'hora de Islas Marshall (Kwajalein)',
        'Pacific/Majuro' => 'hora de Islas Marshall (Majuro)',
        'Pacific/Norfolk' => 'hora de la Isla Norfolk',
        'Pacific/Rarotonga' => 'hora de las islas Cook (Rarotonga)',
        'Pacific/Tarawa' => 'hora de Islas Gilbert (Tarawa)',
        'Pacific/Wake' => 'hora de Isla Wake',
    ],
    'Meta' => [],
];
