<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Dirham',
        ],
        'AOA' => [
            'AOA',
            'kwanza angoley',
        ],
        'AUD' => [
            'A$',
            'Dolara aostralianina',
        ],
        'BHD' => [
            'BHD',
            'dinar bahreïni',
        ],
        'BIF' => [
            'BIF',
            'Farantsa Borondi',
        ],
        'BWP' => [
            'BWP',
            'Pola botsoaney',
        ],
        'CAD' => [
            'CA$',
            'Dôlara Kanadianina',
        ],
        'CDF' => [
            'CDF',
            'Farantsa kôngôley',
        ],
        'CHF' => [
            'CHF',
            'Farantsa soisa',
        ],
        'CNY' => [
            'CN¥',
            'Yoan sinoa Renminbi',
        ],
        'CVE' => [
            'CVE',
            'Escudo',
        ],
        'DJF' => [
            'DJF',
            'Farantsa Djibotianina',
        ],
        'DZD' => [
            'DZD',
            'Dinara alzerianina',
        ],
        'EGP' => [
            'EGP',
            'vola venty ejipsiana',
        ],
        'ERN' => [
            'ERN',
            'Nakfà Eritreanina',
        ],
        'ETB' => [
            'ETB',
            'Bir etiopianina',
        ],
        'EUR' => [
            '€',
            'Eoro',
        ],
        'GBP' => [
            '£',
            'livre sterling',
        ],
        'GHC' => [
            'GHC',
            'cédi',
        ],
        'GMD' => [
            'GMD',
            'Dalasi gambianina',
        ],
        'GNS' => [
            'GNS',
            'Farantsa Gineanina',
        ],
        'INR' => [
            '₹',
            'Ropia Indianina',
        ],
        'JPY' => [
            'JP¥',
            'Yen Japoney',
        ],
        'KES' => [
            'KES',
            'Shilling kenianina',
        ],
        'KMF' => [
            'KMF',
            'Farantsa Komorianina',
        ],
        'LRD' => [
            'LRD',
            'Dôlara Liberianina',
        ],
        'LSL' => [
            'LSL',
            'Loti',
        ],
        'LYD' => [
            'LYD',
            'Dinara Libyanina',
        ],
        'MAD' => [
            'MAD',
            'Dirham marokianina',
        ],
        'MGA' => [
            'Ar',
            'Ariary',
        ],
        'MRO' => [
            'MRO',
            'Ouguiya moritanianina (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Ouguiya moritanianina',
        ],
        'MUR' => [
            'MUR',
            'Ropia maorisianina',
        ],
        'MWK' => [
            'MWK',
            'kwacha malawite',
        ],
        'MZM' => [
            'MZM',
            'Metikaly',
        ],
        'NAD' => [
            'NAD',
            'Dolara namibianina',
        ],
        'NGN' => [
            'NGN',
            'Naira nigerianina',
        ],
        'RWF' => [
            'RWF',
            'Farantsa Roande',
        ],
        'SAR' => [
            'SAR',
            'Rial saodianina',
        ],
        'SCR' => [
            'SCR',
            'Ropia Seysheloà',
        ],
        'SDG' => [
            'SDG',
            'Dinara Sodaney',
        ],
        'SDP' => [
            'SDP',
            'livre soudanaise (1956–2007)',
        ],
        'SHP' => [
            'SHP',
            'livre de Sainte-Hélène',
        ],
        'SLE' => [
            'SLE',
            'Leone',
        ],
        'SLL' => [
            'SLL',
            'Leone (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Shilling somalianina',
        ],
        'STD' => [
            'STD',
            'Dobra (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Dobra',
        ],
        'SZL' => [
            'SZL',
            'Lilangeni',
        ],
        'TND' => [
            'TND',
            'Dinar tonizianina',
        ],
        'TZS' => [
            'TZS',
            'Shilling tanzanianina',
        ],
        'UGX' => [
            'UGX',
            'Shilling ogandianina',
        ],
        'USD' => [
            'US$',
            'Dolara amerikanina',
        ],
        'XAF' => [
            'FCFA',
            'Farantsa CFA (BEAC)',
        ],
        'XOF' => [
            'F CFA',
            'Farantsa CFA (BCEAO)',
        ],
        'ZAR' => [
            'ZAR',
            'Rand afrikanina tatsimo',
        ],
        'ZMK' => [
            'ZMK',
            'Kwacha zambianina (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Kwacha zambianina',
        ],
        'ZWD' => [
            'ZWD',
            'Dôlara Zimbaboeanina',
        ],
    ],
];
