<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'af_NA' => 'африкаанс (Намібія)',
        'af_ZA' => 'африкаанс (Південно-Африканська Республіка)',
        'ak' => 'акан',
        'ak_GH' => 'акан (Гана)',
        'am' => 'амхарська',
        'am_ET' => 'амхарська (Ефіопія)',
        'ar' => 'арабська',
        'ar_001' => 'арабська (Світ)',
        'ar_AE' => 'арабська (Обʼєднані Арабські Емірати)',
        'ar_BH' => 'арабська (Бахрейн)',
        'ar_DJ' => 'арабська (Джибуті)',
        'ar_DZ' => 'арабська (Алжир)',
        'ar_EG' => 'арабська (Єгипет)',
        'ar_EH' => 'арабська (Західна Сахара)',
        'ar_ER' => 'арабська (Еритрея)',
        'ar_IL' => 'арабська (Ізраїль)',
        'ar_IQ' => 'арабська (Ірак)',
        'ar_JO' => 'арабська (Йорданія)',
        'ar_KM' => 'арабська (Комори)',
        'ar_KW' => 'арабська (Кувейт)',
        'ar_LB' => 'арабська (Ліван)',
        'ar_LY' => 'арабська (Лівія)',
        'ar_MA' => 'арабська (Марокко)',
        'ar_MR' => 'арабська (Мавританія)',
        'ar_OM' => 'арабська (Оман)',
        'ar_PS' => 'арабська (Палестинські території)',
        'ar_QA' => 'арабська (Катар)',
        'ar_SA' => 'арабська (Саудівська Аравія)',
        'ar_SD' => 'арабська (Судан)',
        'ar_SO' => 'арабська (Сомалі)',
        'ar_SS' => 'арабська (Південний Судан)',
        'ar_SY' => 'арабська (Сирія)',
        'ar_TD' => 'арабська (Чад)',
        'ar_TN' => 'арабська (Туніс)',
        'ar_YE' => 'арабська (Ємен)',
        'as' => 'ассамська',
        'as_IN' => 'ассамська (Індія)',
        'az' => 'азербайджанська',
        'az_AZ' => 'азербайджанська (Азербайджан)',
        'az_Cyrl' => 'азербайджанська (кирилиця)',
        'az_Cyrl_AZ' => 'азербайджанська (кирилиця, Азербайджан)',
        'az_Latn' => 'азербайджанська (латиниця)',
        'az_Latn_AZ' => 'азербайджанська (латиниця, Азербайджан)',
        'ba' => 'башкирська',
        'ba_RU' => 'башкирська (Росія)',
        'be' => 'білоруська',
        'be_BY' => 'білоруська (Білорусь)',
        'bg' => 'болгарська',
        'bg_BG' => 'болгарська (Болгарія)',
        'bm' => 'бамбара',
        'bm_ML' => 'бамбара (Малі)',
        'bn' => 'бенгальська',
        'bn_BD' => 'бенгальська (Бангладеш)',
        'bn_IN' => 'бенгальська (Індія)',
        'bo' => 'тибетська',
        'bo_CN' => 'тибетська (Китай)',
        'bo_IN' => 'тибетська (Індія)',
        'br' => 'бретонська',
        'br_FR' => 'бретонська (Франція)',
        'bs' => 'боснійська',
        'bs_BA' => 'боснійська (Боснія і Герцеговина)',
        'bs_Cyrl' => 'боснійська (кирилиця)',
        'bs_Cyrl_BA' => 'боснійська (кирилиця, Боснія і Герцеговина)',
        'bs_Latn' => 'боснійська (латиниця)',
        'bs_Latn_BA' => 'боснійська (латиниця, Боснія і Герцеговина)',
        'ca' => 'каталонська',
        'ca_AD' => 'каталонська (Андорра)',
        'ca_ES' => 'каталонська (Іспанія)',
        'ca_FR' => 'каталонська (Франція)',
        'ca_IT' => 'каталонська (Італія)',
        'ce' => 'чеченська',
        'ce_RU' => 'чеченська (Росія)',
        'cs' => 'чеська',
        'cs_CZ' => 'чеська (Чехія)',
        'cv' => 'чуваська',
        'cv_RU' => 'чуваська (Росія)',
        'cy' => 'валлійська',
        'cy_GB' => 'валлійська (Велика Британія)',
        'da' => 'данська',
        'da_DK' => 'данська (Данія)',
        'da_GL' => 'данська (Гренландія)',
        'de' => 'німецька',
        'de_AT' => 'німецька (Австрія)',
        'de_BE' => 'німецька (Бельгія)',
        'de_CH' => 'німецька (Швейцарія)',
        'de_DE' => 'німецька (Німеччина)',
        'de_IT' => 'німецька (Італія)',
        'de_LI' => 'німецька (Ліхтенштейн)',
        'de_LU' => 'німецька (Люксембург)',
        'dz' => 'дзонг-ке',
        'dz_BT' => 'дзонг-ке (Бутан)',
        'ee' => 'еве',
        'ee_GH' => 'еве (Гана)',
        'ee_TG' => 'еве (Того)',
        'el' => 'грецька',
        'el_CY' => 'грецька (Кіпр)',
        'el_GR' => 'грецька (Греція)',
        'en' => 'англійська',
        'en_001' => 'англійська (Світ)',
        'en_150' => 'англійська (Європа)',
        'en_AE' => 'англійська (Обʼєднані Арабські Емірати)',
        'en_AG' => 'англійська (Антигуа і Барбуда)',
        'en_AI' => 'англійська (Ангілья)',
        'en_AS' => 'англійська (Американське Самоа)',
        'en_AT' => 'англійська (Австрія)',
        'en_AU' => 'англійська (Австралія)',
        'en_BB' => 'англійська (Барбадос)',
        'en_BE' => 'англійська (Бельгія)',
        'en_BI' => 'англійська (Бурунді)',
        'en_BM' => 'англійська (Бермудські Острови)',
        'en_BS' => 'англійська (Багамські Острови)',
        'en_BW' => 'англійська (Ботсвана)',
        'en_BZ' => 'англійська (Беліз)',
        'en_CA' => 'англійська (Канада)',
        'en_CC' => 'англійська (Кокосові [Кілінг] Острови)',
        'en_CH' => 'англійська (Швейцарія)',
        'en_CK' => 'англійська (Острови Кука)',
        'en_CM' => 'англійська (Камерун)',
        'en_CX' => 'англійська (Острів Різдва)',
        'en_CY' => 'англійська (Кіпр)',
        'en_CZ' => 'англійська (Чехія)',
        'en_DE' => 'англійська (Німеччина)',
        'en_DK' => 'англійська (Данія)',
        'en_DM' => 'англійська (Домініка)',
        'en_EE' => 'англійська (Естонія)',
        'en_ER' => 'англійська (Еритрея)',
        'en_ES' => 'англійська (Іспанія)',
        'en_FI' => 'англійська (Фінляндія)',
        'en_FJ' => 'англійська (Фіджі)',
        'en_FK' => 'англійська (Фолклендські Острови)',
        'en_FM' => 'англійська (Мікронезія)',
        'en_FR' => 'англійська (Франція)',
        'en_GB' => 'англійська (Велика Британія)',
        'en_GD' => 'англійська (Гренада)',
        'en_GE' => 'англійська (Грузія)',
        'en_GG' => 'англійська (Гернсі)',
        'en_GH' => 'англійська (Гана)',
        'en_GI' => 'англійська (Гібралтар)',
        'en_GM' => 'англійська (Гамбія)',
        'en_GS' => 'англійська (Південна Джорджія та Південні Сандвічеві Острови)',
        'en_GU' => 'англійська (Гуам)',
        'en_GY' => 'англійська (Гаяна)',
        'en_HK' => 'англійська (Гонконг, ОАР Китаю)',
        'en_HU' => 'англійська (Угорщина)',
        'en_ID' => 'англійська (Індонезія)',
        'en_IE' => 'англійська (Ірландія)',
        'en_IL' => 'англійська (Ізраїль)',
        'en_IM' => 'англійська (Острів Мен)',
        'en_IN' => 'англійська (Індія)',
        'en_IO' => 'англійська (Британська територія в Індійському океані)',
        'en_IT' => 'англійська (Італія)',
        'en_JE' => 'англійська (Джерсі)',
        'en_JM' => 'англійська (Ямайка)',
        'en_JP' => 'англійська (Японія)',
        'en_KE' => 'англійська (Кенія)',
        'en_KI' => 'англійська (Кірибаті)',
        'en_KN' => 'англійська (Сент-Кітс і Невіс)',
        'en_KY' => 'англійська (Кайманові Острови)',
        'en_LC' => 'англійська (Сент-Люсія)',
        'en_LR' => 'англійська (Ліберія)',
        'en_LS' => 'англійська (Лесото)',
        'en_LT' => 'англійська (Литва)',
        'en_LV' => 'англійська (Латвія)',
        'en_MG' => 'англійська (Мадагаскар)',
        'en_MH' => 'англійська (Маршаллові Острови)',
        'en_MO' => 'англійська (Макао, ОАР Китаю)',
        'en_MP' => 'англійська (Північні Маріанські Острови)',
        'en_MS' => 'англійська (Монтсеррат)',
        'en_MT' => 'англійська (Мальта)',
        'en_MU' => 'англійська (Маврикій)',
        'en_MV' => 'англійська (Мальдіви)',
        'en_MW' => 'англійська (Малаві)',
        'en_MY' => 'англійська (Малайзія)',
        'en_NA' => 'англійська (Намібія)',
        'en_NF' => 'англійська (Острів Норфолк)',
        'en_NG' => 'англійська (Нігерія)',
        'en_NL' => 'англійська (Нідерланди)',
        'en_NO' => 'англійська (Норвегія)',
        'en_NR' => 'англійська (Науру)',
        'en_NU' => 'англійська (Ніуе)',
        'en_NZ' => 'англійська (Нова Зеландія)',
        'en_PG' => 'англійська (Папуа-Нова Гвінея)',
        'en_PH' => 'англійська (Філіппіни)',
        'en_PK' => 'англійська (Пакистан)',
        'en_PL' => 'англійська (Польща)',
        'en_PN' => 'англійська (Острови Піткерн)',
        'en_PR' => 'англійська (Пуерто-Рико)',
        'en_PT' => 'англійська (Португалія)',
        'en_PW' => 'англійська (Палау)',
        'en_RO' => 'англійська (Румунія)',
        'en_RW' => 'англійська (Руанда)',
        'en_SB' => 'англійська (Соломонові Острови)',
        'en_SC' => 'англійська (Сейшельські Острови)',
        'en_SD' => 'англійська (Судан)',
        'en_SE' => 'англійська (Швеція)',
        'en_SG' => 'англійська (Сінгапур)',
        'en_SH' => 'англійська (Острів Святої Єлени)',
        'en_SI' => 'англійська (Словенія)',
        'en_SK' => 'англійська (Словаччина)',
        'en_SL' => 'англійська (Сьєрра-Леоне)',
        'en_SS' => 'англійська (Південний Судан)',
        'en_SX' => 'англійська (Сінт-Мартен)',
        'en_SZ' => 'англійська (Есватіні)',
        'en_TC' => 'англійська (Острови Теркс і Кайкос)',
        'en_TK' => 'англійська (Токелау)',
        'en_TO' => 'англійська (Тонга)',
        'en_TT' => 'англійська (Тринідад і Тобаго)',
        'en_TV' => 'англійська (Тувалу)',
        'en_TZ' => 'англійська (Танзанія)',
        'en_UA' => 'англійська (Україна)',
        'en_UG' => 'англійська (Уганда)',
        'en_UM' => 'англійська (Віддалені острови США)',
        'en_US' => 'англійська (Сполучені Штати)',
        'en_VC' => 'англійська (Сент-Вінсент і Гренадіни)',
        'en_VG' => 'англійська (Британські Віргінські острови)',
        'en_VI' => 'англійська (Віргінські Острови [США])',
        'en_VU' => 'англійська (Вануату)',
        'en_WS' => 'англійська (Самоа)',
        'en_ZA' => 'англійська (Південно-Африканська Республіка)',
        'en_ZM' => 'англійська (Замбія)',
        'en_ZW' => 'англійська (Зімбабве)',
        'eo' => 'есперанто',
        'eo_001' => 'есперанто (Світ)',
        'es' => 'іспанська',
        'es_419' => 'іспанська (Латинська Америка)',
        'es_AR' => 'іспанська (Аргентина)',
        'es_BO' => 'іспанська (Болівія)',
        'es_BR' => 'іспанська (Бразилія)',
        'es_BZ' => 'іспанська (Беліз)',
        'es_CL' => 'іспанська (Чилі)',
        'es_CO' => 'іспанська (Колумбія)',
        'es_CR' => 'іспанська (Коста-Рика)',
        'es_CU' => 'іспанська (Куба)',
        'es_DO' => 'іспанська (Домініканська Республіка)',
        'es_EC' => 'іспанська (Еквадор)',
        'es_ES' => 'іспанська (Іспанія)',
        'es_GQ' => 'іспанська (Екваторіальна Гвінея)',
        'es_GT' => 'іспанська (Гватемала)',
        'es_HN' => 'іспанська (Гондурас)',
        'es_MX' => 'іспанська (Мексика)',
        'es_NI' => 'іспанська (Нікарагуа)',
        'es_PA' => 'іспанська (Панама)',
        'es_PE' => 'іспанська (Перу)',
        'es_PH' => 'іспанська (Філіппіни)',
        'es_PR' => 'іспанська (Пуерто-Рико)',
        'es_PY' => 'іспанська (Парагвай)',
        'es_SV' => 'іспанська (Сальвадор)',
        'es_US' => 'іспанська (Сполучені Штати)',
        'es_UY' => 'іспанська (Уругвай)',
        'es_VE' => 'іспанська (Венесуела)',
        'et' => 'естонська',
        'et_EE' => 'естонська (Естонія)',
        'eu' => 'баскська',
        'eu_ES' => 'баскська (Іспанія)',
        'fa' => 'перська',
        'fa_AF' => 'перська (Афганістан)',
        'fa_IR' => 'перська (Іран)',
        'ff' => 'фула',
        'ff_Adlm' => 'фула (адлам)',
        'ff_Adlm_BF' => 'фула (адлам, Буркіна-Фасо)',
        'ff_Adlm_CM' => 'фула (адлам, Камерун)',
        'ff_Adlm_GH' => 'фула (адлам, Гана)',
        'ff_Adlm_GM' => 'фула (адлам, Гамбія)',
        'ff_Adlm_GN' => 'фула (адлам, Гвінея)',
        'ff_Adlm_GW' => 'фула (адлам, Гвінея-Бісау)',
        'ff_Adlm_LR' => 'фула (адлам, Ліберія)',
        'ff_Adlm_MR' => 'фула (адлам, Мавританія)',
        'ff_Adlm_NE' => 'фула (адлам, Нігер)',
        'ff_Adlm_NG' => 'фула (адлам, Нігерія)',
        'ff_Adlm_SL' => 'фула (адлам, Сьєрра-Леоне)',
        'ff_Adlm_SN' => 'фула (адлам, Сенегал)',
        'ff_CM' => 'фула (Камерун)',
        'ff_GN' => 'фула (Гвінея)',
        'ff_Latn' => 'фула (латиниця)',
        'ff_Latn_BF' => 'фула (латиниця, Буркіна-Фасо)',
        'ff_Latn_CM' => 'фула (латиниця, Камерун)',
        'ff_Latn_GH' => 'фула (латиниця, Гана)',
        'ff_Latn_GM' => 'фула (латиниця, Гамбія)',
        'ff_Latn_GN' => 'фула (латиниця, Гвінея)',
        'ff_Latn_GW' => 'фула (латиниця, Гвінея-Бісау)',
        'ff_Latn_LR' => 'фула (латиниця, Ліберія)',
        'ff_Latn_MR' => 'фула (латиниця, Мавританія)',
        'ff_Latn_NE' => 'фула (латиниця, Нігер)',
        'ff_Latn_NG' => 'фула (латиниця, Нігерія)',
        'ff_Latn_SL' => 'фула (латиниця, Сьєрра-Леоне)',
        'ff_Latn_SN' => 'фула (латиниця, Сенегал)',
        'ff_MR' => 'фула (Мавританія)',
        'ff_SN' => 'фула (Сенегал)',
        'fi' => 'фінська',
        'fi_FI' => 'фінська (Фінляндія)',
        'fo' => 'фарерська',
        'fo_DK' => 'фарерська (Данія)',
        'fo_FO' => 'фарерська (Фарерські Острови)',
        'fr' => 'французька',
        'fr_BE' => 'французька (Бельгія)',
        'fr_BF' => 'французька (Буркіна-Фасо)',
        'fr_BI' => 'французька (Бурунді)',
        'fr_BJ' => 'французька (Бенін)',
        'fr_BL' => 'французька (Сен-Бартелемі)',
        'fr_CA' => 'французька (Канада)',
        'fr_CD' => 'французька (Конго – Кіншаса)',
        'fr_CF' => 'французька (Центральноафриканська Республіка)',
        'fr_CG' => 'французька (Конго – Браззавіль)',
        'fr_CH' => 'французька (Швейцарія)',
        'fr_CI' => 'французька (Кот-дʼІвуар)',
        'fr_CM' => 'французька (Камерун)',
        'fr_DJ' => 'французька (Джибуті)',
        'fr_DZ' => 'французька (Алжир)',
        'fr_FR' => 'французька (Франція)',
        'fr_GA' => 'французька (Габон)',
        'fr_GF' => 'французька (Французька Гвіана)',
        'fr_GN' => 'французька (Гвінея)',
        'fr_GP' => 'французька (Гваделупа)',
        'fr_GQ' => 'французька (Екваторіальна Гвінея)',
        'fr_HT' => 'французька (Гаїті)',
        'fr_KM' => 'французька (Комори)',
        'fr_LU' => 'французька (Люксембург)',
        'fr_MA' => 'французька (Марокко)',
        'fr_MC' => 'французька (Монако)',
        'fr_MF' => 'французька (Сен-Мартен)',
        'fr_MG' => 'французька (Мадагаскар)',
        'fr_ML' => 'французька (Малі)',
        'fr_MQ' => 'французька (Мартиніка)',
        'fr_MR' => 'французька (Мавританія)',
        'fr_MU' => 'французька (Маврикій)',
        'fr_NC' => 'французька (Нова Каледонія)',
        'fr_NE' => 'французька (Нігер)',
        'fr_PF' => 'французька (Французька Полінезія)',
        'fr_PM' => 'французька (Сен-Пʼєр і Мікелон)',
        'fr_RE' => 'французька (Реюньйон)',
        'fr_RW' => 'французька (Руанда)',
        'fr_SC' => 'французька (Сейшельські Острови)',
        'fr_SN' => 'французька (Сенегал)',
        'fr_SY' => 'французька (Сирія)',
        'fr_TD' => 'французька (Чад)',
        'fr_TG' => 'французька (Того)',
        'fr_TN' => 'французька (Туніс)',
        'fr_VU' => 'французька (Вануату)',
        'fr_WF' => 'французька (Уолліс і Футуна)',
        'fr_YT' => 'французька (Майотта)',
        'fy' => 'західнофризька',
        'fy_NL' => 'західнофризька (Нідерланди)',
        'ga' => 'ірландська',
        'ga_GB' => 'ірландська (Велика Британія)',
        'ga_IE' => 'ірландська (Ірландія)',
        'gd' => 'шотландська гельська',
        'gd_GB' => 'шотландська гельська (Велика Британія)',
        'gl' => 'галісійська',
        'gl_ES' => 'галісійська (Іспанія)',
        'gu' => 'гуджараті',
        'gu_IN' => 'гуджараті (Індія)',
        'gv' => 'менкська',
        'gv_IM' => 'менкська (Острів Мен)',
        'ha' => 'хауса',
        'ha_GH' => 'хауса (Гана)',
        'ha_NE' => 'хауса (Нігер)',
        'ha_NG' => 'хауса (Нігерія)',
        'he' => 'іврит',
        'he_IL' => 'іврит (Ізраїль)',
        'hi' => 'гінді',
        'hi_IN' => 'гінді (Індія)',
        'hi_Latn' => 'гінді (латиниця)',
        'hi_Latn_IN' => 'гінді (латиниця, Індія)',
        'hr' => 'хорватська',
        'hr_BA' => 'хорватська (Боснія і Герцеговина)',
        'hr_HR' => 'хорватська (Хорватія)',
        'hu' => 'угорська',
        'hu_HU' => 'угорська (Угорщина)',
        'hy' => 'вірменська',
        'hy_AM' => 'вірменська (Вірменія)',
        'ia' => 'інтерлінгва',
        'ia_001' => 'інтерлінгва (Світ)',
        'id' => 'індонезійська',
        'id_ID' => 'індонезійська (Індонезія)',
        'ie' => 'інтерлінгве',
        'ie_EE' => 'інтерлінгве (Естонія)',
        'ig' => 'ігбо',
        'ig_NG' => 'ігбо (Нігерія)',
        'ii' => 'сичуаньська ї',
        'ii_CN' => 'сичуаньська ї (Китай)',
        'is' => 'ісландська',
        'is_IS' => 'ісландська (Ісландія)',
        'it' => 'італійська',
        'it_CH' => 'італійська (Швейцарія)',
        'it_IT' => 'італійська (Італія)',
        'it_SM' => 'італійська (Сан-Марино)',
        'it_VA' => 'італійська (Ватикан)',
        'ja' => 'японська',
        'ja_JP' => 'японська (Японія)',
        'jv' => 'яванська',
        'jv_ID' => 'яванська (Індонезія)',
        'ka' => 'грузинська',
        'ka_GE' => 'грузинська (Грузія)',
        'ki' => 'кікуйю',
        'ki_KE' => 'кікуйю (Кенія)',
        'kk' => 'казахська',
        'kk_Arab' => 'казахська (арабиця)',
        'kk_Arab_CN' => 'казахська (арабиця, Китай)',
        'kk_Cyrl' => 'казахська (кирилиця)',
        'kk_Cyrl_KZ' => 'казахська (кирилиця, Казахстан)',
        'kk_KZ' => 'казахська (Казахстан)',
        'kl' => 'калааллісут',
        'kl_GL' => 'калааллісут (Гренландія)',
        'km' => 'кхмерська',
        'km_KH' => 'кхмерська (Камбоджа)',
        'kn' => 'каннада',
        'kn_IN' => 'каннада (Індія)',
        'ko' => 'корейська',
        'ko_CN' => 'корейська (Китай)',
        'ko_KP' => 'корейська (Північна Корея)',
        'ko_KR' => 'корейська (Південна Корея)',
        'ks' => 'кашмірська',
        'ks_Arab' => 'кашмірська (арабиця)',
        'ks_Arab_IN' => 'кашмірська (арабиця, Індія)',
        'ks_Deva' => 'кашмірська (деванагарі)',
        'ks_Deva_IN' => 'кашмірська (деванагарі, Індія)',
        'ks_IN' => 'кашмірська (Індія)',
        'ku' => 'курдська',
        'ku_Latn' => 'курдська (латиниця)',
        'ku_Latn_IQ' => 'курдська (латиниця, Ірак)',
        'ku_Latn_SY' => 'курдська (латиниця, Сирія)',
        'ku_Latn_TR' => 'курдська (латиниця, Туреччина)',
        'ku_SY' => 'курдська (Сирія)',
        'ku_TR' => 'курдська (Туреччина)',
        'kw' => 'корнська',
        'kw_GB' => 'корнська (Велика Британія)',
        'ky' => 'киргизька',
        'ky_KG' => 'киргизька (Киргизстан)',
        'lb' => 'люксембурзька',
        'lb_LU' => 'люксембурзька (Люксембург)',
        'lg' => 'ганда',
        'lg_UG' => 'ганда (Уганда)',
        'ln' => 'лінгала',
        'ln_AO' => 'лінгала (Ангола)',
        'ln_CD' => 'лінгала (Конго – Кіншаса)',
        'ln_CF' => 'лінгала (Центральноафриканська Республіка)',
        'ln_CG' => 'лінгала (Конго – Браззавіль)',
        'lo' => 'лаоська',
        'lo_LA' => 'лаоська (Лаос)',
        'lt' => 'литовська',
        'lt_LT' => 'литовська (Литва)',
        'lu' => 'луба-катанга',
        'lu_CD' => 'луба-катанга (Конго – Кіншаса)',
        'lv' => 'латиська',
        'lv_LV' => 'латиська (Латвія)',
        'mg' => 'малагасійська',
        'mg_MG' => 'малагасійська (Мадагаскар)',
        'mi' => 'маорі',
        'mi_NZ' => 'маорі (Нова Зеландія)',
        'mk' => 'македонська',
        'mk_MK' => 'македонська (Північна Македонія)',
        'ml' => 'малаялам',
        'ml_IN' => 'малаялам (Індія)',
        'mn' => 'монгольська',
        'mn_MN' => 'монгольська (Монголія)',
        'mr' => 'маратхі',
        'mr_IN' => 'маратхі (Індія)',
        'ms' => 'малайська',
        'ms_BN' => 'малайська (Бруней)',
        'ms_ID' => 'малайська (Індонезія)',
        'ms_MY' => 'малайська (Малайзія)',
        'ms_SG' => 'малайська (Сінгапур)',
        'mt' => 'мальтійська',
        'mt_MT' => 'мальтійська (Мальта)',
        'my' => 'бірманська',
        'my_MM' => 'бірманська (Мʼянма [Бірма])',
        'nb' => 'норвезька [букмол]',
        'nb_NO' => 'норвезька [букмол] (Норвегія)',
        'nb_SJ' => 'норвезька [букмол] (Шпіцберген та Ян-Маєн)',
        'nd' => 'північна ндебеле',
        'nd_ZW' => 'північна ндебеле (Зімбабве)',
        'ne' => 'непальська',
        'ne_IN' => 'непальська (Індія)',
        'ne_NP' => 'непальська (Непал)',
        'nl' => 'нідерландська',
        'nl_AW' => 'нідерландська (Аруба)',
        'nl_BE' => 'нідерландська (Бельгія)',
        'nl_BQ' => 'нідерландська (Карибські Нідерланди)',
        'nl_CW' => 'нідерландська (Кюрасао)',
        'nl_NL' => 'нідерландська (Нідерланди)',
        'nl_SR' => 'нідерландська (Суринам)',
        'nl_SX' => 'нідерландська (Сінт-Мартен)',
        'nn' => 'норвезька [нюношк]',
        'nn_NO' => 'норвезька [нюношк] (Норвегія)',
        'no' => 'норвезька',
        'no_NO' => 'норвезька (Норвегія)',
        'oc' => 'окситанська',
        'oc_ES' => 'окситанська (Іспанія)',
        'oc_FR' => 'окситанська (Франція)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Ефіопія)',
        'om_KE' => 'оромо (Кенія)',
        'or' => 'одія',
        'or_IN' => 'одія (Індія)',
        'os' => 'осетинська',
        'os_GE' => 'осетинська (Грузія)',
        'os_RU' => 'осетинська (Росія)',
        'pa' => 'панджабі',
        'pa_Arab' => 'панджабі (арабиця)',
        'pa_Arab_PK' => 'панджабі (арабиця, Пакистан)',
        'pa_Guru' => 'панджабі (гурмухі)',
        'pa_Guru_IN' => 'панджабі (гурмухі, Індія)',
        'pa_IN' => 'панджабі (Індія)',
        'pa_PK' => 'панджабі (Пакистан)',
        'pl' => 'польська',
        'pl_PL' => 'польська (Польща)',
        'ps' => 'пушту',
        'ps_AF' => 'пушту (Афганістан)',
        'ps_PK' => 'пушту (Пакистан)',
        'pt' => 'португальська',
        'pt_AO' => 'португальська (Ангола)',
        'pt_BR' => 'португальська (Бразилія)',
        'pt_CH' => 'португальська (Швейцарія)',
        'pt_CV' => 'португальська (Кабо-Верде)',
        'pt_GQ' => 'португальська (Екваторіальна Гвінея)',
        'pt_GW' => 'португальська (Гвінея-Бісау)',
        'pt_LU' => 'португальська (Люксембург)',
        'pt_MO' => 'португальська (Макао, ОАР Китаю)',
        'pt_MZ' => 'португальська (Мозамбік)',
        'pt_PT' => 'португальська (Португалія)',
        'pt_ST' => 'португальська (Сан-Томе і Принсіпі)',
        'pt_TL' => 'португальська (Тимор-Лешті)',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Болівія)',
        'qu_EC' => 'кечуа (Еквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'ретороманська',
        'rm_CH' => 'ретороманська (Швейцарія)',
        'rn' => 'рунді',
        'rn_BI' => 'рунді (Бурунді)',
        'ro' => 'румунська',
        'ro_MD' => 'румунська (Молдова)',
        'ro_RO' => 'румунська (Румунія)',
        'ru' => 'російська',
        'ru_BY' => 'російська (Білорусь)',
        'ru_KG' => 'російська (Киргизстан)',
        'ru_KZ' => 'російська (Казахстан)',
        'ru_MD' => 'російська (Молдова)',
        'ru_RU' => 'російська (Росія)',
        'ru_UA' => 'російська (Україна)',
        'rw' => 'кіньяруанда',
        'rw_RW' => 'кіньяруанда (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (Індія)',
        'sc' => 'сардинська',
        'sc_IT' => 'сардинська (Італія)',
        'sd' => 'синдхі',
        'sd_Arab' => 'синдхі (арабиця)',
        'sd_Arab_PK' => 'синдхі (арабиця, Пакистан)',
        'sd_Deva' => 'синдхі (деванагарі)',
        'sd_Deva_IN' => 'синдхі (деванагарі, Індія)',
        'sd_IN' => 'синдхі (Індія)',
        'sd_PK' => 'синдхі (Пакистан)',
        'se' => 'північносаамська',
        'se_FI' => 'північносаамська (Фінляндія)',
        'se_NO' => 'північносаамська (Норвегія)',
        'se_SE' => 'північносаамська (Швеція)',
        'sg' => 'санго',
        'sg_CF' => 'санго (Центральноафриканська Республіка)',
        'sh' => 'сербсько-хорватська',
        'sh_BA' => 'сербсько-хорватська (Боснія і Герцеговина)',
        'si' => 'сингальська',
        'si_LK' => 'сингальська (Шрі-Ланка)',
        'sk' => 'словацька',
        'sk_SK' => 'словацька (Словаччина)',
        'sl' => 'словенська',
        'sl_SI' => 'словенська (Словенія)',
        'sn' => 'шона',
        'sn_ZW' => 'шона (Зімбабве)',
        'so' => 'сомалі',
        'so_DJ' => 'сомалі (Джибуті)',
        'so_ET' => 'сомалі (Ефіопія)',
        'so_KE' => 'сомалі (Кенія)',
        'so_SO' => 'сомалі (Сомалі)',
        'sq' => 'албанська',
        'sq_AL' => 'албанська (Албанія)',
        'sq_MK' => 'албанська (Північна Македонія)',
        'sr' => 'сербська',
        'sr_BA' => 'сербська (Боснія і Герцеговина)',
        'sr_Cyrl' => 'сербська (кирилиця)',
        'sr_Cyrl_BA' => 'сербська (кирилиця, Боснія і Герцеговина)',
        'sr_Cyrl_ME' => 'сербська (кирилиця, Чорногорія)',
        'sr_Cyrl_RS' => 'сербська (кирилиця, Сербія)',
        'sr_Latn' => 'сербська (латиниця)',
        'sr_Latn_BA' => 'сербська (латиниця, Боснія і Герцеговина)',
        'sr_Latn_ME' => 'сербська (латиниця, Чорногорія)',
        'sr_Latn_RS' => 'сербська (латиниця, Сербія)',
        'sr_ME' => 'сербська (Чорногорія)',
        'sr_RS' => 'сербська (Сербія)',
        'st' => 'південна сото',
        'st_LS' => 'південна сото (Лесото)',
        'st_ZA' => 'південна сото (Південно-Африканська Республіка)',
        'su' => 'сунданська',
        'su_ID' => 'сунданська (Індонезія)',
        'su_Latn' => 'сунданська (латиниця)',
        'su_Latn_ID' => 'сунданська (латиниця, Індонезія)',
        'sv' => 'шведська',
        'sv_AX' => 'шведська (Аландські Острови)',
        'sv_FI' => 'шведська (Фінляндія)',
        'sv_SE' => 'шведська (Швеція)',
        'sw' => 'суахілі',
        'sw_CD' => 'суахілі (Конго – Кіншаса)',
        'sw_KE' => 'суахілі (Кенія)',
        'sw_TZ' => 'суахілі (Танзанія)',
        'sw_UG' => 'суахілі (Уганда)',
        'ta' => 'тамільська',
        'ta_IN' => 'тамільська (Індія)',
        'ta_LK' => 'тамільська (Шрі-Ланка)',
        'ta_MY' => 'тамільська (Малайзія)',
        'ta_SG' => 'тамільська (Сінгапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (Індія)',
        'tg' => 'таджицька',
        'tg_TJ' => 'таджицька (Таджикистан)',
        'th' => 'тайська',
        'th_TH' => 'тайська (Таїланд)',
        'ti' => 'тигринья',
        'ti_ER' => 'тигринья (Еритрея)',
        'ti_ET' => 'тигринья (Ефіопія)',
        'tk' => 'туркменська',
        'tk_TM' => 'туркменська (Туркменістан)',
        'tl' => 'тагальська',
        'tl_PH' => 'тагальська (Філіппіни)',
        'tn' => 'тсвана',
        'tn_BW' => 'тсвана (Ботсвана)',
        'tn_ZA' => 'тсвана (Південно-Африканська Республіка)',
        'to' => 'тонганська',
        'to_TO' => 'тонганська (Тонга)',
        'tr' => 'турецька',
        'tr_CY' => 'турецька (Кіпр)',
        'tr_TR' => 'турецька (Туреччина)',
        'tt' => 'татарська',
        'tt_RU' => 'татарська (Росія)',
        'ug' => 'уйгурська',
        'ug_CN' => 'уйгурська (Китай)',
        'uk' => 'українська',
        'uk_UA' => 'українська (Україна)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Індія)',
        'ur_PK' => 'урду (Пакистан)',
        'uz' => 'узбецька',
        'uz_AF' => 'узбецька (Афганістан)',
        'uz_Arab' => 'узбецька (арабиця)',
        'uz_Arab_AF' => 'узбецька (арабиця, Афганістан)',
        'uz_Cyrl' => 'узбецька (кирилиця)',
        'uz_Cyrl_UZ' => 'узбецька (кирилиця, Узбекистан)',
        'uz_Latn' => 'узбецька (латиниця)',
        'uz_Latn_UZ' => 'узбецька (латиниця, Узбекистан)',
        'uz_UZ' => 'узбецька (Узбекистан)',
        'vi' => 'вʼєтнамська',
        'vi_VN' => 'вʼєтнамська (Вʼєтнам)',
        'wo' => 'волоф',
        'wo_SN' => 'волоф (Сенегал)',
        'xh' => 'кхоса',
        'xh_ZA' => 'кхоса (Південно-Африканська Республіка)',
        'yi' => 'їдиш',
        'yi_UA' => 'їдиш (Україна)',
        'yo' => 'йоруба',
        'yo_BJ' => 'йоруба (Бенін)',
        'yo_NG' => 'йоруба (Нігерія)',
        'za' => 'чжуан',
        'za_CN' => 'чжуан (Китай)',
        'zh' => 'китайська',
        'zh_CN' => 'китайська (Китай)',
        'zh_HK' => 'китайська (Гонконг, ОАР Китаю)',
        'zh_Hans' => 'китайська (спрощена)',
        'zh_Hans_CN' => 'китайська (спрощена, Китай)',
        'zh_Hans_HK' => 'китайська (спрощена, Гонконг, ОАР Китаю)',
        'zh_Hans_MO' => 'китайська (спрощена, Макао, ОАР Китаю)',
        'zh_Hans_MY' => 'китайська (спрощена, Малайзія)',
        'zh_Hans_SG' => 'китайська (спрощена, Сінгапур)',
        'zh_Hant' => 'китайська (традиційна)',
        'zh_Hant_HK' => 'китайська (традиційна, Гонконг, ОАР Китаю)',
        'zh_Hant_MO' => 'китайська (традиційна, Макао, ОАР Китаю)',
        'zh_Hant_MY' => 'китайська (традиційна, Малайзія)',
        'zh_Hant_TW' => 'китайська (традиційна, Тайвань)',
        'zh_MO' => 'китайська (Макао, ОАР Китаю)',
        'zh_SG' => 'китайська (Сінгапур)',
        'zh_TW' => 'китайська (Тайвань)',
        'zu' => 'зулуська',
        'zu_ZA' => 'зулуська (Південно-Африканська Республіка)',
    ],
];
