<?php

return [
    'Names' => [
        'en' => 'anglés',
        'en_ES' => 'anglés (Espanha)',
        'en_FR' => 'anglés (França)',
        'en_HK' => 'anglés (Hong Kong)',
        'oc' => 'occitan',
        'oc_ES' => 'occitan (Espanha)',
        'oc_FR' => 'occitan (França)',
    ],
];
