<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Дирхам ӀЦЭ',
        ],
        'AFN' => [
            'AFN',
            'ОвхӀан-пачхьалкхан афгани',
        ],
        'ALL' => [
            'ALL',
            'Албанин лек',
        ],
        'AMD' => [
            'AMD',
            'Эрмалойчоьнан драм',
        ],
        'ANG' => [
            'ANG',
            'Нидерландин Антилин гульден',
        ],
        'AOA' => [
            'AOA',
            'Анголан кванза',
        ],
        'ARS' => [
            'ARS',
            'Аргентинан песо',
        ],
        'AUD' => [
            'A$',
            'Австралин доллар',
        ],
        'AWG' => [
            'AWG',
            'Арубан флорин',
        ],
        'AZN' => [
            'AZN',
            'Азербайджанан манат',
        ],
        'BAM' => [
            'BAM',
            'Боснин а, Герцеговинан а хийцалун марка',
        ],
        'BBD' => [
            'BBD',
            'Барбадосан доллар',
        ],
        'BDT' => [
            'BDT',
            'Бангладешан така',
        ],
        'BGN' => [
            'BGN',
            'Болгарин лев',
        ],
        'BHD' => [
            'BHD',
            'Бахрейнан динар',
        ],
        'BIF' => [
            'BIF',
            'Бурундин франк',
        ],
        'BMD' => [
            'BMD',
            'Бермудан доллар',
        ],
        'BND' => [
            'BND',
            'Брунейн доллар',
        ],
        'BOB' => [
            'BOB',
            'Боливин боливиано',
        ],
        'BRL' => [
            'R$',
            'Бразилин реал',
        ],
        'BSD' => [
            'BSD',
            'Багаман доллар',
        ],
        'BTN' => [
            'BTN',
            'Бутанан нгултрум',
        ],
        'BWP' => [
            'BWP',
            'Ботсванан пула',
        ],
        'BYN' => [
            'BYN',
            'Белоруссин сом',
        ],
        'BYR' => [
            'BYR',
            'Белоруссин сом (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Белизин доллар',
        ],
        'CAD' => [
            'CA$',
            'Канадан доллар',
        ],
        'CDF' => [
            'CDF',
            'Конголезин франк',
        ],
        'CHF' => [
            'CHF',
            'Швейцарин франк',
        ],
        'CLP' => [
            'CLP',
            'Чилин песо',
        ],
        'CNY' => [
            'CN¥',
            'Китайн юань',
        ],
        'COP' => [
            'COP',
            'Колумбин песо',
        ],
        'CRC' => [
            'CRC',
            'Костарикан колон',
        ],
        'CUC' => [
            'CUC',
            'Кубан хийцалун песо',
        ],
        'CUP' => [
            'CUP',
            'Кубан песо',
        ],
        'CVE' => [
            'CVE',
            'Кабо-Верден эскудо',
        ],
        'CZK' => [
            'CZK',
            'Чехин крона',
        ],
        'DJF' => [
            'DJF',
            'Джибутин франк',
        ],
        'DKK' => [
            'DKK',
            'Данин крона',
        ],
        'DOP' => [
            'DOP',
            'Доминикан песо',
        ],
        'DZD' => [
            'DZD',
            'Алжиран динар',
        ],
        'EGP' => [
            'EGP',
            'Мисаран фунт',
        ],
        'ERN' => [
            'ERN',
            'Эритрейн накфа',
        ],
        'ETB' => [
            'ETB',
            'Эфиопин быр',
        ],
        'EUR' => [
            '€',
            'Евро',
        ],
        'FJD' => [
            'FJD',
            'Фиджин доллар',
        ],
        'FKP' => [
            'FKP',
            'Фолклендан гӀайренийн фунт',
        ],
        'GBP' => [
            '£',
            'Англин фунт',
        ],
        'GEL' => [
            'GEL',
            'Гуьржийчоьнан лари',
        ],
        'GHS' => [
            'GHS',
            'Ганан седи',
        ],
        'GIP' => [
            'GIP',
            'Гибралтаран фунт',
        ],
        'GMD' => [
            'GMD',
            'Гамбин даласи',
        ],
        'GNF' => [
            'GNF',
            'Гвинейн франк',
        ],
        'GTQ' => [
            'GTQ',
            'Гватемалан кетсаль',
        ],
        'GYD' => [
            'GYD',
            'Гайанан доллар',
        ],
        'HKD' => [
            'HK$',
            'Гонконган доллар',
        ],
        'HNL' => [
            'HNL',
            'Гондурасан лемпира',
        ],
        'HRK' => [
            'HRK',
            'Хорватин куна',
        ],
        'HTG' => [
            'HTG',
            'Гаитин гурд',
        ],
        'HUF' => [
            'HUF',
            'Венгрин форинт',
        ],
        'IDR' => [
            'IDR',
            'Индонезин рупи',
        ],
        'ILS' => [
            '₪',
            'Израилан керла шекель',
        ],
        'INR' => [
            '₹',
            'Индин рупи',
        ],
        'IQD' => [
            'IQD',
            'Ӏиракъан динар',
        ],
        'IRR' => [
            'IRR',
            'ГӀажарийчоьнан риал',
        ],
        'ISK' => [
            'ISK',
            'Исландин крона',
        ],
        'JMD' => [
            'JMD',
            'Ямайн доллар',
        ],
        'JOD' => [
            'JOD',
            'Урданан динар',
        ],
        'JPY' => [
            'JP¥',
            'Японин иена',
        ],
        'KES' => [
            'KES',
            'Кенин шиллинг',
        ],
        'KGS' => [
            'KGS',
            'Киргизин сом',
        ],
        'KHR' => [
            'KHR',
            'Камбоджан риель',
        ],
        'KMF' => [
            'KMF',
            'Коморийн гӀайренийн франк',
        ],
        'KPW' => [
            'KPW',
            'Къилбаседа Корейн вона',
        ],
        'KRW' => [
            '₩',
            'Къилба Корейн вона',
        ],
        'KWD' => [
            'KWD',
            'Кувейтан динар',
        ],
        'KYD' => [
            'KYD',
            'Кайманийн гӀайренийн доллар',
        ],
        'KZT' => [
            'KZT',
            'Кхазакхстанан тенге',
        ],
        'LAK' => [
            'LAK',
            'Лаосан кип',
        ],
        'LBP' => [
            'LBP',
            'Ливанан фунт',
        ],
        'LKR' => [
            'LKR',
            'Шри-Ланкан рупи',
        ],
        'LRD' => [
            'LRD',
            'Либерин доллар',
        ],
        'LYD' => [
            'LYD',
            'Ливин динар',
        ],
        'MAD' => [
            'MAD',
            'Мароккон дирхам',
        ],
        'MDL' => [
            'MDL',
            'Молдавин лей',
        ],
        'MGA' => [
            'MGA',
            'Малагасийн ариари',
        ],
        'MKD' => [
            'MKD',
            'Македонин динар',
        ],
        'MMK' => [
            'MMK',
            'Мьянман кьят',
        ],
        'MNT' => [
            'MNT',
            'Монголин тугрик',
        ],
        'MOP' => [
            'MOP',
            'Макаон патака',
        ],
        'MRO' => [
            'MRO',
            'Мавританин уги (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Мавританин уги',
        ],
        'MUR' => [
            'MUR',
            'Маврикин рупи',
        ],
        'MVR' => [
            'MVR',
            'Мальдивийн руфи',
        ],
        'MWK' => [
            'MWK',
            'Малавин квача',
        ],
        'MXN' => [
            'MX$',
            'Мексикан песо',
        ],
        'MYR' => [
            'MYR',
            'Малайзин ринггит',
        ],
        'MZN' => [
            'MZN',
            'Мозамбикан метикал',
        ],
        'NAD' => [
            'NAD',
            'Намибин доллар',
        ],
        'NGN' => [
            'NGN',
            'Нигерин найра',
        ],
        'NIO' => [
            'NIO',
            'Никарагуан кордоба',
        ],
        'NOK' => [
            'NOK',
            'Норвегин крона',
        ],
        'NPR' => [
            'NPR',
            'Непалан рупи',
        ],
        'NZD' => [
            'NZ$',
            'Керла Зеландин доллар',
        ],
        'OMR' => [
            'OMR',
            'Оманан риал',
        ],
        'PAB' => [
            'PAB',
            'Панаман бальбоа',
        ],
        'PEN' => [
            'PEN',
            'Перун соль',
        ],
        'PGK' => [
            'PGK',
            'Папуа — Керла Гвинейн кина',
        ],
        'PHP' => [
            'PHP',
            'Филиппинийн песо',
        ],
        'PKR' => [
            'PKR',
            'Пакистанан рупи',
        ],
        'PLN' => [
            'PLN',
            'Польшан злотый',
        ],
        'PYG' => [
            'PYG',
            'Парагвайн гуарани',
        ],
        'QAR' => [
            'QAR',
            'Катаран риал',
        ],
        'RON' => [
            'RON',
            'Румынин лей',
        ],
        'RSD' => [
            'RSD',
            'Сербин динар',
        ],
        'RUB' => [
            '₽',
            'Российн сом',
        ],
        'RWF' => [
            'RWF',
            'Руандан франк',
        ],
        'SAR' => [
            'SAR',
            'СаӀудийн Ӏаьрбийчоьнан риал',
        ],
        'SBD' => [
            'SBD',
            'Соломонан гӀайренийн доллар',
        ],
        'SCR' => [
            'SCR',
            'Сейшелан рупи',
        ],
        'SDG' => [
            'SDG',
            'Суданан фунт',
        ],
        'SEK' => [
            'SEK',
            'Швецин крона',
        ],
        'SGD' => [
            'SGD',
            'Сингапуран доллар',
        ],
        'SHP' => [
            'SHP',
            'Сийлахьчу Еленин гӀайрен фунт',
        ],
        'SLE' => [
            'SLE',
            'Леоне',
        ],
        'SLL' => [
            'SLL',
            'Леоне (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Сомалин шиллинг',
        ],
        'SRD' => [
            'SRD',
            'Суринаман доллар',
        ],
        'SSP' => [
            'SSP',
            'Къилба Суданан фунт',
        ],
        'STD' => [
            'STD',
            'Сан-Томен а, Принсипин а добра (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Сан-Томен а, Принсипин а добра',
        ],
        'SYP' => [
            'SYP',
            'Шеман фунт',
        ],
        'SZL' => [
            'SZL',
            'Свазилендан лилангени',
        ],
        'THB' => [
            'THB',
            'Таиландан бат',
        ],
        'TJS' => [
            'TJS',
            'Таджикистанан сомони',
        ],
        'TMT' => [
            'TMT',
            'Туркменин керла манат',
        ],
        'TND' => [
            'TND',
            'Тунисан динар',
        ],
        'TOP' => [
            'TOP',
            'Тонганан паанга',
        ],
        'TRY' => [
            'TRY',
            'Туркойчоьнан лира',
        ],
        'TTD' => [
            'TTD',
            'Тринидадан а, Тобагон а доллар',
        ],
        'TWD' => [
            'NT$',
            'Тайванан керла доллар',
        ],
        'TZS' => [
            'TZS',
            'Танзанин шиллинг',
        ],
        'UAH' => [
            'UAH',
            'Украинан гривна',
        ],
        'UGX' => [
            'UGX',
            'Угандан шиллинг',
        ],
        'USD' => [
            'US$',
            'АЦШн доллар',
        ],
        'UYU' => [
            'UYU',
            'Уругвайн песо',
        ],
        'UZS' => [
            'UZS',
            'Узбекистанан сом',
        ],
        'VEF' => [
            'VEF',
            'Венесуэлан боливар (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Венесуэлан боливар',
        ],
        'VND' => [
            '₫',
            'Вьетнаман донг',
        ],
        'VUV' => [
            'VUV',
            'Вануатун вату',
        ],
        'WST' => [
            'WST',
            'Самоанан тала',
        ],
        'XAF' => [
            'FCFA',
            'Юккъерчу Африкан КФА франк',
        ],
        'XCD' => [
            'EC$',
            'Малхбален Карибийн доллар',
        ],
        'XOF' => [
            'F CFA',
            'Малхбузен Африкан КФА франк',
        ],
        'XPF' => [
            'CFPF',
            'Французийн Тийна океанан франк',
        ],
        'YER' => [
            'YER',
            'Йеменан риал',
        ],
        'ZAR' => [
            'ZAR',
            'Къилба-Африкин рэнд',
        ],
        'ZMW' => [
            'ZMW',
            'Замбин квача',
        ],
    ],
];
