<?php

return [
    'Names' => [
        'AUD' => [
            'A$',
            'دالر آسترالیا',
        ],
        'BND' => [
            'BND',
            'دالر برونی',
        ],
        'BYN' => [
            'BYN',
            'روبل روسیهٔ سفید',
        ],
        'BYR' => [
            'BYR',
            'روبل روسیهٔ سفید (۲۰۰۰–۲۰۱۶)',
        ],
        'CAD' => [
            '$CA',
            'دالر کانادا',
        ],
        'CHF' => [
            'CHF',
            'فرانک سویس',
        ],
        'DKK' => [
            'DKK',
            'کرون دنمارک',
        ],
        'JPY' => [
            '¥',
            'ین جاپان',
        ],
        'MXN' => [
            '$MX',
            'پزوی مکسیکو',
        ],
        'NLG' => [
            'NLG',
            'گیلدر هالند',
        ],
        'NOK' => [
            'NOK',
            'کرون ناروی',
        ],
        'SEK' => [
            'SEK',
            'کرون سویدن',
        ],
        'SGD' => [
            'SGD',
            'دالر سینگاپور',
        ],
        'TJS' => [
            'TJS',
            'سامانی تاجکستان',
        ],
        'USD' => [
            '$',
            'دالر امریکا',
        ],
    ],
];
