<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Srednje vrijeme po Griniču (Abidžan)',
        'Africa/Accra' => 'Srednje vrijeme po Griniču (Akra)',
        'Africa/Addis_Ababa' => 'Istočno-afričko vrijeme (Adis Abeba)',
        'Africa/Algiers' => 'Srednjoevropsko vrijeme (Alžir)',
        'Africa/Asmera' => 'Istočno-afričko vrijeme (Asmera)',
        'Africa/Asmara' => 'Istočno-afričko vrijeme (Asmera)',
        'Africa/Bamako' => 'Srednje vrijeme po Griniču (Bamako)',
        'Africa/Bangui' => 'Zapadno-afričko vrijeme (Bangui)',
        'Africa/Banjul' => 'Srednje vrijeme po Griniču (Banžul)',
        'Africa/Bissau' => 'Srednje vrijeme po Griniču (Bisao)',
        'Africa/Blantyre' => 'Centralno-afričko vrijeme (Blantir)',
        'Africa/Brazzaville' => 'Zapadno-afričko vrijeme (Brazavil)',
        'Africa/Bujumbura' => 'Centralno-afričko vrijeme (Budžumbura)',
        'Africa/Cairo' => 'Istočnoevropsko vrijeme (Kairo)',
        'Africa/Casablanca' => 'Zapadnoevropsko vrijeme (Kazablanka)',
        'Africa/Ceuta' => 'Srednjoevropsko vrijeme (Seuta)',
        'Africa/Conakry' => 'Srednje vrijeme po Griniču (Konakri)',
        'Africa/Dakar' => 'Srednje vrijeme po Griniču (Dakar)',
        'Africa/Dar_es_Salaam' => 'Istočno-afričko vrijeme (Dar-es-Salam)',
        'Africa/Djibouti' => 'Istočno-afričko vrijeme (Džibuti)',
        'Africa/Douala' => 'Zapadno-afričko vrijeme (Duala)',
        'Africa/El_Aaiun' => 'Zapadnoevropsko vrijeme (El Ajun)',
        'Africa/Freetown' => 'Srednje vrijeme po Griniču (Fritaun)',
        'Africa/Gaborone' => 'Centralno-afričko vrijeme (Gaboron)',
        'Africa/Harare' => 'Centralno-afričko vrijeme (Harare)',
        'Africa/Johannesburg' => 'Južno-afričko vrijeme (Johanesburg)',
        'Africa/Juba' => 'Centralno-afričko vrijeme (Džuba)',
        'Africa/Kampala' => 'Istočno-afričko vrijeme (Kampala)',
        'Africa/Khartoum' => 'Centralno-afričko vrijeme (Kartum)',
        'Africa/Kigali' => 'Centralno-afričko vrijeme (Kigali)',
        'Africa/Kinshasa' => 'Zapadno-afričko vrijeme (Kinšasa)',
        'Africa/Lagos' => 'Zapadno-afričko vrijeme (Lagos)',
        'Africa/Libreville' => 'Zapadno-afričko vrijeme (Librevil)',
        'Africa/Lome' => 'Srednje vrijeme po Griniču (Lome)',
        'Africa/Luanda' => 'Zapadno-afričko vrijeme (Luanda)',
        'Africa/Lubumbashi' => 'Centralno-afričko vrijeme (Lubumbaši)',
        'Africa/Lusaka' => 'Centralno-afričko vrijeme (Lusaka)',
        'Africa/Malabo' => 'Zapadno-afričko vrijeme (Malabo)',
        'Africa/Maputo' => 'Centralno-afričko vrijeme (Maputo)',
        'Africa/Maseru' => 'Južno-afričko vrijeme (Maseru)',
        'Africa/Mbabane' => 'Južno-afričko vrijeme (Mbabane)',
        'Africa/Mogadishu' => 'Istočno-afričko vrijeme (Mogadiš)',
        'Africa/Monrovia' => 'Srednje vrijeme po Griniču (Monrovija)',
        'Africa/Nairobi' => 'Istočno-afričko vrijeme (Najrobi)',
        'Africa/Ndjamena' => 'Zapadno-afričko vrijeme (Ndžamena)',
        'Africa/Niamey' => 'Zapadno-afričko vrijeme (Nijamej)',
        'Africa/Nouakchott' => 'Srednje vrijeme po Griniču (Nuakšot)',
        'Africa/Ouagadougou' => 'Srednje vrijeme po Griniču (Uagadugu)',
        'Africa/Porto-Novo' => 'Zapadno-afričko vrijeme (Porto Novo)',
        'Africa/Sao_Tome' => 'Srednje vrijeme po Griniču (Sao Tome)',
        'Africa/Tripoli' => 'Istočnoevropsko vrijeme (Tripoli)',
        'Africa/Tunis' => 'Srednjoevropsko vrijeme (Tunis)',
        'Africa/Windhoek' => 'Centralno-afričko vrijeme (Vindhuk)',
        'America/Adak' => 'Havajsko-aleutsko vrijeme (Adak)',
        'America/Anguilla' => 'Atlantsko vrijeme (Angvila)',
        'America/Antigua' => 'Atlantsko vrijeme (Antigva)',
        'America/Araguaina' => 'Brazilija vrijeme (Aragvajana)',
        'America/Argentina/La_Rioja' => 'Argentina vrijeme (La Rioha)',
        'America/Argentina/Rio_Gallegos' => 'Argentina vrijeme (Rio Galjegos)',
        'America/Argentina/Salta' => 'Argentina vrijeme (Salta)',
        'America/Argentina/San_Juan' => 'Argentina vrijeme (San Huan)',
        'America/Argentina/San_Luis' => 'Argentina vrijeme (San Lui)',
        'America/Argentina/Tucuman' => 'Argentina vrijeme (Tukuman)',
        'America/Argentina/Ushuaia' => 'Argentina vrijeme (Ušuaija)',
        'America/Aruba' => 'Atlantsko vrijeme (Aruba)',
        'America/Asuncion' => 'Paragvaj vrijeme (Asunsion)',
        'America/Bahia' => 'Brazilija vrijeme (Baija)',
        'America/Bahia_Banderas' => 'Sjevernoameričko centralno vrijeme (Baija Banderas)',
        'America/Barbados' => 'Atlantsko vrijeme (Barbados)',
        'America/Belem' => 'Brazilija vrijeme (Belem)',
        'America/Belize' => 'Sjevernoameričko centralno vrijeme (Belize)',
        'America/Blanc-Sablon' => 'Atlantsko vrijeme (Blank-Sejblon)',
        'America/Boa_Vista' => 'Amazon vrijeme (Boa Vista)',
        'America/Bogota' => 'Kolumbija vrijeme (Bogota)',
        'America/Boise' => 'Sjevernoameričko planinsko vrijeme (Bojzi)',
        'America/Buenos_Aires' => 'Argentina vrijeme (Buenos Ajres)',
        'America/Argentina/Buenos_Aires' => 'Argentina vrijeme (Buenos Ajres)',
        'America/Cambridge_Bay' => 'Sjevernoameričko planinsko vrijeme (Kembridž Bej)',
        'America/Campo_Grande' => 'Amazon vrijeme (Kampo Grande)',
        'America/Cancun' => 'Sjevernoameričko istočno vrijeme (Kankun)',
        'America/Caracas' => 'Venecuela vrijeme (Karakas)',
        'America/Catamarca' => 'Argentina vrijeme (Katamarka)',
        'America/Argentina/Catamarca' => 'Argentina vrijeme (Katamarka)',
        'America/Cayenne' => 'Francuska Gvajana vrijeme (Kajen)',
        'America/Cayman' => 'Sjevernoameričko istočno vrijeme (Kajmanska Ostrva)',
        'America/Chicago' => 'Sjevernoameričko centralno vrijeme (Čikago)',
        'America/Chihuahua' => 'Sjevernoameričko centralno vrijeme (Čihuahua)',
        'America/Ciudad_Juarez' => 'Sjevernoameričko planinsko vrijeme (Siudad Huarez)',
        'America/Coral_Harbour' => 'Sjevernoameričko istočno vrijeme (Koral Harbur)',
        'America/Atikokan' => 'Sjevernoameričko istočno vrijeme (Koral Harbur)',
        'America/Cordoba' => 'Argentina vrijeme (Kordoba)',
        'America/Argentina/Cordoba' => 'Argentina vrijeme (Kordoba)',
        'America/Costa_Rica' => 'Sjevernoameričko centralno vrijeme (Kostarika)',
        'America/Coyhaique' => 'Čile vrijeme (Kojajke)',
        'America/Creston' => 'Sjevernoameričko planinsko vrijeme (Kreston)',
        'America/Cuiaba' => 'Amazon vrijeme (Kuiaba)',
        'America/Curacao' => 'Atlantsko vrijeme (Kurasao)',
        'America/Danmarkshavn' => 'Srednje vrijeme po Griniču (Danmarkshagen)',
        'America/Dawson_Creek' => 'Sjevernoameričko planinsko vrijeme (Doson Krik)',
        'America/Denver' => 'Sjevernoameričko planinsko vrijeme (Denver)',
        'America/Detroit' => 'Sjevernoameričko istočno vrijeme (Detroit)',
        'America/Dominica' => 'Atlantsko vrijeme (Dominika)',
        'America/Edmonton' => 'Sjevernoameričko planinsko vrijeme (Edmonton)',
        'America/El_Salvador' => 'Sjevernoameričko centralno vrijeme (Salvador)',
        'America/Fort_Nelson' => 'Sjevernoameričko planinsko vrijeme (Fort Nelson)',
        'America/Fortaleza' => 'Brazilija vrijeme (Fortaleza)',
        'America/Glace_Bay' => 'Atlantsko vrijeme (Glejs Bej)',
        'America/Goose_Bay' => 'Atlantsko vrijeme (Gus Bej)',
        'America/Grand_Turk' => 'Sjevernoameričko istočno vrijeme (Grand Turk)',
        'America/Grenada' => 'Atlantsko vrijeme (Grenada)',
        'America/Guadeloupe' => 'Atlantsko vrijeme (Gvadalupe)',
        'America/Guatemala' => 'Sjevernoameričko centralno vrijeme (Gvatemala)',
        'America/Guayaquil' => 'Ekvador vrijeme (Gvajakil)',
        'America/Guyana' => 'Gvajana vrijeme',
        'America/Halifax' => 'Atlantsko vrijeme (Halifaks)',
        'America/Indiana/Knox' => 'Sjevernoameričko centralno vrijeme (Noks, Indijana)',
        'America/Indiana/Marengo' => 'Sjevernoameričko istočno vrijeme (Marengo, Indijana)',
        'America/Indiana/Petersburg' => 'Sjevernoameričko istočno vrijeme (Pitersburg, Indijana)',
        'America/Indiana/Tell_City' => 'Sjevernoameričko centralno vrijeme (Tel Siti, Indijana)',
        'America/Indiana/Vevay' => 'Sjevernoameričko istočno vrijeme (Vivi, Indijana)',
        'America/Indiana/Vincennes' => 'Sjevernoameričko istočno vrijeme (Vinsens, Indijana)',
        'America/Indiana/Winamac' => 'Sjevernoameričko istočno vrijeme (Vinamak, Indijana)',
        'America/Indianapolis' => 'Sjevernoameričko istočno vrijeme (Indijanapolis)',
        'America/Indiana/Indianapolis' => 'Sjevernoameričko istočno vrijeme (Indijanapolis)',
        'America/Inuvik' => 'Sjevernoameričko planinsko vrijeme (Inuvik)',
        'America/Iqaluit' => 'Sjevernoameričko istočno vrijeme (Ikvaluit)',
        'America/Jamaica' => 'Sjevernoameričko istočno vrijeme (Jamajka)',
        'America/Jujuy' => 'Argentina vrijeme (Žužui)',
        'America/Argentina/Jujuy' => 'Argentina vrijeme (Žužui)',
        'America/Kentucky/Monticello' => 'Sjevernoameričko istočno vrijeme (Montičelo, Kentaki)',
        'America/Kralendijk' => 'Atlantsko vrijeme (Kralendajk)',
        'America/La_Paz' => 'Bolivija vrijeme (La Paz)',
        'America/Lima' => 'Peru vrijeme (Lima)',
        'America/Los_Angeles' => 'Sjevernoameričko pacifičko vrijeme (Los Anđeles)',
        'America/Louisville' => 'Sjevernoameričko istočno vrijeme (Luivil)',
        'America/Kentucky/Louisville' => 'Sjevernoameričko istočno vrijeme (Luivil)',
        'America/Lower_Princes' => 'Atlantsko vrijeme (Louer Prinsiz Kvorter)',
        'America/Maceio' => 'Brazilija vrijeme (Masejo)',
        'America/Managua' => 'Sjevernoameričko centralno vrijeme (Managva)',
        'America/Manaus' => 'Amazon vrijeme (Manaus)',
        'America/Marigot' => 'Atlantsko vrijeme (Marigo)',
        'America/Martinique' => 'Atlantsko vrijeme (Martinik)',
        'America/Matamoros' => 'Sjevernoameričko centralno vrijeme (Matamoros)',
        'America/Mendoza' => 'Argentina vrijeme (Mendosa)',
        'America/Argentina/Mendoza' => 'Argentina vrijeme (Mendosa)',
        'America/Menominee' => 'Sjevernoameričko centralno vrijeme (Menomini)',
        'America/Merida' => 'Sjevernoameričko centralno vrijeme (Merida)',
        'America/Mexico_City' => 'Sjevernoameričko centralno vrijeme (Meksiko Siti)',
        'America/Moncton' => 'Atlantsko vrijeme (Monkton)',
        'America/Monterrey' => 'Sjevernoameričko centralno vrijeme (Monterej)',
        'America/Montevideo' => 'Urugvaj vrijeme (Montevideo)',
        'America/Montserrat' => 'Atlantsko vrijeme (Montserat)',
        'America/Nassau' => 'Sjevernoameričko istočno vrijeme (Nasau)',
        'America/New_York' => 'Sjevernoameričko istočno vrijeme (Njujork)',
        'America/Noronha' => 'Fernando de Noronja vrijeme',
        'America/North_Dakota/Beulah' => 'Sjevernoameričko centralno vrijeme (Bjula, Sjeverna Dakota)',
        'America/North_Dakota/Center' => 'Sjevernoameričko centralno vrijeme (Centar, Sjeverna Dakota)',
        'America/North_Dakota/New_Salem' => 'Sjevernoameričko centralno vrijeme (Novi Salem, Sjeverna Dakota)',
        'America/Ojinaga' => 'Sjevernoameričko centralno vrijeme (Ohinaga)',
        'America/Panama' => 'Sjevernoameričko istočno vrijeme (Panama)',
        'America/Paramaribo' => 'Surinam vrijeme (Paramaribo)',
        'America/Phoenix' => 'Sjevernoameričko planinsko vrijeme (Finiks)',
        'America/Port-au-Prince' => 'Sjevernoameričko istočno vrijeme (Port-o-Prens)',
        'America/Port_of_Spain' => 'Atlantsko vrijeme (Port ov Spejn)',
        'America/Porto_Velho' => 'Amazon vrijeme (Porto Veljo)',
        'America/Puerto_Rico' => 'Atlantsko vrijeme (Portoriko)',
        'America/Punta_Arenas' => 'Čile vrijeme (Punta Arenas)',
        'America/Rankin_Inlet' => 'Sjevernoameričko centralno vrijeme (Rankin Inlet)',
        'America/Recife' => 'Brazilija vrijeme (Resife)',
        'America/Regina' => 'Sjevernoameričko centralno vrijeme (Redžajna)',
        'America/Resolute' => 'Sjevernoameričko centralno vrijeme (Rezolut)',
        'America/Santarem' => 'Brazilija vrijeme (Santarem)',
        'America/Santiago' => 'Čile vrijeme (Santjago)',
        'America/Santo_Domingo' => 'Atlantsko vrijeme (Santo Domingo)',
        'America/Sao_Paulo' => 'Brazilija vrijeme (Sao Paolo)',
        'America/Scoresbysund' => 'Grenland (Itokortormit)',
        'America/St_Barthelemy' => 'Atlantsko vrijeme (Sen Bartelemi)',
        'America/St_Johns' => 'Njufaundlend (Sent Džons)',
        'America/St_Kitts' => 'Atlantsko vrijeme (Sent Kits)',
        'America/St_Lucia' => 'Atlantsko vrijeme (Sv. Lucija)',
        'America/St_Thomas' => 'Atlantsko vrijeme (Sent Tomas)',
        'America/St_Vincent' => 'Atlantsko vrijeme (Sent Vinsent)',
        'America/Swift_Current' => 'Sjevernoameričko centralno vrijeme (Svift Karent)',
        'America/Tegucigalpa' => 'Sjevernoameričko centralno vrijeme (Tegusigalpa)',
        'America/Thule' => 'Atlantsko vrijeme (Tul)',
        'America/Tijuana' => 'Sjevernoameričko pacifičko vrijeme (Tihuana)',
        'America/Toronto' => 'Sjevernoameričko istočno vrijeme (Toronto)',
        'America/Tortola' => 'Atlantsko vrijeme (Tortola)',
        'America/Vancouver' => 'Sjevernoameričko pacifičko vrijeme (Vankuver)',
        'America/Winnipeg' => 'Sjevernoameričko centralno vrijeme (Vinipeg)',
        'Antarctica/Casey' => 'Australijsko zapadno vrijeme (Kejsi)',
        'Antarctica/Davis' => 'Dejvis vrijeme',
        'Antarctica/DumontDUrville' => 'Dimon d’Irvil vrijeme',
        'Antarctica/Macquarie' => 'Australijsko istočno vrijeme (Makvori)',
        'Antarctica/Mawson' => 'Moson vrijeme',
        'Antarctica/McMurdo' => 'Novi Zeland vrijeme (Makmurdo)',
        'Antarctica/Palmer' => 'Čile vrijeme (Palmer)',
        'Antarctica/Rothera' => 'Rotera vrijeme',
        'Antarctica/Syowa' => 'Šova vrijeme',
        'Antarctica/Troll' => 'Srednje vrijeme po Griniču (Trol)',
        'Antarctica/Vostok' => 'Vostok vrijeme',
        'Arctic/Longyearbyen' => 'Srednjoevropsko vrijeme (Longjir)',
        'Asia/Aden' => 'Arabijsko vrijeme (Aden)',
        'Asia/Almaty' => 'Kazahstansko vrijeme (Almati)',
        'Asia/Amman' => 'Istočnoevropsko vrijeme (Aman)',
        'Asia/Aqtau' => 'Kazahstansko vrijeme (Aktau)',
        'Asia/Aqtobe' => 'Kazahstansko vrijeme (Akutobe)',
        'Asia/Ashgabat' => 'Turkmenistan vrijeme (Ašhabad)',
        'Asia/Atyrau' => 'Kazahstansko vrijeme (Atirau)',
        'Asia/Baghdad' => 'Arabijsko vrijeme (Bagdad)',
        'Asia/Bahrain' => 'Arabijsko vrijeme (Bahrein)',
        'Asia/Baku' => 'Azerbejdžan vrijeme (Baku)',
        'Asia/Bangkok' => 'Indokina vrijeme (Bangkok)',
        'Asia/Barnaul' => 'Krasnojarsk vrijeme (Barnaul)',
        'Asia/Beirut' => 'Istočnoevropsko vrijeme (Bejrut)',
        'Asia/Bishkek' => 'Kirgistan vrijeme (Biškek)',
        'Asia/Brunei' => 'Brunej Darusalum vrijeme',
        'Asia/Calcutta' => 'Indijsko standardno vrijeme (Kalkuta)',
        'Asia/Kolkata' => 'Indijsko standardno vrijeme (Kalkuta)',
        'Asia/Chita' => 'Jakutsk vrijeme (Čita)',
        'Asia/Colombo' => 'Indijsko standardno vrijeme (Kolombo)',
        'Asia/Damascus' => 'Istočnoevropsko vrijeme (Damask)',
        'Asia/Dhaka' => 'Bangladeš vrijeme (Daka)',
        'Asia/Dili' => 'Istočni Timor vrijeme (Dili)',
        'Asia/Dubai' => 'Zalivsko vrijeme (Dubai)',
        'Asia/Dushanbe' => 'Tadžikistan vrijeme (Dušanbe)',
        'Asia/Famagusta' => 'Istočnoevropsko vrijeme (Famagusta)',
        'Asia/Gaza' => 'Istočnoevropsko vrijeme (Gaza)',
        'Asia/Hebron' => 'Istočnoevropsko vrijeme (Hebron)',
        'Asia/Hong_Kong' => 'Hong Kong vrijeme (Hongkong)',
        'Asia/Hovd' => 'Hovd vrijeme',
        'Asia/Irkutsk' => 'Irkuck vrijeme',
        'Asia/Jakarta' => 'Zapadno-indonezijsko vrijeme (Džakarta)',
        'Asia/Jayapura' => 'Istočno-indonezijsko vrijeme (Džajapura)',
        'Asia/Jerusalem' => 'Izraelsko vrijeme (Jerusalim)',
        'Asia/Kabul' => 'Avganistan vrijeme (Kabul)',
        'Asia/Karachi' => 'Pakistan vrijeme (Karači)',
        'Asia/Katmandu' => 'Nepal vrijeme (Katmandu)',
        'Asia/Kathmandu' => 'Nepal vrijeme (Katmandu)',
        'Asia/Khandyga' => 'Jakutsk vrijeme (Handiga)',
        'Asia/Krasnoyarsk' => 'Krasnojarsk vrijeme',
        'Asia/Kuala_Lumpur' => 'Malezija vrijeme (Kuala Lumpur)',
        'Asia/Kuching' => 'Malezija vrijeme (Kučing)',
        'Asia/Kuwait' => 'Arabijsko vrijeme (Kuvajt)',
        'Asia/Macau' => 'Kina vrijeme (Makao)',
        'Asia/Magadan' => 'Magadan vrijeme',
        'Asia/Makassar' => 'Centralno-indonezijsko vrijeme (Makasar)',
        'Asia/Manila' => 'Filipini vrijeme (Manila)',
        'Asia/Muscat' => 'Zalivsko vrijeme (Muskat)',
        'Asia/Nicosia' => 'Istočnoevropsko vrijeme (Nikozija)',
        'Asia/Novokuznetsk' => 'Krasnojarsk vrijeme (Novokuznjeck)',
        'Asia/Novosibirsk' => 'Krasnojarsk vrijeme (Novosibirsk)',
        'Asia/Omsk' => 'Omsk vrijeme',
        'Asia/Oral' => 'Kazahstansko vrijeme (Oral)',
        'Asia/Phnom_Penh' => 'Indokina vrijeme (Pnom Pen)',
        'Asia/Pontianak' => 'Zapadno-indonezijsko vrijeme (Pontijanak)',
        'Asia/Pyongyang' => 'Korejsko vrijeme (Pjongjang)',
        'Asia/Qatar' => 'Arabijsko vrijeme (Katar)',
        'Asia/Qostanay' => 'Kazahstansko vrijeme (Kostanaj)',
        'Asia/Qyzylorda' => 'Kazahstansko vrijeme (Kizilorda)',
        'Asia/Rangoon' => 'Mjanmar vrijeme (Rangun)',
        'Asia/Yangon' => 'Mjanmar vrijeme (Rangun)',
        'Asia/Riyadh' => 'Arabijsko vrijeme (Rijad)',
        'Asia/Saigon' => 'Indokina vrijeme (Ho Ši Min)',
        'Asia/Ho_Chi_Minh' => 'Indokina vrijeme (Ho Ši Min)',
        'Asia/Sakhalin' => 'Magadan vrijeme (Sahalin)',
        'Asia/Samarkand' => 'Uzbekistan vrijeme (Samarkand)',
        'Asia/Seoul' => 'Korejsko vrijeme (Seul)',
        'Asia/Shanghai' => 'Kina vrijeme (Šangaj)',
        'Asia/Singapore' => 'Singapur, standardno vrijeme',
        'Asia/Srednekolymsk' => 'Magadan vrijeme (Srednjekolimsk)',
        'Asia/Taipei' => 'Tajpej vrijeme',
        'Asia/Tashkent' => 'Uzbekistan vrijeme (Taškent)',
        'Asia/Tbilisi' => 'Gruzija vrijeme (Tbilisi)',
        'Asia/Tehran' => 'Iran vrijeme (Teheran)',
        'Asia/Thimphu' => 'Butan vrijeme (Timpu)',
        'Asia/Tokyo' => 'Japansko vrijeme (Tokio)',
        'Asia/Tomsk' => 'Krasnojarsk vrijeme (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulan Bator vrijeme',
        'Asia/Ust-Nera' => 'Vladivostok vrijeme (Ust-Nera)',
        'Asia/Vientiane' => 'Indokina vrijeme (Vijentijan)',
        'Asia/Vladivostok' => 'Vladivostok vrijeme',
        'Asia/Yakutsk' => 'Jakutsk vrijeme',
        'Asia/Yekaterinburg' => 'Jekaterinburg vrijeme',
        'Asia/Yerevan' => 'Jermenija vrijeme (Jerevan)',
        'Atlantic/Azores' => 'Azori vrijeme',
        'Atlantic/Bermuda' => 'Atlantsko vrijeme (Bermuda)',
        'Atlantic/Canary' => 'Zapadnoevropsko vrijeme (Kanarska ostrva)',
        'Atlantic/Cape_Verde' => 'Zelenortska Ostrva vrijeme',
        'Atlantic/Faeroe' => 'Zapadnoevropsko vrijeme (Farska Ostrva)',
        'Atlantic/Faroe' => 'Zapadnoevropsko vrijeme (Farska Ostrva)',
        'Atlantic/Madeira' => 'Zapadnoevropsko vrijeme (Madeira)',
        'Atlantic/Reykjavik' => 'Srednje vrijeme po Griniču (Rejkjavik)',
        'Atlantic/South_Georgia' => 'Južna Džordžija vrijeme',
        'Atlantic/St_Helena' => 'Srednje vrijeme po Griniču (Sveta Jelena)',
        'Atlantic/Stanley' => 'Folklandska Ostrva vrijeme (Stenli)',
        'Australia/Adelaide' => 'Australijsko centralno vrijeme (Adelejd)',
        'Australia/Brisbane' => 'Australijsko istočno vrijeme (Brizbejn)',
        'Australia/Broken_Hill' => 'Australijsko centralno vrijeme (Broken Hil)',
        'Australia/Darwin' => 'Australijsko centralno vrijeme (Darvin)',
        'Australia/Eucla' => 'Australijsko centralno zapadno vrijeme (Iukla)',
        'Australia/Hobart' => 'Australijsko istočno vrijeme (Hobart)',
        'Australia/Lindeman' => 'Australijsko istočno vrijeme (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Hov vrijeme (Lord Hau)',
        'Australia/Melbourne' => 'Australijsko istočno vrijeme (Melburn)',
        'Australia/Perth' => 'Australijsko zapadno vrijeme (Pert)',
        'Australia/Sydney' => 'Australijsko istočno vrijeme (Sidnej)',
        'Etc/GMT' => 'Srednje vrijeme po Griniču',
        'Etc/UTC' => 'Koordinisano univerzalno vrijeme',
        'Europe/Amsterdam' => 'Srednjoevropsko vrijeme (Amsterdam)',
        'Europe/Andorra' => 'Srednjoevropsko vrijeme (Andora)',
        'Europe/Athens' => 'Istočnoevropsko vrijeme (Atina)',
        'Europe/Belgrade' => 'Srednjoevropsko vrijeme (Beograd)',
        'Europe/Berlin' => 'Srednjoevropsko vrijeme (Berlin)',
        'Europe/Bratislava' => 'Srednjoevropsko vrijeme (Bratislava)',
        'Europe/Brussels' => 'Srednjoevropsko vrijeme (Brisel)',
        'Europe/Bucharest' => 'Istočnoevropsko vrijeme (Bukurešt)',
        'Europe/Budapest' => 'Srednjoevropsko vrijeme (Budimpešta)',
        'Europe/Busingen' => 'Srednjoevropsko vrijeme (Bisingen)',
        'Europe/Chisinau' => 'Istočnoevropsko vrijeme (Kišinjev)',
        'Europe/Copenhagen' => 'Srednjoevropsko vrijeme (Kopenhagen)',
        'Europe/Dublin' => 'Srednje vrijeme po Griniču (Dablin)',
        'Europe/Gibraltar' => 'Srednjoevropsko vrijeme (Gibraltar)',
        'Europe/Guernsey' => 'Srednje vrijeme po Griniču (Gernzi)',
        'Europe/Helsinki' => 'Istočnoevropsko vrijeme (Helsinki)',
        'Europe/Isle_of_Man' => 'Srednje vrijeme po Griniču (Ostrvo Man)',
        'Europe/Jersey' => 'Srednje vrijeme po Griniču (Džerzi)',
        'Europe/Kaliningrad' => 'Istočnoevropsko vrijeme (Kalinjingrad)',
        'Europe/Kiev' => 'Istočnoevropsko vrijeme (Kijev)',
        'Europe/Kyiv' => 'Istočnoevropsko vrijeme (Kijev)',
        'Europe/Kirov' => 'Moskva vrijeme (Kirov)',
        'Europe/Lisbon' => 'Zapadnoevropsko vrijeme (Lisabon)',
        'Europe/Ljubljana' => 'Srednjoevropsko vrijeme (Ljubljana)',
        'Europe/London' => 'Srednje vrijeme po Griniču (London)',
        'Europe/Luxembourg' => 'Srednjoevropsko vrijeme (Luksemburg)',
        'Europe/Madrid' => 'Srednjoevropsko vrijeme (Madrid)',
        'Europe/Malta' => 'Srednjoevropsko vrijeme (Malta)',
        'Europe/Mariehamn' => 'Istočnoevropsko vrijeme (Marihamn)',
        'Europe/Minsk' => 'Moskva vrijeme (Minsk)',
        'Europe/Monaco' => 'Srednjoevropsko vrijeme (Monako)',
        'Europe/Moscow' => 'Moskva vrijeme',
        'Europe/Oslo' => 'Srednjoevropsko vrijeme (Oslo)',
        'Europe/Paris' => 'Srednjoevropsko vrijeme (Pariz)',
        'Europe/Podgorica' => 'Srednjoevropsko vrijeme (Podgorica)',
        'Europe/Prague' => 'Srednjoevropsko vrijeme (Prag)',
        'Europe/Riga' => 'Istočnoevropsko vrijeme (Riga)',
        'Europe/Rome' => 'Srednjoevropsko vrijeme (Rim)',
        'Europe/San_Marino' => 'Srednjoevropsko vrijeme (San Marino)',
        'Europe/Sarajevo' => 'Srednjoevropsko vrijeme (Sarajevo)',
        'Europe/Simferopol' => 'Moskva vrijeme (Simferopolj)',
        'Europe/Skopje' => 'Srednjoevropsko vrijeme (Skoplje)',
        'Europe/Sofia' => 'Istočnoevropsko vrijeme (Sofija)',
        'Europe/Stockholm' => 'Srednjoevropsko vrijeme (Stokholm)',
        'Europe/Tallinn' => 'Istočnoevropsko vrijeme (Talin)',
        'Europe/Tirane' => 'Srednjoevropsko vrijeme (Tirana)',
        'Europe/Vaduz' => 'Srednjoevropsko vrijeme (Vaduz)',
        'Europe/Vatican' => 'Srednjoevropsko vrijeme (Vatikan)',
        'Europe/Vienna' => 'Srednjoevropsko vrijeme (Beč)',
        'Europe/Vilnius' => 'Istočnoevropsko vrijeme (Vilnjus)',
        'Europe/Volgograd' => 'Moskva vrijeme (Volgograd)',
        'Europe/Warsaw' => 'Srednjoevropsko vrijeme (Varšava)',
        'Europe/Zagreb' => 'Srednjoevropsko vrijeme (Zagreb)',
        'Europe/Zurich' => 'Srednjoevropsko vrijeme (Cirih)',
        'Indian/Antananarivo' => 'Istočno-afričko vrijeme (Antananarivo)',
        'Indian/Chagos' => 'Indijsko okeansko vrijeme (Čagos)',
        'Indian/Christmas' => 'Božićno ostrvo vrijeme',
        'Indian/Cocos' => 'Kokosova (Kiling) ostrva vrijeme',
        'Indian/Comoro' => 'Istočno-afričko vrijeme (Komoro)',
        'Indian/Kerguelen' => 'Francusko južno i antarktičko vrijeme (Kergelen)',
        'Indian/Mahe' => 'Sejšeli vrijeme (Mahe)',
        'Indian/Maldives' => 'Maldivi vrijeme',
        'Indian/Mauritius' => 'Mauricijus vrijeme',
        'Indian/Mayotte' => 'Istočno-afričko vrijeme (Majot)',
        'Indian/Reunion' => 'Reunion vrijeme',
        'Pacific/Apia' => 'Apija vrijeme',
        'Pacific/Auckland' => 'Novi Zeland vrijeme (Okland)',
        'Pacific/Bougainville' => 'Papua Nova Gvineja vrijeme (Buganvil)',
        'Pacific/Chatham' => 'Čatam vrijeme',
        'Pacific/Easter' => 'Uskršnja ostrva vrijeme (Uskršnje ostrvo)',
        'Pacific/Efate' => 'Vanuatu vrijeme (Efat)',
        'Pacific/Enderbury' => 'Feniks ostrva vrijeme (Kanton)',
        'Pacific/Kanton' => 'Feniks ostrva vrijeme (Kanton)',
        'Pacific/Fakaofo' => 'Tokelau vrijeme (Fakaofo)',
        'Pacific/Fiji' => 'Fidži vrijeme',
        'Pacific/Funafuti' => 'Tuvalu vrijeme (Funafuti)',
        'Pacific/Galapagos' => 'Galapagos vrijeme',
        'Pacific/Gambier' => 'Gambije vrijeme',
        'Pacific/Guadalcanal' => 'Solomonska Ostrva vrijeme (Gvadalkanal)',
        'Pacific/Guam' => 'Čamoro vrijeme (Guam)',
        'Pacific/Honolulu' => 'Havajsko-aleutsko standardno vrijeme (Honolulu)',
        'Pacific/Kiritimati' => 'Linijska ostrva vrijeme (Kiritimati)',
        'Pacific/Kosrae' => 'Košre vrijeme',
        'Pacific/Kwajalein' => 'Maršalska Ostrva vrijeme (Kvadžalejin)',
        'Pacific/Majuro' => 'Maršalska Ostrva vrijeme (Majuro)',
        'Pacific/Marquesas' => 'Markiz vrijeme',
        'Pacific/Midway' => 'Samoa vrijeme (Midvej)',
        'Pacific/Nauru' => 'Nauru vrijeme',
        'Pacific/Niue' => 'Nijue vrijeme',
        'Pacific/Norfolk' => 'ostrvo Norfolk vrijeme',
        'Pacific/Noumea' => 'Nova Kaledonija vrijeme (Numea)',
        'Pacific/Pago_Pago' => 'Samoa vrijeme (Pago Pago)',
        'Pacific/Palau' => 'Palau vrijeme',
        'Pacific/Pitcairn' => 'Pitkern vrijeme',
        'Pacific/Ponape' => 'Ponpej vrijeme (Ponape)',
        'Pacific/Pohnpei' => 'Ponpej vrijeme (Ponape)',
        'Pacific/Port_Moresby' => 'Papua Nova Gvineja vrijeme (Port Morzbi)',
        'Pacific/Rarotonga' => 'Kukova Ostrva vrijeme (Rarotonga)',
        'Pacific/Saipan' => 'Čamoro vrijeme (Sajpan)',
        'Pacific/Tahiti' => 'Tahiti vrijeme',
        'Pacific/Tarawa' => 'Gilbertova ostrva vrijeme (Tarava)',
        'Pacific/Tongatapu' => 'Tonga vrijeme (Tongatapu)',
        'Pacific/Truk' => 'Čuk vrijeme (Truk)',
        'Pacific/Chuuk' => 'Čuk vrijeme (Truk)',
        'Pacific/Wake' => 'ostrvo Vejk vrijeme',
        'Pacific/Wallis' => 'ostrva Valis i Futuna vrijeme',
    ],
    'Meta' => [],
];
