<?php

return [
    'Names' => [
        'af' => 'африкаанча',
        'af_NA' => 'африкаанча (Намибия)',
        'af_ZA' => 'африкаанча (Түштүк-Африка Республикасы)',
        'ak' => 'аканча',
        'ak_GH' => 'аканча (Гана)',
        'am' => 'амхарча',
        'am_ET' => 'амхарча (Эфиопия)',
        'ar' => 'арабча',
        'ar_001' => 'арабча (Дүйнө)',
        'ar_AE' => 'арабча (Бириккен Араб Эмираттары)',
        'ar_BH' => 'арабча (Бахрейн)',
        'ar_DJ' => 'арабча (Джибути)',
        'ar_DZ' => 'арабча (Алжир)',
        'ar_EG' => 'арабча (Египет)',
        'ar_EH' => 'арабча (Батыш Сахара)',
        'ar_ER' => 'арабча (Эритрея)',
        'ar_IL' => 'арабча (Израиль)',
        'ar_IQ' => 'арабча (Ирак)',
        'ar_JO' => 'арабча (Иордания)',
        'ar_KM' => 'арабча (Коморос)',
        'ar_KW' => 'арабча (Кувейт)',
        'ar_LB' => 'арабча (Ливан)',
        'ar_LY' => 'арабча (Ливия)',
        'ar_MA' => 'арабча (Марокко)',
        'ar_MR' => 'арабча (Мавритания)',
        'ar_OM' => 'арабча (Оман)',
        'ar_PS' => 'арабча (Палестина аймактары)',
        'ar_QA' => 'арабча (Катар)',
        'ar_SA' => 'арабча (Сауд Арабиясы)',
        'ar_SD' => 'арабча (Судан)',
        'ar_SO' => 'арабча (Сомали)',
        'ar_SS' => 'арабча (Түштүк Судан)',
        'ar_SY' => 'арабча (Сирия)',
        'ar_TD' => 'арабча (Чад)',
        'ar_TN' => 'арабча (Тунис)',
        'ar_YE' => 'арабча (Йемен)',
        'as' => 'ассамча',
        'as_IN' => 'ассамча (Индия)',
        'az' => 'азербайжанча',
        'az_AZ' => 'азербайжанча (Азербайжан)',
        'az_Cyrl' => 'азербайжанча (Кирилл)',
        'az_Cyrl_AZ' => 'азербайжанча (Кирилл, Азербайжан)',
        'az_Latn' => 'азербайжанча (Латын)',
        'az_Latn_AZ' => 'азербайжанча (Латын, Азербайжан)',
        'ba' => 'башкырча',
        'ba_RU' => 'башкырча (Россия)',
        'be' => 'беларусча',
        'be_BY' => 'беларусча (Беларусь)',
        'bg' => 'болгарча',
        'bg_BG' => 'болгарча (Болгария)',
        'bm' => 'бамбарача',
        'bm_ML' => 'бамбарача (Мали)',
        'bn' => 'бангладешче',
        'bn_BD' => 'бангладешче (Бангладеш)',
        'bn_IN' => 'бангладешче (Индия)',
        'bo' => 'тибетче',
        'bo_CN' => 'тибетче (Кытай)',
        'bo_IN' => 'тибетче (Индия)',
        'br' => 'бретончо',
        'br_FR' => 'бретончо (Франция)',
        'bs' => 'боснийче',
        'bs_BA' => 'боснийче (Босния жана Герцеговина)',
        'bs_Cyrl' => 'боснийче (Кирилл)',
        'bs_Cyrl_BA' => 'боснийче (Кирилл, Босния жана Герцеговина)',
        'bs_Latn' => 'боснийче (Латын)',
        'bs_Latn_BA' => 'боснийче (Латын, Босния жана Герцеговина)',
        'ca' => 'каталончо',
        'ca_AD' => 'каталончо (Андорра)',
        'ca_ES' => 'каталончо (Испания)',
        'ca_FR' => 'каталончо (Франция)',
        'ca_IT' => 'каталончо (Италия)',
        'ce' => 'чеченче',
        'ce_RU' => 'чеченче (Россия)',
        'cs' => 'чехче',
        'cs_CZ' => 'чехче (Чехия)',
        'cv' => 'чувашча',
        'cv_RU' => 'чувашча (Россия)',
        'cy' => 'уелшче',
        'cy_GB' => 'уелшче (Улуу Британия)',
        'da' => 'датча',
        'da_DK' => 'датча (Дания)',
        'da_GL' => 'датча (Гренландия)',
        'de' => 'немисче',
        'de_AT' => 'немисче (Австрия)',
        'de_BE' => 'немисче (Бельгия)',
        'de_CH' => 'немисче (Швейцария)',
        'de_DE' => 'немисче (Германия)',
        'de_IT' => 'немисче (Италия)',
        'de_LI' => 'немисче (Лихтенштейн)',
        'de_LU' => 'немисче (Люксембург)',
        'dz' => 'жонгуча',
        'dz_BT' => 'жонгуча (Бутан)',
        'ee' => 'эбече',
        'ee_GH' => 'эбече (Гана)',
        'ee_TG' => 'эбече (Того)',
        'el' => 'грекче',
        'el_CY' => 'грекче (Кипр)',
        'el_GR' => 'грекче (Греция)',
        'en' => 'англисче',
        'en_001' => 'англисче (Дүйнө)',
        'en_150' => 'англисче (Европа)',
        'en_AE' => 'англисче (Бириккен Араб Эмираттары)',
        'en_AG' => 'англисче (Антигуа жана Барбуда)',
        'en_AI' => 'англисче (Ангилья)',
        'en_AS' => 'англисче (Америкалык Самоа)',
        'en_AT' => 'англисче (Австрия)',
        'en_AU' => 'англисче (Австралия)',
        'en_BB' => 'англисче (Барбадос)',
        'en_BE' => 'англисче (Бельгия)',
        'en_BI' => 'англисче (Бурунди)',
        'en_BM' => 'англисче (Бермуд аралдары)',
        'en_BS' => 'англисче (Багама аралдары)',
        'en_BW' => 'англисче (Ботсвана)',
        'en_BZ' => 'англисче (Белиз)',
        'en_CA' => 'англисче (Канада)',
        'en_CC' => 'англисче (Кокос [Килинг] аралдары)',
        'en_CH' => 'англисче (Швейцария)',
        'en_CK' => 'англисче (Кук аралдары)',
        'en_CM' => 'англисче (Камерун)',
        'en_CX' => 'англисче (Рождество аралы)',
        'en_CY' => 'англисче (Кипр)',
        'en_CZ' => 'англисче (Чехия)',
        'en_DE' => 'англисче (Германия)',
        'en_DK' => 'англисче (Дания)',
        'en_DM' => 'англисче (Доминика)',
        'en_EE' => 'англисче (Эстония)',
        'en_ER' => 'англисче (Эритрея)',
        'en_ES' => 'англисче (Испания)',
        'en_FI' => 'англисче (Финляндия)',
        'en_FJ' => 'англисче (Фиджи)',
        'en_FK' => 'англисче (Фолкленд аралдары)',
        'en_FM' => 'англисче (Микронезия)',
        'en_FR' => 'англисче (Франция)',
        'en_GB' => 'англисче (Улуу Британия)',
        'en_GD' => 'англисче (Гренада)',
        'en_GE' => 'англисче (Грузия)',
        'en_GG' => 'англисче (Гернси)',
        'en_GH' => 'англисче (Гана)',
        'en_GI' => 'англисче (Гибралтар)',
        'en_GM' => 'англисче (Гамбия)',
        'en_GS' => 'англисче (Түштүк Жоржия жана Түштүк Сэндвич аралдары)',
        'en_GU' => 'англисче (Гуам)',
        'en_GY' => 'англисче (Гайана)',
        'en_HK' => 'англисче (Гонконг Кытай ААА)',
        'en_HU' => 'англисче (Венгрия)',
        'en_ID' => 'англисче (Индонезия)',
        'en_IE' => 'англисче (Ирландия)',
        'en_IL' => 'англисче (Израиль)',
        'en_IM' => 'англисче (Мэн аралы)',
        'en_IN' => 'англисче (Индия)',
        'en_IO' => 'англисче (Инди океанындагы Британ территориясы)',
        'en_IT' => 'англисче (Италия)',
        'en_JE' => 'англисче (Жерси)',
        'en_JM' => 'англисче (Ямайка)',
        'en_JP' => 'англисче (Жапония)',
        'en_KE' => 'англисче (Кения)',
        'en_KI' => 'англисче (Кирибати)',
        'en_KN' => 'англисче (Сент-Китс жана Невис)',
        'en_KY' => 'англисче (Кайман аралдары)',
        'en_LC' => 'англисче (Сент-Люсия)',
        'en_LR' => 'англисче (Либерия)',
        'en_LS' => 'англисче (Лесото)',
        'en_LT' => 'англисче (Литва)',
        'en_LV' => 'англисче (Латвия)',
        'en_MG' => 'англисче (Мадагаскар)',
        'en_MH' => 'англисче (Маршалл аралдары)',
        'en_MO' => 'англисче (Макао Кытай ААА)',
        'en_MP' => 'англисче (Түндүк Мариана аралдары)',
        'en_MS' => 'англисче (Монтсеррат)',
        'en_MT' => 'англисче (Мальта)',
        'en_MU' => 'англисче (Маврикий)',
        'en_MV' => 'англисче (Мальдив)',
        'en_MW' => 'англисче (Малави)',
        'en_MY' => 'англисче (Малайзия)',
        'en_NA' => 'англисче (Намибия)',
        'en_NF' => 'англисче (Норфолк аралы)',
        'en_NG' => 'англисче (Нигерия)',
        'en_NL' => 'англисче (Нидерланд)',
        'en_NO' => 'англисче (Норвегия)',
        'en_NR' => 'англисче (Науру)',
        'en_NU' => 'англисче (Ниуэ)',
        'en_NZ' => 'англисче (Жаңы Зеландия)',
        'en_PG' => 'англисче (Папуа-Жаңы Гвинея)',
        'en_PH' => 'англисче (Филиппин)',
        'en_PK' => 'англисче (Пакистан)',
        'en_PL' => 'англисче (Польша)',
        'en_PN' => 'англисче (Питкэрн аралдары)',
        'en_PR' => 'англисче (Пуэрто-Рико)',
        'en_PT' => 'англисче (Португалия)',
        'en_PW' => 'англисче (Палау)',
        'en_RO' => 'англисче (Румыния)',
        'en_RW' => 'англисче (Руанда)',
        'en_SB' => 'англисче (Соломон аралдары)',
        'en_SC' => 'англисче (Сейшел аралдары)',
        'en_SD' => 'англисче (Судан)',
        'en_SE' => 'англисче (Швеция)',
        'en_SG' => 'англисче (Сингапур)',
        'en_SH' => 'англисче (Ыйык Елена)',
        'en_SI' => 'англисче (Словения)',
        'en_SK' => 'англисче (Словакия)',
        'en_SL' => 'англисче (Сьерра-Леоне)',
        'en_SS' => 'англисче (Түштүк Судан)',
        'en_SX' => 'англисче (Синт-Мартен)',
        'en_SZ' => 'англисче (Свазиленд)',
        'en_TC' => 'англисче (Түркс жана Кайкос аралдары)',
        'en_TK' => 'англисче (Токелау)',
        'en_TO' => 'англисче (Тонга)',
        'en_TT' => 'англисче (Тринидад жана Тобаго)',
        'en_TV' => 'англисче (Тувалу)',
        'en_TZ' => 'англисче (Танзания)',
        'en_UA' => 'англисче (Украина)',
        'en_UG' => 'англисче (Уганда)',
        'en_UM' => 'англисче (АКШнын сырткы аралдары)',
        'en_US' => 'англисче (Кошмо Штаттар)',
        'en_VC' => 'англисче (Сент-Винсент жана Гренадиндер)',
        'en_VG' => 'англисче (Виргин аралдары [Британия])',
        'en_VI' => 'англисче (Виргин аралдары [АКШ])',
        'en_VU' => 'англисче (Вануату)',
        'en_WS' => 'англисче (Самоа)',
        'en_ZA' => 'англисче (Түштүк-Африка Республикасы)',
        'en_ZM' => 'англисче (Замбия)',
        'en_ZW' => 'англисче (Зимбабве)',
        'eo' => 'эсперанто',
        'eo_001' => 'эсперанто (Дүйнө)',
        'es' => 'испанча',
        'es_419' => 'испанча (Латын Америкасы)',
        'es_AR' => 'испанча (Аргентина)',
        'es_BO' => 'испанча (Боливия)',
        'es_BR' => 'испанча (Бразилия)',
        'es_BZ' => 'испанча (Белиз)',
        'es_CL' => 'испанча (Чили)',
        'es_CO' => 'испанча (Колумбия)',
        'es_CR' => 'испанча (Коста-Рика)',
        'es_CU' => 'испанча (Куба)',
        'es_DO' => 'испанча (Доминика Республикасы)',
        'es_EC' => 'испанча (Эквадор)',
        'es_ES' => 'испанча (Испания)',
        'es_GQ' => 'испанча (Экватордук Гвинея)',
        'es_GT' => 'испанча (Гватемала)',
        'es_HN' => 'испанча (Гондурас)',
        'es_MX' => 'испанча (Мексика)',
        'es_NI' => 'испанча (Никарагуа)',
        'es_PA' => 'испанча (Панама)',
        'es_PE' => 'испанча (Перу)',
        'es_PH' => 'испанча (Филиппин)',
        'es_PR' => 'испанча (Пуэрто-Рико)',
        'es_PY' => 'испанча (Парагвай)',
        'es_SV' => 'испанча (Эль-Сальвадор)',
        'es_US' => 'испанча (Кошмо Штаттар)',
        'es_UY' => 'испанча (Уругвай)',
        'es_VE' => 'испанча (Венесуэла)',
        'et' => 'эстончо',
        'et_EE' => 'эстончо (Эстония)',
        'eu' => 'баскча',
        'eu_ES' => 'баскча (Испания)',
        'fa' => 'фарсча',
        'fa_AF' => 'фарсча (Афганистан)',
        'fa_IR' => 'фарсча (Иран)',
        'ff' => 'фулача',
        'ff_Adlm' => 'фулача (Адлам [жазуу])',
        'ff_Adlm_BF' => 'фулача (Адлам [жазуу], Буркина-Фасо)',
        'ff_Adlm_CM' => 'фулача (Адлам [жазуу], Камерун)',
        'ff_Adlm_GH' => 'фулача (Адлам [жазуу], Гана)',
        'ff_Adlm_GM' => 'фулача (Адлам [жазуу], Гамбия)',
        'ff_Adlm_GN' => 'фулача (Адлам [жазуу], Гвинея)',
        'ff_Adlm_GW' => 'фулача (Адлам [жазуу], Гвинея-Бисау)',
        'ff_Adlm_LR' => 'фулача (Адлам [жазуу], Либерия)',
        'ff_Adlm_MR' => 'фулача (Адлам [жазуу], Мавритания)',
        'ff_Adlm_NE' => 'фулача (Адлам [жазуу], Нигер)',
        'ff_Adlm_NG' => 'фулача (Адлам [жазуу], Нигерия)',
        'ff_Adlm_SL' => 'фулача (Адлам [жазуу], Сьерра-Леоне)',
        'ff_Adlm_SN' => 'фулача (Адлам [жазуу], Сенегал)',
        'ff_CM' => 'фулача (Камерун)',
        'ff_GN' => 'фулача (Гвинея)',
        'ff_Latn' => 'фулача (Латын)',
        'ff_Latn_BF' => 'фулача (Латын, Буркина-Фасо)',
        'ff_Latn_CM' => 'фулача (Латын, Камерун)',
        'ff_Latn_GH' => 'фулача (Латын, Гана)',
        'ff_Latn_GM' => 'фулача (Латын, Гамбия)',
        'ff_Latn_GN' => 'фулача (Латын, Гвинея)',
        'ff_Latn_GW' => 'фулача (Латын, Гвинея-Бисау)',
        'ff_Latn_LR' => 'фулача (Латын, Либерия)',
        'ff_Latn_MR' => 'фулача (Латын, Мавритания)',
        'ff_Latn_NE' => 'фулача (Латын, Нигер)',
        'ff_Latn_NG' => 'фулача (Латын, Нигерия)',
        'ff_Latn_SL' => 'фулача (Латын, Сьерра-Леоне)',
        'ff_Latn_SN' => 'фулача (Латын, Сенегал)',
        'ff_MR' => 'фулача (Мавритания)',
        'ff_SN' => 'фулача (Сенегал)',
        'fi' => 'финче',
        'fi_FI' => 'финче (Финляндия)',
        'fo' => 'фарерче',
        'fo_DK' => 'фарерче (Дания)',
        'fo_FO' => 'фарерче (Фарер аралдары)',
        'fr' => 'французча',
        'fr_BE' => 'французча (Бельгия)',
        'fr_BF' => 'французча (Буркина-Фасо)',
        'fr_BI' => 'французча (Бурунди)',
        'fr_BJ' => 'французча (Бенин)',
        'fr_BL' => 'французча (Сент Бартелеми)',
        'fr_CA' => 'французча (Канада)',
        'fr_CD' => 'французча (Конго-Киншаса)',
        'fr_CF' => 'французча (Борбордук Африка Республикасы)',
        'fr_CG' => 'французча (Конго-Браззавил)',
        'fr_CH' => 'французча (Швейцария)',
        'fr_CI' => 'французча (Кот-д’Ивуар)',
        'fr_CM' => 'французча (Камерун)',
        'fr_DJ' => 'французча (Джибути)',
        'fr_DZ' => 'французча (Алжир)',
        'fr_FR' => 'французча (Франция)',
        'fr_GA' => 'французча (Габон)',
        'fr_GF' => 'французча (Франция Гвианасы)',
        'fr_GN' => 'французча (Гвинея)',
        'fr_GP' => 'французча (Гваделупа)',
        'fr_GQ' => 'французча (Экватордук Гвинея)',
        'fr_HT' => 'французча (Гаити)',
        'fr_KM' => 'французча (Коморос)',
        'fr_LU' => 'французча (Люксембург)',
        'fr_MA' => 'французча (Марокко)',
        'fr_MC' => 'французча (Монако)',
        'fr_MF' => 'французча (Сент-Мартин)',
        'fr_MG' => 'французча (Мадагаскар)',
        'fr_ML' => 'французча (Мали)',
        'fr_MQ' => 'французча (Мартиника)',
        'fr_MR' => 'французча (Мавритания)',
        'fr_MU' => 'французча (Маврикий)',
        'fr_NC' => 'французча (Жаңы Каледония)',
        'fr_NE' => 'французча (Нигер)',
        'fr_PF' => 'французча (Полинезия [франциялык])',
        'fr_PM' => 'французча (Сен-Пьер жана Микелон)',
        'fr_RE' => 'французча (Реюньон)',
        'fr_RW' => 'французча (Руанда)',
        'fr_SC' => 'французча (Сейшел аралдары)',
        'fr_SN' => 'французча (Сенегал)',
        'fr_SY' => 'французча (Сирия)',
        'fr_TD' => 'французча (Чад)',
        'fr_TG' => 'французча (Того)',
        'fr_TN' => 'французча (Тунис)',
        'fr_VU' => 'французча (Вануату)',
        'fr_WF' => 'французча (Уоллис жана Футуна)',
        'fr_YT' => 'французча (Майотта)',
        'fy' => 'батыш фризче',
        'fy_NL' => 'батыш фризче (Нидерланд)',
        'ga' => 'ирландча',
        'ga_GB' => 'ирландча (Улуу Британия)',
        'ga_IE' => 'ирландча (Ирландия)',
        'gd' => 'шотладиялык гелча',
        'gd_GB' => 'шотладиялык гелча (Улуу Британия)',
        'gl' => 'галисияча',
        'gl_ES' => 'галисияча (Испания)',
        'gu' => 'гужаратча',
        'gu_IN' => 'гужаратча (Индия)',
        'gv' => 'мэнксыча',
        'gv_IM' => 'мэнксыча (Мэн аралы)',
        'ha' => 'хаусача',
        'ha_GH' => 'хаусача (Гана)',
        'ha_NE' => 'хаусача (Нигер)',
        'ha_NG' => 'хаусача (Нигерия)',
        'he' => 'ивритче',
        'he_IL' => 'ивритче (Израиль)',
        'hi' => 'хиндиче',
        'hi_IN' => 'хиндиче (Индия)',
        'hi_Latn' => 'хиндиче (Латын)',
        'hi_Latn_IN' => 'хиндиче (Латын, Индия)',
        'hr' => 'хорватча',
        'hr_BA' => 'хорватча (Босния жана Герцеговина)',
        'hr_HR' => 'хорватча (Хорватия)',
        'hu' => 'венгерче',
        'hu_HU' => 'венгерче (Венгрия)',
        'hy' => 'армянча',
        'hy_AM' => 'армянча (Армения)',
        'ia' => 'интерлингва',
        'ia_001' => 'интерлингва (Дүйнө)',
        'id' => 'индонезияча',
        'id_ID' => 'индонезияча (Индонезия)',
        'ie' => 'интерлинг',
        'ie_EE' => 'интерлинг (Эстония)',
        'ig' => 'игбочо',
        'ig_NG' => 'игбочо (Нигерия)',
        'ii' => 'сычуань йиче',
        'ii_CN' => 'сычуань йиче (Кытай)',
        'is' => 'исландча',
        'is_IS' => 'исландча (Исландия)',
        'it' => 'италиянча',
        'it_CH' => 'италиянча (Швейцария)',
        'it_IT' => 'италиянча (Италия)',
        'it_SM' => 'италиянча (Сан Марино)',
        'it_VA' => 'италиянча (Ватикан)',
        'ja' => 'жапончо',
        'ja_JP' => 'жапончо (Жапония)',
        'jv' => 'жаванизче',
        'jv_ID' => 'жаванизче (Индонезия)',
        'ka' => 'грузинче',
        'ka_GE' => 'грузинче (Грузия)',
        'ki' => 'кикуйиче',
        'ki_KE' => 'кикуйиче (Кения)',
        'kk' => 'казакча',
        'kk_Arab' => 'казакча (Араб)',
        'kk_Arab_CN' => 'казакча (Араб, Кытай)',
        'kk_Cyrl' => 'казакча (Кирилл)',
        'kk_Cyrl_KZ' => 'казакча (Кирилл, Казакстан)',
        'kk_KZ' => 'казакча (Казакстан)',
        'kl' => 'калаалисутча',
        'kl_GL' => 'калаалисутча (Гренландия)',
        'km' => 'кмерче',
        'km_KH' => 'кмерче (Камбоджа)',
        'kn' => 'каннадача',
        'kn_IN' => 'каннадача (Индия)',
        'ko' => 'корейче',
        'ko_CN' => 'корейче (Кытай)',
        'ko_KP' => 'корейче (Түндүк Корея)',
        'ko_KR' => 'корейче (Түштүк Корея)',
        'ks' => 'кашмирче',
        'ks_Arab' => 'кашмирче (Араб)',
        'ks_Arab_IN' => 'кашмирче (Араб, Индия)',
        'ks_Deva' => 'кашмирче (Деванагари)',
        'ks_Deva_IN' => 'кашмирче (Деванагари, Индия)',
        'ks_IN' => 'кашмирче (Индия)',
        'ku' => 'курдча',
        'ku_Latn' => 'курдча (Латын)',
        'ku_Latn_IQ' => 'курдча (Латын, Ирак)',
        'ku_Latn_SY' => 'курдча (Латын, Сирия)',
        'ku_Latn_TR' => 'курдча (Латын, Түркия)',
        'ku_SY' => 'курдча (Сирия)',
        'ku_TR' => 'курдча (Түркия)',
        'kw' => 'корнишче',
        'kw_GB' => 'корнишче (Улуу Британия)',
        'ky' => 'кыргызча',
        'ky_KG' => 'кыргызча (Кыргызстан)',
        'lb' => 'люксембургча',
        'lb_LU' => 'люксембургча (Люксембург)',
        'lg' => 'гандача',
        'lg_UG' => 'гандача (Уганда)',
        'ln' => 'лингалача',
        'ln_AO' => 'лингалача (Ангола)',
        'ln_CD' => 'лингалача (Конго-Киншаса)',
        'ln_CF' => 'лингалача (Борбордук Африка Республикасы)',
        'ln_CG' => 'лингалача (Конго-Браззавил)',
        'lo' => 'лаочо',
        'lo_LA' => 'лаочо (Лаос)',
        'lt' => 'литовчо',
        'lt_LT' => 'литовчо (Литва)',
        'lu' => 'луба-катангача',
        'lu_CD' => 'луба-катангача (Конго-Киншаса)',
        'lv' => 'латышча',
        'lv_LV' => 'латышча (Латвия)',
        'mg' => 'малагасча',
        'mg_MG' => 'малагасча (Мадагаскар)',
        'mi' => 'маориче',
        'mi_NZ' => 'маориче (Жаңы Зеландия)',
        'mk' => 'македончо',
        'mk_MK' => 'македончо (Түндүк Македония)',
        'ml' => 'малайаламча',
        'ml_IN' => 'малайаламча (Индия)',
        'mn' => 'монголчо',
        'mn_MN' => 'монголчо (Монголия)',
        'mr' => 'маратиче',
        'mr_IN' => 'маратиче (Индия)',
        'ms' => 'малайча',
        'ms_BN' => 'малайча (Бруней)',
        'ms_ID' => 'малайча (Индонезия)',
        'ms_MY' => 'малайча (Малайзия)',
        'ms_SG' => 'малайча (Сингапур)',
        'mt' => 'малтизче',
        'mt_MT' => 'малтизче (Мальта)',
        'my' => 'бурмача',
        'my_MM' => 'бурмача (Мьянма [Бирма])',
        'nb' => 'норвежче [букмал]',
        'nb_NO' => 'норвежче [букмал] (Норвегия)',
        'nb_SJ' => 'норвежче [букмал] (Шпицберген жана Ян-Майен)',
        'nd' => 'түндүк ндыбелче',
        'nd_ZW' => 'түндүк ндыбелче (Зимбабве)',
        'ne' => 'непалча',
        'ne_IN' => 'непалча (Индия)',
        'ne_NP' => 'непалча (Непал)',
        'nl' => 'голландча',
        'nl_AW' => 'голландча (Аруба)',
        'nl_BE' => 'голландча (Бельгия)',
        'nl_BQ' => 'голландча (Кариб Нидерланддары)',
        'nl_CW' => 'голландча (Кюрасао)',
        'nl_NL' => 'голландча (Нидерланд)',
        'nl_SR' => 'голландча (Суринам)',
        'nl_SX' => 'голландча (Синт-Мартен)',
        'nn' => 'норвежче [нинорск]',
        'nn_NO' => 'норвежче [нинорск] (Норвегия)',
        'no' => 'норвежче',
        'no_NO' => 'норвежче (Норвегия)',
        'oc' => 'окситанча',
        'oc_ES' => 'окситанча (Испания)',
        'oc_FR' => 'окситанча (Франция)',
        'om' => 'оромочо',
        'om_ET' => 'оромочо (Эфиопия)',
        'om_KE' => 'оромочо (Кения)',
        'or' => 'орияча',
        'or_IN' => 'орияча (Индия)',
        'os' => 'осетинче',
        'os_GE' => 'осетинче (Грузия)',
        'os_RU' => 'осетинче (Россия)',
        'pa' => 'пунжабиче',
        'pa_Arab' => 'пунжабиче (Араб)',
        'pa_Arab_PK' => 'пунжабиче (Араб, Пакистан)',
        'pa_Guru' => 'пунжабиче (Гурмухи)',
        'pa_Guru_IN' => 'пунжабиче (Гурмухи, Индия)',
        'pa_IN' => 'пунжабиче (Индия)',
        'pa_PK' => 'пунжабиче (Пакистан)',
        'pl' => 'полякча',
        'pl_PL' => 'полякча (Польша)',
        'ps' => 'пуштуча',
        'ps_AF' => 'пуштуча (Афганистан)',
        'ps_PK' => 'пуштуча (Пакистан)',
        'pt' => 'португалча',
        'pt_AO' => 'португалча (Ангола)',
        'pt_BR' => 'португалча (Бразилия)',
        'pt_CH' => 'португалча (Швейцария)',
        'pt_CV' => 'португалча (Кабо-Верде)',
        'pt_GQ' => 'португалча (Экватордук Гвинея)',
        'pt_GW' => 'португалча (Гвинея-Бисау)',
        'pt_LU' => 'португалча (Люксембург)',
        'pt_MO' => 'португалча (Макао Кытай ААА)',
        'pt_MZ' => 'португалча (Мозамбик)',
        'pt_PT' => 'португалча (Португалия)',
        'pt_ST' => 'португалча (Сан-Томе жана Принсипи)',
        'pt_TL' => 'португалча (Тимор-Лесте)',
        'qu' => 'кечуача',
        'qu_BO' => 'кечуача (Боливия)',
        'qu_EC' => 'кечуача (Эквадор)',
        'qu_PE' => 'кечуача (Перу)',
        'rm' => 'романшча',
        'rm_CH' => 'романшча (Швейцария)',
        'rn' => 'рундиче',
        'rn_BI' => 'рундиче (Бурунди)',
        'ro' => 'румынча',
        'ro_MD' => 'румынча (Молдова)',
        'ro_RO' => 'румынча (Румыния)',
        'ru' => 'орусча',
        'ru_BY' => 'орусча (Беларусь)',
        'ru_KG' => 'орусча (Кыргызстан)',
        'ru_KZ' => 'орусча (Казакстан)',
        'ru_MD' => 'орусча (Молдова)',
        'ru_RU' => 'орусча (Россия)',
        'ru_UA' => 'орусча (Украина)',
        'rw' => 'руандача',
        'rw_RW' => 'руандача (Руанда)',
        'sa' => 'санскритче',
        'sa_IN' => 'санскритче (Индия)',
        'sc' => 'сардинче',
        'sc_IT' => 'сардинче (Италия)',
        'sd' => 'синдхиче',
        'sd_Arab' => 'синдхиче (Араб)',
        'sd_Arab_PK' => 'синдхиче (Араб, Пакистан)',
        'sd_Deva' => 'синдхиче (Деванагари)',
        'sd_Deva_IN' => 'синдхиче (Деванагари, Индия)',
        'sd_IN' => 'синдхиче (Индия)',
        'sd_PK' => 'синдхиче (Пакистан)',
        'se' => 'түндүк саамиче',
        'se_FI' => 'түндүк саамиче (Финляндия)',
        'se_NO' => 'түндүк саамиче (Норвегия)',
        'se_SE' => 'түндүк саамиче (Швеция)',
        'sg' => 'сангочо',
        'sg_CF' => 'сангочо (Борбордук Африка Республикасы)',
        'sh' => 'серб-хорват',
        'sh_BA' => 'серб-хорват (Босния жана Герцеговина)',
        'si' => 'сингалача',
        'si_LK' => 'сингалача (Шри-Ланка)',
        'sk' => 'словакча',
        'sk_SK' => 'словакча (Словакия)',
        'sl' => 'словенче',
        'sl_SI' => 'словенче (Словения)',
        'sn' => 'шонача',
        'sn_ZW' => 'шонача (Зимбабве)',
        'so' => 'сомаличе',
        'so_DJ' => 'сомаличе (Джибути)',
        'so_ET' => 'сомаличе (Эфиопия)',
        'so_KE' => 'сомаличе (Кения)',
        'so_SO' => 'сомаличе (Сомали)',
        'sq' => 'албанча',
        'sq_AL' => 'албанча (Албания)',
        'sq_MK' => 'албанча (Түндүк Македония)',
        'sr' => 'сербче',
        'sr_BA' => 'сербче (Босния жана Герцеговина)',
        'sr_Cyrl' => 'сербче (Кирилл)',
        'sr_Cyrl_BA' => 'сербче (Кирилл, Босния жана Герцеговина)',
        'sr_Cyrl_ME' => 'сербче (Кирилл, Черногория)',
        'sr_Cyrl_RS' => 'сербче (Кирилл, Сербия)',
        'sr_Latn' => 'сербче (Латын)',
        'sr_Latn_BA' => 'сербче (Латын, Босния жана Герцеговина)',
        'sr_Latn_ME' => 'сербче (Латын, Черногория)',
        'sr_Latn_RS' => 'сербче (Латын, Сербия)',
        'sr_ME' => 'сербче (Черногория)',
        'sr_RS' => 'сербче (Сербия)',
        'st' => 'сесоточо',
        'st_LS' => 'сесоточо (Лесото)',
        'st_ZA' => 'сесоточо (Түштүк-Африка Республикасы)',
        'su' => 'сунданча',
        'su_ID' => 'сунданча (Индонезия)',
        'su_Latn' => 'сунданча (Латын)',
        'su_Latn_ID' => 'сунданча (Латын, Индонезия)',
        'sv' => 'шведче',
        'sv_AX' => 'шведче (Аланд аралдары)',
        'sv_FI' => 'шведче (Финляндия)',
        'sv_SE' => 'шведче (Швеция)',
        'sw' => 'суахиличе',
        'sw_CD' => 'суахиличе (Конго-Киншаса)',
        'sw_KE' => 'суахиличе (Кения)',
        'sw_TZ' => 'суахиличе (Танзания)',
        'sw_UG' => 'суахиличе (Уганда)',
        'ta' => 'тамилче',
        'ta_IN' => 'тамилче (Индия)',
        'ta_LK' => 'тамилче (Шри-Ланка)',
        'ta_MY' => 'тамилче (Малайзия)',
        'ta_SG' => 'тамилче (Сингапур)',
        'te' => 'телугуча',
        'te_IN' => 'телугуча (Индия)',
        'tg' => 'тажикче',
        'tg_TJ' => 'тажикче (Тажикстан)',
        'th' => 'тайча',
        'th_TH' => 'тайча (Тайланд)',
        'ti' => 'тигриниача',
        'ti_ER' => 'тигриниача (Эритрея)',
        'ti_ET' => 'тигриниача (Эфиопия)',
        'tk' => 'түркмөнчө',
        'tk_TM' => 'түркмөнчө (Түркмөнстан)',
        'tn' => 'тсванача',
        'tn_BW' => 'тсванача (Ботсвана)',
        'tn_ZA' => 'тсванача (Түштүк-Африка Республикасы)',
        'to' => 'тонгача',
        'to_TO' => 'тонгача (Тонга)',
        'tr' => 'түркчө',
        'tr_CY' => 'түркчө (Кипр)',
        'tr_TR' => 'түркчө (Түркия)',
        'tt' => 'татарча',
        'tt_RU' => 'татарча (Россия)',
        'ug' => 'уйгурча',
        'ug_CN' => 'уйгурча (Кытай)',
        'uk' => 'украинче',
        'uk_UA' => 'украинче (Украина)',
        'ur' => 'урдуча',
        'ur_IN' => 'урдуча (Индия)',
        'ur_PK' => 'урдуча (Пакистан)',
        'uz' => 'өзбекче',
        'uz_AF' => 'өзбекче (Афганистан)',
        'uz_Arab' => 'өзбекче (Араб)',
        'uz_Arab_AF' => 'өзбекче (Араб, Афганистан)',
        'uz_Cyrl' => 'өзбекче (Кирилл)',
        'uz_Cyrl_UZ' => 'өзбекче (Кирилл, Өзбекстан)',
        'uz_Latn' => 'өзбекче (Латын)',
        'uz_Latn_UZ' => 'өзбекче (Латын, Өзбекстан)',
        'uz_UZ' => 'өзбекче (Өзбекстан)',
        'vi' => 'вьетнамча',
        'vi_VN' => 'вьетнамча (Вьетнам)',
        'wo' => 'уолофчо',
        'wo_SN' => 'уолофчо (Сенегал)',
        'xh' => 'косача',
        'xh_ZA' => 'косача (Түштүк-Африка Республикасы)',
        'yi' => 'идишче',
        'yi_UA' => 'идишче (Украина)',
        'yo' => 'йорубача',
        'yo_BJ' => 'йорубача (Бенин)',
        'yo_NG' => 'йорубача (Нигерия)',
        'za' => 'чжуанча',
        'za_CN' => 'чжуанча (Кытай)',
        'zh' => 'кытайча',
        'zh_CN' => 'кытайча (Кытай)',
        'zh_HK' => 'кытайча (Гонконг Кытай ААА)',
        'zh_Hans' => 'кытайча (Жөнөкөйлөштүрүлгөн)',
        'zh_Hans_CN' => 'кытайча (Жөнөкөйлөштүрүлгөн, Кытай)',
        'zh_Hans_HK' => 'кытайча (Жөнөкөйлөштүрүлгөн, Гонконг Кытай ААА)',
        'zh_Hans_MO' => 'кытайча (Жөнөкөйлөштүрүлгөн, Макао Кытай ААА)',
        'zh_Hans_MY' => 'кытайча (Жөнөкөйлөштүрүлгөн, Малайзия)',
        'zh_Hans_SG' => 'кытайча (Жөнөкөйлөштүрүлгөн, Сингапур)',
        'zh_Hant' => 'кытайча (Салттуу)',
        'zh_Hant_HK' => 'кытайча (Салттуу, Гонконг Кытай ААА)',
        'zh_Hant_MO' => 'кытайча (Салттуу, Макао Кытай ААА)',
        'zh_Hant_MY' => 'кытайча (Салттуу, Малайзия)',
        'zh_Hant_TW' => 'кытайча (Салттуу, Тайвань)',
        'zh_MO' => 'кытайча (Макао Кытай ААА)',
        'zh_SG' => 'кытайча (Сингапур)',
        'zh_TW' => 'кытайча (Тайвань)',
        'zu' => 'зулуча',
        'zu_ZA' => 'зулуча (Түштүк-Африка Республикасы)',
    ],
];
