<?php

return [
    'Names' => [
        'af' => 'アフリカーンス語',
        'af_NA' => 'アフリカーンス語 (ナミビア)',
        'af_ZA' => 'アフリカーンス語 (南アフリカ)',
        'ak' => 'アカン語',
        'ak_GH' => 'アカン語 (ガーナ)',
        'am' => 'アムハラ語',
        'am_ET' => 'アムハラ語 (エチオピア)',
        'ar' => 'アラビア語',
        'ar_001' => 'アラビア語 (世界)',
        'ar_AE' => 'アラビア語 (アラブ首長国連邦)',
        'ar_BH' => 'アラビア語 (バーレーン)',
        'ar_DJ' => 'アラビア語 (ジブチ)',
        'ar_DZ' => 'アラビア語 (アルジェリア)',
        'ar_EG' => 'アラビア語 (エジプト)',
        'ar_EH' => 'アラビア語 (西サハラ)',
        'ar_ER' => 'アラビア語 (エリトリア)',
        'ar_IL' => 'アラビア語 (イスラエル)',
        'ar_IQ' => 'アラビア語 (イラク)',
        'ar_JO' => 'アラビア語 (ヨルダン)',
        'ar_KM' => 'アラビア語 (コモロ)',
        'ar_KW' => 'アラビア語 (クウェート)',
        'ar_LB' => 'アラビア語 (レバノン)',
        'ar_LY' => 'アラビア語 (リビア)',
        'ar_MA' => 'アラビア語 (モロッコ)',
        'ar_MR' => 'アラビア語 (モーリタニア)',
        'ar_OM' => 'アラビア語 (オマーン)',
        'ar_PS' => 'アラビア語 (パレスチナ自治区)',
        'ar_QA' => 'アラビア語 (カタール)',
        'ar_SA' => 'アラビア語 (サウジアラビア)',
        'ar_SD' => 'アラビア語 (スーダン)',
        'ar_SO' => 'アラビア語 (ソマリア)',
        'ar_SS' => 'アラビア語 (南スーダン)',
        'ar_SY' => 'アラビア語 (シリア)',
        'ar_TD' => 'アラビア語 (チャド)',
        'ar_TN' => 'アラビア語 (チュニジア)',
        'ar_YE' => 'アラビア語 (イエメン)',
        'as' => 'アッサム語',
        'as_IN' => 'アッサム語 (インド)',
        'az' => 'アゼルバイジャン語',
        'az_AZ' => 'アゼルバイジャン語 (アゼルバイジャン)',
        'az_Cyrl' => 'アゼルバイジャン語 (キリル文字)',
        'az_Cyrl_AZ' => 'アゼルバイジャン語 (キリル文字、アゼルバイジャン)',
        'az_Latn' => 'アゼルバイジャン語 (ラテン文字)',
        'az_Latn_AZ' => 'アゼルバイジャン語 (ラテン文字、アゼルバイジャン)',
        'ba' => 'バシキール語',
        'ba_RU' => 'バシキール語 (ロシア)',
        'be' => 'ベラルーシ語',
        'be_BY' => 'ベラルーシ語 (ベラルーシ)',
        'bg' => 'ブルガリア語',
        'bg_BG' => 'ブルガリア語 (ブルガリア)',
        'bm' => 'バンバラ語',
        'bm_ML' => 'バンバラ語 (マリ)',
        'bn' => 'ベンガル語',
        'bn_BD' => 'ベンガル語 (バングラデシュ)',
        'bn_IN' => 'ベンガル語 (インド)',
        'bo' => 'チベット語',
        'bo_CN' => 'チベット語 (中国)',
        'bo_IN' => 'チベット語 (インド)',
        'br' => 'ブルトン語',
        'br_FR' => 'ブルトン語 (フランス)',
        'bs' => 'ボスニア語',
        'bs_BA' => 'ボスニア語 (ボスニア・ヘルツェゴビナ)',
        'bs_Cyrl' => 'ボスニア語 (キリル文字)',
        'bs_Cyrl_BA' => 'ボスニア語 (キリル文字、ボスニア・ヘルツェゴビナ)',
        'bs_Latn' => 'ボスニア語 (ラテン文字)',
        'bs_Latn_BA' => 'ボスニア語 (ラテン文字、ボスニア・ヘルツェゴビナ)',
        'ca' => 'カタロニア語',
        'ca_AD' => 'カタロニア語 (アンドラ)',
        'ca_ES' => 'カタロニア語 (スペイン)',
        'ca_FR' => 'カタロニア語 (フランス)',
        'ca_IT' => 'カタロニア語 (イタリア)',
        'ce' => 'チェチェン語',
        'ce_RU' => 'チェチェン語 (ロシア)',
        'cs' => 'チェコ語',
        'cs_CZ' => 'チェコ語 (チェコ)',
        'cv' => 'チュヴァシ語',
        'cv_RU' => 'チュヴァシ語 (ロシア)',
        'cy' => 'ウェールズ語',
        'cy_GB' => 'ウェールズ語 (イギリス)',
        'da' => 'デンマーク語',
        'da_DK' => 'デンマーク語 (デンマーク)',
        'da_GL' => 'デンマーク語 (グリーンランド)',
        'de' => 'ドイツ語',
        'de_AT' => 'ドイツ語 (オーストリア)',
        'de_BE' => 'ドイツ語 (ベルギー)',
        'de_CH' => 'ドイツ語 (スイス)',
        'de_DE' => 'ドイツ語 (ドイツ)',
        'de_IT' => 'ドイツ語 (イタリア)',
        'de_LI' => 'ドイツ語 (リヒテンシュタイン)',
        'de_LU' => 'ドイツ語 (ルクセンブルク)',
        'dz' => 'ゾンカ語',
        'dz_BT' => 'ゾンカ語 (ブータン)',
        'ee' => 'エウェ語',
        'ee_GH' => 'エウェ語 (ガーナ)',
        'ee_TG' => 'エウェ語 (トーゴ)',
        'el' => 'ギリシャ語',
        'el_CY' => 'ギリシャ語 (キプロス)',
        'el_GR' => 'ギリシャ語 (ギリシャ)',
        'en' => '英語',
        'en_001' => '英語 (世界)',
        'en_150' => '英語 (ヨーロッパ)',
        'en_AE' => '英語 (アラブ首長国連邦)',
        'en_AG' => '英語 (アンティグア・バーブーダ)',
        'en_AI' => '英語 (アンギラ)',
        'en_AS' => '英語 (米領サモア)',
        'en_AT' => '英語 (オーストリア)',
        'en_AU' => '英語 (オーストラリア)',
        'en_BB' => '英語 (バルバドス)',
        'en_BE' => '英語 (ベルギー)',
        'en_BI' => '英語 (ブルンジ)',
        'en_BM' => '英語 (バミューダ)',
        'en_BS' => '英語 (バハマ)',
        'en_BW' => '英語 (ボツワナ)',
        'en_BZ' => '英語 (ベリーズ)',
        'en_CA' => '英語 (カナダ)',
        'en_CC' => '英語 (ココス[キーリング]諸島)',
        'en_CH' => '英語 (スイス)',
        'en_CK' => '英語 (クック諸島)',
        'en_CM' => '英語 (カメルーン)',
        'en_CX' => '英語 (クリスマス島)',
        'en_CY' => '英語 (キプロス)',
        'en_CZ' => '英語 (チェコ)',
        'en_DE' => '英語 (ドイツ)',
        'en_DK' => '英語 (デンマーク)',
        'en_DM' => '英語 (ドミニカ国)',
        'en_EE' => '英語 (エストニア)',
        'en_ER' => '英語 (エリトリア)',
        'en_ES' => '英語 (スペイン)',
        'en_FI' => '英語 (フィンランド)',
        'en_FJ' => '英語 (フィジー)',
        'en_FK' => '英語 (フォークランド諸島)',
        'en_FM' => '英語 (ミクロネシア連邦)',
        'en_FR' => '英語 (フランス)',
        'en_GB' => '英語 (イギリス)',
        'en_GD' => '英語 (グレナダ)',
        'en_GE' => '英語 (ジョージア)',
        'en_GG' => '英語 (ガーンジー)',
        'en_GH' => '英語 (ガーナ)',
        'en_GI' => '英語 (ジブラルタル)',
        'en_GM' => '英語 (ガンビア)',
        'en_GS' => '英語 (サウスジョージア・サウスサンドウィッチ諸島)',
        'en_GU' => '英語 (グアム)',
        'en_GY' => '英語 (ガイアナ)',
        'en_HK' => '英語 (中華人民共和国香港特別行政区)',
        'en_HU' => '英語 (ハンガリー)',
        'en_ID' => '英語 (インドネシア)',
        'en_IE' => '英語 (アイルランド)',
        'en_IL' => '英語 (イスラエル)',
        'en_IM' => '英語 (マン島)',
        'en_IN' => '英語 (インド)',
        'en_IO' => '英語 (英領インド洋地域)',
        'en_IT' => '英語 (イタリア)',
        'en_JE' => '英語 (ジャージー)',
        'en_JM' => '英語 (ジャマイカ)',
        'en_JP' => '英語 (日本)',
        'en_KE' => '英語 (ケニア)',
        'en_KI' => '英語 (キリバス)',
        'en_KN' => '英語 (セントクリストファー・ネーヴィス)',
        'en_KY' => '英語 (ケイマン諸島)',
        'en_LC' => '英語 (セントルシア)',
        'en_LR' => '英語 (リベリア)',
        'en_LS' => '英語 (レソト)',
        'en_LT' => '英語 (リトアニア)',
        'en_LV' => '英語 (ラトビア)',
        'en_MG' => '英語 (マダガスカル)',
        'en_MH' => '英語 (マーシャル諸島)',
        'en_MO' => '英語 (中華人民共和国マカオ特別行政区)',
        'en_MP' => '英語 (北マリアナ諸島)',
        'en_MS' => '英語 (モントセラト)',
        'en_MT' => '英語 (マルタ)',
        'en_MU' => '英語 (モーリシャス)',
        'en_MV' => '英語 (モルディブ)',
        'en_MW' => '英語 (マラウイ)',
        'en_MY' => '英語 (マレーシア)',
        'en_NA' => '英語 (ナミビア)',
        'en_NF' => '英語 (ノーフォーク島)',
        'en_NG' => '英語 (ナイジェリア)',
        'en_NL' => '英語 (オランダ)',
        'en_NO' => '英語 (ノルウェー)',
        'en_NR' => '英語 (ナウル)',
        'en_NU' => '英語 (ニウエ)',
        'en_NZ' => '英語 (ニュージーランド)',
        'en_PG' => '英語 (パプアニューギニア)',
        'en_PH' => '英語 (フィリピン)',
        'en_PK' => '英語 (パキスタン)',
        'en_PL' => '英語 (ポーランド)',
        'en_PN' => '英語 (ピトケアン諸島)',
        'en_PR' => '英語 (プエルトリコ)',
        'en_PT' => '英語 (ポルトガル)',
        'en_PW' => '英語 (パラオ)',
        'en_RO' => '英語 (ルーマニア)',
        'en_RW' => '英語 (ルワンダ)',
        'en_SB' => '英語 (ソロモン諸島)',
        'en_SC' => '英語 (セーシェル)',
        'en_SD' => '英語 (スーダン)',
        'en_SE' => '英語 (スウェーデン)',
        'en_SG' => '英語 (シンガポール)',
        'en_SH' => '英語 (セントヘレナ)',
        'en_SI' => '英語 (スロベニア)',
        'en_SK' => '英語 (スロバキア)',
        'en_SL' => '英語 (シエラレオネ)',
        'en_SS' => '英語 (南スーダン)',
        'en_SX' => '英語 (シント・マールテン)',
        'en_SZ' => '英語 (エスワティニ)',
        'en_TC' => '英語 (タークス・カイコス諸島)',
        'en_TK' => '英語 (トケラウ)',
        'en_TO' => '英語 (トンガ)',
        'en_TT' => '英語 (トリニダード・トバゴ)',
        'en_TV' => '英語 (ツバル)',
        'en_TZ' => '英語 (タンザニア)',
        'en_UA' => '英語 (ウクライナ)',
        'en_UG' => '英語 (ウガンダ)',
        'en_UM' => '英語 (合衆国領有小離島)',
        'en_US' => '英語 (アメリカ合衆国)',
        'en_VC' => '英語 (セントビンセント及びグレナディーン諸島)',
        'en_VG' => '英語 (英領ヴァージン諸島)',
        'en_VI' => '英語 (米領ヴァージン諸島)',
        'en_VU' => '英語 (バヌアツ)',
        'en_WS' => '英語 (サモア)',
        'en_ZA' => '英語 (南アフリカ)',
        'en_ZM' => '英語 (ザンビア)',
        'en_ZW' => '英語 (ジンバブエ)',
        'eo' => 'エスペラント語',
        'eo_001' => 'エスペラント語 (世界)',
        'es' => 'スペイン語',
        'es_419' => 'スペイン語 (ラテンアメリカ)',
        'es_AR' => 'スペイン語 (アルゼンチン)',
        'es_BO' => 'スペイン語 (ボリビア)',
        'es_BR' => 'スペイン語 (ブラジル)',
        'es_BZ' => 'スペイン語 (ベリーズ)',
        'es_CL' => 'スペイン語 (チリ)',
        'es_CO' => 'スペイン語 (コロンビア)',
        'es_CR' => 'スペイン語 (コスタリカ)',
        'es_CU' => 'スペイン語 (キューバ)',
        'es_DO' => 'スペイン語 (ドミニカ共和国)',
        'es_EC' => 'スペイン語 (エクアドル)',
        'es_ES' => 'スペイン語 (スペイン)',
        'es_GQ' => 'スペイン語 (赤道ギニア)',
        'es_GT' => 'スペイン語 (グアテマラ)',
        'es_HN' => 'スペイン語 (ホンジュラス)',
        'es_MX' => 'スペイン語 (メキシコ)',
        'es_NI' => 'スペイン語 (ニカラグア)',
        'es_PA' => 'スペイン語 (パナマ)',
        'es_PE' => 'スペイン語 (ペルー)',
        'es_PH' => 'スペイン語 (フィリピン)',
        'es_PR' => 'スペイン語 (プエルトリコ)',
        'es_PY' => 'スペイン語 (パラグアイ)',
        'es_SV' => 'スペイン語 (エルサルバドル)',
        'es_US' => 'スペイン語 (アメリカ合衆国)',
        'es_UY' => 'スペイン語 (ウルグアイ)',
        'es_VE' => 'スペイン語 (ベネズエラ)',
        'et' => 'エストニア語',
        'et_EE' => 'エストニア語 (エストニア)',
        'eu' => 'バスク語',
        'eu_ES' => 'バスク語 (スペイン)',
        'fa' => 'ペルシア語',
        'fa_AF' => 'ペルシア語 (アフガニスタン)',
        'fa_IR' => 'ペルシア語 (イラン)',
        'ff' => 'フラ語',
        'ff_Adlm' => 'フラ語 (アドラム文字)',
        'ff_Adlm_BF' => 'フラ語 (アドラム文字、ブルキナファソ)',
        'ff_Adlm_CM' => 'フラ語 (アドラム文字、カメルーン)',
        'ff_Adlm_GH' => 'フラ語 (アドラム文字、ガーナ)',
        'ff_Adlm_GM' => 'フラ語 (アドラム文字、ガンビア)',
        'ff_Adlm_GN' => 'フラ語 (アドラム文字、ギニア)',
        'ff_Adlm_GW' => 'フラ語 (アドラム文字、ギニアビサウ)',
        'ff_Adlm_LR' => 'フラ語 (アドラム文字、リベリア)',
        'ff_Adlm_MR' => 'フラ語 (アドラム文字、モーリタニア)',
        'ff_Adlm_NE' => 'フラ語 (アドラム文字、ニジェール)',
        'ff_Adlm_NG' => 'フラ語 (アドラム文字、ナイジェリア)',
        'ff_Adlm_SL' => 'フラ語 (アドラム文字、シエラレオネ)',
        'ff_Adlm_SN' => 'フラ語 (アドラム文字、セネガル)',
        'ff_CM' => 'フラ語 (カメルーン)',
        'ff_GN' => 'フラ語 (ギニア)',
        'ff_Latn' => 'フラ語 (ラテン文字)',
        'ff_Latn_BF' => 'フラ語 (ラテン文字、ブルキナファソ)',
        'ff_Latn_CM' => 'フラ語 (ラテン文字、カメルーン)',
        'ff_Latn_GH' => 'フラ語 (ラテン文字、ガーナ)',
        'ff_Latn_GM' => 'フラ語 (ラテン文字、ガンビア)',
        'ff_Latn_GN' => 'フラ語 (ラテン文字、ギニア)',
        'ff_Latn_GW' => 'フラ語 (ラテン文字、ギニアビサウ)',
        'ff_Latn_LR' => 'フラ語 (ラテン文字、リベリア)',
        'ff_Latn_MR' => 'フラ語 (ラテン文字、モーリタニア)',
        'ff_Latn_NE' => 'フラ語 (ラテン文字、ニジェール)',
        'ff_Latn_NG' => 'フラ語 (ラテン文字、ナイジェリア)',
        'ff_Latn_SL' => 'フラ語 (ラテン文字、シエラレオネ)',
        'ff_Latn_SN' => 'フラ語 (ラテン文字、セネガル)',
        'ff_MR' => 'フラ語 (モーリタニア)',
        'ff_SN' => 'フラ語 (セネガル)',
        'fi' => 'フィンランド語',
        'fi_FI' => 'フィンランド語 (フィンランド)',
        'fo' => 'フェロー語',
        'fo_DK' => 'フェロー語 (デンマーク)',
        'fo_FO' => 'フェロー語 (フェロー諸島)',
        'fr' => 'フランス語',
        'fr_BE' => 'フランス語 (ベルギー)',
        'fr_BF' => 'フランス語 (ブルキナファソ)',
        'fr_BI' => 'フランス語 (ブルンジ)',
        'fr_BJ' => 'フランス語 (ベナン)',
        'fr_BL' => 'フランス語 (サン・バルテルミー)',
        'fr_CA' => 'フランス語 (カナダ)',
        'fr_CD' => 'フランス語 (コンゴ民主共和国[キンシャサ])',
        'fr_CF' => 'フランス語 (中央アフリカ共和国)',
        'fr_CG' => 'フランス語 (コンゴ共和国[ブラザビル])',
        'fr_CH' => 'フランス語 (スイス)',
        'fr_CI' => 'フランス語 (コートジボワール)',
        'fr_CM' => 'フランス語 (カメルーン)',
        'fr_DJ' => 'フランス語 (ジブチ)',
        'fr_DZ' => 'フランス語 (アルジェリア)',
        'fr_FR' => 'フランス語 (フランス)',
        'fr_GA' => 'フランス語 (ガボン)',
        'fr_GF' => 'フランス語 (仏領ギアナ)',
        'fr_GN' => 'フランス語 (ギニア)',
        'fr_GP' => 'フランス語 (グアドループ)',
        'fr_GQ' => 'フランス語 (赤道ギニア)',
        'fr_HT' => 'フランス語 (ハイチ)',
        'fr_KM' => 'フランス語 (コモロ)',
        'fr_LU' => 'フランス語 (ルクセンブルク)',
        'fr_MA' => 'フランス語 (モロッコ)',
        'fr_MC' => 'フランス語 (モナコ)',
        'fr_MF' => 'フランス語 (サン・マルタン)',
        'fr_MG' => 'フランス語 (マダガスカル)',
        'fr_ML' => 'フランス語 (マリ)',
        'fr_MQ' => 'フランス語 (マルティニーク)',
        'fr_MR' => 'フランス語 (モーリタニア)',
        'fr_MU' => 'フランス語 (モーリシャス)',
        'fr_NC' => 'フランス語 (ニューカレドニア)',
        'fr_NE' => 'フランス語 (ニジェール)',
        'fr_PF' => 'フランス語 (仏領ポリネシア)',
        'fr_PM' => 'フランス語 (サンピエール島・ミクロン島)',
        'fr_RE' => 'フランス語 (レユニオン)',
        'fr_RW' => 'フランス語 (ルワンダ)',
        'fr_SC' => 'フランス語 (セーシェル)',
        'fr_SN' => 'フランス語 (セネガル)',
        'fr_SY' => 'フランス語 (シリア)',
        'fr_TD' => 'フランス語 (チャド)',
        'fr_TG' => 'フランス語 (トーゴ)',
        'fr_TN' => 'フランス語 (チュニジア)',
        'fr_VU' => 'フランス語 (バヌアツ)',
        'fr_WF' => 'フランス語 (ウォリス・フツナ)',
        'fr_YT' => 'フランス語 (マヨット)',
        'fy' => '西フリジア語',
        'fy_NL' => '西フリジア語 (オランダ)',
        'ga' => 'アイルランド語',
        'ga_GB' => 'アイルランド語 (イギリス)',
        'ga_IE' => 'アイルランド語 (アイルランド)',
        'gd' => 'スコットランド・ゲール語',
        'gd_GB' => 'スコットランド・ゲール語 (イギリス)',
        'gl' => 'ガリシア語',
        'gl_ES' => 'ガリシア語 (スペイン)',
        'gu' => 'グジャラート語',
        'gu_IN' => 'グジャラート語 (インド)',
        'gv' => 'マン島語',
        'gv_IM' => 'マン島語 (マン島)',
        'ha' => 'ハウサ語',
        'ha_GH' => 'ハウサ語 (ガーナ)',
        'ha_NE' => 'ハウサ語 (ニジェール)',
        'ha_NG' => 'ハウサ語 (ナイジェリア)',
        'he' => 'ヘブライ語',
        'he_IL' => 'ヘブライ語 (イスラエル)',
        'hi' => 'ヒンディー語',
        'hi_IN' => 'ヒンディー語 (インド)',
        'hi_Latn' => 'ヒンディー語 (ラテン文字)',
        'hi_Latn_IN' => 'ヒンディー語 (ラテン文字、インド)',
        'hr' => 'クロアチア語',
        'hr_BA' => 'クロアチア語 (ボスニア・ヘルツェゴビナ)',
        'hr_HR' => 'クロアチア語 (クロアチア)',
        'hu' => 'ハンガリー語',
        'hu_HU' => 'ハンガリー語 (ハンガリー)',
        'hy' => 'アルメニア語',
        'hy_AM' => 'アルメニア語 (アルメニア)',
        'ia' => 'インターリングア',
        'ia_001' => 'インターリングア (世界)',
        'id' => 'インドネシア語',
        'id_ID' => 'インドネシア語 (インドネシア)',
        'ie' => 'インターリング',
        'ie_EE' => 'インターリング (エストニア)',
        'ig' => 'イボ語',
        'ig_NG' => 'イボ語 (ナイジェリア)',
        'ii' => '四川イ語',
        'ii_CN' => '四川イ語 (中国)',
        'is' => 'アイスランド語',
        'is_IS' => 'アイスランド語 (アイスランド)',
        'it' => 'イタリア語',
        'it_CH' => 'イタリア語 (スイス)',
        'it_IT' => 'イタリア語 (イタリア)',
        'it_SM' => 'イタリア語 (サンマリノ)',
        'it_VA' => 'イタリア語 (バチカン市国)',
        'ja' => '日本語',
        'ja_JP' => '日本語 (日本)',
        'jv' => 'ジャワ語',
        'jv_ID' => 'ジャワ語 (インドネシア)',
        'ka' => 'ジョージア語',
        'ka_GE' => 'ジョージア語 (ジョージア)',
        'ki' => 'キクユ語',
        'ki_KE' => 'キクユ語 (ケニア)',
        'kk' => 'カザフ語',
        'kk_Arab' => 'カザフ語 (アラビア文字)',
        'kk_Arab_CN' => 'カザフ語 (アラビア文字、中国)',
        'kk_Cyrl' => 'カザフ語 (キリル文字)',
        'kk_Cyrl_KZ' => 'カザフ語 (キリル文字、カザフスタン)',
        'kk_KZ' => 'カザフ語 (カザフスタン)',
        'kl' => 'グリーンランド語',
        'kl_GL' => 'グリーンランド語 (グリーンランド)',
        'km' => 'クメール語',
        'km_KH' => 'クメール語 (カンボジア)',
        'kn' => 'カンナダ語',
        'kn_IN' => 'カンナダ語 (インド)',
        'ko' => '韓国語',
        'ko_CN' => '韓国語 (中国)',
        'ko_KP' => '韓国語 (北朝鮮)',
        'ko_KR' => '韓国語 (韓国)',
        'ks' => 'カシミール語',
        'ks_Arab' => 'カシミール語 (アラビア文字)',
        'ks_Arab_IN' => 'カシミール語 (アラビア文字、インド)',
        'ks_Deva' => 'カシミール語 (デーバナーガリー文字)',
        'ks_Deva_IN' => 'カシミール語 (デーバナーガリー文字、インド)',
        'ks_IN' => 'カシミール語 (インド)',
        'ku' => 'クルド語',
        'ku_Latn' => 'クルド語 (ラテン文字)',
        'ku_Latn_IQ' => 'クルド語 (ラテン文字、イラク)',
        'ku_Latn_SY' => 'クルド語 (ラテン文字、シリア)',
        'ku_Latn_TR' => 'クルド語 (ラテン文字、トルコ)',
        'ku_SY' => 'クルド語 (シリア)',
        'ku_TR' => 'クルド語 (トルコ)',
        'kw' => 'コーンウォール語',
        'kw_GB' => 'コーンウォール語 (イギリス)',
        'ky' => 'キルギス語',
        'ky_KG' => 'キルギス語 (キルギス)',
        'lb' => 'ルクセンブルク語',
        'lb_LU' => 'ルクセンブルク語 (ルクセンブルク)',
        'lg' => 'ガンダ語',
        'lg_UG' => 'ガンダ語 (ウガンダ)',
        'ln' => 'リンガラ語',
        'ln_AO' => 'リンガラ語 (アンゴラ)',
        'ln_CD' => 'リンガラ語 (コンゴ民主共和国[キンシャサ])',
        'ln_CF' => 'リンガラ語 (中央アフリカ共和国)',
        'ln_CG' => 'リンガラ語 (コンゴ共和国[ブラザビル])',
        'lo' => 'ラオ語',
        'lo_LA' => 'ラオ語 (ラオス)',
        'lt' => 'リトアニア語',
        'lt_LT' => 'リトアニア語 (リトアニア)',
        'lu' => 'ルバ・カタンガ語',
        'lu_CD' => 'ルバ・カタンガ語 (コンゴ民主共和国[キンシャサ])',
        'lv' => 'ラトビア語',
        'lv_LV' => 'ラトビア語 (ラトビア)',
        'mg' => 'マダガスカル語',
        'mg_MG' => 'マダガスカル語 (マダガスカル)',
        'mi' => 'マオリ語',
        'mi_NZ' => 'マオリ語 (ニュージーランド)',
        'mk' => 'マケドニア語',
        'mk_MK' => 'マケドニア語 (北マケドニア)',
        'ml' => 'マラヤーラム語',
        'ml_IN' => 'マラヤーラム語 (インド)',
        'mn' => 'モンゴル語',
        'mn_MN' => 'モンゴル語 (モンゴル)',
        'mr' => 'マラーティー語',
        'mr_IN' => 'マラーティー語 (インド)',
        'ms' => 'マレー語',
        'ms_BN' => 'マレー語 (ブルネイ)',
        'ms_ID' => 'マレー語 (インドネシア)',
        'ms_MY' => 'マレー語 (マレーシア)',
        'ms_SG' => 'マレー語 (シンガポール)',
        'mt' => 'マルタ語',
        'mt_MT' => 'マルタ語 (マルタ)',
        'my' => 'ミャンマー語',
        'my_MM' => 'ミャンマー語 (ミャンマー [ビルマ])',
        'nb' => 'ノルウェー語[ブークモール]',
        'nb_NO' => 'ノルウェー語[ブークモール] (ノルウェー)',
        'nb_SJ' => 'ノルウェー語[ブークモール] (スバールバル諸島・ヤンマイエン島)',
        'nd' => '北ンデベレ語',
        'nd_ZW' => '北ンデベレ語 (ジンバブエ)',
        'ne' => 'ネパール語',
        'ne_IN' => 'ネパール語 (インド)',
        'ne_NP' => 'ネパール語 (ネパール)',
        'nl' => 'オランダ語',
        'nl_AW' => 'オランダ語 (アルバ)',
        'nl_BE' => 'オランダ語 (ベルギー)',
        'nl_BQ' => 'オランダ語 (オランダ領カリブ)',
        'nl_CW' => 'オランダ語 (キュラソー)',
        'nl_NL' => 'オランダ語 (オランダ)',
        'nl_SR' => 'オランダ語 (スリナム)',
        'nl_SX' => 'オランダ語 (シント・マールテン)',
        'nn' => 'ノルウェー語[ニーノシュク]',
        'nn_NO' => 'ノルウェー語[ニーノシュク] (ノルウェー)',
        'no' => 'ノルウェー語',
        'no_NO' => 'ノルウェー語 (ノルウェー)',
        'oc' => 'オック語',
        'oc_ES' => 'オック語 (スペイン)',
        'oc_FR' => 'オック語 (フランス)',
        'om' => 'オロモ語',
        'om_ET' => 'オロモ語 (エチオピア)',
        'om_KE' => 'オロモ語 (ケニア)',
        'or' => 'オディア語',
        'or_IN' => 'オディア語 (インド)',
        'os' => 'オセット語',
        'os_GE' => 'オセット語 (ジョージア)',
        'os_RU' => 'オセット語 (ロシア)',
        'pa' => 'パンジャブ語',
        'pa_Arab' => 'パンジャブ語 (アラビア文字)',
        'pa_Arab_PK' => 'パンジャブ語 (アラビア文字、パキスタン)',
        'pa_Guru' => 'パンジャブ語 (グルムキー文字)',
        'pa_Guru_IN' => 'パンジャブ語 (グルムキー文字、インド)',
        'pa_IN' => 'パンジャブ語 (インド)',
        'pa_PK' => 'パンジャブ語 (パキスタン)',
        'pl' => 'ポーランド語',
        'pl_PL' => 'ポーランド語 (ポーランド)',
        'ps' => 'パシュトゥー語',
        'ps_AF' => 'パシュトゥー語 (アフガニスタン)',
        'ps_PK' => 'パシュトゥー語 (パキスタン)',
        'pt' => 'ポルトガル語',
        'pt_AO' => 'ポルトガル語 (アンゴラ)',
        'pt_BR' => 'ポルトガル語 (ブラジル)',
        'pt_CH' => 'ポルトガル語 (スイス)',
        'pt_CV' => 'ポルトガル語 (カーボベルデ)',
        'pt_GQ' => 'ポルトガル語 (赤道ギニア)',
        'pt_GW' => 'ポルトガル語 (ギニアビサウ)',
        'pt_LU' => 'ポルトガル語 (ルクセンブルク)',
        'pt_MO' => 'ポルトガル語 (中華人民共和国マカオ特別行政区)',
        'pt_MZ' => 'ポルトガル語 (モザンビーク)',
        'pt_PT' => 'ポルトガル語 (ポルトガル)',
        'pt_ST' => 'ポルトガル語 (サントメ・プリンシペ)',
        'pt_TL' => 'ポルトガル語 (東ティモール)',
        'qu' => 'ケチュア語',
        'qu_BO' => 'ケチュア語 (ボリビア)',
        'qu_EC' => 'ケチュア語 (エクアドル)',
        'qu_PE' => 'ケチュア語 (ペルー)',
        'rm' => 'ロマンシュ語',
        'rm_CH' => 'ロマンシュ語 (スイス)',
        'rn' => 'ルンディ語',
        'rn_BI' => 'ルンディ語 (ブルンジ)',
        'ro' => 'ルーマニア語',
        'ro_MD' => 'ルーマニア語 (モルドバ)',
        'ro_RO' => 'ルーマニア語 (ルーマニア)',
        'ru' => 'ロシア語',
        'ru_BY' => 'ロシア語 (ベラルーシ)',
        'ru_KG' => 'ロシア語 (キルギス)',
        'ru_KZ' => 'ロシア語 (カザフスタン)',
        'ru_MD' => 'ロシア語 (モルドバ)',
        'ru_RU' => 'ロシア語 (ロシア)',
        'ru_UA' => 'ロシア語 (ウクライナ)',
        'rw' => 'キニアルワンダ語',
        'rw_RW' => 'キニアルワンダ語 (ルワンダ)',
        'sa' => 'サンスクリット語',
        'sa_IN' => 'サンスクリット語 (インド)',
        'sc' => 'サルデーニャ語',
        'sc_IT' => 'サルデーニャ語 (イタリア)',
        'sd' => 'シンド語',
        'sd_Arab' => 'シンド語 (アラビア文字)',
        'sd_Arab_PK' => 'シンド語 (アラビア文字、パキスタン)',
        'sd_Deva' => 'シンド語 (デーバナーガリー文字)',
        'sd_Deva_IN' => 'シンド語 (デーバナーガリー文字、インド)',
        'sd_IN' => 'シンド語 (インド)',
        'sd_PK' => 'シンド語 (パキスタン)',
        'se' => '北サーミ語',
        'se_FI' => '北サーミ語 (フィンランド)',
        'se_NO' => '北サーミ語 (ノルウェー)',
        'se_SE' => '北サーミ語 (スウェーデン)',
        'sg' => 'サンゴ語',
        'sg_CF' => 'サンゴ語 (中央アフリカ共和国)',
        'sh' => 'セルボ・クロアチア語',
        'sh_BA' => 'セルボ・クロアチア語 (ボスニア・ヘルツェゴビナ)',
        'si' => 'シンハラ語',
        'si_LK' => 'シンハラ語 (スリランカ)',
        'sk' => 'スロバキア語',
        'sk_SK' => 'スロバキア語 (スロバキア)',
        'sl' => 'スロベニア語',
        'sl_SI' => 'スロベニア語 (スロベニア)',
        'sn' => 'ショナ語',
        'sn_ZW' => 'ショナ語 (ジンバブエ)',
        'so' => 'ソマリ語',
        'so_DJ' => 'ソマリ語 (ジブチ)',
        'so_ET' => 'ソマリ語 (エチオピア)',
        'so_KE' => 'ソマリ語 (ケニア)',
        'so_SO' => 'ソマリ語 (ソマリア)',
        'sq' => 'アルバニア語',
        'sq_AL' => 'アルバニア語 (アルバニア)',
        'sq_MK' => 'アルバニア語 (北マケドニア)',
        'sr' => 'セルビア語',
        'sr_BA' => 'セルビア語 (ボスニア・ヘルツェゴビナ)',
        'sr_Cyrl' => 'セルビア語 (キリル文字)',
        'sr_Cyrl_BA' => 'セルビア語 (キリル文字、ボスニア・ヘルツェゴビナ)',
        'sr_Cyrl_ME' => 'セルビア語 (キリル文字、モンテネグロ)',
        'sr_Cyrl_RS' => 'セルビア語 (キリル文字、セルビア)',
        'sr_Latn' => 'セルビア語 (ラテン文字)',
        'sr_Latn_BA' => 'セルビア語 (ラテン文字、ボスニア・ヘルツェゴビナ)',
        'sr_Latn_ME' => 'セルビア語 (ラテン文字、モンテネグロ)',
        'sr_Latn_RS' => 'セルビア語 (ラテン文字、セルビア)',
        'sr_ME' => 'セルビア語 (モンテネグロ)',
        'sr_RS' => 'セルビア語 (セルビア)',
        'st' => '南部ソト語',
        'st_LS' => '南部ソト語 (レソト)',
        'st_ZA' => '南部ソト語 (南アフリカ)',
        'su' => 'スンダ語',
        'su_ID' => 'スンダ語 (インドネシア)',
        'su_Latn' => 'スンダ語 (ラテン文字)',
        'su_Latn_ID' => 'スンダ語 (ラテン文字、インドネシア)',
        'sv' => 'スウェーデン語',
        'sv_AX' => 'スウェーデン語 (オーランド諸島)',
        'sv_FI' => 'スウェーデン語 (フィンランド)',
        'sv_SE' => 'スウェーデン語 (スウェーデン)',
        'sw' => 'スワヒリ語',
        'sw_CD' => 'スワヒリ語 (コンゴ民主共和国[キンシャサ])',
        'sw_KE' => 'スワヒリ語 (ケニア)',
        'sw_TZ' => 'スワヒリ語 (タンザニア)',
        'sw_UG' => 'スワヒリ語 (ウガンダ)',
        'ta' => 'タミル語',
        'ta_IN' => 'タミル語 (インド)',
        'ta_LK' => 'タミル語 (スリランカ)',
        'ta_MY' => 'タミル語 (マレーシア)',
        'ta_SG' => 'タミル語 (シンガポール)',
        'te' => 'テルグ語',
        'te_IN' => 'テルグ語 (インド)',
        'tg' => 'タジク語',
        'tg_TJ' => 'タジク語 (タジキスタン)',
        'th' => 'タイ語',
        'th_TH' => 'タイ語 (タイ)',
        'ti' => 'ティグリニア語',
        'ti_ER' => 'ティグリニア語 (エリトリア)',
        'ti_ET' => 'ティグリニア語 (エチオピア)',
        'tk' => 'トルクメン語',
        'tk_TM' => 'トルクメン語 (トルクメニスタン)',
        'tl' => 'タガログ語',
        'tl_PH' => 'タガログ語 (フィリピン)',
        'tn' => 'ツワナ語',
        'tn_BW' => 'ツワナ語 (ボツワナ)',
        'tn_ZA' => 'ツワナ語 (南アフリカ)',
        'to' => 'トンガ語',
        'to_TO' => 'トンガ語 (トンガ)',
        'tr' => 'トルコ語',
        'tr_CY' => 'トルコ語 (キプロス)',
        'tr_TR' => 'トルコ語 (トルコ)',
        'tt' => 'タタール語',
        'tt_RU' => 'タタール語 (ロシア)',
        'ug' => 'ウイグル語',
        'ug_CN' => 'ウイグル語 (中国)',
        'uk' => 'ウクライナ語',
        'uk_UA' => 'ウクライナ語 (ウクライナ)',
        'ur' => 'ウルドゥー語',
        'ur_IN' => 'ウルドゥー語 (インド)',
        'ur_PK' => 'ウルドゥー語 (パキスタン)',
        'uz' => 'ウズベク語',
        'uz_AF' => 'ウズベク語 (アフガニスタン)',
        'uz_Arab' => 'ウズベク語 (アラビア文字)',
        'uz_Arab_AF' => 'ウズベク語 (アラビア文字、アフガニスタン)',
        'uz_Cyrl' => 'ウズベク語 (キリル文字)',
        'uz_Cyrl_UZ' => 'ウズベク語 (キリル文字、ウズベキスタン)',
        'uz_Latn' => 'ウズベク語 (ラテン文字)',
        'uz_Latn_UZ' => 'ウズベク語 (ラテン文字、ウズベキスタン)',
        'uz_UZ' => 'ウズベク語 (ウズベキスタン)',
        'vi' => 'ベトナム語',
        'vi_VN' => 'ベトナム語 (ベトナム)',
        'wo' => 'ウォロフ語',
        'wo_SN' => 'ウォロフ語 (セネガル)',
        'xh' => 'コサ語',
        'xh_ZA' => 'コサ語 (南アフリカ)',
        'yi' => 'イディッシュ語',
        'yi_UA' => 'イディッシュ語 (ウクライナ)',
        'yo' => 'ヨルバ語',
        'yo_BJ' => 'ヨルバ語 (ベナン)',
        'yo_NG' => 'ヨルバ語 (ナイジェリア)',
        'za' => 'チワン語',
        'za_CN' => 'チワン語 (中国)',
        'zh' => '中国語',
        'zh_CN' => '中国語 (中国)',
        'zh_HK' => '中国語 (中華人民共和国香港特別行政区)',
        'zh_Hans' => '中国語 (簡体字)',
        'zh_Hans_CN' => '中国語 (簡体字、中国)',
        'zh_Hans_HK' => '中国語 (簡体字、中華人民共和国香港特別行政区)',
        'zh_Hans_MO' => '中国語 (簡体字、中華人民共和国マカオ特別行政区)',
        'zh_Hans_MY' => '中国語 (簡体字、マレーシア)',
        'zh_Hans_SG' => '中国語 (簡体字、シンガポール)',
        'zh_Hant' => '中国語 (繁体字)',
        'zh_Hant_HK' => '中国語 (繁体字、中華人民共和国香港特別行政区)',
        'zh_Hant_MO' => '中国語 (繁体字、中華人民共和国マカオ特別行政区)',
        'zh_Hant_MY' => '中国語 (繁体字、マレーシア)',
        'zh_Hant_TW' => '中国語 (繁体字、台湾)',
        'zh_MO' => '中国語 (中華人民共和国マカオ特別行政区)',
        'zh_SG' => '中国語 (シンガポール)',
        'zh_TW' => '中国語 (台湾)',
        'zu' => 'ズールー語',
        'zu_ZA' => 'ズールー語 (南アフリカ)',
    ],
];
