<?php

return [
    'UserAssignedNames' => [],
    'Names' => [
        'AX' => 'Оландска острва',
        'BL' => 'Сен Бартелеми',
        'BN' => 'Брунеји',
        'BV' => 'острво Буве',
        'BY' => 'Бјелорусија',
        'CC' => 'Кокосова (Килинг) острва',
        'CZ' => 'Чешка Република',
        'DE' => 'Њемачка',
        'FK' => 'Фокландска острва',
        'FO' => 'Фарска острва',
        'GS' => 'Јужна Џорџија и Јужна Сендвичка острва',
        'GU' => 'Гвам',
        'GW' => 'Гвинеја Бисао',
        'HK' => 'Хонгконг (САО Кине)',
        'HM' => 'острво Херд и острва Макдоналд',
        'KM' => 'Комори',
        'KP' => 'Сјеверна Кореја',
        'MK' => 'Сјеверна Македонија',
        'MM' => 'Мјанмар (Бурма)',
        'MP' => 'Сјеверна Маријанска острва',
        'NF' => 'острво Норфок',
        'NU' => 'Нијуе',
        'PS' => 'палестинске територије',
        'RE' => 'Реунион',
        'TF' => 'Француске јужне територије',
        'UM' => 'Спољна острва САД',
        'VC' => 'Свети Винсент и Гренадини',
        'VG' => 'Британска Дјевичанска острва',
        'VI' => 'Америчка Дјевичанска острва',
    ],
];
