<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Dirham UAE',
        ],
        'AFN' => [
            'AFN',
            'Afghani Awhekenetāna',
        ],
        'ALL' => [
            'ALL',
            'Lek Arapeinia',
        ],
        'AMD' => [
            'AMD',
            'Dram Āmenia',
        ],
        'ANG' => [
            'ANG',
            'Guilder Anatiri Hōrana',
        ],
        'AOA' => [
            'AOA',
            'Kwanza Anakora',
        ],
        'ARS' => [
            'ARS',
            'Peso Āketina',
        ],
        'AUD' => [
            'A$',
            'Tāra Ahitereiria',
        ],
        'AWG' => [
            'AWG',
            'Florin Arūpa',
        ],
        'AZN' => [
            'AZN',
            'Manat Atepaihānia',
        ],
        'BAM' => [
            'BAM',
            'Mark Pōngia-Herekōwini takahuri',
        ],
        'BBD' => [
            'BBD',
            'Tāra Papatohe',
        ],
        'BDT' => [
            'BDT',
            'Taka Pākaratēhi',
        ],
        'BGN' => [
            'BGN',
            'Leva Purukāria',
        ],
        'BHD' => [
            'BHD',
            'Dinar Pāreina',
        ],
        'BIF' => [
            'BIF',
            'Franc Puruniti',
        ],
        'BMD' => [
            'BMD',
            'Tāra Pāmura',
        ],
        'BND' => [
            'BND',
            'Tāra Poronai',
        ],
        'BOB' => [
            'BOB',
            'Boliviano Poriwia',
        ],
        'BRL' => [
            'R$',
            'Real Parahi',
        ],
        'BSD' => [
            'BSD',
            'Tāra Pahama',
        ],
        'BTN' => [
            'BTN',
            'Ngultrum Pūtana',
        ],
        'BWP' => [
            'BWP',
            'Pula Poriwana',
        ],
        'BYN' => [
            'BYN',
            'Ruble Pērara',
        ],
        'BZD' => [
            'BZD',
            'Tāra Pērihi',
        ],
        'CAD' => [
            'CA$',
            'Tāra Kānata',
        ],
        'CDF' => [
            'CDF',
            'Franc Kōngo',
        ],
        'CHF' => [
            'CHF',
            'Franc Huiterangi',
        ],
        'CLP' => [
            'CLP',
            'Peso Hiri',
        ],
        'CNH' => [
            'CNH',
            'Yuan Haina (ki waho)',
        ],
        'CNY' => [
            'CN¥',
            'Yuan Haina',
        ],
        'COP' => [
            'COP',
            'Peso Koromōpia',
        ],
        'CRC' => [
            'CRC',
            'Colon Koto Rika',
        ],
        'CUC' => [
            'CUC',
            'Peso Kiupa takahuri',
        ],
        'CUP' => [
            'CUP',
            'Peso Kiupa',
        ],
        'CVE' => [
            'CVE',
            'Escudo Kūrae Matomato',
        ],
        'CZK' => [
            'CZK',
            'Koruna Tieke',
        ],
        'DJF' => [
            'DJF',
            'Franc Tepūti',
        ],
        'DKK' => [
            'DKK',
            'Kroner Tenemāka',
        ],
        'DOP' => [
            'DOP',
            'Peso Tominika',
        ],
        'DZD' => [
            'DZD',
            'Dinar Aratiria',
        ],
        'EGP' => [
            'EGP',
            'Pāuna Īhipa',
        ],
        'ERN' => [
            'ERN',
            'Nakfa Eriterea',
        ],
        'ETB' => [
            'ETB',
            'birr Etiopia',
        ],
        'EUR' => [
            '€',
            'Euro',
        ],
        'FJD' => [
            'FJD',
            'Tāra Whītī',
        ],
        'FKP' => [
            'FKP',
            'Pāuna Whākana',
        ],
        'GBP' => [
            '£',
            'Pāuna Piritene',
        ],
        'GEL' => [
            'GEL',
            'Lari Hōria',
        ],
        'GHS' => [
            'GHS',
            'Cedi Kāna',
        ],
        'GIP' => [
            'GIP',
            'Pāuna Kāmaka',
        ],
        'GMD' => [
            'GMD',
            'Dalasi Kamopia',
        ],
        'GNF' => [
            'GNF',
            'Franc Kini',
        ],
        'GTQ' => [
            'GTQ',
            'Quetzal Kuatamāra',
        ],
        'GYD' => [
            'GYD',
            'Tāra Kaiana',
        ],
        'HKD' => [
            'HK$',
            'Tāra Hongipua',
        ],
        'HNL' => [
            'HNL',
            'Lempira Honotura',
        ],
        'HRK' => [
            'HRK',
            'Kuna Koroātia',
        ],
        'HTG' => [
            'HTG',
            'Gourde Haiti',
        ],
        'HUF' => [
            'HUF',
            'Forint Hanekari',
        ],
        'IDR' => [
            'IDR',
            'Rupiah Initonīhia',
        ],
        'ILS' => [
            '₪',
            'Shekel Hou Iharaira',
        ],
        'INR' => [
            '₹',
            'Rupī Iniana',
        ],
        'IQD' => [
            'IQD',
            'Dinar Irāka',
        ],
        'IRR' => [
            'IRR',
            'Rial Irāna',
        ],
        'ISK' => [
            'ISK',
            'Kronur Tiorangi',
        ],
        'JMD' => [
            'JMD',
            'Tāra Hemeika',
        ],
        'JOD' => [
            'JOD',
            'Dinar Hōrano',
        ],
        'JPY' => [
            '¥',
            'Yen Hapanihi',
        ],
        'KES' => [
            'KES',
            'Hereni Kenia',
        ],
        'KGS' => [
            'KGS',
            'Som Kikitānga',
        ],
        'KHR' => [
            'KHR',
            'Riel Kamapōtia',
        ],
        'KMF' => [
            'KMF',
            'Franc Komoro',
        ],
        'KPW' => [
            'KPW',
            'Won Kōrea ki te Raki',
        ],
        'KRW' => [
            '₩',
            'Won Kōrea ki te Tonga',
        ],
        'KWD' => [
            'KWD',
            'Dinar Kūweiti',
        ],
        'KYD' => [
            'KYD',
            'Tāra Kāmana',
        ],
        'KZT' => [
            'KZT',
            'Tenge Katatānga',
        ],
        'LAK' => [
            'LAK',
            'kip Rāoho',
        ],
        'LBP' => [
            'LBP',
            'Pāuna Repanona',
        ],
        'LKR' => [
            'LKR',
            'Rupee Hiri Ranaka',
        ],
        'LRD' => [
            'LRD',
            'Tāra Raipiria',
        ],
        'LSL' => [
            'LSL',
            'Loti Teroto',
        ],
        'LYD' => [
            'LYD',
            'Dinar Ripia',
        ],
        'MAD' => [
            'MAD',
            'Dirham Moroko',
        ],
        'MDL' => [
            'MDL',
            'Leu Morotawa',
        ],
        'MGA' => [
            'MGA',
            'Ariary Matakāhika',
        ],
        'MKD' => [
            'MKD',
            'Denar Makerōnia',
        ],
        'MMK' => [
            'MMK',
            'Kyat Pēma',
        ],
        'MNT' => [
            'MNT',
            'tugrik Mongōria',
        ],
        'MOP' => [
            'MOP',
            'Pataca Makau',
        ],
        'MRU' => [
            'MRU',
            'Ouguiya Mauritania',
        ],
        'MUR' => [
            'MUR',
            'Rupee Marihi',
        ],
        'MVR' => [
            'MVR',
            'Rufiyaa Māratiri',
        ],
        'MWK' => [
            'MWK',
            'Kwacha Marāwi',
        ],
        'MXN' => [
            'MX$',
            'Peso Mēhiko',
        ],
        'MYR' => [
            'MYR',
            'Ringgit Mareia',
        ],
        'MZN' => [
            'MZN',
            'Metical Mohapiki',
        ],
        'NAD' => [
            'NAD',
            'Tāra Namipia',
        ],
        'NGN' => [
            'NGN',
            'Naira Ngāitīria',
        ],
        'NIO' => [
            'NIO',
            'Cordoba Nikarāhua',
        ],
        'NOK' => [
            'NOK',
            'Kroner Nōwei',
        ],
        'NPR' => [
            'NPR',
            'Rupee Nepōra',
        ],
        'NZD' => [
            '$',
            'Tāra o Aotearoa',
        ],
        'OMR' => [
            'OMR',
            'Rial Ōmana',
        ],
        'PAB' => [
            'PAB',
            'Balboa Panama',
        ],
        'PEN' => [
            'PEN',
            'Sole Peru',
        ],
        'PGK' => [
            'PGK',
            'Kina Papua Nūkini',
        ],
        'PHP' => [
            '₱',
            'Peso Piripīni',
        ],
        'PKR' => [
            'PKR',
            'Rupee Pakitāne',
        ],
        'PLN' => [
            'PLN',
            'Zloty Pōrana',
        ],
        'PYG' => [
            'PYG',
            'Guarani Parakai',
        ],
        'QAR' => [
            'QAR',
            'Riyal Katā',
        ],
        'RON' => [
            'RON',
            'Leu Romeinia',
        ],
        'RSD' => [
            'RSD',
            'Dinar Hirupia',
        ],
        'RUB' => [
            'RUB',
            'Rūpera Ruhiana',
        ],
        'RWF' => [
            'RWF',
            'Franc Rāwana',
        ],
        'SAR' => [
            'SAR',
            'Riyal Hauri',
        ],
        'SBD' => [
            'SBD',
            'Tāra Moutere Horomona',
        ],
        'SCR' => [
            'SCR',
            'Rupee Heikere',
        ],
        'SDG' => [
            'SDG',
            'Pāuna Hūtāne',
        ],
        'SEK' => [
            'SEK',
            'Kronor Huitene',
        ],
        'SGD' => [
            'SGD',
            'Tāra Hingapoa',
        ],
        'SHP' => [
            'SHP',
            'Pāuna Hato Herena',
        ],
        'SLE' => [
            'SLE',
            'Leone Araone',
        ],
        'SLL' => [
            'SLL',
            'Leone Araon (1964—2022)e',
        ],
        'SOS' => [
            'SOS',
            'Hereni Hūmārie',
        ],
        'SRD' => [
            'SRD',
            'Tāra Huriname',
        ],
        'SSP' => [
            'SSP',
            'Pāuna Hūtāne Tonga',
        ],
        'STN' => [
            'STN',
            'Dobra Hao Tome me Pirinihipi',
        ],
        'SYP' => [
            'SYP',
            'Pāuna Hiria',
        ],
        'SZL' => [
            'SZL',
            'Lilangeni Warerangi',
        ],
        'THB' => [
            'THB',
            'Baht Tairanga',
        ],
        'TJS' => [
            'TJS',
            'Somoni Takiritānga',
        ],
        'TMT' => [
            'TMT',
            'Manat Tukumanatānga',
        ],
        'TND' => [
            'TND',
            'Dinar Tūnihia',
        ],
        'TOP' => [
            'TOP',
            'Pa’anga Tonga',
        ],
        'TRY' => [
            'TRY',
            'Lira Tākei',
        ],
        'TTD' => [
            'TTD',
            'Tāra Tirinaki Tōpako',
        ],
        'TWD' => [
            'NT$',
            'Tāra Taiwana Hou',
        ],
        'TZS' => [
            'TZS',
            'Hereni Tānahia',
        ],
        'UAH' => [
            'UAH',
            'Hryvnia Ukareinga',
        ],
        'UGX' => [
            'UGX',
            'hereni Ukānga',
        ],
        'USD' => [
            'US$',
            'Tāra US',
        ],
        'UYU' => [
            'UYU',
            'Peso Urukoi',
        ],
        'UZS' => [
            'UZS',
            'Som Uhipeketāne',
        ],
        'VES' => [
            'VES',
            'Bolivar Penehūera',
        ],
        'VND' => [
            '₫',
            'Dong Whitināmu',
        ],
        'VUV' => [
            'VUV',
            'Vatu Whenuatū',
        ],
        'WST' => [
            'WST',
            'Tala Hāmoa',
        ],
        'XAF' => [
            'FCFA',
            'Franc CFA Āwherika Waenga',
        ],
        'XCD' => [
            'EC$',
            'Tāra Karapīana Rāwhiti',
        ],
        'XCG' => [
            'Cg.',
            'Guilder Karapīana',
        ],
        'XOF' => [
            'F CFA',
            'Franc CFA Āwherika ki te Uru',
        ],
        'XPF' => [
            'CFPF',
            'Franc CFP',
        ],
        'YER' => [
            'YER',
            'Rial Īmene',
        ],
        'ZAR' => [
            'ZAR',
            'Rand Āwherika ki te Tonga',
        ],
        'ZMW' => [
            'ZMW',
            'Kwacha Tāmipia',
        ],
        'ZWG' => [
            'ZWG',
            'Kōura Timuwawe',
        ],
    ],
];
