<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'เปเซตาอันดอร์รา',
        ],
        'AED' => [
            'AED',
            'เดอร์แฮมสหรัฐอาหรับเอมิเรตส์',
        ],
        'AFA' => [
            'AFA',
            'อัฟกานีอัฟกานิสถาน (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'อัฟกานิอัฟกานิสถาน',
        ],
        'ALL' => [
            'ALL',
            'เลกแอลเบเนีย',
        ],
        'AMD' => [
            'AMD',
            'แดรมอาร์เมเนีย',
        ],
        'ANG' => [
            'ANG',
            'กิลเดอร์เนเธอร์แลนด์แอนทิลลิส',
        ],
        'AOA' => [
            'AOA',
            'กวานซาแองโกลา',
        ],
        'AOK' => [
            'AOK',
            'กวานซาแองโกลา (1977–1990)',
        ],
        'AON' => [
            'AON',
            'นิวกวานซาแองโกลา (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'กวานซารีจัสทาโดแองโกลา (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'ออสตรัลอาร์เจนตินา',
        ],
        'ARL' => [
            'ARL',
            'เปโซเลย์อาร์เจนตินา (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'เปโซอาร์เจนตินา (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'เปโซอาร์เจนตินา (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'เปโซอาร์เจนตินา',
        ],
        'ATS' => [
            'ATS',
            'ชิลลิงออสเตรีย',
        ],
        'AUD' => [
            'AU$',
            'ดอลลาร์ออสเตรเลีย',
        ],
        'AWG' => [
            'AWG',
            'ฟลอรินอารูบา',
        ],
        'AZM' => [
            'AZM',
            'มานัตอาเซอร์ไบจาน (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'มานัตอาเซอร์ไบจาน',
        ],
        'BAD' => [
            'BAD',
            'ดีนาร์บอสเนีย-เฮอร์เซโกวีนา',
        ],
        'BAM' => [
            'BAM',
            'มาร์กบอสเนีย-เฮอร์เซโกวีนา',
        ],
        'BAN' => [
            'BAN',
            'ดีนาร์ใหม่บอสเนีย-เฮอร์เซโกวีนา (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'ดอลลาร์บาร์เบโดส',
        ],
        'BDT' => [
            'BDT',
            'ตากาบังกลาเทศ',
        ],
        'BEC' => [
            'BEC',
            'ฟรังก์เบลเยียม (เปลี่ยนแปลงได้)',
        ],
        'BEF' => [
            'BEF',
            'ฟรังก์เบลเยียม',
        ],
        'BEL' => [
            'BEL',
            'ฟรังก์เบลเยียม (การเงิน)',
        ],
        'BGL' => [
            'BGL',
            'ฮาร์ดเลฟบัลแกเรีย',
        ],
        'BGM' => [
            'BGM',
            'โซเชียลลิสต์เลฟบัลแกเรีย',
        ],
        'BGN' => [
            'BGN',
            'เลฟบัลแกเรีย',
        ],
        'BGO' => [
            'BGO',
            'เลฟบัลเกเรีย (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'ดีนาร์บาห์เรน',
        ],
        'BIF' => [
            'BIF',
            'ฟรังก์บุรุนดี',
        ],
        'BMD' => [
            'BMD',
            'ดอลลาร์เบอร์มิวดา',
        ],
        'BND' => [
            'BND',
            'ดอลลาร์บรูไน',
        ],
        'BOB' => [
            'BOB',
            'โบลิเวียโนโบลิเวีย',
        ],
        'BOL' => [
            'BOL',
            'โบลิเวียโนโบลิเวีย (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'เปโซโบลิเวีย',
        ],
        'BOV' => [
            'BOV',
            'มฟดอลโบลิเวีย',
        ],
        'BRB' => [
            'BRB',
            'ครูเซโรโนโวบราซิล (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'ครูซาโดบราซิล',
        ],
        'BRE' => [
            'BRE',
            'ครูเซโรบราซิล (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'เรียลบราซิล',
        ],
        'BRN' => [
            'BRN',
            'ครูซาโดโนโวบราซิล',
        ],
        'BRR' => [
            'BRR',
            'ครูเซโรบราซิล',
        ],
        'BRZ' => [
            'BRZ',
            'ครูเซโรบราซิล (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'ดอลลาร์บาฮามาส',
        ],
        'BTN' => [
            'BTN',
            'เอ็งกุลตรัมภูฏาน',
        ],
        'BUK' => [
            'BUK',
            'จ๊าดพม่า',
        ],
        'BWP' => [
            'BWP',
            'ปูลาบอตสวานา',
        ],
        'BYB' => [
            'BYB',
            'นิวรูเบิลเบลารุส (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'รูเบิลเบลารุส',
        ],
        'BYR' => [
            'BYR',
            'รูเบิลเบลารุส (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'ดอลลาร์เบลีซ',
        ],
        'CAD' => [
            'CA$',
            'ดอลลาร์แคนาดา',
        ],
        'CDF' => [
            'CDF',
            'ฟรังก์คองโก',
        ],
        'CHE' => [
            'CHE',
            'ยูโรดับเบิลยูไออาร์',
        ],
        'CHF' => [
            'CHF',
            'ฟรังก์สวิส',
        ],
        'CHW' => [
            'CHW',
            'ฟรังก์ดับเบิลยูไออาร์',
        ],
        'CLE' => [
            'CLE',
            'เอสคูโดชิลี',
        ],
        'CLF' => [
            'CLF',
            'ฟูเมนโตชิลี',
        ],
        'CLP' => [
            'CLP',
            'เปโซชิลี',
        ],
        'CNH' => [
            'CNH',
            'หยวน',
        ],
        'CNY' => [
            'CN¥',
            'หยวนจีน',
        ],
        'COP' => [
            'COP',
            'เปโซโคลอมเบีย',
        ],
        'COU' => [
            'COU',
            'วาเลอร์เรียลโคลอมเบีย',
        ],
        'CRC' => [
            'CRC',
            'โกลองคอสตาริกา',
        ],
        'CSD' => [
            'CSD',
            'ดีนาร์เซอร์เบียเก่า',
        ],
        'CSK' => [
            'CSK',
            'ฮาร์ดโครูนาเช็กโกสโลวัก',
        ],
        'CUC' => [
            'CUC',
            'เปโซคิวบา (แปลงสภาพ)',
        ],
        'CUP' => [
            'CUP',
            'เปโซคิวบา',
        ],
        'CVE' => [
            'CVE',
            'เอสคูโดเคปเวิร์ด',
        ],
        'CYP' => [
            'CYP',
            'ปอนด์ไซปรัส',
        ],
        'CZK' => [
            'CZK',
            'โครูนาสาธารณรัฐเช็ก',
        ],
        'DDM' => [
            'DDM',
            'มาร์กเยอรมันตะวันออก',
        ],
        'DEM' => [
            'DEM',
            'มาร์กเยอรมัน',
        ],
        'DJF' => [
            'DJF',
            'ฟรังก์จิบูตี',
        ],
        'DKK' => [
            'DKK',
            'โครนเดนมาร์ก',
        ],
        'DOP' => [
            'DOP',
            'เปโซโดมินิกัน',
        ],
        'DZD' => [
            'DZD',
            'ดีนาร์แอลจีเรีย',
        ],
        'ECS' => [
            'ECS',
            'ซูเกรเอกวาดอร์',
        ],
        'ECV' => [
            'ECV',
            'วาเลอร์คอนสแตนต์เอกวาดอร์',
        ],
        'EEK' => [
            'EEK',
            'ครูนเอสโตเนีย',
        ],
        'EGP' => [
            'EGP',
            'ปอนด์อียิปต์',
        ],
        'ERN' => [
            'ERN',
            'แนกฟาเอริเทรีย',
        ],
        'ESA' => [
            'ESA',
            'เปเซตาสเปน (บัญชีเอ)',
        ],
        'ESB' => [
            'ESB',
            'เปเซตาสเปน (บัญชีที่เปลี่ยนแปลงได้)',
        ],
        'ESP' => [
            'ESP',
            'เปเซตาสเปน',
        ],
        'ETB' => [
            'ETB',
            'เบอรร์เอธิโอเปีย',
        ],
        'EUR' => [
            '€',
            'ยูโร',
        ],
        'FIM' => [
            'FIM',
            'มาร์กกาฟินแลนด์',
        ],
        'FJD' => [
            'FJD',
            'ดอลลาร์ฟิจิ',
        ],
        'FKP' => [
            'FKP',
            'ปอนด์หมู่เกาะฟอล์กแลนด์',
        ],
        'FRF' => [
            'FRF',
            'ฟรังก์ฝรั่งเศส',
        ],
        'GBP' => [
            '£',
            'ปอนด์สเตอร์ลิง (สหราชอาณาจักร)',
        ],
        'GEK' => [
            'GEK',
            'คูปอนลาริตจอร์เจีย',
        ],
        'GEL' => [
            'GEL',
            'ลารีจอร์เจีย',
        ],
        'GHC' => [
            'GHC',
            'เซดีกานา (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'เซดีกานา',
        ],
        'GIP' => [
            'GIP',
            'ปอนด์ยิบรอลตาร์',
        ],
        'GMD' => [
            'GMD',
            'ดาลาซีแกมเบีย',
        ],
        'GNF' => [
            'GNF',
            'ฟรังก์กินี',
        ],
        'GNS' => [
            'GNS',
            'ไซลีกินี',
        ],
        'GQE' => [
            'GQE',
            'เอ็กเวเลอิเควทอเรียลกินี',
        ],
        'GRD' => [
            'GRD',
            'ดรัชมากรีก',
        ],
        'GTQ' => [
            'GTQ',
            'เควตซัลกัวเตมาลา',
        ],
        'GWE' => [
            'GWE',
            'เอสคูโดกินีโปรตุเกส',
        ],
        'GWP' => [
            'GWP',
            'เปโซกินี-บิสเซา',
        ],
        'GYD' => [
            'GYD',
            'ดอลลาร์กายอานา',
        ],
        'HKD' => [
            'HK$',
            'ดอลลาร์ฮ่องกง',
        ],
        'HNL' => [
            'HNL',
            'เลมปิราฮอนดูรัส',
        ],
        'HRD' => [
            'HRD',
            'ดีนาร์โครเอเชีย',
        ],
        'HRK' => [
            'HRK',
            'คูนาโครเอเชีย',
        ],
        'HTG' => [
            'HTG',
            'กูร์ดเฮติ',
        ],
        'HUF' => [
            'HUF',
            'ฟอรินต์ฮังการี',
        ],
        'IDR' => [
            'IDR',
            'รูเปียห์อินโดนีเซีย',
        ],
        'IEP' => [
            'IEP',
            'ปอนด์ไอริช',
        ],
        'ILP' => [
            'ILP',
            'ปอนด์อิสราเอล',
        ],
        'ILS' => [
            '₪',
            'นิวเชเกลอิสราเอล',
        ],
        'INR' => [
            '₹',
            'รูปีอินเดีย',
        ],
        'IQD' => [
            'IQD',
            'ดีนาร์อิรัก',
        ],
        'IRR' => [
            'IRR',
            'เรียลอิหร่าน',
        ],
        'ISK' => [
            'ISK',
            'โครนาไอซ์แลนด์',
        ],
        'ITL' => [
            'ITL',
            'ลีราอิตาลี',
        ],
        'JMD' => [
            'JMD',
            'ดอลลาร์จาเมกา',
        ],
        'JOD' => [
            'JOD',
            'ดีนาร์จอร์แดน',
        ],
        'JPY' => [
            '¥',
            'เยนญี่ปุ่น',
        ],
        'KES' => [
            'KES',
            'ชิลลิงเคนยา',
        ],
        'KGS' => [
            'KGS',
            'ซอมคีร์กีซสถาน',
        ],
        'KHR' => [
            'KHR',
            'เรียลกัมพูชา',
        ],
        'KMF' => [
            'KMF',
            'ฟรังก์คอโมโรส',
        ],
        'KPW' => [
            'KPW',
            'วอนเกาหลีเหนือ',
        ],
        'KRH' => [
            'KRH',
            'ฮวานเกาหลีใต้ (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'วอนเกาหลีใต้ (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'วอนเกาหลีใต้',
        ],
        'KWD' => [
            'KWD',
            'ดีนาร์คูเวต',
        ],
        'KYD' => [
            'KYD',
            'ดอลลาร์หมู่เกาะเคย์แมน',
        ],
        'KZT' => [
            'KZT',
            'เทงเจคาซัคสถาน',
        ],
        'LAK' => [
            'LAK',
            'กีบลาว',
        ],
        'LBP' => [
            'LBP',
            'ปอนด์เลบานอน',
        ],
        'LKR' => [
            'LKR',
            'รูปีศรีลังกา',
        ],
        'LRD' => [
            'LRD',
            'ดอลลาร์ไลบีเรีย',
        ],
        'LSL' => [
            'LSL',
            'โลตีเลโซโท',
        ],
        'LTL' => [
            'LTL',
            'ลีตัสลิทัวเนีย',
        ],
        'LTT' => [
            'LTT',
            'ทาโลนัสลิทัวเนีย',
        ],
        'LUC' => [
            'LUC',
            'คอนเวอร์ทิเบิลฟรังก์ลักเซมเบิร์ก',
        ],
        'LUF' => [
            'LUF',
            'ฟรังก์ลักเซมเบิร์ก',
        ],
        'LUL' => [
            'LUL',
            'ไฟแนลเชียลฟรังก์ลักเซมเบิร์ก',
        ],
        'LVL' => [
            'LVL',
            'ลัตส์ลัตเวีย',
        ],
        'LVR' => [
            'LVR',
            'รูเบิลลัตเวีย',
        ],
        'LYD' => [
            'LYD',
            'ดีนาร์ลิเบีย',
        ],
        'MAD' => [
            'MAD',
            'ดีแรห์มโมร็อกโก',
        ],
        'MAF' => [
            'MAF',
            'ฟรังก์โมร็อกโก',
        ],
        'MCF' => [
            'MCF',
            'ฟรังก์โมนาโก',
        ],
        'MDC' => [
            'MDC',
            'บัตรปันส่วนมอลโดวา',
        ],
        'MDL' => [
            'MDL',
            'ลิวมอลโดวา',
        ],
        'MGA' => [
            'MGA',
            'อาเรียรีมาลากาซี',
        ],
        'MGF' => [
            'MGF',
            'ฟรังก์มาดากัสการ์',
        ],
        'MKD' => [
            'MKD',
            'ดีนาร์มาซิโดเนีย',
        ],
        'MKN' => [
            'MKN',
            'ดีนาร์มาซิโดเนีย (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'ฟรังก์มาลี',
        ],
        'MMK' => [
            'MMK',
            'จ๊าตพม่า',
        ],
        'MNT' => [
            'MNT',
            'ทูกริกมองโกเลีย',
        ],
        'MOP' => [
            'MOP',
            'ปาตากามาเก๊า',
        ],
        'MRO' => [
            'MRO',
            'อูกียามอริเตเนีย (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'อูกียามอริเตเนีย',
        ],
        'MTL' => [
            'MTL',
            'ลีรามอลตา',
        ],
        'MTP' => [
            'MTP',
            'ปอนด์มอลตา',
        ],
        'MUR' => [
            'MUR',
            'รูปีมอริเชียส',
        ],
        'MVR' => [
            'MVR',
            'รูฟิยามัลดีฟส์',
        ],
        'MWK' => [
            'MWK',
            'ควาชามาลาวี',
        ],
        'MXN' => [
            'MX$',
            'เปโซเม็กซิโก',
        ],
        'MXP' => [
            'MXP',
            'เงินเปโซเม็กซิโก (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'ยูนิแดด ดี อินเวอร์ชั่น เม็กซิโก',
        ],
        'MYR' => [
            'MYR',
            'ริงกิตมาเลเซีย',
        ],
        'MZE' => [
            'MZE',
            'เอสคูโดโมซัมบิก',
        ],
        'MZM' => [
            'MZM',
            'เมติคัลโมซัมบิกเก่า',
        ],
        'MZN' => [
            'MZN',
            'เมติคัลโมซัมบิก',
        ],
        'NAD' => [
            'NAD',
            'ดอลลาร์นามิเบีย',
        ],
        'NGN' => [
            'NGN',
            'ไนราไนจีเรีย',
        ],
        'NIC' => [
            'NIC',
            'คอร์โดบานิการากัว',
        ],
        'NIO' => [
            'NIO',
            'กอร์โดบานิการากัว',
        ],
        'NLG' => [
            'NLG',
            'กิลเดอร์เนเธอร์แลนด์',
        ],
        'NOK' => [
            'NOK',
            'โครนนอร์เวย์',
        ],
        'NPR' => [
            'NPR',
            'รูปีเนปาล',
        ],
        'NZD' => [
            'NZ$',
            'ดอลลาร์นิวซีแลนด์',
        ],
        'OMR' => [
            'OMR',
            'เรียลโอมาน',
        ],
        'PAB' => [
            'PAB',
            'บัลบัวปานามา',
        ],
        'PEI' => [
            'PEI',
            'อินตีเปรู',
        ],
        'PEN' => [
            'PEN',
            'ซอลเปรู',
        ],
        'PES' => [
            'PES',
            'ซอลเปรู (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'กีนาปาปัวนิวกินี',
        ],
        'PHP' => [
            'PHP',
            'เปโซฟิลิปปินส์',
        ],
        'PKR' => [
            'PKR',
            'รูปีปากีสถาน',
        ],
        'PLN' => [
            'PLN',
            'ซลอตีโปแลนด์',
        ],
        'PLZ' => [
            'PLZ',
            'ซลอตีโปแลนด์ (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'เอสคูโดโปรตุเกส',
        ],
        'PYG' => [
            'PYG',
            'กวารานีปารากวัย',
        ],
        'QAR' => [
            'QAR',
            'เรียลกาตาร์',
        ],
        'RHD' => [
            'RHD',
            'ดอลลาร์โรดีเซีย',
        ],
        'ROL' => [
            'ROL',
            'ลิวโรมาเนียเก่า',
        ],
        'RON' => [
            'RON',
            'ลิวโรมาเนีย',
        ],
        'RSD' => [
            'RSD',
            'ดีนาร์เซอร์เบีย',
        ],
        'RUB' => [
            'RUB',
            'รูเบิลรัสเซีย',
        ],
        'RUR' => [
            'RUR',
            'รูเบิลรัสเซีย (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'ฟรังก์รวันดา',
        ],
        'SAR' => [
            'SAR',
            'ริยัลซาอุดีอาระเบีย',
        ],
        'SBD' => [
            'SBD',
            'ดอลลาร์หมู่เกาะโซโลมอน',
        ],
        'SCR' => [
            'SCR',
            'รูปีเซเชลส์',
        ],
        'SDD' => [
            'SDD',
            'ดีนาร์ซูดานเก่า',
        ],
        'SDG' => [
            'SDG',
            'ปอนด์ซูดาน',
        ],
        'SDP' => [
            'SDP',
            'ปอนด์ซูดานเก่า',
        ],
        'SEK' => [
            'SEK',
            'โครนาสวีเดน',
        ],
        'SGD' => [
            'SGD',
            'ดอลลาร์สิงคโปร์',
        ],
        'SHP' => [
            'SHP',
            'ปอนด์เซนต์เฮเลนา',
        ],
        'SIT' => [
            'SIT',
            'ทอลาร์สโลวีเนีย',
        ],
        'SKK' => [
            'SKK',
            'โครูนาสโลวัก',
        ],
        'SLE' => [
            'SLE',
            'ลีโอนเซียร์ราลีโอน',
        ],
        'SLL' => [
            'SLL',
            'ลีโอนเซียร์ราลีโอน (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'ชิลลิงโซมาเลีย',
        ],
        'SRD' => [
            'SRD',
            'ดอลลาร์ซูรินาเม',
        ],
        'SRG' => [
            'SRG',
            'กิลเดอร์ซูรินาเม',
        ],
        'SSP' => [
            'SSP',
            'ปอนด์ซูดานใต้',
        ],
        'STD' => [
            'STD',
            'ดอบราเซาตูเมและปรินซิปี (1977–2017)',
        ],
        'STN' => [
            'STN',
            'ดอบราเซาตูเมและปรินซิปี',
        ],
        'SUR' => [
            'SUR',
            'รูเบิลโซเวียต',
        ],
        'SVC' => [
            'SVC',
            'โคลอนเอลซัลวาดอร์',
        ],
        'SYP' => [
            'SYP',
            'ปอนด์ซีเรีย',
        ],
        'SZL' => [
            'SZL',
            'ลิลันเจนีสวาซิ',
        ],
        'THB' => [
            '฿',
            'บาท',
        ],
        'TJR' => [
            'TJR',
            'รูเบิลทาจิกิสถาน',
        ],
        'TJS' => [
            'TJS',
            'โซโมนิทาจิกิสถาน',
        ],
        'TMM' => [
            'TMM',
            'มานัตเติร์กเมนิสถาน (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'มานัตเติร์กเมนิสถาน',
        ],
        'TND' => [
            'TND',
            'ดีนาร์ตูนิเซีย',
        ],
        'TOP' => [
            'TOP',
            'พาแองกาตองกา',
        ],
        'TPE' => [
            'TPE',
            'เอสคูโดติมอร์',
        ],
        'TRL' => [
            'TRL',
            'ลีราตุรกีเก่า',
        ],
        'TRY' => [
            'TRY',
            'ลีราตุรกี',
        ],
        'TTD' => [
            'TTD',
            'ดอลลาร์ตรินิแดดและโตเบโก',
        ],
        'TWD' => [
            'NT$',
            'ดอลลาร์ไต้หวันใหม่',
        ],
        'TZS' => [
            'TZS',
            'ชิลลิงแทนซาเนีย',
        ],
        'UAH' => [
            'UAH',
            'ฮรีฟเนียยูเครน',
        ],
        'UAK' => [
            'UAK',
            'คาร์โบวาเนตซ์ยูเครน',
        ],
        'UGS' => [
            'UGS',
            'ชิลลิงยูกันดา (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'ชิลลิงยูกันดา',
        ],
        'USD' => [
            'US$',
            'ดอลลาร์สหรัฐ',
        ],
        'USN' => [
            'USN',
            'ดอลลาร์สหรัฐ (วันถัดไป)',
        ],
        'USS' => [
            'USS',
            'ดอลลาร์สหรัฐ (วันเดียวกัน)',
        ],
        'UYI' => [
            'UYI',
            'เปโซเอนยูนิแดดเซสอินเด็กซาแดสอุรุกวัย',
        ],
        'UYP' => [
            'UYP',
            'เปโซอุรุกวัย (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'เปโซอุรุกวัย',
        ],
        'UZS' => [
            'UZS',
            'ซอมอุซเบกิสถาน',
        ],
        'VEB' => [
            'VEB',
            'โบลิวาร์เวเนซุเอลา (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'โบลิวาร์เวเนซุเอลา',
        ],
        'VES' => [
            'VES',
            'โบลีวาร์เวเนซุเอลา',
        ],
        'VND' => [
            '₫',
            'ดองเวียดนาม',
        ],
        'VNN' => [
            'VNN',
            'ดองเวียดนาม (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'วาตูวานูอาตู',
        ],
        'WST' => [
            'WST',
            'ทาลาซามัว',
        ],
        'XAF' => [
            'FCFA',
            'ฟรังก์เซฟาธนาคารรัฐแอฟริกากลาง',
        ],
        'XCD' => [
            'EC$',
            'ดอลลาร์แคริบเบียนตะวันออก',
        ],
        'XCG' => [
            'Cg.',
            'กิลเดอร์แคริบเบียน',
        ],
        'XEU' => [
            'XEU',
            'หน่วยสกุลเงินยุโรป',
        ],
        'XFO' => [
            'XFO',
            'ฟรังก์ทองฝรั่งเศส',
        ],
        'XFU' => [
            'XFU',
            'ฟรังก์ยูไอซีฝรั่งเศส',
        ],
        'XOF' => [
            'F CFA',
            'ฟรังก์เซฟาธนาคารกลางรัฐแอฟริกาตะวันตก',
        ],
        'XPF' => [
            'CFPF',
            'ฟรังก์ซีเอฟพี',
        ],
        'XRE' => [
            'XRE',
            'กองทุนไรเน็ต',
        ],
        'YDD' => [
            'YDD',
            'ดีนาร์เยเมน',
        ],
        'YER' => [
            'YER',
            'เรียลเยเมน',
        ],
        'YUD' => [
            'YUD',
            'ฮาร์ดดีนาร์ยูโกสลาเวีย',
        ],
        'YUM' => [
            'YUM',
            'โนวิย์ดีนาร์ยูโกสลาเวีย',
        ],
        'YUN' => [
            'YUN',
            'คอนเวอร์ทิเบิลดีนาร์ยูโกสลาเวีย',
        ],
        'YUR' => [
            'YUR',
            'ดีนาร์ปฏิรูปยูโกสลาเวีย (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'แรนด์แอฟริกาใต้ (การเงิน)',
        ],
        'ZAR' => [
            'ZAR',
            'แรนด์แอฟริกาใต้',
        ],
        'ZMK' => [
            'ZMK',
            'ควาชาแซมเบีย (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'ควาชาแซมเบีย',
        ],
        'ZRN' => [
            'ZRN',
            'นิวแซร์คองโก',
        ],
        'ZRZ' => [
            'ZRZ',
            'แซร์คองโก',
        ],
        'ZWD' => [
            'ZWD',
            'ดอลลาร์ซิมบับเว',
        ],
        'ZWG' => [
            'ZWG',
            'ทองซิมบับเว',
        ],
        'ZWL' => [
            'ZWL',
            'ดอลลาร์ซิมบับเว (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'ดอลลาร์ซิมบับเว (2008)',
        ],
    ],
];
