<?php

return [
    'Names' => [
        'Adlm' => 'ադլամ',
        'Arab' => 'արաբական',
        'Aran' => 'նաստալիք',
        'Armn' => 'հայկական',
        'Beng' => 'բենգալական',
        'Bopo' => 'բոպոմոֆո',
        'Brai' => 'Բրայլ',
        'Cakm' => 'չակմա',
        'Cans' => 'կանադական միասնական վանկագիր',
        'Cher' => 'չերոկի',
        'Cyrl' => 'կյուրեղագիր',
        'Deva' => 'դեւանագարի',
        'Ethi' => 'եթովպական',
        'Geor' => 'վրացական',
        'Grek' => 'հունական',
        'Gujr' => 'գուջարաթի',
        'Guru' => 'գուրմուխի',
        'Hanb' => 'հանբ',
        'Hang' => 'հանգըլ',
        'Hani' => 'չինական',
        'Hans' => 'պարզեցված',
        'Hant' => 'ավանդական',
        'Hebr' => 'եբրայական',
        'Hira' => 'հիրագանա',
        'Hrkt' => 'ճապոնական վանկագիր',
        'Jamo' => 'ջամո',
        'Jpan' => 'ճապոնական',
        'Kana' => 'կատականա',
        'Khmr' => 'քմերական',
        'Knda' => 'կաննադա',
        'Kore' => 'կորեական',
        'Laoo' => 'լաոսական',
        'Latn' => 'լատինական',
        'Mlym' => 'մալայալամ',
        'Mong' => 'մոնղոլական',
        'Mtei' => 'մանիպուրի',
        'Mymr' => 'մյանմարական',
        'Nkoo' => 'նկո',
        'Olck' => 'օլ չիկի',
        'Orya' => 'օրիյա',
        'Rohg' => 'հանիֆի',
        'Sinh' => 'սինհալական',
        'Sund' => 'սունդանական',
        'Syrc' => 'ասորական',
        'Taml' => 'թամիլական',
        'Telu' => 'թելուգու',
        'Tfng' => 'տիֆինաղ',
        'Thaa' => 'թաանա',
        'Thai' => 'թայական',
        'Tibt' => 'տիբեթական',
        'Vaii' => 'վայական',
        'Yiii' => 'ի',
        'Zmth' => 'մաթեմատիկական նշաններ',
        'Zsye' => 'էմոջի',
        'Zsym' => 'նշաններ',
        'Zxxx' => 'չգրված',
        'Zyyy' => 'ընդհանուր',
    ],
];
