<?php

return [
    'UserAssignedNames' => [
        'XK' => 'ໂຄໂຊໂວ',
    ],
    'Names' => [
        'AD' => 'ອັນດໍຣາ',
        'AE' => 'ສະຫະລັດອາຣັບເອມິເຣດ',
        'AF' => 'ອາຟການິດສະຖານ',
        'AG' => 'ແອນທິກົວ ແລະ ບາບູດາ',
        'AI' => 'ແອນກຸຍລາ',
        'AL' => 'ແອວເບເນຍ',
        'AM' => 'ອາເມເນຍ',
        'AO' => 'ແອງໂກລາ',
        'AQ' => 'ແອນຕາດຕິກາ',
        'AR' => 'ອາເຈນທິນາ',
        'AS' => 'ອາເມຣິກາ ຊາມົວ',
        'AT' => 'ອອສເທຣຍ',
        'AU' => 'ອອສເຕຣເລຍ',
        'AW' => 'ອາຣູບາ',
        'AX' => 'ຫມູ່ເກາະໂອລັນ',
        'AZ' => 'ອາເຊີໄບຈານ',
        'BA' => 'ບອດສະເນຍ ແລະ ແຮສໂກວີນາ',
        'BB' => 'ບາບາໂດສ',
        'BD' => 'ບັງກະລາເທດ',
        'BE' => 'ເບວຢຽມ',
        'BF' => 'ເບີກິນາ ຟາໂຊ',
        'BG' => 'ບັງກາເຣຍ',
        'BH' => 'ບາເຣນ',
        'BI' => 'ບູຣຸນດິ',
        'BJ' => 'ເບນິນ',
        'BL' => 'ເຊນ ບາເທເລມີ',
        'BM' => 'ເບີມິວດາ',
        'BN' => 'ບຣູໄນ',
        'BO' => 'ໂບລິເວຍ',
        'BQ' => 'ຄາຣິບບຽນ ເນເທີແລນ',
        'BR' => 'ບຣາຊິວ',
        'BS' => 'ບາຮາມາສ',
        'BT' => 'ພູຖານ',
        'BV' => 'ເກາະບູເວດ',
        'BW' => 'ບອດສະວານາ',
        'BY' => 'ເບລາຣຸສ',
        'BZ' => 'ເບລີຊ',
        'CA' => 'ແຄນາດາ',
        'CC' => 'ຫມູ່ເກາະໂກໂກສ',
        'CD' => 'ຄອງໂກ - ຄິນຊາຊາ',
        'CF' => 'ສາທາລະນະລັດອາຟຣິກາກາງ',
        'CG' => 'ຄອງໂກ - ບຣາຊາວິວ',
        'CH' => 'ສະວິດເຊີແລນ',
        'CI' => 'ໂຄຕີ ວົວ',
        'CK' => 'ໝູ່ເກາະຄຸກ',
        'CL' => 'ຊິລີ',
        'CM' => 'ຄາເມຣູນ',
        'CN' => 'ຈີນ',
        'CO' => 'ໂຄລົມເບຍ',
        'CR' => 'ໂຄສຕາ ຣິກາ',
        'CU' => 'ຄິວບາ',
        'CV' => 'ເຄບ ເວີດ',
        'CW' => 'ຄູຣາຊາວ',
        'CX' => 'ເກາະຄຣິສມາດ',
        'CY' => 'ໄຊປຣັສ',
        'CZ' => 'ເຊັກເຊຍ',
        'DE' => 'ເຢຍລະມັນ',
        'DJ' => 'ຈິບູຕິ',
        'DK' => 'ເດນມາກ',
        'DM' => 'ໂດມີນິຄາ',
        'DO' => 'ສາທາລະນະລັດ ໂດມິນິກັນ',
        'DZ' => 'ອັລຈິເຣຍ',
        'EC' => 'ເອກວາດໍ',
        'EE' => 'ເອສໂຕເນຍ',
        'EG' => 'ອີຢິບ',
        'EH' => 'ຊາຮາຣາຕາເວັນຕົກ',
        'ER' => 'ເອຣິເທຣຍ',
        'ES' => 'ສະເປນ',
        'ET' => 'ອີທິໂອເປຍ',
        'FI' => 'ຟິນແລນ',
        'FJ' => 'ຟິຈິ',
        'FK' => 'ຫມູ່ເກາະຟອກແລນ',
        'FM' => 'ໄມໂຄຣນີເຊຍ',
        'FO' => 'ຫມູ່ເກາະແຟໂຣ',
        'FR' => 'ຝຣັ່ງ',
        'GA' => 'ກາບອນ',
        'GB' => 'ສະຫະລາດຊະອະນາຈັກ',
        'GD' => 'ເກຣເນດາ',
        'GE' => 'ຈໍເຈຍ',
        'GF' => 'ເຟຣນຊ໌ ກຸຍອານາ',
        'GG' => 'ເກີນຊີ',
        'GH' => 'ການາ',
        'GI' => 'ຈິບບຣອນທາ',
        'GL' => 'ກຣີນແລນ',
        'GM' => 'ສາທາລະນະລັດແກມເບຍ',
        'GN' => 'ກິນີ',
        'GP' => 'ກົວດາລູບ',
        'GQ' => 'ເອຄົວໂທຣຽວ ກີນີ',
        'GR' => 'ກຣີຊ',
        'GS' => 'ໝູ່ເກາະ ຈໍເຈຍຕອນໃຕ້ ແລະ ແຊນວິດຕອນໃຕ້',
        'GT' => 'ກົວເທມາລາ',
        'GU' => 'ກວາມ',
        'GW' => 'ກິນີ-ບິສເຊົາ',
        'GY' => 'ກາຍຢານາ',
        'HK' => 'ຮົງກົງ ເຂດປົກຄອງພິເສດ ຈີນ',
        'HM' => 'ໝູ່ເກາະເຮີດ & ແມັກໂດນອລ',
        'HN' => 'ຮອນດູຣັສ',
        'HR' => 'ໂຄຣເອເທຍ',
        'HT' => 'ໄຮຕິ',
        'HU' => 'ຮັງກາຣີ',
        'ID' => 'ອິນໂດເນເຊຍ',
        'IE' => 'ໄອແລນ',
        'IL' => 'ອິສຣາເອວ',
        'IM' => 'ເອວ ອອບ ແມນ',
        'IN' => 'ອິນເດຍ',
        'IO' => 'ເຂດແດນອັງກິດໃນມະຫາສະໝຸດອິນເດຍ',
        'IQ' => 'ອີຣັກ',
        'IR' => 'ອີຣານ',
        'IS' => 'ໄອສແລນ',
        'IT' => 'ອິຕາລີ',
        'JE' => 'ເຈີຊີ',
        'JM' => 'ຈາໄມຄາ',
        'JO' => 'ຈໍແດນ',
        'JP' => 'ຍີ່ປຸ່ນ',
        'KE' => 'ເຄນຢາ',
        'KG' => 'ຄຽກກິດສະຖານ',
        'KH' => 'ກຳປູເຈຍ',
        'KI' => 'ຄິຣິບາທິ',
        'KM' => 'ໂຄໂມໂຣສ',
        'KN' => 'ເຊນ ຄິດ ແລະ ເນວິສ',
        'KP' => 'ເກົາຫລີເໜືອ',
        'KR' => 'ເກົາຫລີໃຕ້',
        'KW' => 'ກູເວດ',
        'KY' => 'ໝູ່ເກາະ ເຄແມນ',
        'KZ' => 'ຄາຊັກສະຖານ',
        'LA' => 'ລາວ',
        'LB' => 'ເລບານອນ',
        'LC' => 'ເຊນ ລູເຊຍ',
        'LI' => 'ລິດເທນສະຕາຍ',
        'LK' => 'ສີລັງກາ',
        'LR' => 'ລິເບີເຣຍ',
        'LS' => 'ເລໂຊໂທ',
        'LT' => 'ລິທົວເນຍ',
        'LU' => 'ລຸກແຊມເບີກ',
        'LV' => 'ລັດເວຍ',
        'LY' => 'ລິເບຍ',
        'MA' => 'ໂມຣັອກໂຄ',
        'MC' => 'ໂມນາໂຄ',
        'MD' => 'ໂມນໂດວາ',
        'ME' => 'ມອນເຕເນໂກຣ',
        'MF' => 'ເຊນ ມາທິນ',
        'MG' => 'ມາດາກາສະກາ',
        'MH' => 'ຫມູ່ເກາະມາແຊວ',
        'MK' => 'ແມຊິໂດເນຍເໜືອ',
        'ML' => 'ມາລີ',
        'MM' => 'ມຽນມາ (ເບີມາ)',
        'MN' => 'ມອງໂກເລຍ',
        'MO' => 'ມາກາວ ເຂດປົກຄອງພິເສດ ຈີນ',
        'MP' => 'ໝູ່ເກາະມາເຣຍນາຕອນເໜືອ',
        'MQ' => 'ມາຕິນີກ',
        'MR' => 'ມົວຣິເທເນຍ',
        'MS' => 'ມອນເຊີຣາດ',
        'MT' => 'ມອນທາ',
        'MU' => 'ມົວຣິຊຽສ',
        'MV' => 'ມັນດິຟ',
        'MW' => 'ມາລາວີ',
        'MX' => 'ເມັກຊິໂກ',
        'MY' => 'ມາເລເຊຍ',
        'MZ' => 'ໂມແຊມບິກ',
        'NA' => 'ນາມີເບຍ',
        'NC' => 'ນິວ ຄາເລໂດເນຍ',
        'NE' => 'ນິເຈີ',
        'NF' => 'ເກາະນໍໂຟກ',
        'NG' => 'ໄນຈີເຣຍ',
        'NI' => 'ນິກຄາຣາກົວ',
        'NL' => 'ເນເທີແລນ',
        'NO' => 'ນໍເວ',
        'NP' => 'ເນປານ',
        'NR' => 'ນາອູຣູ',
        'NU' => 'ນີອູເອ',
        'NZ' => 'ນິວຊີແລນ',
        'OM' => 'ໂອມານ',
        'PA' => 'ພານາມາ',
        'PE' => 'ເປຣູ',
        'PF' => 'ເຟຣນຊ໌ ໂພລິນີເຊຍ',
        'PG' => 'ປາປົວນິວກີນີ',
        'PH' => 'ຟິລິບປິນ',
        'PK' => 'ປາກິດສະຖານ',
        'PL' => 'ໂປແລນ',
        'PM' => 'ເຊນ ປີແອ ມິເກວລອນ',
        'PN' => 'ໝູ່ເກາະພິດແຄນ',
        'PR' => 'ເພືອໂຕ ຣິໂກ',
        'PS' => 'ດິນແດນປາເລດສະຕິນ',
        'PT' => 'ພອລທູໂກ',
        'PW' => 'ປາລາວ',
        'PY' => 'ພາຣາກວຍ',
        'QA' => 'ກາຕາ',
        'RE' => 'ເຣອູນິຍົງ',
        'RO' => 'ໂຣແມເນຍ',
        'RS' => 'ເຊີເບຍ',
        'RU' => 'ຣັດເຊຍ',
        'RW' => 'ຣວັນດາ',
        'SA' => 'ຊາອຸດິ ອາຣາເບຍ',
        'SB' => 'ຫມູ່ເກາະໂຊໂລມອນ',
        'SC' => 'ເຊເຊວເລສ',
        'SD' => 'ຊູດານ',
        'SE' => 'ສະວີເດັນ',
        'SG' => 'ສິງກະໂປ',
        'SH' => 'ເຊນ ເຮເລນາ',
        'SI' => 'ສະໂລເວເນຍ',
        'SJ' => 'ສະວາບາ ແລະ ແຢນ ມາເຢນ',
        'SK' => 'ສະໂລວາເກຍ',
        'SL' => 'ເຊຍຣາ ລີໂອນ',
        'SM' => 'ແຊນ ມາຣິໂນ',
        'SN' => 'ເຊນີໂກລ',
        'SO' => 'ໂຊມາເລຍ',
        'SR' => 'ຊູຣິນາມ',
        'SS' => 'ຊູດານໃຕ້',
        'ST' => 'ເຊົາທູເມ ແລະ ພຣິນຊິບ',
        'SV' => 'ເອວ ຊໍວາດໍ',
        'SX' => 'ຊິນ ມາເທັນ',
        'SY' => 'ຊີເຣຍ',
        'SZ' => '​ເອ​ສະ​ວາ​ຕິ​ນີ',
        'TC' => 'ໝູ່ເກາະ ເທີກ ແລະ ໄຄໂຄສ',
        'TD' => 'ຊາດ',
        'TF' => 'ເຂດແດນທາງໃຕ້ຂອງຝຮັ່ງ',
        'TG' => 'ໂຕໂກ',
        'TH' => 'ໄທ',
        'TJ' => 'ທາຈິກິດສະຖານ',
        'TK' => 'ໂຕເກເລົາ',
        'TL' => 'ທິມໍ-ເລສເຕ',
        'TM' => 'ເທີກເມນິສະຖານ',
        'TN' => 'ຕູນິເຊຍ',
        'TO' => 'ທອງກາ',
        'TR' => 'ເທີຄີ',
        'TT' => 'ທຣິນິແດດ ແລະ ໂທແບໂກ',
        'TV' => 'ຕູວາລູ',
        'TW' => 'ໄຕ້ຫວັນ',
        'TZ' => 'ທານຊາເນຍ',
        'UA' => 'ຢູເຄຣນ',
        'UG' => 'ອູການດາ',
        'UM' => 'ໝູ່ເກາະຮອບນອກຂອງສະຫະລັດຯ',
        'US' => 'ສະຫະລັດ',
        'UY' => 'ອູຣຸກວຍ',
        'UZ' => 'ອຸສເບກິສະຖານ',
        'VA' => 'ນະຄອນ ວາຕິກັນ',
        'VC' => 'ເຊນ ວິນເຊນ ແລະ ເກຣເນດິນ',
        'VE' => 'ເວເນຊູເອລາ',
        'VG' => 'ໝູ່ເກາະ ເວີຈິນຂອງອັງກິດ',
        'VI' => 'ໝູ່ເກາະ ເວີຈິນ ຂອງສະຫະລັດ',
        'VN' => 'ຫວຽດນາມ',
        'VU' => 'ວານົວຕູ',
        'WF' => 'ວາລລິສ ແລະ ຟູຕູນາ',
        'WS' => 'ຊາມົວ',
        'YE' => 'ເຢເມນ',
        'YT' => 'ມາຢັອດ',
        'ZA' => 'ອາຟຣິກາໃຕ້',
        'ZM' => 'ແຊມເບຍ',
        'ZW' => 'ຊິມບັບເວ',
    ],
];
