<?php

return [
    'Names' => [
        'GNF' => [
            'GNF',
            '𞤊𞤢𞤪𞤢𞤲 𞤘𞤭𞤲𞤫𞤲𞤳𞤮',
        ],
        'SLE' => [
            'Le',
            '𞤂𞤫𞤴𞤮𞤲 𞤅𞤫𞤪𞤢𞤤𞤭𞤴𞤢𞤲𞤳𞤮',
        ],
    ],
];
