<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ꋧꃅꎕꏦꄮꈉ（Abidjan）',
        'Africa/Accra' => 'ꋧꃅꎕꏦꄮꈉ（Accra）',
        'Africa/Bamako' => 'ꋧꃅꎕꏦꄮꈉ（Bamako）',
        'Africa/Banjul' => 'ꋧꃅꎕꏦꄮꈉ（Banjul）',
        'Africa/Bissau' => 'ꋧꃅꎕꏦꄮꈉ（Bissau）',
        'Africa/Conakry' => 'ꋧꃅꎕꏦꄮꈉ（Conakry）',
        'Africa/Dakar' => 'ꋧꃅꎕꏦꄮꈉ（Dakar）',
        'Africa/Freetown' => 'ꋧꃅꎕꏦꄮꈉ（Freetown）',
        'Africa/Lome' => 'ꋧꃅꎕꏦꄮꈉ（Lomé）',
        'Africa/Monrovia' => 'ꋧꃅꎕꏦꄮꈉ（Monrovia）',
        'Africa/Nouakchott' => 'ꋧꃅꎕꏦꄮꈉ（Nouakchott）',
        'Africa/Ouagadougou' => 'ꋧꃅꎕꏦꄮꈉ（Ouagadougou）',
        'Africa/Sao_Tome' => 'ꋧꃅꎕꏦꄮꈉ（São Tomé）',
        'America/Adak' => 'ꂰꇩꄮꈉ（Adak）',
        'America/Anchorage' => 'ꂰꇩꄮꈉ（Anchorage）',
        'America/Araguaina' => 'ꀠꑭꄮꈉ（Araguaína）',
        'America/Bahia' => 'ꀠꑭꄮꈉ（Bahia）',
        'America/Bahia_Banderas' => 'ꃀꑭꇬꄮꈉ（Bahía de Banderas）',
        'America/Belem' => 'ꀠꑭꄮꈉ（Belém）',
        'America/Boa_Vista' => 'ꀠꑭꄮꈉ（Boa Vista）',
        'America/Boise' => 'ꂰꇩꄮꈉ（Boise）',
        'America/Campo_Grande' => 'ꀠꑭꄮꈉ（Campo Grande）',
        'America/Cancun' => 'ꃀꑭꇬꄮꈉ（Cancún）',
        'America/Chicago' => 'ꂰꇩꄮꈉ（Chicago）',
        'America/Chihuahua' => 'ꃀꑭꇬꄮꈉ（Chihuahua）',
        'America/Ciudad_Juarez' => 'ꃀꑭꇬꄮꈉ（Ciudad Juárez）',
        'America/Cuiaba' => 'ꀠꑭꄮꈉ（Cuiabá）',
        'America/Danmarkshavn' => 'ꋧꃅꎕꏦꄮꈉ（Danmarkshavn）',
        'America/Denver' => 'ꂰꇩꄮꈉ（Denver）',
        'America/Detroit' => 'ꂰꇩꄮꈉ（Detroit）',
        'America/Eirunepe' => 'ꀠꑭꄮꈉ（Eirunepé）',
        'America/Fortaleza' => 'ꀠꑭꄮꈉ（Fortaleza）',
        'America/Hermosillo' => 'ꃀꑭꇬꄮꈉ（Hermosillo）',
        'America/Indiana/Knox' => 'ꂰꇩꄮꈉ（Knox, Indiana）',
        'America/Indiana/Marengo' => 'ꂰꇩꄮꈉ（Marengo, Indiana）',
        'America/Indiana/Petersburg' => 'ꂰꇩꄮꈉ（Petersburg, Indiana）',
        'America/Indiana/Tell_City' => 'ꂰꇩꄮꈉ（Tell City, Indiana）',
        'America/Indiana/Vevay' => 'ꂰꇩꄮꈉ（Vevay, Indiana）',
        'America/Indiana/Vincennes' => 'ꂰꇩꄮꈉ（Vincennes, Indiana）',
        'America/Indiana/Winamac' => 'ꂰꇩꄮꈉ（Winamac, Indiana）',
        'America/Indianapolis' => 'ꂰꇩꄮꈉ（Indianapolis）',
        'America/Indiana/Indianapolis' => 'ꂰꇩꄮꈉ（Indianapolis）',
        'America/Juneau' => 'ꂰꇩꄮꈉ（Juneau）',
        'America/Kentucky/Monticello' => 'ꂰꇩꄮꈉ（Monticello, Kentucky）',
        'America/Los_Angeles' => 'ꂰꇩꄮꈉ（Los Angeles）',
        'America/Louisville' => 'ꂰꇩꄮꈉ（Louisville）',
        'America/Kentucky/Louisville' => 'ꂰꇩꄮꈉ（Louisville）',
        'America/Maceio' => 'ꀠꑭꄮꈉ（Maceió）',
        'America/Manaus' => 'ꀠꑭꄮꈉ（Manaus）',
        'America/Matamoros' => 'ꃀꑭꇬꄮꈉ（Matamoros）',
        'America/Mazatlan' => 'ꃀꑭꇬꄮꈉ（Mazatlán）',
        'America/Menominee' => 'ꂰꇩꄮꈉ（Menominee）',
        'America/Merida' => 'ꃀꑭꇬꄮꈉ（Mérida）',
        'America/Metlakatla' => 'ꂰꇩꄮꈉ（Metlakatla）',
        'America/Mexico_City' => 'ꃀꑭꇬꄮꈉ（Ciudad de México）',
        'America/Monterrey' => 'ꃀꑭꇬꄮꈉ（Monterrey）',
        'America/New_York' => 'ꂰꇩꄮꈉ（New York）',
        'America/Nome' => 'ꂰꇩꄮꈉ（Nome）',
        'America/Noronha' => 'ꀠꑭꄮꈉ（Fernando de Noronha）',
        'America/North_Dakota/Beulah' => 'ꂰꇩꄮꈉ（Beulah, North Dakota）',
        'America/North_Dakota/Center' => 'ꂰꇩꄮꈉ（Center, North Dakota）',
        'America/North_Dakota/New_Salem' => 'ꂰꇩꄮꈉ（New Salem, North Dakota）',
        'America/Ojinaga' => 'ꃀꑭꇬꄮꈉ（Ojinaga）',
        'America/Phoenix' => 'ꂰꇩꄮꈉ（Phoenix）',
        'America/Porto_Velho' => 'ꀠꑭꄮꈉ（Porto Velho）',
        'America/Recife' => 'ꀠꑭꄮꈉ（Recife）',
        'America/Rio_Branco' => 'ꀠꑭꄮꈉ（Rio Branco）',
        'America/Santarem' => 'ꀠꑭꄮꈉ（Santarém）',
        'America/Sao_Paulo' => 'ꀠꑭꄮꈉ（São Paulo）',
        'America/Sitka' => 'ꂰꇩꄮꈉ（Sitka）',
        'America/Tijuana' => 'ꃀꑭꇬꄮꈉ（Tijuana）',
        'America/Yakutat' => 'ꂰꇩꄮꈉ（Yakutat）',
        'Antarctica/Troll' => 'ꋧꃅꎕꏦꄮꈉ（Troll）',
        'Asia/Anadyr' => 'ꊉꇆꌦꄮꈉ（Anadyr）',
        'Asia/Barnaul' => 'ꊉꇆꌦꄮꈉ（Barnaul）',
        'Asia/Calcutta' => 'ꑴꄗꄮꈉ（Kolkata）',
        'Asia/Kolkata' => 'ꑴꄗꄮꈉ（Kolkata）',
        'Asia/Chita' => 'ꊉꇆꌦꄮꈉ（Chita）',
        'Asia/Irkutsk' => 'ꊉꇆꌦꄮꈉ（Irkutsk）',
        'Asia/Kamchatka' => 'ꊉꇆꌦꄮꈉ（Kamchatka）',
        'Asia/Khandyga' => 'ꊉꇆꌦꄮꈉ（Khandyga）',
        'Asia/Krasnoyarsk' => 'ꊉꇆꌦꄮꈉ（Krasnoyarsk）',
        'Asia/Magadan' => 'ꊉꇆꌦꄮꈉ（Magadan）',
        'Asia/Novokuznetsk' => 'ꊉꇆꌦꄮꈉ（Novokuznetsk）',
        'Asia/Novosibirsk' => 'ꊉꇆꌦꄮꈉ（Novosibirsk）',
        'Asia/Omsk' => 'ꊉꇆꌦꄮꈉ（Omsk）',
        'Asia/Sakhalin' => 'ꊉꇆꌦꄮꈉ（Sakhalin）',
        'Asia/Shanghai' => 'ꍏꇩꄮꈉ（Shanghai）',
        'Asia/Srednekolymsk' => 'ꊉꇆꌦꄮꈉ（Srednekolymsk）',
        'Asia/Tokyo' => 'ꏝꀪꄮꈉ（Tokyo）',
        'Asia/Tomsk' => 'ꊉꇆꌦꄮꈉ（Tomsk）',
        'Asia/Urumqi' => 'ꍏꇩꄮꈉ（Ürümqi）',
        'Asia/Ust-Nera' => 'ꊉꇆꌦꄮꈉ（Ust-Nera）',
        'Asia/Vladivostok' => 'ꊉꇆꌦꄮꈉ（Vladivostok）',
        'Asia/Yakutsk' => 'ꊉꇆꌦꄮꈉ（Yakutsk）',
        'Asia/Yekaterinburg' => 'ꊉꇆꌦꄮꈉ（Yekaterinburg）',
        'Atlantic/Reykjavik' => 'ꋧꃅꎕꏦꄮꈉ（Reykjavik）',
        'Atlantic/St_Helena' => 'ꋧꃅꎕꏦꄮꈉ（St. Helena）',
        'Etc/GMT' => 'ꋧꃅꎕꏦꄮꈉ',
        'Europe/Astrakhan' => 'ꊉꇆꌦꄮꈉ（Astrakhan）',
        'Europe/Berlin' => 'ꄓꇩꄮꈉ（Berlin）',
        'Europe/Brussels' => 'ꀘꆹꏃꄮꈉ（Brussels）',
        'Europe/Busingen' => 'ꄓꇩꄮꈉ（Büsingen）',
        'Europe/Dublin' => 'ꋧꃅꎕꏦꄮꈉ（Dublin）',
        'Europe/Guernsey' => 'ꋧꃅꎕꏦꄮꈉ（Guernsey）',
        'Europe/Isle_of_Man' => 'ꋧꃅꎕꏦꄮꈉ（Isle of Man）',
        'Europe/Jersey' => 'ꋧꃅꎕꏦꄮꈉ（Jersey）',
        'Europe/Kaliningrad' => 'ꊉꇆꌦꄮꈉ（Kaliningrad）',
        'Europe/Kirov' => 'ꊉꇆꌦꄮꈉ（Kirov）',
        'Europe/London' => 'ꋧꃅꎕꏦꄮꈉ（London）',
        'Europe/Moscow' => 'ꊉꇆꌦꄮꈉ（Moscow）',
        'Europe/Paris' => 'ꃔꇩꄮꈉ（Paris）',
        'Europe/Rome' => 'ꑴꄊꆺꄮꈉ（Rome）',
        'Europe/Samara' => 'ꊉꇆꌦꄮꈉ（Samara）',
        'Europe/Saratov' => 'ꊉꇆꌦꄮꈉ（Saratov）',
        'Europe/Ulyanovsk' => 'ꊉꇆꌦꄮꈉ（Ulyanovsk）',
        'Europe/Volgograd' => 'ꊉꇆꌦꄮꈉ（Volgograd）',
        'Pacific/Honolulu' => 'ꂰꇩꄮꈉ（Honolulu）',
    ],
    'Meta' => [
        'GmtFormat' => 'ꋧꃅꎕꏦꄮꈉ%s',
    ],
];
