<?php

return [
    'UserAssignedNames' => [],
    'Names' => [
        'AD' => 'Andôro',
        'AE' => 'Arâbo Emirâti Ôko',
        'AF' => 'Faganïta, Afganïstäan',
        'AG' => 'Antîgua na Barbûda',
        'AI' => 'Angûîla',
        'AL' => 'Albanïi',
        'AM' => 'Armenïi',
        'AO' => 'Angoläa',
        'AR' => 'Arzantîna',
        'AS' => 'Samöa tî Amerîka',
        'AT' => 'Otrîsi',
        'AU' => 'Ostralïi, Sotralïi',
        'AW' => 'Arûba',
        'AZ' => 'Zerebaidyäan, Azerbaidyäan,',
        'BA' => 'Bosnïi na Herzegovînni',
        'BB' => 'Barabâda',
        'BD' => 'Bengladêshi',
        'BE' => 'Bêleze, Belezîki',
        'BF' => 'Burkina Faso',
        'BG' => 'Bulugarïi',
        'BH' => 'Bahrâina',
        'BI' => 'Burundïi',
        'BJ' => 'Benëen',
        'BM' => 'Beremûda',
        'BN' => 'Brunêi',
        'BO' => 'Bolivïi',
        'BR' => 'Brezîli',
        'BS' => 'Bahâmasa',
        'BT' => 'Butäan',
        'BW' => 'Botswana',
        'BY' => 'Belarüsi',
        'BZ' => 'Belîzi',
        'CA' => 'Kanadäa',
        'CD' => 'Ködörösêse tî Ngunuhalëzo tî kongö',
        'CF' => 'Ködörösêse tî Bêafrîka',
        'CG' => 'Kongö',
        'CH' => 'Sûîsi',
        'CI' => 'Kôdivüära',
        'CK' => 'âzûâ Kûku',
        'CL' => 'Shilïi',
        'CM' => 'Kamerûne',
        'CN' => 'Shîna',
        'CO' => 'Kolombïi',
        'CR' => 'Kôsta Rîka',
        'CU' => 'Kubäa',
        'CV' => 'Azûâ tî Kâpo-Vêre',
        'CY' => 'Sîpri',
        'CZ' => 'Ködörösêse tî Tyêki',
        'DE' => 'Zâmani',
        'DJ' => 'Dibutùii',
        'DK' => 'Danemêrke',
        'DM' => 'Dömïnîka',
        'DO' => 'Ködörösêse tî Dominîka',
        'DZ' => 'Alzerïi',
        'EC' => 'Ekuatëre',
        'EE' => 'Estonïi',
        'EG' => 'Kâmitâ',
        'ER' => 'Eritrëe',
        'ES' => 'Espânye',
        'ET' => 'Etiopïi',
        'FI' => 'Fëlânde',
        'FJ' => 'Fidyïi',
        'FK' => 'Âzûâ tî Mälüîni',
        'FM' => 'Mikronezïi',
        'FR' => 'Farânzi',
        'GA' => 'Gaböon',
        'GB' => 'Ködörögbïä--Ôko',
        'GD' => 'Grenâda',
        'GE' => 'Zorzïi',
        'GF' => 'Güyâni tî farânzi',
        'GH' => 'Ganäa',
        'GI' => 'Zibraltära, Zibaratära',
        'GL' => 'Gorolânde',
        'GM' => 'Gambïi',
        'GN' => 'Ginëe',
        'GP' => 'Guadelûpu',
        'GQ' => 'Ginëe tî Ekuatëre',
        'GR' => 'Gerêsi',
        'GT' => 'Guatêmälä',
        'GU' => 'Guâm',
        'GW' => 'Gninëe-Bisau',
        'GY' => 'Gayâna',
        'HN' => 'Honduräsi',
        'HR' => 'Kroasïi',
        'HT' => 'Haitïi',
        'HU' => 'Hongirùii',
        'ID' => 'Ênndonezïi',
        'IE' => 'Irlânde',
        'IL' => 'Israëli',
        'IN' => 'Ênnde',
        'IQ' => 'Irâki',
        'IR' => 'Iräan',
        'IS' => 'Islânde',
        'IT' => 'Italùii',
        'JM' => 'Zamaîka',
        'JO' => 'Zordanïi',
        'JP' => 'Zapöon',
        'KE' => 'Kenyäa',
        'KG' => 'Kirigizitùaan',
        'KH' => 'Kämbôzi',
        'KI' => 'Kiribati',
        'KM' => 'Kömôro',
        'KN' => 'Sên-Krïstôfo-na-Nevîsi',
        'KP' => 'Korëe tî Banga',
        'KR' => 'Korëe tî Mbongo',
        'KW' => 'Köwêti',
        'KY' => 'Âzûâ Ngundë, Kaimäni',
        'KZ' => 'Kazakisitäan',
        'LA' => 'Lùaôsi',
        'LB' => 'Libùaan',
        'LC' => 'Sênt-Lisïi',
        'LI' => 'Liechtenstein,',
        'LK' => 'Sirî-Lanka',
        'LR' => 'Liberïa',
        'LS' => 'Lesôtho',
        'LT' => 'Lituanïi',
        'LU' => 'Lugzambûru',
        'LV' => 'Letonùii',
        'LY' => 'Libïi',
        'MA' => 'Marôko',
        'MC' => 'Monaköo',
        'MD' => 'Moldavùii',
        'MG' => 'Madagaskära',
        'MH' => 'Âzûâ Märshâl',
        'ML' => 'Malïi',
        'MM' => 'Myämâra',
        'MN' => 'Mongolïi',
        'MP' => 'Âzûâ Märïâni tî Banga',
        'MQ' => 'Märtïnîki',
        'MR' => 'Moritanïi',
        'MS' => 'Monserâte',
        'MT' => 'Mâlta',
        'MU' => 'Mörîsi',
        'MV' => 'Maldîva',
        'MW' => 'Malawïi',
        'MX' => 'Mekisîki',
        'MY' => 'Malezïi',
        'MZ' => 'Mözämbîka',
        'NA' => 'Namibùii',
        'NC' => 'Finî Kaledonïi',
        'NE' => 'Nizëre',
        'NF' => 'Zûâ Nôrfôlko',
        'NG' => 'Nizerïa',
        'NI' => 'Nikaragua',
        'NL' => 'Holände',
        'NO' => 'Nörvêzi',
        'NP' => 'Nëpâli',
        'NR' => 'Nauru',
        'NU' => 'Niue',
        'NZ' => 'Finî Zelânde',
        'OM' => 'Omâni',
        'PA' => 'Panama',
        'PE' => 'Perüu',
        'PF' => 'Polinezïi tî farânzi',
        'PG' => 'Papû Finî Ginëe, Papuazïi',
        'PH' => 'Filipîni',
        'PK' => 'Pakistäan',
        'PL' => 'Pölôni',
        'PM' => 'Sên-Pyêre na Mikelöon',
        'PN' => 'Pitikêrni',
        'PR' => 'Porto Rîko',
        'PS' => 'Sêse tî Palestîni',
        'PT' => 'Pörtugäle, Ködörö Pûra',
        'PW' => 'Palau',
        'PY' => 'Paraguëe',
        'QA' => 'Katära',
        'RE' => 'Reinïon',
        'RO' => 'Rumanïi',
        'RU' => 'Rusïi',
        'RW' => 'Ruandäa',
        'SA' => 'Saûdi Arabïi',
        'SB' => 'Zûâ Salomöon',
        'SC' => 'Sëyshêle',
        'SD' => 'Sudäan',
        'SE' => 'Suêde',
        'SG' => 'Sïngäpûru',
        'SH' => 'Sênt-Helêna',
        'SI' => 'Solovenïi',
        'SK' => 'Solovakïi',
        'SL' => 'Sierä-Leône',
        'SM' => 'Sên-Marëen',
        'SN' => 'Senegäle',
        'SO' => 'Somalïi',
        'SR' => 'Surinäm',
        'ST' => 'Sâô Tömê na Prinsîpe',
        'SV' => 'Salvadöro',
        'SY' => 'Sirïi',
        'SZ' => 'Swäzïlânde',
        'TC' => 'Âzûâ Turku na Kaîki',
        'TD' => 'Tyâde',
        'TG' => 'Togö',
        'TH' => 'Tailânde',
        'TJ' => 'Taazikiistäan',
        'TK' => 'Tokelau',
        'TL' => 'Timôro tî Tö',
        'TM' => 'Turkumenistäan',
        'TN' => 'Tunizïi',
        'TO' => 'Tonga',
        'TR' => 'Turukïi',
        'TT' => 'Trinitùee na Tobagö',
        'TV' => 'Tüvalü',
        'TW' => 'Tâiwâni',
        'TZ' => 'Tanzanïi',
        'UA' => 'Ukrêni',
        'UG' => 'Ugandäa',
        'US' => 'ÂLeaa-Ôko tî Amerika',
        'UY' => 'Uruguëe',
        'UZ' => 'Uzbekistäan',
        'VA' => 'Letëe tî Vatikäan',
        'VC' => 'Sên-Vensäan na âGrenadîni',
        'VE' => 'Venezueläa',
        'VG' => 'Âzôâ Viîrîggo tî Anglëe',
        'VI' => 'Âzûâ Virîgo tî Amerîka',
        'VN' => 'Vietnäm',
        'VU' => 'Vanuatü',
        'WF' => 'Walîsi na Futuna',
        'WS' => 'Samoäa',
        'YE' => 'Yëmêni',
        'YT' => 'Mäyôte',
        'ZA' => 'Mbongo-Afrîka',
        'ZM' => 'Zambïi',
        'ZW' => 'Zimbäbwe',
    ],
];
