<?php

return [
    'Names' => [
        'Arab' => 'Ӏаьрбийн',
        'Armn' => 'эрмалойн',
        'Beng' => 'бенгалхойн',
        'Bopo' => 'бопомофо',
        'Brai' => 'брайля',
        'Cyrl' => 'кириллица',
        'Deva' => 'деванагари',
        'Ethi' => 'эфиопин',
        'Geor' => 'гуьржийн',
        'Grek' => 'грекийн',
        'Gujr' => 'гуджарати',
        'Guru' => 'гурмукхи',
        'Hanb' => 'ханьб',
        'Hang' => 'хангыль',
        'Hani' => 'китайн',
        'Hans' => 'атта китайн',
        'Hant' => 'ламастан китайн',
        'Hebr' => 'жугтийн',
        'Hira' => 'хирагана',
        'Hrkt' => 'катакана я хирагана',
        'Jamo' => 'джамо',
        'Jpan' => 'японийн',
        'Kana' => 'катакана',
        'Khmr' => 'кхмерийн',
        'Knda' => 'каннада',
        'Kore' => 'корейн',
        'Laoo' => 'лаоссийн',
        'Latn' => 'латинан',
        'Mlym' => 'малаялийн',
        'Mong' => 'монголийн',
        'Mymr' => 'мьянманийн',
        'Orya' => 'ори',
        'Sinh' => 'сингалхойн',
        'Taml' => 'тамилхойн',
        'Telu' => 'телугу',
        'Thaa' => 'таана',
        'Thai' => 'тайн',
        'Tibt' => 'тибетхойн',
        'Zmth' => 'математикан маьӀна',
        'Zsye' => 'эмодзи',
        'Zsym' => 'символаш',
        'Zxxx' => 'йоза доцу',
        'Zyyy' => 'массара а тӀеэцна',
    ],
];
