<?php

return [
    'Names' => [
        'Arab' => 'ꀊꇁꀨꁱꂷ',
        'Cyrl' => 'ꀊꆨꌦꇁꃚꁱꂷ',
        'Hans' => 'ꈝꐮꁱꂷ',
        'Hant' => 'ꀎꋏꁱꂷ',
        'Latn' => 'ꇁꄂꁱꂷ',
        'Yiii' => 'ꆈꌠꁱꂷ',
        'Zxxx' => 'ꁱꀋꉆꌠ',
    ],
];
