<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'greenwichský čas (Abidjan)',
        'Africa/Accra' => 'greenwichský čas (Akkra)',
        'Africa/Addis_Ababa' => 'východoafrický čas (Addis Abeba)',
        'Africa/Algiers' => 'stredoeurópsky čas (Alžír)',
        'Africa/Asmera' => 'východoafrický čas (Asmara)',
        'Africa/Asmara' => 'východoafrický čas (Asmara)',
        'Africa/Bamako' => 'greenwichský čas (Bamako)',
        'Africa/Bangui' => 'západoafrický čas (Bangui)',
        'Africa/Banjul' => 'greenwichský čas (Banjul)',
        'Africa/Bissau' => 'greenwichský čas (Bissau)',
        'Africa/Blantyre' => 'stredoafrický čas (Blantyre)',
        'Africa/Brazzaville' => 'západoafrický čas (Brazzaville)',
        'Africa/Bujumbura' => 'stredoafrický čas (Bujumbura)',
        'Africa/Cairo' => 'východoeurópsky čas (Káhira)',
        'Africa/Casablanca' => 'západoeurópsky čas (Casablanca)',
        'Africa/Ceuta' => 'stredoeurópsky čas (Ceuta)',
        'Africa/Conakry' => 'greenwichský čas (Konakry)',
        'Africa/Dakar' => 'greenwichský čas (Dakar)',
        'Africa/Dar_es_Salaam' => 'východoafrický čas (Dar es Salaam)',
        'Africa/Djibouti' => 'východoafrický čas (Džibuti)',
        'Africa/Douala' => 'západoafrický čas (Douala)',
        'Africa/El_Aaiun' => 'západoeurópsky čas (El-Aaiún)',
        'Africa/Freetown' => 'greenwichský čas (Freetown)',
        'Africa/Gaborone' => 'stredoafrický čas (Gaborone)',
        'Africa/Harare' => 'stredoafrický čas (Harare)',
        'Africa/Johannesburg' => 'juhoafrický čas (Johannesburg)',
        'Africa/Juba' => 'stredoafrický čas (Juba)',
        'Africa/Kampala' => 'východoafrický čas (Kampala)',
        'Africa/Khartoum' => 'stredoafrický čas (Chartúm)',
        'Africa/Kigali' => 'stredoafrický čas (Kigali)',
        'Africa/Kinshasa' => 'západoafrický čas (Kinshasa)',
        'Africa/Lagos' => 'západoafrický čas (Lagos)',
        'Africa/Libreville' => 'západoafrický čas (Libreville)',
        'Africa/Lome' => 'greenwichský čas (Lomé)',
        'Africa/Luanda' => 'západoafrický čas (Luanda)',
        'Africa/Lubumbashi' => 'stredoafrický čas (Lubumbashi)',
        'Africa/Lusaka' => 'stredoafrický čas (Lusaka)',
        'Africa/Malabo' => 'západoafrický čas (Malabo)',
        'Africa/Maputo' => 'stredoafrický čas (Maputo)',
        'Africa/Maseru' => 'juhoafrický čas (Maseru)',
        'Africa/Mbabane' => 'juhoafrický čas (Mbabane)',
        'Africa/Mogadishu' => 'východoafrický čas (Mogadišo)',
        'Africa/Monrovia' => 'greenwichský čas (Monrovia)',
        'Africa/Nairobi' => 'východoafrický čas (Nairobi)',
        'Africa/Ndjamena' => 'západoafrický čas (N’Djamena)',
        'Africa/Niamey' => 'západoafrický čas (Niamey)',
        'Africa/Nouakchott' => 'greenwichský čas (Nouakchott)',
        'Africa/Ouagadougou' => 'greenwichský čas (Ouagadougou)',
        'Africa/Porto-Novo' => 'západoafrický čas (Porto-Novo)',
        'Africa/Sao_Tome' => 'greenwichský čas (Svätý Tomáš)',
        'Africa/Tripoli' => 'východoeurópsky čas (Tripolis)',
        'Africa/Tunis' => 'stredoeurópsky čas (Tunis)',
        'Africa/Windhoek' => 'stredoafrický čas (Windhoek)',
        'America/Adak' => 'havajsko-aleutský čas (Adak)',
        'America/Anchorage' => 'aljašský čas (Anchorage)',
        'America/Anguilla' => 'atlantický čas (Anguilla)',
        'America/Antigua' => 'atlantický čas (Antigua)',
        'America/Araguaina' => 'brazílsky čas (Araguaína)',
        'America/Argentina/La_Rioja' => 'argentínsky čas (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'argentínsky čas (Río Gallegos)',
        'America/Argentina/Salta' => 'argentínsky čas (Salta)',
        'America/Argentina/San_Juan' => 'argentínsky čas (San Juan)',
        'America/Argentina/San_Luis' => 'argentínsky čas (San Luis)',
        'America/Argentina/Tucuman' => 'argentínsky čas (Tucumán)',
        'America/Argentina/Ushuaia' => 'argentínsky čas (Ushuaia)',
        'America/Aruba' => 'atlantický čas (Aruba)',
        'America/Asuncion' => 'paraguajský čas (Asunción)',
        'America/Bahia' => 'brazílsky čas (Bahia)',
        'America/Bahia_Banderas' => 'severoamerický centrálny čas (Bahia Banderas)',
        'America/Barbados' => 'atlantický čas (Barbados)',
        'America/Belem' => 'brazílsky čas (Belém)',
        'America/Belize' => 'severoamerický centrálny čas (Belize)',
        'America/Blanc-Sablon' => 'atlantický čas (Blanc-Sablon)',
        'America/Boa_Vista' => 'amazonský čas (Boa Vista)',
        'America/Bogota' => 'kolumbijský čas (Bogotá)',
        'America/Boise' => 'severoamerický horský čas (Boise)',
        'America/Buenos_Aires' => 'argentínsky čas (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'argentínsky čas (Buenos Aires)',
        'America/Cambridge_Bay' => 'severoamerický horský čas (Cambridge Bay)',
        'America/Campo_Grande' => 'amazonský čas (Campo Grande)',
        'America/Cancun' => 'severoamerický východný čas (Cancún)',
        'America/Caracas' => 'venezuelský čas (Caracas)',
        'America/Catamarca' => 'argentínsky čas (Catamarca)',
        'America/Argentina/Catamarca' => 'argentínsky čas (Catamarca)',
        'America/Cayenne' => 'francúzskoguyanský čas (Cayenne)',
        'America/Cayman' => 'severoamerický východný čas (Kajmanie ostrovy)',
        'America/Chicago' => 'severoamerický centrálny čas (Chicago)',
        'America/Chihuahua' => 'severoamerický centrálny čas (Chihuahua)',
        'America/Ciudad_Juarez' => 'severoamerický horský čas (Ciudad Juárez)',
        'America/Coral_Harbour' => 'severoamerický východný čas (Atikokan)',
        'America/Atikokan' => 'severoamerický východný čas (Atikokan)',
        'America/Cordoba' => 'argentínsky čas (Córdoba)',
        'America/Argentina/Cordoba' => 'argentínsky čas (Córdoba)',
        'America/Costa_Rica' => 'severoamerický centrálny čas (Kostarika)',
        'America/Coyhaique' => 'čilský čas (Coyhaique)',
        'America/Creston' => 'severoamerický horský čas (Creston)',
        'America/Cuiaba' => 'amazonský čas (Cuiabá)',
        'America/Curacao' => 'atlantický čas (Curaçao)',
        'America/Danmarkshavn' => 'greenwichský čas (Danmarkshavn)',
        'America/Dawson' => 'yukonský čas (Dawson)',
        'America/Dawson_Creek' => 'severoamerický horský čas (Dawson Creek)',
        'America/Denver' => 'severoamerický horský čas (Denver)',
        'America/Detroit' => 'severoamerický východný čas (Detroit)',
        'America/Dominica' => 'atlantický čas (Dominika)',
        'America/Edmonton' => 'severoamerický horský čas (Edmonton)',
        'America/Eirunepe' => 'acrejský čas (Eirunepé)',
        'America/El_Salvador' => 'severoamerický centrálny čas (Salvádor)',
        'America/Fort_Nelson' => 'severoamerický horský čas (Fort Nelson)',
        'America/Fortaleza' => 'brazílsky čas (Fortaleza)',
        'America/Glace_Bay' => 'atlantický čas (Glace Bay)',
        'America/Godthab' => 'časové pásmo Grónsko (Nuuk)',
        'America/Nuuk' => 'časové pásmo Grónsko (Nuuk)',
        'America/Goose_Bay' => 'atlantický čas (Goose Bay)',
        'America/Grand_Turk' => 'severoamerický východný čas (Grand Turk)',
        'America/Grenada' => 'atlantický čas (Grenada)',
        'America/Guadeloupe' => 'atlantický čas (Guadeloupe)',
        'America/Guatemala' => 'severoamerický centrálny čas (Guatemala)',
        'America/Guayaquil' => 'ekvádorský čas (Guayaquil)',
        'America/Guyana' => 'guyanský čas (Guyana)',
        'America/Halifax' => 'atlantický čas (Halifax)',
        'America/Havana' => 'kubánsky čas (Havana)',
        'America/Hermosillo' => 'mexický tichomorský čas (Hermosillo)',
        'America/Indiana/Knox' => 'severoamerický centrálny čas (Knox, Indiana)',
        'America/Indiana/Marengo' => 'severoamerický východný čas (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'severoamerický východný čas (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'severoamerický centrálny čas (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'severoamerický východný čas (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'severoamerický východný čas (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'severoamerický východný čas (Winamac, Indiana)',
        'America/Indianapolis' => 'severoamerický východný čas (Indianapolis)',
        'America/Indiana/Indianapolis' => 'severoamerický východný čas (Indianapolis)',
        'America/Inuvik' => 'severoamerický horský čas (Inuvik)',
        'America/Iqaluit' => 'severoamerický východný čas (Iqaluit)',
        'America/Jamaica' => 'severoamerický východný čas (Jamajka)',
        'America/Jujuy' => 'argentínsky čas (Jujuy)',
        'America/Argentina/Jujuy' => 'argentínsky čas (Jujuy)',
        'America/Juneau' => 'aljašský čas (Juneau)',
        'America/Kentucky/Monticello' => 'severoamerický východný čas (Monticello, Kentucky)',
        'America/Kralendijk' => 'atlantický čas (Kralendijk)',
        'America/La_Paz' => 'bolívijský čas (La Paz)',
        'America/Lima' => 'peruánsky čas (Lima)',
        'America/Los_Angeles' => 'severoamerický tichomorský čas (Los Angeles)',
        'America/Louisville' => 'severoamerický východný čas (Louisville)',
        'America/Kentucky/Louisville' => 'severoamerický východný čas (Louisville)',
        'America/Lower_Princes' => 'atlantický čas (Lower Prince’s Quarter)',
        'America/Maceio' => 'brazílsky čas (Maceió)',
        'America/Managua' => 'severoamerický centrálny čas (Managua)',
        'America/Manaus' => 'amazonský čas (Manaus)',
        'America/Marigot' => 'atlantický čas (Marigot)',
        'America/Martinique' => 'atlantický čas (Martinik)',
        'America/Matamoros' => 'severoamerický centrálny čas (Matamoros)',
        'America/Mazatlan' => 'mexický tichomorský čas (Mazatlán)',
        'America/Mendoza' => 'argentínsky čas (Mendoza)',
        'America/Argentina/Mendoza' => 'argentínsky čas (Mendoza)',
        'America/Menominee' => 'severoamerický centrálny čas (Menominee)',
        'America/Merida' => 'severoamerický centrálny čas (Mérida)',
        'America/Metlakatla' => 'aljašský čas (Metlakatla)',
        'America/Mexico_City' => 'severoamerický centrálny čas (México)',
        'America/Miquelon' => 'pierre-miquelonský čas (Saint-Pierre)',
        'America/Moncton' => 'atlantický čas (Moncton)',
        'America/Monterrey' => 'severoamerický centrálny čas (Monterrey)',
        'America/Montevideo' => 'uruguajský čas (Montevideo)',
        'America/Montserrat' => 'atlantický čas (Montserrat)',
        'America/Nassau' => 'severoamerický východný čas (Nassau)',
        'America/New_York' => 'severoamerický východný čas (New York)',
        'America/Nome' => 'aljašský čas (Nome)',
        'America/Noronha' => 'čas súostrovia Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'severoamerický centrálny čas (Beulah, Severná Dakota)',
        'America/North_Dakota/Center' => 'severoamerický centrálny čas (Center, Severná Dakota)',
        'America/North_Dakota/New_Salem' => 'severoamerický centrálny čas (New Salem, Severná Dakota)',
        'America/Ojinaga' => 'severoamerický centrálny čas (Ojinaga)',
        'America/Panama' => 'severoamerický východný čas (Panama)',
        'America/Paramaribo' => 'surinamský čas (Paramaribo)',
        'America/Phoenix' => 'severoamerický horský čas (Phoenix)',
        'America/Port-au-Prince' => 'severoamerický východný čas (Port-au-Prince)',
        'America/Port_of_Spain' => 'atlantický čas (Port of Spain)',
        'America/Porto_Velho' => 'amazonský čas (Porto Velho)',
        'America/Puerto_Rico' => 'atlantický čas (Portoriko)',
        'America/Punta_Arenas' => 'čilský čas (Punta Arenas)',
        'America/Rankin_Inlet' => 'severoamerický centrálny čas (Rankin Inlet)',
        'America/Recife' => 'brazílsky čas (Recife)',
        'America/Regina' => 'severoamerický centrálny čas (Regina)',
        'America/Resolute' => 'severoamerický centrálny čas (Resolute)',
        'America/Rio_Branco' => 'acrejský čas (Rio Branco)',
        'America/Santarem' => 'brazílsky čas (Santarém)',
        'America/Santiago' => 'čilský čas (Santiago)',
        'America/Santo_Domingo' => 'atlantický čas (Santo Domingo)',
        'America/Sao_Paulo' => 'brazílsky čas (São Paulo)',
        'America/Scoresbysund' => 'časové pásmo Grónsko (Ittoqqortoormiit)',
        'America/Sitka' => 'aljašský čas (Sitka)',
        'America/St_Barthelemy' => 'atlantický čas (Svätý Bartolomej)',
        'America/St_Johns' => 'newfoundlandský čas (St. John’s)',
        'America/St_Kitts' => 'atlantický čas (St. Kitts)',
        'America/St_Lucia' => 'atlantický čas (Svätá Lucia)',
        'America/St_Thomas' => 'atlantický čas (Sv. Tomáš)',
        'America/St_Vincent' => 'atlantický čas (Sv. Vincent)',
        'America/Swift_Current' => 'severoamerický centrálny čas (Swift Current)',
        'America/Tegucigalpa' => 'severoamerický centrálny čas (Tegucigalpa)',
        'America/Thule' => 'atlantický čas (Thule)',
        'America/Tijuana' => 'severoamerický tichomorský čas (Tijuana)',
        'America/Toronto' => 'severoamerický východný čas (Toronto)',
        'America/Tortola' => 'atlantický čas (Tortola)',
        'America/Vancouver' => 'severoamerický tichomorský čas (Vancouver)',
        'America/Whitehorse' => 'yukonský čas (Whitehorse)',
        'America/Winnipeg' => 'severoamerický centrálny čas (Winnipeg)',
        'America/Yakutat' => 'aljašský čas (Yakutat)',
        'Antarctica/Casey' => 'západoaustrálsky čas (Casey)',
        'Antarctica/Davis' => 'čas Davisovej stanice',
        'Antarctica/DumontDUrville' => 'čas stanice Dumonta d’Urvillea (Dumont-d’Urville)',
        'Antarctica/Macquarie' => 'východoaustrálsky čas (Macquarie)',
        'Antarctica/Mawson' => 'čas Mawsonovej stanice',
        'Antarctica/McMurdo' => 'novozélandský čas (McMurdo)',
        'Antarctica/Palmer' => 'čilský čas (Palmer)',
        'Antarctica/Rothera' => 'čas Rotherovej stanice (Rothera)',
        'Antarctica/Syowa' => 'čas stanice Šówa',
        'Antarctica/Troll' => 'greenwichský čas (Troll)',
        'Antarctica/Vostok' => 'čas stanice Vostok',
        'Arctic/Longyearbyen' => 'stredoeurópsky čas (Longyearbyen)',
        'Asia/Aden' => 'arabský čas (Aden)',
        'Asia/Almaty' => 'kazachstanský čas (Alma‑Ata)',
        'Asia/Amman' => 'východoeurópsky čas (Ammán)',
        'Asia/Anadyr' => 'Petropavlovsk-Kamčatský čas (Anadyr)',
        'Asia/Aqtau' => 'kazachstanský čas (Aktau)',
        'Asia/Aqtobe' => 'kazachstanský čas (Aktobe)',
        'Asia/Ashgabat' => 'turkménsky čas (Ašchabad)',
        'Asia/Atyrau' => 'kazachstanský čas (Atyrau)',
        'Asia/Baghdad' => 'arabský čas (Bagdad)',
        'Asia/Bahrain' => 'arabský čas (Bahrajn)',
        'Asia/Baku' => 'azerbajdžanský čas (Baku)',
        'Asia/Bangkok' => 'indočínsky čas (Bangkok)',
        'Asia/Barnaul' => 'krasnojarský čas (Barnaul)',
        'Asia/Beirut' => 'východoeurópsky čas (Bejrút)',
        'Asia/Bishkek' => 'kirgizský čas (Biškek)',
        'Asia/Brunei' => 'brunejský čas',
        'Asia/Calcutta' => 'indický čas (Kalkata)',
        'Asia/Kolkata' => 'indický čas (Kalkata)',
        'Asia/Chita' => 'jakutský čas (Čita)',
        'Asia/Colombo' => 'indický čas (Kolombo)',
        'Asia/Damascus' => 'východoeurópsky čas (Damask)',
        'Asia/Dhaka' => 'bangladéšsky čas (Dháka)',
        'Asia/Dili' => 'východotimorský čas (Dili)',
        'Asia/Dubai' => 'štandardný čas Perzského zálivu (Dubaj)',
        'Asia/Dushanbe' => 'tadžický čas (Dušanbe)',
        'Asia/Famagusta' => 'východoeurópsky čas (Famagusta)',
        'Asia/Gaza' => 'východoeurópsky čas (Gaza)',
        'Asia/Hebron' => 'východoeurópsky čas (Hebron)',
        'Asia/Hong_Kong' => 'hongkonský čas (Hongkong)',
        'Asia/Hovd' => 'chovdský čas',
        'Asia/Irkutsk' => 'irkutský čas',
        'Asia/Jakarta' => 'západoindonézsky čas (Jakarta)',
        'Asia/Jayapura' => 'východoindonézsky čas (Jayapura)',
        'Asia/Jerusalem' => 'izraelský čas (Jeruzalem)',
        'Asia/Kabul' => 'afganský čas (Kábul)',
        'Asia/Kamchatka' => 'Petropavlovsk-Kamčatský čas (Kamčatka)',
        'Asia/Karachi' => 'pakistanský čas (Karáči)',
        'Asia/Katmandu' => 'nepálsky čas (Káthmandu)',
        'Asia/Kathmandu' => 'nepálsky čas (Káthmandu)',
        'Asia/Khandyga' => 'jakutský čas (Chandyga)',
        'Asia/Krasnoyarsk' => 'krasnojarský čas',
        'Asia/Kuala_Lumpur' => 'malajzijský čas (Kuala Lumpur)',
        'Asia/Kuching' => 'malajzijský čas (Kučing)',
        'Asia/Kuwait' => 'arabský čas (Kuvajt)',
        'Asia/Macau' => 'čínsky čas (Macao)',
        'Asia/Magadan' => 'magadanský čas',
        'Asia/Makassar' => 'stredoindonézsky čas (Makassar)',
        'Asia/Manila' => 'filipínsky čas (Manila)',
        'Asia/Muscat' => 'štandardný čas Perzského zálivu (Maskat)',
        'Asia/Nicosia' => 'východoeurópsky čas (Nikózia)',
        'Asia/Novokuznetsk' => 'krasnojarský čas (Novokuzneck)',
        'Asia/Novosibirsk' => 'krasnojarský čas (Novosibirsk)',
        'Asia/Omsk' => 'omský čas',
        'Asia/Oral' => 'kazachstanský čas (Uraľsk)',
        'Asia/Phnom_Penh' => 'indočínsky čas (Phnom Pénh)',
        'Asia/Pontianak' => 'západoindonézsky čas (Pontianak)',
        'Asia/Pyongyang' => 'kórejský čas (Pchjongjang)',
        'Asia/Qatar' => 'arabský čas (Katar)',
        'Asia/Qostanay' => 'kazachstanský čas (Kostanaj)',
        'Asia/Qyzylorda' => 'kazachstanský čas (Kyzylorda)',
        'Asia/Rangoon' => 'mjanmarský čas (Rangún)',
        'Asia/Yangon' => 'mjanmarský čas (Rangún)',
        'Asia/Riyadh' => 'arabský čas (Rijád)',
        'Asia/Saigon' => 'indočínsky čas (Hočiminovo Mesto)',
        'Asia/Ho_Chi_Minh' => 'indočínsky čas (Hočiminovo Mesto)',
        'Asia/Sakhalin' => 'magadanský čas (Sachalin)',
        'Asia/Samarkand' => 'uzbecký čas (Samarkand)',
        'Asia/Seoul' => 'kórejský čas (Soul)',
        'Asia/Shanghai' => 'čínsky čas (Šanghaj)',
        'Asia/Singapore' => 'singapurský štandardný čas',
        'Asia/Srednekolymsk' => 'magadanský čas (Srednekolymsk)',
        'Asia/Taipei' => 'tchajpejský čas (Tchaj-pej)',
        'Asia/Tashkent' => 'uzbecký čas (Taškent)',
        'Asia/Tbilisi' => 'gruzínsky čas (Tbilisi)',
        'Asia/Tehran' => 'iránsky čas (Teherán)',
        'Asia/Thimphu' => 'bhutánsky čas (Thimphu)',
        'Asia/Tokyo' => 'japonský čas (Tokio)',
        'Asia/Tomsk' => 'krasnojarský čas (Tomsk)',
        'Asia/Ulaanbaatar' => 'ulanbátarský čas',
        'Asia/Urumqi' => 'časové pásmo Čína (Urumči)',
        'Asia/Ust-Nera' => 'vladivostocký čas (Usť-Nera)',
        'Asia/Vientiane' => 'indočínsky čas (Vientian)',
        'Asia/Vladivostok' => 'vladivostocký čas (Vladivostok)',
        'Asia/Yakutsk' => 'jakutský čas',
        'Asia/Yekaterinburg' => 'jekaterinburský čas (Jekaterinburg)',
        'Asia/Yerevan' => 'arménsky čas (Jerevan)',
        'Atlantic/Azores' => 'azorský čas (Azory)',
        'Atlantic/Bermuda' => 'atlantický čas (Bermudy)',
        'Atlantic/Canary' => 'západoeurópsky čas (Kanárske ostrovy)',
        'Atlantic/Cape_Verde' => 'kapverdský čas (Kapverdy)',
        'Atlantic/Faeroe' => 'západoeurópsky čas (Faerské ostrovy)',
        'Atlantic/Faroe' => 'západoeurópsky čas (Faerské ostrovy)',
        'Atlantic/Madeira' => 'západoeurópsky čas (Madeira)',
        'Atlantic/Reykjavik' => 'greenwichský čas (Reykjavík)',
        'Atlantic/South_Georgia' => 'čas Južnej Georgie (Južná Georgia)',
        'Atlantic/St_Helena' => 'greenwichský čas (Svätá Helena)',
        'Atlantic/Stanley' => 'falklandský čas (Stanley)',
        'Australia/Adelaide' => 'stredoaustrálsky čas (Adelaide)',
        'Australia/Brisbane' => 'východoaustrálsky čas (Brisbane)',
        'Australia/Broken_Hill' => 'stredoaustrálsky čas (Broken Hill)',
        'Australia/Darwin' => 'stredoaustrálsky čas (Darwin)',
        'Australia/Eucla' => 'stredozápadný austrálsky čas (Eucla)',
        'Australia/Hobart' => 'východoaustrálsky čas (Hobart)',
        'Australia/Lindeman' => 'východoaustrálsky čas (Lindeman)',
        'Australia/Lord_Howe' => 'čas ostrova lorda Howa (Lord Howe)',
        'Australia/Melbourne' => 'východoaustrálsky čas (Melbourne)',
        'Australia/Perth' => 'západoaustrálsky čas (Perth)',
        'Australia/Sydney' => 'východoaustrálsky čas (Sydney)',
        'Etc/GMT' => 'greenwichský čas',
        'Etc/UTC' => 'koordinovaný svetový čas',
        'Europe/Amsterdam' => 'stredoeurópsky čas (Amsterdam)',
        'Europe/Andorra' => 'stredoeurópsky čas (Andorra)',
        'Europe/Astrakhan' => 'Samarský čas (Astrachán)',
        'Europe/Athens' => 'východoeurópsky čas (Atény)',
        'Europe/Belgrade' => 'stredoeurópsky čas (Belehrad)',
        'Europe/Berlin' => 'stredoeurópsky čas (Berlín)',
        'Europe/Bratislava' => 'stredoeurópsky čas (Bratislava)',
        'Europe/Brussels' => 'stredoeurópsky čas (Brusel)',
        'Europe/Bucharest' => 'východoeurópsky čas (Bukurešť)',
        'Europe/Budapest' => 'stredoeurópsky čas (Budapešť)',
        'Europe/Busingen' => 'stredoeurópsky čas (Büsingen)',
        'Europe/Chisinau' => 'východoeurópsky čas (Kišiňov)',
        'Europe/Copenhagen' => 'stredoeurópsky čas (Kodaň)',
        'Europe/Dublin' => 'greenwichský čas (Dublin)',
        'Europe/Gibraltar' => 'stredoeurópsky čas (Gibraltár)',
        'Europe/Guernsey' => 'greenwichský čas (Guernsey)',
        'Europe/Helsinki' => 'východoeurópsky čas (Helsinki)',
        'Europe/Isle_of_Man' => 'greenwichský čas (Ostrov Man)',
        'Europe/Istanbul' => 'časové pásmo Turecko (Istanbul)',
        'Europe/Jersey' => 'greenwichský čas (Jersey)',
        'Europe/Kaliningrad' => 'východoeurópsky čas (Kaliningrad)',
        'Europe/Kiev' => 'východoeurópsky čas (Kyjev)',
        'Europe/Kyiv' => 'východoeurópsky čas (Kyjev)',
        'Europe/Kirov' => 'moskovský čas (Kirov)',
        'Europe/Lisbon' => 'západoeurópsky čas (Lisabon)',
        'Europe/Ljubljana' => 'stredoeurópsky čas (Ľubľana)',
        'Europe/London' => 'greenwichský čas (Londýn)',
        'Europe/Luxembourg' => 'stredoeurópsky čas (Luxembursko)',
        'Europe/Madrid' => 'stredoeurópsky čas (Madrid)',
        'Europe/Malta' => 'stredoeurópsky čas (Malta)',
        'Europe/Mariehamn' => 'východoeurópsky čas (Mariehamn)',
        'Europe/Minsk' => 'moskovský čas (Minsk)',
        'Europe/Monaco' => 'stredoeurópsky čas (Monako)',
        'Europe/Moscow' => 'moskovský čas (Moskva)',
        'Europe/Oslo' => 'stredoeurópsky čas (Oslo)',
        'Europe/Paris' => 'stredoeurópsky čas (Paríž)',
        'Europe/Podgorica' => 'stredoeurópsky čas (Podgorica)',
        'Europe/Prague' => 'stredoeurópsky čas (Praha)',
        'Europe/Riga' => 'východoeurópsky čas (Riga)',
        'Europe/Rome' => 'stredoeurópsky čas (Rím)',
        'Europe/Samara' => 'Samarský čas (Samara)',
        'Europe/San_Marino' => 'stredoeurópsky čas (San Maríno)',
        'Europe/Sarajevo' => 'stredoeurópsky čas (Sarajevo)',
        'Europe/Saratov' => 'Samarský čas (Saratov)',
        'Europe/Simferopol' => 'moskovský čas (Simferopol)',
        'Europe/Skopje' => 'stredoeurópsky čas (Skopje)',
        'Europe/Sofia' => 'východoeurópsky čas (Sofia)',
        'Europe/Stockholm' => 'stredoeurópsky čas (Štokholm)',
        'Europe/Tallinn' => 'východoeurópsky čas (Tallinn)',
        'Europe/Tirane' => 'stredoeurópsky čas (Tirana)',
        'Europe/Ulyanovsk' => 'Samarský čas (Uľjanovsk)',
        'Europe/Vaduz' => 'stredoeurópsky čas (Vaduz)',
        'Europe/Vatican' => 'stredoeurópsky čas (Vatikán)',
        'Europe/Vienna' => 'stredoeurópsky čas (Viedeň)',
        'Europe/Vilnius' => 'východoeurópsky čas (Vilnius)',
        'Europe/Volgograd' => 'moskovský čas (Volgograd)',
        'Europe/Warsaw' => 'stredoeurópsky čas (Varšava)',
        'Europe/Zagreb' => 'stredoeurópsky čas (Záhreb)',
        'Europe/Zurich' => 'stredoeurópsky čas (Zürich)',
        'Indian/Antananarivo' => 'východoafrický čas (Antananarivo)',
        'Indian/Chagos' => 'indickooceánsky čas (Chagos)',
        'Indian/Christmas' => 'čas Vianočného ostrova (Vianočný ostrov)',
        'Indian/Cocos' => 'čas Kokosových ostrovov (Kokosové ostrovy)',
        'Indian/Comoro' => 'východoafrický čas (Komory)',
        'Indian/Kerguelen' => 'čas Francúzskych južných a antarktických území (Kergueleny)',
        'Indian/Mahe' => 'seychelský čas (Mahé)',
        'Indian/Maldives' => 'maldivský čas (Maldivy)',
        'Indian/Mauritius' => 'maurícijský čas (Maurícius)',
        'Indian/Mayotte' => 'východoafrický čas (Mayotte)',
        'Indian/Reunion' => 'réunionský čas',
        'Pacific/Apia' => 'apijský čas (Apia)',
        'Pacific/Auckland' => 'novozélandský čas (Auckland)',
        'Pacific/Bougainville' => 'čas Papuy-Novej Guiney (Bougainville)',
        'Pacific/Chatham' => 'chathamský čas',
        'Pacific/Easter' => 'čas Veľkonočného ostrova (Veľkonočný ostrov)',
        'Pacific/Efate' => 'vanuatský čas (Efate)',
        'Pacific/Enderbury' => 'čas Fénixových ostrovov (Canton)',
        'Pacific/Kanton' => 'čas Fénixových ostrovov (Canton)',
        'Pacific/Fakaofo' => 'tokelauský čas (Fakaofo)',
        'Pacific/Fiji' => 'fidžijský čas',
        'Pacific/Funafuti' => 'tuvalský čas (Funafuti)',
        'Pacific/Galapagos' => 'galapágsky čas (Galapágy)',
        'Pacific/Gambier' => 'gambierský čas',
        'Pacific/Guadalcanal' => 'čas Šalamúnových ostrovov (Guadalcanal)',
        'Pacific/Guam' => 'chamorrský čas (Guam)',
        'Pacific/Honolulu' => 'havajsko-aleutský štandardný čas (Honolulu)',
        'Pacific/Kiritimati' => 'čas Rovníkových ostrovov (Kiritimati)',
        'Pacific/Kosrae' => 'kosrajský čas (Kosrae)',
        'Pacific/Kwajalein' => 'čas Marshallových ostrovov (Kwajalein)',
        'Pacific/Majuro' => 'čas Marshallových ostrovov (Majuro)',
        'Pacific/Marquesas' => 'markézsky čas (Markézy)',
        'Pacific/Midway' => 'samojský čas (Midway)',
        'Pacific/Nauru' => 'nauruský čas',
        'Pacific/Niue' => 'niuejský čas',
        'Pacific/Norfolk' => 'norfolský čas (Norfolk)',
        'Pacific/Noumea' => 'novokaledónsky čas (Nouméa)',
        'Pacific/Pago_Pago' => 'samojský čas (Pago Pago)',
        'Pacific/Palau' => 'palauský čas',
        'Pacific/Pitcairn' => 'čas Pitcairnových ostrovov',
        'Pacific/Ponape' => 'ponapský čas (Pohnpei)',
        'Pacific/Pohnpei' => 'ponapský čas (Pohnpei)',
        'Pacific/Port_Moresby' => 'čas Papuy-Novej Guiney (Port Moresby)',
        'Pacific/Rarotonga' => 'čas Cookových ostrovov (Rarotonga)',
        'Pacific/Saipan' => 'chamorrský čas (Saipan)',
        'Pacific/Tahiti' => 'tahitský čas (Tahiti)',
        'Pacific/Tarawa' => 'čas Gilbertových ostrovov (Tarawa)',
        'Pacific/Tongatapu' => 'tonžský čas (Tongatapu)',
        'Pacific/Truk' => 'chuukský čas',
        'Pacific/Chuuk' => 'chuukský čas',
        'Pacific/Wake' => 'čas ostrova Wake',
        'Pacific/Wallis' => 'čas ostrovov Wallis a Futuna (Wallis & Futuna)',
    ],
    'Meta' => [],
];
