<?php

return [
    'Names' => [
        'Arab' => 'अरबी',
        'Cyrl' => 'सिरिलिक',
        'Deva' => 'देवनागरी',
        'Hans' => 'आसान (तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।)',
        'Hant' => 'रिवायाती (तरजुम इशार: स्क्रिप्ट नवुक यि वर्ज़न छु चीनी बापथ ज़बान नाव किस मुरकब कि इस्तिमल करान।)',
        'Latn' => 'लातिनी',
        'Zxxx' => 'गेर तहरीर',
    ],
];
