<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'ანდორული პესეტა',
        ],
        'AED' => [
            'AED',
            'არაბთა გაერთიანებული საამიროების დირჰამი',
        ],
        'AFA' => [
            'AFA',
            'ავღანი (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'ავღანური ავღანი',
        ],
        'ALL' => [
            'ALL',
            'ალბანური ლეკი',
        ],
        'AMD' => [
            'AMD',
            'სომხური დრამი',
        ],
        'ANG' => [
            'ANG',
            'ნიდერლანდების ანტილების გულდენი',
        ],
        'AOA' => [
            'AOA',
            'ანგოლური კვანზა',
        ],
        'AOK' => [
            'AOK',
            'ანგოლური კვანზა (1977–1990)',
        ],
        'AON' => [
            'AON',
            'ანგოლური ახალი კვანზა (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'ანგოლური მიტოლებული კვანზა (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'არგენტინული აუსტრალი',
        ],
        'ARP' => [
            'ARP',
            'არგენტინული პესო (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'არგენტინული პესო',
        ],
        'ATS' => [
            'ATS',
            'ავსტრიული შილინგი',
        ],
        'AUD' => [
            'AUD',
            'ავსტრალიური დოლარი',
        ],
        'AWG' => [
            'AWG',
            'არუბანული გულდენი',
        ],
        'AZM' => [
            'AZM',
            'აზერბაიჯანული მანათი (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'აზერბაიჯანული მანათი',
        ],
        'BAD' => [
            'BAD',
            'ბოსნია-ჰერცოგოვინას დინარი',
        ],
        'BAM' => [
            'BAM',
            'ბოსნია და ჰერცოგოვინას კონვერტირებადი მარკა',
        ],
        'BBD' => [
            'BBD',
            'ბარბადოსული დოლარი',
        ],
        'BDT' => [
            'BDT',
            'ბანგლადეშური ტაკა',
        ],
        'BEC' => [
            'BEC',
            'ბელგიური ფრანკი (კოვერტირებადი)',
        ],
        'BEF' => [
            'BEF',
            'ბელგიური ფრანკი',
        ],
        'BEL' => [
            'BEL',
            'ბელგიური ფრანკი (ფინანსური)',
        ],
        'BGL' => [
            'BGL',
            'ბულგარული მყარი ლევი',
        ],
        'BGN' => [
            'BGN',
            'ბულგარული ლევი',
        ],
        'BHD' => [
            'BHD',
            'ბაჰრეინული დინარი',
        ],
        'BIF' => [
            'BIF',
            'ბურუნდიული ფრანკი',
        ],
        'BMD' => [
            'BMD',
            'ბერმუდული დოლარი',
        ],
        'BND' => [
            'BND',
            'ბრუნეული დოლარი',
        ],
        'BOB' => [
            'BOB',
            'ბოლივიური ბოლივიანო',
        ],
        'BOP' => [
            'BOP',
            'ბოლივიური პესო',
        ],
        'BRB' => [
            'BRB',
            'ბრაზილიური კრუზეირო ნოვო (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'ბრაზილიური კრუზადო',
        ],
        'BRE' => [
            'BRE',
            'ბრაზილიური კრუზეირო (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'ბრაზილიური რეალი',
        ],
        'BRN' => [
            'BRN',
            'ბრაზილიური კრუზადო ნოვო',
        ],
        'BRR' => [
            'BRR',
            'ბრაზილიური კრუზეირო',
        ],
        'BSD' => [
            'BSD',
            'ბაჰამური დოლარი',
        ],
        'BTN' => [
            'BTN',
            'ბუტანური ნგულტრუმი',
        ],
        'BWP' => [
            'BWP',
            'ბოცვანური პულა',
        ],
        'BYB' => [
            'BYB',
            'ახალი ბელარუსიული რუბლი (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'ბელორუსული რუბლი',
        ],
        'BYR' => [
            'BYR',
            'ბელორუსული რუბლი (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'ბელიზის დოლარი',
        ],
        'CAD' => [
            'CA$',
            'კანადური დოლარი',
        ],
        'CDF' => [
            'CDF',
            'კონგოს ფრანკი',
        ],
        'CHF' => [
            'CHF',
            'შვეიცარიული ფრანკი',
        ],
        'CLP' => [
            'CLP',
            'ჩილეს პესო',
        ],
        'CNH' => [
            'CNH',
            'ჩინური იუანი (ოფშორი)',
        ],
        'CNY' => [
            'CNY',
            'ჩინური იუანი',
        ],
        'COP' => [
            'COP',
            'კოლუმბიური პესო',
        ],
        'CRC' => [
            'CRC',
            'კოსტა-რიკული კოლონი',
        ],
        'CSD' => [
            'CSD',
            'ძველი სერბიული დინარი',
        ],
        'CSK' => [
            'CSK',
            'ჩეხოსლოვაკიის მყარი კრონა',
        ],
        'CUC' => [
            'CUC',
            'კუბური კონვერტირებადი პესო',
        ],
        'CUP' => [
            'CUP',
            'კუბური პესო',
        ],
        'CVE' => [
            'CVE',
            'კაბო-ვერდეს ესკუდო',
        ],
        'CYP' => [
            'CYP',
            'კვიპროსის გირვანქა',
        ],
        'CZK' => [
            'CZK',
            'ჩეხური კრონა',
        ],
        'DDM' => [
            'DDM',
            'აღმოსავლეთ გერმანული მარკა',
        ],
        'DEM' => [
            'DEM',
            'გერმანული მარკა',
        ],
        'DJF' => [
            'DJF',
            'ჯიბუტის ფრანკი',
        ],
        'DKK' => [
            'DKK',
            'დანიური კრონა',
        ],
        'DOP' => [
            'DOP',
            'დომინიკური პესო',
        ],
        'DZD' => [
            'DZD',
            'ალჟირული დინარი',
        ],
        'EEK' => [
            'EEK',
            'ესტონური კრუნა',
        ],
        'EGP' => [
            'EGP',
            'ეგვიპტური გირვანქა',
        ],
        'ERN' => [
            'ERN',
            'ერიტრეის ნაკფა',
        ],
        'ESP' => [
            'ESP',
            'ესპანური პესეტა',
        ],
        'ETB' => [
            'ETB',
            'ეთიოპიური ბირი',
        ],
        'EUR' => [
            '€',
            'ევრო',
        ],
        'FIM' => [
            'FIM',
            'ფინური მარკა',
        ],
        'FJD' => [
            'FJD',
            'ფიჯის დოლარი',
        ],
        'FKP' => [
            'FKP',
            'ფოლკლენდის კუნძულების ფუნტი',
        ],
        'FRF' => [
            'FRF',
            'ფრანგული ფრანკი',
        ],
        'GBP' => [
            '£',
            'ბრიტანული გირვანქა სტერლინგი',
        ],
        'GEK' => [
            'GEK',
            'ქართული კუპონი ლარით',
        ],
        'GEL' => [
            '₾',
            'ქართული ლარი',
        ],
        'GHS' => [
            'GHS',
            'განური სედი',
        ],
        'GIP' => [
            'GIP',
            'გიბრალტარული ფუნტი',
        ],
        'GMD' => [
            'GMD',
            'გამბიური დალასი',
        ],
        'GNF' => [
            'GNF',
            'გვინეური ფრანკი',
        ],
        'GRD' => [
            'GRD',
            'ბერძნული დრაჰმა',
        ],
        'GTQ' => [
            'GTQ',
            'გვატემალური კეტსალი',
        ],
        'GWE' => [
            'GWE',
            'პორტუგალიური გინეა ესკუდო',
        ],
        'GYD' => [
            'GYD',
            'გაიანური დოლარი',
        ],
        'HKD' => [
            'HKD',
            'ჰონკონგის დოლარი',
        ],
        'HNL' => [
            'HNL',
            'ჰონდურასული ლემპირა',
        ],
        'HRD' => [
            'HRD',
            'ხორვატიული დინარი',
        ],
        'HRK' => [
            'HRK',
            'ხორვატული კუნა',
        ],
        'HTG' => [
            'HTG',
            'ჰაიტური გურდი',
        ],
        'HUF' => [
            'HUF',
            'უნგრული ფორინტი',
        ],
        'IDR' => [
            'IDR',
            'ინდონეზიური რუპია',
        ],
        'IEP' => [
            'IEP',
            'ირლანდიური გირვანქა',
        ],
        'ILS' => [
            'ILS',
            'ისრაელის ახალი შეკელი',
        ],
        'INR' => [
            'INR',
            'ინდური რუპია',
        ],
        'IQD' => [
            'IQD',
            'ერაყული დინარი',
        ],
        'IRR' => [
            'IRR',
            'ირანული რიალი',
        ],
        'ISK' => [
            'ISK',
            'ისლანდიური კრონა',
        ],
        'ITL' => [
            'ITL',
            'იტალიური ლირა',
        ],
        'JMD' => [
            'JMD',
            'იამაიკური დოლარი',
        ],
        'JOD' => [
            'JOD',
            'იორდანიული დოლარი',
        ],
        'JPY' => [
            'JPY',
            'იაპონური იენი',
        ],
        'KES' => [
            'KES',
            'კენიური შილინგი',
        ],
        'KGS' => [
            'KGS',
            'ყირგიზული სომი',
        ],
        'KHR' => [
            'KHR',
            'კამბოჯური რიელი',
        ],
        'KMF' => [
            'KMF',
            'კომორული ფრანკი',
        ],
        'KPW' => [
            'KPW',
            'ჩრდილოეთ კორეული ვონი',
        ],
        'KRW' => [
            'KRW',
            'სამხრეთ კორეული ვონი',
        ],
        'KWD' => [
            'KWD',
            'ქუვეითური დინარი',
        ],
        'KYD' => [
            'KYD',
            'კაიმანის კუნძულების დოლარი',
        ],
        'KZT' => [
            'KZT',
            'ყაზახური ტენგე',
        ],
        'LAK' => [
            'LAK',
            'ლაოსური კიპი',
        ],
        'LBP' => [
            'LBP',
            'ლიბანური ფუნტი',
        ],
        'LKR' => [
            'LKR',
            'შრი-ლანკური რუპია',
        ],
        'LRD' => [
            'LRD',
            'ლიბერიული დოლარი',
        ],
        'LSL' => [
            'LSL',
            'ლესოთოს ლოტი',
        ],
        'LTL' => [
            'LTL',
            'ლიტვური ლიტა',
        ],
        'LTT' => [
            'LTT',
            'ლიტვური ტალონი',
        ],
        'LUC' => [
            'LUC',
            'ლუქსემბურგის კონვერტირებადი ფრანკი',
        ],
        'LUF' => [
            'LUF',
            'ლუქსემბურგის ფრანკი',
        ],
        'LUL' => [
            'LUL',
            'ლუქსემბურგის ფინანსური ფრანკი',
        ],
        'LVL' => [
            'LVL',
            'ლატვიური ლატი',
        ],
        'LVR' => [
            'LVR',
            'ლატვიური რუბლი',
        ],
        'LYD' => [
            'LYD',
            'ლიბიური დინარი',
        ],
        'MAD' => [
            'MAD',
            'მაროკოს დირჰამი',
        ],
        'MAF' => [
            'MAF',
            'მაროკოს ფრანკი',
        ],
        'MDL' => [
            'MDL',
            'მოლდოვური ლეუ',
        ],
        'MGA' => [
            'MGA',
            'მადაგასკარის არიარი',
        ],
        'MGF' => [
            'MGF',
            'მადაგასკარის ფრანკი',
        ],
        'MKD' => [
            'MKD',
            'მაკედონიური დინარი',
        ],
        'MLF' => [
            'MLF',
            'მალის ფრანკი',
        ],
        'MMK' => [
            'MMK',
            'მიანმარის კიატი',
        ],
        'MNT' => [
            'MNT',
            'მონღოლური ტუგრიკი',
        ],
        'MOP' => [
            'MOP',
            'მაკაუს პატაკა',
        ],
        'MRO' => [
            'MRO',
            'მავრიტანული უგია (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'მავრიტანული უგია',
        ],
        'MTL' => [
            'MTL',
            'მალტის ლირა',
        ],
        'MTP' => [
            'MTP',
            'მალტის გირვანქა',
        ],
        'MUR' => [
            'MUR',
            'მავრიტანული რუპია',
        ],
        'MVR' => [
            'MVR',
            'მალდივური რუფია',
        ],
        'MWK' => [
            'MWK',
            'მალავიური კვაჩა',
        ],
        'MXN' => [
            'MX$',
            'მექსიკური პესო',
        ],
        'MXP' => [
            'MXP',
            'მექსიკური ვერცხლის პესო (1861–1992)',
        ],
        'MYR' => [
            'MYR',
            'მალაიზიური რინგიტი',
        ],
        'MZE' => [
            'MZE',
            'მოზამბიკური ესკუდო',
        ],
        'MZM' => [
            'MZM',
            'ძველი მოზამბიკური მეტიკალი',
        ],
        'MZN' => [
            'MZN',
            'მოზამბიკური მეტიკალი',
        ],
        'NAD' => [
            'NAD',
            'ნამიბიური დოლარი',
        ],
        'NGN' => [
            'NGN',
            'ნიგერიული ნაირა',
        ],
        'NIC' => [
            'NIC',
            'ნიკარაგუას კორდობა',
        ],
        'NIO' => [
            'NIO',
            'ნიკარაგუას ოქროს კორდობა',
        ],
        'NLG' => [
            'NLG',
            'ჰოლანდიური გულდენი',
        ],
        'NOK' => [
            'NOK',
            'ნორვეგიული კრონა',
        ],
        'NPR' => [
            'NPR',
            'ნეპალური რუპია',
        ],
        'NZD' => [
            'NZD',
            'ახალი ზელანდიის დოლარი',
        ],
        'OMR' => [
            'OMR',
            'ომანის რიალი',
        ],
        'PAB' => [
            'PAB',
            'პანამური ბალბოა',
        ],
        'PEI' => [
            'PEI',
            'პერუს ინტი',
        ],
        'PEN' => [
            'PEN',
            'პერუს სოლი',
        ],
        'PES' => [
            'PES',
            'პერუს სოლი (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'პაპუა-ახალი გვინეის კინა',
        ],
        'PHP' => [
            'PHP',
            'ფილიპინური პესო',
        ],
        'PKR' => [
            'PKR',
            'პაკისტანური რუპია',
        ],
        'PLN' => [
            'PLN',
            'პოლონური ზლოტი',
        ],
        'PLZ' => [
            'PLZ',
            'პოლონური ზლოტი (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'პორტუგალიური ესკუდო',
        ],
        'PYG' => [
            'PYG',
            'პარაგვაული გუარანი',
        ],
        'QAR' => [
            'QAR',
            'კატარის რიალი',
        ],
        'RHD' => [
            'RHD',
            'როდეზიული დოლარი',
        ],
        'ROL' => [
            'ROL',
            'ძველი რუმინული ლეუ',
        ],
        'RON' => [
            'RON',
            'რუმინული ლეუ',
        ],
        'RSD' => [
            'RSD',
            'სერბული დინარი',
        ],
        'RUB' => [
            'RUB',
            'რუსული რუბლი',
        ],
        'RUR' => [
            'RUR',
            'რუსული რუბლი (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'რუანდული ფრანკი',
        ],
        'SAR' => [
            'SAR',
            'საუდის არაბეთის რიალი',
        ],
        'SBD' => [
            'SBD',
            'სოლომონის კუნძულების დოლარი',
        ],
        'SCR' => [
            'SCR',
            'სეიშელური რუპია',
        ],
        'SDD' => [
            'SDD',
            'სუდანის დინარი',
        ],
        'SDG' => [
            'SDG',
            'სუდანური ფუნტი',
        ],
        'SDP' => [
            'SDP',
            'სუდანის გირვანქა',
        ],
        'SEK' => [
            'SEK',
            'შვედური კრონა',
        ],
        'SGD' => [
            'SGD',
            'სინგაპურის დოლარი',
        ],
        'SHP' => [
            'SHP',
            'წმ. ელენეს კუნძულის ფუნტი',
        ],
        'SLE' => [
            'SLE',
            'სიერა-ლეონეს ლეონე',
        ],
        'SLL' => [
            'SLL',
            'სიერა-ლეონეს ლეონე (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'სომალური შილინგი',
        ],
        'SRD' => [
            'SRD',
            'სურინამული დოლარი',
        ],
        'SRG' => [
            'SRG',
            'სურინამის გულდენი',
        ],
        'SSP' => [
            'SSP',
            'სამხრეთ სუდანური ფუნტი',
        ],
        'STD' => [
            'STD',
            'სან-ტომე და პრინსიპის დობრა (1977–2017)',
        ],
        'STN' => [
            'STN',
            'სან-ტომე და პრინსიპის დობრა',
        ],
        'SUR' => [
            'SUR',
            'საბჭოთა რუბლი',
        ],
        'SYP' => [
            'SYP',
            'სირიული ფუნტი',
        ],
        'SZL' => [
            'SZL',
            'სვაზილენდის ლილანგენი',
        ],
        'THB' => [
            'THB',
            'ტაილანდური ბატი',
        ],
        'TJR' => [
            'TJR',
            'ტაჯიკური რუბლი',
        ],
        'TJS' => [
            'TJS',
            'ტაჯიკური სომონი',
        ],
        'TMM' => [
            'TMM',
            'თურქმენული მანათი',
        ],
        'TMT' => [
            'TMT',
            'თურქმენეთის მანათი',
        ],
        'TND' => [
            'TND',
            'ტუნისური დინარი',
        ],
        'TOP' => [
            'TOP',
            'ტონგანური პაანგა',
        ],
        'TRL' => [
            'TRL',
            'თურქული ლირა',
        ],
        'TRY' => [
            'TRY',
            'ახალი თურქული ლირა',
        ],
        'TTD' => [
            'TTD',
            'ტრინიდად და ტობაგოს დოლარი',
        ],
        'TWD' => [
            'NT$',
            'ტაივანური ახალი დოლარი',
        ],
        'TZS' => [
            'TZS',
            'ტანზანიური შილინგი',
        ],
        'UAH' => [
            'UAH',
            'უკრაინული გრივნა',
        ],
        'UAK' => [
            'UAK',
            'უკრაინული კარბოვანეცი',
        ],
        'UGS' => [
            'UGS',
            'უგანდური შილინგი (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'უგანდური შილინგი',
        ],
        'USD' => [
            'US$',
            'აშშ დოლარი',
        ],
        'USN' => [
            'USN',
            'აშშ დოლარი (შემდეგი დღე)',
        ],
        'USS' => [
            'USS',
            'აშშ დოლარი (იგივე დღე)',
        ],
        'UYP' => [
            'UYP',
            'ურუგვაის პესო (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'ურუგვაის პესო',
        ],
        'UZS' => [
            'UZS',
            'უზბეკური სუმი',
        ],
        'VEB' => [
            'VEB',
            'ვენესუელის ბოლივარი (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'ვენესუელის ბოლივარი (2008–2018)',
        ],
        'VES' => [
            'VES',
            'ვენესუელის ბოლივარი',
        ],
        'VND' => [
            'VND',
            'ვიეტნამური დონგი',
        ],
        'VUV' => [
            'VUV',
            'ვანუატუს ვატუ',
        ],
        'WST' => [
            'WST',
            'სამოური ტალა',
        ],
        'XAF' => [
            'FCFA',
            'ცენტრალურ აფრიკული CFA ფრანკი',
        ],
        'XCD' => [
            'EC$',
            'აღმოსავლეთ კარიბიული დოლარი',
        ],
        'XCG' => [
            'Cg.',
            'კარიბის გულდენი',
        ],
        'XEU' => [
            'XEU',
            'ევროპული სავალუტო ერთეული',
        ],
        'XFO' => [
            'XFO',
            'ფრანგული ოქროს ფრანკი',
        ],
        'XOF' => [
            'F CFA',
            'დასავლეთ აფრიკული CFA ფრანკი',
        ],
        'XPF' => [
            'CFPF',
            'CFP ფრანკი',
        ],
        'YDD' => [
            'YDD',
            'იემენის დინარი',
        ],
        'YER' => [
            'YER',
            'იემენის რეალი',
        ],
        'YUD' => [
            'YUD',
            'იუგოსლავიური მყარი დინარი',
        ],
        'YUM' => [
            'YUM',
            'იუგოსლავიური ახალი დინარი',
        ],
        'YUN' => [
            'YUN',
            'იუგოსლავიური კონვერტირებადი დინარი',
        ],
        'ZAR' => [
            'ZAR',
            'სამხრეთ აფრიკული რანდი',
        ],
        'ZMK' => [
            'ZMK',
            'ზამბიური კვაჭა (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'ზამბიური კვაჭა',
        ],
        'ZRN' => [
            'ZRN',
            'ზაირის ახალი ზაირი',
        ],
        'ZRZ' => [
            'ZRZ',
            'ზაირის ზაირი',
        ],
        'ZWD' => [
            'ZWD',
            'ზიმბაბვეს დოლარი',
        ],
        'ZWG' => [
            'ZWG',
            'ზიმბაბვეს გოლდი',
        ],
    ],
];
