<?php

return [
    'Names' => [
        'aa' => 'աֆարերեն',
        'ab' => 'աբխազերեն',
        'ace' => 'աչեհերեն',
        'ach' => 'աչոլի',
        'ada' => 'ադանգմերեն',
        'ady' => 'ադիղերեն',
        'aeb' => 'թունիսական արաբերեն',
        'af' => 'աֆրիկաանս',
        'agq' => 'աղեմ',
        'ain' => 'այներեն',
        'ak' => 'աքան',
        'akk' => 'աքքադերեն',
        'ale' => 'ալեութերեն',
        'alt' => 'հարավային ալթայերեն',
        'am' => 'ամհարերեն',
        'an' => 'արագոներեն',
        'ang' => 'հին անգլերեն',
        'ann' => 'օբոլո',
        'anp' => 'անգիկա',
        'ar' => 'արաբերեն',
        'arc' => 'արամեերեն',
        'arn' => 'մապուչի',
        'arp' => 'արապահո',
        'arq' => 'ալժիրական արաբերեն',
        'ars' => 'նեջդի արաբերեն',
        'arz' => 'եգիպտական արաբերեն',
        'as' => 'ասամերեն',
        'asa' => 'ասու',
        'ase' => 'ամերիկյան ժեստերի լեզու',
        'ast' => 'աստուրերեն',
        'atj' => 'աթիկամեկ',
        'av' => 'ավարերեն',
        'awa' => 'ավադհի',
        'ay' => 'այմարա',
        'az' => 'ադրբեջաներեն',
        'ba' => 'բաշկիրերեն',
        'bal' => 'բելուջերեն',
        'ban' => 'բալիերեն',
        'bas' => 'բասաա',
        'be' => 'բելառուսերեն',
        'bem' => 'բեմբա',
        'bez' => 'բենա',
        'bg' => 'բուլղարերեն',
        'bgc' => 'հարյանվի',
        'bgn' => 'արևմտաբելուջիերեն',
        'bho' => 'բհոպուրի',
        'bi' => 'բիսլամա',
        'bin' => 'բինի',
        'bla' => 'սիկսիկա',
        'blo' => 'անիի',
        'bm' => 'բամբարա',
        'bn' => 'բենգալերեն',
        'bo' => 'տիբեթերեն',
        'br' => 'բրետոներեն',
        'brx' => 'բոդո',
        'bs' => 'բոսնիերեն',
        'bss' => 'աքուզ',
        'bug' => 'բուգիերեն',
        'byn' => 'բիլին',
        'ca' => 'կատալաներեն',
        'cay' => 'կայուգա',
        'ccp' => 'չակմա',
        'ce' => 'չեչեներեն',
        'ceb' => 'սեբուերեն',
        'cgg' => 'չիգա',
        'ch' => 'չամոռո',
        'chk' => 'տրուկերեն',
        'chm' => 'մարի',
        'cho' => 'չոկտո',
        'chp' => 'չիպևայան',
        'chr' => 'չերոկի',
        'chy' => 'շայեն',
        'ckb' => 'սորանի քրդերեն',
        'clc' => 'չիլկոտիներեն',
        'co' => 'կորսիկերեն',
        'cop' => 'ղպտերեն',
        'crg' => 'միչիֆ',
        'crh' => 'ղրիմյան թուրքերեն',
        'crj' => 'հարավ-արևելյան քրի',
        'crk' => 'հարթավայրերի քրի',
        'crl' => 'հյուսիս-արևելյան քրի',
        'crm' => 'մուզ քրի',
        'crr' => 'կարոլինական ալգոնկիներեն',
        'crs' => 'սեյշելյան խառնակերտ ֆրանսերեն',
        'cs' => 'չեխերեն',
        'csw' => 'ճահճի քրի',
        'cu' => 'սլավոներեն, եկեղեցական',
        'cv' => 'չուվաշերեն',
        'cy' => 'ուելսերեն',
        'da' => 'դանիերեն',
        'dak' => 'դակոտա',
        'dar' => 'դարգիներեն',
        'dav' => 'թաիթա',
        'de' => 'գերմաներեն',
        'dgr' => 'դոգրիբ',
        'dje' => 'զարմա',
        'doi' => 'դոգրի',
        'dsb' => 'ստորին սորբերեն',
        'dua' => 'դուալա',
        'dv' => 'դիվեհի',
        'dyo' => 'ջոլա-ֆոնյի',
        'dz' => 'ջոնգքհա',
        'dzg' => 'դազագա',
        'ebu' => 'էմբու',
        'ee' => 'էվե',
        'efi' => 'էֆիկ',
        'egy' => 'հին եգիպտերեն',
        'eka' => 'էկաջուկ',
        'el' => 'հունարեն',
        'en' => 'անգլերեն',
        'eo' => 'էսպերանտո',
        'es' => 'իսպաներեն',
        'et' => 'էստոներեն',
        'eu' => 'բասկերեն',
        'ewo' => 'էվոնդո',
        'fa' => 'պարսկերեն',
        'ff' => 'ֆուլահ',
        'fi' => 'ֆիններեն',
        'fil' => 'ֆիլիպիներեն',
        'fit' => 'տորնադելեն ֆիններեն',
        'fj' => 'ֆիջիերեն',
        'fo' => 'ֆարյորերեն',
        'fon' => 'ֆոն',
        'fr' => 'ֆրանսերեն',
        'frc' => 'քաջունական ֆրանսերեն',
        'fro' => 'հին ֆրանսերեն',
        'frr' => 'հյուսիսային ֆրիզերեն',
        'frs' => 'արևելաֆրիզերեն',
        'fur' => 'ֆրիուլիերեն',
        'fy' => 'արևմտաֆրիզերեն',
        'ga' => 'իռլանդերեն',
        'gaa' => 'գայերեն',
        'gag' => 'գագաուզերեն',
        'gbz' => 'զրադաշտական դարի',
        'gd' => 'շոտլանդական գաելերեն',
        'gez' => 'գեեզ',
        'gil' => 'կիրիբատի',
        'gl' => 'գալիսերեն',
        'gn' => 'գուարանի',
        'goh' => 'հին վերին գերմաներեն',
        'gor' => 'գորոնտալո',
        'got' => 'գոթերեն',
        'grc' => 'հին հունարեն',
        'gsw' => 'շվեյցարական գերմաներեն',
        'gu' => 'գուջարաթի',
        'guc' => 'վայուու',
        'guz' => 'գուսի',
        'gv' => 'մեներեն',
        'gwi' => 'գվիչին',
        'ha' => 'հաուսա',
        'hai' => 'հայդա',
        'haw' => 'հավայիերեն',
        'hax' => 'հարավային հայդա',
        'he' => 'եբրայերեն',
        'hi' => 'հինդի',
        'hil' => 'հիլիգայնոն',
        'hmn' => 'հմոնգ',
        'hr' => 'խորվաթերեն',
        'hsb' => 'վերին սորբերեն',
        'hsn' => 'սյան չինարեն',
        'ht' => 'խառնակերտ հայիթերեն',
        'hu' => 'հունգարերեն',
        'hup' => 'հուպա',
        'hur' => 'հալքոմելեմ',
        'hy' => 'հայերեն',
        'hz' => 'հերերո',
        'ia' => 'ինտերլինգուա',
        'iba' => 'իբաներեն',
        'ibb' => 'իբիբիո',
        'id' => 'ինդոնեզերեն',
        'ie' => 'ինտերլինգուե',
        'ig' => 'իգբո',
        'ii' => 'սիչուան',
        'ikt' => 'արևմտականադական ինուկտիտուտ',
        'ilo' => 'իլոկերեն',
        'inh' => 'ինգուշերեն',
        'io' => 'իդո',
        'is' => 'իսլանդերեն',
        'it' => 'իտալերեն',
        'iu' => 'ինուկտիտուտ',
        'ja' => 'ճապոներեն',
        'jbo' => 'լոժբան',
        'jgo' => 'նգոմբա',
        'jmc' => 'մաշամե',
        'jv' => 'ճավայերեն',
        'ka' => 'վրացերեն',
        'kab' => 'կաբիլերեն',
        'kac' => 'կաչիներեն',
        'kaj' => 'ջյու',
        'kam' => 'կամբա',
        'kbd' => 'կաբարդերեն',
        'kcg' => 'տիապ',
        'kde' => 'մակոնդե',
        'kea' => 'կաբուվերդերեն',
        'kfo' => 'կորո',
        'kgp' => 'կաինգան',
        'kha' => 'քասիերեն',
        'khq' => 'կոյրա չինի',
        'ki' => 'կիկույու',
        'kj' => 'կուանյամա',
        'kk' => 'ղազախերեն',
        'kkj' => 'կակո',
        'kl' => 'կալաալիսուտ',
        'kln' => 'կալենջին',
        'km' => 'քմերերեն',
        'kmb' => 'կիմբունդու',
        'kn' => 'կաննադա',
        'ko' => 'կորեերեն',
        'koi' => 'պերմյակ կոմիերեն',
        'kok' => 'կոնկանի',
        'kpe' => 'կպելլեերեն',
        'kr' => 'կանուրի',
        'krc' => 'կարաչայ-բալկարերեն',
        'krl' => 'կարելերեն',
        'kru' => 'կուրուխ',
        'ks' => 'քաշմիրերեն',
        'ksb' => 'շամբալա',
        'ksf' => 'բաֆիա',
        'ksh' => 'քյոլներեն',
        'ku' => 'քրդերեն',
        'kum' => 'կումիկերեն',
        'kv' => 'կոմիերեն',
        'kw' => 'կոռներեն',
        'kwk' => 'կվակվալա',
        'kxv' => 'կուվի',
        'ky' => 'ղրղզերեն',
        'la' => 'լատիներեն',
        'lad' => 'լադինո',
        'lag' => 'լանգի',
        'lb' => 'լյուքսեմբուրգերեն',
        'lez' => 'լեզգիերեն',
        'lg' => 'գանդա',
        'li' => 'լիմբուրգերեն',
        'lij' => 'լիգուրերեն',
        'lil' => 'լիլուետ',
        'lkt' => 'լակոտա',
        'lmo' => 'լոմբարդերեն',
        'ln' => 'լինգալա',
        'lo' => 'լաոսերեն',
        'lou' => 'լուիզիանական կրեոլերեն',
        'loz' => 'լոզի',
        'lrc' => 'հյուսիսային լուրիերեն',
        'lsm' => 'սաամերեն',
        'lt' => 'լիտվերեն',
        'lu' => 'լուբա-կատանգա',
        'lua' => 'լուբա-լուլուա',
        'lun' => 'լունդա',
        'luo' => 'լուո',
        'lus' => 'միզո',
        'luy' => 'լույա',
        'lv' => 'լատվիերեն',
        'mad' => 'մադուրերեն',
        'mag' => 'մագահի',
        'mai' => 'մայթիլի',
        'mak' => 'մակասարերեն',
        'mas' => 'մասաի',
        'mdf' => 'մոկշայերեն',
        'men' => 'մենդե',
        'mer' => 'մերու',
        'mfe' => 'մորիսյեն',
        'mg' => 'մալգաշերեն',
        'mgh' => 'մաքուա-մետտո',
        'mgo' => 'մետա',
        'mh' => 'մարշալերեն',
        'mi' => 'մաորի',
        'mic' => 'միկմակ',
        'min' => 'մինանգկաբաու',
        'mk' => 'մակեդոներեն',
        'ml' => 'մալայալամ',
        'mn' => 'մոնղոլերեն',
        'mni' => 'մանիպուրի',
        'moe' => 'իննու-այմուն',
        'moh' => 'մոհավք',
        'mos' => 'մոսսի',
        'mr' => 'մարաթի',
        'mrj' => 'արևմտամարիերեն',
        'ms' => 'մալայերեն',
        'mt' => 'մալթայերեն',
        'mua' => 'մունդանգ',
        'mus' => 'մասքոջի',
        'mwl' => 'միրանդերեն',
        'my' => 'բիրմայերեն',
        'myv' => 'էրզյա',
        'mzn' => 'մազանդարաներեն',
        'na' => 'նաուրու',
        'nap' => 'նեապոլերեն',
        'naq' => 'նամա',
        'nb' => 'գրքային նորվեգերեն',
        'nd' => 'հյուսիսային նդեբելե',
        'nds' => 'ստորին գերմաներեն',
        'ne' => 'նեպալերեն',
        'new' => 'նեվարերեն',
        'ng' => 'նդոնգա',
        'nia' => 'նիասերեն',
        'niu' => 'նիուերեն',
        'nl' => 'հոլանդերեն',
        'nmg' => 'կվասիո',
        'nn' => 'նոր նորվեգերեն',
        'nnh' => 'նգիեմբուն',
        'no' => 'նորվեգերեն',
        'nog' => 'նոգայերեն',
        'non' => 'հին նորվեգերեն',
        'nqo' => 'նկո',
        'nr' => 'հարավային նդեբելե',
        'nso' => 'հյուսիսային սոթո',
        'nus' => 'նուեր',
        'nv' => 'նավախո',
        'ny' => 'նյանջա',
        'nyn' => 'նյանկոլե',
        'oc' => 'օքսիտաներեն',
        'oj' => 'օջիբվա',
        'ojb' => 'հյուսիս-արևմտյան օջիբվե',
        'ojc' => 'կենտրոնական օջիբվե',
        'ojs' => 'օջի քրի',
        'ojw' => 'արևմտյան օջիբվե',
        'oka' => 'օկանագան',
        'om' => 'օրոմո',
        'or' => 'օրիյա',
        'os' => 'օսերեն',
        'osa' => 'օսեյջ',
        'ota' => 'օսմաներեն',
        'pa' => 'փենջաբերեն',
        'pag' => 'պանգասինաներեն',
        'pal' => 'պահլավերեն',
        'pam' => 'պամպանգաերեն',
        'pap' => 'պապյամենտո',
        'pau' => 'պալաուերեն',
        'pcd' => 'պիկարդերեն',
        'pcm' => 'նիգերիական փիջին',
        'pdc' => 'փենսիլվանական գերմաներեն',
        'pdt' => 'պլատագերմաներեն',
        'peo' => 'հին պարսկերեն',
        'pfl' => 'պալատինյան գերմաներեն',
        'phn' => 'փյունիկերեն',
        'pi' => 'պալի',
        'pis' => 'փիջին',
        'pl' => 'լեհերեն',
        'pms' => 'պիեմոնտերեն',
        'pnt' => 'պոնտերեն',
        'pon' => 'պոնպեերեն',
        'pqm' => 'մալեսիտ-պասամակվոդի',
        'prg' => 'պրուսերեն',
        'pro' => 'հին պրովանսերեն',
        'ps' => 'փուշթու',
        'pt' => 'պորտուգալերեն',
        'qu' => 'կեչուա',
        'quc' => 'քիչե',
        'raj' => 'ռաջաստաներեն',
        'rap' => 'ռապանուի',
        'rar' => 'ռարոտոնգաներեն',
        'rgn' => 'ռոմանիոլերեն',
        'rhg' => 'ռոհինջա',
        'rif' => 'ռիֆերեն',
        'rm' => 'ռոմանշերեն',
        'rn' => 'ռունդի',
        'ro' => 'ռումիներեն',
        'rof' => 'ռոմբո',
        'rom' => 'ռոմաներեն',
        'rtm' => 'ռոտուման',
        'ru' => 'ռուսերեն',
        'rue' => 'ռուսիներեն',
        'rug' => 'ռովիանա',
        'rup' => 'արոմաներեն',
        'rw' => 'կինյառուանդա',
        'rwk' => 'ռվա',
        'sa' => 'սանսկրիտ',
        'sad' => 'սանդավե',
        'sah' => 'յակուտերեն',
        'saq' => 'սամբուրու',
        'sat' => 'սանտալի',
        'sba' => 'նգամբայ',
        'sbp' => 'սանգու',
        'sc' => 'սարդիներեն',
        'scn' => 'սիցիլիերեն',
        'sco' => 'շոտլանդերեն',
        'sd' => 'սինդհի',
        'sdh' => 'հարավային քրդերեն',
        'se' => 'հյուսիսային սաամի',
        'seh' => 'սենա',
        'ses' => 'կոյրաբորո սեննի',
        'sg' => 'սանգո',
        'sga' => 'հին իռլանդերեն',
        'sh' => 'սերբա-խորվաթերեն',
        'shi' => 'տաշելհիթ',
        'shn' => 'շաներեն',
        'si' => 'սինհալերեն',
        'sk' => 'սլովակերեն',
        'sl' => 'սլովեներեն',
        'slh' => 'հարավային լուշուցիդ',
        'sm' => 'սամոաերեն',
        'sma' => 'հարավային սաամի',
        'smj' => 'լուլե սաամի',
        'smn' => 'ինարի սաամի',
        'sms' => 'սկոլտ սաամի',
        'sn' => 'շոնա',
        'snk' => 'սոնինկե',
        'so' => 'սոմալիերեն',
        'sq' => 'ալբաներեն',
        'sr' => 'սերբերեն',
        'srn' => 'սրանան տոնգո',
        'ss' => 'սվազերեն',
        'ssy' => 'սահոերեն',
        'st' => 'հարավային սոթո',
        'str' => 'սթրեյթս սալիշերեն',
        'su' => 'սունդաներեն',
        'suk' => 'սուկումա',
        'sv' => 'շվեդերեն',
        'sw' => 'սուահիլի',
        'swb' => 'կոմորերեն',
        'syr' => 'ասորերեն',
        'szl' => 'սիլեզերեն',
        'ta' => 'թամիլերեն',
        'tce' => 'հարավային թուտչոնե',
        'tcy' => 'տուլու',
        'te' => 'թելուգու',
        'tem' => 'տեմնե',
        'teo' => 'տեսո',
        'ter' => 'տերենո',
        'tet' => 'տետում',
        'tg' => 'տաջիկերեն',
        'tgx' => 'թագիշ',
        'th' => 'թայերեն',
        'tht' => 'թալթան',
        'ti' => 'տիգրինյա',
        'tig' => 'տիգրե',
        'tiv' => 'տիվերեն',
        'tk' => 'թուրքմեներեն',
        'tkl' => 'տոկելաու',
        'tkr' => 'ցախուր',
        'tl' => 'տագալերեն',
        'tlh' => 'կլինգոն',
        'tli' => 'տլինգիտ',
        'tly' => 'թալիշերեն',
        'tmh' => 'տամաշեկ',
        'tn' => 'ցվանա',
        'to' => 'տոնգերեն',
        'tok' => 'տոկիպոնա',
        'tpi' => 'տոկ փիսին',
        'tr' => 'թուրքերեն',
        'tru' => 'տուրոյո',
        'trv' => 'տարոկո',
        'ts' => 'ցոնգա',
        'tsd' => 'ցակոներեն',
        'tsi' => 'ցիմշյան',
        'tt' => 'թաթարերեն',
        'ttm' => 'հյուսիսային թուտչոնե',
        'tum' => 'տումբուկա',
        'tvl' => 'թուվալուերեն',
        'tw' => 'տուի',
        'twq' => 'տասավաք',
        'ty' => 'թաիտերեն',
        'tyv' => 'տուվերեն',
        'tzm' => 'կենտրոնատլասյան թամազիղտ',
        'udm' => 'ուդմուրտերեն',
        'ug' => 'ույղուրերեն',
        'uga' => 'ուգարիտերեն',
        'uk' => 'ուկրաիներեն',
        'umb' => 'ումբունդու',
        'ur' => 'ուրդու',
        'uz' => 'ուզբեկերեն',
        'vai' => 'վաի',
        've' => 'վենդա',
        'vec' => 'վենետերեն',
        'vep' => 'վեպսերեն',
        'vi' => 'վիետնամերեն',
        'vls' => 'արևմտաֆլամանդերեն',
        'vmw' => 'մաքուա',
        'vo' => 'վոլապյուկ',
        'vot' => 'վոդերեն',
        'vro' => 'վորո',
        'vun' => 'վունջո',
        'wa' => 'վալոներեն',
        'wae' => 'վալսերեն',
        'wal' => 'վոլայտա',
        'war' => 'վարայերեն',
        'was' => 'վաշո',
        'wbp' => 'վարլպիրի',
        'wo' => 'վոլոֆ',
        'wuu' => 'վու չինարեն',
        'xal' => 'կալմիկերեն',
        'xh' => 'քոսա',
        'xnr' => 'կանգրի',
        'xog' => 'սոգա',
        'yao' => 'յաո',
        'yap' => 'յափերեն',
        'yav' => 'յանգբեն',
        'ybb' => 'եմբա',
        'yi' => 'իդիշ',
        'yo' => 'յորուբա',
        'yrl' => 'նինգաթու',
        'yue' => 'կանտոներեն',
        'za' => 'ժուանգ',
        'zap' => 'սապոտեկերեն',
        'zea' => 'զեյլանդերեն',
        'zen' => 'զենագա',
        'zgh' => 'ընդհանուր մարոկյան թամազիղտ',
        'zh' => 'չինարեն',
        'zu' => 'զուլուերեն',
        'zun' => 'զունիերեն',
        'zza' => 'զազաերեն',
    ],
    'LocalizedNames' => [
        'ar_001' => 'արդի ընդհանուր արաբերեն',
        'de_AT' => 'ավստրիական գերմաներեն',
        'de_CH' => 'շվեյցարական վերին գերմաներեն',
        'en_AU' => 'ավստրալիական անգլերեն',
        'en_CA' => 'կանադական անգլերեն',
        'en_GB' => 'բրիտանական անգլերեն',
        'en_US' => 'ամերիկյան անգլերեն',
        'es_419' => 'լատինամերիկյան իսպաներեն',
        'es_ES' => 'եվրոպական իսպաներեն',
        'es_MX' => 'մեքսիկական իսպաներեն',
        'fa_AF' => 'դարի',
        'fr_CA' => 'կանադական ֆրանսերեն',
        'fr_CH' => 'շվեյցարական ֆրանսերեն',
        'hi_Latn' => 'հինդի (լատինատառ)',
        'nds_NL' => 'ստորին սաքսոներեն',
        'nl_BE' => 'ֆլամանդերեն',
        'pt_BR' => 'բրազիլական պորտուգալերեն',
        'pt_PT' => 'եվրոպական պորտուգալերեն',
        'ro_MD' => 'մոլդովերեն',
        'sw_CD' => 'կոնգոյի սուահիլի',
        'zh_Hans' => 'պարզեցված չինարեն',
        'zh_Hant' => 'ավանդական չինարեն',
    ],
];
