<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'بيستا أندوري',
        ],
        'AED' => [
            'د.إ.‏',
            'درهم إماراتي',
        ],
        'AFA' => [
            'AFA',
            'أفغاني - 1927-2002',
        ],
        'AFN' => [
            'AFN',
            'أفغاني',
        ],
        'ALL' => [
            'ALL',
            'ليك ألباني',
        ],
        'AMD' => [
            'AMD',
            'درام أرميني',
        ],
        'ANG' => [
            'ANG',
            'غيلدر أنتيلي هولندي',
        ],
        'AOA' => [
            'AOA',
            'كوانزا أنغولي',
        ],
        'AOK' => [
            'AOK',
            'كوانزا أنجولي - 1977-1990',
        ],
        'AON' => [
            'AON',
            'كوانزا أنجولي جديدة - 1990-2000',
        ],
        'AOR' => [
            'AOR',
            'كوانزا أنجولي معدلة - 1995 - 1999',
        ],
        'ARA' => [
            'ARA',
            'استرال أرجنتيني',
        ],
        'ARP' => [
            'ARP',
            'بيزو أرجنتيني - 1983-1985',
        ],
        'ARS' => [
            'ARS',
            'بيزو أرجنتيني',
        ],
        'ATS' => [
            'ATS',
            'شلن نمساوي',
        ],
        'AUD' => [
            'AU$',
            'دولار أسترالي',
        ],
        'AWG' => [
            'AWG',
            'فلورن أروبي',
        ],
        'AZM' => [
            'AZM',
            'مانات أذريبجاني',
        ],
        'AZN' => [
            'AZN',
            'مانات أذربيجان',
        ],
        'BAD' => [
            'BAD',
            'دينار البوسنة والهرسك',
        ],
        'BAM' => [
            'BAM',
            'مارك البوسنة والهرسك قابل للتحويل',
        ],
        'BBD' => [
            'BBD',
            'دولار بربادوسي',
        ],
        'BDT' => [
            'BDT',
            'تاكا بنغلاديشي',
        ],
        'BEC' => [
            'BEC',
            'فرنك بلجيكي قابل للتحويل',
        ],
        'BEF' => [
            'BEF',
            'فرنك بلجيكي',
        ],
        'BEL' => [
            'BEL',
            'فرنك بلجيكي مالي',
        ],
        'BGN' => [
            'BGN',
            'ليف بلغاري',
        ],
        'BHD' => [
            'د.ب.‏',
            'دينار بحريني',
        ],
        'BIF' => [
            'BIF',
            'فرنك بروندي',
        ],
        'BMD' => [
            'BMD',
            'دولار برمودي',
        ],
        'BND' => [
            'BND',
            'دولار بروناي',
        ],
        'BOB' => [
            'BOB',
            'بوليفيانو بوليفي',
        ],
        'BOP' => [
            'BOP',
            'بيزو بوليفي',
        ],
        'BOV' => [
            'BOV',
            'مفدول بوليفي',
        ],
        'BRB' => [
            'BRB',
            'نوفو كروزايرو برازيلي - 1967-1986',
        ],
        'BRC' => [
            'BRC',
            'كروزادو برازيلي',
        ],
        'BRE' => [
            'BRE',
            'كروزايرو برازيلي - 1990-1993',
        ],
        'BRL' => [
            'R$',
            'ريال برازيلي',
        ],
        'BSD' => [
            'BSD',
            'دولار باهامي',
        ],
        'BTN' => [
            'BTN',
            'نولتوم بوتاني',
        ],
        'BUK' => [
            'BUK',
            'كيات بورمي',
        ],
        'BWP' => [
            'BWP',
            'بولا بتسواني',
        ],
        'BYB' => [
            'BYB',
            'روبل بيلاروسي جديد - 1994-1999',
        ],
        'BYN' => [
            'BYN',
            'روبل بيلاروسي',
        ],
        'BYR' => [
            'BYR',
            'روبل بيلاروسي (٢٠٠٠–٢٠١٦)',
        ],
        'BZD' => [
            'BZD',
            'دولار بليزي',
        ],
        'CAD' => [
            'CA$',
            'دولار كندي',
        ],
        'CDF' => [
            'CDF',
            'فرنك كونغولي',
        ],
        'CHF' => [
            'CHF',
            'فرنك سويسري',
        ],
        'CLP' => [
            'CLP',
            'بيزو تشيلي',
        ],
        'CNH' => [
            'CNH',
            'يوان صيني (في الخارج)',
        ],
        'CNY' => [
            'CN¥',
            'يوان صيني',
        ],
        'COP' => [
            'COP',
            'بيزو كولومبي',
        ],
        'CRC' => [
            'CRC',
            'كولن كوستاريكي',
        ],
        'CSD' => [
            'CSD',
            'دينار صربي قديم',
        ],
        'CSK' => [
            'CSK',
            'كرونة تشيكوسلوفاكيا',
        ],
        'CUC' => [
            'CUC',
            'بيزو كوبي قابل للتحويل',
        ],
        'CUP' => [
            'CUP',
            'بيزو كوبي',
        ],
        'CVE' => [
            'CVE',
            'اسكودو الرأس الأخضر',
        ],
        'CYP' => [
            'CYP',
            'جنيه قبرصي',
        ],
        'CZK' => [
            'CZK',
            'كرونة تشيكية',
        ],
        'DDM' => [
            'DDM',
            'أوستمارك ألماني شرقي',
        ],
        'DEM' => [
            'DEM',
            'مارك ألماني',
        ],
        'DJF' => [
            'DJF',
            'فرنك جيبوتي',
        ],
        'DKK' => [
            'DKK',
            'كرونة دنماركية',
        ],
        'DOP' => [
            'DOP',
            'بيزو الدومنيكان',
        ],
        'DZD' => [
            'د.ج.‏',
            'دينار جزائري',
        ],
        'EEK' => [
            'EEK',
            'كرونة استونية',
        ],
        'EGP' => [
            'ج.م.‏',
            'جنيه مصري',
        ],
        'ERN' => [
            'ERN',
            'ناكفا أريتري',
        ],
        'ESP' => [
            'ESP',
            'بيزيتا إسباني',
        ],
        'ETB' => [
            'ETB',
            'بير أثيوبي',
        ],
        'EUR' => [
            '€',
            'يورو',
        ],
        'FIM' => [
            'FIM',
            'ماركا فنلندي',
        ],
        'FJD' => [
            'FJD',
            'دولار فيجي',
        ],
        'FKP' => [
            'FKP',
            'جنيه جزر فوكلاند',
        ],
        'FRF' => [
            'FRF',
            'فرنك فرنسي',
        ],
        'GBP' => [
            'UK£',
            'جنيه إسترليني',
        ],
        'GEL' => [
            'GEL',
            'لارى جورجي',
        ],
        'GHC' => [
            'GHC',
            'سيدي غاني',
        ],
        'GHS' => [
            'GHS',
            'سيدي غانا',
        ],
        'GIP' => [
            'GIP',
            'جنيه جبل طارق',
        ],
        'GMD' => [
            'GMD',
            'دلاسي غامبي',
        ],
        'GNF' => [
            'GNF',
            'فرنك غينيا',
        ],
        'GNS' => [
            'GNS',
            'سيلي غينيا',
        ],
        'GQE' => [
            'GQE',
            'اكويل جونينا غينيا الاستوائيّة',
        ],
        'GRD' => [
            'GRD',
            'دراخما يوناني',
        ],
        'GTQ' => [
            'GTQ',
            'كوتزال غواتيمالا',
        ],
        'GWE' => [
            'GWE',
            'اسكود برتغالي غينيا',
        ],
        'GWP' => [
            'GWP',
            'بيزو غينيا بيساو',
        ],
        'GYD' => [
            'GYD',
            'دولار غيانا',
        ],
        'HKD' => [
            'HK$',
            'دولار هونغ كونغ',
        ],
        'HNL' => [
            'HNL',
            'ليمبيرا هنداروس',
        ],
        'HRD' => [
            'HRD',
            'دينار كرواتي',
        ],
        'HRK' => [
            'HRK',
            'كونا كرواتي',
        ],
        'HTG' => [
            'HTG',
            'جوردى هايتي',
        ],
        'HUF' => [
            'HUF',
            'فورينت هنغاري',
        ],
        'IDR' => [
            'IDR',
            'روبية إندونيسية',
        ],
        'IEP' => [
            'IEP',
            'جنيه إيرلندي',
        ],
        'ILP' => [
            'ILP',
            'جنيه إسرائيلي',
        ],
        'ILS' => [
            '₪',
            'شيكل إسرائيلي جديد',
        ],
        'INR' => [
            '₹',
            'روبية هندي',
        ],
        'IQD' => [
            'د.ع.‏',
            'دينار عراقي',
        ],
        'IRR' => [
            'ر.إ.',
            'ريال إيراني',
        ],
        'ISK' => [
            'ISK',
            'كرونة أيسلندية',
        ],
        'ITL' => [
            'ITL',
            'ليرة إيطالية',
        ],
        'JMD' => [
            'JMD',
            'دولار جامايكي',
        ],
        'JOD' => [
            'د.أ.‏',
            'دينار أردني',
        ],
        'JPY' => [
            'JP¥',
            'ين ياباني',
        ],
        'KES' => [
            'KES',
            'شلن كينيي',
        ],
        'KGS' => [
            'KGS',
            'سوم قيرغستاني',
        ],
        'KHR' => [
            'KHR',
            'رييال كمبودي',
        ],
        'KMF' => [
            'KMF',
            'فرنك جزر القمر',
        ],
        'KPW' => [
            'KPW',
            'وون كوريا الشمالية',
        ],
        'KRW' => [
            '₩',
            'وون كوريا الجنوبية',
        ],
        'KWD' => [
            'د.ك.‏',
            'دينار كويتي',
        ],
        'KYD' => [
            'KYD',
            'دولار جزر كيمن',
        ],
        'KZT' => [
            'KZT',
            'تينغ كازاخستاني',
        ],
        'LAK' => [
            'LAK',
            'كيب لاوسي',
        ],
        'LBP' => [
            'ل.ل.‏',
            'جنيه لبناني',
        ],
        'LKR' => [
            'LKR',
            'روبية سريلانكية',
        ],
        'LRD' => [
            'LRD',
            'دولار ليبيري',
        ],
        'LSL' => [
            'LSL',
            'لوتي ليسوتو',
        ],
        'LTL' => [
            'LTL',
            'ليتا ليتوانية',
        ],
        'LTT' => [
            'LTT',
            'تالوناس ليتواني',
        ],
        'LUC' => [
            'LUC',
            'فرنك لوكسمبرج قابل للتحويل',
        ],
        'LUF' => [
            'LUF',
            'فرنك لوكسمبرج',
        ],
        'LUL' => [
            'LUL',
            'فرنك لوكسمبرج المالي',
        ],
        'LVL' => [
            'LVL',
            'لاتس لاتفيا',
        ],
        'LVR' => [
            'LVR',
            'روبل لاتفيا',
        ],
        'LYD' => [
            'د.ل.‏',
            'دينار ليبي',
        ],
        'MAD' => [
            'د.م.‏',
            'درهم مغربي',
        ],
        'MAF' => [
            'MAF',
            'فرنك مغربي',
        ],
        'MDL' => [
            'MDL',
            'ليو مولدوفي',
        ],
        'MGA' => [
            'MGA',
            'أرياري مدغشقر',
        ],
        'MGF' => [
            'MGF',
            'فرنك مدغشقر',
        ],
        'MKD' => [
            'MKD',
            'دينار مقدوني',
        ],
        'MLF' => [
            'MLF',
            'فرنك مالي',
        ],
        'MMK' => [
            'MMK',
            'كيات ميانمار',
        ],
        'MNT' => [
            'MNT',
            'توغروغ منغولي',
        ],
        'MOP' => [
            'MOP',
            'باتاكا ماكاوي',
        ],
        'MRO' => [
            'MRO',
            'أوقية موريتانية - 1973-2017',
        ],
        'MRU' => [
            'أ.م.',
            'أوقية موريتانية',
        ],
        'MTL' => [
            'MTL',
            'ليرة مالطية',
        ],
        'MTP' => [
            'MTP',
            'جنيه مالطي',
        ],
        'MUR' => [
            'MUR',
            'روبية موريشيوسية',
        ],
        'MVR' => [
            'MVR',
            'روفيه جزر المالديف',
        ],
        'MWK' => [
            'MWK',
            'كواشا مالاوي',
        ],
        'MXN' => [
            'MX$',
            'بيزو مكسيكي',
        ],
        'MXP' => [
            'MXP',
            'بيزو فضي مكسيكي - 1861-1992',
        ],
        'MYR' => [
            'MYR',
            'رينغيت ماليزي',
        ],
        'MZE' => [
            'MZE',
            'اسكود موزمبيقي',
        ],
        'MZN' => [
            'MZN',
            'متكال موزمبيقي',
        ],
        'NAD' => [
            'NAD',
            'دولار ناميبي',
        ],
        'NGN' => [
            'NGN',
            'نايرا نيجيري',
        ],
        'NIC' => [
            'NIC',
            'كوردوبة نيكاراجوا',
        ],
        'NIO' => [
            'NIO',
            'قرطبة نيكاراغوا',
        ],
        'NLG' => [
            'NLG',
            'جلدر هولندي',
        ],
        'NOK' => [
            'NOK',
            'كرونة نرويجية',
        ],
        'NPR' => [
            'NPR',
            'روبية نيبالي',
        ],
        'NZD' => [
            'NZ$',
            'دولار نيوزيلندي',
        ],
        'OMR' => [
            'ر.ع.‏',
            'ريال عماني',
        ],
        'PAB' => [
            'PAB',
            'بالبوا بنمي',
        ],
        'PEN' => [
            'PEN',
            'سول بيروفي',
        ],
        'PGK' => [
            'PGK',
            'كينا بابوا غينيا الجديدة',
        ],
        'PHP' => [
            'PHP',
            'بيزو فلبيني',
        ],
        'PKR' => [
            'PKR',
            'روبية باكستاني',
        ],
        'PLN' => [
            'PLN',
            'زلوتي بولندي',
        ],
        'PLZ' => [
            'PLZ',
            'زلوتي بولندي - 1950-1995',
        ],
        'PTE' => [
            'PTE',
            'اسكود برتغالي',
        ],
        'PYG' => [
            'PYG',
            'غواراني باراغواي',
        ],
        'QAR' => [
            'ر.ق.‏',
            'ريال قطري',
        ],
        'RHD' => [
            'RHD',
            'دولار روديسي',
        ],
        'ROL' => [
            'ROL',
            'ليو روماني قديم',
        ],
        'RON' => [
            'RON',
            'ليو روماني',
        ],
        'RSD' => [
            'RSD',
            'دينار صربي',
        ],
        'RUB' => [
            'RUB',
            'روبل روسي',
        ],
        'RUR' => [
            'RUR',
            'روبل روسي - 1991-1998',
        ],
        'RWF' => [
            'RWF',
            'فرنك رواندي',
        ],
        'SAR' => [
            'ر.س.‏',
            'ريال سعودي',
        ],
        'SBD' => [
            'SBD',
            'دولار جزر سليمان',
        ],
        'SCR' => [
            'SCR',
            'روبية سيشيلية',
        ],
        'SDD' => [
            'د.س.‏',
            'دينار سوداني',
        ],
        'SDG' => [
            'ج.س.',
            'جنيه سوداني',
        ],
        'SDP' => [
            'SDP',
            'جنيه سوداني قديم',
        ],
        'SEK' => [
            'SEK',
            'كرونة سويدية',
        ],
        'SGD' => [
            'SGD',
            'دولار سنغافوري',
        ],
        'SHP' => [
            'SHP',
            'جنيه سانت هيلين',
        ],
        'SIT' => [
            'SIT',
            'تولار سلوفيني',
        ],
        'SKK' => [
            'SKK',
            'كرونة سلوفاكية',
        ],
        'SLE' => [
            'SLE',
            'ليون سيراليوني',
        ],
        'SLL' => [
            'SLL',
            'ليون سيراليوني - 1964-2022',
        ],
        'SOS' => [
            'SOS',
            'شلن صومالي',
        ],
        'SRD' => [
            'SRD',
            'دولار سورينامي',
        ],
        'SRG' => [
            'SRG',
            'جلدر سورينامي',
        ],
        'SSP' => [
            'SSP',
            'جنيه جنوب السودان',
        ],
        'STD' => [
            'STD',
            'دوبرا ساو تومي وبرينسيبي - 1977-2017',
        ],
        'STN' => [
            'STN',
            'دوبرا ساو تومي وبرينسيبي',
        ],
        'SUR' => [
            'SUR',
            'روبل سوفيتي',
        ],
        'SVC' => [
            'SVC',
            'كولون سلفادوري',
        ],
        'SYP' => [
            'ل.س.‏',
            'ليرة سورية',
        ],
        'SZL' => [
            'SZL',
            'ليلانجيني سوازيلندي',
        ],
        'THB' => [
            '฿',
            'باخت تايلاندي',
        ],
        'TJR' => [
            'TJR',
            'روبل طاجيكستاني',
        ],
        'TJS' => [
            'TJS',
            'سوموني طاجيكستاني',
        ],
        'TMM' => [
            'TMM',
            'مانات تركمنستاني',
        ],
        'TMT' => [
            'TMT',
            'مانات تركمانستان',
        ],
        'TND' => [
            'د.ت.‏',
            'دينار تونسي',
        ],
        'TOP' => [
            'TOP',
            'بانغا تونغا',
        ],
        'TPE' => [
            'TPE',
            'اسكود تيموري',
        ],
        'TRL' => [
            'TRL',
            'ليرة تركي',
        ],
        'TRY' => [
            'TRY',
            'ليرة تركية',
        ],
        'TTD' => [
            'TTD',
            'دولار ترينداد وتوباغو',
        ],
        'TWD' => [
            'NT$',
            'دولار تايواني',
        ],
        'TZS' => [
            'TZS',
            'شلن تنزاني',
        ],
        'UAH' => [
            'UAH',
            'هريفنيا أوكراني',
        ],
        'UGS' => [
            'UGS',
            'شلن أوغندي - 1966-1987',
        ],
        'UGX' => [
            'UGX',
            'شلن أوغندي',
        ],
        'USD' => [
            'US$',
            'دولار أمريكي',
        ],
        'USN' => [
            'USN',
            'دولار أمريكي (اليوم التالي)‏',
        ],
        'USS' => [
            'USS',
            'دولار أمريكي (نفس اليوم)‏',
        ],
        'UYP' => [
            'UYP',
            'بيزو أوروجواي - 1975-1993',
        ],
        'UYU' => [
            'UYU',
            'بيزو اوروغواي',
        ],
        'UZS' => [
            'UZS',
            'سوم أوزبكستاني',
        ],
        'VEB' => [
            'VEB',
            'بوليفار فنزويلي - 1871-2008',
        ],
        'VEF' => [
            'VEF',
            'بوليفار فنزويلي - 2008–2018',
        ],
        'VES' => [
            'VES',
            'بوليفار فنزويلي',
        ],
        'VND' => [
            '₫',
            'دونج فيتنامي',
        ],
        'VUV' => [
            'VUV',
            'فاتو فانواتو',
        ],
        'WST' => [
            'WST',
            'تالا ساموا',
        ],
        'XAF' => [
            'FCFA',
            'فرنك وسط أفريقي',
        ],
        'XCD' => [
            'EC$',
            'دولار شرق الكاريبي',
        ],
        'XCG' => [
            'Cg.',
            'غيلدر كاريبي',
        ],
        'XEU' => [
            'XEU',
            'وحدة النقد الأوروبية',
        ],
        'XFO' => [
            'XFO',
            'فرنك فرنسي ذهبي',
        ],
        'XFU' => [
            'XFU',
            '(UIC)فرنك فرنسي',
        ],
        'XOF' => [
            'F CFA',
            'فرنك غرب أفريقي',
        ],
        'XPF' => [
            'CFPF',
            'فرنك سي إف بي',
        ],
        'YDD' => [
            'YDD',
            'دينار يمني',
        ],
        'YER' => [
            'ر.ي.‏',
            'ريال يمني',
        ],
        'YUD' => [
            'YUD',
            'دينار يوغسلافي',
        ],
        'YUN' => [
            'YUN',
            'دينار يوغسلافي قابل للتحويل',
        ],
        'ZAL' => [
            'ZAL',
            'راند جنوب أفريقيا -مالي',
        ],
        'ZAR' => [
            'ZAR',
            'راند جنوب أفريقيا',
        ],
        'ZMK' => [
            'ZMK',
            'كواشا زامبي - 1968-2012',
        ],
        'ZMW' => [
            'ZMW',
            'كواشا زامبي',
        ],
        'ZRN' => [
            'ZRN',
            'زائير زائيري جديد',
        ],
        'ZRZ' => [
            'ZRZ',
            'زائير زائيري',
        ],
        'ZWD' => [
            'ZWD',
            'دولار زمبابوي',
        ],
        'ZWG' => [
            'ZWG',
            'ذهب زيمبابوي',
        ],
        'ZWL' => [
            'ZWL',
            'دولار زمبابوي 2009',
        ],
    ],
];
