<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Дирҳами АМА',
        ],
        'AFN' => [
            'AFN',
            'Афғонии Афғонистон',
        ],
        'ALL' => [
            'ALL',
            'Леки албанӣ',
        ],
        'AMD' => [
            'AMD',
            'Драми Арманистон',
        ],
        'ANG' => [
            'ANG',
            'Гулдени Антилии Нидерланд',
        ],
        'AOA' => [
            'AOA',
            'Кванзаи Ангола',
        ],
        'ARS' => [
            'ARS',
            'Песои Аргентина',
        ],
        'AUD' => [
            'A$',
            'Доллари Австралия',
        ],
        'AWG' => [
            'AWG',
            'Флорини Арубан',
        ],
        'AZN' => [
            'AZN',
            'Манати Озарбойҷон',
        ],
        'BAM' => [
            'BAM',
            'Маркаҳои конвертатсияшавандаи Босния-Герсеговина',
        ],
        'BBD' => [
            'BBD',
            'Доллари Барбад',
        ],
        'BDT' => [
            'BDT',
            'Такаси Бангладеши',
        ],
        'BGN' => [
            'BGN',
            'Леви Болгария',
        ],
        'BHD' => [
            'BHD',
            'Динори Баҳрайн',
        ],
        'BIF' => [
            'BIF',
            'Франки Бурунди',
        ],
        'BMD' => [
            'BMD',
            'Доллари Бермуд',
        ],
        'BND' => [
            'BND',
            'Доллари Бруней',
        ],
        'BOB' => [
            'BOB',
            'Боливянои Боливия',
        ],
        'BRL' => [
            'R$',
            'Реали бразилиягӣ',
        ],
        'BSD' => [
            'BSD',
            'Доллари Багама',
        ],
        'BTN' => [
            'BTN',
            'Нгултруми Бутан',
        ],
        'BWP' => [
            'BWP',
            'Пулаи Ботсвана',
        ],
        'BYN' => [
            'BYN',
            'Рубли Беларус',
        ],
        'BZD' => [
            'BZD',
            'Доллари Белиз',
        ],
        'CAD' => [
            'CA$',
            'Доллари Канада',
        ],
        'CDF' => [
            'CDF',
            'Франки Конго',
        ],
        'CHF' => [
            'CHF',
            'Франки Швейтсария',
        ],
        'CLP' => [
            'CLP',
            'Песои Чили',
        ],
        'CNH' => [
            'CNH',
            'Юани Хитой (офшорӣ)',
        ],
        'CNY' => [
            'CN¥',
            'Иенаи хитоӣ',
        ],
        'COP' => [
            'COP',
            'Песои Колумбия',
        ],
        'CRC' => [
            'CRC',
            'Колони Коста-Рика',
        ],
        'CUC' => [
            'CUC',
            'Песои конвертшавандаи Куба',
        ],
        'CUP' => [
            'CUP',
            'Песои Куба',
        ],
        'CVE' => [
            'CVE',
            'Эскудои Кабо Верде',
        ],
        'CZK' => [
            'CZK',
            'Крони Чехия',
        ],
        'DJF' => [
            'DJF',
            'Франки Ҷибутӣ',
        ],
        'DKK' => [
            'DKK',
            'Крони Дания',
        ],
        'DOP' => [
            'DOP',
            'Песои Доминикан',
        ],
        'DZD' => [
            'DZD',
            'Динори Алҷазоир',
        ],
        'EGP' => [
            'EGP',
            'Фунти мисрӣ',
        ],
        'ERN' => [
            'ERN',
            'Накфаи Эритрея',
        ],
        'ETB' => [
            'ETB',
            'Бирри Эфиопия',
        ],
        'EUR' => [
            '€',
            'Евро',
        ],
        'FJD' => [
            'FJD',
            'Доллари Фиҷи',
        ],
        'FKP' => [
            'FKP',
            'Фунти Ҷазираҳои Фолкленд',
        ],
        'GBP' => [
            '£',
            'Фунт стерлинги британӣ',
        ],
        'GEL' => [
            'GEL',
            'Лариси гурҷӣ',
        ],
        'GHS' => [
            'GHS',
            'Седи Гана',
        ],
        'GIP' => [
            'GIP',
            'Фунти Гибралтар',
        ],
        'GMD' => [
            'GMD',
            'Даласи Гамбия',
        ],
        'GNF' => [
            'GNF',
            'Франки Гвинея',
        ],
        'GTQ' => [
            'GTQ',
            'Кветзали Гватемала',
        ],
        'GYD' => [
            'GYD',
            'Доллари Гайана',
        ],
        'HKD' => [
            'HK$',
            'Доллари Гонконг',
        ],
        'HNL' => [
            'HNL',
            'Лемпираи Гондурас',
        ],
        'HRK' => [
            'HRK',
            'Кунаи Хорватия',
        ],
        'HTG' => [
            'HTG',
            'Гурди Ҳаити',
        ],
        'HUF' => [
            'HUF',
            'Форинти Венгрия',
        ],
        'IDR' => [
            'IDR',
            'Рупияи Индонезия',
        ],
        'ILS' => [
            '₪',
            'Шекелҳои нави Исроил',
        ],
        'INR' => [
            '₹',
            'Рупияи ҳиндустонӣ',
        ],
        'IQD' => [
            'IQD',
            'Динори Ироқ',
        ],
        'IRR' => [
            'IRR',
            'Риёли Эрон',
        ],
        'ISK' => [
            'ISK',
            'Кронури Исландия',
        ],
        'JMD' => [
            'JMD',
            'Доллари Ямайка',
        ],
        'JOD' => [
            'JOD',
            'Динори Иордания',
        ],
        'JPY' => [
            'JP¥',
            'Иенаи японӣ',
        ],
        'KES' => [
            'KES',
            'Шиллинги Кения',
        ],
        'KGS' => [
            'KGS',
            'Соми Қирғизистон',
        ],
        'KHR' => [
            'KHR',
            'Риэли Камбоҷа',
        ],
        'KMF' => [
            'KMF',
            'Франки Комория',
        ],
        'KPW' => [
            'KPW',
            'Вони Кореяи Шимолӣ',
        ],
        'KRW' => [
            '₩',
            'Вони Кореяи Ҷанубӣ',
        ],
        'KWD' => [
            'KWD',
            'Динори Кувайт',
        ],
        'KYD' => [
            'KYD',
            'Доллари Ҷазираҳои Кайман',
        ],
        'KZT' => [
            'KZT',
            'Тангаи Казокистон',
        ],
        'LAK' => [
            'LAK',
            'Кипи Лаосй',
        ],
        'LBP' => [
            'LBP',
            'Фунти Лубнон',
        ],
        'LKR' => [
            'LKR',
            'Рупи Шри-Ланка',
        ],
        'LRD' => [
            'LRD',
            'Доллари Либерия',
        ],
        'LSL' => [
            'LSL',
            'Лотиси Лесото',
        ],
        'LYD' => [
            'LYD',
            'Динори Либия',
        ],
        'MAD' => [
            'MAD',
            'Дирхами Марокаш',
        ],
        'MDL' => [
            'MDL',
            'Лейи Молдова',
        ],
        'MGA' => [
            'MGA',
            'Ариарии Малагасий',
        ],
        'MKD' => [
            'MKD',
            'Денори Македония',
        ],
        'MMK' => [
            'MMK',
            'киати Мянмар',
        ],
        'MNT' => [
            'MNT',
            'Тугрики Муғулистон',
        ],
        'MOP' => [
            'MOP',
            'Патакаи Макао',
        ],
        'MRU' => [
            'MRU',
            'Огуияи Мавритания',
        ],
        'MUR' => [
            'MUR',
            'Рупияи Маврикий',
        ],
        'MVR' => [
            'MVR',
            'Руфияи Малдив',
        ],
        'MWK' => [
            'MWK',
            'Квачаи Малавия',
        ],
        'MXN' => [
            'MX$',
            'Песои Мексика',
        ],
        'MYR' => [
            'MYR',
            'Ринггити Малайзия',
        ],
        'MZN' => [
            'MZN',
            'Метикали Мозамбик',
        ],
        'NAD' => [
            'NAD',
            'Доллари Намибия',
        ],
        'NGN' => [
            'NGN',
            'Найраи Нигерия',
        ],
        'NIO' => [
            'NIO',
            'Кордобаи Никарагуа',
        ],
        'NOK' => [
            'NOK',
            'Кронаи Норвегия',
        ],
        'NPR' => [
            'NPR',
            'Рупияи Непал',
        ],
        'NZD' => [
            'NZ$',
            'Доллари Зеландияи Нав',
        ],
        'OMR' => [
            'OMR',
            'Риёли Уммон',
        ],
        'PAB' => [
            'PAB',
            'Балбоаи Панама',
        ],
        'PEN' => [
            'PEN',
            'Соли Перу',
        ],
        'PGK' => [
            'PGK',
            'Кинаи Гвинеяи Папуа',
        ],
        'PHP' => [
            '₱',
            'Песои Филиппин',
        ],
        'PKR' => [
            'PKR',
            'Рупияи Покистон',
        ],
        'PLN' => [
            'PLN',
            'Злотии Польша',
        ],
        'PYG' => [
            'PYG',
            'Гуарании Парагвай',
        ],
        'QAR' => [
            'QAR',
            'Риёли Қатар',
        ],
        'RON' => [
            'RON',
            'Лейи Руминия',
        ],
        'RSD' => [
            'RSD',
            'Динори Сербия',
        ],
        'RUB' => [
            'RUB',
            'Рубли русӣ',
        ],
        'RWF' => [
            'RWF',
            'Франки Руанда',
        ],
        'SAR' => [
            'SAR',
            'Риёли Саудӣ',
        ],
        'SBD' => [
            'SBD',
            'Доллари Ҷазираҳои Соломон',
        ],
        'SCR' => [
            'SCR',
            'Рупии Сейшел',
        ],
        'SDG' => [
            'SDG',
            'Фунти Судон',
        ],
        'SEK' => [
            'SEK',
            'Крони шведӣ',
        ],
        'SGD' => [
            'SGD',
            'Доллари Сингапур',
        ],
        'SHP' => [
            'SHP',
            'Фунти Сент Елена',
        ],
        'SLE' => [
            'SLE',
            'Леони Серра-Леоне',
        ],
        'SLL' => [
            'SLL',
            'Леони Серра-Леоне (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Шиллинги Сомали',
        ],
        'SRD' => [
            'SRD',
            'Доллари Суринам',
        ],
        'SSP' => [
            'SSP',
            'Фунти Судони Ҷанубӣ',
        ],
        'STN' => [
            'STN',
            'Добраи Сан-Томе ва Принсипи',
        ],
        'SYP' => [
            'SYP',
            'Фунти Сурия',
        ],
        'SZL' => [
            'SZL',
            'Эмалангени Свази',
        ],
        'THB' => [
            'THB',
            'Бати Таиланд',
        ],
        'TJS' => [
            'сом.',
            'Сомонии Тоҷикистон',
        ],
        'TMT' => [
            'TMT',
            'манати Туркманистон',
        ],
        'TND' => [
            'TND',
            'Динори Тунис',
        ],
        'TOP' => [
            'TOP',
            'Паангаи Тонга',
        ],
        'TRY' => [
            'TRY',
            'Лираи Туркия',
        ],
        'TTD' => [
            'TTD',
            'Доллари Тринидад ва Тобаго',
        ],
        'TWD' => [
            'NT$',
            'Доллари нави Тайван',
        ],
        'TZS' => [
            'TZS',
            'Шиллинги Танзания',
        ],
        'UAH' => [
            'UAH',
            'Гривнаи украинӣ',
        ],
        'UGX' => [
            'UGX',
            'Шилинги Уганда',
        ],
        'USD' => [
            '$',
            'Доллари ИМА',
        ],
        'UYU' => [
            'UYU',
            'Песои Уругвай',
        ],
        'UZS' => [
            'UZS',
            'Сўми Ӯзбекистон',
        ],
        'VES' => [
            'VES',
            'Боливари Венесуэла',
        ],
        'VND' => [
            '₫',
            'Донги Ветнам',
        ],
        'VUV' => [
            'VUV',
            'Ватуи Вануату',
        ],
        'WST' => [
            'WST',
            'Талаи Самоа',
        ],
        'XAF' => [
            'FCFA',
            'Франки CFA Африқои Марказӣ',
        ],
        'XCD' => [
            'EC$',
            'Доллари Кариби Шарқӣ',
        ],
        'XCG' => [
            'Cg.',
            'гулдени Кариб',
        ],
        'XOF' => [
            'F CFA',
            'Франки Африқои Ғарбӣ',
        ],
        'XPF' => [
            'CFPF',
            'Франки CFP',
        ],
        'YER' => [
            'YER',
            'Риали Яман',
        ],
        'ZAR' => [
            'ZAR',
            'Рэнди Африқои Ҷанубӣ',
        ],
        'ZMW' => [
            'ZMW',
            'Квачаи Замбия',
        ],
        'ZWG' => [
            'ZWG',
            'тиллоии Зимбабве',
        ],
    ],
];
