<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Andorran peseta',
        ],
        'AED' => [
            'AED',
            'Arabiemiirikuntien dirhami',
        ],
        'AFA' => [
            'AFA',
            'Afganistanin afgaani (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'Afganistanin afgaani',
        ],
        'ALK' => [
            'ALK',
            'Albanian lek (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'Albanian lek',
        ],
        'AMD' => [
            'AMD',
            'Armenian dram',
        ],
        'ANG' => [
            'ANG',
            'Alankomaiden Antillien guldeni',
        ],
        'AOA' => [
            'AOA',
            'Angolan kwanza',
        ],
        'AOK' => [
            'AOK',
            'Angolan kwanza (1977–1991)',
        ],
        'AON' => [
            'AON',
            'Angolan uusi kwanza (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Angolan kwanza reajustado (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Argentiinan austral',
        ],
        'ARL' => [
            'ARL',
            'Argentiinan ley-peso (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'Argentiinan peso (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'Argentiinan peso (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'Argentiinan peso',
        ],
        'ATS' => [
            'ATS',
            'Itävallan šillinki',
        ],
        'AUD' => [
            'AUD',
            'Australian dollari',
        ],
        'AWG' => [
            'AWG',
            'Aruban floriini',
        ],
        'AZM' => [
            'AZM',
            'Azerbaidžanin manat (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'Azerbaidžanin manat',
        ],
        'BAD' => [
            'BAD',
            'Bosnia-Hertsegovinan dinaari (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'Bosnia-Hertsegovinan vaihdettava markka',
        ],
        'BAN' => [
            'BAN',
            'Bosnia-Hertsegovinan uusi dinaari (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'Barbadosin dollari',
        ],
        'BDT' => [
            'BDT',
            'Bangladeshin taka',
        ],
        'BEC' => [
            'BEC',
            'Belgian vaihdettava frangi',
        ],
        'BEF' => [
            'BEF',
            'Belgian frangi',
        ],
        'BEL' => [
            'BEL',
            'Belgian rahoitusfrangi',
        ],
        'BGL' => [
            'BGL',
            'Bulgarian kova lev',
        ],
        'BGM' => [
            'BGM',
            'Bulgarian sosialistinen lev',
        ],
        'BGN' => [
            'BGN',
            'Bulgarian lev',
        ],
        'BGO' => [
            'BGO',
            'Bulgarian lev (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'Bahrainin dinaari',
        ],
        'BIF' => [
            'BIF',
            'Burundin frangi',
        ],
        'BMD' => [
            'BMD',
            'Bermudan dollari',
        ],
        'BND' => [
            'BND',
            'Brunein dollari',
        ],
        'BOB' => [
            'BOB',
            'Bolivian boliviano',
        ],
        'BOL' => [
            'BOL',
            'Bolivian boliviano (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'Bolivian peso',
        ],
        'BOV' => [
            'BOV',
            'Bolivian mvdol',
        ],
        'BRB' => [
            'BRB',
            'Brasilian uusi cruzeiro (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Brasilian cruzado (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'Brasilian cruzeiro (1990–1993)',
        ],
        'BRL' => [
            'BRL',
            'Brasilian real',
        ],
        'BRN' => [
            'BRN',
            'Brasilian uusi cruzado (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'Brasilian cruzeiro (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'Brasilian cruzeiro (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'Bahaman dollari',
        ],
        'BTN' => [
            'BTN',
            'Bhutanin ngultrum',
        ],
        'BUK' => [
            'BUK',
            'Burman kyat',
        ],
        'BWP' => [
            'BWP',
            'Botswanan pula',
        ],
        'BYB' => [
            'BYB',
            'Valko-Venäjän uusi rupla (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'Valko-Venäjän rupla',
        ],
        'BYR' => [
            'BYR',
            'Valko-Venäjän rupla (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Belizen dollari',
        ],
        'CAD' => [
            'CAD',
            'Kanadan dollari',
        ],
        'CDF' => [
            'CDF',
            'Kongon frangi',
        ],
        'CHE' => [
            'CHE',
            'Sveitsin WIR-euro',
        ],
        'CHF' => [
            'CHF',
            'Sveitsin frangi',
        ],
        'CHW' => [
            'CHW',
            'Sveitsin WIR-frangi',
        ],
        'CLE' => [
            'CLE',
            'Chilen escudo',
        ],
        'CLF' => [
            'CLF',
            'Chilen unidades de fomento',
        ],
        'CLP' => [
            'CLP',
            'Chilen peso',
        ],
        'CNH' => [
            'CNH',
            'Kiinan juan (offshore)',
        ],
        'CNX' => [
            'CNX',
            'Kiinan kansanpankin dollari',
        ],
        'CNY' => [
            'CNY',
            'Kiinan juan',
        ],
        'COP' => [
            'COP',
            'Kolumbian peso',
        ],
        'COU' => [
            'COU',
            'Kolumbian unidad de valor real',
        ],
        'CRC' => [
            'CRC',
            'Costa Rican colón',
        ],
        'CSD' => [
            'CSD',
            'Serbian dinaari (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'Tšekkoslovakian kova koruna',
        ],
        'CUC' => [
            'CUC',
            'Kuuban vaihdettava peso',
        ],
        'CUP' => [
            'CUP',
            'Kuuban peso',
        ],
        'CVE' => [
            'CVE',
            'Kap Verden escudo',
        ],
        'CYP' => [
            'CYP',
            'Kyproksen punta',
        ],
        'CZK' => [
            'CZK',
            'Tšekin koruna',
        ],
        'DDM' => [
            'DDM',
            'Itä-Saksan markka',
        ],
        'DEM' => [
            'DEM',
            'Saksan markka',
        ],
        'DJF' => [
            'DJF',
            'Djiboutin frangi',
        ],
        'DKK' => [
            'DKK',
            'Tanskan kruunu',
        ],
        'DOP' => [
            'DOP',
            'Dominikaanisen tasavallan peso',
        ],
        'DZD' => [
            'DZD',
            'Algerian dinaari',
        ],
        'ECS' => [
            'ECS',
            'Ecuadorin sucre',
        ],
        'ECV' => [
            'ECV',
            'Ecuadorin UVC',
        ],
        'EEK' => [
            'EEK',
            'Viron kruunu',
        ],
        'EGP' => [
            'EGP',
            'Egyptin punta',
        ],
        'ERN' => [
            'ERN',
            'Eritrean nakfa',
        ],
        'ESA' => [
            'ESA',
            'Espanjan peseta (A-tili)',
        ],
        'ESB' => [
            'ESB',
            'Espanjan peseta (vaihdettava tili)',
        ],
        'ESP' => [
            'ESP',
            'Espanjan peseta',
        ],
        'ETB' => [
            'ETB',
            'Etiopian birr',
        ],
        'EUR' => [
            '€',
            'euro',
        ],
        'FIM' => [
            'mk',
            'Suomen markka',
        ],
        'FJD' => [
            'FJD',
            'Fidžin dollari',
        ],
        'FKP' => [
            'FKP',
            'Falklandinsaarten punta',
        ],
        'FRF' => [
            'FRF',
            'Ranskan frangi',
        ],
        'GBP' => [
            '£',
            'Englannin punta',
        ],
        'GEK' => [
            'GEK',
            'Georgian kuponkilari',
        ],
        'GEL' => [
            'GEL',
            'Georgian lari',
        ],
        'GHC' => [
            'GHC',
            'Ghanan cedi (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'Ghanan cedi',
        ],
        'GIP' => [
            'GIP',
            'Gibraltarin punta',
        ],
        'GMD' => [
            'GMD',
            'Gambian dalasi',
        ],
        'GNF' => [
            'GNF',
            'Guinean frangi',
        ],
        'GNS' => [
            'GNS',
            'Guinean syli',
        ],
        'GQE' => [
            'GQE',
            'Päiväntasaajan Guinean ekwele',
        ],
        'GRD' => [
            'GRD',
            'Kreikan drakma',
        ],
        'GTQ' => [
            'GTQ',
            'Guatemalan quetzal',
        ],
        'GWE' => [
            'GWE',
            'Portugalin Guinean escudo',
        ],
        'GWP' => [
            'GWP',
            'Guinea-Bissaun peso',
        ],
        'GYD' => [
            'GYD',
            'Guyanan dollari',
        ],
        'HKD' => [
            'HKD',
            'Hongkongin dollari',
        ],
        'HNL' => [
            'HNL',
            'Hondurasin lempira',
        ],
        'HRD' => [
            'HRD',
            'Kroatian dinaari',
        ],
        'HRK' => [
            'HRK',
            'Kroatian kuna',
        ],
        'HTG' => [
            'HTG',
            'Haitin gourde',
        ],
        'HUF' => [
            'HUF',
            'Unkarin forintti',
        ],
        'IDR' => [
            'IDR',
            'Indonesian rupia',
        ],
        'IEP' => [
            'IEP',
            'Irlannin punta',
        ],
        'ILP' => [
            'ILP',
            'Israelin punta',
        ],
        'ILR' => [
            'ILR',
            'Israelin sekeli (1980–1985)',
        ],
        'ILS' => [
            'ILS',
            'Israelin uusi sekeli',
        ],
        'INR' => [
            'INR',
            'Intian rupia',
        ],
        'IQD' => [
            'IQD',
            'Irakin dinaari',
        ],
        'IRR' => [
            'IRR',
            'Iranin rial',
        ],
        'ISJ' => [
            'ISJ',
            'Islannin kruunu (1918–1981)',
        ],
        'ISK' => [
            'ISK',
            'Islannin kruunu',
        ],
        'ITL' => [
            'ITL',
            'Italian liira',
        ],
        'JMD' => [
            'JMD',
            'Jamaikan dollari',
        ],
        'JOD' => [
            'JOD',
            'Jordanian dinaari',
        ],
        'JPY' => [
            '¥',
            'Japanin jeni',
        ],
        'KES' => [
            'KES',
            'Kenian šillinki',
        ],
        'KGS' => [
            'KGS',
            'Kirgisian som',
        ],
        'KHR' => [
            'KHR',
            'Kambodžan riel',
        ],
        'KMF' => [
            'KMF',
            'Komorien frangi',
        ],
        'KPW' => [
            'KPW',
            'Pohjois-Korean won',
        ],
        'KRH' => [
            'KRH',
            'Etelä-Korean hwan (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'Etelä-Korean won (1945–1953)',
        ],
        'KRW' => [
            'KRW',
            'Etelä-Korean won',
        ],
        'KWD' => [
            'KWD',
            'Kuwaitin dinaari',
        ],
        'KYD' => [
            'KYD',
            'Caymansaarten dollari',
        ],
        'KZT' => [
            'KZT',
            'Kazakstanin tenge',
        ],
        'LAK' => [
            'LAK',
            'Laosin kip',
        ],
        'LBP' => [
            'LBP',
            'Libanonin punta',
        ],
        'LKR' => [
            'LKR',
            'Sri Lankan rupia',
        ],
        'LRD' => [
            'LRD',
            'Liberian dollari',
        ],
        'LSL' => [
            'LSL',
            'Lesothon loti',
        ],
        'LTL' => [
            'LTL',
            'Liettuan liti',
        ],
        'LTT' => [
            'LTT',
            'Liettuan talonas',
        ],
        'LUC' => [
            'LUC',
            'Luxemburgin vaihdettava frangi',
        ],
        'LUF' => [
            'LUF',
            'Luxemburgin frangi',
        ],
        'LUL' => [
            'LUL',
            'Luxemburgin rahoitusfrangi',
        ],
        'LVL' => [
            'LVL',
            'Latvian lati',
        ],
        'LVR' => [
            'LVR',
            'Latvian rupla',
        ],
        'LYD' => [
            'LYD',
            'Libyan dinaari',
        ],
        'MAD' => [
            'MAD',
            'Marokon dirhami',
        ],
        'MAF' => [
            'MAF',
            'Marokon frangi',
        ],
        'MCF' => [
            'MCF',
            'Monacon frangi',
        ],
        'MDC' => [
            'MDC',
            'Moldovan kuponkileu',
        ],
        'MDL' => [
            'MDL',
            'Moldovan leu',
        ],
        'MGA' => [
            'MGA',
            'Madagaskarin ariary',
        ],
        'MGF' => [
            'MGF',
            'Madagaskarin frangi',
        ],
        'MKD' => [
            'MKD',
            'Makedonian denaari',
        ],
        'MKN' => [
            'MKN',
            'Makedonian dinaari (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'Malin frangi',
        ],
        'MMK' => [
            'MMK',
            'Myanmarin kyat',
        ],
        'MNT' => [
            'MNT',
            'Mongolian tugrik',
        ],
        'MOP' => [
            'MOP',
            'Macaon pataca',
        ],
        'MRO' => [
            'MRO',
            'Mauritanian ouguiya (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Mauritanian ouguiya',
        ],
        'MTL' => [
            'MTL',
            'Maltan liira',
        ],
        'MTP' => [
            'MTP',
            'Maltan punta',
        ],
        'MUR' => [
            'MUR',
            'Mauritiuksen rupia',
        ],
        'MVP' => [
            'MVP',
            'Malediivien rupia (1947–1981)',
        ],
        'MVR' => [
            'MVR',
            'Malediivien rufiyaa',
        ],
        'MWK' => [
            'MWK',
            'Malawin kwacha',
        ],
        'MXN' => [
            'MXN',
            'Meksikon peso',
        ],
        'MXP' => [
            'MXP',
            'Meksikon hopeapeso (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Meksikon UDI',
        ],
        'MYR' => [
            'MYR',
            'Malesian ringgit',
        ],
        'MZE' => [
            'MZE',
            'Mosambikin escudo',
        ],
        'MZM' => [
            'MZM',
            'Mosambikin metical (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'Mosambikin metical',
        ],
        'NAD' => [
            'NAD',
            'Namibian dollari',
        ],
        'NGN' => [
            'NGN',
            'Nigerian naira',
        ],
        'NIC' => [
            'NIC',
            'Nicaraguan córdoba (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'Nicaraguan córdoba',
        ],
        'NLG' => [
            'NLG',
            'Alankomaiden guldeni',
        ],
        'NOK' => [
            'NOK',
            'Norjan kruunu',
        ],
        'NPR' => [
            'NPR',
            'Nepalin rupia',
        ],
        'NZD' => [
            'NZD',
            'Uuden-Seelannin dollari',
        ],
        'OMR' => [
            'OMR',
            'Omanin rial',
        ],
        'PAB' => [
            'PAB',
            'Panaman balboa',
        ],
        'PEI' => [
            'PEI',
            'Perun inti',
        ],
        'PEN' => [
            'PEN',
            'Perun sol',
        ],
        'PES' => [
            'PES',
            'Perun sol (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'Papua-Uuden-Guinean kina',
        ],
        'PHP' => [
            'PHP',
            'Filippiinien peso',
        ],
        'PKR' => [
            'PKR',
            'Pakistanin rupia',
        ],
        'PLN' => [
            'PLN',
            'Puolan złoty',
        ],
        'PLZ' => [
            'PLZ',
            'Puolan złoty (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'Portugalin escudo',
        ],
        'PYG' => [
            'PYG',
            'Paraguayn guarani',
        ],
        'QAR' => [
            'QAR',
            'Qatarin rial',
        ],
        'RHD' => [
            'RHD',
            'Rhodesian dollari',
        ],
        'ROL' => [
            'ROL',
            'Romanian leu (1952–2006)',
        ],
        'RON' => [
            'RON',
            'Romanian leu',
        ],
        'RSD' => [
            'RSD',
            'Serbian dinaari',
        ],
        'RUB' => [
            'RUB',
            'Venäjän rupla',
        ],
        'RUR' => [
            'RUR',
            'Venäjän rupla (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'Ruandan frangi',
        ],
        'SAR' => [
            'SAR',
            'Saudi-Arabian rial',
        ],
        'SBD' => [
            'SBD',
            'Salomonsaarten dollari',
        ],
        'SCR' => [
            'SCR',
            'Seychellien rupia',
        ],
        'SDD' => [
            'SDD',
            'Sudanin dinaari (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'Sudanin punta',
        ],
        'SDP' => [
            'SDP',
            'Sudanin punta (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'Ruotsin kruunu',
        ],
        'SGD' => [
            'SGD',
            'Singaporen dollari',
        ],
        'SHP' => [
            'SHP',
            'Saint Helenan punta',
        ],
        'SIT' => [
            'SIT',
            'Slovenian tolar',
        ],
        'SKK' => [
            'SKK',
            'Slovakian koruna',
        ],
        'SLE' => [
            'SLE',
            'Sierra Leonen leone',
        ],
        'SLL' => [
            'SLL',
            'Sierra Leonen leone (1964–2022)',
        ],
        'SOS' => [
            'SOS',
            'Somalian šillinki',
        ],
        'SRD' => [
            'SRD',
            'Surinamen dollari',
        ],
        'SRG' => [
            'SRG',
            'Surinamen guldeni',
        ],
        'SSP' => [
            'SSP',
            'Etelä-Sudanin punta',
        ],
        'STD' => [
            'STD',
            'São Tomén ja Príncipen dobra (1977–2017)',
        ],
        'STN' => [
            'STN',
            'São Tomén ja Príncipen dobra',
        ],
        'SUR' => [
            'SUR',
            'Neuvostoliiton rupla',
        ],
        'SVC' => [
            'SVC',
            'El Salvadorin colón',
        ],
        'SYP' => [
            'SYP',
            'Syyrian punta',
        ],
        'SZL' => [
            'SZL',
            'Swazimaan lilangeni',
        ],
        'THB' => [
            'THB',
            'Thaimaan baht',
        ],
        'TJR' => [
            'TJR',
            'Tadžikistanin rupla',
        ],
        'TJS' => [
            'TJS',
            'Tadžikistanin somoni',
        ],
        'TMM' => [
            'TMM',
            'Turkmenistanin manat (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'Turkmenistanin manat',
        ],
        'TND' => [
            'TND',
            'Tunisian dinaari',
        ],
        'TOP' => [
            'TOP',
            'Tongan pa’anga',
        ],
        'TPE' => [
            'TPE',
            'Timorin escudo',
        ],
        'TRL' => [
            'TRL',
            'Turkin liira (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'Turkin liira',
        ],
        'TTD' => [
            'TTD',
            'Trinidadin ja Tobagon dollari',
        ],
        'TWD' => [
            'TWD',
            'Taiwanin uusi dollari',
        ],
        'TZS' => [
            'TZS',
            'Tansanian šillinki',
        ],
        'UAH' => [
            'UAH',
            'Ukrainan hryvnia',
        ],
        'UAK' => [
            'UAK',
            'Ukrainan karbovanetz',
        ],
        'UGS' => [
            'UGS',
            'Ugandan šillinki (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'Ugandan šillinki',
        ],
        'USD' => [
            '$',
            'Yhdysvaltain dollari',
        ],
        'USN' => [
            'USN',
            'Yhdysvaltain dollari (seuraava päivä)',
        ],
        'USS' => [
            'USS',
            'Yhdysvaltain dollari (sama päivä)',
        ],
        'UYI' => [
            'UYI',
            'Uruguayn peso en unidades indexadas',
        ],
        'UYP' => [
            'UYP',
            'Uruguayn peso (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'Uruguayn peso',
        ],
        'UYW' => [
            'UYW',
            'Uruguayn nimellinen palkkaindeksiyksikkö',
        ],
        'UZS' => [
            'UZS',
            'Uzbekistanin som',
        ],
        'VEB' => [
            'VEB',
            'Venezuelan bolívar (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'Venezuelan bolívar (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Venezuelan suvereeni bolívar',
        ],
        'VND' => [
            'VND',
            'Vietnamin dong',
        ],
        'VNN' => [
            'VNN',
            'Vietnamin dong (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'Vanuatun vatu',
        ],
        'WST' => [
            'WST',
            'Samoan tala',
        ],
        'XAF' => [
            'FCFA',
            'CFA-frangi BEAC',
        ],
        'XCD' => [
            'XCD',
            'Itä-Karibian dollari',
        ],
        'XCG' => [
            'Cg.',
            'Karibian guldeni',
        ],
        'XEU' => [
            'XEU',
            'Euroopan valuuttayksikkö (ECU)',
        ],
        'XFO' => [
            'XFO',
            'Ranskan kultafrangi',
        ],
        'XFU' => [
            'XFU',
            'Ranskan UIC-frangi',
        ],
        'XOF' => [
            'F CFA',
            'CFA-frangi BCEAO',
        ],
        'XPF' => [
            'XPF',
            'CFP-frangi',
        ],
        'XRE' => [
            'XRE',
            'RINET-rahastot',
        ],
        'YDD' => [
            'YDD',
            'Jemenin dinaari',
        ],
        'YER' => [
            'YER',
            'Jemenin rial',
        ],
        'YUD' => [
            'YUD',
            'Jugoslavian kova dinaari (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'Jugoslavian uusi dinaari (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'Jugoslavian vaihdettava dinaari (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'Jugoslavian uudistettu dinaari (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'Etelä-Afrikan rahoitusrandi',
        ],
        'ZAR' => [
            'ZAR',
            'Etelä-Afrikan randi',
        ],
        'ZMK' => [
            'ZMK',
            'Sambian kwacha (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Sambian kwacha',
        ],
        'ZRN' => [
            'ZRN',
            'Zairen uusi zaire (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'Zairen zaire (1971–1993)',
        ],
        'ZWD' => [
            'ZWD',
            'Zimbabwen dollari (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'Zimbabwen kulta',
        ],
        'ZWL' => [
            'ZWL',
            'Zimbabwen dollari (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'Zimbabwen dollari (2008)',
        ],
    ],
];
