<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಅಬಿದ್‌ಜನ್)',
        'Africa/Accra' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಅಕ್ರಾ)',
        'Africa/Addis_Ababa' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಆಡಿಸ್ ಅಬಾಬಾ)',
        'Africa/Algiers' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಅಲ್ಜೀರ್ಸ್)',
        'Africa/Asmera' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಅಸ್ಮಾರಾ)',
        'Africa/Asmara' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಅಸ್ಮಾರಾ)',
        'Africa/Bamako' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಬಮಾಕೊ)',
        'Africa/Bangui' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಬಾಂಗಿ)',
        'Africa/Banjul' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಬಂಜುಲ್)',
        'Africa/Bissau' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಬಿಸ್ಸಾವ್)',
        'Africa/Blantyre' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಬ್ಲ್ಯಾಂಟೈರ್)',
        'Africa/Brazzaville' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಬ್ರೆಜಾವೀಲ್)',
        'Africa/Bujumbura' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಬುಜುಂಬುರಾ)',
        'Africa/Cairo' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕೈರೋ)',
        'Africa/Casablanca' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕ್ಯಾಸಾಬ್ಲಾಂಕಾ)',
        'Africa/Ceuta' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸೆಯುಟಾ)',
        'Africa/Conakry' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಕೊನಾಕ್ರಿ)',
        'Africa/Dakar' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಡಾಕರ್)',
        'Africa/Dar_es_Salaam' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಡಾರ್ ಎಸ್ ಸಲಾಮ್)',
        'Africa/Djibouti' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಜಿಬೂಟಿ)',
        'Africa/Douala' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ದೌಲಾ)',
        'Africa/El_Aaiun' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಎಲ್ ಔನ್)',
        'Africa/Freetown' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಫ್ರೀಟೌನ್)',
        'Africa/Gaborone' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಗ್ಯಾಬರೋನೆ)',
        'Africa/Harare' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಹರಾರೆ)',
        'Africa/Johannesburg' => 'ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ ಪ್ರಮಾಣಿತ ಸಮಯ (ಜೋಹಾನ್ಸ್‌ಬರ್ಗ್)',
        'Africa/Juba' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಜುಬಾ)',
        'Africa/Kampala' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಕಂಪಾಲಾ)',
        'Africa/Khartoum' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಖರ್ಟೋಮ್)',
        'Africa/Kigali' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಕಿಗಾಲಿ)',
        'Africa/Kinshasa' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಕಿನ್ಷಾಸಾ)',
        'Africa/Lagos' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಲಾಗೋಸ್)',
        'Africa/Libreville' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಲಿಬ್ರೆವೀಲ್)',
        'Africa/Lome' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಲೋಮ್)',
        'Africa/Luanda' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಲುವಾಂಡಾ)',
        'Africa/Lubumbashi' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಲುಬುಂಬಾಶಿ)',
        'Africa/Lusaka' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಲುಸಾಕಾ)',
        'Africa/Malabo' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಮಲಾಬೋ)',
        'Africa/Maputo' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ಮ್ಯಾಪುಟೊ)',
        'Africa/Maseru' => 'ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ ಪ್ರಮಾಣಿತ ಸಮಯ (ಮಸೇರು)',
        'Africa/Mbabane' => 'ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ ಪ್ರಮಾಣಿತ ಸಮಯ (ಅಂಬಬಾನೆ)',
        'Africa/Mogadishu' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಮೊಗಾದಿಶು)',
        'Africa/Monrovia' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಮೊನ್ರೋವಿಯಾ)',
        'Africa/Nairobi' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ನೈರೋಬಿ)',
        'Africa/Ndjamena' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಡ್ಜಮೇನಾ)',
        'Africa/Niamey' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ನಿಯಾಮೆ)',
        'Africa/Nouakchott' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ನೌಕ್‌ಚೋಟ್ಟ್)',
        'Africa/Ouagadougou' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಔಗಾಡೋಗು)',
        'Africa/Porto-Novo' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ (ಪೋರ್ಟೋ-ನೋವೋ)',
        'Africa/Sao_Tome' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಸಾವ್ ಟೊಮಿ)',
        'Africa/Tripoli' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಟ್ರೈಪೋಲಿ)',
        'Africa/Tunis' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಟುನೀಸ್)',
        'Africa/Windhoek' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ (ವಿಂಡ್ಹೋಕ್)',
        'America/Adak' => 'ಹವಾಯಿ-ಅಲ್ಯುಟಿಯನ್ ಸಮಯ (ಅಡಕ್‌‌)',
        'America/Anchorage' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ಆಂಕರೋಜ್)',
        'America/Anguilla' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಆಂಗ್ವಿಲ್ಲಾ)',
        'America/Antigua' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಆಂಟಿಗುವಾ)',
        'America/Araguaina' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಅರಾಗುಯಾನಾ)',
        'America/Argentina/La_Rioja' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಲಾ ರಿಯೋಜಾ)',
        'America/Argentina/Rio_Gallegos' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ರಿಯೋ ಗಲ್ಲೆಗೊಸ್)',
        'America/Argentina/Salta' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಸಾಲ್ಟಾ)',
        'America/Argentina/San_Juan' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಸ್ಯಾನ್ ಜುವಾನ್)',
        'America/Argentina/San_Luis' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಸ್ಯಾನ್ ಲೂಯೀಸ್)',
        'America/Argentina/Tucuman' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಟುಕುಮಾನ್)',
        'America/Argentina/Ushuaia' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಉಶ್ವಾಯ)',
        'America/Aruba' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಅರುಬಾ)',
        'America/Asuncion' => 'ಪರಾಗ್ವೇ ಸಮಯ (ಅಸುನ್ಸಿಯಾನ್)',
        'America/Bahia' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಬಹೀಯಾ)',
        'America/Bahia_Banderas' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಬಾಹಿಯಾ ಬಂಡೇರಾಸ್)',
        'America/Barbados' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಬಾರ್ಬಡೋಸ್)',
        'America/Belem' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಬೇಲೆಂ)',
        'America/Belize' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಬೆಲೀಜ್)',
        'America/Blanc-Sablon' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಬ್ಲಾಂಕ್-ಸಾಬ್ಲನ್)',
        'America/Boa_Vista' => 'ಅಮೆಜಾನ್ ಸಮಯ (ಬೋವಾ ವಿಸ್ಟ)',
        'America/Bogota' => 'ಕೊಲಂಬಿಯಾ ಸಮಯ (ಬೊಗೋಟ)',
        'America/Boise' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಬ್ವಾಸಿ)',
        'America/Buenos_Aires' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಬ್ಯೂನಸ್ ಐರಿಸ್)',
        'America/Argentina/Buenos_Aires' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಬ್ಯೂನಸ್ ಐರಿಸ್)',
        'America/Cambridge_Bay' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಕೇಮ್‌ಬ್ರಿಡ್ಜ್ ಬೇ)',
        'America/Campo_Grande' => 'ಅಮೆಜಾನ್ ಸಮಯ (ಕಾಂಪೊ ಗ್ರಾಂಡೆ)',
        'America/Cancun' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಕ್ಯಾಂಕನ್)',
        'America/Caracas' => 'ವೆನಿಜುವೆಲಾ ಸಮಯ (ಕ್ಯಾರಕಾಸ್)',
        'America/Catamarca' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಕಟಮಾರ್ಕ)',
        'America/Argentina/Catamarca' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಕಟಮಾರ್ಕ)',
        'America/Cayenne' => 'ಫ್ರೆಂಚ್ ಗಯಾನಾ ಸಮಯ (ಕೆಯೆನಿ)',
        'America/Cayman' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಕೇಮನ್)',
        'America/Chicago' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಚಿಕಾಗೋ)',
        'America/Chihuahua' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಚಿವಾವ)',
        'America/Ciudad_Juarez' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಸಿಯುಡಾಡ್ ವಾರೆಝ್)',
        'America/Coral_Harbour' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಅಟಿಕೊಕಾನ್)',
        'America/Atikokan' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಅಟಿಕೊಕಾನ್)',
        'America/Cordoba' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಕೊರ್ಡೊಬಾ)',
        'America/Argentina/Cordoba' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಕೊರ್ಡೊಬಾ)',
        'America/Costa_Rica' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಕೋಸ್ಟಾ ರಿಕಾ)',
        'America/Coyhaique' => 'ಚಿಲಿ ಸಮಯ (ಕೊಯಯ್ಕಿ)',
        'America/Creston' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಕ್ರೆಸ್ಟನ್)',
        'America/Cuiaba' => 'ಅಮೆಜಾನ್ ಸಮಯ (ಕ್ಯೂಇಬಾ)',
        'America/Curacao' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಕುರಾಕಾವ್)',
        'America/Danmarkshavn' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಡನ್‌ಮಾರ್ಕ್‌ಶ್ವಾನ್)',
        'America/Dawson' => 'ಯುಕಾನ್ ಸಮಯ (ಡಾಸನ್)',
        'America/Dawson_Creek' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಡಾಸನ್ ಕ್ರೀಕ್)',
        'America/Denver' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಡೆನ್ವರ್)',
        'America/Detroit' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಡೆಟ್ರಾಯ್ಟ್)',
        'America/Dominica' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಡೊಮಿನಿಕಾ)',
        'America/Edmonton' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಎಡ್ಮಂಟನ್‌)',
        'America/Eirunepe' => 'ಏಕರ್ ಸಮಯ (ಇರುನಿಪೆ)',
        'America/El_Salvador' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಎಲ್ ಸಾಲ್ವಡೋರ್)',
        'America/Fort_Nelson' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಫೋರ್ಟ್ ನೆಲ್ಸನ್)',
        'America/Fortaleza' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಫೊರ್ಟಲೆಜಾ)',
        'America/Glace_Bay' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಗ್ಲೇಸ್ ಬೇ)',
        'America/Godthab' => 'ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ನೂಕ್)',
        'America/Nuuk' => 'ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ನೂಕ್)',
        'America/Goose_Bay' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಗೂಸ್ ಬೇ)',
        'America/Grand_Turk' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಗ್ರ್ಯಾಂಡ್ ಟರ್ಕ್)',
        'America/Grenada' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಗ್ರೆನಾಡ)',
        'America/Guadeloupe' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಗ್ವಾಡೆಲೋಪ್)',
        'America/Guatemala' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಗ್ವಾಟೆಮಾಲಾ)',
        'America/Guayaquil' => 'ಈಕ್ವೆಡಾರ್ ಸಮಯ (ಗುಯಾಕ್ವಿಲ್)',
        'America/Guyana' => 'ಗಯಾನಾ ಸಮಯ',
        'America/Halifax' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಹ್ಯಾಲಿಫೆಕ್ಸ್)',
        'America/Havana' => 'ಕ್ಯೂಬಾ ಸಮಯ (ಹವಾನಾ)',
        'America/Hermosillo' => 'ಮೆಕ್ಸಿಕನ್ ಪೆಸಿಫಿಕ್ ಸಮಯ (ಹರ್ಮೊಸಿಲ್ಲೋ)',
        'America/Indiana/Knox' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ನಾಕ್ಸ್, ಇಂಡಿಯಾನಾ)',
        'America/Indiana/Marengo' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಮರೆಂಗೊ, ಇಂಡಿಯಾನಾ)',
        'America/Indiana/Petersburg' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಪೀಟರ್ಸ್‌ಬರ್ಗ್, ಇಂಡಿಯಾನಾ)',
        'America/Indiana/Tell_City' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಟೆಲ್ ಸಿಟಿ, ಇಂಡಿಯಾನಾ)',
        'America/Indiana/Vevay' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ವೇವಾಯ್, ಇಂಡಿಯಾನಾ)',
        'America/Indiana/Vincennes' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ವಿನ್‌ಸೆನ್ನೀಸ್, ಇಂಡಿಯಾನಾ)',
        'America/Indiana/Winamac' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ವಿನಾಮ್ಯಾಕ್, ಇಂಡಿಯಾನಾ)',
        'America/Indianapolis' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಇಂಡಿಯಾನಾಪೊಲಿಸ್)',
        'America/Indiana/Indianapolis' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಇಂಡಿಯಾನಾಪೊಲಿಸ್)',
        'America/Inuvik' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಇನುವಿಕ್)',
        'America/Iqaluit' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಈಕ್ವಾಲಿಟ್)',
        'America/Jamaica' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಜಮೈಕಾ)',
        'America/Jujuy' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಜುಜೈ)',
        'America/Argentina/Jujuy' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಜುಜೈ)',
        'America/Juneau' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ಜುನೇವ್)',
        'America/Kentucky/Monticello' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಮೊಂಟಿಸೆಲ್ಲೋ, ಕೆಂಟುಕಿ)',
        'America/Kralendijk' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಕ್ರೆಲೆಂಡಿಜ್ಕ್)',
        'America/La_Paz' => 'ಬೊಲಿವಿಯಾ ಸಮಯ (ಲಾ ಪೆಜ್)',
        'America/Lima' => 'ಪೆರು ಸಮಯ (ಲಿಮಾ)',
        'America/Los_Angeles' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೆಸಿಫಿಕ್ ಸಮಯ (ಲಾಸ್ ಏಂಜಲೀಸ್)',
        'America/Louisville' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಲೂಯೀಸ್‌ವಿಲ್ಲೆ)',
        'America/Kentucky/Louisville' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಲೂಯೀಸ್‌ವಿಲ್ಲೆ)',
        'America/Lower_Princes' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಲೋವರ್ ಪ್ರಿನ್ಸಸ್ ಕ್ವಾರ್ಟರ್)',
        'America/Maceio' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಮೆಸೀಯೊ)',
        'America/Managua' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮನಾಗುವಾ)',
        'America/Manaus' => 'ಅಮೆಜಾನ್ ಸಮಯ (ಮನಾವ್ಸ್)',
        'America/Marigot' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಮರಿಗೊ)',
        'America/Martinique' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಮಾರ್ಟಿನಿಕ್)',
        'America/Matamoros' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮಟಾಮೋರಸ್)',
        'America/Mazatlan' => 'ಮೆಕ್ಸಿಕನ್ ಪೆಸಿಫಿಕ್ ಸಮಯ (ಮಜಟ್ಲಾನ್)',
        'America/Mendoza' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಮೆಂಡೊಜಾ)',
        'America/Argentina/Mendoza' => 'ಅರ್ಜೆಂಟೀನಾ ಸಮಯ (ಮೆಂಡೊಜಾ)',
        'America/Menominee' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮೆನೊಮಿನೀ)',
        'America/Merida' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮೆರಿದಾ)',
        'America/Metlakatla' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ಮೆಟ್ಲಾಕಾಟ್ಲಾ)',
        'America/Mexico_City' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮೆಕ್ಸಿಕೋ ನಗರ)',
        'America/Miquelon' => 'ಸೇಂಟ್ ಪಿಯರ್ ಮತ್ತು ಮಿಕ್ವೆಲನ್ ಸಮಯ (ಮಿಕೆಲಾನ್)',
        'America/Moncton' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಮಾಂಕ್ಟನ್)',
        'America/Monterrey' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಮಾಂಟೆರ್ರಿ)',
        'America/Montevideo' => 'ಉರುಗ್ವೇ ಸಮಯ (ಮಾಂಟಿವೀಡಿಯೊ)',
        'America/Montserrat' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಮಾಂಟ್‌ಸೆರೇಟ್)',
        'America/Nassau' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ನಸ್ಸೌವ್)',
        'America/New_York' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ನ್ಯೂಯಾರ್ಕ್)',
        'America/Nome' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ನೋಮ್)',
        'America/Noronha' => 'ಫೆರ್ನಾಂಡೋ ಡೆ ನೊರೊನ್ಹಾ ಸಮಯ',
        'America/North_Dakota/Beulah' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಬ್ಯೂಲಾ, ಉತ್ತರ ಡಕೊಟ)',
        'America/North_Dakota/Center' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಸೆಂಟರ್, ಉತ್ತರ ಡಕೊಟ)',
        'America/North_Dakota/New_Salem' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ನ್ಯೂ ಸಲೇಂ, ಉತ್ತರ ಡಕೊಟ)',
        'America/Ojinaga' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಓಜಿನಾಗಾ)',
        'America/Panama' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಪನಾಮಾ)',
        'America/Paramaribo' => 'ಸುರಿನೇಮ್ ಸಮಯ (ಪರಮಾರಿಬೋ)',
        'America/Phoenix' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ (ಫಿನಿಕ್ಸ್)',
        'America/Port-au-Prince' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಪೋರ್ಟ್-ಒ-ಪ್ರಿನ್ಸ್)',
        'America/Port_of_Spain' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಪೋರ್ಟ್ ಆಫ್ ಸ್ಪೇನ್)',
        'America/Porto_Velho' => 'ಅಮೆಜಾನ್ ಸಮಯ (ಪೋರ್ಟೊ ವೆಲ್ಹೋ)',
        'America/Puerto_Rico' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಪ್ಯುರ್ಟೋ ರಿಕೊ)',
        'America/Punta_Arenas' => 'ಚಿಲಿ ಸಮಯ (ಪುಂತಾ ಅರೇನಾಸ್)',
        'America/Rankin_Inlet' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ರಾಂಕಿನ್ ಇನ್‌ಲೆಟ್)',
        'America/Recife' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ರೆಸಿಫಿ)',
        'America/Regina' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ರೆಜಿನಾ)',
        'America/Resolute' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ರೆಸೊಲ್ಯೂಟ್)',
        'America/Rio_Branco' => 'ಏಕರ್ ಸಮಯ (ರಿಯೋ ಬ್ರ್ಯಾಂಕೊ)',
        'America/Santarem' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಸಾಂಟರೆಮ್)',
        'America/Santiago' => 'ಚಿಲಿ ಸಮಯ (ಸ್ಯಾಂಟಿಯಾಗೊ)',
        'America/Santo_Domingo' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸ್ಯಾಂಟೋ ಡೊಮಿಂಗೊ)',
        'America/Sao_Paulo' => 'ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ (ಸಾವ್ ಪಾಲೊ)',
        'America/Scoresbysund' => 'ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ಇಟ್ಟೊಕ್ಕೊರ್ಟೂಮಿಯೈಟ್)',
        'America/Sitka' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ಸಿತ್ಕಾ)',
        'America/St_Barthelemy' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ಬಾರ್ತೆಲೆಮಿ)',
        'America/St_Johns' => 'ನ್ಯೂಫೌಂಡ್‌ಲ್ಯಾಂಡ್ ಸಮಯ (ಸೇಂಟ್ ಜಾನ್ಸ್)',
        'America/St_Kitts' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ಕಿಟ್ಸ್)',
        'America/St_Lucia' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ಲೂಸಿಯಾ)',
        'America/St_Thomas' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ಥಾಮಸ್)',
        'America/St_Vincent' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಸೇಂಟ್ ವಿನ್ಸೆಂಟ್)',
        'America/Swift_Current' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ಸ್ವಿಫ್ಟ್ ಕರೆಂಟ್)',
        'America/Tegucigalpa' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ತೆಗುಸಿಗಲ್ಪಾ)',
        'America/Thule' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಥೂಲೆ)',
        'America/Tijuana' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೆಸಿಫಿಕ್ ಸಮಯ (ತಿಜ್ವಾನಾ)',
        'America/Toronto' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ (ಟೊರೊಂಟೋ)',
        'America/Tortola' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಟಾರ್ಟೊಲಾ)',
        'America/Vancouver' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಪೆಸಿಫಿಕ್ ಸಮಯ (ವ್ಯಾಂಕೊವರ್‌)',
        'America/Whitehorse' => 'ಯುಕಾನ್ ಸಮಯ (ವೈಟ್‌ಹಾರ್ಸ್)',
        'America/Winnipeg' => 'ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ (ವಿನ್ನಿಪೆಗ್)',
        'America/Yakutat' => 'ಅಲಾಸ್ಕಾ ಸಮಯ (ಯಾಕುಟಾಟ್)',
        'Antarctica/Casey' => 'ಪಶ್ಚಿಮ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಕೇಸಿ)',
        'Antarctica/Davis' => 'ಡೇವಿಸ್ ಸಮಯ (ಡೇವೀಸ್)',
        'Antarctica/DumontDUrville' => 'ಡುಮಂಟ್-ಡಿ ಉರ್ವಿಲೆ ಸಮಯ',
        'Antarctica/Macquarie' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಮ್ಯಾಕ್ವೆರಿ)',
        'Antarctica/Mawson' => 'ಮಾವ್‌ಸನ್ ಸಮಯ (ಮಾವ್ಸನ್)',
        'Antarctica/McMurdo' => 'ನ್ಯೂಜಿಲ್ಯಾಂಡ್ ಸಮಯ (ಮ್ಯಾಕ್‍ಮುರ್ಡೊ)',
        'Antarctica/Palmer' => 'ಚಿಲಿ ಸಮಯ (ಪಾಲ್ಮರ್)',
        'Antarctica/Rothera' => 'ರೊತೇರಾ ಸಮಯ (ರೊಥೇರಾ)',
        'Antarctica/Syowa' => 'ಸ್ಯೊವಾ ಸಮಯ (ಸ್ಯೋವಾ)',
        'Antarctica/Troll' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಟ್ರಾಲ್)',
        'Antarctica/Vostok' => 'ವೋಸ್ಟೊಕ್ ಸಮಯ (ವೋಸ್ಟೋಕ್)',
        'Arctic/Longyearbyen' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಲಾಂಗ್ಯೀರ್ಬೆನ್)',
        'Asia/Aden' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ಏಡನ್)',
        'Asia/Almaty' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಅಲ್ಮಾಟಿ)',
        'Asia/Amman' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಅಮ್ಮಾನ್)',
        'Asia/Anadyr' => 'ಪೆತ್ರೋಪಾವ್ಲೋಸ್ಕ್‌‌-ಕಮ್ಚತ್ಸ್‌ಕೀ ಸಮಯ (ಅನದ್ಯರ್)',
        'Asia/Aqtau' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಅಕ್ತಾವ್)',
        'Asia/Aqtobe' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಅಕ್ಟೋಬೆ)',
        'Asia/Ashgabat' => 'ತುರ್ಕ್‌ಮೇನಿಸ್ತಾನ್ ಸಮಯ (ಅಶ್ಗಬಾತ್)',
        'Asia/Atyrau' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಅಟ್ರಾವ್)',
        'Asia/Baghdad' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ಬಾಗ್ದಾದ್)',
        'Asia/Bahrain' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ಬಹ್ರೇನ್)',
        'Asia/Baku' => 'ಅಜರ್ಬೈಜಾನ್ ಸಮಯ (ಬಕು)',
        'Asia/Bangkok' => 'ಇಂಡೊಚೈನಾ ಸಮಯ (ಬ್ಯಾಂಕಾಕ್)',
        'Asia/Barnaul' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ಬಾರ್ನೌಲ್)',
        'Asia/Beirut' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬೀರಟ್)',
        'Asia/Bishkek' => 'ಕಿರ್ಗಿಸ್ತಾನ್ ಸಮಯ (ಬಿಶ್ಕೆಕ್)',
        'Asia/Brunei' => 'ಬ್ರೂನಿ ದಾರುಸಲೆಮ್ ಸಮಯ',
        'Asia/Calcutta' => 'ಭಾರತೀಯ ಪ್ರಮಾಣಿತ ಸಮಯ (ಕೊಲ್ಕತ್ತಾ)',
        'Asia/Kolkata' => 'ಭಾರತೀಯ ಪ್ರಮಾಣಿತ ಸಮಯ (ಕೊಲ್ಕತ್ತಾ)',
        'Asia/Chita' => 'ಯಾಕುಟ್ಸಕ್ ಸಮಯ (ಚಿಟ)',
        'Asia/Colombo' => 'ಭಾರತೀಯ ಪ್ರಮಾಣಿತ ಸಮಯ (ಕೊಲಂಬೊ)',
        'Asia/Damascus' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಡಮಾಸ್ಕಸ್)',
        'Asia/Dhaka' => 'ಬಾಂಗ್ಲಾದೇಶ ಸಮಯ (ಢಾಕಾ)',
        'Asia/Dili' => 'ಪೂರ್ವ ಟಿಮೋರ್ ಸಮಯ (ದಿಲಿ)',
        'Asia/Dubai' => 'ಗಲ್ಫ್ ಪ್ರಮಾಣಿತ ಸಮಯ (ದುಬೈ)',
        'Asia/Dushanbe' => 'ತಝಕಿಸ್ತಾನ್ ಸಮಯ (ದುಶಾಂಬೆ)',
        'Asia/Famagusta' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಫಮಾಗುಸ್ತಾ)',
        'Asia/Gaza' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಗಾಜಾ)',
        'Asia/Hebron' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಹೆಬ್ರಾನ್)',
        'Asia/Hong_Kong' => 'ಹಾಂಗ್ ಕಾಂಗ್ ಸಮಯ',
        'Asia/Hovd' => 'ಹವ್ಡ್ ಸಮಯ (ಹೋವ್ಡ್)',
        'Asia/Irkutsk' => 'ಇರ್‌ಕುಟಸ್ಕ್ ಸಮಯ (ಇರಕುಟ್ಸ್ಕ್)',
        'Asia/Jakarta' => 'ಪಶ್ಚಿಮ ಇಂಡೋನೇಷಿಯ ಸಮಯ (ಜಕಾರ್ತಾ)',
        'Asia/Jayapura' => 'ಪೂರ್ವ ಇಂಡೋನೇಷಿಯಾ ಸಮಯ (ಜಯಪುರ)',
        'Asia/Jerusalem' => 'ಇಸ್ರೇಲ್ ಸಮಯ (ಜೆರುಸಲೆಮ್)',
        'Asia/Kabul' => 'ಅಫಘಾನಿಸ್ತಾನ ಸಮಯ (ಕಾಬೂಲ್)',
        'Asia/Kamchatka' => 'ಪೆತ್ರೋಪಾವ್ಲೋಸ್ಕ್‌‌-ಕಮ್ಚತ್ಸ್‌ಕೀ ಸಮಯ (ಕಂಚಟ್ಕ್)',
        'Asia/Karachi' => 'ಪಾಕಿಸ್ತಾನ ಸಮಯ (ಕರಾಚಿ)',
        'Asia/Katmandu' => 'ನೇಪಾಳ ಸಮಯ (ಕಠ್ಮಂಡು)',
        'Asia/Kathmandu' => 'ನೇಪಾಳ ಸಮಯ (ಕಠ್ಮಂಡು)',
        'Asia/Khandyga' => 'ಯಾಕುಟ್ಸಕ್ ಸಮಯ (ಖಂಡ್ಯಾಗಾ)',
        'Asia/Krasnoyarsk' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ಕ್ರಾಸ್ನೊಯಾರ್ಸ್ಕ್)',
        'Asia/Kuala_Lumpur' => 'ಮಲೇಷಿಯಾ ಸಮಯ (ಕೌಲಾ ಲಂಪುರ)',
        'Asia/Kuching' => 'ಮಲೇಷಿಯಾ ಸಮಯ (ಕುಚಿಂಗ್)',
        'Asia/Kuwait' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ಕುವೈತ್)',
        'Asia/Macau' => 'ಚೀನಾ ಸಮಯ (ಮಕಾವು)',
        'Asia/Magadan' => 'ಮಗಡಾನ್ ಸಮಯ (ಮಗದನ್‌)',
        'Asia/Makassar' => 'ಮಧ್ಯ ಇಂಡೋನೇಷಿಯಾ ಸಮಯ (ಮೆಕಾಸ್ಸರ್)',
        'Asia/Manila' => 'ಫಿಲಿಫೈನ್ ಸಮಯ (ಮನಿಲಾ)',
        'Asia/Muscat' => 'ಗಲ್ಫ್ ಪ್ರಮಾಣಿತ ಸಮಯ (ಮಸ್ಕಟ್)',
        'Asia/Nicosia' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ನಿಕೋಸಿಯಾ)',
        'Asia/Novokuznetsk' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ನೋವೋಕುಜೆ)',
        'Asia/Novosibirsk' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ನೊವೋಸಿಬಿಸ್ಕ್)',
        'Asia/Omsk' => 'ಒಮಾಸ್ಕ್ ಸಮಯ (ಒಮ್ಸ್ಕ್)',
        'Asia/Oral' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಒರಲ್)',
        'Asia/Phnom_Penh' => 'ಇಂಡೊಚೈನಾ ಸಮಯ (ನೋಮ್ ಪೆನ್)',
        'Asia/Pontianak' => 'ಪಶ್ಚಿಮ ಇಂಡೋನೇಷಿಯ ಸಮಯ (ಪೊಂಟಿಯಾನಕ್)',
        'Asia/Pyongyang' => 'ಕೊರಿಯನ್ ಸಮಯ (ಪ್ಯೊಂಗ್‍ಯಾಂಗ್)',
        'Asia/Qatar' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ಖತಾರ್)',
        'Asia/Qostanay' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಕೊಸ್ಟನಯ್)',
        'Asia/Qyzylorda' => 'ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ (ಕಿಜೈಲೋರ್ದ)',
        'Asia/Rangoon' => 'ಮ್ಯಾನ್ಮಾರ್ ಸಮಯ (ಯಾಂಗೊನ್)',
        'Asia/Yangon' => 'ಮ್ಯಾನ್ಮಾರ್ ಸಮಯ (ಯಾಂಗೊನ್)',
        'Asia/Riyadh' => 'ಅರೇಬಿಯನ್ ಸಮಯ (ರಿಯಾದ್)',
        'Asia/Saigon' => 'ಇಂಡೊಚೈನಾ ಸಮಯ (ಹೊ ಚಿ ಮಿನ್ ಸಿಟಿ)',
        'Asia/Ho_Chi_Minh' => 'ಇಂಡೊಚೈನಾ ಸಮಯ (ಹೊ ಚಿ ಮಿನ್ ಸಿಟಿ)',
        'Asia/Sakhalin' => 'ಮಗಡಾನ್ ಸಮಯ (ಸಖಾಲಿನ್)',
        'Asia/Samarkand' => 'ಉಜ್ಬೇಕಿಸ್ತಾನ್ ಸಮಯ (ಸಮರಖಂಡ)',
        'Asia/Seoul' => 'ಕೊರಿಯನ್ ಸಮಯ (ಸಿಯೋಲ್)',
        'Asia/Shanghai' => 'ಚೀನಾ ಸಮಯ (ಶಾಂಘೈ)',
        'Asia/Singapore' => 'ಸಿಂಗಪುರ್ ಪ್ರಮಾಣಿತ ಸಮಯ',
        'Asia/Srednekolymsk' => 'ಮಗಡಾನ್ ಸಮಯ (ಸ್ರೇದ್ನೇಕೋಲೀಮಸ್ಕ)',
        'Asia/Taipei' => 'ತೈಪೆ ಸಮಯ',
        'Asia/Tashkent' => 'ಉಜ್ಬೇಕಿಸ್ತಾನ್ ಸಮಯ (ತಾಶ್ಕೆಂಟ್)',
        'Asia/Tbilisi' => 'ಜಾರ್ಜಿಯಾ ಸಮಯ (ಟಿಬಿಲಿಸಿ)',
        'Asia/Tehran' => 'ಇರಾನ್ ಸಮಯ (ತೆಹ್ರಾನ್)',
        'Asia/Thimphu' => 'ಭೂತಾನ್ ಸಮಯ (ಥಿಂಪು)',
        'Asia/Tokyo' => 'ಜಪಾನ್ ಸಮಯ (ಟೋಕಿಯೊ)',
        'Asia/Tomsk' => 'ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ (ಟೋಮ್‌ಸ್ಕ್)',
        'Asia/Ulaanbaatar' => 'ಉಲಾನ್ ಬತೊರ್ ಸಮಯ',
        'Asia/Urumqi' => 'ಚೀನಾ ಸಮಯ (ಉರುಮ್‍ಕಿ)',
        'Asia/Ust-Nera' => 'ವ್ಲಾಡಿವೋಸ್ಟೋಕ್ ಸಮಯ (ಉಸ್ತ್-ನೆರಾ)',
        'Asia/Vientiane' => 'ಇಂಡೊಚೈನಾ ಸಮಯ (ವಿಯೆಂಟಿಯಾನ್)',
        'Asia/Vladivostok' => 'ವ್ಲಾಡಿವೋಸ್ಟೋಕ್ ಸಮಯ (ವ್ಲಾದಿವೊಸ್ಟಾಕ್‌)',
        'Asia/Yakutsk' => 'ಯಾಕುಟ್ಸಕ್ ಸಮಯ (ಯಕುಟ್ಸ್ಕ್)',
        'Asia/Yekaterinburg' => 'ಯೇಕಟರಿನ್‌ಬರ್ಗ್ ಸಮಯ (ಎಕ್ಯಾಟೆರಿನ್ಬರ್ಗ್)',
        'Asia/Yerevan' => 'ಅರ್ಮೇನಿಯ ಸಮಯ (ಯೆರೆವಾನ್)',
        'Atlantic/Azores' => 'ಅಜೋರಸ್ ಸಮಯ (ಅಝೋರಿಸ್)',
        'Atlantic/Bermuda' => 'ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ (ಬರ್ಮುಡಾ)',
        'Atlantic/Canary' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕ್ಯಾನರಿ)',
        'Atlantic/Cape_Verde' => 'ಕೇಪ್ ವರ್ಡ್ ಸಮಯ (ಕೇಪ್ ವೆರ್ಡ್)',
        'Atlantic/Faeroe' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಫ್ಯಾರೊ)',
        'Atlantic/Faroe' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಫ್ಯಾರೊ)',
        'Atlantic/Madeira' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಮೆಡಿರಾ)',
        'Atlantic/Reykjavik' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ರೈಕ್ಜಾವಿಕ್)',
        'Atlantic/South_Georgia' => 'ದಕ್ಷಿಣ ಜಾರ್ಜಿಯಾ ಸಮಯ',
        'Atlantic/St_Helena' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಸೇಂಟ್ ಹೆಲೆನಾ)',
        'Atlantic/Stanley' => 'ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳ ಸಮಯ (ಸ್ಟ್ಯಾನ್ಲಿ)',
        'Australia/Adelaide' => 'ಕೇಂದ್ರ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಅಡಿಲೇಡ್)',
        'Australia/Brisbane' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಬ್ರಿಸ್ಬೇನ್‌)',
        'Australia/Broken_Hill' => 'ಕೇಂದ್ರ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಬ್ರೊಕನ್ ಹಿಲ್)',
        'Australia/Darwin' => 'ಕೇಂದ್ರ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಡಾರ್ವಿನ್)',
        'Australia/Eucla' => 'ಆಸ್ಟ್ರೇಲಿಯಾದ ಕೇಂದ್ರ ಪಶ್ಚಿಮ ಸಮಯ (ಯುಕ್ಲಾ)',
        'Australia/Hobart' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಹೋಬಾರ್ಟ್‌)',
        'Australia/Lindeman' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಲಿಂಡಿಮಾನ್)',
        'Australia/Lord_Howe' => 'ಲಾರ್ಡ್ ಹೋವ್ ಸಮಯ',
        'Australia/Melbourne' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಮೆಲ್ಬರ್ನ್)',
        'Australia/Perth' => 'ಪಶ್ಚಿಮ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಪರ್ಥ್)',
        'Australia/Sydney' => 'ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ (ಸಿಡ್ನಿ)',
        'Etc/GMT' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ',
        'Etc/UTC' => 'ಸಂಘಟಿತ ಸಾರ್ವತ್ರಿಕ ಸಮಯ',
        'Europe/Amsterdam' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಆಮ್‌ಸ್ಟೆರ್‌ಡ್ಯಾಂ)',
        'Europe/Andorra' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಅಂಡೋರಾ)',
        'Europe/Astrakhan' => 'ಸಮರ ಸಮಯ (ಆಸ್ಟ್ರಾಖಾನ್)',
        'Europe/Athens' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಅಥೆನ್ಸ್)',
        'Europe/Belgrade' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬೆಲ್‌ಗ್ರೇಡ್)',
        'Europe/Berlin' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬರ್ಲಿನ್)',
        'Europe/Bratislava' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬ್ರಾಟಿಸ್ಲಾವ)',
        'Europe/Brussels' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬ್ರಸ್ಸೆಲ್ಸ್)',
        'Europe/Bucharest' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬುಕಾರೆಸ್ಟ್)',
        'Europe/Budapest' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬುಡಾಪೆಸ್ಟ್)',
        'Europe/Busingen' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಬುಸಿಂಜೆನ್)',
        'Europe/Chisinau' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಚಿಸಿನಾವ್)',
        'Europe/Copenhagen' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕೋಪೆನ್‌ಹೇಗನ್)',
        'Europe/Dublin' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಡುಬ್ಲಿನ್)',
        'Europe/Gibraltar' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಜಿಬ್ರಾಲ್ಟರ್)',
        'Europe/Guernsey' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಗ್ಯುರ್ನ್‍ಸೆ)',
        'Europe/Helsinki' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಹೆಲ್ಸಿಂಕಿ)',
        'Europe/Isle_of_Man' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಐಲ್ ಆಫ್ ಮ್ಯಾನ್)',
        'Europe/Istanbul' => 'ತುರ್ಕಿಯೆ ಸಮಯ (ಇಸ್ತಾನ್‌ಬುಲ್)',
        'Europe/Jersey' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಜೆರ್ಸಿ)',
        'Europe/Kaliningrad' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕಲಿನಿನ್‌ಗ್ರಾಡ್)',
        'Europe/Kiev' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕಿವ್)',
        'Europe/Kyiv' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಕಿವ್)',
        'Europe/Kirov' => 'ಮಾಸ್ಕೋ ಸಮಯ (ಕಿರಾವ್)',
        'Europe/Lisbon' => 'ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ (ಲಿಸ್ಬನ್)',
        'Europe/Ljubljana' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಲ್ಯೂಬ್ಲ್ಯಾನಾ)',
        'Europe/London' => 'ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ (ಲಂಡನ್)',
        'Europe/Luxembourg' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಲಕ್ಸೆಂಬರ್ಗ್)',
        'Europe/Madrid' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಮ್ಯಾಡ್ರಿಡ್)',
        'Europe/Malta' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಮಾಲ್ಟಾ)',
        'Europe/Mariehamn' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಮರಿಹಮ್ನ್)',
        'Europe/Minsk' => 'ಮಾಸ್ಕೋ ಸಮಯ (ಮಿನ್‌ಸ್ಕ್)',
        'Europe/Monaco' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಮೊನಾಕೊ)',
        'Europe/Moscow' => 'ಮಾಸ್ಕೋ ಸಮಯ',
        'Europe/Oslo' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಓಸ್ಲೋ)',
        'Europe/Paris' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಪ್ಯಾರಿಸ್)',
        'Europe/Podgorica' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಪೊಡ್ಗೊರಿಕ)',
        'Europe/Prague' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಪ್ರಾಗ್ವೆ)',
        'Europe/Riga' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ರಿಗಾ)',
        'Europe/Rome' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ರೋಮ್)',
        'Europe/Samara' => 'ಸಮರ ಸಮಯ',
        'Europe/San_Marino' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸ್ಯಾನ್ ಮರೀನೊ)',
        'Europe/Sarajevo' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸರಯೇವೊ)',
        'Europe/Saratov' => 'ಸಮರ ಸಮಯ (ಸರಾಟೋವ್)',
        'Europe/Simferopol' => 'ಮಾಸ್ಕೋ ಸಮಯ (ಸಿಮ್ಫೆರೋಪೋಲ್)',
        'Europe/Skopje' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸ್ಕಾಪಿಯಾ)',
        'Europe/Sofia' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸೋಫಿಯಾ)',
        'Europe/Stockholm' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಸ್ಟಾಕ್‍ಹೋಮ್)',
        'Europe/Tallinn' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ಟ್ಯಾಲಿನ್)',
        'Europe/Tirane' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಟಿರಾನೆ)',
        'Europe/Ulyanovsk' => 'ಸಮರ ಸಮಯ (ಉಲ್ಯಾನೊವಸ್ಕ್)',
        'Europe/Vaduz' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ವಡೂಜ್)',
        'Europe/Vatican' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ವ್ಯಾಟಿಕನ್)',
        'Europe/Vienna' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ವಿಯೆನ್ನಾ)',
        'Europe/Vilnius' => 'ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ (ವಿಲ್ನಿಯಸ್)',
        'Europe/Volgograd' => 'ಮಾಸ್ಕೋ ಸಮಯ (ವೊಲ್ಗೊಗ್ರಾಡ್)',
        'Europe/Warsaw' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ವಾರ್ಸಾ)',
        'Europe/Zagreb' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಜಾಗ್ರೆಬ್‌)',
        'Europe/Zurich' => 'ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ (ಜ್ಯೂರಿಕ್)',
        'Indian/Antananarivo' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಅಂಟಾನನಾರಿವೊ)',
        'Indian/Chagos' => 'ಹಿಂದೂ ಮಹಾಸಾಗರ ಸಮಯ (ಚಾಗೊಸ್)',
        'Indian/Christmas' => 'ಕ್ರಿಸ್ಮಸ್ ದ್ವೀಪ ಸಮಯ',
        'Indian/Cocos' => 'ಕೋಕೋಸ್ ದ್ವೀಪಗಳ ಸಮಯ (ಕೊಕೋಸ್)',
        'Indian/Comoro' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಕೊಮೋರೊ)',
        'Indian/Kerguelen' => 'ದಕ್ಷಿಣ ಫ್ರೆಂಚ್ ಮತ್ತು ಅಂಟಾರ್ಟಿಕಾ ಸಮಯ (ಕೆರ್ಗ್ಯುಲೆನ್)',
        'Indian/Mahe' => 'ಸೀಷೆಲ್ಸ್ ಸಮಯ (ಮಾಹೆ)',
        'Indian/Maldives' => 'ಮಾಲ್ಡೀವ್ಸ್ ಸಮಯ',
        'Indian/Mauritius' => 'ಮಾರಿಷಸ್ ಸಮಯ',
        'Indian/Mayotte' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ (ಮಯೊಟ್ಟೆ)',
        'Indian/Reunion' => 'ರಿಯೂನಿಯನ್ ಸಮಯ (ರೀಯೂನಿಯನ್)',
        'Pacific/Apia' => 'ಅಪಿಯಾ ಸಮಯ',
        'Pacific/Auckland' => 'ನ್ಯೂಜಿಲ್ಯಾಂಡ್ ಸಮಯ (ಆಕ್ ಲ್ಯಾಂಡ್)',
        'Pacific/Bougainville' => 'ಪಪುವಾ ನ್ಯೂ ಗಿನಿಯಾ ಸಮಯ (ಬೌಗೆನ್‍ವಿಲ್ಲೆ)',
        'Pacific/Chatham' => 'ಚಥಾಮ್ ಸಮಯ',
        'Pacific/Easter' => 'ಈಸ್ಟರ್ ದ್ವೀಪ ಸಮಯ',
        'Pacific/Efate' => 'ವನೌತು ಸಮಯ (ಇಫೇಟ್)',
        'Pacific/Enderbury' => 'ಫಿನಿಕ್ಸ್ ದ್ವೀಪಗಳ ಸಮಯ (ಕ್ಯಾಂಟನ್ ಐಲ್ಯಾಂಡ್)',
        'Pacific/Kanton' => 'ಫಿನಿಕ್ಸ್ ದ್ವೀಪಗಳ ಸಮಯ (ಕ್ಯಾಂಟನ್ ಐಲ್ಯಾಂಡ್)',
        'Pacific/Fakaofo' => 'ಟೊಕೆಲಾವ್ ಸಮಯ (ಫಕೋಫೋ)',
        'Pacific/Fiji' => 'ಫಿಜಿ ಸಮಯ',
        'Pacific/Funafuti' => 'ತುವಾಲು ಸಮಯ (ಫುನಾಫುಟಿ)',
        'Pacific/Galapagos' => 'ಗಾಲಾಪಾಗೋಸ್ ಸಮಯ (ಗಲಾಪಗೋಸ್)',
        'Pacific/Gambier' => 'ಗ್ಯಾಂಬಿಯರ್ ಸಮಯ',
        'Pacific/Guadalcanal' => 'ಸಾಲಮನ್ ದ್ವೀಪಗಳ ಸಮಯ (ಗ್ವಾಡಲ್ಕೆನಾಲ್)',
        'Pacific/Guam' => 'ಚಮೋರೋ ಪ್ರಮಾಣಿತ ಸಮಯ (ಗ್ವಾಮ್)',
        'Pacific/Honolulu' => 'ಹವಾಯಿ-ಅಲ್ಯುಟಿಯನ್ ಪ್ರಮಾಣಿತ ಸಮಯ (ಹೊನಲುಲು)',
        'Pacific/Kiritimati' => 'ಲೈನ್ ದ್ವೀಪಗಳ ಸಮಯ (ಕಿರಿತಿಮತಿ)',
        'Pacific/Kosrae' => 'ಕೊಸರೆ ಸಮಯ (ಕೋಸ್ರೆ)',
        'Pacific/Kwajalein' => 'ಮಾರ್ಷಲ್ ದ್ವೀಪಗಳ ಸಮಯ (ಕ್ವಾಜಲೇನ್)',
        'Pacific/Majuro' => 'ಮಾರ್ಷಲ್ ದ್ವೀಪಗಳ ಸಮಯ (ಮಜುರೊ)',
        'Pacific/Marquesas' => 'ಮಾರ್ಕ್ಯುಸಸ್ ಸಮಯ (ಮಾರ್ಕ್ಯೂಸಸ್)',
        'Pacific/Midway' => 'ಸಮೋವಾ ಸಮಯ (ಮಿಡ್‌ವೇ)',
        'Pacific/Nauru' => 'ನೌರು ಸಮಯ',
        'Pacific/Niue' => 'ನಿಯು ಸಮಯ',
        'Pacific/Norfolk' => 'ನಾರ್ಫೋಕ್ ದ್ವೀಪ ಸಮಯ',
        'Pacific/Noumea' => 'ಹೊಸ ಕ್ಯಾಲೆಡೋನಿಯಾ ಸಮಯ (ನ್ಯೂಮಿಯಾ)',
        'Pacific/Pago_Pago' => 'ಸಮೋವಾ ಸಮಯ (ಪಾಗೊ ಪಾಗೊ)',
        'Pacific/Palau' => 'ಪಾಲಾವ್ ಸಮಯ',
        'Pacific/Pitcairn' => 'ಪಿಟ್‌ಕೈರ್ನ್ ಸಮಯ',
        'Pacific/Ponape' => 'ಪೊನಾಪೆ ಸಮಯ (ಪೋನ್‌ಪೆ)',
        'Pacific/Pohnpei' => 'ಪೊನಾಪೆ ಸಮಯ (ಪೋನ್‌ಪೆ)',
        'Pacific/Port_Moresby' => 'ಪಪುವಾ ನ್ಯೂ ಗಿನಿಯಾ ಸಮಯ (ಪೋರ್ಟ್ ಮೋರಿಸ್‌ಬೈ)',
        'Pacific/Rarotonga' => 'ಕುಕ್ ದ್ವೀಪಗಳ ಸಮಯ (ರರೋಟೋಂಗಾ)',
        'Pacific/Saipan' => 'ಚಮೋರೋ ಪ್ರಮಾಣಿತ ಸಮಯ (ಸೈಪನ್)',
        'Pacific/Tahiti' => 'ತಾಹಿತಿ ಸಮಯ (ತಹಿತಿ)',
        'Pacific/Tarawa' => 'ಗಿಲ್ಬರ್ಟ್ ದ್ವೀಪಗಳ ಸಮಯ (ತರಾವಾ)',
        'Pacific/Tongatapu' => 'ಟೊಂಗಾ ಸಮಯ (ಟೊಂಗಾಟಾಪು)',
        'Pacific/Truk' => 'ಚುಕ್ ಸಮಯ',
        'Pacific/Chuuk' => 'ಚುಕ್ ಸಮಯ',
        'Pacific/Wake' => 'ವೇಕ್ ದ್ವೀಪ ಸಮಯ',
        'Pacific/Wallis' => 'ವ್ಯಾಲೀಸ್ ಮತ್ತು ಫ್ಯುಟುನಾ ಸಮಯ (ವ್ಯಾಲಿಸ್)',
    ],
    'Meta' => [],
];
