<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibia)',
        'af_ZA' => 'afrikaans (Africa de Sud)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amharică',
        'am_ET' => 'amharică (Etiopia)',
        'ar' => 'arabă',
        'ar_001' => 'arabă (Lume)',
        'ar_AE' => 'arabă (Emiratele Arabe Unite)',
        'ar_BH' => 'arabă (Bahrain)',
        'ar_DJ' => 'arabă (Djibouti)',
        'ar_DZ' => 'arabă (Algeria)',
        'ar_EG' => 'arabă (Egipt)',
        'ar_EH' => 'arabă (Sahara Occidentală)',
        'ar_ER' => 'arabă (Eritreea)',
        'ar_IL' => 'arabă (Israel)',
        'ar_IQ' => 'arabă (Irak)',
        'ar_JO' => 'arabă (Iordania)',
        'ar_KM' => 'arabă (Comore)',
        'ar_KW' => 'arabă (Kuweit)',
        'ar_LB' => 'arabă (Liban)',
        'ar_LY' => 'arabă (Libia)',
        'ar_MA' => 'arabă (Maroc)',
        'ar_MR' => 'arabă (Mauritania)',
        'ar_OM' => 'arabă (Oman)',
        'ar_PS' => 'arabă (Teritoriile Palestiniene)',
        'ar_QA' => 'arabă (Qatar)',
        'ar_SA' => 'arabă (Arabia Saudită)',
        'ar_SD' => 'arabă (Sudan)',
        'ar_SO' => 'arabă (Somalia)',
        'ar_SS' => 'arabă (Sudanul de Sud)',
        'ar_SY' => 'arabă (Siria)',
        'ar_TD' => 'arabă (Ciad)',
        'ar_TN' => 'arabă (Tunisia)',
        'ar_YE' => 'arabă (Yemen)',
        'as' => 'asameză',
        'as_IN' => 'asameză (India)',
        'az' => 'azeră',
        'az_AZ' => 'azeră (Azerbaidjan)',
        'az_Cyrl' => 'azeră (chirilică)',
        'az_Cyrl_AZ' => 'azeră (chirilică, Azerbaidjan)',
        'az_Latn' => 'azeră (latină)',
        'az_Latn_AZ' => 'azeră (latină, Azerbaidjan)',
        'ba' => 'bașkiră',
        'ba_RU' => 'bașkiră (Rusia)',
        'be' => 'belarusă',
        'be_BY' => 'belarusă (Belarus)',
        'bg' => 'bulgară',
        'bg_BG' => 'bulgară (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengaleză',
        'bn_BD' => 'bengaleză (Bangladesh)',
        'bn_IN' => 'bengaleză (India)',
        'bo' => 'tibetană',
        'bo_CN' => 'tibetană (China)',
        'bo_IN' => 'tibetană (India)',
        'br' => 'bretonă',
        'br_FR' => 'bretonă (Franța)',
        'bs' => 'bosniacă',
        'bs_BA' => 'bosniacă (Bosnia și Herțegovina)',
        'bs_Cyrl' => 'bosniacă (chirilică)',
        'bs_Cyrl_BA' => 'bosniacă (chirilică, Bosnia și Herțegovina)',
        'bs_Latn' => 'bosniacă (latină)',
        'bs_Latn_BA' => 'bosniacă (latină, Bosnia și Herțegovina)',
        'ca' => 'catalană',
        'ca_AD' => 'catalană (Andorra)',
        'ca_ES' => 'catalană (Spania)',
        'ca_FR' => 'catalană (Franța)',
        'ca_IT' => 'catalană (Italia)',
        'ce' => 'cecenă',
        'ce_RU' => 'cecenă (Rusia)',
        'cs' => 'cehă',
        'cs_CZ' => 'cehă (Cehia)',
        'cv' => 'ciuvașă',
        'cv_RU' => 'ciuvașă (Rusia)',
        'cy' => 'galeză',
        'cy_GB' => 'galeză (Regatul Unit)',
        'da' => 'daneză',
        'da_DK' => 'daneză (Danemarca)',
        'da_GL' => 'daneză (Groenlanda)',
        'de' => 'germană',
        'de_AT' => 'germană (Austria)',
        'de_BE' => 'germană (Belgia)',
        'de_CH' => 'germană (Elveția)',
        'de_DE' => 'germană (Germania)',
        'de_IT' => 'germană (Italia)',
        'de_LI' => 'germană (Liechtenstein)',
        'de_LU' => 'germană (Luxemburg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhutan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'greacă',
        'el_CY' => 'greacă (Cipru)',
        'el_GR' => 'greacă (Grecia)',
        'en' => 'engleză',
        'en_001' => 'engleză (Lume)',
        'en_150' => 'engleză (Europa)',
        'en_AE' => 'engleză (Emiratele Arabe Unite)',
        'en_AG' => 'engleză (Antigua și Barbuda)',
        'en_AI' => 'engleză (Anguilla)',
        'en_AS' => 'engleză (Samoa Americană)',
        'en_AT' => 'engleză (Austria)',
        'en_AU' => 'engleză (Australia)',
        'en_BB' => 'engleză (Barbados)',
        'en_BE' => 'engleză (Belgia)',
        'en_BI' => 'engleză (Burundi)',
        'en_BM' => 'engleză (Bermuda)',
        'en_BS' => 'engleză (Bahamas)',
        'en_BW' => 'engleză (Botswana)',
        'en_BZ' => 'engleză (Belize)',
        'en_CA' => 'engleză (Canada)',
        'en_CC' => 'engleză (Insulele Cocos [Keeling])',
        'en_CH' => 'engleză (Elveția)',
        'en_CK' => 'engleză (Insulele Cook)',
        'en_CM' => 'engleză (Camerun)',
        'en_CX' => 'engleză (Insula Christmas)',
        'en_CY' => 'engleză (Cipru)',
        'en_CZ' => 'engleză (Cehia)',
        'en_DE' => 'engleză (Germania)',
        'en_DK' => 'engleză (Danemarca)',
        'en_DM' => 'engleză (Dominica)',
        'en_EE' => 'engleză (Estonia)',
        'en_ER' => 'engleză (Eritreea)',
        'en_ES' => 'engleză (Spania)',
        'en_FI' => 'engleză (Finlanda)',
        'en_FJ' => 'engleză (Fiji)',
        'en_FK' => 'engleză (Insulele Falkland)',
        'en_FM' => 'engleză (Micronezia)',
        'en_FR' => 'engleză (Franța)',
        'en_GB' => 'engleză (Regatul Unit)',
        'en_GD' => 'engleză (Grenada)',
        'en_GE' => 'engleză (Georgia)',
        'en_GG' => 'engleză (Guernsey)',
        'en_GH' => 'engleză (Ghana)',
        'en_GI' => 'engleză (Gibraltar)',
        'en_GM' => 'engleză (Gambia)',
        'en_GS' => 'engleză (Georgia de Sud și Insulele Sandwich de Sud)',
        'en_GU' => 'engleză (Guam)',
        'en_GY' => 'engleză (Guyana)',
        'en_HK' => 'engleză (R.A.S. Hong Kong, China)',
        'en_HU' => 'engleză (Ungaria)',
        'en_ID' => 'engleză (Indonezia)',
        'en_IE' => 'engleză (Irlanda)',
        'en_IL' => 'engleză (Israel)',
        'en_IM' => 'engleză (Insula Man)',
        'en_IN' => 'engleză (India)',
        'en_IO' => 'engleză (Teritoriul Britanic din Oceanul Indian)',
        'en_IT' => 'engleză (Italia)',
        'en_JE' => 'engleză (Jersey)',
        'en_JM' => 'engleză (Jamaica)',
        'en_JP' => 'engleză (Japonia)',
        'en_KE' => 'engleză (Kenya)',
        'en_KI' => 'engleză (Kiribati)',
        'en_KN' => 'engleză (Saint Kitts și Nevis)',
        'en_KY' => 'engleză (Insulele Cayman)',
        'en_LC' => 'engleză (Sfânta Lucia)',
        'en_LR' => 'engleză (Liberia)',
        'en_LS' => 'engleză (Lesotho)',
        'en_LT' => 'engleză (Lituania)',
        'en_LV' => 'engleză (Letonia)',
        'en_MG' => 'engleză (Madagascar)',
        'en_MH' => 'engleză (Insulele Marshall)',
        'en_MO' => 'engleză (R.A.S. Macao, China)',
        'en_MP' => 'engleză (Insulele Mariane de Nord)',
        'en_MS' => 'engleză (Montserrat)',
        'en_MT' => 'engleză (Malta)',
        'en_MU' => 'engleză (Mauritius)',
        'en_MV' => 'engleză (Maldive)',
        'en_MW' => 'engleză (Malawi)',
        'en_MY' => 'engleză (Malaysia)',
        'en_NA' => 'engleză (Namibia)',
        'en_NF' => 'engleză (Insula Norfolk)',
        'en_NG' => 'engleză (Nigeria)',
        'en_NL' => 'engleză (Țările de Jos)',
        'en_NO' => 'engleză (Norvegia)',
        'en_NR' => 'engleză (Nauru)',
        'en_NU' => 'engleză (Niue)',
        'en_NZ' => 'engleză (Noua Zeelandă)',
        'en_PG' => 'engleză (Papua-Noua Guinee)',
        'en_PH' => 'engleză (Filipine)',
        'en_PK' => 'engleză (Pakistan)',
        'en_PL' => 'engleză (Polonia)',
        'en_PN' => 'engleză (Insulele Pitcairn)',
        'en_PR' => 'engleză (Puerto Rico)',
        'en_PT' => 'engleză (Portugalia)',
        'en_PW' => 'engleză (Palau)',
        'en_RO' => 'engleză (România)',
        'en_RW' => 'engleză (Rwanda)',
        'en_SB' => 'engleză (Insulele Solomon)',
        'en_SC' => 'engleză (Seychelles)',
        'en_SD' => 'engleză (Sudan)',
        'en_SE' => 'engleză (Suedia)',
        'en_SG' => 'engleză (Singapore)',
        'en_SH' => 'engleză (Sfânta Elena)',
        'en_SI' => 'engleză (Slovenia)',
        'en_SK' => 'engleză (Slovacia)',
        'en_SL' => 'engleză (Sierra Leone)',
        'en_SS' => 'engleză (Sudanul de Sud)',
        'en_SX' => 'engleză (Sint-Maarten)',
        'en_SZ' => 'engleză (Eswatini)',
        'en_TC' => 'engleză (Insulele Turks și Caicos)',
        'en_TK' => 'engleză (Tokelau)',
        'en_TO' => 'engleză (Tonga)',
        'en_TT' => 'engleză (Trinidad și Tobago)',
        'en_TV' => 'engleză (Tuvalu)',
        'en_TZ' => 'engleză (Tanzania)',
        'en_UA' => 'engleză (Ucraina)',
        'en_UG' => 'engleză (Uganda)',
        'en_UM' => 'engleză (Insulele Îndepărtate ale S.U.A.)',
        'en_US' => 'engleză (Statele Unite ale Americii)',
        'en_VC' => 'engleză (Saint Vincent și Grenadinele)',
        'en_VG' => 'engleză (Insulele Virgine Britanice)',
        'en_VI' => 'engleză (Insulele Virgine Americane)',
        'en_VU' => 'engleză (Vanuatu)',
        'en_WS' => 'engleză (Samoa)',
        'en_ZA' => 'engleză (Africa de Sud)',
        'en_ZM' => 'engleză (Zambia)',
        'en_ZW' => 'engleză (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Lume)',
        'es' => 'spaniolă',
        'es_419' => 'spaniolă (America Latină)',
        'es_AR' => 'spaniolă (Argentina)',
        'es_BO' => 'spaniolă (Bolivia)',
        'es_BR' => 'spaniolă (Brazilia)',
        'es_BZ' => 'spaniolă (Belize)',
        'es_CL' => 'spaniolă (Chile)',
        'es_CO' => 'spaniolă (Columbia)',
        'es_CR' => 'spaniolă (Costa Rica)',
        'es_CU' => 'spaniolă (Cuba)',
        'es_DO' => 'spaniolă (Republica Dominicană)',
        'es_EC' => 'spaniolă (Ecuador)',
        'es_ES' => 'spaniolă (Spania)',
        'es_GQ' => 'spaniolă (Guineea Ecuatorială)',
        'es_GT' => 'spaniolă (Guatemala)',
        'es_HN' => 'spaniolă (Honduras)',
        'es_MX' => 'spaniolă (Mexic)',
        'es_NI' => 'spaniolă (Nicaragua)',
        'es_PA' => 'spaniolă (Panama)',
        'es_PE' => 'spaniolă (Peru)',
        'es_PH' => 'spaniolă (Filipine)',
        'es_PR' => 'spaniolă (Puerto Rico)',
        'es_PY' => 'spaniolă (Paraguay)',
        'es_SV' => 'spaniolă (El Salvador)',
        'es_US' => 'spaniolă (Statele Unite ale Americii)',
        'es_UY' => 'spaniolă (Uruguay)',
        'es_VE' => 'spaniolă (Venezuela)',
        'et' => 'estonă',
        'et_EE' => 'estonă (Estonia)',
        'eu' => 'bască',
        'eu_ES' => 'bască (Spania)',
        'fa' => 'persană',
        'fa_AF' => 'persană (Afganistan)',
        'fa_IR' => 'persană (Iran)',
        'ff' => 'fulah',
        'ff_Adlm' => 'fulah (adlam)',
        'ff_Adlm_BF' => 'fulah (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulah (adlam, Camerun)',
        'ff_Adlm_GH' => 'fulah (adlam, Ghana)',
        'ff_Adlm_GM' => 'fulah (adlam, Gambia)',
        'ff_Adlm_GN' => 'fulah (adlam, Guineea)',
        'ff_Adlm_GW' => 'fulah (adlam, Guineea-Bissau)',
        'ff_Adlm_LR' => 'fulah (adlam, Liberia)',
        'ff_Adlm_MR' => 'fulah (adlam, Mauritania)',
        'ff_Adlm_NE' => 'fulah (adlam, Niger)',
        'ff_Adlm_NG' => 'fulah (adlam, Nigeria)',
        'ff_Adlm_SL' => 'fulah (adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'fulah (adlam, Senegal)',
        'ff_CM' => 'fulah (Camerun)',
        'ff_GN' => 'fulah (Guineea)',
        'ff_Latn' => 'fulah (latină)',
        'ff_Latn_BF' => 'fulah (latină, Burkina Faso)',
        'ff_Latn_CM' => 'fulah (latină, Camerun)',
        'ff_Latn_GH' => 'fulah (latină, Ghana)',
        'ff_Latn_GM' => 'fulah (latină, Gambia)',
        'ff_Latn_GN' => 'fulah (latină, Guineea)',
        'ff_Latn_GW' => 'fulah (latină, Guineea-Bissau)',
        'ff_Latn_LR' => 'fulah (latină, Liberia)',
        'ff_Latn_MR' => 'fulah (latină, Mauritania)',
        'ff_Latn_NE' => 'fulah (latină, Niger)',
        'ff_Latn_NG' => 'fulah (latină, Nigeria)',
        'ff_Latn_SL' => 'fulah (latină, Sierra Leone)',
        'ff_Latn_SN' => 'fulah (latină, Senegal)',
        'ff_MR' => 'fulah (Mauritania)',
        'ff_SN' => 'fulah (Senegal)',
        'fi' => 'finlandeză',
        'fi_FI' => 'finlandeză (Finlanda)',
        'fo' => 'feroeză',
        'fo_DK' => 'feroeză (Danemarca)',
        'fo_FO' => 'feroeză (Insulele Feroe)',
        'fr' => 'franceză',
        'fr_BE' => 'franceză (Belgia)',
        'fr_BF' => 'franceză (Burkina Faso)',
        'fr_BI' => 'franceză (Burundi)',
        'fr_BJ' => 'franceză (Benin)',
        'fr_BL' => 'franceză (Saint-Barthélemy)',
        'fr_CA' => 'franceză (Canada)',
        'fr_CD' => 'franceză (Congo - Kinshasa)',
        'fr_CF' => 'franceză (Republica Centrafricană)',
        'fr_CG' => 'franceză (Congo - Brazzaville)',
        'fr_CH' => 'franceză (Elveția)',
        'fr_CI' => 'franceză (Côte d’Ivoire)',
        'fr_CM' => 'franceză (Camerun)',
        'fr_DJ' => 'franceză (Djibouti)',
        'fr_DZ' => 'franceză (Algeria)',
        'fr_FR' => 'franceză (Franța)',
        'fr_GA' => 'franceză (Gabon)',
        'fr_GF' => 'franceză (Guyana Franceză)',
        'fr_GN' => 'franceză (Guineea)',
        'fr_GP' => 'franceză (Guadelupa)',
        'fr_GQ' => 'franceză (Guineea Ecuatorială)',
        'fr_HT' => 'franceză (Haiti)',
        'fr_KM' => 'franceză (Comore)',
        'fr_LU' => 'franceză (Luxemburg)',
        'fr_MA' => 'franceză (Maroc)',
        'fr_MC' => 'franceză (Monaco)',
        'fr_MF' => 'franceză (Sfântul Martin)',
        'fr_MG' => 'franceză (Madagascar)',
        'fr_ML' => 'franceză (Mali)',
        'fr_MQ' => 'franceză (Martinica)',
        'fr_MR' => 'franceză (Mauritania)',
        'fr_MU' => 'franceză (Mauritius)',
        'fr_NC' => 'franceză (Noua Caledonie)',
        'fr_NE' => 'franceză (Niger)',
        'fr_PF' => 'franceză (Polinezia Franceză)',
        'fr_PM' => 'franceză (Saint-Pierre și Miquelon)',
        'fr_RE' => 'franceză (Réunion)',
        'fr_RW' => 'franceză (Rwanda)',
        'fr_SC' => 'franceză (Seychelles)',
        'fr_SN' => 'franceză (Senegal)',
        'fr_SY' => 'franceză (Siria)',
        'fr_TD' => 'franceză (Ciad)',
        'fr_TG' => 'franceză (Togo)',
        'fr_TN' => 'franceză (Tunisia)',
        'fr_VU' => 'franceză (Vanuatu)',
        'fr_WF' => 'franceză (Wallis și Futuna)',
        'fr_YT' => 'franceză (Mayotte)',
        'fy' => 'frizonă occidentală',
        'fy_NL' => 'frizonă occidentală (Țările de Jos)',
        'ga' => 'irlandeză',
        'ga_GB' => 'irlandeză (Regatul Unit)',
        'ga_IE' => 'irlandeză (Irlanda)',
        'gd' => 'gaelică scoțiană',
        'gd_GB' => 'gaelică scoțiană (Regatul Unit)',
        'gl' => 'galiciană',
        'gl_ES' => 'galiciană (Spania)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (India)',
        'gv' => 'manx',
        'gv_IM' => 'manx (Insula Man)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'ebraică',
        'he_IL' => 'ebraică (Israel)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (India)',
        'hi_Latn' => 'hindi (latină)',
        'hi_Latn_IN' => 'hindi (latină, India)',
        'hr' => 'croată',
        'hr_BA' => 'croată (Bosnia și Herțegovina)',
        'hr_HR' => 'croată (Croația)',
        'hu' => 'maghiară',
        'hu_HU' => 'maghiară (Ungaria)',
        'hy' => 'armeană',
        'hy_AM' => 'armeană (Armenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (Lume)',
        'id' => 'indoneziană',
        'id_ID' => 'indoneziană (Indonezia)',
        'ie' => 'interlingue',
        'ie_EE' => 'interlingue (Estonia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeria)',
        'ii' => 'yi din Sichuan',
        'ii_CN' => 'yi din Sichuan (China)',
        'is' => 'islandeză',
        'is_IS' => 'islandeză (Islanda)',
        'it' => 'italiană',
        'it_CH' => 'italiană (Elveția)',
        'it_IT' => 'italiană (Italia)',
        'it_SM' => 'italiană (San Marino)',
        'it_VA' => 'italiană (Statul Cetății Vaticanului)',
        'ja' => 'japoneză',
        'ja_JP' => 'japoneză (Japonia)',
        'jv' => 'javaneză',
        'jv_ID' => 'javaneză (Indonezia)',
        'ka' => 'georgiană',
        'ka_GE' => 'georgiană (Georgia)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenya)',
        'kk' => 'kazahă',
        'kk_Arab' => 'kazahă (arabă)',
        'kk_Arab_CN' => 'kazahă (arabă, China)',
        'kk_Cyrl' => 'kazahă (chirilică)',
        'kk_Cyrl_KZ' => 'kazahă (chirilică, Kazahstan)',
        'kk_KZ' => 'kazahă (Kazahstan)',
        'kl' => 'kalaallisut',
        'kl_GL' => 'kalaallisut (Groenlanda)',
        'km' => 'khmeră',
        'km_KH' => 'khmeră (Cambodgia)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (India)',
        'ko' => 'coreeană',
        'ko_CN' => 'coreeană (China)',
        'ko_KP' => 'coreeană (Coreea de Nord)',
        'ko_KR' => 'coreeană (Coreea de Sud)',
        'ks' => 'cașmiră',
        'ks_Arab' => 'cașmiră (arabă)',
        'ks_Arab_IN' => 'cașmiră (arabă, India)',
        'ks_Deva' => 'cașmiră (devanagari)',
        'ks_Deva_IN' => 'cașmiră (devanagari, India)',
        'ks_IN' => 'cașmiră (India)',
        'ku' => 'kurdă',
        'ku_Latn' => 'kurdă (latină)',
        'ku_Latn_IQ' => 'kurdă (latină, Irak)',
        'ku_Latn_SY' => 'kurdă (latină, Siria)',
        'ku_Latn_TR' => 'kurdă (latină, Turcia)',
        'ku_SY' => 'kurdă (Siria)',
        'ku_TR' => 'kurdă (Turcia)',
        'kw' => 'cornică',
        'kw_GB' => 'cornică (Regatul Unit)',
        'ky' => 'kârgâză',
        'ky_KG' => 'kârgâză (Kârgâzstan)',
        'lb' => 'luxemburgheză',
        'lb_LU' => 'luxemburgheză (Luxemburg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Congo - Kinshasa)',
        'ln_CF' => 'lingala (Republica Centrafricană)',
        'ln_CG' => 'lingala (Congo - Brazzaville)',
        'lo' => 'laoțiană',
        'lo_LA' => 'laoțiană (Laos)',
        'lt' => 'lituaniană',
        'lt_LT' => 'lituaniană (Lituania)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Congo - Kinshasa)',
        'lv' => 'letonă',
        'lv_LV' => 'letonă (Letonia)',
        'mg' => 'malgașă',
        'mg_MG' => 'malgașă (Madagascar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Noua Zeelandă)',
        'mk' => 'macedoneană',
        'mk_MK' => 'macedoneană (Macedonia de Nord)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (India)',
        'mn' => 'mongolă',
        'mn_MN' => 'mongolă (Mongolia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (India)',
        'ms' => 'malaeză',
        'ms_BN' => 'malaeză (Brunei)',
        'ms_ID' => 'malaeză (Indonezia)',
        'ms_MY' => 'malaeză (Malaysia)',
        'ms_SG' => 'malaeză (Singapore)',
        'mt' => 'malteză',
        'mt_MT' => 'malteză (Malta)',
        'my' => 'birmană',
        'my_MM' => 'birmană (Myanmar [Birmania])',
        'nb' => 'norvegiană bokmål',
        'nb_NO' => 'norvegiană bokmål (Norvegia)',
        'nb_SJ' => 'norvegiană bokmål (Svalbard și Jan Mayen)',
        'nd' => 'ndebele de nord',
        'nd_ZW' => 'ndebele de nord (Zimbabwe)',
        'ne' => 'nepaleză',
        'ne_IN' => 'nepaleză (India)',
        'ne_NP' => 'nepaleză (Nepal)',
        'nl' => 'neerlandeză',
        'nl_AW' => 'neerlandeză (Aruba)',
        'nl_BE' => 'neerlandeză (Belgia)',
        'nl_BQ' => 'neerlandeză (Insulele Caraibe Olandeze)',
        'nl_CW' => 'neerlandeză (Curaçao)',
        'nl_NL' => 'neerlandeză (Țările de Jos)',
        'nl_SR' => 'neerlandeză (Suriname)',
        'nl_SX' => 'neerlandeză (Sint-Maarten)',
        'nn' => 'norvegiană nynorsk',
        'nn_NO' => 'norvegiană nynorsk (Norvegia)',
        'no' => 'norvegiană',
        'no_NO' => 'norvegiană (Norvegia)',
        'oc' => 'occitană',
        'oc_ES' => 'occitană (Spania)',
        'oc_FR' => 'occitană (Franța)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiopia)',
        'om_KE' => 'oromo (Kenya)',
        'or' => 'odia',
        'or_IN' => 'odia (India)',
        'os' => 'osetă',
        'os_GE' => 'osetă (Georgia)',
        'os_RU' => 'osetă (Rusia)',
        'pa' => 'punjabi',
        'pa_Arab' => 'punjabi (arabă)',
        'pa_Arab_PK' => 'punjabi (arabă, Pakistan)',
        'pa_Guru' => 'punjabi (gurmukhi)',
        'pa_Guru_IN' => 'punjabi (gurmukhi, India)',
        'pa_IN' => 'punjabi (India)',
        'pa_PK' => 'punjabi (Pakistan)',
        'pl' => 'poloneză',
        'pl_PL' => 'poloneză (Polonia)',
        'ps' => 'paștună',
        'ps_AF' => 'paștună (Afganistan)',
        'ps_PK' => 'paștună (Pakistan)',
        'pt' => 'portugheză',
        'pt_AO' => 'portugheză (Angola)',
        'pt_BR' => 'portugheză (Brazilia)',
        'pt_CH' => 'portugheză (Elveția)',
        'pt_CV' => 'portugheză (Capul Verde)',
        'pt_GQ' => 'portugheză (Guineea Ecuatorială)',
        'pt_GW' => 'portugheză (Guineea-Bissau)',
        'pt_LU' => 'portugheză (Luxemburg)',
        'pt_MO' => 'portugheză (R.A.S. Macao, China)',
        'pt_MZ' => 'portugheză (Mozambic)',
        'pt_PT' => 'portugheză (Portugalia)',
        'pt_ST' => 'portugheză (São Tomé și Príncipe)',
        'pt_TL' => 'portugheză (Timor-Leste)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolivia)',
        'qu_EC' => 'quechua (Ecuador)',
        'qu_PE' => 'quechua (Peru)',
        'rm' => 'romanșă',
        'rm_CH' => 'romanșă (Elveția)',
        'rn' => 'kirundi',
        'rn_BI' => 'kirundi (Burundi)',
        'ro' => 'română',
        'ro_MD' => 'română (Republica Moldova)',
        'ro_RO' => 'română (România)',
        'ru' => 'rusă',
        'ru_BY' => 'rusă (Belarus)',
        'ru_KG' => 'rusă (Kârgâzstan)',
        'ru_KZ' => 'rusă (Kazahstan)',
        'ru_MD' => 'rusă (Republica Moldova)',
        'ru_RU' => 'rusă (Rusia)',
        'ru_UA' => 'rusă (Ucraina)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Rwanda)',
        'sa' => 'sanscrită',
        'sa_IN' => 'sanscrită (India)',
        'sc' => 'sardiniană',
        'sc_IT' => 'sardiniană (Italia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arabă)',
        'sd_Arab_PK' => 'sindhi (arabă, Pakistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, India)',
        'sd_IN' => 'sindhi (India)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'sami de nord',
        'se_FI' => 'sami de nord (Finlanda)',
        'se_NO' => 'sami de nord (Norvegia)',
        'se_SE' => 'sami de nord (Suedia)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Republica Centrafricană)',
        'sh' => 'sârbo-croată',
        'sh_BA' => 'sârbo-croată (Bosnia și Herțegovina)',
        'si' => 'singhaleză',
        'si_LK' => 'singhaleză (Sri Lanka)',
        'sk' => 'slovacă',
        'sk_SK' => 'slovacă (Slovacia)',
        'sl' => 'slovenă',
        'sl_SI' => 'slovenă (Slovenia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabwe)',
        'so' => 'somaleză',
        'so_DJ' => 'somaleză (Djibouti)',
        'so_ET' => 'somaleză (Etiopia)',
        'so_KE' => 'somaleză (Kenya)',
        'so_SO' => 'somaleză (Somalia)',
        'sq' => 'albaneză',
        'sq_AL' => 'albaneză (Albania)',
        'sq_MK' => 'albaneză (Macedonia de Nord)',
        'sr' => 'sârbă',
        'sr_BA' => 'sârbă (Bosnia și Herțegovina)',
        'sr_Cyrl' => 'sârbă (chirilică)',
        'sr_Cyrl_BA' => 'sârbă (chirilică, Bosnia și Herțegovina)',
        'sr_Cyrl_ME' => 'sârbă (chirilică, Muntenegru)',
        'sr_Cyrl_RS' => 'sârbă (chirilică, Serbia)',
        'sr_Latn' => 'sârbă (latină)',
        'sr_Latn_BA' => 'sârbă (latină, Bosnia și Herțegovina)',
        'sr_Latn_ME' => 'sârbă (latină, Muntenegru)',
        'sr_Latn_RS' => 'sârbă (latină, Serbia)',
        'sr_ME' => 'sârbă (Muntenegru)',
        'sr_RS' => 'sârbă (Serbia)',
        'st' => 'sesotho',
        'st_LS' => 'sesotho (Lesotho)',
        'st_ZA' => 'sesotho (Africa de Sud)',
        'su' => 'sundaneză',
        'su_ID' => 'sundaneză (Indonezia)',
        'su_Latn' => 'sundaneză (latină)',
        'su_Latn_ID' => 'sundaneză (latină, Indonezia)',
        'sv' => 'suedeză',
        'sv_AX' => 'suedeză (Insulele Åland)',
        'sv_FI' => 'suedeză (Finlanda)',
        'sv_SE' => 'suedeză (Suedia)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Congo - Kinshasa)',
        'sw_KE' => 'swahili (Kenya)',
        'sw_TZ' => 'swahili (Tanzania)',
        'sw_UG' => 'swahili (Uganda)',
        'ta' => 'tamilă',
        'ta_IN' => 'tamilă (India)',
        'ta_LK' => 'tamilă (Sri Lanka)',
        'ta_MY' => 'tamilă (Malaysia)',
        'ta_SG' => 'tamilă (Singapore)',
        'te' => 'telugu',
        'te_IN' => 'telugu (India)',
        'tg' => 'tadjică',
        'tg_TJ' => 'tadjică (Tadjikistan)',
        'th' => 'thailandeză',
        'th_TH' => 'thailandeză (Thailanda)',
        'ti' => 'tigrină',
        'ti_ER' => 'tigrină (Eritreea)',
        'ti_ET' => 'tigrină (Etiopia)',
        'tk' => 'turkmenă',
        'tk_TM' => 'turkmenă (Turkmenistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filipine)',
        'tn' => 'setswana',
        'tn_BW' => 'setswana (Botswana)',
        'tn_ZA' => 'setswana (Africa de Sud)',
        'to' => 'tongană',
        'to_TO' => 'tongană (Tonga)',
        'tr' => 'turcă',
        'tr_CY' => 'turcă (Cipru)',
        'tr_TR' => 'turcă (Turcia)',
        'tt' => 'tătară',
        'tt_RU' => 'tătară (Rusia)',
        'ug' => 'uigură',
        'ug_CN' => 'uigură (China)',
        'uk' => 'ucraineană',
        'uk_UA' => 'ucraineană (Ucraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (India)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'uzbecă',
        'uz_AF' => 'uzbecă (Afganistan)',
        'uz_Arab' => 'uzbecă (arabă)',
        'uz_Arab_AF' => 'uzbecă (arabă, Afganistan)',
        'uz_Cyrl' => 'uzbecă (chirilică)',
        'uz_Cyrl_UZ' => 'uzbecă (chirilică, Uzbekistan)',
        'uz_Latn' => 'uzbecă (latină)',
        'uz_Latn_UZ' => 'uzbecă (latină, Uzbekistan)',
        'uz_UZ' => 'uzbecă (Uzbekistan)',
        'vi' => 'vietnameză',
        'vi_VN' => 'vietnameză (Vietnam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Africa de Sud)',
        'yi' => 'idiș',
        'yi_UA' => 'idiș (Ucraina)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benin)',
        'yo_NG' => 'yoruba (Nigeria)',
        'za' => 'zhuang',
        'za_CN' => 'zhuang (China)',
        'zh' => 'chineză',
        'zh_CN' => 'chineză (China)',
        'zh_HK' => 'chineză (R.A.S. Hong Kong, China)',
        'zh_Hans' => 'chineză (simplificată)',
        'zh_Hans_CN' => 'chineză (simplificată, China)',
        'zh_Hans_HK' => 'chineză (simplificată, R.A.S. Hong Kong, China)',
        'zh_Hans_MO' => 'chineză (simplificată, R.A.S. Macao, China)',
        'zh_Hans_MY' => 'chineză (simplificată, Malaysia)',
        'zh_Hans_SG' => 'chineză (simplificată, Singapore)',
        'zh_Hant' => 'chineză (tradițională)',
        'zh_Hant_HK' => 'chineză (tradițională, R.A.S. Hong Kong, China)',
        'zh_Hant_MO' => 'chineză (tradițională, R.A.S. Macao, China)',
        'zh_Hant_MY' => 'chineză (tradițională, Malaysia)',
        'zh_Hant_TW' => 'chineză (tradițională, Taiwan)',
        'zh_MO' => 'chineză (R.A.S. Macao, China)',
        'zh_SG' => 'chineză (Singapore)',
        'zh_TW' => 'chineză (Taiwan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Africa de Sud)',
    ],
];
