<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'গ্রীনিচ মিন টাইম (আবিদজান)',
        'Africa/Accra' => 'গ্রীনিচ মিন টাইম (আক্রা)',
        'Africa/Addis_Ababa' => 'পূর্ব আফ্রিকা সময় (আদ্দিস আবাবা)',
        'Africa/Algiers' => 'মধ্য ইউরোপীয় সময় (আলজিয়ার্স)',
        'Africa/Asmera' => 'পূর্ব আফ্রিকা সময় (অ্যাসমারাহু)',
        'Africa/Asmara' => 'পূর্ব আফ্রিকা সময় (অ্যাসমারাহু)',
        'Africa/Bamako' => 'গ্রীনিচ মিন টাইম (বাম্যাকো)',
        'Africa/Bangui' => 'পশ্চিম আফ্রিকা সময় (বাঙ্গুই)',
        'Africa/Banjul' => 'গ্রীনিচ মিন টাইম (বাঞ্জুল)',
        'Africa/Bissau' => 'গ্রীনিচ মিন টাইম (বিসোউ)',
        'Africa/Blantyre' => 'মধ্য আফ্রিকা সময় (ব্ল্যানটায়ের)',
        'Africa/Brazzaville' => 'পশ্চিম আফ্রিকা সময় (ব্রাজাভিলি)',
        'Africa/Bujumbura' => 'মধ্য আফ্রিকা সময় (বুজুমবুরহু)',
        'Africa/Cairo' => 'পূর্ব ইউরোপীয় সময় (কায়রো)',
        'Africa/Casablanca' => 'পশ্চিম ইউরোপীয় সময় (কাসাব্লাঙ্কা)',
        'Africa/Ceuta' => 'মধ্য ইউরোপীয় সময় (সেউটা)',
        'Africa/Conakry' => 'গ্রীনিচ মিন টাইম (কনাক্রি)',
        'Africa/Dakar' => 'গ্রীনিচ মিন টাইম (ডাকার)',
        'Africa/Dar_es_Salaam' => 'পূর্ব আফ্রিকা সময় (দার এস সালাম)',
        'Africa/Djibouti' => 'পূর্ব আফ্রিকা সময় (জিবুটি)',
        'Africa/Douala' => 'পশ্চিম আফ্রিকা সময় (ডোয়ালা)',
        'Africa/El_Aaiun' => 'পশ্চিম ইউরোপীয় সময় (এল আহইউন)',
        'Africa/Freetown' => 'গ্রীনিচ মিন টাইম (ফ্রীটাউন)',
        'Africa/Gaborone' => 'মধ্য আফ্রিকা সময় (গ্যাবুরনি)',
        'Africa/Harare' => 'মধ্য আফ্রিকা সময় (হারারে)',
        'Africa/Johannesburg' => 'দক্ষিণ আফ্রিকা মানক সময় (জোহানেসবার্গ)',
        'Africa/Juba' => 'মধ্য আফ্রিকা সময় (জুবা)',
        'Africa/Kampala' => 'পূর্ব আফ্রিকা সময় (কামপালা)',
        'Africa/Khartoum' => 'মধ্য আফ্রিকা সময় (খার্তুম)',
        'Africa/Kigali' => 'মধ্য আফ্রিকা সময় (কিগালি)',
        'Africa/Kinshasa' => 'পশ্চিম আফ্রিকা সময় (কিনশাসা)',
        'Africa/Lagos' => 'পশ্চিম আফ্রিকা সময় (লাগোস)',
        'Africa/Libreville' => 'পশ্চিম আফ্রিকা সময় (লিব্রুভিল)',
        'Africa/Lome' => 'গ্রীনিচ মিন টাইম (লোমে)',
        'Africa/Luanda' => 'পশ্চিম আফ্রিকা সময় (লোয়ান্ডা)',
        'Africa/Lubumbashi' => 'মধ্য আফ্রিকা সময় (লুবুম্বাশি)',
        'Africa/Lusaka' => 'মধ্য আফ্রিকা সময় (লুসাকা)',
        'Africa/Malabo' => 'পশ্চিম আফ্রিকা সময় (মালাবো)',
        'Africa/Maputo' => 'মধ্য আফ্রিকা সময় (মাপুতো)',
        'Africa/Maseru' => 'দক্ষিণ আফ্রিকা মানক সময় (মাহসুরু)',
        'Africa/Mbabane' => 'দক্ষিণ আফ্রিকা মানক সময় (অমবাবান)',
        'Africa/Mogadishu' => 'পূর্ব আফ্রিকা সময় (মাওগাদিসু)',
        'Africa/Monrovia' => 'গ্রীনিচ মিন টাইম (মনরোভিয়া)',
        'Africa/Nairobi' => 'পূর্ব আফ্রিকা সময় (নাইরোবি)',
        'Africa/Ndjamena' => 'পশ্চিম আফ্রিকা সময় (এনজমেনা)',
        'Africa/Niamey' => 'পশ্চিম আফ্রিকা সময় (নিয়ামে)',
        'Africa/Nouakchott' => 'গ্রীনিচ মিন টাইম (নোয়াকশট)',
        'Africa/Ouagadougou' => 'গ্রীনিচ মিন টাইম (ওয়াহগুডোগু)',
        'Africa/Porto-Novo' => 'পশ্চিম আফ্রিকা সময় (পোর্টো-নোভো)',
        'Africa/Sao_Tome' => 'গ্রীনিচ মিন টাইম (সাও টোম)',
        'Africa/Tripoli' => 'পূর্ব ইউরোপীয় সময় (ত্রিপোলি)',
        'Africa/Tunis' => 'মধ্য ইউরোপীয় সময় (টিউনিস)',
        'Africa/Windhoek' => 'মধ্য আফ্রিকা সময় (উইনধোক)',
        'America/Adak' => 'হাওয়াই-আলেউত সময় (আডক)',
        'America/Anchorage' => 'আলাস্কা সময় (এনকোরেজ)',
        'America/Anguilla' => 'অতলান্তিকের সময় (অ্যাঙ্গুইলা)',
        'America/Antigua' => 'অতলান্তিকের সময় (অ্যান্টিগুয়া)',
        'America/Araguaina' => 'ব্রাসিলিয়া সময় (আরাগুয়াইনা)',
        'America/Argentina/La_Rioja' => 'আর্জেন্টিনা সময় (লা রিওহা)',
        'America/Argentina/Rio_Gallegos' => 'আর্জেন্টিনা সময় (রিও গায়েগোস)',
        'America/Argentina/Salta' => 'আর্জেন্টিনা সময় (স্যালটা)',
        'America/Argentina/San_Juan' => 'আর্জেন্টিনা সময় (সান জুয়ান)',
        'America/Argentina/San_Luis' => 'আর্জেন্টিনা সময় (সান লুইস)',
        'America/Argentina/Tucuman' => 'আর্জেন্টিনা সময় (টুকুমান)',
        'America/Argentina/Ushuaia' => 'আর্জেন্টিনা সময় (উশুয়াইয়া)',
        'America/Aruba' => 'অতলান্তিকের সময় (এরুবা)',
        'America/Asuncion' => 'প্যারাগুয়ে সময় (আসুনসিয়ন)',
        'America/Bahia' => 'ব্রাসিলিয়া সময় (বাহিয়া)',
        'America/Bahia_Banderas' => 'কেন্দ্রীয় সময় (বাহিয়া বান্দেরাস)',
        'America/Barbados' => 'অতলান্তিকের সময় (বার্বাডোজ)',
        'America/Belem' => 'ব্রাসিলিয়া সময় (বেলেম)',
        'America/Belize' => 'কেন্দ্রীয় সময় (বেলিজ)',
        'America/Blanc-Sablon' => 'অতলান্তিকের সময় (ব্লাঙ্ক-সাব্লোন)',
        'America/Boa_Vista' => 'আমাজন সময় (বোয়া ভিস্তা)',
        'America/Bogota' => 'কলম্বিয়া সময় (বোগোটা)',
        'America/Boise' => 'পার্বত্য অঞ্চলের সময় (বয়জি)',
        'America/Buenos_Aires' => 'আর্জেন্টিনা সময় (বুয়েনোস আয়েরেস)',
        'America/Argentina/Buenos_Aires' => 'আর্জেন্টিনা সময় (বুয়েনোস আয়েরেস)',
        'America/Cambridge_Bay' => 'পার্বত্য অঞ্চলের সময় (কেমব্রিজ বে)',
        'America/Campo_Grande' => 'আমাজন সময় (কাম্পো গ্রান্ডে)',
        'America/Cancun' => 'পূর্বাঞ্চলীয় সময় (ক্যানকুন)',
        'America/Caracas' => 'ভেনেজুয়েলা সময় (ক্যারাকাস)',
        'America/Catamarca' => 'আর্জেন্টিনা সময় (ক্যাটামার্কা)',
        'America/Argentina/Catamarca' => 'আর্জেন্টিনা সময় (ক্যাটামার্কা)',
        'America/Cayenne' => 'ফরাসি গায়ানা সময় (কাহেন)',
        'America/Cayman' => 'পূর্বাঞ্চলীয় সময় (কামেন)',
        'America/Chicago' => 'কেন্দ্রীয় সময় (শিকাগো)',
        'America/Chihuahua' => 'কেন্দ্রীয় সময় (চিহুয়াহুয়া)',
        'America/Ciudad_Juarez' => 'পার্বত্য অঞ্চলের সময় (সিউদাদ জুয়ারেজ)',
        'America/Coral_Harbour' => 'পূর্বাঞ্চলীয় সময় (আটিকোকান)',
        'America/Atikokan' => 'পূর্বাঞ্চলীয় সময় (আটিকোকান)',
        'America/Cordoba' => 'আর্জেন্টিনা সময় (কর্ডোবা)',
        'America/Argentina/Cordoba' => 'আর্জেন্টিনা সময় (কর্ডোবা)',
        'America/Costa_Rica' => 'কেন্দ্রীয় সময় (কোস্টারিকা)',
        'America/Coyhaique' => 'চিলি সময় (কোয়আইকে)',
        'America/Creston' => 'পার্বত্য অঞ্চলের সময় (ক্রিস্টান)',
        'America/Cuiaba' => 'আমাজন সময় (কুইয়াবা)',
        'America/Curacao' => 'অতলান্তিকের সময় (কুরাসাও)',
        'America/Danmarkshavn' => 'গ্রীনিচ মিন টাইম (ডানমার্কশ্যাভন)',
        'America/Dawson' => 'ইউকোন সময় (ডসোন)',
        'America/Dawson_Creek' => 'পার্বত্য অঞ্চলের সময় (ডসোন ক্রিক)',
        'America/Denver' => 'পার্বত্য অঞ্চলের সময় (ডেনভার)',
        'America/Detroit' => 'পূর্বাঞ্চলীয় সময় (ডেট্রোইট)',
        'America/Dominica' => 'অতলান্তিকের সময় (ডোমিনিকা)',
        'America/Edmonton' => 'পার্বত্য অঞ্চলের সময় (এডমন্টোন)',
        'America/Eirunepe' => 'একর সময় (আইরুনেপে)',
        'America/El_Salvador' => 'কেন্দ্রীয় সময় (এল সালভাদোর)',
        'America/Fort_Nelson' => 'পার্বত্য অঞ্চলের সময় (ফোর্ট নেলসন)',
        'America/Fortaleza' => 'ব্রাসিলিয়া সময় (ফোর্টালেজা)',
        'America/Glace_Bay' => 'অতলান্তিকের সময় (গ্লাস বে)',
        'America/Godthab' => 'গ্রীনল্যান্ড সময় (নুক)',
        'America/Nuuk' => 'গ্রীনল্যান্ড সময় (নুক)',
        'America/Goose_Bay' => 'অতলান্তিকের সময় (গুস বে)',
        'America/Grand_Turk' => 'পূর্বাঞ্চলীয় সময় (গ্র্যান্ড তুর্ক)',
        'America/Grenada' => 'অতলান্তিকের সময় (গ্রেনাডা)',
        'America/Guadeloupe' => 'অতলান্তিকের সময় (গুয়াদেলোপ)',
        'America/Guatemala' => 'কেন্দ্রীয় সময় (গুয়াতেমালা)',
        'America/Guayaquil' => 'ইকুয়েডর সময় (গোয়াইয়াকিল)',
        'America/Guyana' => 'গুয়ানা সময় (গায়ানা)',
        'America/Halifax' => 'অতলান্তিকের সময় (হ্যালিফ্যাক্স)',
        'America/Havana' => 'কিউবার সময় (হাভানা)',
        'America/Hermosillo' => 'মেক্সিকান প্রশান্ত মহাসাগরীয় সময় (হারমোসিল্লো)',
        'America/Indiana/Knox' => 'কেন্দ্রীয় সময় (নক্স, ইন্ডিয়ানা)',
        'America/Indiana/Marengo' => 'পূর্বাঞ্চলীয় সময় (মারেঙ্গো, ইন্ডিয়ানা)',
        'America/Indiana/Petersburg' => 'পূর্বাঞ্চলীয় সময় (পিটারর্সবার্গ, ইন্ডিয়ানা)',
        'America/Indiana/Tell_City' => 'কেন্দ্রীয় সময় (টেলসিটি, ইন্ডিয়ানা)',
        'America/Indiana/Vevay' => 'পূর্বাঞ্চলীয় সময় (ভেভেয়, ইন্ডিয়ানা)',
        'America/Indiana/Vincennes' => 'পূর্বাঞ্চলীয় সময় (ভিনসেন্নেস, ইন্ডিয়ানা)',
        'America/Indiana/Winamac' => 'পূর্বাঞ্চলীয় সময় (উইনাম্যাক, ইন্ডিয়ানা)',
        'America/Indianapolis' => 'পূর্বাঞ্চলীয় সময় (ইন্ডিয়ানাপোলিস)',
        'America/Indiana/Indianapolis' => 'পূর্বাঞ্চলীয় সময় (ইন্ডিয়ানাপোলিস)',
        'America/Inuvik' => 'পার্বত্য অঞ্চলের সময় (ইনুভ্যাক)',
        'America/Iqaluit' => 'পূর্বাঞ্চলীয় সময় (ইকুয়ালুইট)',
        'America/Jamaica' => 'পূর্বাঞ্চলীয় সময় (জামাইকা)',
        'America/Jujuy' => 'আর্জেন্টিনা সময় (জুজুই)',
        'America/Argentina/Jujuy' => 'আর্জেন্টিনা সময় (জুজুই)',
        'America/Juneau' => 'আলাস্কা সময় (জুনো)',
        'America/Kentucky/Monticello' => 'পূর্বাঞ্চলীয় সময় (মন্টিচেলো, কেন্টাকি)',
        'America/Kralendijk' => 'অতলান্তিকের সময় (ক্রেলেন্ডাজিক)',
        'America/La_Paz' => 'বোলিভিয়া সময় (লা পাজ)',
        'America/Lima' => 'পেরু সময় (লিমা)',
        'America/Los_Angeles' => 'প্রশান্ত মহাসাগরীয় অঞ্চলের সময় (লস অ্যাঞ্জেলেস)',
        'America/Louisville' => 'পূর্বাঞ্চলীয় সময় (লুইসভিল)',
        'America/Kentucky/Louisville' => 'পূর্বাঞ্চলীয় সময় (লুইসভিল)',
        'America/Lower_Princes' => 'অতলান্তিকের সময় (লোয়ার প্রিন্সেস কোয়ার্টার)',
        'America/Maceio' => 'ব্রাসিলিয়া সময় (মাসেয়ো)',
        'America/Managua' => 'কেন্দ্রীয় সময় (মানাগুয়া)',
        'America/Manaus' => 'আমাজন সময় (মানাউস)',
        'America/Marigot' => 'অতলান্তিকের সময় (মারিগো)',
        'America/Martinique' => 'অতলান্তিকের সময় (মারটিনিক)',
        'America/Matamoros' => 'কেন্দ্রীয় সময় (মাতামোরস)',
        'America/Mazatlan' => 'মেক্সিকান প্রশান্ত মহাসাগরীয় সময় (মাজাটলান)',
        'America/Mendoza' => 'আর্জেন্টিনা সময় (মেন্ডোজা)',
        'America/Argentina/Mendoza' => 'আর্জেন্টিনা সময় (মেন্ডোজা)',
        'America/Menominee' => 'কেন্দ্রীয় সময় (মেনোমিনি)',
        'America/Merida' => 'কেন্দ্রীয় সময় (মেরিডা)',
        'America/Metlakatla' => 'আলাস্কা সময় (মেটলাকাটলা)',
        'America/Mexico_City' => 'কেন্দ্রীয় সময় (মেক্সিকো সিটি)',
        'America/Miquelon' => 'সেন্ট পিয়ের ও মিকেলন সময় (মিকুলন)',
        'America/Moncton' => 'অতলান্তিকের সময় (মঙ্কটোন)',
        'America/Monterrey' => 'কেন্দ্রীয় সময় (মন্টেরি)',
        'America/Montevideo' => 'উরুগুয়ে সময় (মন্টেভিডিও)',
        'America/Montserrat' => 'অতলান্তিকের সময় (মন্তসেরাত)',
        'America/Nassau' => 'পূর্বাঞ্চলীয় সময় (নাসাউ)',
        'America/New_York' => 'পূর্বাঞ্চলীয় সময় (নিউইয়র্ক)',
        'America/Nome' => 'আলাস্কা সময় (নোম)',
        'America/Noronha' => 'ফার্নান্দো ডি নোরোনহা সময় (নরোন্‌হা)',
        'America/North_Dakota/Beulah' => 'কেন্দ্রীয় সময় (বেউলা, উত্তর ডাকোটা)',
        'America/North_Dakota/Center' => 'কেন্দ্রীয় সময় (মধ্য, উত্তর ডাকোটা)',
        'America/North_Dakota/New_Salem' => 'কেন্দ্রীয় সময় (নিউ সালেম, উত্তর ডাকোটা)',
        'America/Ojinaga' => 'কেন্দ্রীয় সময় (ওজিনাগা)',
        'America/Panama' => 'পূর্বাঞ্চলীয় সময় (পানামা)',
        'America/Paramaribo' => 'সুরিনাম সময় (প্যারামেরিবো)',
        'America/Phoenix' => 'পার্বত্য অঞ্চলের সময় (ফিনিক্স)',
        'America/Port-au-Prince' => 'পূর্বাঞ্চলীয় সময় (পোর্ট-অহ-প্রিন্স)',
        'America/Port_of_Spain' => 'অতলান্তিকের সময় (পোর্ট অফ স্পেন)',
        'America/Porto_Velho' => 'আমাজন সময় (পোর্তো ভেল্‌হো)',
        'America/Puerto_Rico' => 'অতলান্তিকের সময় (পুয়ের্তো রিকো)',
        'America/Punta_Arenas' => 'চিলি সময় (পুন্টা আরেনাস)',
        'America/Rankin_Inlet' => 'কেন্দ্রীয় সময় (র‍্যাঙ্কিন ইনলেট)',
        'America/Recife' => 'ব্রাসিলিয়া সময় (রেসিফে)',
        'America/Regina' => 'কেন্দ্রীয় সময় (রেজিনা)',
        'America/Resolute' => 'কেন্দ্রীয় সময় (রেসোলুট)',
        'America/Rio_Branco' => 'একর সময় (রিও ব্রাঙ্কো)',
        'America/Santarem' => 'ব্রাসিলিয়া সময় (সেনটুরেম)',
        'America/Santiago' => 'চিলি সময় (সান্টিয়াগো)',
        'America/Santo_Domingo' => 'অতলান্তিকের সময় (স্যান্টো ডোমিংগো)',
        'America/Sao_Paulo' => 'ব্রাসিলিয়া সময় (সাও পাউলো)',
        'America/Scoresbysund' => 'গ্রীনল্যান্ড সময় (ইট্টকুয়োরটুরমিট)',
        'America/Sitka' => 'আলাস্কা সময় (শিটকা)',
        'America/St_Barthelemy' => 'অতলান্তিকের সময় (সেন্ট.বার্থেলেমি)',
        'America/St_Johns' => 'নিউফাউন্ডল্যান্ড সময় (সেন্ট জন্স)',
        'America/St_Kitts' => 'অতলান্তিকের সময় (সেন্ট. কিটস)',
        'America/St_Lucia' => 'অতলান্তিকের সময় (সেন্ট. লুসিয়া)',
        'America/St_Thomas' => 'অতলান্তিকের সময় (সেন্ট. থমাস)',
        'America/St_Vincent' => 'অতলান্তিকের সময় (সেন্ট. ভিনসেন্ট)',
        'America/Swift_Current' => 'কেন্দ্রীয় সময় (সুইফ্ট কারেন্ট)',
        'America/Tegucigalpa' => 'কেন্দ্রীয় সময় (তেগুসিগালপা)',
        'America/Thule' => 'অতলান্তিকের সময় (থুলি)',
        'America/Tijuana' => 'প্রশান্ত মহাসাগরীয় অঞ্চলের সময় (তিজুয়ানা)',
        'America/Toronto' => 'পূর্বাঞ্চলীয় সময় (টোরন্টো)',
        'America/Tortola' => 'অতলান্তিকের সময় (টরটোলা)',
        'America/Vancouver' => 'প্রশান্ত মহাসাগরীয় অঞ্চলের সময় (ভ্যাঙ্কুভার)',
        'America/Whitehorse' => 'ইউকোন সময় (হোয়াইটহর্স)',
        'America/Winnipeg' => 'কেন্দ্রীয় সময় (উইনিপেগ)',
        'America/Yakutat' => 'আলাস্কা সময় (ইয়াকুটাট)',
        'Antarctica/Casey' => 'পশ্চিমি অস্ট্রেলীয় সময় (কেইসি)',
        'Antarctica/Davis' => 'ডেভিস সময়',
        'Antarctica/DumontDUrville' => 'ডুমন্ট-দ্য’উরভিলে সময় (ডুমন্ট ডি’উরভিল)',
        'Antarctica/Macquarie' => 'পূর্ব অস্ট্রেলীয় সময় (ম্যাককুয়্যারি)',
        'Antarctica/Mawson' => 'মসন সময় (মসোন)',
        'Antarctica/McMurdo' => 'নিউজিল্যান্ড সময় (ম্যাকমুর্ডো)',
        'Antarctica/Palmer' => 'চিলি সময় (পালমার)',
        'Antarctica/Rothera' => 'রথেরা সময়',
        'Antarctica/Syowa' => 'সায়োওয়া সময় (সিওয়া)',
        'Antarctica/Troll' => 'গ্রীনিচ মিন টাইম (ট্রল)',
        'Antarctica/Vostok' => 'ভসটক সময় (ভস্টোক)',
        'Arctic/Longyearbyen' => 'মধ্য ইউরোপীয় সময় (লঞ্জিয়বিয়েঁন)',
        'Asia/Aden' => 'আরবি সময় (আহদেন)',
        'Asia/Almaty' => 'কাজাখাস্তান সময় (আলমাটি)',
        'Asia/Amman' => 'পূর্ব ইউরোপীয় সময় (আম্মান)',
        'Asia/Anadyr' => 'পিত্রেপ্যাভলস্ক- ক্যামচ্যাটস্কি সময় (অ্যানাডির)',
        'Asia/Aqtau' => 'কাজাখাস্তান সময় (আকটাউ)',
        'Asia/Aqtobe' => 'কাজাখাস্তান সময় (আকটোবে)',
        'Asia/Ashgabat' => 'তুর্কমেনিস্তান সময় (আশগাবাত)',
        'Asia/Atyrau' => 'কাজাখাস্তান সময় (অতিরাউ)',
        'Asia/Baghdad' => 'আরবি সময় (বাগদাদ)',
        'Asia/Bahrain' => 'আরবি সময় (বাহারিন)',
        'Asia/Baku' => 'আজারবাইজান সময় (বাকু)',
        'Asia/Bangkok' => 'ইন্দোচীন সময় (ব্যাংকক)',
        'Asia/Barnaul' => 'ক্রাসনোয়ার্স্কি সময় (বার্নৌল)',
        'Asia/Beirut' => 'পূর্ব ইউরোপীয় সময় (বেইরুট)',
        'Asia/Bishkek' => 'কিরগিস্তান সময় (বিশকেক)',
        'Asia/Brunei' => 'ব্রুনেই দারুসসালাম সময়',
        'Asia/Calcutta' => 'ভারতীয় মানক সময় (কোলকাতা)',
        'Asia/Kolkata' => 'ভারতীয় মানক সময় (কোলকাতা)',
        'Asia/Chita' => 'ইয়াকুটাস্ক সময় (চিতা)',
        'Asia/Colombo' => 'ভারতীয় মানক সময় (কলম্বো)',
        'Asia/Damascus' => 'পূর্ব ইউরোপীয় সময় (দামাস্কাস)',
        'Asia/Dhaka' => 'বাংলাদেশ সময় (ঢাকা)',
        'Asia/Dili' => 'পূর্ব টিমর সময় (দিলি)',
        'Asia/Dubai' => 'উপসাগরীয় মানক সময় (দুবাই)',
        'Asia/Dushanbe' => 'তাজাখাস্তান সময় (দুশানবে)',
        'Asia/Famagusta' => 'পূর্ব ইউরোপীয় সময় (ফামাগাস্তা)',
        'Asia/Gaza' => 'পূর্ব ইউরোপীয় সময় (গাজা)',
        'Asia/Hebron' => 'পূর্ব ইউরোপীয় সময় (হেব্রোন)',
        'Asia/Hong_Kong' => 'হং কং সময়',
        'Asia/Hovd' => 'হোভড সময় (হোভ্ড)',
        'Asia/Irkutsk' => 'ইরকুটস্ক সময়',
        'Asia/Jakarta' => 'পশ্চিমী ইন্দোনেশিয়া সময় (জাকার্তা)',
        'Asia/Jayapura' => 'পূর্ব ইন্দোনেশিয়া সময় (জয়াপুরা)',
        'Asia/Jerusalem' => 'ইজরায়েল সময় (জেরুজালেম)',
        'Asia/Kabul' => 'আফগানিস্তান সময় (কাবুল)',
        'Asia/Kamchatka' => 'পিত্রেপ্যাভলস্ক- ক্যামচ্যাটস্কি সময় (কামচাটকা)',
        'Asia/Karachi' => 'পাকিস্তান সময় (করাচি)',
        'Asia/Katmandu' => 'নেপাল সময় (কাঠমান্ডু)',
        'Asia/Kathmandu' => 'নেপাল সময় (কাঠমান্ডু)',
        'Asia/Khandyga' => 'ইয়াকুটাস্ক সময় (খানডিয়াগা)',
        'Asia/Krasnoyarsk' => 'ক্রাসনোয়ার্স্কি সময় (ক্রাসনোইয়ার্স্ক)',
        'Asia/Kuala_Lumpur' => 'মালয়েশিয়া সময় (কুয়ালালামপুর)',
        'Asia/Kuching' => 'মালয়েশিয়া সময় (কুচিং)',
        'Asia/Kuwait' => 'আরবি সময় (কুয়েত)',
        'Asia/Macau' => 'চীন সময় (ম্যাকাও)',
        'Asia/Magadan' => 'ম্যাগাডান সময়',
        'Asia/Makassar' => 'কেন্দ্রীয় ইন্দোনেশিয়া সময় (মাকাসসার)',
        'Asia/Manila' => 'ফিলিপাইন সময় (ম্যানিলা)',
        'Asia/Muscat' => 'উপসাগরীয় মানক সময় (মাসকট)',
        'Asia/Nicosia' => 'পূর্ব ইউরোপীয় সময় (নিকোসিয়া)',
        'Asia/Novokuznetsk' => 'ক্রাসনোয়ার্স্কি সময় (নভকুয়েতস্নক)',
        'Asia/Novosibirsk' => 'ক্রাসনোয়ার্স্কি সময় (নভোসিবির্স্ক)',
        'Asia/Omsk' => 'ওমস্ক সময় (ওম্স্ক)',
        'Asia/Oral' => 'কাজাখাস্তান সময় (ওরাল)',
        'Asia/Phnom_Penh' => 'ইন্দোচীন সময় (নম পেন)',
        'Asia/Pontianak' => 'পশ্চিমী ইন্দোনেশিয়া সময় (পন্টিয়ান্যাক)',
        'Asia/Pyongyang' => 'কোরিয়ান সময় (পিয়ংইয়ং)',
        'Asia/Qatar' => 'আরবি সময় (কাতার)',
        'Asia/Qostanay' => 'কাজাখাস্তান সময় (কোস্টানয়)',
        'Asia/Qyzylorda' => 'কাজাখাস্তান সময় (কিজিলর্ডা)',
        'Asia/Rangoon' => 'মায়ানমার সময় (রেঙ্গুন)',
        'Asia/Yangon' => 'মায়ানমার সময় (রেঙ্গুন)',
        'Asia/Riyadh' => 'আরবি সময় (রিয়াধ)',
        'Asia/Saigon' => 'ইন্দোচীন সময় (হো চি মিন শহর)',
        'Asia/Ho_Chi_Minh' => 'ইন্দোচীন সময় (হো চি মিন শহর)',
        'Asia/Sakhalin' => 'ম্যাগাডান সময় (সাখালিন)',
        'Asia/Samarkand' => 'উজবেকিস্তান সময় (সমরখন্দ)',
        'Asia/Seoul' => 'কোরিয়ান সময় (সিওল)',
        'Asia/Shanghai' => 'চীন সময় (সাংহাই)',
        'Asia/Singapore' => 'সিঙ্গাপুর মানক সময়',
        'Asia/Srednekolymsk' => 'ম্যাগাডান সময় (স্রেদনেকোলয়মস্ক)',
        'Asia/Taipei' => 'তাইপেই সময়',
        'Asia/Tashkent' => 'উজবেকিস্তান সময় (তাসখন্দ)',
        'Asia/Tbilisi' => 'জর্জিয়া সময় (সিবিলিশি)',
        'Asia/Tehran' => 'ইরান সময় (তেহেরান)',
        'Asia/Thimphu' => 'ভুটান সময় (থিম্ফু)',
        'Asia/Tokyo' => 'জাপান সময় (টোকিও)',
        'Asia/Tomsk' => 'ক্রাসনোয়ার্স্কি সময় (তোমস্ক)',
        'Asia/Ulaanbaatar' => 'উলান বাতোর সময় (উলানবাতার)',
        'Asia/Urumqi' => 'চীন সময় (উরুমকি)',
        'Asia/Ust-Nera' => 'ভ্লাদিভস্তক সময় (উস্ত- নেরা)',
        'Asia/Vientiane' => 'ইন্দোচীন সময় (ভিয়েনতায়েন)',
        'Asia/Vladivostok' => 'ভ্লাদিভস্তক সময় (ভ্লাদিভস্তোক)',
        'Asia/Yakutsk' => 'ইয়াকুটাস্ক সময় (ইয়াকুটস্ক)',
        'Asia/Yekaterinburg' => 'ইয়েকাতেরিনবুর্গ সময় (ইয়েকাটেরিনবার্গ)',
        'Asia/Yerevan' => 'আর্মেনিয়া সময় (ইয়েরাভান)',
        'Atlantic/Azores' => 'এজোরেস সময় (আজোরেস)',
        'Atlantic/Bermuda' => 'অতলান্তিকের সময় (বারমুডা)',
        'Atlantic/Canary' => 'পশ্চিম ইউরোপীয় সময় (কানেরি)',
        'Atlantic/Cape_Verde' => 'কেপ ভার্দ সময়',
        'Atlantic/Faeroe' => 'পশ্চিম ইউরোপীয় সময় (ফ্যারো)',
        'Atlantic/Faroe' => 'পশ্চিম ইউরোপীয় সময় (ফ্যারো)',
        'Atlantic/Madeira' => 'পশ্চিম ইউরোপীয় সময় (মাডেইরা)',
        'Atlantic/Reykjavik' => 'গ্রীনিচ মিন টাইম (রিকজাভিক)',
        'Atlantic/South_Georgia' => 'দক্ষিণ জর্জিয়া সময়',
        'Atlantic/St_Helena' => 'গ্রীনিচ মিন টাইম (সেন্ট. হেলেনা)',
        'Atlantic/Stanley' => 'ফকল্যান্ড দ্বীপপুঞ্জ সময় (স্টানলী)',
        'Australia/Adelaide' => 'কেন্দ্রীয় অস্ট্রেলীয় সময় (এ্যাডেলেইড)',
        'Australia/Brisbane' => 'পূর্ব অস্ট্রেলীয় সময় (ব্রিসবেন)',
        'Australia/Broken_Hill' => 'কেন্দ্রীয় অস্ট্রেলীয় সময় (ব্রোকেন হিল)',
        'Australia/Darwin' => 'কেন্দ্রীয় অস্ট্রেলীয় সময় (ডারউইন)',
        'Australia/Eucla' => 'অস্ট্রেলীয় কেন্দ্রীয় পশ্চিমি সময় (ইউক্লা)',
        'Australia/Hobart' => 'পূর্ব অস্ট্রেলীয় সময় (হোবার্ট)',
        'Australia/Lindeman' => 'পূর্ব অস্ট্রেলীয় সময় (লিনডেম্যান)',
        'Australia/Lord_Howe' => 'লর্ড হাওয়ে সময়',
        'Australia/Melbourne' => 'পূর্ব অস্ট্রেলীয় সময় (মেলবোর্ন)',
        'Australia/Perth' => 'পশ্চিমি অস্ট্রেলীয় সময় (পার্থ)',
        'Australia/Sydney' => 'পূর্ব অস্ট্রেলীয় সময় (সিডনি)',
        'Etc/GMT' => 'গ্রীনিচ মিন টাইম',
        'Etc/UTC' => 'স্থানাংকিত আন্তর্জাতিক সময়',
        'Europe/Amsterdam' => 'মধ্য ইউরোপীয় সময় (আমস্টারডাম)',
        'Europe/Andorra' => 'মধ্য ইউরোপীয় সময় (অ্যান্ডোরা)',
        'Europe/Astrakhan' => 'সামারা সময় (আসট্রাখান)',
        'Europe/Athens' => 'পূর্ব ইউরোপীয় সময় (এথেন্স)',
        'Europe/Belgrade' => 'মধ্য ইউরোপীয় সময় (বেলগ্রেড)',
        'Europe/Berlin' => 'মধ্য ইউরোপীয় সময় (বার্লিন)',
        'Europe/Bratislava' => 'মধ্য ইউরোপীয় সময় (ব্রাতিস্লাভা)',
        'Europe/Brussels' => 'মধ্য ইউরোপীয় সময় (ব্রাসেলস)',
        'Europe/Bucharest' => 'পূর্ব ইউরোপীয় সময় (বুখারেস্ট)',
        'Europe/Budapest' => 'মধ্য ইউরোপীয় সময় (বুডাপেস্ট)',
        'Europe/Busingen' => 'মধ্য ইউরোপীয় সময় (বুসিনগেন)',
        'Europe/Chisinau' => 'পূর্ব ইউরোপীয় সময় (কিসিনাহু)',
        'Europe/Copenhagen' => 'মধ্য ইউরোপীয় সময় (কোপেনহেগেন)',
        'Europe/Dublin' => 'গ্রীনিচ মিন টাইম (ডাবলিন)',
        'Europe/Gibraltar' => 'মধ্য ইউরোপীয় সময় (জিব্রাল্টার)',
        'Europe/Guernsey' => 'গ্রীনিচ মিন টাইম (গুয়ার্নসি)',
        'Europe/Helsinki' => 'পূর্ব ইউরোপীয় সময় (হেলসিঙ্কি)',
        'Europe/Isle_of_Man' => 'গ্রীনিচ মিন টাইম (আইল অফ ম্যান)',
        'Europe/Istanbul' => 'তুরস্ক সময় (ইস্তানবুল)',
        'Europe/Jersey' => 'গ্রীনিচ মিন টাইম (জার্সি)',
        'Europe/Kaliningrad' => 'পূর্ব ইউরোপীয় সময় (কালিনিঙগ্রাড)',
        'Europe/Kiev' => 'পূর্ব ইউরোপীয় সময় (কিয়েভ)',
        'Europe/Kyiv' => 'পূর্ব ইউরোপীয় সময় (কিয়েভ)',
        'Europe/Kirov' => 'মস্কো সময় (কিরোভ)',
        'Europe/Lisbon' => 'পশ্চিম ইউরোপীয় সময় (লিসবন)',
        'Europe/Ljubljana' => 'মধ্য ইউরোপীয় সময় (লুবলিয়ানা)',
        'Europe/London' => 'গ্রীনিচ মিন টাইম (লন্ডন)',
        'Europe/Luxembourg' => 'মধ্য ইউরোপীয় সময় (লুক্সেমবার্গ)',
        'Europe/Madrid' => 'মধ্য ইউরোপীয় সময় (মাদ্রিদ)',
        'Europe/Malta' => 'মধ্য ইউরোপীয় সময় (মাল্টা)',
        'Europe/Mariehamn' => 'পূর্ব ইউরোপীয় সময় (মরিয়েহামেন)',
        'Europe/Minsk' => 'মস্কো সময় (মিন্সক)',
        'Europe/Monaco' => 'মধ্য ইউরোপীয় সময় (মোনাকো)',
        'Europe/Moscow' => 'মস্কো সময়',
        'Europe/Oslo' => 'মধ্য ইউরোপীয় সময় (অসলো)',
        'Europe/Paris' => 'মধ্য ইউরোপীয় সময় (প্যারিস)',
        'Europe/Podgorica' => 'মধ্য ইউরোপীয় সময় (পডগরিত্সা)',
        'Europe/Prague' => 'মধ্য ইউরোপীয় সময় (প্রাগ)',
        'Europe/Riga' => 'পূর্ব ইউরোপীয় সময় (রিগা)',
        'Europe/Rome' => 'মধ্য ইউরোপীয় সময় (রোম)',
        'Europe/Samara' => 'সামারা সময়',
        'Europe/San_Marino' => 'মধ্য ইউরোপীয় সময় (সান মেরিনো)',
        'Europe/Sarajevo' => 'মধ্য ইউরোপীয় সময় (সারাজিভো)',
        'Europe/Saratov' => 'সামারা সময় (সারাটোভ)',
        'Europe/Simferopol' => 'মস্কো সময় (সিমফেরোপোল)',
        'Europe/Skopje' => 'মধ্য ইউরোপীয় সময় (স্কপয়ে)',
        'Europe/Sofia' => 'পূর্ব ইউরোপীয় সময় (সোফিয়া)',
        'Europe/Stockholm' => 'মধ্য ইউরোপীয় সময় (স্টকহোম)',
        'Europe/Tallinn' => 'পূর্ব ইউরোপীয় সময় (তাহলিন)',
        'Europe/Tirane' => 'মধ্য ইউরোপীয় সময় (তিরানা)',
        'Europe/Ulyanovsk' => 'সামারা সময় (উলিয়ানোভস্ক)',
        'Europe/Vaduz' => 'মধ্য ইউরোপীয় সময় (ভাদুজ)',
        'Europe/Vatican' => 'মধ্য ইউরোপীয় সময় (ভাটিকান)',
        'Europe/Vienna' => 'মধ্য ইউরোপীয় সময় (ভিয়েনা)',
        'Europe/Vilnius' => 'পূর্ব ইউরোপীয় সময় (ভিলনিওস)',
        'Europe/Volgograd' => 'মস্কো সময় (ভোল্গোগ্রাদ)',
        'Europe/Warsaw' => 'মধ্য ইউরোপীয় সময় (ওয়ারশ)',
        'Europe/Zagreb' => 'মধ্য ইউরোপীয় সময় (জাগ্রেব)',
        'Europe/Zurich' => 'মধ্য ইউরোপীয় সময় (জুরিখ)',
        'Indian/Antananarivo' => 'পূর্ব আফ্রিকা সময় (আন্তুনানারিভো)',
        'Indian/Chagos' => 'ভারত মহাসাগরীয় সময় (ছাগোস)',
        'Indian/Christmas' => 'ক্রিসমাস দ্বীপ সময়',
        'Indian/Cocos' => 'কোকোস দ্বীপপুঞ্জ সময়',
        'Indian/Comoro' => 'পূর্ব আফ্রিকা সময় (কোমোরো)',
        'Indian/Kerguelen' => 'ফরাসি দক্ষিণ এবং আন্টার্কটিক সময় (কার্গুলেন)',
        'Indian/Mahe' => 'সেশেলস সময় (মাহে)',
        'Indian/Maldives' => 'মালদ্বীপ সময়',
        'Indian/Mauritius' => 'মরিশাস সময়',
        'Indian/Mayotte' => 'পূর্ব আফ্রিকা সময় (মায়োতো)',
        'Indian/Reunion' => 'রিইউনিয়ন সময়',
        'Pacific/Apia' => 'অপিয়া সময় (আপিয়া)',
        'Pacific/Auckland' => 'নিউজিল্যান্ড সময় (অকল্যান্ড)',
        'Pacific/Bougainville' => 'পাপুয়া নিউ গিনি সময় (বুগেনভিলে)',
        'Pacific/Chatham' => 'চ্যাথাম সময় (চ্যাঠাম)',
        'Pacific/Easter' => 'ইস্টার দ্বীপ সময়',
        'Pacific/Efate' => 'ভানুয়াতু সময় (ইফাতে)',
        'Pacific/Enderbury' => 'ফোনিক্স দ্বীপপুঞ্জ সময় (ক্যান্টন)',
        'Pacific/Kanton' => 'ফোনিক্স দ্বীপপুঞ্জ সময় (ক্যান্টন)',
        'Pacific/Fakaofo' => 'টোকেলাউ সময় (ফ্যাকাওফো)',
        'Pacific/Fiji' => 'ফিজি সময়',
        'Pacific/Funafuti' => 'টুভালু সময় (ফুনাফুটি)',
        'Pacific/Galapagos' => 'গালাপাগোস সময় (গ্যালাপ্যাগোস)',
        'Pacific/Gambier' => 'গ্যাম্বিয়ার সময় (গাম্বিয়ের)',
        'Pacific/Guadalcanal' => 'সলোমন দ্বীপপুঞ্জ সময় (গোয়াদালকুনাল)',
        'Pacific/Guam' => 'চামেরো মানক সময় (গুয়াম)',
        'Pacific/Honolulu' => 'হাওয়াই-আলেউত মানক সময় (হনোলুলু)',
        'Pacific/Kiritimati' => 'লাইন দ্বীপপুঞ্জ সময় (কিরিতিমাতি)',
        'Pacific/Kosrae' => 'কোসরেই সময় (কোসরায়)',
        'Pacific/Kwajalein' => 'মার্শাল দ্বীপপুঞ্জ সময় (কোয়াজালেইন)',
        'Pacific/Majuro' => 'মার্শাল দ্বীপপুঞ্জ সময় (মাজুরো)',
        'Pacific/Marquesas' => 'মার্কেসাস সময়',
        'Pacific/Midway' => 'সামোয়া সময় (মিডওয়ে)',
        'Pacific/Nauru' => 'নাউরু সময়',
        'Pacific/Niue' => 'নিউই সময় (নিউয়ি)',
        'Pacific/Norfolk' => 'নরফোক দ্বীপ সময় (নরফক)',
        'Pacific/Noumea' => 'নিউ ক্যালেডোনিয়া সময় (নুমিয়া)',
        'Pacific/Pago_Pago' => 'সামোয়া সময় (প্যাগো প্যাগো)',
        'Pacific/Palau' => 'পালাউ সময়',
        'Pacific/Pitcairn' => 'পিটকেয়ার্ন সময়',
        'Pacific/Ponape' => 'পোনাপে সময়',
        'Pacific/Pohnpei' => 'পোনাপে সময়',
        'Pacific/Port_Moresby' => 'পাপুয়া নিউ গিনি সময় (পোর্ট মৌরজবি)',
        'Pacific/Rarotonga' => 'কুক দ্বীপপুঞ্জ সময় (রারউহতুঙ্গা)',
        'Pacific/Saipan' => 'চামেরো মানক সময় (সাইপান)',
        'Pacific/Tahiti' => 'তাহিতি সময়',
        'Pacific/Tarawa' => 'গিলবার্ট দ্বীপপুঞ্জ সময় (টারাওয়া)',
        'Pacific/Tongatapu' => 'টোঙ্গা সময় (টোঙ্গাটাপু)',
        'Pacific/Truk' => 'চুক সময়',
        'Pacific/Chuuk' => 'চুক সময়',
        'Pacific/Wake' => 'ওয়েক দ্বীপ সময়',
        'Pacific/Wallis' => 'ওয়ালিস এবং ফুটুনা সময় (ওলিস)',
    ],
    'Meta' => [
        'GmtFormat' => 'GMT %s',
    ],
];
