<?php

return [
    'Names' => [
        'aa' => 'افار ءتىلى',
        'ab' => 'ابحاز ءتىلى',
        'af' => 'افريكاانس ءتىلى',
        'agq' => 'اگەم ءتىلى',
        'ak' => 'اكان ءتىلى',
        'am' => 'امحار ءتىلى',
        'an' => 'اراگون ءتىلى',
        'ann' => 'وبولو ءتىلى',
        'apc' => 'شامي ءتىلى',
        'ar' => 'اراب ءتىلى',
        'arn' => 'ماپۋچە ءتىلى',
        'as' => 'اسسام ءتىلى',
        'asa' => 'اسۋ ءتىلى',
        'ast' => 'استرۋيا ءتىلى',
        'az' => 'ءازىربايجان ءتىلى',
        'ba' => 'باشقۇرت ءتىلى',
        'bal' => 'بالۋچي ءتىلى',
        'bas' => 'باسا ءتىلى',
        'be' => 'بەلارۋس ءتىلى',
        'bem' => 'بەمبا ءتىلى',
        'bew' => 'بەياۋي ءتىلى',
        'bez' => 'بەنا ءتىلى',
        'bg' => 'بولگار ءتىلى',
        'bgc' => 'حارياني ءتىلى',
        'bgn' => 'باتىس بالۋچي ءتىلى',
        'bho' => 'بحودجپۋري ءتىلى',
        'blo' => 'اني ءتىلى',
        'blt' => 'تاي دام ءتىلى',
        'bm' => 'بامبارا ءتىلى',
        'bn' => 'بەنگال ءتىلى',
        'bo' => 'تيبەت ءتىلى',
        'bqi' => 'باحتيار ءتىلى',
        'br' => 'برەتون ءتىلى',
        'brx' => 'بودو ءتىلى',
        'bs' => 'بوسنيا ءتىلى',
        'bss' => 'اكوسە ءتىلى',
        'bua' => 'بۋريات ءتىلى',
        'byn' => 'بلين ءتىلى',
        'ca' => 'كاتالان ءتىلى',
        'cad' => 'كاددو ءتىلى',
        'cch' => 'اتسام ءتىلى',
        'ccp' => 'چاكما ءتىلى',
        'ce' => 'شەشەن ءتىلى',
        'ceb' => 'سەبۋانو ءتىلى',
        'cgg' => 'كيگا ءتىلى',
        'cho' => 'چوكتو ءتىلى',
        'chr' => 'چەروكي ءتىلى',
        'cic' => 'چيكاساۋ ءتىلى',
        'ckb' => 'سوراني ءتىلى',
        'co' => 'كورسيكا ءتىلى',
        'cop' => 'كوپىت ءتىلى',
        'cs' => 'چەح ءتىلى',
        'csw' => 'باتپاقتى جەردىڭ كري ءتىلى',
        'cu' => 'شىركەۋلىك سلاۆيان ءتىلى',
        'cv' => 'چۋۆاش ءتىلى',
        'cy' => 'ۆاللي ءتىلى',
        'da' => 'دات ءتىلى',
        'dav' => 'تايتا ءتىلى',
        'de' => 'نەمىس ءتىلى',
        'dje' => 'زارما ءتىلى',
        'doi' => 'دوگري ءتىلى',
        'dsb' => 'تومەنگى سوربيان ءتىلى',
        'dua' => 'دۋالا ءتىلى',
        'dv' => 'ديۆەحي ءتىلى',
        'dyo' => 'ديولا ءتىلى',
        'dz' => 'جوڭكا ءتىلى',
        'ebu' => 'ەمبۋ ءتىلى',
        'ee' => 'ەۆە ءتىلى',
        'el' => 'گرەك ءتىلى',
        'en' => 'اعىلشىن ءتىلى',
        'eo' => 'ەسپەرانتو ءتىلى',
        'es' => 'يسپان ءتىلى',
        'et' => 'ەستون ءتىلى',
        'eu' => 'باسك ءتىلى',
        'ewo' => 'ەۆوندو ءتىلى',
        'fa' => 'پارسى ءتىلى',
        'ff' => 'فۋلا ءتىلى',
        'fi' => 'فين ءتىلى',
        'fil' => 'فيليپين ءتىلى',
        'fo' => 'فارەر ءتىلى',
        'fr' => 'فرانسۋز ءتىلى',
        'frc' => 'كاجۋن ءتىلى',
        'frr' => 'سولتۇستىك-شىعىس كري ءتىلى',
        'fur' => 'فريۋل ءتىلى',
        'fy' => 'باتىس فريز ءتىلى',
        'ga' => 'يرلاند ءتىلى',
        'gaa' => 'گا ءتىلى',
        'gd' => 'شوتلانديالىق گەل ءتىلى',
        'gez' => 'گەەز ءتىلى',
        'gl' => 'گاليسيا ءتىلى',
        'gn' => 'گۋاريني ءتىلى',
        'gsw' => 'شۆەيساريالىق نەمىس ءتىلى',
        'gu' => 'گۋجاراتي ءتىلى',
        'guz' => 'گۋسي ءتىلى',
        'gv' => 'مەن ءتىلى',
        'ha' => 'حاۋسا ءتىلى',
        'haw' => 'حاۋاي ءتىلى',
        'he' => 'يۆريت ءتىلى',
        'hi' => 'حيندي ءتىلى',
        'hnj' => 'حموڭ نيۋا ءتىلى',
        'hr' => 'حورۆات ءتىلى',
        'hsb' => 'جوعارعى سوربيان ءتىلى',
        'ht' => 'گايتيان كىرەول ءتىلى',
        'hu' => 'ماجار ءتىلى',
        'hy' => 'ارميان ءتىلى',
        'ia' => 'ينتەرلينگۆا ءتىلى',
        'id' => 'يندونەزيا ءتىلى',
        'ie' => 'ينتەرلينگۆە ءتىلى',
        'ig' => 'يگبو ءتىلى',
        'ii' => 'سىچۋان ي ءتىلى',
        'io' => 'يدو ءتىلى',
        'is' => 'يسلاند ءتىلى',
        'it' => 'يتاليان ءتىلى',
        'iu' => 'ينۋكتيتۋت ءتىلى',
        'ja' => 'جاپون ءتىلى',
        'jbo' => 'لاجبان ءتىلى',
        'jgo' => 'نگومبا ءتىلى',
        'jmc' => 'ماچامە ءتىلى',
        'jv' => 'ياۆا ءتىلى',
        'ka' => 'گرۋزين ءتىلى',
        'kaa' => 'قاراقالپاق ءتىلى',
        'kab' => 'كابيل ءتىلى',
        'kaj' => 'كاجي ءتىلى',
        'kam' => 'كامبا ءتىلى',
        'kcg' => 'تياپ ءتىلى',
        'kde' => 'ماكوندە ءتىلى',
        'kea' => 'كابۋۆەرديانۋ ءتىلى',
        'kek' => 'كەكچي ءتىلى',
        'ken' => 'كەنياڭ ءتىلى',
        'kgp' => 'كاينگاڭ ءتىلى',
        'khq' => 'كويرا چيني ءتىلى',
        'ki' => 'كيكۋيۋ ءتىلى',
        'kk' => 'قازاق ءتىلى',
        'kkj' => 'كاكو ءتىلى',
        'kl' => 'كالاليسۋت ءتىلى',
        'kln' => 'كالەنجين ءتىلى',
        'km' => 'كحمەر ءتىلى',
        'kn' => 'كاننادا ءتىلى',
        'ko' => 'كورەي ءتىلى',
        'kok' => 'كونكاني ءتىلى',
        'kpe' => 'كپەلە ءتىلى',
        'ks' => 'كاشمير ءتىلى',
        'ksb' => 'شامبالا ءتىلى',
        'ksf' => 'بافيا ءتىلى',
        'ksh' => 'كولونيان ءتىلى',
        'ku' => 'كۇرد ءتىلى',
        'kw' => 'كورن ءتىلى',
        'kxv' => 'كۋۆي ءتىلى',
        'ky' => 'قىرعىز ءتىلى',
        'la' => 'لاتىن ءتىلى',
        'lag' => 'لانگي ءتىلى',
        'lb' => 'ليۋكسەمبۋرگ ءتىلى',
        'lg' => 'گاندا ءتىلى',
        'lij' => 'ليگۋر ءتىلى',
        'lkt' => 'لاكوتا ءتىلى',
        'lld' => 'لادينو ءتىلى',
        'lmo' => 'لومبارد ءتىلى',
        'ln' => 'لينگالا ءتىلى',
        'lo' => 'لاوس ءتىلى',
        'lou' => 'كىرەول ءتىلى',
        'lrc' => 'سولتۇستىك فريز ءتىلى',
        'lt' => 'ليتۆا ءتىلى',
        'ltg' => 'لاتگاليان ءتىلى',
        'lu' => 'لۋبا-كاتاڭا ءتىلى',
        'luo' => 'لۋو ءتىلى',
        'luy' => 'لۋحيا ءتىلى',
        'lv' => 'لاتىش ءتىلى',
        'lzz' => 'لاز ءتىلى',
        'mai' => 'مايتحيلي ءتىلى',
        'mas' => 'ماساي ءتىلى',
        'mdf' => 'موكشا ءتىلى',
        'mer' => 'مەرۋ ءتىلى',
        'mfe' => 'موريسيەن ءتىلى',
        'mg' => 'مالاگاسي ءتىلى',
        'mgh' => 'ماكۋا-مەتتو ءتىلى',
        'mgo' => 'مەتا ءتىلى',
        'mhn' => 'موكەنو ءتىلى',
        'mi' => 'ماوري ءتىلى',
        'mic' => 'ميكماۋ ءتىلى',
        'mk' => 'ماكەدون ءتىلى',
        'ml' => 'مالايالام ءتىلى',
        'mn' => 'موڭعول ءتىلى',
        'mni' => 'مانيپۋري ءتىلى',
        'moh' => 'موحاۋك ءتىلى',
        'mr' => 'ماراتحي ءتىلى',
        'ms' => 'مالاي ءتىلى',
        'mt' => 'مالتا ءتىلى',
        'mua' => 'مۋنداڭ ءتىلى',
        'mus' => 'كريك ءتىلى',
        'my' => 'بيرما ءتىلى',
        'myv' => 'ەرزيا ءتىلى',
        'mzn' => 'مازاندەران ءتىلى',
        'naq' => 'ناما ءتىلى',
        'nb' => 'نورۆەگيالىق بۋكمول ءتىلى',
        'nd' => 'سولتۇستىك ندەبەلە ءتىلى',
        'nds' => 'تومەنگى نەمىس ءتىلى',
        'ne' => 'نەپال ءتىلى',
        'nl' => 'نيدەرلاند ءتىلى',
        'nmg' => 'كۋاسيو ءتىلى',
        'nn' => 'نورۆەگيالىق نيۋنورسك ءتىلى',
        'nnh' => 'نگيەمبۋن ءتىلى',
        'no' => 'نورۆەگ ءتىلى',
        'nqo' => 'نكو ءتىلى',
        'nr' => 'وڭتۇستىك ندەبەلە ءتىلى',
        'nso' => 'سولتۇستىك سوتو ءتىلى',
        'nus' => 'نۋەر ءتىلى',
        'nv' => 'ناۆاحو ءتىلى',
        'ny' => 'نيانجا ءتىلى',
        'nyn' => 'نيانكولە ءتىلى',
        'oc' => 'وكسيتان ءتىلى',
        'om' => 'ورومو ءتىلى',
        'or' => 'وريا ءتىلى',
        'os' => 'وسەتين ءتىلى',
        'osa' => 'وسەيج ءتىلى',
        'pa' => 'پەنجاب ءتىلى',
        'pap' => 'پاپيامەنتو ءتىلى',
        'pcm' => 'نيگەريالىق پيدجين ءتىلى',
        'pi' => 'پالي ءتىلى',
        'pis' => 'پيجين ءتىلى',
        'pl' => 'پولياك ءتىلى',
        'pms' => 'پيەمونت ءتىلى',
        'prg' => 'پرۋسسيا ءتىلى',
        'ps' => 'پۋشتۋ ءتىلى',
        'pt' => 'پورتۋگال ءتىلى',
        'qu' => 'كەچۋا ءتىلى',
        'quc' => 'كيچە ءتىلى',
        'raj' => 'راجاستاني ءتىلى',
        'rhg' => 'روحينجا ءتىلى',
        'rif' => 'ريفيان ءتىلى',
        'rm' => 'رومانش ءتىلى',
        'rn' => 'رۋندي ءتىلى',
        'ro' => 'رۋمىن ءتىلى',
        'rof' => 'رومبو ءتىلى',
        'ru' => 'ورىس ءتىلى',
        'rw' => 'كينيارۋاندا ءتىلى',
        'rwk' => 'رۋا ءتىلى',
        'sa' => 'سانسكريت ءتىلى',
        'sah' => 'ساحا ءتىلى',
        'saq' => 'سامبۋرۋ ءتىلى',
        'sat' => 'سانتالي ءتىلى',
        'sbp' => 'ساڭۋ ءتىلى',
        'sc' => 'ساردين ءتىلى',
        'scn' => 'سيسيليا ءتىلى',
        'sd' => 'سيندحي ءتىلى',
        'sdh' => 'وڭتۇستىك كۇرد ءتىلى',
        'se' => 'سولتۇستىك سامي ءتىلى',
        'seh' => 'سەنا ءتىلى',
        'ses' => 'كويرابورو سەنني ءتىلى',
        'sg' => 'ساڭو ءتىلى',
        'sgs' => 'ساموگيتيان ءتىلى',
        'shi' => 'تاشەلحيت ءتىلى',
        'shn' => 'شان ءتىلى',
        'si' => 'سينگال ءتىلى',
        'sid' => 'سيدامو ءتىلى',
        'sk' => 'سلوۆاك ءتىلى',
        'skr' => 'سارايكي ءتىلى',
        'sl' => 'سلوۆەن ءتىلى',
        'sma' => 'وڭتۇستىك سامي ءتىلى',
        'smj' => 'لۋلە-سامي ءتىلى',
        'smn' => 'يناري سامي ءتىلى',
        'sms' => 'كولتا سامي ءتىلى',
        'sn' => 'شونا ءتىلى',
        'so' => 'سومالي ءتىلى',
        'sq' => 'البان ءتىلى',
        'sr' => 'سەرب ءتىلى',
        'ss' => 'سۋاتي ءتىلى',
        'ssy' => 'ساحو ءتىلى',
        'st' => 'وڭتۇستىك سوتو ءتىلى',
        'su' => 'سۋدان ءتىلى',
        'sv' => 'شۆەد ءتىلى',
        'sw' => 'سۋاحيلي ءتىلى',
        'syr' => 'سيريا ءتىلى',
        'szl' => 'سيلەز ءتىلى',
        'ta' => 'تاميل ءتىلى',
        'te' => 'تەلۋگۋ ءتىلى',
        'teo' => 'تەسو ءتىلى',
        'tg' => 'تاجىك ءتىلى',
        'th' => 'تاي ءتىلى',
        'ti' => 'تيگرينيا ءتىلى',
        'tig' => 'تيگرە ءتىلى',
        'tk' => 'تۇرىكمەن ءتىلى',
        'tn' => 'سۋانا ءتىلى',
        'to' => 'تونگان ءتىلى',
        'tok' => 'توكي-پونا ءتىلى',
        'tpi' => 'توك-پيسين ءتىلى',
        'tr' => 'تۇرىك ءتىلى',
        'trv' => 'تاروكو ءتىلى',
        'trw' => 'توۋالي ءتىلى',
        'ts' => 'سونگا ءتىلى',
        'tt' => 'تاتار ءتىلى',
        'twq' => 'تاساۋاك ءتىلى',
        'tyv' => 'تۋۆين ءتىلى',
        'tzm' => 'ورتالىق اتلاس تامازيگحت ءتىلى',
        'ug' => 'ۇيعىر ءتىلى',
        'uk' => 'ۋكراين ءتىلى',
        'ur' => 'ۋردۋ ءتىلى',
        'uz' => 'وزبەك ءتىلى',
        'vai' => 'ۆاي ءتىلى',
        've' => 'ۆەندا ءتىلى',
        'vec' => 'ۆەنەسيا ءتىلى',
        'vi' => 'ۆيەتنام ءتىلى',
        'vmw' => 'ماكۋا ءتىلى',
        'vo' => 'ۆولاپيۋك ءتىلى',
        'vun' => 'ۆۋنجو ءتىلى',
        'wa' => 'ۋالون ءتىلى',
        'wae' => 'ۋالسەر ءتىلى',
        'wal' => 'ۋولايتا ءتىلى',
        'wbp' => 'ۋالبيري ءتىلى',
        'wo' => 'ۆولوف ءتىلى',
        'xh' => 'كحوسا ءتىلى',
        'xnr' => 'كاڭري ءتىلى',
        'xog' => 'سوگا ءتىلى',
        'yav' => 'ياڭبەن ءتىلى',
        'yi' => 'يديش ءتىلى',
        'yo' => 'يورۋبا ءتىلى',
        'yrl' => 'نەنگاتۋ ءتىلى',
        'yue' => 'گۋاڭدۇڭ ءتىلى',
        'za' => 'جۋاڭ ءتىلى',
        'zgh' => 'ماروككولىق ستاندارتتى تامازيگحت ءتىلى',
        'zh' => 'قىتاي ءتىلى',
        'zu' => 'زۋلۋ ءتىلى',
    ],
    'LocalizedNames' => [
        'ar_001' => 'قازىرگى ستاندارتتى اراب ءتىلى',
        'fa_AF' => 'داري ءتىلى',
        'kk_Arab' => 'قازاق ءتىلى (توتە)',
        'nds_NL' => 'تومەنگى ساكسون ءتىلى',
        'nl_BE' => 'فلاماند ءتىلى',
        'pt_BR' => 'برازيليالىق پورتۋگال ءتىلى',
        'pt_PT' => 'ەۋروپالىق پورتۋگال ءتىلى',
        'ro_MD' => 'مولدوۆان ءتىلى',
        'sw_CD' => 'كونگو سۋاحيلي ءتىلى',
        'zh_Hans' => 'جەڭىلدەتىلگەن قىتاي ءتىلى',
        'zh_Hant' => 'ءداستۇرلى قىتاي ءتىلى',
    ],
];
