<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'متحده عرب امارات درهم',
        ],
        'AFA' => [
            'AFA',
            'افغانۍ (1927–2002)',
        ],
        'AFN' => [
            '؋',
            'افغانۍ',
        ],
        'ALL' => [
            'ALL',
            'البانوي لک',
        ],
        'AMD' => [
            'AMD',
            'ارمينيايي ډرام',
        ],
        'ANG' => [
            'ANG',
            'هالېنډي انټيليايي ګيلډر',
        ],
        'AOA' => [
            'AOA',
            'انګولي کوانزا',
        ],
        'ARS' => [
            'ARS',
            'ارجنټاين پسو',
        ],
        'AUD' => [
            'A$',
            'آسترالوي ډالر',
        ],
        'AWG' => [
            'AWG',
            'اروبايي فلورن',
        ],
        'AZN' => [
            'AZN',
            'آزربايجاني منت',
        ],
        'BAM' => [
            'BAM',
            'بوسنيا هرزګوينيايي بدلېدونکې مارک',
        ],
        'BBD' => [
            'BBD',
            'باربيډين ډالر',
        ],
        'BDT' => [
            'BDT',
            'بنګالۍ ټاکه',
        ],
        'BGN' => [
            'BGN',
            'بلغاري ليو',
        ],
        'BHD' => [
            'BHD',
            'بحريني دينار',
        ],
        'BIF' => [
            'BIF',
            'برونډي فرانک',
        ],
        'BMD' => [
            'BMD',
            'برمودا ډالر',
        ],
        'BND' => [
            'BND',
            'برونايي ډالر',
        ],
        'BOB' => [
            'BOB',
            'بوليوي بوليويانو',
        ],
        'BRL' => [
            'R$',
            'برازيلي ريل',
        ],
        'BSD' => [
            'BSD',
            'بهاماسي ډالر',
        ],
        'BTN' => [
            'BTN',
            'بهوټانۍ انګولټرم',
        ],
        'BWP' => [
            'BWP',
            'بوټسواني پولا',
        ],
        'BYN' => [
            'BYN',
            'بلاروسي روبل',
        ],
        'BZD' => [
            'BZD',
            'بليز ډالر',
        ],
        'CAD' => [
            'CA$',
            'کاناډايي ډالر',
        ],
        'CDF' => [
            'CDF',
            'کانګولي فرانک',
        ],
        'CHF' => [
            'CHF',
            'سويسي فرانک',
        ],
        'CLP' => [
            'CLP',
            'چلي پسو',
        ],
        'CNH' => [
            'CNH',
            'چيني يوان (آف شور)',
        ],
        'CNY' => [
            'CN¥',
            'چيني يوان',
        ],
        'COP' => [
            'COP',
            'کولمبين پسو',
        ],
        'CRC' => [
            'CRC',
            'کوسټا ريکن کولون',
        ],
        'CUC' => [
            'CUC',
            'کيوبايي بدلېدونکي پسو',
        ],
        'CUP' => [
            'CUP',
            'کيوبايي پسو',
        ],
        'CVE' => [
            'CVE',
            'کيپ وردين اسکوډو',
        ],
        'CZK' => [
            'CZK',
            'چيک کرونا',
        ],
        'DJF' => [
            'DJF',
            'جبوتي فرانک',
        ],
        'DKK' => [
            'DKK',
            'ډنمارکي کرون',
        ],
        'DOP' => [
            'DOP',
            'دومينيکا پسو',
        ],
        'DZD' => [
            'DZD',
            'الجيرين دينار',
        ],
        'EGP' => [
            'EGP',
            'مصري پونډ',
        ],
        'ERN' => [
            'ERN',
            'ايريټرين نکفا',
        ],
        'ETB' => [
            'ETB',
            'ايتهوپيايي بر',
        ],
        'EUR' => [
            '€',
            'يورو',
        ],
        'FJD' => [
            'FJD',
            'فجي ډالر',
        ],
        'FKP' => [
            'FKP',
            'پاکلېنډ ټاپوګانو پونډ',
        ],
        'GBP' => [
            '£',
            'برتانوې پونډ',
        ],
        'GEL' => [
            'GEL',
            'جارجیاېي لارې',
        ],
        'GHS' => [
            'GHS',
            'ګانين سيډي',
        ],
        'GIP' => [
            'GIP',
            'جبل الطارقي پونډ',
        ],
        'GMD' => [
            'GMD',
            'ګيمبين دلاسې',
        ],
        'GNF' => [
            'GNF',
            'ګنې فرانک',
        ],
        'GTQ' => [
            'GTQ',
            'ګويټيمالن کوټزل',
        ],
        'GYD' => [
            'GYD',
            'ګايانيز ډالر',
        ],
        'HKD' => [
            'HK$',
            'هانګ کانګ ډالر',
        ],
        'HNL' => [
            'HNL',
            'هونډوران ليمپيرا',
        ],
        'HRK' => [
            'HRK',
            'کروشيايي کونا',
        ],
        'HTG' => [
            'HTG',
            'هيټي ګورډ',
        ],
        'HUF' => [
            'HUF',
            'هنګري فورنټ',
        ],
        'IDR' => [
            'IDR',
            'انډونيشي روپيا',
        ],
        'ILS' => [
            '₪',
            'اسرايلي نيو شيکل',
        ],
        'INR' => [
            '₹',
            'هندي روپۍ',
        ],
        'IQD' => [
            'IQD',
            'عراقي دينار',
        ],
        'IRR' => [
            'IRR',
            'ايراني ريال',
        ],
        'ISK' => [
            'ISK',
            'آيسلېنډي کرونا',
        ],
        'JMD' => [
            'JMD',
            'جمايکايي ډالر',
        ],
        'JOD' => [
            'JOD',
            'اردني دينار',
        ],
        'JPY' => [
            'JP¥',
            'جاپاني ين',
        ],
        'KES' => [
            'KES',
            'کينيايي شيلنګ',
        ],
        'KGS' => [
            'KGS',
            'کرغزستاني سوم',
        ],
        'KHR' => [
            'KHR',
            'کمبوډي ريل',
        ],
        'KMF' => [
            'KMF',
            'کوموري فرانک',
        ],
        'KPW' => [
            'KPW',
            'شمالي کوريايي وان',
        ],
        'KRW' => [
            '₩',
            'جنوبي کوريايي وان',
        ],
        'KWD' => [
            'KWD',
            'کويتي دينار',
        ],
        'KYD' => [
            'KYD',
            'کيمن ټاپوګانو ډالر',
        ],
        'KZT' => [
            'KZT',
            'قازقستاني ټينج',
        ],
        'LAK' => [
            'LAK',
            'لاشې کپ',
        ],
        'LBP' => [
            'LBP',
            'لبناني پونډ',
        ],
        'LKR' => [
            'LKR',
            'سري لنکن روپۍ',
        ],
        'LRD' => [
            'LRD',
            'لايبيرين ډالر',
        ],
        'LSL' => [
            'LSL',
            'Lesotho Loti',
        ],
        'LYD' => [
            'LYD',
            'ليبياېي دينار',
        ],
        'MAD' => [
            'MAD',
            'مراکشي درهم',
        ],
        'MDL' => [
            'MDL',
            'مالډوي ليو',
        ],
        'MGA' => [
            'MGA',
            'ملاګاسي ارياري',
        ],
        'MKD' => [
            'MKD',
            'مسيډونايي دينار',
        ],
        'MMK' => [
            'MMK',
            'ميانماري کيات',
        ],
        'MNT' => [
            'MNT',
            'منګوليايي توګريک',
        ],
        'MOP' => [
            'MOP',
            'مکانيس پټاکا',
        ],
        'MRU' => [
            'MRU',
            'موريشيسي ډالر',
        ],
        'MUR' => [
            'MUR',
            'موريشيسي روپۍ',
        ],
        'MVR' => [
            'MVR',
            'مالديپي روپيا',
        ],
        'MWK' => [
            'MWK',
            'ملاوي کواچا',
        ],
        'MXN' => [
            'MX$',
            'ميکسيکن پيسو',
        ],
        'MYR' => [
            'MYR',
            'ملايشي رنګټ',
        ],
        'MZN' => [
            'MZN',
            'موزمبيقي ميټيکل',
        ],
        'NAD' => [
            'NAD',
            'نيميبيايي ډالر',
        ],
        'NGN' => [
            'NGN',
            'نايجيري نايرا',
        ],
        'NIO' => [
            'NIO',
            'نيکاراګون کورډوبا',
        ],
        'NOK' => [
            'NOK',
            'نارويجين کرون',
        ],
        'NPR' => [
            'NPR',
            'نيپالي روپۍ',
        ],
        'NZD' => [
            'NZ$',
            'نيوزي لينډي ډالر',
        ],
        'OMR' => [
            'OMR',
            'عماني ريال',
        ],
        'PAB' => [
            'PAB',
            'پانامۍ بالبوا',
        ],
        'PEN' => [
            'PEN',
            'پيروين سول',
        ],
        'PGK' => [
            'PGK',
            'پاپوا نيوګاني کينا',
        ],
        'PHP' => [
            '₱',
            'فلپاينۍ پیسو',
        ],
        'PKR' => [
            'PKR',
            'پاکستانۍ کلداره',
        ],
        'PLN' => [
            'PLN',
            'پولينډي زلوټي',
        ],
        'PYG' => [
            'PYG',
            'پيراګوين ګوراني',
        ],
        'QAR' => [
            'QAR',
            'قطري ريال',
        ],
        'RON' => [
            'RON',
            'روماني ليو',
        ],
        'RSD' => [
            'RSD',
            'سربيايي دينار',
        ],
        'RUB' => [
            'RUB',
            'روسي روبل',
        ],
        'RWF' => [
            'RWF',
            'روانډي فرانک',
        ],
        'SAR' => [
            'SAR',
            'سعودي ريال',
        ],
        'SBD' => [
            'SBD',
            'سولومن ټاپوګانو ډالر',
        ],
        'SCR' => [
            'SCR',
            'سيچيليسي روپۍ',
        ],
        'SDG' => [
            'SDG',
            'سوډاني پونډ',
        ],
        'SEK' => [
            'SEK',
            'سويډني کرونا',
        ],
        'SGD' => [
            'SGD',
            'سنګاپور ډالر',
        ],
        'SHP' => [
            'SHP',
            'سينټ هيلينا پونډ',
        ],
        'SLE' => [
            'SLE',
            'سيرا ليوني ليون',
        ],
        'SLL' => [
            'SLL',
            'سيرا ليوني ليون - 1964-2022',
        ],
        'SOS' => [
            'SOS',
            'سومالي شيلنګ',
        ],
        'SRD' => [
            'SRD',
            'سورينيمي ډالر',
        ],
        'SSP' => [
            'SSP',
            'جنوب سوډاني پونډ',
        ],
        'STN' => [
            'STN',
            'ساو ټوم او پرينسپي ډوبرا',
        ],
        'SYP' => [
            'SYP',
            'سوريايي پونډ',
        ],
        'SZL' => [
            'SZL',
            'سوازي ليلانګيني',
        ],
        'THB' => [
            'THB',
            'تهايي بات',
        ],
        'TJS' => [
            'TJS',
            'تاجکستاني سوموني',
        ],
        'TMT' => [
            'TMT',
            'ترکمانستاني منت',
        ],
        'TND' => [
            'TND',
            'تيونسې دينار',
        ],
        'TOP' => [
            'TOP',
            'ټونګن پانګا',
        ],
        'TRY' => [
            'TRY',
            'ترکي ليرا',
        ],
        'TTD' => [
            'TTD',
            'ټرينيډاډ او ټوباګو ډالر',
        ],
        'TWD' => [
            'NT$',
            'نيو تائيواني ډالر',
        ],
        'TZS' => [
            'TZS',
            'تنزاني شيلنګ',
        ],
        'UAH' => [
            'UAH',
            'اوکرايني هريونيا',
        ],
        'UGX' => [
            'UGX',
            'يوګانډي شيلنګ',
        ],
        'USD' => [
            '$',
            'امريکايي ډالر',
        ],
        'UYU' => [
            'UYU',
            'يوراګوي پسو',
        ],
        'UZS' => [
            'UZS',
            'ازبکستاني سوم',
        ],
        'VES' => [
            'VES',
            'وينزويلي بوليوار',
        ],
        'VND' => [
            '₫',
            'ويتنامي ډونګ',
        ],
        'VUV' => [
            'VUV',
            'ونواتو واتو',
        ],
        'WST' => [
            'WST',
            'سموون تالا',
        ],
        'XAF' => [
            'FCFA',
            'مرکزي افريقايي CFA فرانک',
        ],
        'XCD' => [
            'EC$',
            'ختيځ کربين ډالر',
        ],
        'XCG' => [
            'Cg.',
            'د کارابین ګیلډر',
        ],
        'XOF' => [
            'F CFA',
            'ختيځ افريقايي CFA فرانک',
        ],
        'XPF' => [
            'CFPF',
            'CFP فرانک',
        ],
        'YER' => [
            'YER',
            'يمني ريال',
        ],
        'ZAR' => [
            'ZAR',
            'جنوبي افريقاېي رنډ',
        ],
        'ZMW' => [
            'ZMW',
            'زيمبي کواچا',
        ],
        'ZWG' => [
            'ZWG',
            'د زمبابوې سره زر',
        ],
    ],
];
