<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'متحدہ عرب اماراتی درہم',
        ],
        'AFN' => [
            'AFN',
            'افغان افغانی',
        ],
        'ALL' => [
            'ALL',
            'البانیا کا لیک',
        ],
        'AMD' => [
            'AMD',
            'آرمینیائی ڈرم',
        ],
        'ANG' => [
            'ANG',
            'نیدر لینڈز انٹیلیئن گلڈر',
        ],
        'AOA' => [
            'AOA',
            'انگولا کا کوانزا',
        ],
        'ARS' => [
            'ARS',
            'ارجنٹائن پیسو',
        ],
        'AUD' => [
            'A$',
            'آسٹریلین ڈالر',
        ],
        'AWG' => [
            'AWG',
            'اروبن فلورِن',
        ],
        'AZN' => [
            'AZN',
            'آذربائجانی منات',
        ],
        'BAM' => [
            'BAM',
            'بوسنیا ہرزیگووینا کا قابل منتقلی نشان',
        ],
        'BBD' => [
            'BBD',
            'باربیڈین ڈالر',
        ],
        'BDT' => [
            'BDT',
            'بنگلہ دیشی ٹکا',
        ],
        'BGN' => [
            'BGN',
            'بلغارین لیو',
        ],
        'BHD' => [
            'BHD',
            'بحرینی دینار',
        ],
        'BIF' => [
            'BIF',
            'برونڈیئن فرانک',
        ],
        'BMD' => [
            'BMD',
            'برموڈا ڈالر',
        ],
        'BND' => [
            'BND',
            'برونئی ڈالر',
        ],
        'BOB' => [
            'BOB',
            'بولیوین بولیویانو',
        ],
        'BRL' => [
            'R$',
            'برازیلی ریئل',
        ],
        'BSD' => [
            'BSD',
            'بہامانی ڈالر',
        ],
        'BTN' => [
            'BTN',
            'بھوٹانی گُلٹرم',
        ],
        'BWP' => [
            'BWP',
            'بوتسوانا کا پولا',
        ],
        'BYN' => [
            'BYN',
            'بیلاروسی روبل',
        ],
        'BYR' => [
            'BYR',
            'بیلاروسی روبل (۲۰۰۰–۲۰۱۶)',
        ],
        'BZD' => [
            'BZD',
            'بیلیز ڈالر',
        ],
        'CAD' => [
            'CA$',
            'کنیڈین ڈالر',
        ],
        'CDF' => [
            'CDF',
            'کانگولیز فرانک',
        ],
        'CHF' => [
            'CHF',
            'سوئس فرانکس',
        ],
        'CLP' => [
            'CLP',
            'چلین پیسو',
        ],
        'CNH' => [
            'CNH',
            'چینی یوآن (آف شور)',
        ],
        'CNY' => [
            'CN¥',
            'چینی یوآن',
        ],
        'COP' => [
            'COP',
            'کولمبین پیسو',
        ],
        'CRC' => [
            'CRC',
            'کوسٹا ریکا کا کولن',
        ],
        'CUC' => [
            'CUC',
            'کیوبا کا قابل منتقلی پیسو',
        ],
        'CUP' => [
            'CUP',
            'کیوبا کا پیسو',
        ],
        'CVE' => [
            'CVE',
            'کیپ ورڈی کا اسکیوڈو',
        ],
        'CZK' => [
            'CZK',
            'چیک کرونا',
        ],
        'DEM' => [
            'DEM',
            'ڈچ مارکس',
        ],
        'DJF' => [
            'DJF',
            'جبوتی فرانک',
        ],
        'DKK' => [
            'DKK',
            'ڈنمارک کرون',
        ],
        'DOP' => [
            'DOP',
            'ڈومنیکن پیسو',
        ],
        'DZD' => [
            'DZD',
            'الجیریائی دینار',
        ],
        'EEK' => [
            'EEK',
            'ایسٹونین کرون',
        ],
        'EGP' => [
            'EGP',
            'مصری پاؤنڈ',
        ],
        'ERN' => [
            'ERN',
            'اریٹیریائی ناکفا',
        ],
        'ETB' => [
            'ETB',
            'ایتھوپیائی بِرّ',
        ],
        'EUR' => [
            '€',
            'یورو',
        ],
        'FJD' => [
            'FJD',
            'فجی کا ڈالر',
        ],
        'FKP' => [
            'FKP',
            'فاکلینڈ آئلینڈز پونڈ',
        ],
        'GBP' => [
            '£',
            'برطانوی پاؤنڈ',
        ],
        'GEL' => [
            'GEL',
            'جارجیائی لاری',
        ],
        'GHS' => [
            'GHS',
            'گھانا کا سیڈی',
        ],
        'GIP' => [
            'GIP',
            'جبل الطارق پونڈ',
        ],
        'GMD' => [
            'GMD',
            'گامبیا کا ڈلاسی',
        ],
        'GNF' => [
            'GNF',
            'گنی فرانک',
        ],
        'GTQ' => [
            'GTQ',
            'گواٹے مالا کا کوئٹزل',
        ],
        'GYD' => [
            'GYD',
            'گویانیز ڈالر',
        ],
        'HKD' => [
            'HK$',
            'ھانگ کانگ ڈالر',
        ],
        'HNL' => [
            'HNL',
            'ہونڈوران لیمپیرا',
        ],
        'HRK' => [
            'HRK',
            'کروشین کونا',
        ],
        'HTG' => [
            'HTG',
            'ہیتی کا گؤرڈی',
        ],
        'HUF' => [
            'HUF',
            'ہنگرین فورنٹ',
        ],
        'IDR' => [
            'IDR',
            'انڈونیشین روپیہ',
        ],
        'ILS' => [
            '₪',
            'اسرائیلی نیا شیکل',
        ],
        'INR' => [
            '₹',
            'بھارتی روپیہ',
        ],
        'IQD' => [
            'IQD',
            'عراقی دینار',
        ],
        'IRR' => [
            'IRR',
            'ایرانی ریال',
        ],
        'ISK' => [
            'ISK',
            'آئس لينڈی کرونا',
        ],
        'JMD' => [
            'JMD',
            'جمائیکن ڈالر',
        ],
        'JOD' => [
            'JOD',
            'اردنی دینار',
        ],
        'JPY' => [
            'JP¥',
            'جاپانی ین',
        ],
        'KES' => [
            'KES',
            'کینیائی شلنگ',
        ],
        'KGS' => [
            'KGS',
            'کرغستانی سوم',
        ],
        'KHR' => [
            'KHR',
            'کمبوڈیائی ریئل',
        ],
        'KMF' => [
            'KMF',
            'کوموریئن فرانک',
        ],
        'KPW' => [
            'KPW',
            'شمالی کوریائی وون',
        ],
        'KRW' => [
            '₩',
            'جنوبی کوریائی وون',
        ],
        'KWD' => [
            'KWD',
            'کویتی دینار',
        ],
        'KYD' => [
            'KYD',
            'کیمین آئلینڈز ڈالر',
        ],
        'KZT' => [
            'KZT',
            'قزاخستانی ٹینگ',
        ],
        'LAK' => [
            'LAK',
            'لاؤشیائی کِپ',
        ],
        'LBP' => [
            'LBP',
            'لبنانی پونڈ',
        ],
        'LKR' => [
            'LKR',
            'سری لنکائی روپیہ',
        ],
        'LRD' => [
            'LRD',
            'لائبریائی ڈالر',
        ],
        'LSL' => [
            'LSL',
            'لیسوتھو لوتی',
        ],
        'LTL' => [
            'LTL',
            'لیتھوینیائی لیٹاس',
        ],
        'LVL' => [
            'LVL',
            'لاتویائی لیٹس',
        ],
        'LYD' => [
            'LYD',
            'لیبیائی دینار',
        ],
        'MAD' => [
            'MAD',
            'مراکشی درہم',
        ],
        'MDL' => [
            'MDL',
            'مالدووی لیو',
        ],
        'MGA' => [
            'MGA',
            'ملاگاسی اریاری',
        ],
        'MKD' => [
            'MKD',
            'مقدونیائی دینار',
        ],
        'MMK' => [
            'MMK',
            'میانمار کیاٹ',
        ],
        'MNT' => [
            'MNT',
            'منگولیائی ٹگرِ',
        ],
        'MOP' => [
            'MOP',
            'میکانیز پٹاکا',
        ],
        'MRO' => [
            'MRO',
            'موریطانیائی اوگوئیا (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'موریطانیائی اوگوئیا',
        ],
        'MUR' => [
            'MUR',
            'ماریشس کا روپیہ',
        ],
        'MVR' => [
            'MVR',
            'مالدیپ کا روفیہ',
        ],
        'MWK' => [
            'MWK',
            'ملاوی کواچا',
        ],
        'MXN' => [
            'MX$',
            'میکسیکی پیسو',
        ],
        'MYR' => [
            'MYR',
            'ملیشیائی رنگِٹ',
        ],
        'MZN' => [
            'MZN',
            'موزامبیقی میٹیکل',
        ],
        'NAD' => [
            'NAD',
            'نامیبیائی ڈالر',
        ],
        'NGN' => [
            'NGN',
            'نائیجیریائی نائرا',
        ],
        'NIO' => [
            'NIO',
            'نکارا گوا کا کورڈوبا',
        ],
        'NOK' => [
            'NOK',
            'ناروے کرون',
        ],
        'NPR' => [
            'NPR',
            'نیپالی روپیہ',
        ],
        'NZD' => [
            'NZ$',
            'نیوزی لینڈ ڈالر',
        ],
        'OMR' => [
            'OMR',
            'عمانی ریال',
        ],
        'PAB' => [
            'PAB',
            'پنامہ کا بالبوآ',
        ],
        'PEN' => [
            'PEN',
            'پیروویئن سول',
        ],
        'PGK' => [
            'PGK',
            'پاپوآ نیو گنی کا کینا',
        ],
        'PHP' => [
            'PHP',
            'فلپائنی پیسو',
        ],
        'PKR' => [
            'Rs',
            'پاکستانی روپیہ',
        ],
        'PLN' => [
            'PLN',
            'پولش زلوٹی',
        ],
        'PYG' => [
            'PYG',
            'پیراگوئے کا گوآرنی',
        ],
        'QAR' => [
            'QAR',
            'قطری ریال',
        ],
        'RON' => [
            'RON',
            'رومانیائی لیو',
        ],
        'RSD' => [
            'RSD',
            'سربین دینار',
        ],
        'RUB' => [
            'RUB',
            'روسی روبل',
        ],
        'RWF' => [
            'RWF',
            'روانڈا کا فرانک',
        ],
        'SAR' => [
            'SAR',
            'سعودی ریال',
        ],
        'SBD' => [
            'SBD',
            'سولومن آئلینڈز ڈالر',
        ],
        'SCR' => [
            'SCR',
            'سشلی کا روپیہ',
        ],
        'SDG' => [
            'SDG',
            'سوڈانی پاؤنڈ',
        ],
        'SEK' => [
            'SEK',
            'سویڈن کرونا',
        ],
        'SGD' => [
            'SGD',
            'سنگا پور ڈالر',
        ],
        'SHP' => [
            'SHP',
            'سینٹ ہیلینا پاؤنڈ',
        ],
        'SIT' => [
            'SIT',
            'سلوانین ٹولر',
        ],
        'SKK' => [
            'SKK',
            'سلووک کرونا',
        ],
        'SLE' => [
            'SLE',
            'سیئرا لیونین لیون',
        ],
        'SLL' => [
            'SLL',
            'سیئرا لیونین لیون - 1964-2022',
        ],
        'SOS' => [
            'SOS',
            'صومالی شلنگ',
        ],
        'SRD' => [
            'SRD',
            'سورینامی ڈالر',
        ],
        'SSP' => [
            'SSP',
            'جنوبی سوڈانی پاؤنڈ',
        ],
        'STD' => [
            'STD',
            'ساؤ ٹوم اور پرنسپے ڈوبرا (1977–2017)',
        ],
        'STN' => [
            'STN',
            'ساؤ ٹومے اور پرنسپے ڈوبرا',
        ],
        'SYP' => [
            'SYP',
            'شامی پونڈ',
        ],
        'SZL' => [
            'SZL',
            'سوازی لیلانجینی',
        ],
        'THB' => [
            '฿',
            'تھائی باہت',
        ],
        'TJS' => [
            'TJS',
            'تاجکستانی سومونی',
        ],
        'TMT' => [
            'TMT',
            'ترکمانستانی منات',
        ],
        'TND' => [
            'TND',
            'تیونیسیائی دینار',
        ],
        'TOP' => [
            'TOP',
            'ٹونگن پانگا',
        ],
        'TRY' => [
            'TRY',
            'ترکی لیرا',
        ],
        'TTD' => [
            'TTD',
            'ترینیداد اور ٹوباگو کا ڈالر',
        ],
        'TWD' => [
            'NT$',
            'نیو تائیوان ڈالر',
        ],
        'TZS' => [
            'TZS',
            'تنزانیائی شلنگ',
        ],
        'UAH' => [
            'UAH',
            'یوکرینیائی ہریونیا',
        ],
        'UGX' => [
            'UGX',
            'یوگانڈا شلنگ',
        ],
        'USD' => [
            '$',
            'امریکی ڈالر',
        ],
        'UYU' => [
            'UYU',
            'یوروگویان پیسو',
        ],
        'UZS' => [
            'UZS',
            'ازبکستانی سوم',
        ],
        'VEB' => [
            'VEB',
            'وینزویلا بولیور (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'وینزویلا بولیور (2008–2018)',
        ],
        'VES' => [
            'VES',
            'وینزویلا بولیور',
        ],
        'VND' => [
            '₫',
            'ویتنامی ڈانگ',
        ],
        'VUV' => [
            'VUV',
            'وینوواتو واتو',
        ],
        'WST' => [
            'WST',
            'ساموآ کا ٹالا',
        ],
        'XAF' => [
            'FCFA',
            'وسطی افریقی [CFA] فرانک',
        ],
        'XCD' => [
            'EC$',
            'مشرقی کریبیا کا ڈالر',
        ],
        'XCG' => [
            'Cg.',
            'کیریبین گلڈر',
        ],
        'XOF' => [
            'F CFA',
            'مغربی افریقی [CFA] فرانک',
        ],
        'XPF' => [
            'CFPF',
            'CFP فرانک',
        ],
        'YER' => [
            'YER',
            'یمنی ریال',
        ],
        'ZAR' => [
            'ZAR',
            'جنوبی افریقی رانڈ',
        ],
        'ZMK' => [
            'ZMK',
            'زامبیائی کواچا (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'زامبیائی کواچا',
        ],
        'ZWG' => [
            'ZWG',
            'زمبابوے گولڈ',
        ],
    ],
];
