<?php

return [
    'Names' => [
        'af' => 'африкаанс чӗлхи',
        'af_NA' => 'африкаанс чӗлхи (Намиби)',
        'af_ZA' => 'африкаанс чӗлхи (Кӑнтӑр Африка Республики)',
        'ak' => 'акан чӗлхи',
        'ak_GH' => 'акан чӗлхи (Гана)',
        'am' => 'амхар чӗлхи',
        'am_ET' => 'амхар чӗлхи (Эфиопи)',
        'ar' => 'араб чӗлхи',
        'ar_001' => 'араб чӗлхи (тӗнче)',
        'ar_AE' => 'араб чӗлхи (Пӗрлешнӗ Араб Эмирачӗсем)',
        'ar_BH' => 'араб чӗлхи (Бахрейн)',
        'ar_DJ' => 'араб чӗлхи (Джибути)',
        'ar_DZ' => 'араб чӗлхи (Алжир)',
        'ar_EG' => 'араб чӗлхи (Египет)',
        'ar_EH' => 'араб чӗлхи (Анӑҫ Сахара)',
        'ar_ER' => 'араб чӗлхи (Эритрей)',
        'ar_IL' => 'араб чӗлхи (Израиль)',
        'ar_IQ' => 'араб чӗлхи (Ирак)',
        'ar_JO' => 'араб чӗлхи (Иордани)',
        'ar_KM' => 'араб чӗлхи (Комор утравӗсем)',
        'ar_KW' => 'араб чӗлхи (Кувейт)',
        'ar_LB' => 'араб чӗлхи (Ливан)',
        'ar_LY' => 'араб чӗлхи (Ливи)',
        'ar_MA' => 'араб чӗлхи (Марокко)',
        'ar_MR' => 'араб чӗлхи (Мавритани)',
        'ar_OM' => 'араб чӗлхи (Оман)',
        'ar_PS' => 'араб чӗлхи (Палестина территорийӗсем)',
        'ar_QA' => 'араб чӗлхи (Катар)',
        'ar_SA' => 'араб чӗлхи (Сауд Аравийӗ)',
        'ar_SD' => 'араб чӗлхи (Судан)',
        'ar_SO' => 'араб чӗлхи (Сомали)',
        'ar_SS' => 'араб чӗлхи (Кӑнтӑр Судан)',
        'ar_SY' => 'араб чӗлхи (Сири)',
        'ar_TD' => 'араб чӗлхи (Чад)',
        'ar_TN' => 'араб чӗлхи (Тунис)',
        'ar_YE' => 'араб чӗлхи (Йемен)',
        'as' => 'ассам чӗлхи',
        'as_IN' => 'ассам чӗлхи (Инди)',
        'az' => 'азербайджан чӗлхи',
        'az_AZ' => 'азербайджан чӗлхи (Азербайджан)',
        'az_Cyrl' => 'азербайджан чӗлхи (кирилл ҫырулӑхӗ)',
        'az_Cyrl_AZ' => 'азербайджан чӗлхи (кирилл ҫырулӑхӗ, Азербайджан)',
        'az_Latn' => 'азербайджан чӗлхи (латин ҫырулӑхӗ)',
        'az_Latn_AZ' => 'азербайджан чӗлхи (латин ҫырулӑхӗ, Азербайджан)',
        'ba' => 'пушкӑрт чӗлхи',
        'ba_RU' => 'пушкӑрт чӗлхи (Раҫҫей)',
        'be' => 'беларус чӗлхи',
        'be_BY' => 'беларус чӗлхи (Беларусь)',
        'bg' => 'болгар чӗлхи',
        'bg_BG' => 'болгар чӗлхи (Болгари)',
        'bm' => 'бамбара чӗлхи',
        'bm_ML' => 'бамбара чӗлхи (Мали)',
        'bn' => 'бенгал чӗлхи',
        'bn_BD' => 'бенгал чӗлхи (Бангладеш)',
        'bn_IN' => 'бенгал чӗлхи (Инди)',
        'bo' => 'тибет чӗлхи',
        'bo_CN' => 'тибет чӗлхи (Китай)',
        'bo_IN' => 'тибет чӗлхи (Инди)',
        'br' => 'бретон чӗлхи',
        'br_FR' => 'бретон чӗлхи (Франци)',
        'bs' => 'босни чӗлхи',
        'bs_BA' => 'босни чӗлхи (Боснипе Герцеговина)',
        'bs_Cyrl' => 'босни чӗлхи (кирилл ҫырулӑхӗ)',
        'bs_Cyrl_BA' => 'босни чӗлхи (кирилл ҫырулӑхӗ, Боснипе Герцеговина)',
        'bs_Latn' => 'босни чӗлхи (латин ҫырулӑхӗ)',
        'bs_Latn_BA' => 'босни чӗлхи (латин ҫырулӑхӗ, Боснипе Герцеговина)',
        'ca' => 'каталан чӗлхи',
        'ca_AD' => 'каталан чӗлхи (Андорра)',
        'ca_ES' => 'каталан чӗлхи (Испани)',
        'ca_FR' => 'каталан чӗлхи (Франци)',
        'ca_IT' => 'каталан чӗлхи (Итали)',
        'ce' => 'чечен чӗлхи',
        'ce_RU' => 'чечен чӗлхи (Раҫҫей)',
        'cs' => 'чех чӗлхи',
        'cs_CZ' => 'чех чӗлхи (Чехи)',
        'cv' => 'чӑваш чӗлхи',
        'cv_RU' => 'чӑваш чӗлхи (Раҫҫей)',
        'cy' => 'валли чӗлхи',
        'cy_GB' => 'валли чӗлхи (Аслӑ Британи)',
        'da' => 'датчан чӗлхи',
        'da_DK' => 'датчан чӗлхи (Дани)',
        'da_GL' => 'датчан чӗлхи (Гренланди)',
        'de' => 'нимӗҫ чӗлхи',
        'de_AT' => 'нимӗҫ чӗлхи (Австри)',
        'de_BE' => 'нимӗҫ чӗлхи (Бельги)',
        'de_CH' => 'нимӗҫ чӗлхи (Швейцари)',
        'de_DE' => 'нимӗҫ чӗлхи (Германи)',
        'de_IT' => 'нимӗҫ чӗлхи (Итали)',
        'de_LI' => 'нимӗҫ чӗлхи (Лихтенштейн)',
        'de_LU' => 'нимӗҫ чӗлхи (Люксембург)',
        'dz' => 'дзонг-кэ чӗлхи',
        'dz_BT' => 'дзонг-кэ чӗлхи (Бутан)',
        'ee' => 'эве чӗлхи',
        'ee_GH' => 'эве чӗлхи (Гана)',
        'ee_TG' => 'эве чӗлхи (Того)',
        'el' => 'грек чӗлхи',
        'el_CY' => 'грек чӗлхи (Кипр)',
        'el_GR' => 'грек чӗлхи (Греци)',
        'en' => 'акӑлчан чӗлхи',
        'en_001' => 'акӑлчан чӗлхи (тӗнче)',
        'en_150' => 'акӑлчан чӗлхи (Европа)',
        'en_AE' => 'акӑлчан чӗлхи (Пӗрлешнӗ Араб Эмирачӗсем)',
        'en_AG' => 'акӑлчан чӗлхи (Антигуапа Барбуда)',
        'en_AI' => 'акӑлчан чӗлхи (Ангилья)',
        'en_AS' => 'акӑлчан чӗлхи (Америка Самойи)',
        'en_AT' => 'акӑлчан чӗлхи (Австри)',
        'en_AU' => 'акӑлчан чӗлхи (Австрали)',
        'en_BB' => 'акӑлчан чӗлхи (Барбадос)',
        'en_BE' => 'акӑлчан чӗлхи (Бельги)',
        'en_BI' => 'акӑлчан чӗлхи (Бурунди)',
        'en_BM' => 'акӑлчан чӗлхи (Бермуд утравӗсем)',
        'en_BS' => 'акӑлчан чӗлхи (Багама утравӗсем)',
        'en_BW' => 'акӑлчан чӗлхи (Ботсвана)',
        'en_BZ' => 'акӑлчан чӗлхи (Белиз)',
        'en_CA' => 'акӑлчан чӗлхи (Канада)',
        'en_CC' => 'акӑлчан чӗлхи (Кокос утравӗсем)',
        'en_CH' => 'акӑлчан чӗлхи (Швейцари)',
        'en_CK' => 'акӑлчан чӗлхи (Кук утравӗсем)',
        'en_CM' => 'акӑлчан чӗлхи (Камерун)',
        'en_CX' => 'акӑлчан чӗлхи (Раштав утравӗ)',
        'en_CY' => 'акӑлчан чӗлхи (Кипр)',
        'en_CZ' => 'акӑлчан чӗлхи (Чехи)',
        'en_DE' => 'акӑлчан чӗлхи (Германи)',
        'en_DK' => 'акӑлчан чӗлхи (Дани)',
        'en_DM' => 'акӑлчан чӗлхи (Доминика)',
        'en_EE' => 'акӑлчан чӗлхи (Эстони)',
        'en_ER' => 'акӑлчан чӗлхи (Эритрей)',
        'en_ES' => 'акӑлчан чӗлхи (Испани)',
        'en_FI' => 'акӑлчан чӗлхи (Финлянди)',
        'en_FJ' => 'акӑлчан чӗлхи (Фиджи)',
        'en_FK' => 'акӑлчан чӗлхи (Фолкленд утравӗсем)',
        'en_FM' => 'акӑлчан чӗлхи (Микронези)',
        'en_FR' => 'акӑлчан чӗлхи (Франци)',
        'en_GB' => 'акӑлчан чӗлхи (Аслӑ Британи)',
        'en_GD' => 'акӑлчан чӗлхи (Гренада)',
        'en_GE' => 'акӑлчан чӗлхи (Грузи)',
        'en_GG' => 'акӑлчан чӗлхи (Гернси)',
        'en_GH' => 'акӑлчан чӗлхи (Гана)',
        'en_GI' => 'акӑлчан чӗлхи (Гибралтар)',
        'en_GM' => 'акӑлчан чӗлхи (Гамби)',
        'en_GS' => 'акӑлчан чӗлхи (Кӑнтӑр Георгипе Кӑнтӑр Сандвич утравӗсем)',
        'en_GU' => 'акӑлчан чӗлхи (Гуам)',
        'en_GY' => 'акӑлчан чӗлхи (Гайана)',
        'en_HK' => 'акӑлчан чӗлхи (Гонконг [ЯАР])',
        'en_HU' => 'акӑлчан чӗлхи (Венгри)',
        'en_ID' => 'акӑлчан чӗлхи (Индонези)',
        'en_IE' => 'акӑлчан чӗлхи (Ирланди)',
        'en_IL' => 'акӑлчан чӗлхи (Израиль)',
        'en_IM' => 'акӑлчан чӗлхи (Мэн утравӗ)',
        'en_IN' => 'акӑлчан чӗлхи (Инди)',
        'en_IO' => 'акӑлчан чӗлхи (Инди океанӗнчи Британи территорийӗ)',
        'en_IT' => 'акӑлчан чӗлхи (Итали)',
        'en_JE' => 'акӑлчан чӗлхи (Джерси)',
        'en_JM' => 'акӑлчан чӗлхи (Ямайка)',
        'en_JP' => 'акӑлчан чӗлхи (Япони)',
        'en_KE' => 'акӑлчан чӗлхи (Кени)',
        'en_KI' => 'акӑлчан чӗлхи (Кирибати)',
        'en_KN' => 'акӑлчан чӗлхи (Сент-Китспа Невис)',
        'en_KY' => 'акӑлчан чӗлхи (Кайман утравӗсем)',
        'en_LC' => 'акӑлчан чӗлхи (Сент-Люси)',
        'en_LR' => 'акӑлчан чӗлхи (Либери)',
        'en_LS' => 'акӑлчан чӗлхи (Лесото)',
        'en_LT' => 'акӑлчан чӗлхи (Литва)',
        'en_LV' => 'акӑлчан чӗлхи (Латви)',
        'en_MG' => 'акӑлчан чӗлхи (Мадагаскар)',
        'en_MH' => 'акӑлчан чӗлхи (Маршалл утравӗсем)',
        'en_MO' => 'акӑлчан чӗлхи (Макао [ЯАР])',
        'en_MP' => 'акӑлчан чӗлхи (Ҫур ҫӗр Мариан утравӗсем)',
        'en_MS' => 'акӑлчан чӗлхи (Монтсеррат)',
        'en_MT' => 'акӑлчан чӗлхи (Мальта)',
        'en_MU' => 'акӑлчан чӗлхи (Маврики)',
        'en_MV' => 'акӑлчан чӗлхи (Мальдив)',
        'en_MW' => 'акӑлчан чӗлхи (Малави)',
        'en_MY' => 'акӑлчан чӗлхи (Малайзи)',
        'en_NA' => 'акӑлчан чӗлхи (Намиби)',
        'en_NF' => 'акӑлчан чӗлхи (Норфолк утравӗ)',
        'en_NG' => 'акӑлчан чӗлхи (Нигери)',
        'en_NL' => 'акӑлчан чӗлхи (Нидерланд)',
        'en_NO' => 'акӑлчан чӗлхи (Норвеги)',
        'en_NR' => 'акӑлчан чӗлхи (Науру)',
        'en_NU' => 'акӑлчан чӗлхи (Ниуэ)',
        'en_NZ' => 'акӑлчан чӗлхи (Ҫӗнӗ Зеланди)',
        'en_PG' => 'акӑлчан чӗлхи (Папуа — Ҫӗнӗ Гвинея)',
        'en_PH' => 'акӑлчан чӗлхи (Филиппин)',
        'en_PK' => 'акӑлчан чӗлхи (Пакистан)',
        'en_PL' => 'акӑлчан чӗлхи (Польша)',
        'en_PN' => 'акӑлчан чӗлхи (Питкэрн утравӗсем)',
        'en_PR' => 'акӑлчан чӗлхи (Пуэрто-Рико)',
        'en_PT' => 'акӑлчан чӗлхи (Португали)',
        'en_PW' => 'акӑлчан чӗлхи (Палау)',
        'en_RO' => 'акӑлчан чӗлхи (Румыни)',
        'en_RW' => 'акӑлчан чӗлхи (Руанда)',
        'en_SB' => 'акӑлчан чӗлхи (Соломон утравӗсем)',
        'en_SC' => 'акӑлчан чӗлхи (Сейшел утравӗсем)',
        'en_SD' => 'акӑлчан чӗлхи (Судан)',
        'en_SE' => 'акӑлчан чӗлхи (Швеци)',
        'en_SG' => 'акӑлчан чӗлхи (Сингапур)',
        'en_SH' => 'акӑлчан чӗлхи (Сӑваплӑ Елена утравӗ)',
        'en_SI' => 'акӑлчан чӗлхи (Словени)',
        'en_SK' => 'акӑлчан чӗлхи (Словаки)',
        'en_SL' => 'акӑлчан чӗлхи (Сьерра-Леоне)',
        'en_SS' => 'акӑлчан чӗлхи (Кӑнтӑр Судан)',
        'en_SX' => 'акӑлчан чӗлхи (Синт-Мартен)',
        'en_SZ' => 'акӑлчан чӗлхи (Эсватини)',
        'en_TC' => 'акӑлчан чӗлхи (Тёркспа Кайкос утравӗсем)',
        'en_TK' => 'акӑлчан чӗлхи (Токелау)',
        'en_TO' => 'акӑлчан чӗлхи (Тонга)',
        'en_TT' => 'акӑлчан чӗлхи (Тринидадпа Тобаго)',
        'en_TV' => 'акӑлчан чӗлхи (Тувалу)',
        'en_TZ' => 'акӑлчан чӗлхи (Танзани)',
        'en_UA' => 'акӑлчан чӗлхи (Украина)',
        'en_UG' => 'акӑлчан чӗлхи (Уганда)',
        'en_UM' => 'акӑлчан чӗлхи (АПШ-н тулаш пӗчӗк утравӗсем)',
        'en_US' => 'акӑлчан чӗлхи (Пӗрлешнӗ Штатсем)',
        'en_VC' => 'акӑлчан чӗлхи (Сент-Винсентпа Гренада)',
        'en_VG' => 'акӑлчан чӗлхи (Виргин утравӗсем [Британи])',
        'en_VI' => 'акӑлчан чӗлхи (Виргин утравӗсем [АПШ])',
        'en_VU' => 'акӑлчан чӗлхи (Вануату)',
        'en_WS' => 'акӑлчан чӗлхи (Самоа)',
        'en_ZA' => 'акӑлчан чӗлхи (Кӑнтӑр Африка Республики)',
        'en_ZM' => 'акӑлчан чӗлхи (Замби)',
        'en_ZW' => 'акӑлчан чӗлхи (Зимбабве)',
        'eo' => 'эсперанто чӗлхи',
        'eo_001' => 'эсперанто чӗлхи (тӗнче)',
        'es' => 'испан чӗлхи',
        'es_419' => 'испан чӗлхи (Латинла Америка)',
        'es_AR' => 'испан чӗлхи (Аргентина)',
        'es_BO' => 'испан чӗлхи (Боливи)',
        'es_BR' => 'испан чӗлхи (Бразили)',
        'es_BZ' => 'испан чӗлхи (Белиз)',
        'es_CL' => 'испан чӗлхи (Чили)',
        'es_CO' => 'испан чӗлхи (Колумби)',
        'es_CR' => 'испан чӗлхи (Коста-Рика)',
        'es_CU' => 'испан чӗлхи (Куба)',
        'es_DO' => 'испан чӗлхи (Доминика Республики)',
        'es_EC' => 'испан чӗлхи (Эквадор)',
        'es_ES' => 'испан чӗлхи (Испани)',
        'es_GQ' => 'испан чӗлхи (Экваторти Гвинея)',
        'es_GT' => 'испан чӗлхи (Гватемала)',
        'es_HN' => 'испан чӗлхи (Гондурас)',
        'es_MX' => 'испан чӗлхи (Мексика)',
        'es_NI' => 'испан чӗлхи (Никарагуа)',
        'es_PA' => 'испан чӗлхи (Панама)',
        'es_PE' => 'испан чӗлхи (Перу)',
        'es_PH' => 'испан чӗлхи (Филиппин)',
        'es_PR' => 'испан чӗлхи (Пуэрто-Рико)',
        'es_PY' => 'испан чӗлхи (Парагвай)',
        'es_SV' => 'испан чӗлхи (Сальвадор)',
        'es_US' => 'испан чӗлхи (Пӗрлешнӗ Штатсем)',
        'es_UY' => 'испан чӗлхи (Уругвай)',
        'es_VE' => 'испан чӗлхи (Венесуэла)',
        'et' => 'эстон чӗлхи',
        'et_EE' => 'эстон чӗлхи (Эстони)',
        'eu' => 'баск чӗлхи',
        'eu_ES' => 'баск чӗлхи (Испани)',
        'fa' => 'перс чӗлхи',
        'fa_AF' => 'перс чӗлхи (Афганистан)',
        'fa_IR' => 'перс чӗлхи (Иран)',
        'ff' => 'фула чӗлхи',
        'ff_Adlm' => 'фула чӗлхи (адлам ҫырулӑхӗ)',
        'ff_Adlm_BF' => 'фула чӗлхи (адлам ҫырулӑхӗ, Буркина-Фасо)',
        'ff_Adlm_CM' => 'фула чӗлхи (адлам ҫырулӑхӗ, Камерун)',
        'ff_Adlm_GH' => 'фула чӗлхи (адлам ҫырулӑхӗ, Гана)',
        'ff_Adlm_GM' => 'фула чӗлхи (адлам ҫырулӑхӗ, Гамби)',
        'ff_Adlm_GN' => 'фула чӗлхи (адлам ҫырулӑхӗ, Гвиней)',
        'ff_Adlm_GW' => 'фула чӗлхи (адлам ҫырулӑхӗ, Гвиней-Бисау)',
        'ff_Adlm_LR' => 'фула чӗлхи (адлам ҫырулӑхӗ, Либери)',
        'ff_Adlm_MR' => 'фула чӗлхи (адлам ҫырулӑхӗ, Мавритани)',
        'ff_Adlm_NE' => 'фула чӗлхи (адлам ҫырулӑхӗ, Нигер)',
        'ff_Adlm_NG' => 'фула чӗлхи (адлам ҫырулӑхӗ, Нигери)',
        'ff_Adlm_SL' => 'фула чӗлхи (адлам ҫырулӑхӗ, Сьерра-Леоне)',
        'ff_Adlm_SN' => 'фула чӗлхи (адлам ҫырулӑхӗ, Сенегал)',
        'ff_CM' => 'фула чӗлхи (Камерун)',
        'ff_GN' => 'фула чӗлхи (Гвиней)',
        'ff_Latn' => 'фула чӗлхи (латин ҫырулӑхӗ)',
        'ff_Latn_BF' => 'фула чӗлхи (латин ҫырулӑхӗ, Буркина-Фасо)',
        'ff_Latn_CM' => 'фула чӗлхи (латин ҫырулӑхӗ, Камерун)',
        'ff_Latn_GH' => 'фула чӗлхи (латин ҫырулӑхӗ, Гана)',
        'ff_Latn_GM' => 'фула чӗлхи (латин ҫырулӑхӗ, Гамби)',
        'ff_Latn_GN' => 'фула чӗлхи (латин ҫырулӑхӗ, Гвиней)',
        'ff_Latn_GW' => 'фула чӗлхи (латин ҫырулӑхӗ, Гвиней-Бисау)',
        'ff_Latn_LR' => 'фула чӗлхи (латин ҫырулӑхӗ, Либери)',
        'ff_Latn_MR' => 'фула чӗлхи (латин ҫырулӑхӗ, Мавритани)',
        'ff_Latn_NE' => 'фула чӗлхи (латин ҫырулӑхӗ, Нигер)',
        'ff_Latn_NG' => 'фула чӗлхи (латин ҫырулӑхӗ, Нигери)',
        'ff_Latn_SL' => 'фула чӗлхи (латин ҫырулӑхӗ, Сьерра-Леоне)',
        'ff_Latn_SN' => 'фула чӗлхи (латин ҫырулӑхӗ, Сенегал)',
        'ff_MR' => 'фула чӗлхи (Мавритани)',
        'ff_SN' => 'фула чӗлхи (Сенегал)',
        'fi' => 'финн чӗлхи',
        'fi_FI' => 'финн чӗлхи (Финлянди)',
        'fo' => 'фарер чӗлхи',
        'fo_DK' => 'фарер чӗлхи (Дани)',
        'fo_FO' => 'фарер чӗлхи (Фарер утравӗсем)',
        'fr' => 'француз чӗлхи',
        'fr_BE' => 'француз чӗлхи (Бельги)',
        'fr_BF' => 'француз чӗлхи (Буркина-Фасо)',
        'fr_BI' => 'француз чӗлхи (Бурунди)',
        'fr_BJ' => 'француз чӗлхи (Бенин)',
        'fr_BL' => 'француз чӗлхи (Сен-Бартелеми)',
        'fr_CA' => 'француз чӗлхи (Канада)',
        'fr_CD' => 'француз чӗлхи (Конго)',
        'fr_CF' => 'француз чӗлхи (Вӑта Африка Республики)',
        'fr_CG' => 'француз чӗлхи (Конго-Браззавиль)',
        'fr_CH' => 'француз чӗлхи (Швейцари)',
        'fr_CI' => 'француз чӗлхи (Кот-д’Ивуар)',
        'fr_CM' => 'француз чӗлхи (Камерун)',
        'fr_DJ' => 'француз чӗлхи (Джибути)',
        'fr_DZ' => 'француз чӗлхи (Алжир)',
        'fr_FR' => 'француз чӗлхи (Франци)',
        'fr_GA' => 'француз чӗлхи (Габон)',
        'fr_GF' => 'француз чӗлхи (Франци Гвиани)',
        'fr_GN' => 'француз чӗлхи (Гвиней)',
        'fr_GP' => 'француз чӗлхи (Гваделупа)',
        'fr_GQ' => 'француз чӗлхи (Экваторти Гвинея)',
        'fr_HT' => 'француз чӗлхи (Гаити)',
        'fr_KM' => 'француз чӗлхи (Комор утравӗсем)',
        'fr_LU' => 'француз чӗлхи (Люксембург)',
        'fr_MA' => 'француз чӗлхи (Марокко)',
        'fr_MC' => 'француз чӗлхи (Монако)',
        'fr_MF' => 'француз чӗлхи (Сен-Мартен)',
        'fr_MG' => 'француз чӗлхи (Мадагаскар)',
        'fr_ML' => 'француз чӗлхи (Мали)',
        'fr_MQ' => 'француз чӗлхи (Мартиника)',
        'fr_MR' => 'француз чӗлхи (Мавритани)',
        'fr_MU' => 'француз чӗлхи (Маврики)',
        'fr_NC' => 'француз чӗлхи (Ҫӗнӗ Каледони)',
        'fr_NE' => 'француз чӗлхи (Нигер)',
        'fr_PF' => 'француз чӗлхи (Франци Полинезийӗ)',
        'fr_PM' => 'француз чӗлхи (Сен-Пьерпа Микелон)',
        'fr_RE' => 'француз чӗлхи (Реюньон)',
        'fr_RW' => 'француз чӗлхи (Руанда)',
        'fr_SC' => 'француз чӗлхи (Сейшел утравӗсем)',
        'fr_SN' => 'француз чӗлхи (Сенегал)',
        'fr_SY' => 'француз чӗлхи (Сири)',
        'fr_TD' => 'француз чӗлхи (Чад)',
        'fr_TG' => 'француз чӗлхи (Того)',
        'fr_TN' => 'француз чӗлхи (Тунис)',
        'fr_VU' => 'француз чӗлхи (Вануату)',
        'fr_WF' => 'француз чӗлхи (Уоллиспа Футуна)',
        'fr_YT' => 'француз чӗлхи (Майотта)',
        'fy' => 'анӑҫ фриз чӗлхи',
        'fy_NL' => 'анӑҫ фриз чӗлхи (Нидерланд)',
        'ga' => 'ирланд чӗлхи',
        'ga_GB' => 'ирланд чӗлхи (Аслӑ Британи)',
        'ga_IE' => 'ирланд чӗлхи (Ирланди)',
        'gd' => 'гэл чӗлхи',
        'gd_GB' => 'гэл чӗлхи (Аслӑ Британи)',
        'gl' => 'галиси чӗлхи',
        'gl_ES' => 'галиси чӗлхи (Испани)',
        'gu' => 'гуджарати чӗлхи',
        'gu_IN' => 'гуджарати чӗлхи (Инди)',
        'gv' => 'мэн чӗлхи',
        'gv_IM' => 'мэн чӗлхи (Мэн утравӗ)',
        'ha' => 'хауса чӗлхи',
        'ha_GH' => 'хауса чӗлхи (Гана)',
        'ha_NE' => 'хауса чӗлхи (Нигер)',
        'ha_NG' => 'хауса чӗлхи (Нигери)',
        'he' => 'иврит чӗлхи',
        'he_IL' => 'иврит чӗлхи (Израиль)',
        'hi' => 'хинди чӗлхи',
        'hi_IN' => 'хинди чӗлхи (Инди)',
        'hi_Latn' => 'хинди чӗлхи (латин ҫырулӑхӗ)',
        'hi_Latn_IN' => 'хинди чӗлхи (латин ҫырулӑхӗ, Инди)',
        'hr' => 'хорват чӗлхи',
        'hr_BA' => 'хорват чӗлхи (Боснипе Герцеговина)',
        'hr_HR' => 'хорват чӗлхи (Хорвати)',
        'hu' => 'венгер чӗлхи',
        'hu_HU' => 'венгер чӗлхи (Венгри)',
        'hy' => 'эрмен чӗлхи',
        'hy_AM' => 'эрмен чӗлхи (Армени)',
        'ia' => 'интерлингва чӗлхи',
        'ia_001' => 'интерлингва чӗлхи (тӗнче)',
        'id' => 'индонези чӗлхи',
        'id_ID' => 'индонези чӗлхи (Индонези)',
        'ie' => 'интерлингве чӗлхи',
        'ie_EE' => 'интерлингве чӗлхи (Эстони)',
        'ig' => 'игбо чӗлхи',
        'ig_NG' => 'игбо чӗлхи (Нигери)',
        'ii' => 'носу чӗлхи',
        'ii_CN' => 'носу чӗлхи (Китай)',
        'is' => 'исланд чӗлхи',
        'is_IS' => 'исланд чӗлхи (Исланди)',
        'it' => 'итальян чӗлхи',
        'it_CH' => 'итальян чӗлхи (Швейцари)',
        'it_IT' => 'итальян чӗлхи (Итали)',
        'it_SM' => 'итальян чӗлхи (Сан-Марино)',
        'it_VA' => 'итальян чӗлхи (Ватикан)',
        'ja' => 'япон чӗлхи',
        'ja_JP' => 'япон чӗлхи (Япони)',
        'jv' => 'яван чӗлхи',
        'jv_ID' => 'яван чӗлхи (Индонези)',
        'ka' => 'грузин чӗлхи',
        'ka_GE' => 'грузин чӗлхи (Грузи)',
        'ki' => 'кикуйю чӗлхи',
        'ki_KE' => 'кикуйю чӗлхи (Кени)',
        'kk' => 'казах чӗлхи',
        'kk_Arab' => 'казах чӗлхи (араб ҫырулӑхӗ)',
        'kk_Arab_CN' => 'казах чӗлхи (араб ҫырулӑхӗ, Китай)',
        'kk_Cyrl' => 'казах чӗлхи (кирилл ҫырулӑхӗ)',
        'kk_Cyrl_KZ' => 'казах чӗлхи (кирилл ҫырулӑхӗ, Казахстан)',
        'kk_KZ' => 'казах чӗлхи (Казахстан)',
        'kl' => 'гренланд чӗлхи',
        'kl_GL' => 'гренланд чӗлхи (Гренланди)',
        'km' => 'кхмер чӗлхи',
        'km_KH' => 'кхмер чӗлхи (Камбоджа)',
        'kn' => 'каннада чӗлхи',
        'kn_IN' => 'каннада чӗлхи (Инди)',
        'ko' => 'корей чӗлхи',
        'ko_CN' => 'корей чӗлхи (Китай)',
        'ko_KP' => 'корей чӗлхи (Ҫур ҫӗр Корея)',
        'ko_KR' => 'корей чӗлхи (Кӑнтӑр Корея)',
        'ks' => 'кашмири чӗлхи',
        'ks_Arab' => 'кашмири чӗлхи (араб ҫырулӑхӗ)',
        'ks_Arab_IN' => 'кашмири чӗлхи (араб ҫырулӑхӗ, Инди)',
        'ks_Deva' => 'кашмири чӗлхи (деванагари ҫырулӑхӗ)',
        'ks_Deva_IN' => 'кашмири чӗлхи (деванагари ҫырулӑхӗ, Инди)',
        'ks_IN' => 'кашмири чӗлхи (Инди)',
        'ku' => 'курд чӗлхи',
        'ku_Latn' => 'курд чӗлхи (латин ҫырулӑхӗ)',
        'ku_Latn_IQ' => 'курд чӗлхи (латин ҫырулӑхӗ, Ирак)',
        'ku_Latn_SY' => 'курд чӗлхи (латин ҫырулӑхӗ, Сири)',
        'ku_Latn_TR' => 'курд чӗлхи (латин ҫырулӑхӗ, Турци)',
        'ku_SY' => 'курд чӗлхи (Сири)',
        'ku_TR' => 'курд чӗлхи (Турци)',
        'kw' => 'корн чӗлхи',
        'kw_GB' => 'корн чӗлхи (Аслӑ Британи)',
        'ky' => 'кӑркӑс чӗлхи',
        'ky_KG' => 'кӑркӑс чӗлхи (Кӑркӑсстан)',
        'lb' => 'люксембург чӗлхи',
        'lb_LU' => 'люксембург чӗлхи (Люксембург)',
        'lg' => 'ганда чӗлхи',
        'lg_UG' => 'ганда чӗлхи (Уганда)',
        'ln' => 'лингала чӗлхи',
        'ln_AO' => 'лингала чӗлхи (Ангола)',
        'ln_CD' => 'лингала чӗлхи (Конго)',
        'ln_CF' => 'лингала чӗлхи (Вӑта Африка Республики)',
        'ln_CG' => 'лингала чӗлхи (Конго-Браззавиль)',
        'lo' => 'лаос чӗлхи',
        'lo_LA' => 'лаос чӗлхи (Лаос)',
        'lt' => 'литва чӗлхи',
        'lt_LT' => 'литва чӗлхи (Литва)',
        'lu' => 'луба-катанга чӗлхи',
        'lu_CD' => 'луба-катанга чӗлхи (Конго)',
        'lv' => 'латыш чӗлхи',
        'lv_LV' => 'латыш чӗлхи (Латви)',
        'mg' => 'малагас чӗлхи',
        'mg_MG' => 'малагас чӗлхи (Мадагаскар)',
        'mi' => 'маори чӗлхи',
        'mi_NZ' => 'маори чӗлхи (Ҫӗнӗ Зеланди)',
        'mk' => 'македон чӗлхи',
        'mk_MK' => 'македон чӗлхи (Ҫур ҫӗр Македони)',
        'ml' => 'малаялам чӗлхи',
        'ml_IN' => 'малаялам чӗлхи (Инди)',
        'mn' => 'монгол чӗлхи',
        'mn_MN' => 'монгол чӗлхи (Монголи)',
        'mr' => 'маратхи чӗлхи',
        'mr_IN' => 'маратхи чӗлхи (Инди)',
        'ms' => 'малай чӗлхи',
        'ms_BN' => 'малай чӗлхи (Бруней)',
        'ms_ID' => 'малай чӗлхи (Индонези)',
        'ms_MY' => 'малай чӗлхи (Малайзи)',
        'ms_SG' => 'малай чӗлхи (Сингапур)',
        'mt' => 'мальта чӗлхи',
        'mt_MT' => 'мальта чӗлхи (Мальта)',
        'my' => 'бирман чӗлхи',
        'my_MM' => 'бирман чӗлхи (Мьянма [Бирма])',
        'nb' => 'букмол норвег чӗлхи',
        'nb_NO' => 'букмол норвег чӗлхи (Норвеги)',
        'nb_SJ' => 'букмол норвег чӗлхи (Шпицбергенпа Ян-Майен)',
        'nd' => 'ҫур ҫӗр ндебеле чӗлхи',
        'nd_ZW' => 'ҫур ҫӗр ндебеле чӗлхи (Зимбабве)',
        'ne' => 'непал чӗлхи',
        'ne_IN' => 'непал чӗлхи (Инди)',
        'ne_NP' => 'непал чӗлхи (Непал)',
        'nl' => 'нидерланд чӗлхи',
        'nl_AW' => 'нидерланд чӗлхи (Аруба)',
        'nl_BE' => 'нидерланд чӗлхи (Бельги)',
        'nl_BQ' => 'нидерланд чӗлхи (Бонэйр, Синт-Эстатиуспа Саба)',
        'nl_CW' => 'нидерланд чӗлхи (Кюрасао)',
        'nl_NL' => 'нидерланд чӗлхи (Нидерланд)',
        'nl_SR' => 'нидерланд чӗлхи (Суринам)',
        'nl_SX' => 'нидерланд чӗлхи (Синт-Мартен)',
        'nn' => 'нюнорск норвег чӗлхи',
        'nn_NO' => 'нюнорск норвег чӗлхи (Норвеги)',
        'no' => 'норвег чӗлхи',
        'no_NO' => 'норвег чӗлхи (Норвеги)',
        'oc' => 'окситан чӗлхи',
        'oc_ES' => 'окситан чӗлхи (Испани)',
        'oc_FR' => 'окситан чӗлхи (Франци)',
        'om' => 'оромо чӗлхи',
        'om_ET' => 'оромо чӗлхи (Эфиопи)',
        'om_KE' => 'оромо чӗлхи (Кени)',
        'or' => 'ори чӗлхи',
        'or_IN' => 'ори чӗлхи (Инди)',
        'os' => 'осетин чӗлхи',
        'os_GE' => 'осетин чӗлхи (Грузи)',
        'os_RU' => 'осетин чӗлхи (Раҫҫей)',
        'pa' => 'панджаби чӗлхи',
        'pa_Arab' => 'панджаби чӗлхи (араб ҫырулӑхӗ)',
        'pa_Arab_PK' => 'панджаби чӗлхи (араб ҫырулӑхӗ, Пакистан)',
        'pa_Guru' => 'панджаби чӗлхи (гурмукхи ҫырулӑхӗ)',
        'pa_Guru_IN' => 'панджаби чӗлхи (гурмукхи ҫырулӑхӗ, Инди)',
        'pa_IN' => 'панджаби чӗлхи (Инди)',
        'pa_PK' => 'панджаби чӗлхи (Пакистан)',
        'pl' => 'поляк чӗлхи',
        'pl_PL' => 'поляк чӗлхи (Польша)',
        'ps' => 'пушту чӗлхи',
        'ps_AF' => 'пушту чӗлхи (Афганистан)',
        'ps_PK' => 'пушту чӗлхи (Пакистан)',
        'pt' => 'португал чӗлхи',
        'pt_AO' => 'португал чӗлхи (Ангола)',
        'pt_BR' => 'португал чӗлхи (Бразили)',
        'pt_CH' => 'португал чӗлхи (Швейцари)',
        'pt_CV' => 'португал чӗлхи (Кабо-Верде)',
        'pt_GQ' => 'португал чӗлхи (Экваторти Гвинея)',
        'pt_GW' => 'португал чӗлхи (Гвиней-Бисау)',
        'pt_LU' => 'португал чӗлхи (Люксембург)',
        'pt_MO' => 'португал чӗлхи (Макао [ЯАР])',
        'pt_MZ' => 'португал чӗлхи (Мозамбик)',
        'pt_PT' => 'португал чӗлхи (Португали)',
        'pt_ST' => 'португал чӗлхи (Сан-Томепе Принсипи)',
        'pt_TL' => 'португал чӗлхи (Тухӑҫ Тимор)',
        'qu' => 'кечуа чӗлхи',
        'qu_BO' => 'кечуа чӗлхи (Боливи)',
        'qu_EC' => 'кечуа чӗлхи (Эквадор)',
        'qu_PE' => 'кечуа чӗлхи (Перу)',
        'rm' => 'романш чӗлхи',
        'rm_CH' => 'романш чӗлхи (Швейцари)',
        'rn' => 'рунди чӗлхи',
        'rn_BI' => 'рунди чӗлхи (Бурунди)',
        'ro' => 'румын чӗлхи',
        'ro_MD' => 'румын чӗлхи (Молдова)',
        'ro_RO' => 'румын чӗлхи (Румыни)',
        'ru' => 'вырӑс чӗлхи',
        'ru_BY' => 'вырӑс чӗлхи (Беларусь)',
        'ru_KG' => 'вырӑс чӗлхи (Кӑркӑсстан)',
        'ru_KZ' => 'вырӑс чӗлхи (Казахстан)',
        'ru_MD' => 'вырӑс чӗлхи (Молдова)',
        'ru_RU' => 'вырӑс чӗлхи (Раҫҫей)',
        'ru_UA' => 'вырӑс чӗлхи (Украина)',
        'rw' => 'киньяруанда чӗлхи',
        'rw_RW' => 'киньяруанда чӗлхи (Руанда)',
        'sa' => 'санскрит чӗлхи',
        'sa_IN' => 'санскрит чӗлхи (Инди)',
        'sc' => 'сардин чӗлхи',
        'sc_IT' => 'сардин чӗлхи (Итали)',
        'sd' => 'синдхи чӗлхи',
        'sd_Arab' => 'синдхи чӗлхи (араб ҫырулӑхӗ)',
        'sd_Arab_PK' => 'синдхи чӗлхи (араб ҫырулӑхӗ, Пакистан)',
        'sd_Deva' => 'синдхи чӗлхи (деванагари ҫырулӑхӗ)',
        'sd_Deva_IN' => 'синдхи чӗлхи (деванагари ҫырулӑхӗ, Инди)',
        'sd_IN' => 'синдхи чӗлхи (Инди)',
        'sd_PK' => 'синдхи чӗлхи (Пакистан)',
        'se' => 'ҫур ҫӗр саам чӗлхи',
        'se_FI' => 'ҫур ҫӗр саам чӗлхи (Финлянди)',
        'se_NO' => 'ҫур ҫӗр саам чӗлхи (Норвеги)',
        'se_SE' => 'ҫур ҫӗр саам чӗлхи (Швеци)',
        'sg' => 'санго чӗлхи',
        'sg_CF' => 'санго чӗлхи (Вӑта Африка Республики)',
        'si' => 'сингал чӗлхи',
        'si_LK' => 'сингал чӗлхи (Шри-Ланка)',
        'sk' => 'словак чӗлхи',
        'sk_SK' => 'словак чӗлхи (Словаки)',
        'sl' => 'словен чӗлхи',
        'sl_SI' => 'словен чӗлхи (Словени)',
        'sn' => 'шона чӗлхи',
        'sn_ZW' => 'шона чӗлхи (Зимбабве)',
        'so' => 'сомали чӗлхи',
        'so_DJ' => 'сомали чӗлхи (Джибути)',
        'so_ET' => 'сомали чӗлхи (Эфиопи)',
        'so_KE' => 'сомали чӗлхи (Кени)',
        'so_SO' => 'сомали чӗлхи (Сомали)',
        'sq' => 'албан чӗлхи',
        'sq_AL' => 'албан чӗлхи (Албани)',
        'sq_MK' => 'албан чӗлхи (Ҫур ҫӗр Македони)',
        'sr' => 'серб чӗлхи',
        'sr_BA' => 'серб чӗлхи (Боснипе Герцеговина)',
        'sr_Cyrl' => 'серб чӗлхи (кирилл ҫырулӑхӗ)',
        'sr_Cyrl_BA' => 'серб чӗлхи (кирилл ҫырулӑхӗ, Боснипе Герцеговина)',
        'sr_Cyrl_ME' => 'серб чӗлхи (кирилл ҫырулӑхӗ, Черногори)',
        'sr_Cyrl_RS' => 'серб чӗлхи (кирилл ҫырулӑхӗ, Серби)',
        'sr_Latn' => 'серб чӗлхи (латин ҫырулӑхӗ)',
        'sr_Latn_BA' => 'серб чӗлхи (латин ҫырулӑхӗ, Боснипе Герцеговина)',
        'sr_Latn_ME' => 'серб чӗлхи (латин ҫырулӑхӗ, Черногори)',
        'sr_Latn_RS' => 'серб чӗлхи (латин ҫырулӑхӗ, Серби)',
        'sr_ME' => 'серб чӗлхи (Черногори)',
        'sr_RS' => 'серб чӗлхи (Серби)',
        'st' => 'кӑнтӑр сото чӗлхи',
        'st_LS' => 'кӑнтӑр сото чӗлхи (Лесото)',
        'st_ZA' => 'кӑнтӑр сото чӗлхи (Кӑнтӑр Африка Республики)',
        'su' => 'сундан чӗлхи',
        'su_ID' => 'сундан чӗлхи (Индонези)',
        'su_Latn' => 'сундан чӗлхи (латин ҫырулӑхӗ)',
        'su_Latn_ID' => 'сундан чӗлхи (латин ҫырулӑхӗ, Индонези)',
        'sv' => 'швед чӗлхи',
        'sv_AX' => 'швед чӗлхи (Аланд утравӗсем)',
        'sv_FI' => 'швед чӗлхи (Финлянди)',
        'sv_SE' => 'швед чӗлхи (Швеци)',
        'sw' => 'суахили чӗлхи',
        'sw_CD' => 'суахили чӗлхи (Конго)',
        'sw_KE' => 'суахили чӗлхи (Кени)',
        'sw_TZ' => 'суахили чӗлхи (Танзани)',
        'sw_UG' => 'суахили чӗлхи (Уганда)',
        'ta' => 'тамил чӗлхи',
        'ta_IN' => 'тамил чӗлхи (Инди)',
        'ta_LK' => 'тамил чӗлхи (Шри-Ланка)',
        'ta_MY' => 'тамил чӗлхи (Малайзи)',
        'ta_SG' => 'тамил чӗлхи (Сингапур)',
        'te' => 'телугу чӗлхи',
        'te_IN' => 'телугу чӗлхи (Инди)',
        'tg' => 'таджик чӗлхи',
        'tg_TJ' => 'таджик чӗлхи (Таджикистан)',
        'th' => 'тай чӗлхи',
        'th_TH' => 'тай чӗлхи (Таиланд)',
        'ti' => 'тигринья чӗлхи',
        'ti_ER' => 'тигринья чӗлхи (Эритрей)',
        'ti_ET' => 'тигринья чӗлхи (Эфиопи)',
        'tk' => 'туркмен чӗлхи',
        'tk_TM' => 'туркмен чӗлхи (Туркменистан)',
        'tn' => 'тсвана чӗлхи',
        'tn_BW' => 'тсвана чӗлхи (Ботсвана)',
        'tn_ZA' => 'тсвана чӗлхи (Кӑнтӑр Африка Республики)',
        'to' => 'тонган чӗлхи',
        'to_TO' => 'тонган чӗлхи (Тонга)',
        'tr' => 'турккӑ чӗлхи',
        'tr_CY' => 'турккӑ чӗлхи (Кипр)',
        'tr_TR' => 'турккӑ чӗлхи (Турци)',
        'tt' => 'тутар чӗлхи',
        'tt_RU' => 'тутар чӗлхи (Раҫҫей)',
        'ug' => 'уйгур чӗлхи',
        'ug_CN' => 'уйгур чӗлхи (Китай)',
        'uk' => 'украин чӗлхи',
        'uk_UA' => 'украин чӗлхи (Украина)',
        'ur' => 'урду чӗлхи',
        'ur_IN' => 'урду чӗлхи (Инди)',
        'ur_PK' => 'урду чӗлхи (Пакистан)',
        'uz' => 'узбек чӗлхи',
        'uz_AF' => 'узбек чӗлхи (Афганистан)',
        'uz_Arab' => 'узбек чӗлхи (араб ҫырулӑхӗ)',
        'uz_Arab_AF' => 'узбек чӗлхи (араб ҫырулӑхӗ, Афганистан)',
        'uz_Cyrl' => 'узбек чӗлхи (кирилл ҫырулӑхӗ)',
        'uz_Cyrl_UZ' => 'узбек чӗлхи (кирилл ҫырулӑхӗ, Узбекистан)',
        'uz_Latn' => 'узбек чӗлхи (латин ҫырулӑхӗ)',
        'uz_Latn_UZ' => 'узбек чӗлхи (латин ҫырулӑхӗ, Узбекистан)',
        'uz_UZ' => 'узбек чӗлхи (Узбекистан)',
        'vi' => 'вьетнам чӗлхи',
        'vi_VN' => 'вьетнам чӗлхи (Вьетнам)',
        'wo' => 'волоф чӗлхи',
        'wo_SN' => 'волоф чӗлхи (Сенегал)',
        'xh' => 'коса чӗлхи',
        'xh_ZA' => 'коса чӗлхи (Кӑнтӑр Африка Республики)',
        'yi' => 'идиш чӗлхи',
        'yi_UA' => 'идиш чӗлхи (Украина)',
        'yo' => 'йоруба чӗлхи',
        'yo_BJ' => 'йоруба чӗлхи (Бенин)',
        'yo_NG' => 'йоруба чӗлхи (Нигери)',
        'za' => 'чжуань чӗлхи',
        'za_CN' => 'чжуань чӗлхи (Китай)',
        'zh' => 'китай чӗлхи',
        'zh_CN' => 'китай чӗлхи (Китай)',
        'zh_HK' => 'китай чӗлхи (Гонконг [ЯАР])',
        'zh_Hans' => 'китай чӗлхи (ҫӑмӑллатнӑ китай ҫырулӑхӗ)',
        'zh_Hans_CN' => 'китай чӗлхи (ҫӑмӑллатнӑ китай ҫырулӑхӗ, Китай)',
        'zh_Hans_HK' => 'китай чӗлхи (ҫӑмӑллатнӑ китай ҫырулӑхӗ, Гонконг [ЯАР])',
        'zh_Hans_MO' => 'китай чӗлхи (ҫӑмӑллатнӑ китай ҫырулӑхӗ, Макао [ЯАР])',
        'zh_Hans_MY' => 'китай чӗлхи (ҫӑмӑллатнӑ китай ҫырулӑхӗ, Малайзи)',
        'zh_Hans_SG' => 'китай чӗлхи (ҫӑмӑллатнӑ китай ҫырулӑхӗ, Сингапур)',
        'zh_Hant' => 'китай чӗлхи (йӑлана кӗнӗ китай ҫырулӑхӗ)',
        'zh_Hant_HK' => 'китай чӗлхи (йӑлана кӗнӗ китай ҫырулӑхӗ, Гонконг [ЯАР])',
        'zh_Hant_MO' => 'китай чӗлхи (йӑлана кӗнӗ китай ҫырулӑхӗ, Макао [ЯАР])',
        'zh_Hant_MY' => 'китай чӗлхи (йӑлана кӗнӗ китай ҫырулӑхӗ, Малайзи)',
        'zh_Hant_TW' => 'китай чӗлхи (йӑлана кӗнӗ китай ҫырулӑхӗ, Тайвань)',
        'zh_MO' => 'китай чӗлхи (Макао [ЯАР])',
        'zh_SG' => 'китай чӗлхи (Сингапур)',
        'zh_TW' => 'китай чӗлхи (Тайвань)',
        'zu' => 'зулу чӗлхи',
        'zu_ZA' => 'зулу чӗлхи (Кӑнтӑр Африка Республики)',
    ],
];
