<?php

return [
    'Names' => [
        'aa' => 'afarera',
        'ab' => 'abkhaziera',
        'ace' => 'acehnera',
        'ach' => 'acholiera',
        'ada' => 'adangmera',
        'ady' => 'adigera',
        'af' => 'afrikaansa',
        'agq' => 'aghemera',
        'ain' => 'ainuera',
        'ak' => 'akanera',
        'ale' => 'aleutera',
        'alt' => 'hegoaldeko altaiera',
        'am' => 'amharera',
        'an' => 'aragoiera',
        'ann' => 'oboloera',
        'anp' => 'angikera',
        'ar' => 'arabiera',
        'arn' => 'mapudunguna',
        'arp' => 'arapahoera',
        'ars' => 'Najdeko arabiera',
        'as' => 'assamera',
        'asa' => 'asua',
        'ast' => 'asturiera',
        'atj' => 'atikamekwera',
        'av' => 'avarera',
        'awa' => 'awadhiera',
        'ay' => 'aimara',
        'az' => 'azerbaijanera',
        'ba' => 'baxkirera',
        'bal' => 'balutxera',
        'ban' => 'baliera',
        'bas' => 'basaa',
        'be' => 'bielorrusiera',
        'bem' => 'bembera',
        'bez' => 'benera',
        'bg' => 'bulgariera',
        'bgc' => 'haryanera',
        'bho' => 'bhojpurera',
        'bi' => 'bislama',
        'bin' => 'edoera',
        'bla' => 'siksikera',
        'blo' => 'aniiera',
        'bm' => 'bambarera',
        'bn' => 'bengalera',
        'bo' => 'tibetera',
        'br' => 'bretoiera',
        'brx' => 'bodoera',
        'bs' => 'bosniera',
        'bug' => 'buginera',
        'byn' => 'bilenera',
        'ca' => 'katalana',
        'cay' => 'cayugera',
        'ccp' => 'chakmera',
        'ce' => 'txetxenera',
        'ceb' => 'cebuanoera',
        'cgg' => 'chiga',
        'ch' => 'txamorroera',
        'chk' => 'chuukera',
        'chm' => 'mariera',
        'cho' => 'txoktawera',
        'chp' => 'chipewyera',
        'chr' => 'txerokiera',
        'chy' => 'txeieneera',
        'ckb' => 'erdialdeko kurduera',
        'clc' => 'chilcotinera',
        'co' => 'korsikera',
        'crg' => 'metisera',
        'crj' => 'hego-ekialdeko creera',
        'crk' => 'lautadetako creera',
        'crl' => 'ipar-ekialdeko creera',
        'crm' => 'Mooseko creera',
        'crr' => 'Carolinako algonkinera',
        'crs' => 'Seychelleetako kreolera',
        'cs' => 'txekiera',
        'csw' => 'zingiretako creera',
        'cu' => 'elizako eslaviera',
        'cv' => 'txuvaxera',
        'cy' => 'galesa',
        'da' => 'daniera',
        'dak' => 'dakotera',
        'dar' => 'darginera',
        'dav' => 'taitera',
        'de' => 'alemana',
        'dgr' => 'dogribera',
        'dje' => 'zarma',
        'doi' => 'dogria',
        'dsb' => 'behe-sorabiera',
        'dua' => 'dualera',
        'dv' => 'dhivehia',
        'dyo' => 'fonyi jolera',
        'dz' => 'dzongkha',
        'dzg' => 'dazaera',
        'ebu' => 'embuera',
        'ee' => 'eweera',
        'efi' => 'efikera',
        'eka' => 'ekajuka',
        'el' => 'greziera',
        'en' => 'ingelesa',
        'eo' => 'esperantoa',
        'es' => 'gaztelania',
        'et' => 'estoniera',
        'eu' => 'euskara',
        'ewo' => 'ewondoa',
        'fa' => 'persiera',
        'ff' => 'fula',
        'fi' => 'finlandiera',
        'fil' => 'filipinera',
        'fj' => 'fijiera',
        'fo' => 'faroera',
        'fon' => 'fonera',
        'fr' => 'frantsesa',
        'frc' => 'cajun frantsesa',
        'frr' => 'iparraldeko frisiera',
        'fur' => 'friulera',
        'fy' => 'mendebaldeko frisiera',
        'ga' => 'irlandera',
        'gaa' => 'gaera',
        'gag' => 'gagauzera',
        'gd' => 'Eskoziako gaelikoa',
        'gez' => 'ge’eza',
        'gil' => 'kiribatiera',
        'gl' => 'galiziera',
        'gn' => 'guaraniera',
        'gor' => 'gorontaloera',
        'gsw' => 'Suitzako alemana',
        'gu' => 'gujaratera',
        'guz' => 'gusiiera',
        'gv' => 'manxera',
        'gwi' => 'gwich’inera',
        'ha' => 'hausa',
        'hai' => 'haidera',
        'haw' => 'hawaiiera',
        'hax' => 'hegoaldeko haidera',
        'he' => 'hebreera',
        'hi' => 'hindia',
        'hil' => 'hiligaynonera',
        'hmn' => 'hmonga',
        'hr' => 'kroaziera',
        'hsb' => 'goi-sorabiera',
        'ht' => 'Haitiko kreolera',
        'hu' => 'hungariera',
        'hup' => 'hupera',
        'hur' => 'halkomelema',
        'hy' => 'armeniera',
        'hz' => 'hereroera',
        'ia' => 'interlingua',
        'iba' => 'ibanera',
        'ibb' => 'ibibioera',
        'id' => 'indonesiera',
        'ie' => 'interlinguea',
        'ig' => 'igboera',
        'ii' => 'Sichuango yiera',
        'ikt' => 'Kanada mendebaldeko inuitera',
        'ilo' => 'ilocanoera',
        'inh' => 'ingushera',
        'io' => 'idoa',
        'is' => 'islandiera',
        'it' => 'italiera',
        'iu' => 'inuitera',
        'ja' => 'japoniera',
        'jbo' => 'lojbana',
        'jgo' => 'ngomba',
        'jmc' => 'machamea',
        'jv' => 'javera',
        'ka' => 'georgiera',
        'kab' => 'kabiliera',
        'kac' => 'jingphoera',
        'kaj' => 'jjua',
        'kam' => 'kambera',
        'kbd' => 'kabardiera',
        'kcg' => 'tyapa',
        'kde' => 'makondeera',
        'kea' => 'Cabo Verdeko kreolera',
        'kfo' => 'koroa',
        'kg' => 'kikongoa',
        'kgp' => 'kaingangera',
        'kha' => 'khasiera',
        'khq' => 'koyra chiinia',
        'ki' => 'kikuyuera',
        'kj' => 'kuanyama',
        'kk' => 'kazakhera',
        'kkj' => 'kakoa',
        'kl' => 'groenlandiera',
        'kln' => 'kalenjinera',
        'km' => 'khemerera',
        'kmb' => 'kimbundua',
        'kn' => 'kannada',
        'ko' => 'koreera',
        'koi' => 'komi-permyakera',
        'kok' => 'konkanera',
        'kpe' => 'kpelleera',
        'kr' => 'kanuriera',
        'krc' => 'karachayera-balkarera',
        'krl' => 'kareliera',
        'kru' => 'kurukhera',
        'ks' => 'kaxmirera',
        'ksb' => 'shambalera',
        'ksf' => 'bafiera',
        'ksh' => 'koloniera',
        'ku' => 'kurduera',
        'kum' => 'kumykera',
        'kv' => 'komiera',
        'kw' => 'kornubiera',
        'kwk' => 'kwakwala',
        'kxv' => 'kuvia',
        'ky' => 'kirgizera',
        'la' => 'latina',
        'lad' => 'ladinoa',
        'lag' => 'langiera',
        'lb' => 'luxenburgera',
        'lez' => 'lezginera',
        'lg' => 'luganda',
        'li' => 'limburgera',
        'lij' => 'liguriera',
        'lil' => 'lillooetera',
        'lkt' => 'lakotera',
        'lmo' => 'lombardiera',
        'ln' => 'lingala',
        'lo' => 'laosera',
        'lou' => 'Louisianako kreolera',
        'loz' => 'loziera',
        'lrc' => 'iparraldeko lurera',
        'lsm' => 'saamia',
        'lt' => 'lituaniera',
        'lu' => 'Katangako lubera',
        'lua' => 'Kasai mendebaldeko lubera',
        'lun' => 'lundera',
        'luo' => 'luoera',
        'lus' => 'mizoera',
        'luy' => 'luhyera',
        'lv' => 'letoniera',
        'mad' => 'madurera',
        'mag' => 'magadhera',
        'mai' => 'maithilia',
        'mak' => 'makassarera',
        'mas' => 'masaiera',
        'mdf' => 'mokxera',
        'men' => 'mendeera',
        'mer' => 'meruera',
        'mfe' => 'Mauritaniako kreolera',
        'mg' => 'malgaxea',
        'mgh' => 'makhuwa-meettoera',
        'mgo' => 'metaʼera',
        'mh' => 'marshallera',
        'mi' => 'maoriera',
        'mic' => 'mikmakera',
        'min' => 'minangkabauera',
        'mk' => 'mazedoniera',
        'ml' => 'malabarera',
        'mn' => 'mongoliera',
        'mni' => 'manipurera',
        'moe' => 'innuera',
        'moh' => 'mohawkera',
        'mos' => 'mossiera',
        'mr' => 'marathera',
        'ms' => 'malaysiera',
        'mt' => 'maltera',
        'mua' => 'mudangera',
        'mus' => 'muscogeera',
        'mwl' => 'mirandesa',
        'my' => 'birmaniera',
        'myv' => 'erziera',
        'mzn' => 'mazandarandera',
        'na' => 'nauruera',
        'nap' => 'napoliera',
        'naq' => 'namera',
        'nb' => 'bokmål (norvegiera)',
        'nd' => 'iparraldeko ndebeleera',
        'nds' => 'behe-alemana',
        'ne' => 'nepalera',
        'new' => 'newarera',
        'ng' => 'ndonga',
        'nia' => 'niasera',
        'niu' => 'niueera',
        'nl' => 'nederlandera',
        'nmg' => 'kwasiera',
        'nn' => 'nynorsk (norvegiera)',
        'nnh' => 'ngiemboonera',
        'no' => 'norvegiera',
        'nog' => 'nogaiera',
        'nqo' => 'n’koera',
        'nr' => 'hegoaldeko ndebeleera',
        'nso' => 'pediera',
        'nus' => 'nuerera',
        'nv' => 'navajoera',
        'ny' => 'chewera',
        'nyn' => 'nkoreera',
        'oc' => 'okzitaniera',
        'ojb' => 'ipar-mendebaldeko ojibwa',
        'ojc' => 'erdialdeko ojibwa',
        'ojs' => 'oji-creera',
        'ojw' => 'mendebaldeko ojibwa',
        'oka' => 'okanaganera',
        'om' => 'oromoera',
        'or' => 'oriya',
        'os' => 'osetiera',
        'pa' => 'punjabera',
        'pag' => 'pangasinanera',
        'pam' => 'pampangera',
        'pap' => 'papiamentoa',
        'pau' => 'palauera',
        'pcm' => 'Nigeriako pidgina',
        'pis' => 'pijina',
        'pl' => 'poloniera',
        'pqm' => 'maliseet-passamaquoddyera',
        'prg' => 'prusiera',
        'ps' => 'paxtunera',
        'pt' => 'portugesa',
        'qu' => 'kitxua',
        'quc' => 'quicheera',
        'raj' => 'rajastanera',
        'rap' => 'rapanuia',
        'rar' => 'rarotongera',
        'rhg' => 'rohingyera',
        'rm' => 'erretorromaniera',
        'rn' => 'rundiera',
        'ro' => 'errumaniera',
        'rof' => 'romboa',
        'ru' => 'errusiera',
        'rup' => 'aromaniera',
        'rw' => 'kinyaruanda',
        'rwk' => 'rwera',
        'sa' => 'sanskritoa',
        'sad' => 'sandaweera',
        'sah' => 'sakhera',
        'saq' => 'samburuera',
        'sat' => 'santalera',
        'sba' => 'ngambayera',
        'sbp' => 'sanguera',
        'sc' => 'sardiniera',
        'scn' => 'siziliera',
        'sco' => 'eskoziera',
        'sd' => 'sindhia',
        'se' => 'iparraldeko samiera',
        'seh' => 'senera',
        'ses' => 'koyraboro sennia',
        'sg' => 'sangoa',
        'sh' => 'serbokroaziera',
        'shi' => 'tachelhita',
        'shn' => 'shanera',
        'si' => 'sinhala',
        'sk' => 'eslovakiera',
        'sl' => 'esloveniera',
        'slh' => 'lushootseeda',
        'sm' => 'samoera',
        'sma' => 'hegoaldeko samiera',
        'smj' => 'Luleko samiera',
        'smn' => 'Inariko samiera',
        'sms' => 'skolten samiera',
        'sn' => 'shonera',
        'snk' => 'soninkeera',
        'so' => 'somaliera',
        'sq' => 'albaniera',
        'sr' => 'serbiera',
        'srn' => 'sranan tongoa',
        'ss' => 'swatiera',
        'ssy' => 'sahoa',
        'st' => 'hegoaldeko sothoera',
        'str' => 'itsasarteetako salishera',
        'su' => 'sundanera',
        'suk' => 'sukumera',
        'sv' => 'suediera',
        'sw' => 'swahilia',
        'swb' => 'komoreera',
        'syr' => 'asiriera',
        'szl' => 'silesiera',
        'ta' => 'tamilera',
        'tce' => 'hegoaldeko tutchoneera',
        'te' => 'telugua',
        'tem' => 'temneera',
        'teo' => 'tesoera',
        'tet' => 'tetuma',
        'tg' => 'tajikera',
        'tgx' => 'tagishera',
        'th' => 'thailandiera',
        'tht' => 'tahltanera',
        'ti' => 'tigrinyera',
        'tig' => 'tigreera',
        'tk' => 'turkmenera',
        'tl' => 'tagaloa',
        'tlh' => 'klingonera',
        'tli' => 'tlingitera',
        'tn' => 'tswanera',
        'to' => 'tongera',
        'tok' => 'toki pona',
        'tpi' => 'tok pisin',
        'tr' => 'turkiera',
        'trv' => 'tarokoera',
        'ts' => 'tsongera',
        'tt' => 'tatarera',
        'ttm' => 'iparraldeko tutchoneera',
        'tum' => 'tumbukera',
        'tvl' => 'tuvaluera',
        'tw' => 'twia',
        'twq' => 'tasawaqa',
        'ty' => 'tahitiera',
        'tyv' => 'tuvera',
        'tzm' => 'Erdialdeko Atlaseko amazigera',
        'udm' => 'udmurtera',
        'ug' => 'uigurrera',
        'uk' => 'ukrainera',
        'umb' => 'umbundua',
        'ur' => 'urdua',
        'uz' => 'uzbekera',
        'vai' => 'vaiera',
        've' => 'vendera',
        'vec' => 'veneziera',
        'vi' => 'vietnamera',
        'vmw' => 'makhuwera',
        'vo' => 'volapük',
        'vun' => 'vunjoa',
        'wa' => 'valoniera',
        'wae' => 'walserera',
        'wal' => 'wolayttera',
        'war' => 'warayera',
        'wo' => 'wolofera',
        'wuu' => 'wu txinera',
        'xal' => 'kalmykera',
        'xh' => 'xhosera',
        'xnr' => 'kangrera',
        'xog' => 'sogera',
        'yav' => 'yangbenera',
        'ybb' => 'yemba',
        'yi' => 'yiddisha',
        'yo' => 'jorubera',
        'yrl' => 'nheengatua',
        'yue' => 'kantonera',
        'za' => 'zhuangera',
        'zgh' => 'amazigera estandarra',
        'zh' => 'txinera',
        'zu' => 'zuluera',
        'zun' => 'zuñiera',
        'zza' => 'zazera',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabiera moderno estandarra',
        'de_AT' => 'Austriako alemana',
        'de_CH' => 'Suitzako aleman garaia',
        'en_AU' => 'Australiako ingelesa',
        'en_CA' => 'Kanadako ingelesa',
        'en_GB' => 'Britainia Handiko ingelesa',
        'en_US' => 'ingeles amerikarra',
        'es_419' => 'Latinoamerikako gaztelania',
        'es_ES' => 'Europako gaztelania',
        'es_MX' => 'Mexikoko gaztelania',
        'fa_AF' => 'daria',
        'fr_CA' => 'Kanadako frantsesa',
        'fr_CH' => 'Suitzako frantsesa',
        'hi_Latn' => 'hindia (latindarra)',
        'nds_NL' => 'behe-saxoiera',
        'nl_BE' => 'flandriera',
        'pt_BR' => 'Brasilgo portugesa',
        'pt_PT' => 'Europako portugesa',
        'ro_MD' => 'moldaviera',
        'sw_CD' => 'Kongoko swahilia',
        'zh_Hans' => 'txinera sinplifikatua',
        'zh_Hant' => 'txinera tradizionala',
    ],
];
