<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Andorra Pezetası',
        ],
        'AED' => [
            'AED',
            'Birleşik Arap Emirlikleri dirhemi',
        ],
        'AFA' => [
            'AFA',
            'Afganistan Afganisi (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'Afganistan afganisi',
        ],
        'ALK' => [
            'ALK',
            'Arnavutluk Leki (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'Arnavutluk leki',
        ],
        'AMD' => [
            'AMD',
            'Ermenistan dramı',
        ],
        'ANG' => [
            'ANG',
            'Hollanda Antilleri guldeni',
        ],
        'AOA' => [
            'AOA',
            'Angola kvanzası',
        ],
        'AOK' => [
            'AOK',
            'Angola Kvanzası (1977–1990)',
        ],
        'AON' => [
            'AON',
            'Yeni Angola Kvanzası (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Angola Kvanzası Reajustado (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Arjantin Australi',
        ],
        'ARL' => [
            'ARL',
            'Arjantin Peso Leyi (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'Arjantin Pesosu (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'Arjantin Pezosu (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'Arjantin pesosu',
        ],
        'ATS' => [
            'ATS',
            'Avusturya Şilini',
        ],
        'AUD' => [
            'AU$',
            'Avustralya doları',
        ],
        'AWG' => [
            'AWG',
            'Aruba florini',
        ],
        'AZM' => [
            'AZM',
            'Azerbaycan Manatı (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'Azerbaycan manatı',
        ],
        'BAD' => [
            'BAD',
            'Bosna Hersek Dinarı',
        ],
        'BAM' => [
            'BAM',
            'Konvertibl Bosna Hersek markı',
        ],
        'BAN' => [
            'BAN',
            'Yeni Bosna Hersek Dinarı (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'Barbados doları',
        ],
        'BDT' => [
            'BDT',
            'Bangladeş takası',
        ],
        'BEC' => [
            'BEC',
            'Belçika Frangı (konvertibl)',
        ],
        'BEF' => [
            'BEF',
            'Belçika Frangı',
        ],
        'BEL' => [
            'BEL',
            'Belçika Frangı (finansal)',
        ],
        'BGL' => [
            'BGL',
            'Bulgar Levası (Hard)',
        ],
        'BGM' => [
            'BGM',
            'Sosyalist Bulgaristan Levası',
        ],
        'BGN' => [
            'BGN',
            'Bulgar levası',
        ],
        'BGO' => [
            'BGO',
            'Bulgar Levası (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'Bahreyn dinarı',
        ],
        'BIF' => [
            'BIF',
            'Burundi frangı',
        ],
        'BMD' => [
            'BMD',
            'Bermuda doları',
        ],
        'BND' => [
            'BND',
            'Brunei doları',
        ],
        'BOB' => [
            'BOB',
            'Bolivya bolivyanosu',
        ],
        'BOL' => [
            'BOL',
            'Bolivya Bolivyanosu (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'Bolivya Pezosu',
        ],
        'BOV' => [
            'BOV',
            'Bolivya Mvdolu',
        ],
        'BRB' => [
            'BRB',
            'Yeni Brezilya Kruzeirosu (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Brezilya Kruzadosu',
        ],
        'BRE' => [
            'BRE',
            'Brezilya Kruzeirosu (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'Brezilya reali',
        ],
        'BRN' => [
            'BRN',
            'Yeni Brezilya Kruzadosu',
        ],
        'BRR' => [
            'BRR',
            'Brezilya Kruzeirosu',
        ],
        'BRZ' => [
            'BRZ',
            'Brezilya Kruzeirosu (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'Bahama doları',
        ],
        'BTN' => [
            'BTN',
            'Butan ngultrumu',
        ],
        'BUK' => [
            'BUK',
            'Burma Kyatı',
        ],
        'BWP' => [
            'BWP',
            'Botsvana pulası',
        ],
        'BYB' => [
            'BYB',
            'Yeni Beyaz Rusya Rublesi (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'Belarus rublesi',
        ],
        'BYR' => [
            'BYR',
            'Beyaz Rusya Rublesi (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Belize doları',
        ],
        'CAD' => [
            'CA$',
            'Kanada doları',
        ],
        'CDF' => [
            'CDF',
            'Kongo frangı',
        ],
        'CHE' => [
            'CHE',
            'WIR Avrosu',
        ],
        'CHF' => [
            'CHF',
            'İsviçre frangı',
        ],
        'CHW' => [
            'CHW',
            'WIR Frangı',
        ],
        'CLE' => [
            'CLE',
            'Şili Esküdosu',
        ],
        'CLF' => [
            'CLF',
            'Şili Unidades de Fomento',
        ],
        'CLP' => [
            'CLP',
            'Şili pesosu',
        ],
        'CNH' => [
            'CNH',
            'Çin yuanı (offshore)',
        ],
        'CNX' => [
            'CNX',
            'Çin Halk Cumhuriyeti Merkez Bankası Doları',
        ],
        'CNY' => [
            'CN¥',
            'Çin yuanı',
        ],
        'COP' => [
            'COP',
            'Kolombiya pesosu',
        ],
        'COU' => [
            'COU',
            'Unidad de Valor Real',
        ],
        'CRC' => [
            'CRC',
            'Kosta Rika kolonu',
        ],
        'CSD' => [
            'CSD',
            'Eski Sırbistan Dinarı',
        ],
        'CSK' => [
            'CSK',
            'Çekoslavak Korunası (Hard)',
        ],
        'CUC' => [
            'CUC',
            'Konvertibl Küba pesosu',
        ],
        'CUP' => [
            'CUP',
            'Küba pesosu',
        ],
        'CVE' => [
            'CVE',
            'Cape Verde esküdosu',
        ],
        'CYP' => [
            'CYP',
            'Güney Kıbrıs Lirası',
        ],
        'CZK' => [
            'CZK',
            'Çek korunası',
        ],
        'DDM' => [
            'DDM',
            'Doğu Alman Markı',
        ],
        'DEM' => [
            'DEM',
            'Alman Markı',
        ],
        'DJF' => [
            'DJF',
            'Cibuti frangı',
        ],
        'DKK' => [
            'DKK',
            'Danimarka kronu',
        ],
        'DOP' => [
            'DOP',
            'Dominik pesosu',
        ],
        'DZD' => [
            'DZD',
            'Cezayir dinarı',
        ],
        'ECS' => [
            'ECS',
            'Ekvador Sukresi',
        ],
        'ECV' => [
            'ECV',
            'Ekvador Unidad de Valor Constante (UVC)',
        ],
        'EEK' => [
            'EEK',
            'Estonya Krunu',
        ],
        'EGP' => [
            'EGP',
            'Mısır lirası',
        ],
        'ERN' => [
            'ERN',
            'Eritre nakfası',
        ],
        'ESA' => [
            'ESA',
            'İspanyol Pezetası (A hesabı)',
        ],
        'ESB' => [
            'ESB',
            'İspanyol Pezetası (konvertibl hesap)',
        ],
        'ESP' => [
            'ESP',
            'İspanyol Pezetası',
        ],
        'ETB' => [
            'ETB',
            'Etiyopya birri',
        ],
        'EUR' => [
            '€',
            'Euro',
        ],
        'FIM' => [
            'FIM',
            'Fin Markkası',
        ],
        'FJD' => [
            'FJD',
            'Fiji doları',
        ],
        'FKP' => [
            'FKP',
            'Falkland Adaları lirası',
        ],
        'FRF' => [
            'FRF',
            'Fransız Frangı',
        ],
        'GBP' => [
            '£',
            'İngiliz sterlini',
        ],
        'GEK' => [
            'GEK',
            'Gürcistan Kupon Larisi',
        ],
        'GEL' => [
            'GEL',
            'Gürcistan larisi',
        ],
        'GHC' => [
            'GHC',
            'Gana Sedisi (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'Gana sedisi',
        ],
        'GIP' => [
            'GIP',
            'Cebelitarık lirası',
        ],
        'GMD' => [
            'GMD',
            'Gambiya dalasisi',
        ],
        'GNF' => [
            'GNF',
            'Gine frangı',
        ],
        'GNS' => [
            'GNS',
            'Gine Sylisi',
        ],
        'GQE' => [
            'GQE',
            'Ekvator Ginesi Ekuelesi',
        ],
        'GRD' => [
            'GRD',
            'Yunan Drahmisi',
        ],
        'GTQ' => [
            'GTQ',
            'Guatemala quetzalı',
        ],
        'GWE' => [
            'GWE',
            'Portekiz Ginesi Esküdosu',
        ],
        'GWP' => [
            'GWP',
            'Gine-Bissau Pezosu',
        ],
        'GYD' => [
            'GYD',
            'Guyana doları',
        ],
        'HKD' => [
            'HK$',
            'Hong Kong doları',
        ],
        'HNL' => [
            'HNL',
            'Honduras lempirası',
        ],
        'HRD' => [
            'HRD',
            'Hırvatistan Dinarı',
        ],
        'HRK' => [
            'HRK',
            'Hırvatistan kunası',
        ],
        'HTG' => [
            'HTG',
            'Haiti gurdu',
        ],
        'HUF' => [
            'HUF',
            'Macar forinti',
        ],
        'IDR' => [
            'IDR',
            'Endonezya rupisi',
        ],
        'IEP' => [
            'IEP',
            'İrlanda Lirası',
        ],
        'ILP' => [
            'ILP',
            'İsrail Lirası',
        ],
        'ILR' => [
            'ILR',
            'İsrail Şekeli (1980–1985)',
        ],
        'ILS' => [
            '₪',
            'Yeni İsrail şekeli',
        ],
        'INR' => [
            '₹',
            'Hindistan rupisi',
        ],
        'IQD' => [
            'IQD',
            'Irak dinarı',
        ],
        'IRR' => [
            'IRR',
            'İran riyali',
        ],
        'ISJ' => [
            'ISJ',
            'İzlanda Kronu (1918–1981)',
        ],
        'ISK' => [
            'ISK',
            'İzlanda kronu',
        ],
        'ITL' => [
            'ITL',
            'İtalyan Lireti',
        ],
        'JMD' => [
            'JMD',
            'Jamaika doları',
        ],
        'JOD' => [
            'JOD',
            'Ürdün dinarı',
        ],
        'JPY' => [
            '¥',
            'Japon yeni',
        ],
        'KES' => [
            'KES',
            'Kenya şilini',
        ],
        'KGS' => [
            'KGS',
            'Kırgızistan somu',
        ],
        'KHR' => [
            'KHR',
            'Kamboçya rieli',
        ],
        'KMF' => [
            'KMF',
            'Komorlar frangı',
        ],
        'KPW' => [
            'KPW',
            'Kuzey Kore wonu',
        ],
        'KRH' => [
            'KRH',
            'Güney Kore Hwanı (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'Güney Kore Wonu (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'Güney Kore wonu',
        ],
        'KWD' => [
            'KWD',
            'Kuveyt dinarı',
        ],
        'KYD' => [
            'KYD',
            'Cayman Adaları doları',
        ],
        'KZT' => [
            'KZT',
            'Kazakistan tengesi',
        ],
        'LAK' => [
            'LAK',
            'Laos kipi',
        ],
        'LBP' => [
            'LBP',
            'Lübnan lirası',
        ],
        'LKR' => [
            'LKR',
            'Sri Lanka rupisi',
        ],
        'LRD' => [
            'LRD',
            'Liberya doları',
        ],
        'LSL' => [
            'LSL',
            'Lesotho lotisi',
        ],
        'LTL' => [
            'LTL',
            'Litvanya Litası',
        ],
        'LTT' => [
            'LTT',
            'Litvanya Talonu',
        ],
        'LUC' => [
            'LUC',
            'Konvertibl Lüksemburg Frangı',
        ],
        'LUF' => [
            'LUF',
            'Lüksemburg Frangı',
        ],
        'LUL' => [
            'LUL',
            'Finansal Lüksemburg Frangı',
        ],
        'LVL' => [
            'LVL',
            'Letonya Latı',
        ],
        'LVR' => [
            'LVR',
            'Letonya Rublesi',
        ],
        'LYD' => [
            'LYD',
            'Libya dinarı',
        ],
        'MAD' => [
            'MAD',
            'Fas dirhemi',
        ],
        'MAF' => [
            'MAF',
            'Fas Frangı',
        ],
        'MCF' => [
            'MCF',
            'Monako Frangı',
        ],
        'MDC' => [
            'MDC',
            'Moldova Kuponu',
        ],
        'MDL' => [
            'MDL',
            'Moldova leyi',
        ],
        'MGA' => [
            'MGA',
            'Madagaskar ariarisi',
        ],
        'MGF' => [
            'MGF',
            'Madagaskar Frangı',
        ],
        'MKD' => [
            'MKD',
            'Makedonya dinarı',
        ],
        'MKN' => [
            'MKN',
            'Makedonya Dinarı (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'Mali Frangı',
        ],
        'MMK' => [
            'MMK',
            'Myanmar kyatı',
        ],
        'MNT' => [
            'MNT',
            'Moğolistan tugriki',
        ],
        'MOP' => [
            'MOP',
            'Makao patakası',
        ],
        'MRO' => [
            'MRO',
            'Moritanya Ugiyası (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Moritanya ugiyası',
        ],
        'MTL' => [
            'MTL',
            'Malta Lirası',
        ],
        'MTP' => [
            'MTP',
            'Malta Sterlini',
        ],
        'MUR' => [
            'MUR',
            'Mauritius rupisi',
        ],
        'MVP' => [
            'MVP',
            'Maldiv Rupisi',
        ],
        'MVR' => [
            'MVR',
            'Maldiv rufiyaası',
        ],
        'MWK' => [
            'MWK',
            'Malavi kvaçası',
        ],
        'MXN' => [
            'MX$',
            'Meksika pesosu',
        ],
        'MXP' => [
            'MXP',
            'Gümüş Meksika Pezosu (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Meksika Unidad de Inversion (UDI)',
        ],
        'MYR' => [
            'MYR',
            'Malezya ringgiti',
        ],
        'MZE' => [
            'MZE',
            'Mozambik Esküdosu',
        ],
        'MZM' => [
            'MZM',
            'Eski Mozambik Metikali',
        ],
        'MZN' => [
            'MZN',
            'Mozambik metikali',
        ],
        'NAD' => [
            'NAD',
            'Namibya doları',
        ],
        'NGN' => [
            'NGN',
            'Nijerya nairası',
        ],
        'NIC' => [
            'NIC',
            'Nikaragua Kordobası (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'Nikaragua kordobası',
        ],
        'NLG' => [
            'NLG',
            'Hollanda Florini',
        ],
        'NOK' => [
            'NOK',
            'Norveç kronu',
        ],
        'NPR' => [
            'NPR',
            'Nepal rupisi',
        ],
        'NZD' => [
            'NZ$',
            'Yeni Zelanda doları',
        ],
        'OMR' => [
            'OMR',
            'Umman riyali',
        ],
        'PAB' => [
            'PAB',
            'Panama balboası',
        ],
        'PEI' => [
            'PEI',
            'Peru İnti',
        ],
        'PEN' => [
            'PEN',
            'Peru solü',
        ],
        'PES' => [
            'PES',
            'Peru Solü (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'Papua Yeni Gine kinası',
        ],
        'PHP' => [
            'PHP',
            'Filipinler pesosu',
        ],
        'PKR' => [
            'PKR',
            'Pakistan rupisi',
        ],
        'PLN' => [
            'PLN',
            'Polonya zlotisi',
        ],
        'PLZ' => [
            'PLZ',
            'Polonya Zlotisi (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'Portekiz Esküdosu',
        ],
        'PYG' => [
            'PYG',
            'Paraguay guaranisi',
        ],
        'QAR' => [
            'QAR',
            'Katar riyali',
        ],
        'RHD' => [
            'RHD',
            'Rodezya Doları',
        ],
        'ROL' => [
            'ROL',
            'Eski Romen Leyi',
        ],
        'RON' => [
            'RON',
            'Romen leyi',
        ],
        'RSD' => [
            'RSD',
            'Sırp dinarı',
        ],
        'RUB' => [
            'RUB',
            'Rus rublesi',
        ],
        'RUR' => [
            'RUR',
            'Rus Rublesi (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'Ruanda frangı',
        ],
        'SAR' => [
            'SAR',
            'Suudi Arabistan riyali',
        ],
        'SBD' => [
            'SBD',
            'Solomon Adaları doları',
        ],
        'SCR' => [
            'SCR',
            'Seyşeller rupisi',
        ],
        'SDD' => [
            'SDD',
            'Eski Sudan Dinarı',
        ],
        'SDG' => [
            'SDG',
            'Sudan lirası',
        ],
        'SDP' => [
            'SDP',
            'Eski Sudan Lirası',
        ],
        'SEK' => [
            'SEK',
            'İsveç kronu',
        ],
        'SGD' => [
            'SGD',
            'Singapur doları',
        ],
        'SHP' => [
            'SHP',
            'Saint Helena lirası',
        ],
        'SIT' => [
            'SIT',
            'Slovenya Toları',
        ],
        'SKK' => [
            'SKK',
            'Slovak Korunası',
        ],
        'SLE' => [
            'SLE',
            'Sierra Leone leonesi',
        ],
        'SLL' => [
            'SLL',
            'Sierra Leone leonesi (1964–2022)',
        ],
        'SOS' => [
            'SOS',
            'Somali şilini',
        ],
        'SRD' => [
            'SRD',
            'Surinam doları',
        ],
        'SRG' => [
            'SRG',
            'Surinam Guldeni',
        ],
        'SSP' => [
            'SSP',
            'Güney Sudan lirası',
        ],
        'STD' => [
            'STD',
            'São Tomé ve Príncipe Dobrası (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Sao Tome ve Principe dobrası',
        ],
        'SUR' => [
            'SUR',
            'Sovyet Rublesi',
        ],
        'SVC' => [
            'SVC',
            'El Salvador Kolonu',
        ],
        'SYP' => [
            'SYP',
            'Suriye lirası',
        ],
        'SZL' => [
            'SZL',
            'Svaziland lilangenisi',
        ],
        'THB' => [
            '฿',
            'Tayland bahtı',
        ],
        'TJR' => [
            'TJR',
            'Tacikistan Rublesi',
        ],
        'TJS' => [
            'TJS',
            'Tacikistan somonisi',
        ],
        'TMM' => [
            'TMM',
            'Türkmenistan Manatı (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'Türkmenistan manatı',
        ],
        'TND' => [
            'TND',
            'Tunus dinarı',
        ],
        'TOP' => [
            'TOP',
            'Tonga paʻangası',
        ],
        'TPE' => [
            'TPE',
            'Timor Esküdosu',
        ],
        'TRL' => [
            'TRL',
            'Eski Türk Lirası',
        ],
        'TRY' => [
            '₺',
            'Türk lirası',
        ],
        'TTD' => [
            'TTD',
            'Trinidad ve Tobago doları',
        ],
        'TWD' => [
            'NT$',
            'Yeni Tayvan doları',
        ],
        'TZS' => [
            'TZS',
            'Tanzanya şilini',
        ],
        'UAH' => [
            'UAH',
            'Ukrayna grivnası',
        ],
        'UAK' => [
            'UAK',
            'Ukrayna Karbovanetz',
        ],
        'UGS' => [
            'UGS',
            'Uganda Şilini (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'Uganda şilini',
        ],
        'USD' => [
            '$',
            'ABD doları',
        ],
        'USN' => [
            'USN',
            'ABD Doları (Ertesi gün)',
        ],
        'USS' => [
            'USS',
            'ABD Doları (Aynı gün)',
        ],
        'UYI' => [
            'UYI',
            'Uruguay Peso en Unidades Indexadas',
        ],
        'UYP' => [
            'UYP',
            'Uruguay Pezosu (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'Uruguay pesosu',
        ],
        'UZS' => [
            'UZS',
            'Özbekistan somu',
        ],
        'VEB' => [
            'VEB',
            'Venezuela Bolivarı (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'Venezuela Bolivarı (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Venezuela bolivarı',
        ],
        'VND' => [
            '₫',
            'Vietnam dongu',
        ],
        'VNN' => [
            'VNN',
            'Vietnam Dongu (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'Vanuatu vatusu',
        ],
        'WST' => [
            'WST',
            'Samoa talası',
        ],
        'XAF' => [
            'FCFA',
            'Orta Afrika CFA frangı',
        ],
        'XCD' => [
            'EC$',
            'Doğu Karayip doları',
        ],
        'XCG' => [
            'Cg.',
            'Karayip guldeni',
        ],
        'XEU' => [
            'XEU',
            'Avrupa Para Birimi',
        ],
        'XFO' => [
            'XFO',
            'Fransız Altın Frangı',
        ],
        'XFU' => [
            'XFU',
            'Fransız UIC-Frangı',
        ],
        'XOF' => [
            'F CFA',
            'Batı Afrika CFA frangı',
        ],
        'XPF' => [
            'CFPF',
            'CFP frangı',
        ],
        'XRE' => [
            'XRE',
            'RINET Fonları',
        ],
        'YDD' => [
            'YDD',
            'Yemen Dinarı',
        ],
        'YER' => [
            'YER',
            'Yemen riyali',
        ],
        'YUD' => [
            'YUD',
            'Yugoslav Dinarı (Hard)',
        ],
        'YUM' => [
            'YUM',
            'Yeni Yugoslav Dinarı',
        ],
        'YUN' => [
            'YUN',
            'Konvertibl Yugoslav Dinarı',
        ],
        'YUR' => [
            'YUR',
            'İyileştirilmiş Yugoslav Dinarı (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'Güney Afrika Randı (finansal)',
        ],
        'ZAR' => [
            'ZAR',
            'Güney Afrika randı',
        ],
        'ZMK' => [
            'ZMK',
            'Zambiya Kvaçası (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Zambiya kvaçası',
        ],
        'ZRN' => [
            'ZRN',
            'Yeni Zaire Zairesi',
        ],
        'ZRZ' => [
            'ZRZ',
            'Zaire Zairesi',
        ],
        'ZWD' => [
            'ZWD',
            'Zimbabve Doları',
        ],
        'ZWG' => [
            'ZWG',
            'Zimbabve altını',
        ],
        'ZWL' => [
            'ZWL',
            'Zimbabve Doları (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'Zimbabve Doları (2008)',
        ],
    ],
];
