<?php

return [
    'Names' => [
        'Adlm' => 'адлам жазуы',
        'Aghb' => 'агван жазуы',
        'Ahom' => 'ахом жазуы',
        'Arab' => 'араб жазуы',
        'Aran' => 'насталик жазуы',
        'Armi' => 'арамей жазуы',
        'Armn' => 'армян жазуы',
        'Avst' => 'авеста жазуы',
        'Bali' => 'балий жазуы',
        'Bamu' => 'бамум жазуы',
        'Bass' => 'басса жазуы',
        'Batk' => 'батак жазуы',
        'Beng' => 'бенгал жазуы',
        'Bhks' => 'бхайксуки жазуы',
        'Bopo' => 'бопомофо жазуы',
        'Brah' => 'брахми жазуы',
        'Brai' => 'Брайль жазуы',
        'Bugi' => 'бугий жазуы',
        'Buhd' => 'бухид жазуы',
        'Cakm' => 'чакма жазуы',
        'Cans' => 'канадалық буын жүйелі жазу',
        'Cari' => 'карий жазуы',
        'Cham' => 'чам жазуы',
        'Cher' => 'чероки жазуы',
        'Chrs' => 'хорезм жазуы',
        'Copt' => 'копт жазуы',
        'Cpmn' => 'кипр-миной жазуы',
        'Cprt' => 'кипр жазуы',
        'Cyrl' => 'кирилл жазуы',
        'Deva' => 'деванагари жазуы',
        'Diak' => 'дивехи акуру жазуы',
        'Dogr' => 'догри жазуы',
        'Dsrt' => 'дезерет жазуы',
        'Dupl' => 'дюплойе жазуы',
        'Egyp' => 'мысыр жазуы',
        'Elba' => 'эльбасан жазуы',
        'Elym' => 'элимай жазуы',
        'Ethi' => 'эфиопиялық жазу',
        'Geor' => 'грузин жазуы',
        'Glag' => 'глаголица',
        'Gong' => 'гунджала гонди жазуы',
        'Gonm' => 'масарам гонди жазуы',
        'Goth' => 'гот жазуы',
        'Gran' => 'грантха жазуы',
        'Grek' => 'грек жазуы',
        'Gujr' => 'гуджарати жазуы',
        'Guru' => 'гурмукхи жазуы',
        'Hanb' => 'ханб жазуы',
        'Hang' => 'хангыл жазуы',
        'Hani' => 'қытай жазуы',
        'Hano' => 'хануну жазуы',
        'Hans' => 'жеңілдетілген жазу',
        'Hant' => 'дәстүрлі жазу',
        'Hatr' => 'хатра жазуы',
        'Hebr' => 'иврит жазуы',
        'Hira' => 'хирагана жазуы',
        'Hluw' => 'Анадолы иероглифтері',
        'Hmng' => 'пахау жазуы',
        'Hmnp' => 'ньиакенг пуачуэ хмонг жазуы',
        'Hrkt' => 'хирагана немесе катакана',
        'Hung' => 'мажар рунасы',
        'Ital' => 'ескі италия жазуы',
        'Jamo' => 'джамо жазуы',
        'Java' => 'ява жазуы',
        'Jpan' => 'жапон жазуы',
        'Kali' => 'кая-ли жазуы',
        'Kana' => 'катакана жазуы',
        'Kawi' => 'кави жазуы',
        'Khar' => 'кхароштхи жазуы',
        'Khmr' => 'кхмер жазуы',
        'Khoj' => 'ходжики жазуы',
        'Kits' => 'шағын кидан жазуы',
        'Knda' => 'каннада жазуы',
        'Kore' => 'корей жазуы',
        'Kthi' => 'кайтхи жазуы',
        'Lana' => 'ланна жазуы',
        'Laoo' => 'лаос жазуы',
        'Latn' => 'латын жазуы',
        'Lepc' => 'лепча жазуы',
        'Limb' => 'лимбу жазуы',
        'Lina' => 'A линиялық жазуы',
        'Linb' => 'B линиялық жазуы',
        'Lisu' => 'фрейзер жазуы',
        'Lyci' => 'ликий жазуы',
        'Lydi' => 'лидий жазуы',
        'Mahj' => 'махаджани жазуы',
        'Maka' => 'макасар жазуы',
        'Mand' => 'мандей жазуы',
        'Mani' => 'манихей жазуы',
        'Marc' => 'марчен жазуы',
        'Medf' => 'обэри окаимэ жазуы',
        'Mend' => 'кикакуи жазуы',
        'Merc' => 'мероит курсив жазуы',
        'Mero' => 'мероит жазуы',
        'Mlym' => 'малаялам жазуы',
        'Modi' => 'моди жазуы',
        'Mong' => 'моңғол жазуы',
        'Mroo' => 'мро жазуы',
        'Mtei' => 'мейтей жазуы',
        'Mult' => 'мултани жазуы',
        'Mymr' => 'мьянма жазуы',
        'Nagm' => 'наг мундари жазуы',
        'Nand' => 'нандинагари жазуы',
        'Narb' => 'көне солтүстік араб жазуы',
        'Nbat' => 'набатей жазуы',
        'Newa' => 'ньюа жазуы',
        'Nkoo' => 'нко жазуы',
        'Nshu' => 'нюй-шу жазуы',
        'Ogam' => 'огам жазуы',
        'Olck' => 'ол-чики жазуы',
        'Orkh' => 'көне түркі жазбалары',
        'Orya' => 'ория жазуы',
        'Osge' => 'осейдж жазуы',
        'Osma' => 'исмания жазуы',
        'Ougr' => 'көне ұйғыр жазуы',
        'Palm' => 'палмир жазуы',
        'Pauc' => 'пау син хау жазуы',
        'Perm' => 'көне перм жазуы',
        'Phag' => 'тибет-моңғол жазуы',
        'Phli' => 'жазба пехлеви',
        'Phlp' => 'забур пехлеви жазуы',
        'Phnx' => 'финикия жазуы',
        'Plrd' => 'поллард фонетикалық жазуы',
        'Prti' => 'жазба парфия',
        'Qaag' => 'зоджи жазуы',
        'Rjng' => 'реджанг жазуы',
        'Rohg' => 'ханифи жазуы',
        'Runr' => 'руна',
        'Samr' => 'самария жазуы',
        'Sarb' => 'оңтүстік араб жазуы',
        'Saur' => 'саураштра жазуы',
        'Sgnw' => 'жазу',
        'Shaw' => 'шоу жазуы',
        'Shrd' => 'шарада жазуы',
        'Sidd' => 'сиддхам жазуы',
        'Sind' => 'кхудавади жазуы',
        'Sinh' => 'сингаль жазуы',
        'Sogd' => 'соғды жазуы',
        'Sogo' => 'көне соғды жазуы',
        'Sora' => 'соранг сомпенг жазуы',
        'Soyo' => 'соёмбо жазуы',
        'Sund' => 'сунд жазуы',
        'Sylo' => 'силхет нагари жазуы',
        'Syrc' => 'сирия жазуы',
        'Tagb' => 'тагбанва жазуы',
        'Takr' => 'такри жазуы',
        'Tale' => 'лы жазуы',
        'Talu' => 'жаңа лы жазуы',
        'Taml' => 'тамиль жазуы',
        'Tang' => 'танғұт жазуы',
        'Tavt' => 'тай вьет жазуы',
        'Telu' => 'телугу жазуы',
        'Tfng' => 'тифинаг жазуы',
        'Tglg' => 'байбайин жазуы',
        'Thaa' => 'тана жазуы',
        'Thai' => 'тай жазуы',
        'Tibt' => 'тибет жазуы',
        'Tirh' => 'тирхута жазуы',
        'Tnsa' => 'тангса жазуы',
        'Toto' => 'тото жазуы',
        'Ugar' => 'угарит жазуы',
        'Vaii' => 'ваи жазуы',
        'Vith' => 'виткути жазуы',
        'Wara' => 'варанг кшити жазуы',
        'Wcho' => 'ванчо жазуы',
        'Xpeo' => 'көне парсы жазуы',
        'Xsux' => 'шумер-аккад сына жазуы',
        'Yezi' => 'езид жазуы',
        'Yiii' => 'и жазуы',
        'Zanb' => 'занабазар шаршы жазуы',
        'Zinh' => 'мұра етілген',
        'Zmth' => 'математикалық жазу',
        'Zsye' => 'эмодзи',
        'Zsym' => 'таңбалар',
        'Zxxx' => 'жазусыз',
        'Zyyy' => 'жалпы',
    ],
];
