<?php

return [
    'Names' => [
        'af' => 'Kiafrikana',
        'af_NA' => 'Kiafrikana (Namibia)',
        'af_ZA' => 'Kiafrikana (Afrika Kusini)',
        'ak' => 'Kiakani',
        'ak_GH' => 'Kiakani (Ghana)',
        'am' => 'Kiamhari',
        'am_ET' => 'Kiamhari (Ethiopia)',
        'ar' => 'Kiarabu',
        'ar_001' => 'Kiarabu (Dunia)',
        'ar_AE' => 'Kiarabu (Falme za Kiarabu)',
        'ar_BH' => 'Kiarabu (Bahareni)',
        'ar_DJ' => 'Kiarabu (Jibuti)',
        'ar_DZ' => 'Kiarabu (Aljeria)',
        'ar_EG' => 'Kiarabu (Misri)',
        'ar_EH' => 'Kiarabu (Sahara Magharibi)',
        'ar_ER' => 'Kiarabu (Eritrea)',
        'ar_IL' => 'Kiarabu (Israeli)',
        'ar_IQ' => 'Kiarabu (Iraki)',
        'ar_JO' => 'Kiarabu (Jordan)',
        'ar_KM' => 'Kiarabu (Komoro)',
        'ar_KW' => 'Kiarabu (Kuwait)',
        'ar_LB' => 'Kiarabu (Lebanon)',
        'ar_LY' => 'Kiarabu (Libya)',
        'ar_MA' => 'Kiarabu (Morocco)',
        'ar_MR' => 'Kiarabu (Moritania)',
        'ar_OM' => 'Kiarabu (Oman)',
        'ar_PS' => 'Kiarabu (Maeneo ya Palestina)',
        'ar_QA' => 'Kiarabu (Qatar)',
        'ar_SA' => 'Kiarabu (Saudia)',
        'ar_SD' => 'Kiarabu (Sudan)',
        'ar_SO' => 'Kiarabu (Somalia)',
        'ar_SS' => 'Kiarabu (Sudan Kusini)',
        'ar_SY' => 'Kiarabu (Syria)',
        'ar_TD' => 'Kiarabu (Chad)',
        'ar_TN' => 'Kiarabu (Tunisia)',
        'ar_YE' => 'Kiarabu (Yemeni)',
        'as' => 'Kiassam',
        'as_IN' => 'Kiassam (India)',
        'az' => 'Kiazerbaijani',
        'az_AZ' => 'Kiazerbaijani (Azerbaijani)',
        'az_Cyrl' => 'Kiazerbaijani (Kisiriliki)',
        'az_Cyrl_AZ' => 'Kiazerbaijani (Kisiriliki, Azerbaijani)',
        'az_Latn' => 'Kiazerbaijani (Kilatini)',
        'az_Latn_AZ' => 'Kiazerbaijani (Kilatini, Azerbaijani)',
        'ba' => 'Kibashkiri',
        'ba_RU' => 'Kibashkiri (Urusi)',
        'be' => 'Kibelarusi',
        'be_BY' => 'Kibelarusi (Belarus)',
        'bg' => 'Kibulgaria',
        'bg_BG' => 'Kibulgaria (Bulgaria)',
        'bm' => 'Kibambara',
        'bm_ML' => 'Kibambara (Mali)',
        'bn' => 'Kibengali',
        'bn_BD' => 'Kibengali (Bangladeshi)',
        'bn_IN' => 'Kibengali (India)',
        'bo' => 'Kitibeti',
        'bo_CN' => 'Kitibeti (Uchina)',
        'bo_IN' => 'Kitibeti (India)',
        'br' => 'Kibretoni',
        'br_FR' => 'Kibretoni (Ufaransa)',
        'bs' => 'Kibosnia',
        'bs_BA' => 'Kibosnia (Bosnia na Hezegovina)',
        'bs_Cyrl' => 'Kibosnia (Kisiriliki)',
        'bs_Cyrl_BA' => 'Kibosnia (Kisiriliki, Bosnia na Hezegovina)',
        'bs_Latn' => 'Kibosnia (Kilatini)',
        'bs_Latn_BA' => 'Kibosnia (Kilatini, Bosnia na Hezegovina)',
        'ca' => 'Kikatalani',
        'ca_AD' => 'Kikatalani (Andorra)',
        'ca_ES' => 'Kikatalani (Uhispania)',
        'ca_FR' => 'Kikatalani (Ufaransa)',
        'ca_IT' => 'Kikatalani (Italia)',
        'ce' => 'Kichechenia',
        'ce_RU' => 'Kichechenia (Urusi)',
        'cs' => 'Kicheki',
        'cs_CZ' => 'Kicheki (Chechia)',
        'cv' => 'Kichuvash',
        'cv_RU' => 'Kichuvash (Urusi)',
        'cy' => 'Kiwelisi',
        'cy_GB' => 'Kiwelisi (Ufalme wa Muungano)',
        'da' => 'Kidenmaki',
        'da_DK' => 'Kidenmaki (Denmaki)',
        'da_GL' => 'Kidenmaki (Greenland)',
        'de' => 'Kijerumani',
        'de_AT' => 'Kijerumani (Austria)',
        'de_BE' => 'Kijerumani (Ubelgiji)',
        'de_CH' => 'Kijerumani (Uswisi)',
        'de_DE' => 'Kijerumani (Ujerumani)',
        'de_IT' => 'Kijerumani (Italia)',
        'de_LI' => 'Kijerumani (Liechtenstein)',
        'de_LU' => 'Kijerumani (Luxembourg)',
        'dz' => 'Kizongkha',
        'dz_BT' => 'Kizongkha (Bhutan)',
        'ee' => 'Kiewe',
        'ee_GH' => 'Kiewe (Ghana)',
        'ee_TG' => 'Kiewe (Togo)',
        'el' => 'Kigiriki',
        'el_CY' => 'Kigiriki (Saiprasi)',
        'el_GR' => 'Kigiriki (Ugiriki)',
        'en' => 'Kiingereza',
        'en_001' => 'Kiingereza (Dunia)',
        'en_150' => 'Kiingereza (Ulaya)',
        'en_AE' => 'Kiingereza (Falme za Kiarabu)',
        'en_AG' => 'Kiingereza (Antigua na Barbuda)',
        'en_AI' => 'Kiingereza (Anguilla)',
        'en_AS' => 'Kiingereza (Samoa ya Marekani)',
        'en_AT' => 'Kiingereza (Austria)',
        'en_AU' => 'Kiingereza (Australia)',
        'en_BB' => 'Kiingereza (Babadosi)',
        'en_BE' => 'Kiingereza (Ubelgiji)',
        'en_BI' => 'Kiingereza (Burundi)',
        'en_BM' => 'Kiingereza (Bermuda)',
        'en_BS' => 'Kiingereza (Bahama)',
        'en_BW' => 'Kiingereza (Botswana)',
        'en_BZ' => 'Kiingereza (Belize)',
        'en_CA' => 'Kiingereza (Kanada)',
        'en_CC' => 'Kiingereza (Visiwa vya Cocos [Keeling])',
        'en_CH' => 'Kiingereza (Uswisi)',
        'en_CK' => 'Kiingereza (Visiwa vya Cook)',
        'en_CM' => 'Kiingereza (Kameruni)',
        'en_CX' => 'Kiingereza (Kisiwa cha Krismasi)',
        'en_CY' => 'Kiingereza (Saiprasi)',
        'en_CZ' => 'Kiingereza (Chechia)',
        'en_DE' => 'Kiingereza (Ujerumani)',
        'en_DK' => 'Kiingereza (Denmaki)',
        'en_DM' => 'Kiingereza (Dominika)',
        'en_EE' => 'Kiingereza (Estonia)',
        'en_ER' => 'Kiingereza (Eritrea)',
        'en_ES' => 'Kiingereza (Uhispania)',
        'en_FI' => 'Kiingereza (Ufini)',
        'en_FJ' => 'Kiingereza (Fiji)',
        'en_FK' => 'Kiingereza (Visiwa vya Falkland)',
        'en_FM' => 'Kiingereza (Mikronesia)',
        'en_FR' => 'Kiingereza (Ufaransa)',
        'en_GB' => 'Kiingereza (Ufalme wa Muungano)',
        'en_GD' => 'Kiingereza (Grenada)',
        'en_GE' => 'Kiingereza (Jojia)',
        'en_GG' => 'Kiingereza (Guernsey)',
        'en_GH' => 'Kiingereza (Ghana)',
        'en_GI' => 'Kiingereza (Gibraltar)',
        'en_GM' => 'Kiingereza (Gambia)',
        'en_GS' => 'Kiingereza (Visiwa vya Georgia Kusini na Sandwich Kusini)',
        'en_GU' => 'Kiingereza (Guam)',
        'en_GY' => 'Kiingereza (Guyana)',
        'en_HK' => 'Kiingereza (Hong Kong SAR China)',
        'en_HU' => 'Kiingereza (Hungaria)',
        'en_ID' => 'Kiingereza (Indonesia)',
        'en_IE' => 'Kiingereza (Ayalandi)',
        'en_IL' => 'Kiingereza (Israeli)',
        'en_IM' => 'Kiingereza (Kisiwa cha Man)',
        'en_IN' => 'Kiingereza (India)',
        'en_IO' => 'Kiingereza (Eneo la Uingereza katika Bahari Hindi)',
        'en_IT' => 'Kiingereza (Italia)',
        'en_JE' => 'Kiingereza (Jersey)',
        'en_JM' => 'Kiingereza (Jamaika)',
        'en_JP' => 'Kiingereza (Japani)',
        'en_KE' => 'Kiingereza (Kenya)',
        'en_KI' => 'Kiingereza (Kiribati)',
        'en_KN' => 'Kiingereza (St. Kitts na Nevis)',
        'en_KY' => 'Kiingereza (Visiwa vya Cayman)',
        'en_LC' => 'Kiingereza (St. Lucia)',
        'en_LR' => 'Kiingereza (Liberia)',
        'en_LS' => 'Kiingereza (Lesoto)',
        'en_LT' => 'Kiingereza (Lithuania)',
        'en_LV' => 'Kiingereza (Latvia)',
        'en_MG' => 'Kiingereza (Madagaska)',
        'en_MH' => 'Kiingereza (Visiwa vya Marshall)',
        'en_MO' => 'Kiingereza (Makau SAR China)',
        'en_MP' => 'Kiingereza (Visiwa vya Mariana vya Kaskazini)',
        'en_MS' => 'Kiingereza (Montserrat)',
        'en_MT' => 'Kiingereza (Malta)',
        'en_MU' => 'Kiingereza (Morisi)',
        'en_MV' => 'Kiingereza (Maldivi)',
        'en_MW' => 'Kiingereza (Malawi)',
        'en_MY' => 'Kiingereza (Malesia)',
        'en_NA' => 'Kiingereza (Namibia)',
        'en_NF' => 'Kiingereza (Kisiwa cha Norfolk)',
        'en_NG' => 'Kiingereza (Nigeria)',
        'en_NL' => 'Kiingereza (Uholanzi)',
        'en_NO' => 'Kiingereza (Norway)',
        'en_NR' => 'Kiingereza (Nauru)',
        'en_NU' => 'Kiingereza (Niue)',
        'en_NZ' => 'Kiingereza (Nyuzilandi)',
        'en_PG' => 'Kiingereza (Papua New Guinea)',
        'en_PH' => 'Kiingereza (Ufilipino)',
        'en_PK' => 'Kiingereza (Pakistani)',
        'en_PL' => 'Kiingereza (Poland)',
        'en_PN' => 'Kiingereza (Visiwa vya Pitcairn)',
        'en_PR' => 'Kiingereza (Puerto Rico)',
        'en_PT' => 'Kiingereza (Ureno)',
        'en_PW' => 'Kiingereza (Palau)',
        'en_RO' => 'Kiingereza (Romania)',
        'en_RW' => 'Kiingereza (Rwanda)',
        'en_SB' => 'Kiingereza (Visiwa vya Solomon)',
        'en_SC' => 'Kiingereza (Ushelisheli)',
        'en_SD' => 'Kiingereza (Sudan)',
        'en_SE' => 'Kiingereza (Uswidi)',
        'en_SG' => 'Kiingereza (Singapore)',
        'en_SH' => 'Kiingereza (St. Helena)',
        'en_SI' => 'Kiingereza (Slovenia)',
        'en_SK' => 'Kiingereza (Slovakia)',
        'en_SL' => 'Kiingereza (Siera Leoni)',
        'en_SS' => 'Kiingereza (Sudan Kusini)',
        'en_SX' => 'Kiingereza (Sint Maarten)',
        'en_SZ' => 'Kiingereza (Eswatini)',
        'en_TC' => 'Kiingereza (Visiwa vya Turks na Caicos)',
        'en_TK' => 'Kiingereza (Tokelau)',
        'en_TO' => 'Kiingereza (Tonga)',
        'en_TT' => 'Kiingereza (Trinidad na Tobago)',
        'en_TV' => 'Kiingereza (Tuvalu)',
        'en_TZ' => 'Kiingereza (Tanzania)',
        'en_UA' => 'Kiingereza (Ukraine)',
        'en_UG' => 'Kiingereza (Uganda)',
        'en_UM' => 'Kiingereza (Visiwa Vidogo vya Nje vya Marekani)',
        'en_US' => 'Kiingereza (Marekani)',
        'en_VC' => 'Kiingereza (St. Vincent na Grenadines)',
        'en_VG' => 'Kiingereza (Visiwa vya Virgin, Uingereza)',
        'en_VI' => 'Kiingereza (Visiwa vya Virgin, Marekani)',
        'en_VU' => 'Kiingereza (Vanuatu)',
        'en_WS' => 'Kiingereza (Samoa)',
        'en_ZA' => 'Kiingereza (Afrika Kusini)',
        'en_ZM' => 'Kiingereza (Zambia)',
        'en_ZW' => 'Kiingereza (Zimbabwe)',
        'eo' => 'Kiesperanto',
        'eo_001' => 'Kiesperanto (Dunia)',
        'es' => 'Kihispania',
        'es_419' => 'Kihispania (Amerika ya Kilatini)',
        'es_AR' => 'Kihispania (Ajentina)',
        'es_BO' => 'Kihispania (Bolivia)',
        'es_BR' => 'Kihispania (Brazil)',
        'es_BZ' => 'Kihispania (Belize)',
        'es_CL' => 'Kihispania (Chile)',
        'es_CO' => 'Kihispania (Kolombia)',
        'es_CR' => 'Kihispania (Kostarika)',
        'es_CU' => 'Kihispania (Kuba)',
        'es_DO' => 'Kihispania (Jamhuri ya Dominika)',
        'es_EC' => 'Kihispania (Ecuador)',
        'es_ES' => 'Kihispania (Uhispania)',
        'es_GQ' => 'Kihispania (Guinea ya Ikweta)',
        'es_GT' => 'Kihispania (Guatemala)',
        'es_HN' => 'Kihispania (Honduras)',
        'es_MX' => 'Kihispania (Meksiko)',
        'es_NI' => 'Kihispania (Nikaragwa)',
        'es_PA' => 'Kihispania (Panama)',
        'es_PE' => 'Kihispania (Peru)',
        'es_PH' => 'Kihispania (Ufilipino)',
        'es_PR' => 'Kihispania (Puerto Rico)',
        'es_PY' => 'Kihispania (Paraguay)',
        'es_SV' => 'Kihispania (El Salvador)',
        'es_US' => 'Kihispania (Marekani)',
        'es_UY' => 'Kihispania (Uruguay)',
        'es_VE' => 'Kihispania (Venezuela)',
        'et' => 'Kiestonia',
        'et_EE' => 'Kiestonia (Estonia)',
        'eu' => 'Kibaski',
        'eu_ES' => 'Kibaski (Uhispania)',
        'fa' => 'Kiajemi',
        'fa_AF' => 'Kiajemi (Afghanistan)',
        'fa_IR' => 'Kiajemi (Iran)',
        'ff' => 'Kifulani',
        'ff_Adlm' => 'Kifulani (Kiadlamu)',
        'ff_Adlm_BF' => 'Kifulani (Kiadlamu, Bukinafaso)',
        'ff_Adlm_CM' => 'Kifulani (Kiadlamu, Kameruni)',
        'ff_Adlm_GH' => 'Kifulani (Kiadlamu, Ghana)',
        'ff_Adlm_GM' => 'Kifulani (Kiadlamu, Gambia)',
        'ff_Adlm_GN' => 'Kifulani (Kiadlamu, Gine)',
        'ff_Adlm_GW' => 'Kifulani (Kiadlamu, Ginebisau)',
        'ff_Adlm_LR' => 'Kifulani (Kiadlamu, Liberia)',
        'ff_Adlm_MR' => 'Kifulani (Kiadlamu, Moritania)',
        'ff_Adlm_NE' => 'Kifulani (Kiadlamu, Niger)',
        'ff_Adlm_NG' => 'Kifulani (Kiadlamu, Nigeria)',
        'ff_Adlm_SL' => 'Kifulani (Kiadlamu, Siera Leoni)',
        'ff_Adlm_SN' => 'Kifulani (Kiadlamu, Senegali)',
        'ff_CM' => 'Kifulani (Kameruni)',
        'ff_GN' => 'Kifulani (Gine)',
        'ff_Latn' => 'Kifulani (Kilatini)',
        'ff_Latn_BF' => 'Kifulani (Kilatini, Bukinafaso)',
        'ff_Latn_CM' => 'Kifulani (Kilatini, Kameruni)',
        'ff_Latn_GH' => 'Kifulani (Kilatini, Ghana)',
        'ff_Latn_GM' => 'Kifulani (Kilatini, Gambia)',
        'ff_Latn_GN' => 'Kifulani (Kilatini, Gine)',
        'ff_Latn_GW' => 'Kifulani (Kilatini, Ginebisau)',
        'ff_Latn_LR' => 'Kifulani (Kilatini, Liberia)',
        'ff_Latn_MR' => 'Kifulani (Kilatini, Moritania)',
        'ff_Latn_NE' => 'Kifulani (Kilatini, Niger)',
        'ff_Latn_NG' => 'Kifulani (Kilatini, Nigeria)',
        'ff_Latn_SL' => 'Kifulani (Kilatini, Siera Leoni)',
        'ff_Latn_SN' => 'Kifulani (Kilatini, Senegali)',
        'ff_MR' => 'Kifulani (Moritania)',
        'ff_SN' => 'Kifulani (Senegali)',
        'fi' => 'Kifini',
        'fi_FI' => 'Kifini (Ufini)',
        'fo' => 'Kifaroe',
        'fo_DK' => 'Kifaroe (Denmaki)',
        'fo_FO' => 'Kifaroe (Visiwa vya Faroe)',
        'fr' => 'Kifaransa',
        'fr_BE' => 'Kifaransa (Ubelgiji)',
        'fr_BF' => 'Kifaransa (Bukinafaso)',
        'fr_BI' => 'Kifaransa (Burundi)',
        'fr_BJ' => 'Kifaransa (Benin)',
        'fr_BL' => 'Kifaransa (St. Barthelemy)',
        'fr_CA' => 'Kifaransa (Kanada)',
        'fr_CD' => 'Kifaransa (Kongo - Kinshasa)',
        'fr_CF' => 'Kifaransa (Jamhuri ya Afrika ya Kati)',
        'fr_CG' => 'Kifaransa (Kongo - Brazzaville)',
        'fr_CH' => 'Kifaransa (Uswisi)',
        'fr_CI' => 'Kifaransa (Cote d’Ivoire)',
        'fr_CM' => 'Kifaransa (Kameruni)',
        'fr_DJ' => 'Kifaransa (Jibuti)',
        'fr_DZ' => 'Kifaransa (Aljeria)',
        'fr_FR' => 'Kifaransa (Ufaransa)',
        'fr_GA' => 'Kifaransa (Gabon)',
        'fr_GF' => 'Kifaransa (Guiana ya Ufaransa)',
        'fr_GN' => 'Kifaransa (Gine)',
        'fr_GP' => 'Kifaransa (Guadeloupe)',
        'fr_GQ' => 'Kifaransa (Guinea ya Ikweta)',
        'fr_HT' => 'Kifaransa (Haiti)',
        'fr_KM' => 'Kifaransa (Komoro)',
        'fr_LU' => 'Kifaransa (Luxembourg)',
        'fr_MA' => 'Kifaransa (Morocco)',
        'fr_MC' => 'Kifaransa (Monaco)',
        'fr_MF' => 'Kifaransa (St. Martin)',
        'fr_MG' => 'Kifaransa (Madagaska)',
        'fr_ML' => 'Kifaransa (Mali)',
        'fr_MQ' => 'Kifaransa (Martinique)',
        'fr_MR' => 'Kifaransa (Moritania)',
        'fr_MU' => 'Kifaransa (Morisi)',
        'fr_NC' => 'Kifaransa (New Caledonia)',
        'fr_NE' => 'Kifaransa (Niger)',
        'fr_PF' => 'Kifaransa (Polynesia ya Ufaransa)',
        'fr_PM' => 'Kifaransa (Santapierre na Miquelon)',
        'fr_RE' => 'Kifaransa (Reunion)',
        'fr_RW' => 'Kifaransa (Rwanda)',
        'fr_SC' => 'Kifaransa (Ushelisheli)',
        'fr_SN' => 'Kifaransa (Senegali)',
        'fr_SY' => 'Kifaransa (Syria)',
        'fr_TD' => 'Kifaransa (Chad)',
        'fr_TG' => 'Kifaransa (Togo)',
        'fr_TN' => 'Kifaransa (Tunisia)',
        'fr_VU' => 'Kifaransa (Vanuatu)',
        'fr_WF' => 'Kifaransa (Wallis na Futuna)',
        'fr_YT' => 'Kifaransa (Mayotte)',
        'fy' => 'Kifrisia cha Magharibi',
        'fy_NL' => 'Kifrisia cha Magharibi (Uholanzi)',
        'ga' => 'Kiayalandi',
        'ga_GB' => 'Kiayalandi (Ufalme wa Muungano)',
        'ga_IE' => 'Kiayalandi (Ayalandi)',
        'gd' => 'Kigaeli cha Uskoti',
        'gd_GB' => 'Kigaeli cha Uskoti (Ufalme wa Muungano)',
        'gl' => 'Kigalisi',
        'gl_ES' => 'Kigalisi (Uhispania)',
        'gu' => 'Kigujarati',
        'gu_IN' => 'Kigujarati (India)',
        'gv' => 'Kimanx',
        'gv_IM' => 'Kimanx (Kisiwa cha Man)',
        'ha' => 'Kihausa',
        'ha_GH' => 'Kihausa (Ghana)',
        'ha_NE' => 'Kihausa (Niger)',
        'ha_NG' => 'Kihausa (Nigeria)',
        'he' => 'Kiebrania',
        'he_IL' => 'Kiebrania (Israeli)',
        'hi' => 'Kihindi',
        'hi_IN' => 'Kihindi (India)',
        'hi_Latn' => 'Kihindi (Kilatini)',
        'hi_Latn_IN' => 'Kihindi (Kilatini, India)',
        'hr' => 'Kikorasia',
        'hr_BA' => 'Kikorasia (Bosnia na Hezegovina)',
        'hr_HR' => 'Kikorasia (Croatia)',
        'hu' => 'Kihungaria',
        'hu_HU' => 'Kihungaria (Hungaria)',
        'hy' => 'Kiarmenia',
        'hy_AM' => 'Kiarmenia (Armenia)',
        'ia' => 'Kiintalingua',
        'ia_001' => 'Kiintalingua (Dunia)',
        'id' => 'Kiindonesia',
        'id_ID' => 'Kiindonesia (Indonesia)',
        'ie' => 'lugha ya kisayansi',
        'ie_EE' => 'lugha ya kisayansi (Estonia)',
        'ig' => 'Kiigbo',
        'ig_NG' => 'Kiigbo (Nigeria)',
        'ii' => 'Kiyi cha Sichuan',
        'ii_CN' => 'Kiyi cha Sichuan (Uchina)',
        'is' => 'Kiisilandi',
        'is_IS' => 'Kiisilandi (Aisilandi)',
        'it' => 'Kiitaliano',
        'it_CH' => 'Kiitaliano (Uswisi)',
        'it_IT' => 'Kiitaliano (Italia)',
        'it_SM' => 'Kiitaliano (San Marino)',
        'it_VA' => 'Kiitaliano (Mji wa Vatican)',
        'ja' => 'Kijapani',
        'ja_JP' => 'Kijapani (Japani)',
        'jv' => 'Kijava',
        'jv_ID' => 'Kijava (Indonesia)',
        'ka' => 'Kijojia',
        'ka_GE' => 'Kijojia (Jojia)',
        'ki' => 'Kikikuyu',
        'ki_KE' => 'Kikikuyu (Kenya)',
        'kk' => 'Kikazakh',
        'kk_Arab' => 'Kikazakh (Kiarabu)',
        'kk_Arab_CN' => 'Kikazakh (Kiarabu, Uchina)',
        'kk_Cyrl' => 'Kikazakh (Kisiriliki)',
        'kk_Cyrl_KZ' => 'Kikazakh (Kisiriliki, Kazakistani)',
        'kk_KZ' => 'Kikazakh (Kazakistani)',
        'kl' => 'Kikalaallisut',
        'kl_GL' => 'Kikalaallisut (Greenland)',
        'km' => 'Kikambodia',
        'km_KH' => 'Kikambodia (Kambodia)',
        'kn' => 'Kikannada',
        'kn_IN' => 'Kikannada (India)',
        'ko' => 'Kikorea',
        'ko_CN' => 'Kikorea (Uchina)',
        'ko_KP' => 'Kikorea (Korea Kaskazini)',
        'ko_KR' => 'Kikorea (Korea Kusini)',
        'ks' => 'Kikashmiri',
        'ks_Arab' => 'Kikashmiri (Kiarabu)',
        'ks_Arab_IN' => 'Kikashmiri (Kiarabu, India)',
        'ks_Deva' => 'Kikashmiri (Kidevanagari)',
        'ks_Deva_IN' => 'Kikashmiri (Kidevanagari, India)',
        'ks_IN' => 'Kikashmiri (India)',
        'ku' => 'Kikurdi',
        'ku_Latn' => 'Kikurdi (Kilatini)',
        'ku_Latn_IQ' => 'Kikurdi (Kilatini, Iraki)',
        'ku_Latn_SY' => 'Kikurdi (Kilatini, Syria)',
        'ku_Latn_TR' => 'Kikurdi (Kilatini, Uturuki)',
        'ku_SY' => 'Kikurdi (Syria)',
        'ku_TR' => 'Kikurdi (Uturuki)',
        'kw' => 'Kikorni',
        'kw_GB' => 'Kikorni (Ufalme wa Muungano)',
        'ky' => 'Kikyrgyz',
        'ky_KG' => 'Kikyrgyz (Kirigizistani)',
        'lb' => 'Kilasembagi',
        'lb_LU' => 'Kilasembagi (Luxembourg)',
        'lg' => 'Kiganda',
        'lg_UG' => 'Kiganda (Uganda)',
        'ln' => 'Kilingala',
        'ln_AO' => 'Kilingala (Angola)',
        'ln_CD' => 'Kilingala (Kongo - Kinshasa)',
        'ln_CF' => 'Kilingala (Jamhuri ya Afrika ya Kati)',
        'ln_CG' => 'Kilingala (Kongo - Brazzaville)',
        'lo' => 'Kilaosi',
        'lo_LA' => 'Kilaosi (Laos)',
        'lt' => 'Kilithuania',
        'lt_LT' => 'Kilithuania (Lithuania)',
        'lu' => 'Kiluba-Katanga',
        'lu_CD' => 'Kiluba-Katanga (Kongo - Kinshasa)',
        'lv' => 'Kilatvia',
        'lv_LV' => 'Kilatvia (Latvia)',
        'mg' => 'Kimalagasi',
        'mg_MG' => 'Kimalagasi (Madagaska)',
        'mi' => 'Kimaori',
        'mi_NZ' => 'Kimaori (Nyuzilandi)',
        'mk' => 'Kimacedonia',
        'mk_MK' => 'Kimacedonia (Masedonia ya Kaskazini)',
        'ml' => 'Kimalayalamu',
        'ml_IN' => 'Kimalayalamu (India)',
        'mn' => 'Kimongolia',
        'mn_MN' => 'Kimongolia (Mongolia)',
        'mr' => 'Kimarathi',
        'mr_IN' => 'Kimarathi (India)',
        'ms' => 'Kimalei',
        'ms_BN' => 'Kimalei (Brunei)',
        'ms_ID' => 'Kimalei (Indonesia)',
        'ms_MY' => 'Kimalei (Malesia)',
        'ms_SG' => 'Kimalei (Singapore)',
        'mt' => 'Kimalta',
        'mt_MT' => 'Kimalta (Malta)',
        'my' => 'Kiburma',
        'my_MM' => 'Kiburma (Myanmar [Burma])',
        'nb' => 'Kinorwe cha Bokmal',
        'nb_NO' => 'Kinorwe cha Bokmal (Norway)',
        'nb_SJ' => 'Kinorwe cha Bokmal (Svalbard na Jan Mayen)',
        'nd' => 'Kindebele cha Kaskazini',
        'nd_ZW' => 'Kindebele cha Kaskazini (Zimbabwe)',
        'ne' => 'Kinepali',
        'ne_IN' => 'Kinepali (India)',
        'ne_NP' => 'Kinepali (Nepal)',
        'nl' => 'Kiholanzi',
        'nl_AW' => 'Kiholanzi (Aruba)',
        'nl_BE' => 'Kiholanzi (Ubelgiji)',
        'nl_BQ' => 'Kiholanzi (Uholanzi ya Karibiani)',
        'nl_CW' => 'Kiholanzi (Curacao)',
        'nl_NL' => 'Kiholanzi (Uholanzi)',
        'nl_SR' => 'Kiholanzi (Suriname)',
        'nl_SX' => 'Kiholanzi (Sint Maarten)',
        'nn' => 'Kinorwe cha Nynorsk',
        'nn_NO' => 'Kinorwe cha Nynorsk (Norway)',
        'no' => 'Kinorwe',
        'no_NO' => 'Kinorwe (Norway)',
        'oc' => 'Kiokitani',
        'oc_ES' => 'Kiokitani (Uhispania)',
        'oc_FR' => 'Kiokitani (Ufaransa)',
        'om' => 'Kioromo',
        'om_ET' => 'Kioromo (Ethiopia)',
        'om_KE' => 'Kioromo (Kenya)',
        'or' => 'Kioriya',
        'or_IN' => 'Kioriya (India)',
        'os' => 'Kiosetia',
        'os_GE' => 'Kiosetia (Jojia)',
        'os_RU' => 'Kiosetia (Urusi)',
        'pa' => 'Kipunjabi',
        'pa_Arab' => 'Kipunjabi (Kiarabu)',
        'pa_Arab_PK' => 'Kipunjabi (Kiarabu, Pakistani)',
        'pa_Guru' => 'Kipunjabi (Kigurmukhi)',
        'pa_Guru_IN' => 'Kipunjabi (Kigurmukhi, India)',
        'pa_IN' => 'Kipunjabi (India)',
        'pa_PK' => 'Kipunjabi (Pakistani)',
        'pl' => 'Kipolandi',
        'pl_PL' => 'Kipolandi (Poland)',
        'ps' => 'Kipashto',
        'ps_AF' => 'Kipashto (Afghanistan)',
        'ps_PK' => 'Kipashto (Pakistani)',
        'pt' => 'Kireno',
        'pt_AO' => 'Kireno (Angola)',
        'pt_BR' => 'Kireno (Brazil)',
        'pt_CH' => 'Kireno (Uswisi)',
        'pt_CV' => 'Kireno (Cape Verde)',
        'pt_GQ' => 'Kireno (Guinea ya Ikweta)',
        'pt_GW' => 'Kireno (Ginebisau)',
        'pt_LU' => 'Kireno (Luxembourg)',
        'pt_MO' => 'Kireno (Makau SAR China)',
        'pt_MZ' => 'Kireno (Msumbiji)',
        'pt_PT' => 'Kireno (Ureno)',
        'pt_ST' => 'Kireno (Sao Tome na Principe)',
        'pt_TL' => 'Kireno (Timor-Leste)',
        'qu' => 'Kikechua',
        'qu_BO' => 'Kikechua (Bolivia)',
        'qu_EC' => 'Kikechua (Ecuador)',
        'qu_PE' => 'Kikechua (Peru)',
        'rm' => 'Kiromanshi',
        'rm_CH' => 'Kiromanshi (Uswisi)',
        'rn' => 'Kirundi',
        'rn_BI' => 'Kirundi (Burundi)',
        'ro' => 'Kiromania',
        'ro_MD' => 'Kiromania (Moldova)',
        'ro_RO' => 'Kiromania (Romania)',
        'ru' => 'Kirusi',
        'ru_BY' => 'Kirusi (Belarus)',
        'ru_KG' => 'Kirusi (Kirigizistani)',
        'ru_KZ' => 'Kirusi (Kazakistani)',
        'ru_MD' => 'Kirusi (Moldova)',
        'ru_RU' => 'Kirusi (Urusi)',
        'ru_UA' => 'Kirusi (Ukraine)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Rwanda)',
        'sa' => 'Kisanskriti',
        'sa_IN' => 'Kisanskriti (India)',
        'sc' => 'Kisardinia',
        'sc_IT' => 'Kisardinia (Italia)',
        'sd' => 'Kisindhi',
        'sd_Arab' => 'Kisindhi (Kiarabu)',
        'sd_Arab_PK' => 'Kisindhi (Kiarabu, Pakistani)',
        'sd_Deva' => 'Kisindhi (Kidevanagari)',
        'sd_Deva_IN' => 'Kisindhi (Kidevanagari, India)',
        'sd_IN' => 'Kisindhi (India)',
        'sd_PK' => 'Kisindhi (Pakistani)',
        'se' => 'Kisami cha Kaskazini',
        'se_FI' => 'Kisami cha Kaskazini (Ufini)',
        'se_NO' => 'Kisami cha Kaskazini (Norway)',
        'se_SE' => 'Kisami cha Kaskazini (Uswidi)',
        'sg' => 'Kisango',
        'sg_CF' => 'Kisango (Jamhuri ya Afrika ya Kati)',
        'sh' => 'Kiserbia-kroeshia',
        'sh_BA' => 'Kiserbia-kroeshia (Bosnia na Hezegovina)',
        'si' => 'Kisinhala',
        'si_LK' => 'Kisinhala (Sri Lanka)',
        'sk' => 'Kislovakia',
        'sk_SK' => 'Kislovakia (Slovakia)',
        'sl' => 'Kislovenia',
        'sl_SI' => 'Kislovenia (Slovenia)',
        'sn' => 'Kishona',
        'sn_ZW' => 'Kishona (Zimbabwe)',
        'so' => 'Kisomali',
        'so_DJ' => 'Kisomali (Jibuti)',
        'so_ET' => 'Kisomali (Ethiopia)',
        'so_KE' => 'Kisomali (Kenya)',
        'so_SO' => 'Kisomali (Somalia)',
        'sq' => 'Kialbania',
        'sq_AL' => 'Kialbania (Albania)',
        'sq_MK' => 'Kialbania (Masedonia ya Kaskazini)',
        'sr' => 'Kiserbia',
        'sr_BA' => 'Kiserbia (Bosnia na Hezegovina)',
        'sr_Cyrl' => 'Kiserbia (Kisiriliki)',
        'sr_Cyrl_BA' => 'Kiserbia (Kisiriliki, Bosnia na Hezegovina)',
        'sr_Cyrl_ME' => 'Kiserbia (Kisiriliki, Montenegro)',
        'sr_Cyrl_RS' => 'Kiserbia (Kisiriliki, Serbia)',
        'sr_Latn' => 'Kiserbia (Kilatini)',
        'sr_Latn_BA' => 'Kiserbia (Kilatini, Bosnia na Hezegovina)',
        'sr_Latn_ME' => 'Kiserbia (Kilatini, Montenegro)',
        'sr_Latn_RS' => 'Kiserbia (Kilatini, Serbia)',
        'sr_ME' => 'Kiserbia (Montenegro)',
        'sr_RS' => 'Kiserbia (Serbia)',
        'st' => 'Kisotho',
        'st_LS' => 'Kisotho (Lesoto)',
        'st_ZA' => 'Kisotho (Afrika Kusini)',
        'su' => 'Kisunda',
        'su_ID' => 'Kisunda (Indonesia)',
        'su_Latn' => 'Kisunda (Kilatini)',
        'su_Latn_ID' => 'Kisunda (Kilatini, Indonesia)',
        'sv' => 'Kiswidi',
        'sv_AX' => 'Kiswidi (Visiwa vya Aland)',
        'sv_FI' => 'Kiswidi (Ufini)',
        'sv_SE' => 'Kiswidi (Uswidi)',
        'sw' => 'Kiswahili',
        'sw_CD' => 'Kiswahili (Kongo - Kinshasa)',
        'sw_KE' => 'Kiswahili (Kenya)',
        'sw_TZ' => 'Kiswahili (Tanzania)',
        'sw_UG' => 'Kiswahili (Uganda)',
        'ta' => 'Kitamili',
        'ta_IN' => 'Kitamili (India)',
        'ta_LK' => 'Kitamili (Sri Lanka)',
        'ta_MY' => 'Kitamili (Malesia)',
        'ta_SG' => 'Kitamili (Singapore)',
        'te' => 'Kitelugu',
        'te_IN' => 'Kitelugu (India)',
        'tg' => 'Kitajiki',
        'tg_TJ' => 'Kitajiki (Tajikistani)',
        'th' => 'Kithai',
        'th_TH' => 'Kithai (Tailandi)',
        'ti' => 'Kitigrinya',
        'ti_ER' => 'Kitigrinya (Eritrea)',
        'ti_ET' => 'Kitigrinya (Ethiopia)',
        'tk' => 'Kiturukimeni',
        'tk_TM' => 'Kiturukimeni (Turkmenistan)',
        'tn' => 'Kitswana',
        'tn_BW' => 'Kitswana (Botswana)',
        'tn_ZA' => 'Kitswana (Afrika Kusini)',
        'to' => 'Kitonga',
        'to_TO' => 'Kitonga (Tonga)',
        'tr' => 'Kituruki',
        'tr_CY' => 'Kituruki (Saiprasi)',
        'tr_TR' => 'Kituruki (Uturuki)',
        'tt' => 'Kitatari',
        'tt_RU' => 'Kitatari (Urusi)',
        'ug' => 'Kiuyghur',
        'ug_CN' => 'Kiuyghur (Uchina)',
        'uk' => 'Kiukraini',
        'uk_UA' => 'Kiukraini (Ukraine)',
        'ur' => 'Kiurdu',
        'ur_IN' => 'Kiurdu (India)',
        'ur_PK' => 'Kiurdu (Pakistani)',
        'uz' => 'Kiuzbeki',
        'uz_AF' => 'Kiuzbeki (Afghanistan)',
        'uz_Arab' => 'Kiuzbeki (Kiarabu)',
        'uz_Arab_AF' => 'Kiuzbeki (Kiarabu, Afghanistan)',
        'uz_Cyrl' => 'Kiuzbeki (Kisiriliki)',
        'uz_Cyrl_UZ' => 'Kiuzbeki (Kisiriliki, Uzibekistani)',
        'uz_Latn' => 'Kiuzbeki (Kilatini)',
        'uz_Latn_UZ' => 'Kiuzbeki (Kilatini, Uzibekistani)',
        'uz_UZ' => 'Kiuzbeki (Uzibekistani)',
        'vi' => 'Kivietinamu',
        'vi_VN' => 'Kivietinamu (Vietnamu)',
        'wo' => 'Kiwolofu',
        'wo_SN' => 'Kiwolofu (Senegali)',
        'xh' => 'Kixhosa',
        'xh_ZA' => 'Kixhosa (Afrika Kusini)',
        'yi' => 'Kiyiddi',
        'yi_UA' => 'Kiyiddi (Ukraine)',
        'yo' => 'Kiyoruba',
        'yo_BJ' => 'Kiyoruba (Benin)',
        'yo_NG' => 'Kiyoruba (Nigeria)',
        'za' => 'Kizhuang',
        'za_CN' => 'Kizhuang (Uchina)',
        'zh' => 'Kichina',
        'zh_CN' => 'Kichina (Uchina)',
        'zh_HK' => 'Kichina (Hong Kong SAR China)',
        'zh_Hans' => 'Kichina (Rahisi)',
        'zh_Hans_CN' => 'Kichina (Rahisi, Uchina)',
        'zh_Hans_HK' => 'Kichina (Rahisi, Hong Kong SAR China)',
        'zh_Hans_MO' => 'Kichina (Rahisi, Makau SAR China)',
        'zh_Hans_MY' => 'Kichina (Rahisi, Malesia)',
        'zh_Hans_SG' => 'Kichina (Rahisi, Singapore)',
        'zh_Hant' => 'Kichina (Cha jadi)',
        'zh_Hant_HK' => 'Kichina (Cha jadi, Hong Kong SAR China)',
        'zh_Hant_MO' => 'Kichina (Cha jadi, Makau SAR China)',
        'zh_Hant_MY' => 'Kichina (Cha jadi, Malesia)',
        'zh_Hant_TW' => 'Kichina (Cha jadi, Taiwan)',
        'zh_MO' => 'Kichina (Makau SAR China)',
        'zh_SG' => 'Kichina (Singapore)',
        'zh_TW' => 'Kichina (Taiwan)',
        'zu' => 'Kizulu',
        'zu_ZA' => 'Kizulu (Afrika Kusini)',
    ],
];
