<?php

declare(strict_types=1);

namespace SimpleSAML\SOAP\Exception;

/**
 * This exception may be raised when a violation of the XML SOAP specification is detected
 *
 * @package simplesamlphp/xml-soap
 */
class ProtocolViolationException extends RuntimeException
{
}
