<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'arabe',
        'Aran' => 'nastaliq',
        'Armi' => 'araméen impérial',
        'Armn' => 'arménien',
        'Avst' => 'avestique',
        'Bali' => 'balinais',
        'Batk' => 'batak',
        'Beng' => 'bengali',
        'Blis' => 'symboles Bliss',
        'Bopo' => 'bopomofo',
        'Brah' => 'brâhmî',
        'Brai' => 'braille',
        'Bugi' => 'bouguis',
        'Buhd' => 'bouhide',
        'Cakm' => 'chakma',
        'Cans' => 'syllabaire autochtone canadien unifié',
        'Cari' => 'carien',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Cirt' => 'cirth',
        'Copt' => 'copte',
        'Cprt' => 'syllabaire chypriote',
        'Cyrl' => 'cyrillique',
        'Cyrs' => 'cyrillique (variante slavonne)',
        'Deva' => 'dévanagari',
        'Dsrt' => 'déséret',
        'Egyd' => 'démotique égyptien',
        'Egyh' => 'hiératique égyptien',
        'Egyp' => 'hiéroglyphes égyptiens',
        'Elym' => 'élymaïque',
        'Ethi' => 'éthiopique',
        'Geok' => 'géorgien khoutsouri',
        'Geor' => 'géorgien',
        'Glag' => 'glagolitique',
        'Goth' => 'gotique',
        'Grek' => 'grec',
        'Gujr' => 'goudjarâtî',
        'Guru' => 'gourmoukhî',
        'Hanb' => 'han avec bopomofo',
        'Hang' => 'hangûl',
        'Hani' => 'sinogrammes',
        'Hano' => 'hanounóo',
        'Hans' => 'simplifié',
        'Hant' => 'traditionnel',
        'Hebr' => 'hébreu',
        'Hira' => 'hiragana',
        'Hmng' => 'pahawh hmong',
        'Hmnp' => 'nyiakeng puachue hmong',
        'Hrkt' => 'katakana ou hiragana',
        'Hung' => 'ancien hongrois',
        'Inds' => 'indus',
        'Ital' => 'ancien italique',
        'Jamo' => 'jamo',
        'Java' => 'javanais',
        'Jpan' => 'japonais',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharochthî',
        'Khmr' => 'khmer',
        'Knda' => 'kannara',
        'Kore' => 'coréen',
        'Kthi' => 'kaithî',
        'Lana' => 'lanna',
        'Laoo' => 'lao',
        'Latf' => 'latin (variante brisée)',
        'Latg' => 'latin (variante gaélique)',
        'Latn' => 'latin',
        'Lepc' => 'lepcha',
        'Limb' => 'limbou',
        'Lina' => 'linéaire A',
        'Linb' => 'linéaire B',
        'Lyci' => 'lycien',
        'Lydi' => 'lydien',
        'Mand' => 'mandéen',
        'Mani' => 'manichéen',
        'Maya' => 'hiéroglyphes mayas',
        'Mero' => 'méroïtique',
        'Mlym' => 'malayalam',
        'Mong' => 'mongol',
        'Moon' => 'moon',
        'Mtei' => 'meitei mayek',
        'Mymr' => 'birman',
        'Nand' => 'nandinagari',
        'Nkoo' => 'n’ko',
        'Ogam' => 'ogam',
        'Olck' => 'ol-chiki',
        'Orkh' => 'orkhon',
        'Orya' => 'odia',
        'Osma' => 'osmanais',
        'Perm' => 'ancien permien',
        'Phag' => 'phags pa',
        'Phli' => 'pehlevi des inscriptions',
        'Phlp' => 'pehlevi des psautiers',
        'Phlv' => 'pehlevi des livres',
        'Phnx' => 'phénicien',
        'Plrd' => 'phonétique de Pollard',
        'Prti' => 'parthe des inscriptions',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'runique',
        'Samr' => 'samaritain',
        'Sara' => 'sarati',
        'Saur' => 'saurashtra',
        'Sgnw' => 'écriture des signes',
        'Shaw' => 'shavien',
        'Sinh' => 'cingalais',
        'Sund' => 'sundanais',
        'Sylo' => 'sylotî nâgrî',
        'Syrc' => 'syriaque',
        'Syre' => 'syriaque estranghélo',
        'Syrj' => 'syriaque occidental',
        'Syrn' => 'syriaque oriental',
        'Tagb' => 'tagbanoua',
        'Tale' => 'taï-le',
        'Talu' => 'nouveau taï-lue',
        'Taml' => 'tamoul',
        'Tavt' => 'taï viêt',
        'Telu' => 'télougou',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagal',
        'Thaa' => 'thâna',
        'Thai' => 'thaï',
        'Tibt' => 'tibétain',
        'Ugar' => 'ougaritique',
        'Vaii' => 'vaï',
        'Visp' => 'parole visible',
        'Wcho' => 'wantcho',
        'Xpeo' => 'cunéiforme persépolitain',
        'Xsux' => 'cunéiforme suméro-akkadien',
        'Yiii' => 'yi',
        'Zinh' => 'hérité',
        'Zmth' => 'notation mathématique',
        'Zsye' => 'emoji',
        'Zsym' => 'symboles',
        'Zxxx' => 'non écrit',
        'Zyyy' => 'commun',
    ],
];
