<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'temp dal meridian da Greenwich (Abidjan)',
        'Africa/Accra' => 'temp dal meridian da Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'temp da l’Africa Orientala (Addis Abeba)',
        'Africa/Algiers' => 'temp da l’Europa Centrala (Algier)',
        'Africa/Asmera' => 'temp da l’Africa Orientala (Asmara)',
        'Africa/Asmara' => 'temp da l’Africa Orientala (Asmara)',
        'Africa/Bamako' => 'temp dal meridian da Greenwich (Bamako)',
        'Africa/Bangui' => 'temp da l’Africa Occidentala (Bangui)',
        'Africa/Banjul' => 'temp dal meridian da Greenwich (Banjul)',
        'Africa/Bissau' => 'temp dal meridian da Greenwich (Bissau)',
        'Africa/Blantyre' => 'temp da l’Africa Centrala (Blantyre)',
        'Africa/Brazzaville' => 'temp da l’Africa Occidentala (Brazzaville)',
        'Africa/Bujumbura' => 'temp da l’Africa Centrala (Bujumbura)',
        'Africa/Cairo' => 'temp da l’Europa Orientala (Cairo)',
        'Africa/Casablanca' => 'temp da l’Europa dal Vest (Casablanca)',
        'Africa/Ceuta' => 'temp da l’Europa Centrala (Ceuta)',
        'Africa/Conakry' => 'temp dal meridian da Greenwich (Conakry)',
        'Africa/Dakar' => 'temp dal meridian da Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'temp da l’Africa Orientala (Daressalam)',
        'Africa/Djibouti' => 'temp da l’Africa Orientala (Dschibuti)',
        'Africa/Douala' => 'temp da l’Africa Occidentala (Douala)',
        'Africa/El_Aaiun' => 'temp da l’Europa dal Vest (El Aaiún)',
        'Africa/Freetown' => 'temp dal meridian da Greenwich (Freetown)',
        'Africa/Gaborone' => 'temp da l’Africa Centrala (Gaborone)',
        'Africa/Harare' => 'temp da l’Africa Centrala (Harare)',
        'Africa/Johannesburg' => 'temp normal da l’Africa Meridiunala (Johannesburg)',
        'Africa/Juba' => 'temp da l’Africa Centrala (Juba)',
        'Africa/Kampala' => 'temp da l’Africa Orientala (Kampala)',
        'Africa/Khartoum' => 'temp da l’Africa Centrala (Khartum)',
        'Africa/Kigali' => 'temp da l’Africa Centrala (Kigali)',
        'Africa/Kinshasa' => 'temp da l’Africa Occidentala (Kinshasa)',
        'Africa/Lagos' => 'temp da l’Africa Occidentala (Lagos)',
        'Africa/Libreville' => 'temp da l’Africa Occidentala (Libreville)',
        'Africa/Lome' => 'temp dal meridian da Greenwich (Lomé)',
        'Africa/Luanda' => 'temp da l’Africa Occidentala (Luanda)',
        'Africa/Lubumbashi' => 'temp da l’Africa Centrala (Lubumbashi)',
        'Africa/Lusaka' => 'temp da l’Africa Centrala (Lusaka)',
        'Africa/Malabo' => 'temp da l’Africa Occidentala (Malabo)',
        'Africa/Maputo' => 'temp da l’Africa Centrala (Maputo)',
        'Africa/Maseru' => 'temp normal da l’Africa Meridiunala (Maseru)',
        'Africa/Mbabane' => 'temp normal da l’Africa Meridiunala (Mbabane)',
        'Africa/Mogadishu' => 'temp da l’Africa Orientala (Mogadischu)',
        'Africa/Monrovia' => 'temp dal meridian da Greenwich (Monrovia)',
        'Africa/Nairobi' => 'temp da l’Africa Orientala (Nairobi)',
        'Africa/Ndjamena' => 'temp da l’Africa Occidentala (N’Djamena)',
        'Africa/Niamey' => 'temp da l’Africa Occidentala (Niamey)',
        'Africa/Nouakchott' => 'temp dal meridian da Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'temp dal meridian da Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'temp da l’Africa Occidentala (Porto-Novo)',
        'Africa/Sao_Tome' => 'temp dal meridian da Greenwich (São Tomé)',
        'Africa/Tripoli' => 'temp da l’Europa Orientala (Tripolis)',
        'Africa/Tunis' => 'temp da l’Europa Centrala (Tunis)',
        'Africa/Windhoek' => 'temp da l’Africa Centrala (Windhoek)',
        'America/Adak' => 'temp dal Hawai e las Aleutinas (Adak)',
        'America/Anchorage' => 'temp da l’Alasca (Anchorage)',
        'America/Anguilla' => 'temp da l’Atlantic USA (Anguilla)',
        'America/Antigua' => 'temp da l’Atlantic USA (Antigua)',
        'America/Araguaina' => 'temp da la Brasilia (Araguaína)',
        'America/Argentina/La_Rioja' => 'temp da l’Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'temp da l’Argentina (Río Gallegos)',
        'America/Argentina/Salta' => 'temp da l’Argentina (Salta)',
        'America/Argentina/San_Juan' => 'temp da l’Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'temp da l’Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'temp da l’Argentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'temp da l’Argentina (Ushuaia)',
        'America/Aruba' => 'temp da l’Atlantic USA (Aruba)',
        'America/Asuncion' => 'temp dal Paraguai (Asunción)',
        'America/Bahia' => 'temp da la Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'temp dal center USA (Bahía de Banderas)',
        'America/Barbados' => 'temp da l’Atlantic USA (Barbados)',
        'America/Belem' => 'temp da la Brasilia (Belém)',
        'America/Belize' => 'temp dal center USA (Belize)',
        'America/Blanc-Sablon' => 'temp da l’Atlantic USA (Blanc-Sablon)',
        'America/Boa_Vista' => 'temp da l’Amazonas (Boa Vista)',
        'America/Bogota' => 'temp da la Columbia (Bogotá)',
        'America/Boise' => 'temp dals Rocky Mountains (Boise)',
        'America/Buenos_Aires' => 'temp da l’Argentina (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'temp da l’Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'temp dals Rocky Mountains (Cambridge Bay)',
        'America/Campo_Grande' => 'temp da l’Amazonas (Campo Grande)',
        'America/Cancun' => 'temp da l’ost USA (Cancún)',
        'America/Caracas' => 'temp da la Venezuela (Caracas)',
        'America/Catamarca' => 'temp da l’Argentina (Catamarca)',
        'America/Argentina/Catamarca' => 'temp da l’Argentina (Catamarca)',
        'America/Cayenne' => 'temp da la Guyana Franzosa (Cayenne)',
        'America/Cayman' => 'temp da l’ost USA (Inslas Cayman)',
        'America/Chicago' => 'temp dal center USA (Chicago)',
        'America/Chihuahua' => 'temp dal center USA (Chihuahua)',
        'America/Ciudad_Juarez' => 'temp dals Rocky Mountains (Ciudad Juárez)',
        'America/Coral_Harbour' => 'temp da l’ost USA (Atikokan)',
        'America/Atikokan' => 'temp da l’ost USA (Atikokan)',
        'America/Cordoba' => 'temp da l’Argentina (Córdoba)',
        'America/Argentina/Cordoba' => 'temp da l’Argentina (Córdoba)',
        'America/Costa_Rica' => 'temp dal center USA (Costa Rica)',
        'America/Coyhaique' => 'temp dal Chile (Coyhaique)',
        'America/Creston' => 'temp dals Rocky Mountains (Creston)',
        'America/Cuiaba' => 'temp da l’Amazonas (Cuiabá)',
        'America/Curacao' => 'temp da l’Atlantic USA (Curaçao)',
        'America/Danmarkshavn' => 'temp dal meridian da Greenwich (Danmarkshavn)',
        'America/Dawson' => 'temp dal Yukon (Dawson)',
        'America/Dawson_Creek' => 'temp dals Rocky Mountains (Dawson Creek)',
        'America/Denver' => 'temp dals Rocky Mountains (Denver)',
        'America/Detroit' => 'temp da l’ost USA (Detroit)',
        'America/Dominica' => 'temp da l’Atlantic USA (Dominica)',
        'America/Edmonton' => 'temp dals Rocky Mountains (Edmonton)',
        'America/Eirunepe' => 'Brasilia (temp local) (Eirunepé)',
        'America/El_Salvador' => 'temp dal center USA (El Salvador)',
        'America/Fort_Nelson' => 'temp dals Rocky Mountains (Fort Nelson)',
        'America/Fortaleza' => 'temp da la Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'temp da l’Atlantic USA (Glace Bay)',
        'America/Godthab' => 'Grönlanda (temp local) (Nuuk)',
        'America/Nuuk' => 'Grönlanda (temp local) (Nuuk)',
        'America/Goose_Bay' => 'temp da l’Atlantic USA (Goose Bay)',
        'America/Grand_Turk' => 'temp da l’ost USA (Grand Turk)',
        'America/Grenada' => 'temp da l’Atlantic USA (Grenada)',
        'America/Guadeloupe' => 'temp da l’Atlantic USA (Guadalupa)',
        'America/Guatemala' => 'temp dal center USA (Guatemala)',
        'America/Guayaquil' => 'temp da l’Ecuador (Guayaquil)',
        'America/Guyana' => 'temp da la Guyana',
        'America/Halifax' => 'temp da l’Atlantic USA (Halifax)',
        'America/Havana' => 'temp da la Cuba (Havanna)',
        'America/Hermosillo' => 'temp mexican dal Pacific (Hermosillo)',
        'America/Indiana/Knox' => 'temp dal center USA (Knox, Indiana)',
        'America/Indiana/Marengo' => 'temp da l’ost USA (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'temp da l’ost USA (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'temp dal center USA (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'temp da l’ost USA (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'temp da l’ost USA (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'temp da l’ost USA (Winamac, Indiana)',
        'America/Indianapolis' => 'temp da l’ost USA (Indianapolis)',
        'America/Indiana/Indianapolis' => 'temp da l’ost USA (Indianapolis)',
        'America/Inuvik' => 'temp dals Rocky Mountains (Inuvik)',
        'America/Iqaluit' => 'temp da l’ost USA (Iqaluit)',
        'America/Jamaica' => 'temp da l’ost USA (Giamaica)',
        'America/Jujuy' => 'temp da l’Argentina (Jujuy)',
        'America/Argentina/Jujuy' => 'temp da l’Argentina (Jujuy)',
        'America/Juneau' => 'temp da l’Alasca (Juneau)',
        'America/Kentucky/Monticello' => 'temp da l’ost USA (Monticello, Kentucky)',
        'America/Kralendijk' => 'temp da l’Atlantic USA (Kralendijk)',
        'America/La_Paz' => 'temp da la Bolivia (La Paz)',
        'America/Lima' => 'temp dal Peru (Lima)',
        'America/Los_Angeles' => 'temp dal Pacific USA (Los Angeles)',
        'America/Louisville' => 'temp da l’ost USA (Louisville)',
        'America/Kentucky/Louisville' => 'temp da l’ost USA (Louisville)',
        'America/Lower_Princes' => 'temp da l’Atlantic USA (Lower Prince’s Quarter)',
        'America/Maceio' => 'temp da la Brasilia (Maceió)',
        'America/Managua' => 'temp dal center USA (Managua)',
        'America/Manaus' => 'temp da l’Amazonas (Manaus)',
        'America/Marigot' => 'temp da l’Atlantic USA (Marigot)',
        'America/Martinique' => 'temp da l’Atlantic USA (Martinica)',
        'America/Matamoros' => 'temp dal center USA (Matamoros)',
        'America/Mazatlan' => 'temp mexican dal Pacific (Mazatlán)',
        'America/Mendoza' => 'temp da l’Argentina (Mendoza)',
        'America/Argentina/Mendoza' => 'temp da l’Argentina (Mendoza)',
        'America/Menominee' => 'temp dal center USA (Menominee)',
        'America/Merida' => 'temp dal center USA (Mérida)',
        'America/Metlakatla' => 'temp da l’Alasca (Metlakatla)',
        'America/Mexico_City' => 'temp dal center USA (Citad dal Mexico)',
        'America/Miquelon' => 'temp da Saint Pierre e Miquelon',
        'America/Moncton' => 'temp da l’Atlantic USA (Moncton)',
        'America/Monterrey' => 'temp dal center USA (Monterrey)',
        'America/Montevideo' => 'temp da l’Uruguai (Montevideo)',
        'America/Montserrat' => 'temp da l’Atlantic USA (Montserrat)',
        'America/Nassau' => 'temp da l’ost USA (Nassau)',
        'America/New_York' => 'temp da l’ost USA (New York)',
        'America/Nome' => 'temp da l’Alasca (Nome)',
        'America/Noronha' => 'temp da Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'temp dal center USA (Beulah, Dakota dal Nord)',
        'America/North_Dakota/Center' => 'temp dal center USA (Center, Dakota dal Nord)',
        'America/North_Dakota/New_Salem' => 'temp dal center USA (New Salem, Dakota dal Nord)',
        'America/Ojinaga' => 'temp dal center USA (Ojinaga)',
        'America/Panama' => 'temp da l’ost USA (Panama)',
        'America/Paramaribo' => 'temp dal Surinam (Paramaribo)',
        'America/Phoenix' => 'temp dals Rocky Mountains (Phoenix)',
        'America/Port-au-Prince' => 'temp da l’ost USA (Port-au-Prince)',
        'America/Port_of_Spain' => 'temp da l’Atlantic USA (Port of Spain)',
        'America/Porto_Velho' => 'temp da l’Amazonas (Porto Velho)',
        'America/Puerto_Rico' => 'temp da l’Atlantic USA (Puerto Rico)',
        'America/Punta_Arenas' => 'temp dal Chile (Punta Arenas)',
        'America/Rankin_Inlet' => 'temp dal center USA (Rankin Inlet)',
        'America/Recife' => 'temp da la Brasilia (Recife)',
        'America/Regina' => 'temp dal center USA (Regina)',
        'America/Resolute' => 'temp dal center USA (Resolute)',
        'America/Rio_Branco' => 'Brasilia (temp local) (Rio Branco)',
        'America/Santarem' => 'temp da la Brasilia (Santarém)',
        'America/Santiago' => 'temp dal Chile (Santiago)',
        'America/Santo_Domingo' => 'temp da l’Atlantic USA (Santo Domingo)',
        'America/Sao_Paulo' => 'temp da la Brasilia (São Paulo)',
        'America/Scoresbysund' => 'Grönlanda (temp local) (Ittoqqortoormiit)',
        'America/Sitka' => 'temp da l’Alasca (Sitka)',
        'America/St_Barthelemy' => 'temp da l’Atlantic USA (Son Barthélemy)',
        'America/St_Johns' => 'temp da la Terranova (St. John’s)',
        'America/St_Kitts' => 'temp da l’Atlantic USA (Saint Kitts)',
        'America/St_Lucia' => 'temp da l’Atlantic USA (Sontga Lucia)',
        'America/St_Thomas' => 'temp da l’Atlantic USA (Saint Thomas)',
        'America/St_Vincent' => 'temp da l’Atlantic USA (Son Vincenz)',
        'America/Swift_Current' => 'temp dal center USA (Swift Current)',
        'America/Tegucigalpa' => 'temp dal center USA (Tegucigalpa)',
        'America/Thule' => 'temp da l’Atlantic USA (Thule)',
        'America/Tijuana' => 'temp dal Pacific USA (Tijuana)',
        'America/Toronto' => 'temp da l’ost USA (Toronto)',
        'America/Tortola' => 'temp da l’Atlantic USA (Tortola)',
        'America/Vancouver' => 'temp dal Pacific USA (Vancouver)',
        'America/Whitehorse' => 'temp dal Yukon (Whitehorse)',
        'America/Winnipeg' => 'temp dal center USA (Winnipeg)',
        'America/Yakutat' => 'temp da l’Alasca (Yakutat)',
        'Antarctica/Casey' => 'temp dal vest da l’Australia (Casey)',
        'Antarctica/Davis' => 'temp da Davis',
        'Antarctica/DumontDUrville' => 'temp da Dumont d’Urville',
        'Antarctica/Macquarie' => 'temp da l’ost da l’Australia (Macquarie)',
        'Antarctica/Mawson' => 'temp da Mawson',
        'Antarctica/McMurdo' => 'temp da la Nova Zelanda (McMurdo)',
        'Antarctica/Palmer' => 'temp dal Chile (Palmer)',
        'Antarctica/Rothera' => 'temp da Rothera',
        'Antarctica/Syowa' => 'temp da Shōwa (Showa)',
        'Antarctica/Troll' => 'temp dal meridian da Greenwich (Troll)',
        'Antarctica/Vostok' => 'temp da Vostok',
        'Arctic/Longyearbyen' => 'temp da l’Europa Centrala (Longyearbyen)',
        'Asia/Aden' => 'temp arab (Aden)',
        'Asia/Almaty' => 'temp dal Kasachstan (Almaty)',
        'Asia/Amman' => 'temp da l’Europa Orientala (Amman)',
        'Asia/Anadyr' => 'Russia (temp local) (Anadyr)',
        'Asia/Aqtau' => 'temp dal Kasachstan (Aqtau)',
        'Asia/Aqtobe' => 'temp dal Kasachstan (Aqtobe)',
        'Asia/Ashgabat' => 'temp dal Turkmenistan (Aşgabat)',
        'Asia/Atyrau' => 'temp dal Kasachstan (Atyrau)',
        'Asia/Baghdad' => 'temp arab (Bagdad)',
        'Asia/Bahrain' => 'temp arab (Bahrain)',
        'Asia/Baku' => 'temp da l’Aserbaidschan (Baku)',
        'Asia/Bangkok' => 'temp da l’Indochina (Bangkok)',
        'Asia/Barnaul' => 'temp da Krasnojarsk (Barnaul)',
        'Asia/Beirut' => 'temp da l’Europa Orientala (Beirut)',
        'Asia/Bishkek' => 'temp dal Kirghistan (Bischkek)',
        'Asia/Brunei' => 'temp dal Brunei',
        'Asia/Calcutta' => 'temp normal da l’India (Calcutta)',
        'Asia/Kolkata' => 'temp normal da l’India (Calcutta)',
        'Asia/Chita' => 'temp da Jakutsk (Tschita)',
        'Asia/Colombo' => 'temp normal da l’India (Colombo)',
        'Asia/Damascus' => 'temp da l’Europa Orientala (Damascus)',
        'Asia/Dhaka' => 'temp dal Bangladesch (Dhaka)',
        'Asia/Dili' => 'temp dal Timor da l’Ost (Dili)',
        'Asia/Dubai' => 'temp normal dal Golf (Dubai)',
        'Asia/Dushanbe' => 'temp dal Tadschikistan (Duschanbe)',
        'Asia/Famagusta' => 'temp da l’Europa Orientala (Famagusta)',
        'Asia/Gaza' => 'temp da l’Europa Orientala (Gaza)',
        'Asia/Hebron' => 'temp da l’Europa Orientala (Hebron)',
        'Asia/Hong_Kong' => 'temp dal Hongkong',
        'Asia/Hovd' => 'temp da Hovd (Khovd)',
        'Asia/Irkutsk' => 'temp dad Irkutsk',
        'Asia/Jakarta' => 'temp dal vest da l’Indonesia (Jakarta)',
        'Asia/Jayapura' => 'temp da l’ost da l’Indonesia (Jayapura)',
        'Asia/Jerusalem' => 'temp da l’Israel (Jerusalem)',
        'Asia/Kabul' => 'temp da l’Afganistan (Kabul)',
        'Asia/Kamchatka' => 'Russia (temp local) (Kamtschatka)',
        'Asia/Karachi' => 'temp dal Pakistan (Karatschi)',
        'Asia/Katmandu' => 'temp dal Nepal (Kathmandu)',
        'Asia/Kathmandu' => 'temp dal Nepal (Kathmandu)',
        'Asia/Khandyga' => 'temp da Jakutsk (Chandyga)',
        'Asia/Krasnoyarsk' => 'temp da Krasnojarsk',
        'Asia/Kuala_Lumpur' => 'temp da la Malaisia (Kuala Lumpur)',
        'Asia/Kuching' => 'temp da la Malaisia (Kuching)',
        'Asia/Kuwait' => 'temp arab (Kuwait)',
        'Asia/Macau' => 'temp da la China (Macao)',
        'Asia/Magadan' => 'temp da Magadan',
        'Asia/Makassar' => 'temp dal center da l’Indonesia (Makassar)',
        'Asia/Manila' => 'temp da las Filippinas (Manila)',
        'Asia/Muscat' => 'temp normal dal Golf (Mascat)',
        'Asia/Nicosia' => 'temp da l’Europa Orientala (Nicosia)',
        'Asia/Novokuznetsk' => 'temp da Krasnojarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'temp da Krasnojarsk (Novosibirsk)',
        'Asia/Omsk' => 'temp dad Omsk',
        'Asia/Oral' => 'temp dal Kasachstan (Oral)',
        'Asia/Phnom_Penh' => 'temp da l’Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'temp dal vest da l’Indonesia (Pontianak)',
        'Asia/Pyongyang' => 'temp da la Corea (Pjöngjang)',
        'Asia/Qatar' => 'temp arab (Qatar)',
        'Asia/Qostanay' => 'temp dal Kasachstan (Qostanai)',
        'Asia/Qyzylorda' => 'temp dal Kasachstan (Qysylorda)',
        'Asia/Rangoon' => 'temp dal Myanmar (Yangon)',
        'Asia/Yangon' => 'temp dal Myanmar (Yangon)',
        'Asia/Riyadh' => 'temp arab (Riad)',
        'Asia/Saigon' => 'temp da l’Indochina (Citad da Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'temp da l’Indochina (Citad da Ho Chi Minh)',
        'Asia/Sakhalin' => 'temp da Magadan (Sachalin)',
        'Asia/Samarkand' => 'temp da l’Usbekistan (Samarcanda)',
        'Asia/Seoul' => 'temp da la Corea (Seoul)',
        'Asia/Shanghai' => 'temp da la China (Schanghai)',
        'Asia/Singapore' => 'temp normal dal Singapur',
        'Asia/Srednekolymsk' => 'temp da Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'temp dal Taiwan (Taipei)',
        'Asia/Tashkent' => 'temp da l’Usbekistan (Taschkent)',
        'Asia/Tbilisi' => 'temp da la Georgia (Tiflis)',
        'Asia/Tehran' => 'temp da l’Iran (Teheran)',
        'Asia/Thimphu' => 'temp dal Butan (Thimphu)',
        'Asia/Tokyo' => 'temp dal Giapun (Tokio)',
        'Asia/Tomsk' => 'temp da Krasnojarsk (Tomsk)',
        'Asia/Ulaanbaatar' => 'temp dad Ulaanbaatar',
        'Asia/Urumqi' => 'China (temp local) (Ürümqi)',
        'Asia/Ust-Nera' => 'temp da Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'temp da l’Indochina (Vientiane)',
        'Asia/Vladivostok' => 'temp da Vladivostok',
        'Asia/Yakutsk' => 'temp da Jakutsk',
        'Asia/Yekaterinburg' => 'temp da Jekaterinburg',
        'Asia/Yerevan' => 'temp da l’Armenia (Jerevan)',
        'Atlantic/Azores' => 'temp da las Azoras',
        'Atlantic/Bermuda' => 'temp da l’Atlantic USA (Bermudas)',
        'Atlantic/Canary' => 'temp da l’Europa dal Vest (Inslas Canarias)',
        'Atlantic/Cape_Verde' => 'temp dal Cap Verd',
        'Atlantic/Faeroe' => 'temp da l’Europa dal Vest (Inslas Feroe)',
        'Atlantic/Faroe' => 'temp da l’Europa dal Vest (Inslas Feroe)',
        'Atlantic/Madeira' => 'temp da l’Europa dal Vest (Madeira)',
        'Atlantic/Reykjavik' => 'temp dal meridian da Greenwich (Reykjavík)',
        'Atlantic/South_Georgia' => 'temp da la Georgia dal Sid',
        'Atlantic/St_Helena' => 'temp dal meridian da Greenwich (Sontg’elena)',
        'Atlantic/Stanley' => 'temp da las Inslas Falkland (Stanley)',
        'Australia/Adelaide' => 'temp dal center da l’Australia (Adelaide)',
        'Australia/Brisbane' => 'temp da l’ost da l’Australia (Brisbane)',
        'Australia/Broken_Hill' => 'temp dal center da l’Australia (Broken Hill)',
        'Australia/Darwin' => 'temp dal center da l’Australia (Darwin)',
        'Australia/Eucla' => 'temp dal center-vest da l’Australia (Eucla)',
        'Australia/Hobart' => 'temp da l’ost da l’Australia (Hobart)',
        'Australia/Lindeman' => 'temp da l’ost da l’Australia (Lindeman)',
        'Australia/Lord_Howe' => 'temp da Lord Howe',
        'Australia/Melbourne' => 'temp da l’ost da l’Australia (Melbourne)',
        'Australia/Perth' => 'temp dal vest da l’Australia (Perth)',
        'Australia/Sydney' => 'temp da l’ost da l’Australia (Sydney)',
        'Etc/GMT' => 'temp dal meridian da Greenwich',
        'Etc/UTC' => 'temp universal coordinà',
        'Europe/Amsterdam' => 'temp da l’Europa Centrala (Amsterdam)',
        'Europe/Andorra' => 'temp da l’Europa Centrala (Andorra)',
        'Europe/Astrakhan' => 'Russia (temp local) (Astrachan)',
        'Europe/Athens' => 'temp da l’Europa Orientala (Athen)',
        'Europe/Belgrade' => 'temp da l’Europa Centrala (Belgrad)',
        'Europe/Berlin' => 'temp da l’Europa Centrala (Berlin)',
        'Europe/Bratislava' => 'temp da l’Europa Centrala (Bratislava)',
        'Europe/Brussels' => 'temp da l’Europa Centrala (Brüssel)',
        'Europe/Bucharest' => 'temp da l’Europa Orientala (Bucarest)',
        'Europe/Budapest' => 'temp da l’Europa Centrala (Budapest)',
        'Europe/Busingen' => 'temp da l’Europa Centrala (Büsingen)',
        'Europe/Chisinau' => 'temp da l’Europa Orientala (Chișinău)',
        'Europe/Copenhagen' => 'temp da l’Europa Centrala (Copenhagen)',
        'Europe/Dublin' => 'temp dal meridian da Greenwich (Dublin)',
        'Europe/Gibraltar' => 'temp da l’Europa Centrala (Gibraltar)',
        'Europe/Guernsey' => 'temp dal meridian da Greenwich (Guernsey)',
        'Europe/Helsinki' => 'temp da l’Europa Orientala (Helsinki)',
        'Europe/Isle_of_Man' => 'temp dal meridian da Greenwich (Insla da Man)',
        'Europe/Istanbul' => 'Tirchia (temp local) (Istanbul)',
        'Europe/Jersey' => 'temp dal meridian da Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'temp da l’Europa Orientala (Kaliningrad)',
        'Europe/Kiev' => 'temp da l’Europa Orientala (Kiev)',
        'Europe/Kyiv' => 'temp da l’Europa Orientala (Kiev)',
        'Europe/Kirov' => 'temp da Moscau (Kirov)',
        'Europe/Lisbon' => 'temp da l’Europa dal Vest (Lissabon)',
        'Europe/Ljubljana' => 'temp da l’Europa Centrala (Ljubljana)',
        'Europe/London' => 'temp dal meridian da Greenwich (Londra)',
        'Europe/Luxembourg' => 'temp da l’Europa Centrala (Luxemburg)',
        'Europe/Madrid' => 'temp da l’Europa Centrala (Madrid)',
        'Europe/Malta' => 'temp da l’Europa Centrala (Malta)',
        'Europe/Mariehamn' => 'temp da l’Europa Orientala (Mariehamn)',
        'Europe/Minsk' => 'temp da Moscau (Minsk)',
        'Europe/Monaco' => 'temp da l’Europa Centrala (Monaco)',
        'Europe/Moscow' => 'temp da Moscau',
        'Europe/Oslo' => 'temp da l’Europa Centrala (Oslo)',
        'Europe/Paris' => 'temp da l’Europa Centrala (Paris)',
        'Europe/Podgorica' => 'temp da l’Europa Centrala (Podgorica)',
        'Europe/Prague' => 'temp da l’Europa Centrala (Prag)',
        'Europe/Riga' => 'temp da l’Europa Orientala (Riga)',
        'Europe/Rome' => 'temp da l’Europa Centrala (Roma)',
        'Europe/Samara' => 'Russia (temp local) (Samara)',
        'Europe/San_Marino' => 'temp da l’Europa Centrala (San Marino)',
        'Europe/Sarajevo' => 'temp da l’Europa Centrala (Sarajevo)',
        'Europe/Saratov' => 'Russia (temp local) (Saratov)',
        'Europe/Simferopol' => 'temp da Moscau (Simferopol)',
        'Europe/Skopje' => 'temp da l’Europa Centrala (Skopje)',
        'Europe/Sofia' => 'temp da l’Europa Orientala (Sofia)',
        'Europe/Stockholm' => 'temp da l’Europa Centrala (Stockholm)',
        'Europe/Tallinn' => 'temp da l’Europa Orientala (Tallinn)',
        'Europe/Tirane' => 'temp da l’Europa Centrala (Tirana)',
        'Europe/Ulyanovsk' => 'Russia (temp local) (Ulyanovsk)',
        'Europe/Vaduz' => 'temp da l’Europa Centrala (Vaduz)',
        'Europe/Vatican' => 'temp da l’Europa Centrala (Vatican)',
        'Europe/Vienna' => 'temp da l’Europa Centrala (Vienna)',
        'Europe/Vilnius' => 'temp da l’Europa Orientala (Vilnius)',
        'Europe/Volgograd' => 'temp da Moscau (Volgograd)',
        'Europe/Warsaw' => 'temp da l’Europa Centrala (Varsovia)',
        'Europe/Zagreb' => 'temp da l’Europa Centrala (Zagreb)',
        'Europe/Zurich' => 'temp da l’Europa Centrala (Turitg)',
        'Indian/Antananarivo' => 'temp da l’Africa Orientala (Antananarivo)',
        'Indian/Chagos' => 'temp da l’Ocean Indic (Chagos)',
        'Indian/Christmas' => 'temp da l’Insla da Nadal',
        'Indian/Cocos' => 'temp da las Inslas Cocos',
        'Indian/Comoro' => 'temp da l’Africa Orientala (Comoras)',
        'Indian/Kerguelen' => 'temp dals Territoris Franzos Meridiunals ed Antarctics (Kerguelen)',
        'Indian/Mahe' => 'temp da las Seychellas (Mahé)',
        'Indian/Maldives' => 'temp da las Maledivas',
        'Indian/Mauritius' => 'temp dal Mauritius',
        'Indian/Mayotte' => 'temp da l’Africa Orientala (Mayotte)',
        'Indian/Reunion' => 'temp da la Réunion',
        'Pacific/Apia' => 'temp da la Samoa (Apia)',
        'Pacific/Auckland' => 'temp da la Nova Zelanda (Auckland)',
        'Pacific/Bougainville' => 'temp da la Papua Nova Guinea (Bougainville)',
        'Pacific/Chatham' => 'temp da las Inslas Chatham',
        'Pacific/Easter' => 'temp da l’Insla da Pasca',
        'Pacific/Efate' => 'temp dal Vanuatu (Efate)',
        'Pacific/Enderbury' => 'temp da las Inslas Fenix (Canton)',
        'Pacific/Kanton' => 'temp da las Inslas Fenix (Canton)',
        'Pacific/Fakaofo' => 'temp da Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'temp dal Fidschi',
        'Pacific/Funafuti' => 'temp da las Inslas da Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'temp da las Inslas Galápagos',
        'Pacific/Gambier' => 'temp da las Inslas Gambier',
        'Pacific/Guadalcanal' => 'temp da las Inslas da Salomon (Guadalcanal)',
        'Pacific/Guam' => 'temp dals Chamorro (Guam)',
        'Pacific/Honolulu' => 'temp normal dal Hawai e las Aleutinas (Honolulu)',
        'Pacific/Kiritimati' => 'temp da las Inslas da la Lingia (Kiritimati)',
        'Pacific/Kosrae' => 'temp da Kosrae',
        'Pacific/Kwajalein' => 'temp da las Inslas da Marshall (Kwajalein)',
        'Pacific/Majuro' => 'temp da las Inslas da Marshall (Majuro)',
        'Pacific/Marquesas' => 'temp da las Inslas Marquesas',
        'Pacific/Midway' => 'temp da la Samoa Americana (Midway)',
        'Pacific/Nauru' => 'temp da Nauru',
        'Pacific/Niue' => 'temp da Niue',
        'Pacific/Norfolk' => 'temp da l’Insla Norfolk',
        'Pacific/Noumea' => 'temp da la Nova Caledonia (Nouméa)',
        'Pacific/Pago_Pago' => 'temp da la Samoa Americana (Pago Pago)',
        'Pacific/Palau' => 'temp da Palau',
        'Pacific/Pitcairn' => 'temp da las Inslas Pitcairn',
        'Pacific/Ponape' => 'temp da Pohnpei',
        'Pacific/Pohnpei' => 'temp da Pohnpei',
        'Pacific/Port_Moresby' => 'temp da la Papua Nova Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'temp da las Inslas Cook (Rarotonga)',
        'Pacific/Saipan' => 'temp dals Chamorro (Saipan)',
        'Pacific/Tahiti' => 'temp da Tahiti',
        'Pacific/Tarawa' => 'temp da las Inslas Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'temp da Tonga (Tongatapu)',
        'Pacific/Truk' => 'temp da Chuuk',
        'Pacific/Chuuk' => 'temp da Chuuk',
        'Pacific/Wake' => 'temp da l’Insla Wake',
        'Pacific/Wallis' => 'temp da Wallis e Futuna (Wallis & Futuna)',
    ],
    'Meta' => [],
];
