<?php

return [
    'Names' => [
        'Adlm' => 'አድላም',
        'Arab' => 'ዓረብኛ',
        'Aran' => 'ናስታሊ',
        'Armn' => 'ዓይቡቤን',
        'Beng' => 'ቋንቋ ቤንጋል',
        'Bopo' => 'ቦፖሞፎ',
        'Brai' => 'ብሬል',
        'Cakm' => 'ቻክማ',
        'Cans' => 'ውሁድ ካናዳዊ ኣቦርጅናል ሲላቢክስ',
        'Cher' => 'ቼሪዮክ',
        'Cyrl' => 'ቋንቋ ሲሪል',
        'Deva' => 'ዴቫንጋሪ',
        'Ethi' => 'እትዮጵያዊ',
        'Geor' => 'ናይ ጆርጅያ',
        'Grek' => 'ግሪክ',
        'Gujr' => 'ጉጃርቲ',
        'Guru' => 'ጉርሙኪ',
        'Hanb' => 'ሃን ምስ ቦፖሞፎ',
        'Hang' => 'ሃንጉል',
        'Hani' => 'ሃን',
        'Hans' => 'ዝተቐለለ',
        'Hant' => 'ባህላዊ',
        'Hebr' => 'ኢብራይስጥ',
        'Hira' => 'ሂራጋና',
        'Hrkt' => 'ጃፓናዊ ሲለባሪታት',
        'Jamo' => 'ጃሞ',
        'Jpan' => 'ጃፓናዊ',
        'Kana' => 'ካታካና',
        'Khmr' => 'ክመር',
        'Knda' => 'ካናዳ',
        'Kore' => 'ኮርያዊ',
        'Laoo' => 'ሌኦ',
        'Latn' => 'ላቲን',
        'Mlym' => 'ማላያላም',
        'Mong' => 'ማኦንጎላዊ',
        'Mtei' => 'መይተይ ማየክ',
        'Mymr' => 'ማይንማር',
        'Nkoo' => 'ንኮ',
        'Olck' => 'ኦል ቺኪ',
        'Orya' => 'ኦዲያ',
        'Rohg' => 'ሃኒፊ',
        'Sinh' => 'ሲንሃላ',
        'Sund' => 'ሱንዳናዊ',
        'Syrc' => 'ስይሪክ',
        'Taml' => 'ታሚል',
        'Telu' => 'ቴሉጉ',
        'Tfng' => 'ቲፊንጋ',
        'Thaa' => 'ትሃና',
        'Thai' => 'ታይ',
        'Tibt' => 'ቲቤት',
        'Vaii' => 'ቫይ',
        'Yiii' => 'ዪ',
        'Zmth' => 'ናይ ሒሳብ ምልክት',
        'Zsye' => 'ኢሞጂ',
        'Zsym' => 'ምልክታት',
        'Zxxx' => 'ዘይተጻሕፈ',
        'Zyyy' => 'ልሙድ',
    ],
];
