<?php

return [
    'Names' => [
        'Africa/Abidjan' => '[Μέση ώρα Γκρίνουιτς (Αμπιτζάν)]',
        'Africa/Accra' => '[Μέση ώρα Γκρίνουιτς (Άκρα)]',
        'Africa/Addis_Ababa' => '[Ώρα Ανατολικής Αφρικής (Αντίς Αμπέμπα)]',
        'Africa/Algiers' => '[Ώρα Κεντρικής Ευρώπης (Αλγέρι)]',
        'Africa/Asmera' => '[Ώρα Ανατολικής Αφρικής (Ασμάρα)]',
        'Africa/Asmara' => '[Ώρα Ανατολικής Αφρικής (Ασμάρα)]',
        'Africa/Bamako' => '[Μέση ώρα Γκρίνουιτς (Μπαμάκο)]',
        'Africa/Bangui' => '[Ώρα Δυτικής Αφρικής (Μπανγκί)]',
        'Africa/Banjul' => '[Μέση ώρα Γκρίνουιτς (Μπανζούλ)]',
        'Africa/Bissau' => '[Μέση ώρα Γκρίνουιτς (Μπισάου)]',
        'Africa/Blantyre' => '[Ώρα Κεντρικής Αφρικής (Μπλαντάιρ)]',
        'Africa/Brazzaville' => '[Ώρα Δυτικής Αφρικής (Μπραζαβίλ)]',
        'Africa/Bujumbura' => '[Ώρα Κεντρικής Αφρικής (Μπουζουμπούρα)]',
        'Africa/Cairo' => '[Ώρα Ανατολικής Ευρώπης (Κάιρο)]',
        'Africa/Casablanca' => '[Ώρα Δυτικής Ευρώπης (Καζαμπλάνκα)]',
        'Africa/Ceuta' => '[Ώρα Κεντρικής Ευρώπης (Θέουτα)]',
        'Africa/Conakry' => '[Μέση ώρα Γκρίνουιτς (Κόνακρι)]',
        'Africa/Dakar' => '[Μέση ώρα Γκρίνουιτς (Ντακάρ)]',
        'Africa/Dar_es_Salaam' => '[Ώρα Ανατολικής Αφρικής (Νταρ ες Σαλάμ)]',
        'Africa/Djibouti' => '[Ώρα Ανατολικής Αφρικής (Τζιμπουτί)]',
        'Africa/Douala' => '[Ώρα Δυτικής Αφρικής (Ντουάλα)]',
        'Africa/El_Aaiun' => '[Ώρα Δυτικής Ευρώπης (Ελ Αγιούν)]',
        'Africa/Freetown' => '[Μέση ώρα Γκρίνουιτς (Φρίταουν)]',
        'Africa/Gaborone' => '[Ώρα Κεντρικής Αφρικής (Γκαμπορόνε)]',
        'Africa/Harare' => '[Ώρα Κεντρικής Αφρικής (Χαράρε)]',
        'Africa/Johannesburg' => '[Χειμερινή ώρα Νότιας Αφρικής (Γιοχάνεσμπουργκ)]',
        'Africa/Juba' => '[Ώρα Κεντρικής Αφρικής (Τζούμπα)]',
        'Africa/Kampala' => '[Ώρα Ανατολικής Αφρικής (Καμπάλα)]',
        'Africa/Khartoum' => '[Ώρα Κεντρικής Αφρικής (Χαρτούμ)]',
        'Africa/Kigali' => '[Ώρα Κεντρικής Αφρικής (Κιγκάλι)]',
        'Africa/Kinshasa' => '[Ώρα Δυτικής Αφρικής (Κινσάσα)]',
        'Africa/Lagos' => '[Ώρα Δυτικής Αφρικής (Λάγκος)]',
        'Africa/Libreville' => '[Ώρα Δυτικής Αφρικής (Λιμπρεβίλ)]',
        'Africa/Lome' => '[Μέση ώρα Γκρίνουιτς (Λομέ)]',
        'Africa/Luanda' => '[Ώρα Δυτικής Αφρικής (Λουάντα)]',
        'Africa/Lubumbashi' => '[Ώρα Κεντρικής Αφρικής (Λουμπουμπάσι)]',
        'Africa/Lusaka' => '[Ώρα Κεντρικής Αφρικής (Λουζάκα)]',
        'Africa/Malabo' => '[Ώρα Δυτικής Αφρικής (Μαλάμπο)]',
        'Africa/Maputo' => '[Ώρα Κεντρικής Αφρικής (Μαπούτο)]',
        'Africa/Maseru' => '[Χειμερινή ώρα Νότιας Αφρικής (Μασέρου)]',
        'Africa/Mbabane' => '[Χειμερινή ώρα Νότιας Αφρικής (Μπαμπάνε)]',
        'Africa/Mogadishu' => '[Ώρα Ανατολικής Αφρικής (Μογκαντίσου)]',
        'Africa/Monrovia' => '[Μέση ώρα Γκρίνουιτς (Μονρόβια)]',
        'Africa/Nairobi' => '[Ώρα Ανατολικής Αφρικής (Ναϊρόμπι)]',
        'Africa/Ndjamena' => '[Ώρα Δυτικής Αφρικής (Ντζαμένα)]',
        'Africa/Niamey' => '[Ώρα Δυτικής Αφρικής (Νιαμέι)]',
        'Africa/Nouakchott' => '[Μέση ώρα Γκρίνουιτς (Νουακσότ)]',
        'Africa/Ouagadougou' => '[Μέση ώρα Γκρίνουιτς (Ουαγκαντούγκου)]',
        'Africa/Porto-Novo' => '[Ώρα Δυτικής Αφρικής (Πόρτο-Νόβο)]',
        'Africa/Sao_Tome' => '[Μέση ώρα Γκρίνουιτς (Σάο Τομέ)]',
        'Africa/Tripoli' => '[Ώρα Ανατολικής Ευρώπης (Τρίπολη)]',
        'Africa/Tunis' => '[Ώρα Κεντρικής Ευρώπης (Τύνιδα)]',
        'Africa/Windhoek' => '[Ώρα Κεντρικής Αφρικής (Βίντχουκ)]',
        'America/Adak' => '[Ώρα Χαβάης-Αλεούτιων Νήσων (Άντακ)]',
        'America/Anchorage' => '[Ώρα Αλάσκας (Άνκορατζ)]',
        'America/Anguilla' => '[Ώρα Ατλαντικού (Ανγκουίλα)]',
        'America/Antigua' => '[Ώρα Ατλαντικού (Αντίγκουα)]',
        'America/Araguaina' => '[Ώρα Μπραζίλιας (Αραγκουάινα)]',
        'America/Argentina/La_Rioja' => '[Ώρα Αργεντινής (Λα Ριόχα)]',
        'America/Argentina/Rio_Gallegos' => '[Ώρα Αργεντινής (Ρίο Γκαγιέγκος)]',
        'America/Argentina/Salta' => '[Ώρα Αργεντινής (Σάλτα)]',
        'America/Argentina/San_Juan' => '[Ώρα Αργεντινής (Σαν Χουάν)]',
        'America/Argentina/San_Luis' => '[Ώρα Αργεντινής (Σαν Λούις)]',
        'America/Argentina/Tucuman' => '[Ώρα Αργεντινής (Τουκουμάν)]',
        'America/Argentina/Ushuaia' => '[Ώρα Αργεντινής (Ουσουάια)]',
        'America/Aruba' => '[Ώρα Ατλαντικού (Αρούμπα)]',
        'America/Asuncion' => '[Ώρα Παραγουάης (Ασουνσιόν)]',
        'America/Bahia' => '[Ώρα Μπραζίλιας (Μπαΐα)]',
        'America/Bahia_Banderas' => '[Κεντρική ώρα Βόρειας Αμερικής (Μπαΐα ντε Μπαντέρας)]',
        'America/Barbados' => '[Ώρα Ατλαντικού (Μπαρμπέιντος)]',
        'America/Belem' => '[Ώρα Μπραζίλιας (Μπελέμ)]',
        'America/Belize' => '[Κεντρική ώρα Βόρειας Αμερικής (Μπελίζ)]',
        'America/Blanc-Sablon' => '[Ώρα Ατλαντικού (Μπλαν Σαμπλόν)]',
        'America/Boa_Vista' => '[Ώρα Αμαζονίου (Μπόα Βίστα)]',
        'America/Bogota' => '[Ώρα Κολομβίας (Μπογκοτά)]',
        'America/Boise' => '[Ορεινή ώρα Βόρειας Αμερικής (Μπόιζι)]',
        'America/Buenos_Aires' => '[Ώρα Αργεντινής (Μπουένος Άιρες)]',
        'America/Argentina/Buenos_Aires' => '[Ώρα Αργεντινής (Μπουένος Άιρες)]',
        'America/Cambridge_Bay' => '[Ορεινή ώρα Βόρειας Αμερικής (Κέμπριτζ Μπέι)]',
        'America/Campo_Grande' => '[Ώρα Αμαζονίου (Κάμπο Γκράντε)]',
        'America/Cancun' => '[Ανατολική ώρα Βόρειας Αμερικής (Κανκούν)]',
        'America/Caracas' => '[Ώρα Βενεζουέλας (Καράκας)]',
        'America/Catamarca' => '[Ώρα Αργεντινής (Καταμάρκα)]',
        'America/Argentina/Catamarca' => '[Ώρα Αργεντινής (Καταμάρκα)]',
        'America/Cayenne' => '[Ώρα Γαλλικής Γουιάνας (Καγιέν)]',
        'America/Cayman' => '[Ανατολική ώρα Βόρειας Αμερικής (Κέιμαν)]',
        'America/Chicago' => '[Κεντρική ώρα Βόρειας Αμερικής (Σικάγο)]',
        'America/Chihuahua' => '[Κεντρική ώρα Βόρειας Αμερικής (Τσιουάουα)]',
        'America/Ciudad_Juarez' => '[Ορεινή ώρα Βόρειας Αμερικής (Σιουδάδ Χουάρες)]',
        'America/Coral_Harbour' => '[Ανατολική ώρα Βόρειας Αμερικής (Ατικόκαν)]',
        'America/Atikokan' => '[Ανατολική ώρα Βόρειας Αμερικής (Ατικόκαν)]',
        'America/Cordoba' => '[Ώρα Αργεντινής (Κόρδοβα)]',
        'America/Argentina/Cordoba' => '[Ώρα Αργεντινής (Κόρδοβα)]',
        'America/Costa_Rica' => '[Κεντρική ώρα Βόρειας Αμερικής (Κόστα Ρίκα)]',
        'America/Coyhaique' => '[Ώρα Χιλής (Κοϊάικε)]',
        'America/Creston' => '[Ορεινή ώρα Βόρειας Αμερικής (Κρέστον)]',
        'America/Cuiaba' => '[Ώρα Αμαζονίου (Κουιαμπά)]',
        'America/Curacao' => '[Ώρα Ατλαντικού (Κουρασάο)]',
        'America/Danmarkshavn' => '[Μέση ώρα Γκρίνουιτς (Ντανμαρκσάβν)]',
        'America/Dawson' => '[Ώρα Γιούκον (Ντόσον)]',
        'America/Dawson_Creek' => '[Ορεινή ώρα Βόρειας Αμερικής (Ντόσον Κρικ)]',
        'America/Denver' => '[Ορεινή ώρα Βόρειας Αμερικής (Ντένβερ)]',
        'America/Detroit' => '[Ανατολική ώρα Βόρειας Αμερικής (Ντιτρόιτ)]',
        'America/Dominica' => '[Ώρα Ατλαντικού (Ντομίνικα)]',
        'America/Edmonton' => '[Ορεινή ώρα Βόρειας Αμερικής (Έντμοντον)]',
        'America/Eirunepe' => '[Ώρα Άκρε (Εϊρουνεπέ)]',
        'America/El_Salvador' => '[Κεντρική ώρα Βόρειας Αμερικής (Ελ Σαλβαδόρ)]',
        'America/Fort_Nelson' => '[Ορεινή ώρα Βόρειας Αμερικής (Φορτ Νέλσον)]',
        'America/Fortaleza' => '[Ώρα Μπραζίλιας (Φορταλέζα)]',
        'America/Glace_Bay' => '[Ώρα Ατλαντικού (Γκλέις Μπέι)]',
        'America/Godthab' => '[Ώρα (Γροιλανδία) (Νουούκ)]',
        'America/Nuuk' => '[Ώρα (Γροιλανδία) (Νουούκ)]',
        'America/Goose_Bay' => '[Ώρα Ατλαντικού (Γκους Μπέι)]',
        'America/Grand_Turk' => '[Ανατολική ώρα Βόρειας Αμερικής (Γκραντ Τουρκ)]',
        'America/Grenada' => '[Ώρα Ατλαντικού (Γρενάδα)]',
        'America/Guadeloupe' => '[Ώρα Ατλαντικού (Γουαδελούπη)]',
        'America/Guatemala' => '[Κεντρική ώρα Βόρειας Αμερικής (Γουατεμάλα)]',
        'America/Guayaquil' => '[Ώρα Ισημερινού (Γκουαγιακίλ)]',
        'America/Guyana' => 'Ώρα Γουιάνας',
        'America/Halifax' => '[Ώρα Ατλαντικού (Χάλιφαξ)]',
        'America/Havana' => '[Ώρα Κούβας (Αβάνα)]',
        'America/Hermosillo' => '[Ώρα Ειρηνικού Μεξικού (Ερμοσίγιο)]',
        'America/Indiana/Knox' => '[Κεντρική ώρα Βόρειας Αμερικής (Νοξ, Ιντιάνα)]',
        'America/Indiana/Marengo' => '[Ανατολική ώρα Βόρειας Αμερικής (Μαρένγκο, Ιντιάνα)]',
        'America/Indiana/Petersburg' => '[Ανατολική ώρα Βόρειας Αμερικής (Πίτερσμπεργκ, Ιντιάνα)]',
        'America/Indiana/Tell_City' => '[Κεντρική ώρα Βόρειας Αμερικής (Τελ Σίτι, Ιντιάνα)]',
        'America/Indiana/Vevay' => '[Ανατολική ώρα Βόρειας Αμερικής (Βιβέι, Ιντιάνα)]',
        'America/Indiana/Vincennes' => '[Ανατολική ώρα Βόρειας Αμερικής (Βανσέν, Ιντιάνα)]',
        'America/Indiana/Winamac' => '[Ανατολική ώρα Βόρειας Αμερικής (Γουίναμακ, Ιντιάνα)]',
        'America/Indianapolis' => '[Ανατολική ώρα Βόρειας Αμερικής (Ιντιανάπολις)]',
        'America/Indiana/Indianapolis' => '[Ανατολική ώρα Βόρειας Αμερικής (Ιντιανάπολις)]',
        'America/Inuvik' => '[Ορεινή ώρα Βόρειας Αμερικής (Ινούβικ)]',
        'America/Iqaluit' => '[Ανατολική ώρα Βόρειας Αμερικής (Ικαλούιτ)]',
        'America/Jamaica' => '[Ανατολική ώρα Βόρειας Αμερικής (Τζαμάικα)]',
        'America/Jujuy' => '[Ώρα Αργεντινής (Χουχούι)]',
        'America/Argentina/Jujuy' => '[Ώρα Αργεντινής (Χουχούι)]',
        'America/Juneau' => '[Ώρα Αλάσκας (Τζούνο)]',
        'America/Kentucky/Monticello' => '[Ανατολική ώρα Βόρειας Αμερικής (Μοντιτσέλο, Κεντάκι)]',
        'America/Kralendijk' => '[Ώρα Ατλαντικού (Κράλεντικ)]',
        'America/La_Paz' => '[Ώρα Βολιβίας (Λα Παζ)]',
        'America/Lima' => '[Ώρα Περού (Λίμα)]',
        'America/Los_Angeles' => '[Ώρα Ειρηνικού (Λος Άντζελες)]',
        'America/Louisville' => '[Ανατολική ώρα Βόρειας Αμερικής (Λούιβιλ)]',
        'America/Kentucky/Louisville' => '[Ανατολική ώρα Βόρειας Αμερικής (Λούιβιλ)]',
        'America/Lower_Princes' => '[Ώρα Ατλαντικού (Lower Prince’s Quarter)]',
        'America/Maceio' => '[Ώρα Μπραζίλιας (Μασεϊό)]',
        'America/Managua' => '[Κεντρική ώρα Βόρειας Αμερικής (Μανάγκουα)]',
        'America/Manaus' => '[Ώρα Αμαζονίου (Μανάους)]',
        'America/Marigot' => '[Ώρα Ατλαντικού (Μαριγκό)]',
        'America/Martinique' => '[Ώρα Ατλαντικού (Μαρτινίκα)]',
        'America/Matamoros' => '[Κεντρική ώρα Βόρειας Αμερικής (Ματαμόρος)]',
        'America/Mazatlan' => '[Ώρα Ειρηνικού Μεξικού (Μαζατλάν)]',
        'America/Mendoza' => '[Ώρα Αργεντινής (Μεντόζα)]',
        'America/Argentina/Mendoza' => '[Ώρα Αργεντινής (Μεντόζα)]',
        'America/Menominee' => '[Κεντρική ώρα Βόρειας Αμερικής (Μενομίνε)]',
        'America/Merida' => '[Κεντρική ώρα Βόρειας Αμερικής (Μέριδα)]',
        'America/Metlakatla' => '[Ώρα Αλάσκας (Μετλακάτλα)]',
        'America/Mexico_City' => '[Κεντρική ώρα Βόρειας Αμερικής (Πόλη του Μεξικού)]',
        'America/Miquelon' => 'Ώρα Σεν Πιερ και Μικελόν',
        'America/Moncton' => '[Ώρα Ατλαντικού (Μόνκτον)]',
        'America/Monterrey' => '[Κεντρική ώρα Βόρειας Αμερικής (Μοντερέι)]',
        'America/Montevideo' => '[Ώρα Ουρουγουάης (Μοντεβιδέο)]',
        'America/Montserrat' => '[Ώρα Ατλαντικού (Μονσεράτ)]',
        'America/Nassau' => '[Ανατολική ώρα Βόρειας Αμερικής (Νασάου)]',
        'America/New_York' => '[Ανατολική ώρα Βόρειας Αμερικής (Νέα Υόρκη)]',
        'America/Nome' => '[Ώρα Αλάσκας (Νόμε)]',
        'America/Noronha' => 'Ώρα Φερνάρντο ντε Νορόνια',
        'America/North_Dakota/Beulah' => '[Κεντρική ώρα Βόρειας Αμερικής (Μπέουλα, Βόρεια Ντακότα)]',
        'America/North_Dakota/Center' => '[Κεντρική ώρα Βόρειας Αμερικής (Σέντερ, Βόρεια Ντακότα)]',
        'America/North_Dakota/New_Salem' => '[Κεντρική ώρα Βόρειας Αμερικής (Νιου Σέιλεμ, Βόρεια Ντακότα)]',
        'America/Ojinaga' => '[Κεντρική ώρα Βόρειας Αμερικής (Οχινάγκα)]',
        'America/Panama' => '[Ανατολική ώρα Βόρειας Αμερικής (Παναμάς)]',
        'America/Paramaribo' => '[Ώρα Σουρινάμ (Παραμαρίμπο)]',
        'America/Phoenix' => '[Ορεινή ώρα Βόρειας Αμερικής (Φοίνιξ)]',
        'America/Port-au-Prince' => '[Ανατολική ώρα Βόρειας Αμερικής (Πορτ-ο-Πρενς)]',
        'America/Port_of_Spain' => '[Ώρα Ατλαντικού (Πορτ οφ Σπέιν)]',
        'America/Porto_Velho' => '[Ώρα Αμαζονίου (Πόρτο Βέλιο)]',
        'America/Puerto_Rico' => '[Ώρα Ατλαντικού (Πουέρτο Ρίκο)]',
        'America/Punta_Arenas' => '[Ώρα Χιλής (Πούντα Αρένας)]',
        'America/Rankin_Inlet' => '[Κεντρική ώρα Βόρειας Αμερικής (Ράνκιν Ίνλετ)]',
        'America/Recife' => '[Ώρα Μπραζίλιας (Ρεσίφε)]',
        'America/Regina' => '[Κεντρική ώρα Βόρειας Αμερικής (Ρετζάινα)]',
        'America/Resolute' => '[Κεντρική ώρα Βόρειας Αμερικής (Ρέζολουτ)]',
        'America/Rio_Branco' => '[Ώρα Άκρε (Ρίο Μπράνκο)]',
        'America/Santarem' => '[Ώρα Μπραζίλιας (Σανταρέμ)]',
        'America/Santiago' => '[Ώρα Χιλής (Σαντιάγκο)]',
        'America/Santo_Domingo' => '[Ώρα Ατλαντικού (Άγιος Δομίνικος)]',
        'America/Sao_Paulo' => '[Ώρα Μπραζίλιας (Σάο Πάολο)]',
        'America/Scoresbysund' => '[Ώρα (Γροιλανδία) (Σκορεσμπίσουντ)]',
        'America/Sitka' => '[Ώρα Αλάσκας (Σίτκα)]',
        'America/St_Barthelemy' => '[Ώρα Ατλαντικού (Άγιος Βαρθολομαίος)]',
        'America/St_Johns' => '[Ώρα Νέας Γης (Σεν Τζονς)]',
        'America/St_Kitts' => '[Ώρα Ατλαντικού (Σεν Κιτς)]',
        'America/St_Lucia' => '[Ώρα Ατλαντικού (Αγία Λουκία)]',
        'America/St_Thomas' => '[Ώρα Ατλαντικού (Άγιος Θωμάς)]',
        'America/St_Vincent' => '[Ώρα Ατλαντικού (Άγιος Βικέντιος)]',
        'America/Swift_Current' => '[Κεντρική ώρα Βόρειας Αμερικής (Σουίφτ Κάρεντ)]',
        'America/Tegucigalpa' => '[Κεντρική ώρα Βόρειας Αμερικής (Τεγκουσιγκάλπα)]',
        'America/Thule' => '[Ώρα Ατλαντικού (Θούλη)]',
        'America/Tijuana' => '[Ώρα Ειρηνικού (Τιχουάνα)]',
        'America/Toronto' => '[Ανατολική ώρα Βόρειας Αμερικής (Τορόντο)]',
        'America/Tortola' => '[Ώρα Ατλαντικού (Τορτόλα)]',
        'America/Vancouver' => '[Ώρα Ειρηνικού (Βανκούβερ)]',
        'America/Whitehorse' => '[Ώρα Γιούκον (Γουάιτχορς)]',
        'America/Winnipeg' => '[Κεντρική ώρα Βόρειας Αμερικής (Γουίνιπεγκ)]',
        'America/Yakutat' => '[Ώρα Αλάσκας (Γιάκουτατ)]',
        'Antarctica/Casey' => '[Ώρα Δυτικής Αυστραλίας (Κάσεϊ)]',
        'Antarctica/Davis' => 'Ώρα Ντέιβις',
        'Antarctica/DumontDUrville' => 'Ώρα Ντιμόν ντ’ Ουρβίλ',
        'Antarctica/Macquarie' => '[Ώρα Ανατολικής Αυστραλίας (Μακουάρι)]',
        'Antarctica/Mawson' => 'Ώρα Μόσον',
        'Antarctica/McMurdo' => '[Ώρα Νέας Ζηλανδίας (Μακμέρντο)]',
        'Antarctica/Palmer' => '[Ώρα Χιλής (Πάλμερ)]',
        'Antarctica/Rothera' => 'Ώρα Ρόθερα',
        'Antarctica/Syowa' => 'Ώρα Σίοβα',
        'Antarctica/Troll' => '[Μέση ώρα Γκρίνουιτς (Τρολ)]',
        'Antarctica/Vostok' => 'Ώρα Βόστοκ',
        'Arctic/Longyearbyen' => '[Ώρα Κεντρικής Ευρώπης (Λόνγκιεαρμπιεν)]',
        'Asia/Aden' => '[Αραβική ώρα (Άντεν)]',
        'Asia/Almaty' => '[Ώρα Καζακστάν (Αλμάτι)]',
        'Asia/Amman' => '[Ώρα Ανατολικής Ευρώπης (Αμμάν)]',
        'Asia/Anadyr' => '[Ώρα Καμτσάτκα (Αναντίρ)]',
        'Asia/Aqtau' => '[Ώρα Καζακστάν (Ακτάου)]',
        'Asia/Aqtobe' => '[Ώρα Καζακστάν (Ακτόμπε)]',
        'Asia/Ashgabat' => '[Ώρα Τουρκμενιστάν (Ασχαμπάτ)]',
        'Asia/Atyrau' => '[Ώρα Καζακστάν (Ατιράου)]',
        'Asia/Baghdad' => '[Αραβική ώρα (Βαγδάτη)]',
        'Asia/Bahrain' => '[Αραβική ώρα (Μπαχρέιν)]',
        'Asia/Baku' => '[Ώρα Αζερμπαϊτζάν (Μπακού)]',
        'Asia/Bangkok' => '[Ώρα Ινδοκίνας (Μπανγκόκ)]',
        'Asia/Barnaul' => '[Ώρα Κρασνογιάρσκ (Μπαρναούλ)]',
        'Asia/Beirut' => '[Ώρα Ανατολικής Ευρώπης (Βυρητός)]',
        'Asia/Bishkek' => '[Ώρα Κιργιστάν (Μπισκέκ)]',
        'Asia/Brunei' => 'Ώρα Μπρουνέι Νταρουσαλάμ',
        'Asia/Calcutta' => '[Ώρα Ινδίας (Καλκούτα)]',
        'Asia/Kolkata' => '[Ώρα Ινδίας (Καλκούτα)]',
        'Asia/Chita' => '[Ώρα Γιακούτσκ (Τσιτά)]',
        'Asia/Colombo' => '[Ώρα Ινδίας (Κολόμπο)]',
        'Asia/Damascus' => '[Ώρα Ανατολικής Ευρώπης (Δαμασκός)]',
        'Asia/Dhaka' => '[Ώρα Μπανγκλαντές (Ντάκα)]',
        'Asia/Dili' => '[Ώρα Ανατολικού Τιμόρ (Ντίλι)]',
        'Asia/Dubai' => '[Ώρα Κόλπου (Ντουμπάι)]',
        'Asia/Dushanbe' => '[Ώρα Τατζικιστάν (Ντουσάνμπε)]',
        'Asia/Famagusta' => '[Ώρα Ανατολικής Ευρώπης (Αμμόχωστος)]',
        'Asia/Gaza' => '[Ώρα Ανατολικής Ευρώπης (Γάζα)]',
        'Asia/Hebron' => '[Ώρα Ανατολικής Ευρώπης (Χεβρώνα)]',
        'Asia/Hong_Kong' => 'Ώρα Χονγκ Κονγκ',
        'Asia/Hovd' => 'Ώρα Χοβντ',
        'Asia/Irkutsk' => 'Ώρα Ιρκούτσκ',
        'Asia/Jakarta' => '[Ώρα Δυτικής Ινδονησίας (Τζακάρτα)]',
        'Asia/Jayapura' => '[Ώρα Ανατολικής Ινδονησίας (Τζαγιαπούρα)]',
        'Asia/Jerusalem' => '[Ώρα Ισραήλ (Ιερουσαλήμ)]',
        'Asia/Kabul' => '[Ώρα Αφγανιστάν (Καμπούλ)]',
        'Asia/Kamchatka' => 'Ώρα Καμτσάτκα',
        'Asia/Karachi' => '[Ώρα Πακιστάν (Καράτσι)]',
        'Asia/Katmandu' => '[Ώρα Νεπάλ (Κατμαντού)]',
        'Asia/Kathmandu' => '[Ώρα Νεπάλ (Κατμαντού)]',
        'Asia/Khandyga' => '[Ώρα Γιακούτσκ (Χαντίγκα)]',
        'Asia/Krasnoyarsk' => 'Ώρα Κρασνογιάρσκ',
        'Asia/Kuala_Lumpur' => '[Ώρα Μαλαισίας (Κουάλα Λουμπούρ)]',
        'Asia/Kuching' => '[Ώρα Μαλαισίας (Κουτσίνγκ)]',
        'Asia/Kuwait' => '[Αραβική ώρα (Κουβέιτ)]',
        'Asia/Macau' => '[Ώρα Κίνας (Μακάο)]',
        'Asia/Magadan' => 'Ώρα Μαγκαντάν',
        'Asia/Makassar' => '[Ώρα Κεντρικής Ινδονησίας (Μακασάρ)]',
        'Asia/Manila' => '[Ώρα Φιλιππινών (Μανίλα)]',
        'Asia/Muscat' => '[Ώρα Κόλπου (Μασκάτ)]',
        'Asia/Nicosia' => '[Ώρα Ανατολικής Ευρώπης (Λευκωσία)]',
        'Asia/Novokuznetsk' => '[Ώρα Κρασνογιάρσκ (Νοβοκουζνέτσκ)]',
        'Asia/Novosibirsk' => '[Ώρα Κρασνογιάρσκ (Νοβοσιμπίρσκ)]',
        'Asia/Omsk' => 'Ώρα Ομσκ',
        'Asia/Oral' => '[Ώρα Καζακστάν (Οράλ)]',
        'Asia/Phnom_Penh' => '[Ώρα Ινδοκίνας (Πνομ Πενχ)]',
        'Asia/Pontianak' => '[Ώρα Δυτικής Ινδονησίας (Πόντιανακ)]',
        'Asia/Pyongyang' => '[Ώρα Κορέας (Πιονγκγιάνγκ)]',
        'Asia/Qatar' => '[Αραβική ώρα (Κατάρ)]',
        'Asia/Qostanay' => '[Ώρα Καζακστάν (Κοστανάι)]',
        'Asia/Qyzylorda' => '[Ώρα Καζακστάν (Κιζιλορντά)]',
        'Asia/Rangoon' => '[Ώρα Μιανμάρ (Ρανγκούν)]',
        'Asia/Yangon' => '[Ώρα Μιανμάρ (Ρανγκούν)]',
        'Asia/Riyadh' => '[Αραβική ώρα (Ριάντ)]',
        'Asia/Saigon' => '[Ώρα Ινδοκίνας (Πόλη Χο Τσι Μινχ)]',
        'Asia/Ho_Chi_Minh' => '[Ώρα Ινδοκίνας (Πόλη Χο Τσι Μινχ)]',
        'Asia/Sakhalin' => '[Ώρα Μαγκαντάν (Σαχαλίνη)]',
        'Asia/Samarkand' => '[Ώρα Ουζμπεκιστάν (Σαμαρκάνδη)]',
        'Asia/Seoul' => '[Ώρα Κορέας (Σεούλ)]',
        'Asia/Shanghai' => '[Ώρα Κίνας (Σανγκάη)]',
        'Asia/Singapore' => 'Ώρα Σιγκαπούρης',
        'Asia/Srednekolymsk' => '[Ώρα Μαγκαντάν (Σρεντνεκολίμσκ)]',
        'Asia/Taipei' => 'Ώρα Ταϊπέι',
        'Asia/Tashkent' => '[Ώρα Ουζμπεκιστάν (Τασκένδη)]',
        'Asia/Tbilisi' => '[Ώρα Γεωργίας (Τιφλίδα)]',
        'Asia/Tehran' => '[Ώρα Ιράν (Τεχεράνη)]',
        'Asia/Thimphu' => '[Ώρα Μπουτάν (Θίμφου)]',
        'Asia/Tokyo' => '[Ώρα Ιαπωνίας (Τόκιο)]',
        'Asia/Tomsk' => '[Ώρα Κρασνογιάρσκ (Τομσκ)]',
        'Asia/Ulaanbaatar' => 'Ώρα Ουλάν Μπατόρ',
        'Asia/Urumqi' => '[Ώρα (Κίνα) (Ουρούμτσι)]',
        'Asia/Ust-Nera' => '[Ώρα Βλαδιβοστόκ (Ουστ-Νερά)]',
        'Asia/Vientiane' => '[Ώρα Ινδοκίνας (Βιεντιάν)]',
        'Asia/Vladivostok' => 'Ώρα Βλαδιβοστόκ',
        'Asia/Yakutsk' => 'Ώρα Γιακούτσκ',
        'Asia/Yekaterinburg' => 'Ώρα Αικατερινούπολης',
        'Asia/Yerevan' => '[Ώρα Αρμενίας (Ερεβάν)]',
        'Atlantic/Azores' => '[Ώρα Αζορών (Αζόρες)]',
        'Atlantic/Bermuda' => '[Ώρα Ατλαντικού (Βερμούδες)]',
        'Atlantic/Canary' => '[Ώρα Δυτικής Ευρώπης (Κανάρια)]',
        'Atlantic/Cape_Verde' => '[Ώρα Πράσινου Ακρωτηρίου (Πράσινο Ακρωτήριο)]',
        'Atlantic/Faeroe' => '[Ώρα Δυτικής Ευρώπης (Φερόες)]',
        'Atlantic/Faroe' => '[Ώρα Δυτικής Ευρώπης (Φερόες)]',
        'Atlantic/Madeira' => '[Ώρα Δυτικής Ευρώπης (Μαδέρα)]',
        'Atlantic/Reykjavik' => '[Μέση ώρα Γκρίνουιτς (Ρέυκιαβικ)]',
        'Atlantic/South_Georgia' => '[Ώρα Νότιας Γεωργίας (Νότια Γεωργία)]',
        'Atlantic/St_Helena' => '[Μέση ώρα Γκρίνουιτς (Αγ. Ελένη)]',
        'Atlantic/Stanley' => '[Ώρα Νήσων Φόκλαντ (Στάνλεϊ)]',
        'Australia/Adelaide' => '[Ώρα Κεντρικής Αυστραλίας (Αδελαΐδα)]',
        'Australia/Brisbane' => '[Ώρα Ανατολικής Αυστραλίας (Μπρισμπέιν)]',
        'Australia/Broken_Hill' => '[Ώρα Κεντρικής Αυστραλίας (Μπρόκεν Χιλ)]',
        'Australia/Darwin' => '[Ώρα Κεντρικής Αυστραλίας (Ντάργουιν)]',
        'Australia/Eucla' => '[Ώρα Κεντροδυτικής Αυστραλίας (Γιούκλα)]',
        'Australia/Hobart' => '[Ώρα Ανατολικής Αυστραλίας (Χόμπαρτ)]',
        'Australia/Lindeman' => '[Ώρα Ανατολικής Αυστραλίας (Λίντεμαν)]',
        'Australia/Lord_Howe' => 'Ώρα Λορντ Χάου',
        'Australia/Melbourne' => '[Ώρα Ανατολικής Αυστραλίας (Μελβούρνη)]',
        'Australia/Perth' => '[Ώρα Δυτικής Αυστραλίας (Περθ)]',
        'Australia/Sydney' => '[Ώρα Ανατολικής Αυστραλίας (Σίδνεϊ)]',
        'Etc/GMT' => 'Μέση ώρα Γκρίνουιτς',
        'Etc/UTC' => 'Συντονισμένη Παγκόσμια Ώρα',
        'Europe/Amsterdam' => '[Ώρα Κεντρικής Ευρώπης (Άμστερνταμ)]',
        'Europe/Andorra' => '[Ώρα Κεντρικής Ευρώπης (Ανδόρα)]',
        'Europe/Astrakhan' => '[Ώρα Σάμαρας (Αστραχάν)]',
        'Europe/Athens' => '[Ώρα Ανατολικής Ευρώπης (Αθήνα)]',
        'Europe/Belgrade' => '[Ώρα Κεντρικής Ευρώπης (Βελιγράδι)]',
        'Europe/Berlin' => '[Ώρα Κεντρικής Ευρώπης (Βερολίνο)]',
        'Europe/Bratislava' => '[Ώρα Κεντρικής Ευρώπης (Μπρατισλάβα)]',
        'Europe/Brussels' => '[Ώρα Κεντρικής Ευρώπης (Βρυξέλλες)]',
        'Europe/Bucharest' => '[Ώρα Ανατολικής Ευρώπης (Βουκουρέστι)]',
        'Europe/Budapest' => '[Ώρα Κεντρικής Ευρώπης (Βουδαπέστη)]',
        'Europe/Busingen' => '[Ώρα Κεντρικής Ευρώπης (Μπίσινγκεν)]',
        'Europe/Chisinau' => '[Ώρα Ανατολικής Ευρώπης (Κισινάου)]',
        'Europe/Copenhagen' => '[Ώρα Κεντρικής Ευρώπης (Κοπεγχάγη)]',
        'Europe/Dublin' => '[Μέση ώρα Γκρίνουιτς (Δουβλίνο)]',
        'Europe/Gibraltar' => '[Ώρα Κεντρικής Ευρώπης (Γιβραλτάρ)]',
        'Europe/Guernsey' => '[Μέση ώρα Γκρίνουιτς (Γκέρνζι)]',
        'Europe/Helsinki' => '[Ώρα Ανατολικής Ευρώπης (Ελσίνκι)]',
        'Europe/Isle_of_Man' => '[Μέση ώρα Γκρίνουιτς (Νήσος του Μαν)]',
        'Europe/Istanbul' => '[Ώρα Τουρκίας (Κωνσταντινούπολη)]',
        'Europe/Jersey' => '[Μέση ώρα Γκρίνουιτς (Τζέρσεϊ)]',
        'Europe/Kaliningrad' => '[Ώρα Ανατολικής Ευρώπης (Καλίνινγκραντ)]',
        'Europe/Kiev' => '[Ώρα Ανατολικής Ευρώπης (Κίεβο)]',
        'Europe/Kyiv' => '[Ώρα Ανατολικής Ευρώπης (Κίεβο)]',
        'Europe/Kirov' => '[Ώρα Μόσχας (Κίροφ)]',
        'Europe/Lisbon' => '[Ώρα Δυτικής Ευρώπης (Λισαβόνα)]',
        'Europe/Ljubljana' => '[Ώρα Κεντρικής Ευρώπης (Λιουμπλιάνα)]',
        'Europe/London' => '[Μέση ώρα Γκρίνουιτς (Λονδίνο)]',
        'Europe/Luxembourg' => '[Ώρα Κεντρικής Ευρώπης (Λουξεμβούργο)]',
        'Europe/Madrid' => '[Ώρα Κεντρικής Ευρώπης (Μαδρίτη)]',
        'Europe/Malta' => '[Ώρα Κεντρικής Ευρώπης (Μάλτα)]',
        'Europe/Mariehamn' => '[Ώρα Ανατολικής Ευρώπης (Μάριεχαμν)]',
        'Europe/Minsk' => '[Ώρα Μόσχας (Μινσκ)]',
        'Europe/Monaco' => '[Ώρα Κεντρικής Ευρώπης (Μονακό)]',
        'Europe/Moscow' => 'Ώρα Μόσχας',
        'Europe/Oslo' => '[Ώρα Κεντρικής Ευρώπης (Όσλο)]',
        'Europe/Paris' => '[Ώρα Κεντρικής Ευρώπης (Παρίσι)]',
        'Europe/Podgorica' => '[Ώρα Κεντρικής Ευρώπης (Ποντγκόριτσα)]',
        'Europe/Prague' => '[Ώρα Κεντρικής Ευρώπης (Πράγα)]',
        'Europe/Riga' => '[Ώρα Ανατολικής Ευρώπης (Ρίγα)]',
        'Europe/Rome' => '[Ώρα Κεντρικής Ευρώπης (Ρώμη)]',
        'Europe/Samara' => '[Ώρα Σάμαρας (Σαμάρα)]',
        'Europe/San_Marino' => '[Ώρα Κεντρικής Ευρώπης (Άγιος Μαρίνος)]',
        'Europe/Sarajevo' => '[Ώρα Κεντρικής Ευρώπης (Σαράγεβο)]',
        'Europe/Saratov' => '[Ώρα Σάμαρας (Σαράτοφ)]',
        'Europe/Simferopol' => '[Ώρα Μόσχας (Συμφερόπολη)]',
        'Europe/Skopje' => '[Ώρα Κεντρικής Ευρώπης (Σκόπια)]',
        'Europe/Sofia' => '[Ώρα Ανατολικής Ευρώπης (Σόφια)]',
        'Europe/Stockholm' => '[Ώρα Κεντρικής Ευρώπης (Στοκχόλμη)]',
        'Europe/Tallinn' => '[Ώρα Ανατολικής Ευρώπης (Ταλίν)]',
        'Europe/Tirane' => '[Ώρα Κεντρικής Ευρώπης (Τίρανα)]',
        'Europe/Ulyanovsk' => '[Ώρα Σάμαρας (Ουλιάνοφσκ)]',
        'Europe/Vaduz' => '[Ώρα Κεντρικής Ευρώπης (Βαντούζ)]',
        'Europe/Vatican' => '[Ώρα Κεντρικής Ευρώπης (Βατικανό)]',
        'Europe/Vienna' => '[Ώρα Κεντρικής Ευρώπης (Βιέννη)]',
        'Europe/Vilnius' => '[Ώρα Ανατολικής Ευρώπης (Βίλνιους)]',
        'Europe/Volgograd' => '[Ώρα Μόσχας (Βόλγκοκραντ)]',
        'Europe/Warsaw' => '[Ώρα Κεντρικής Ευρώπης (Βαρσοβία)]',
        'Europe/Zagreb' => '[Ώρα Κεντρικής Ευρώπης (Ζάγκρεμπ)]',
        'Europe/Zurich' => '[Ώρα Κεντρικής Ευρώπης (Ζυρίχη)]',
        'Indian/Antananarivo' => '[Ώρα Ανατολικής Αφρικής (Ανταναναρίβο)]',
        'Indian/Chagos' => '[Ώρα Ινδικού Ωκεανού (Τσάγκος)]',
        'Indian/Christmas' => '[Ώρα Νήσου Χριστουγέννων (Νήσος Χριστουγέννων)]',
        'Indian/Cocos' => 'Ώρα Νήσων Κόκος',
        'Indian/Comoro' => '[Ώρα Ανατολικής Αφρικής (Κομόρο)]',
        'Indian/Kerguelen' => '[Ώρα Γαλλικού Νότου και Ανταρκτικής (Κεργκελέν)]',
        'Indian/Mahe' => '[Ώρα Σεϋχελλών (Μάχε)]',
        'Indian/Maldives' => '[Ώρα Μαλδίβων (Μαλδίβες)]',
        'Indian/Mauritius' => '[Ώρα Μαυρίκιου (Μαυρίκιος)]',
        'Indian/Mayotte' => '[Ώρα Ανατολικής Αφρικής (Μαγιότ)]',
        'Indian/Reunion' => 'Ώρα Ρεϊνιόν',
        'Pacific/Apia' => 'Ώρα Απία',
        'Pacific/Auckland' => '[Ώρα Νέας Ζηλανδίας (Όκλαντ)]',
        'Pacific/Bougainville' => '[Ώρα Παπούας Νέας Γουινέας (Μπουγκενβίλ)]',
        'Pacific/Chatham' => 'Ώρα Τσάταμ',
        'Pacific/Easter' => '[Ώρα Νήσου Πάσχα (Νήσος Πάσχα)]',
        'Pacific/Efate' => '[Ώρα Βανουάτου (Εφάτε)]',
        'Pacific/Enderbury' => '[Ώρα Νήσων Φοίνιξ (Καντών)]',
        'Pacific/Kanton' => '[Ώρα Νήσων Φοίνιξ (Καντών)]',
        'Pacific/Fakaofo' => '[Ώρα Τοκελάου (Φακαόφο)]',
        'Pacific/Fiji' => 'Ώρα Φίτζι',
        'Pacific/Funafuti' => '[Ώρα Τουβαλού (Φουναφούτι)]',
        'Pacific/Galapagos' => 'Ώρα Γκαλάπαγκος',
        'Pacific/Gambier' => 'Ώρα Γκάμπιερ',
        'Pacific/Guadalcanal' => '[Ώρα Νήσων Σολομώντος (Γκουανταλκανάλ)]',
        'Pacific/Guam' => '[Ώρα Τσαμόρο (Γκουάμ)]',
        'Pacific/Honolulu' => '[Χειμερινή ώρα Χαβάης-Αλεούτιων Νήσων (Χονολουλού)]',
        'Pacific/Kiritimati' => '[Ώρα Νήσων Λάιν (Κιριτιμάτι)]',
        'Pacific/Kosrae' => 'Ώρα Κόσραϊ',
        'Pacific/Kwajalein' => '[Ώρα Νήσων Μάρσαλ (Κουατζαλέιν)]',
        'Pacific/Majuro' => '[Ώρα Νήσων Μάρσαλ (Ματζούρο)]',
        'Pacific/Marquesas' => 'Ώρα Μαρκέζας',
        'Pacific/Midway' => '[Ώρα Σαμόα (Μίντγουεϊ)]',
        'Pacific/Nauru' => 'Ώρα Ναούρου',
        'Pacific/Niue' => 'Ώρα Νιούε',
        'Pacific/Norfolk' => 'Ώρα Νήσου Νόρφολκ',
        'Pacific/Noumea' => '[Ώρα Νέας Καληδονίας (Νουμέα)]',
        'Pacific/Pago_Pago' => '[Ώρα Σαμόα (Πάγκο Πάγκο)]',
        'Pacific/Palau' => 'Ώρα Παλάου',
        'Pacific/Pitcairn' => 'Ώρα Πίτκερν',
        'Pacific/Ponape' => 'Ώρα Πονάπε',
        'Pacific/Pohnpei' => 'Ώρα Πονάπε',
        'Pacific/Port_Moresby' => '[Ώρα Παπούας Νέας Γουινέας (Πορτ Μόρεσμπι)]',
        'Pacific/Rarotonga' => '[Ώρα Νήσων Κουκ (Ραροτόνγκα)]',
        'Pacific/Saipan' => '[Ώρα Τσαμόρο (Σαϊπάν)]',
        'Pacific/Tahiti' => 'Ώρα Ταϊτής',
        'Pacific/Tarawa' => '[Ώρα Νήσων Γκίλμπερτ (Ταράουα)]',
        'Pacific/Tongatapu' => '[Ώρα Τόνγκα (Τονγκατάπου)]',
        'Pacific/Truk' => 'Ώρα Τσουκ',
        'Pacific/Chuuk' => 'Ώρα Τσουκ',
        'Pacific/Wake' => 'Ώρα Νήσου Γουέικ',
        'Pacific/Wallis' => '[Ώρα Ουάλις και Φουτούνα (Γουάλις)]',
    ],
    'Meta' => [],
];
