<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Grinvičo laikas (Abidžanas)',
        'Africa/Accra' => 'Grinvičo laikas (Akra)',
        'Africa/Addis_Ababa' => 'Rytų Afrikos laikas (Adis Abeba)',
        'Africa/Algiers' => 'Vidurio Europos laikas (Alžyras)',
        'Africa/Asmera' => 'Rytų Afrikos laikas (Asmara)',
        'Africa/Asmara' => 'Rytų Afrikos laikas (Asmara)',
        'Africa/Bamako' => 'Grinvičo laikas (Bamakas)',
        'Africa/Bangui' => 'Vakarų Afrikos laikas (Bangis)',
        'Africa/Banjul' => 'Grinvičo laikas (Bandžulis)',
        'Africa/Bissau' => 'Grinvičo laikas (Bisau)',
        'Africa/Blantyre' => 'Centrinės Afrikos laikas (Blantairas)',
        'Africa/Brazzaville' => 'Vakarų Afrikos laikas (Brazavilis)',
        'Africa/Bujumbura' => 'Centrinės Afrikos laikas (Bužumbūra)',
        'Africa/Cairo' => 'Rytų Europos laikas (Kairas)',
        'Africa/Casablanca' => 'Vakarų Europos laikas (Kasablanka)',
        'Africa/Ceuta' => 'Vidurio Europos laikas (Seuta)',
        'Africa/Conakry' => 'Grinvičo laikas (Konakris)',
        'Africa/Dakar' => 'Grinvičo laikas (Dakaras)',
        'Africa/Dar_es_Salaam' => 'Rytų Afrikos laikas (Dar es Salamas)',
        'Africa/Djibouti' => 'Rytų Afrikos laikas (Džibutis)',
        'Africa/Douala' => 'Vakarų Afrikos laikas (Duala)',
        'Africa/El_Aaiun' => 'Vakarų Europos laikas (al Ajūnas)',
        'Africa/Freetown' => 'Grinvičo laikas (Fritaunas)',
        'Africa/Gaborone' => 'Centrinės Afrikos laikas (Gaboronas)',
        'Africa/Harare' => 'Centrinės Afrikos laikas (Hararė)',
        'Africa/Johannesburg' => 'Pietų Afrikos laikas (Johanesburgas)',
        'Africa/Juba' => 'Centrinės Afrikos laikas (Džuba)',
        'Africa/Kampala' => 'Rytų Afrikos laikas (Kampala)',
        'Africa/Khartoum' => 'Centrinės Afrikos laikas (Chartumas)',
        'Africa/Kigali' => 'Centrinės Afrikos laikas (Kigalis)',
        'Africa/Kinshasa' => 'Vakarų Afrikos laikas (Kinšasa)',
        'Africa/Lagos' => 'Vakarų Afrikos laikas (Lagosas)',
        'Africa/Libreville' => 'Vakarų Afrikos laikas (Librevilis)',
        'Africa/Lome' => 'Grinvičo laikas (Lomė)',
        'Africa/Luanda' => 'Vakarų Afrikos laikas (Luanda)',
        'Africa/Lubumbashi' => 'Centrinės Afrikos laikas (Lubumbašis)',
        'Africa/Lusaka' => 'Centrinės Afrikos laikas (Lusaka)',
        'Africa/Malabo' => 'Vakarų Afrikos laikas (Malabas)',
        'Africa/Maputo' => 'Centrinės Afrikos laikas (Maputas)',
        'Africa/Maseru' => 'Pietų Afrikos laikas (Maseru)',
        'Africa/Mbabane' => 'Pietų Afrikos laikas (Mbabanė)',
        'Africa/Mogadishu' => 'Rytų Afrikos laikas (Mogadišas)',
        'Africa/Monrovia' => 'Grinvičo laikas (Monrovija)',
        'Africa/Nairobi' => 'Rytų Afrikos laikas (Nairobis)',
        'Africa/Ndjamena' => 'Vakarų Afrikos laikas (Ndžamena)',
        'Africa/Niamey' => 'Vakarų Afrikos laikas (Niamėjus)',
        'Africa/Nouakchott' => 'Grinvičo laikas (Nuakšotas)',
        'Africa/Ouagadougou' => 'Grinvičo laikas (Vagadugu)',
        'Africa/Porto-Novo' => 'Vakarų Afrikos laikas (Porto Novas)',
        'Africa/Sao_Tome' => 'Grinvičo laikas (San Tomė)',
        'Africa/Tripoli' => 'Rytų Europos laikas (Tripolis)',
        'Africa/Tunis' => 'Vidurio Europos laikas (Tunisas)',
        'Africa/Windhoek' => 'Centrinės Afrikos laikas (Vindhukas)',
        'America/Adak' => 'Havajų-Aleutų laikas (Eidakas)',
        'America/Anchorage' => 'Aliaskos laikas (Ankoridžas)',
        'America/Anguilla' => 'Atlanto laikas (Angilija)',
        'America/Antigua' => 'Atlanto laikas (Antigva)',
        'America/Araguaina' => 'Brazilijos laikas (Aragvajana)',
        'America/Argentina/La_Rioja' => 'Argentinos laikas (La Riocha)',
        'America/Argentina/Rio_Gallegos' => 'Argentinos laikas (Rio Galjegosas)',
        'America/Argentina/Salta' => 'Argentinos laikas (Saltas)',
        'America/Argentina/San_Juan' => 'Argentinos laikas (San Chuanas)',
        'America/Argentina/San_Luis' => 'Argentinos laikas (Sent Luisas)',
        'America/Argentina/Tucuman' => 'Argentinos laikas (Tukumanas)',
        'America/Argentina/Ushuaia' => 'Argentinos laikas (Ušuaja)',
        'America/Aruba' => 'Atlanto laikas (Aruba)',
        'America/Asuncion' => 'Paragvajaus laikas (Asunsjonas)',
        'America/Bahia' => 'Brazilijos laikas (Baija)',
        'America/Bahia_Banderas' => 'Šiaurės Amerikos centro laikas (Bahia Banderasas)',
        'America/Barbados' => 'Atlanto laikas (Barbadosas)',
        'America/Belem' => 'Brazilijos laikas (Belenas)',
        'America/Belize' => 'Šiaurės Amerikos centro laikas (Belizas)',
        'America/Blanc-Sablon' => 'Atlanto laikas (Blanč Sablonas)',
        'America/Boa_Vista' => 'Amazonės laikas (Bua Vista)',
        'America/Bogota' => 'Kolumbijos laikas (Bogotá)',
        'America/Boise' => 'Šiaurės Amerikos kalnų laikas (Boisis)',
        'America/Buenos_Aires' => 'Argentinos laikas (Buenos Airės)',
        'America/Argentina/Buenos_Aires' => 'Argentinos laikas (Buenos Airės)',
        'America/Cambridge_Bay' => 'Šiaurės Amerikos kalnų laikas (Keimbridž Bėjus)',
        'America/Campo_Grande' => 'Amazonės laikas (Kampo Grandė)',
        'America/Cancun' => 'Šiaurės Amerikos rytų laikas (Kankūnas)',
        'America/Caracas' => 'Venesuelos laikas (Karakasas)',
        'America/Catamarca' => 'Argentinos laikas (Katamarka)',
        'America/Argentina/Catamarca' => 'Argentinos laikas (Katamarka)',
        'America/Cayenne' => 'Prancūzijos Gvianos laikas (Kajenas)',
        'America/Cayman' => 'Šiaurės Amerikos rytų laikas (Kaimanas)',
        'America/Chicago' => 'Šiaurės Amerikos centro laikas (Čikaga)',
        'America/Chihuahua' => 'Šiaurės Amerikos centro laikas (Čihuahua)',
        'America/Ciudad_Juarez' => 'Šiaurės Amerikos kalnų laikas (Siudad Chuaresas)',
        'America/Coral_Harbour' => 'Šiaurės Amerikos rytų laikas (Atikokanas)',
        'America/Atikokan' => 'Šiaurės Amerikos rytų laikas (Atikokanas)',
        'America/Cordoba' => 'Argentinos laikas (Kordoba)',
        'America/Argentina/Cordoba' => 'Argentinos laikas (Kordoba)',
        'America/Costa_Rica' => 'Šiaurės Amerikos centro laikas (Kosta Rika)',
        'America/Coyhaique' => 'Čilės laikas (Kojhaikė)',
        'America/Creston' => 'Šiaurės Amerikos kalnų laikas (Krestonas)',
        'America/Cuiaba' => 'Amazonės laikas (Kujaba)',
        'America/Curacao' => 'Atlanto laikas (Kiurasao)',
        'America/Danmarkshavn' => 'Grinvičo laikas (Danmarkshaunas)',
        'America/Dawson' => 'Jukono laikas (Dosonas)',
        'America/Dawson_Creek' => 'Šiaurės Amerikos kalnų laikas (Doson Krikas)',
        'America/Denver' => 'Šiaurės Amerikos kalnų laikas (Denveris)',
        'America/Detroit' => 'Šiaurės Amerikos rytų laikas (Detroitas)',
        'America/Dominica' => 'Atlanto laikas (Dominika)',
        'America/Edmonton' => 'Šiaurės Amerikos kalnų laikas (Edmontonas)',
        'America/Eirunepe' => 'Ako laikas (Eirunepė)',
        'America/El_Salvador' => 'Šiaurės Amerikos centro laikas (Salvadoras)',
        'America/Fort_Nelson' => 'Šiaurės Amerikos kalnų laikas (Fort Nelsonas)',
        'America/Fortaleza' => 'Brazilijos laikas (Fortaleza)',
        'America/Glace_Bay' => 'Atlanto laikas (Gleis Bėjus)',
        'America/Godthab' => 'Laikas: Grenlandija (Nūkas)',
        'America/Nuuk' => 'Laikas: Grenlandija (Nūkas)',
        'America/Goose_Bay' => 'Atlanto laikas (Gus Bėjus)',
        'America/Grand_Turk' => 'Šiaurės Amerikos rytų laikas (Grand Terkas)',
        'America/Grenada' => 'Atlanto laikas (Grenada)',
        'America/Guadeloupe' => 'Atlanto laikas (Gvadalupė)',
        'America/Guatemala' => 'Šiaurės Amerikos centro laikas (Gvatemala)',
        'America/Guayaquil' => 'Ekvadoro laikas (Gvajakilis)',
        'America/Guyana' => 'Gajanos laikas (Gvajana)',
        'America/Halifax' => 'Atlanto laikas (Halifaksas)',
        'America/Havana' => 'Kubos laikas (Havana)',
        'America/Hermosillo' => 'Meksikos Ramiojo vandenyno laikas (Hermosiljas)',
        'America/Indiana/Knox' => 'Šiaurės Amerikos centro laikas (Noksas, Indiana)',
        'America/Indiana/Marengo' => 'Šiaurės Amerikos rytų laikas (Marengas, Indiana)',
        'America/Indiana/Petersburg' => 'Šiaurės Amerikos rytų laikas (Pitersbergas, Indiana)',
        'America/Indiana/Tell_City' => 'Šiaurės Amerikos centro laikas (Tel Sitis, Indiana)',
        'America/Indiana/Vevay' => 'Šiaurės Amerikos rytų laikas (Vivis, Indiana)',
        'America/Indiana/Vincennes' => 'Šiaurės Amerikos rytų laikas (Vinsenas, Indiana)',
        'America/Indiana/Winamac' => 'Šiaurės Amerikos rytų laikas (Vinamakas, Indiana)',
        'America/Indianapolis' => 'Šiaurės Amerikos rytų laikas (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Šiaurės Amerikos rytų laikas (Indianapolis)',
        'America/Inuvik' => 'Šiaurės Amerikos kalnų laikas (Inuvikas)',
        'America/Iqaluit' => 'Šiaurės Amerikos rytų laikas (Ikaluitas)',
        'America/Jamaica' => 'Šiaurės Amerikos rytų laikas (Jamaika)',
        'America/Jujuy' => 'Argentinos laikas (Chuchujus)',
        'America/Argentina/Jujuy' => 'Argentinos laikas (Chuchujus)',
        'America/Juneau' => 'Aliaskos laikas (Džunas)',
        'America/Kentucky/Monticello' => 'Šiaurės Amerikos rytų laikas (Montiselas, Kentukis)',
        'America/Kralendijk' => 'Atlanto laikas (Kralendeikas)',
        'America/La_Paz' => 'Bolivijos laikas (La Pasas)',
        'America/Lima' => 'Peru laikas (Lima)',
        'America/Los_Angeles' => 'Šiaurės Amerikos Ramiojo vandenyno laikas (Los Andželas)',
        'America/Louisville' => 'Šiaurės Amerikos rytų laikas (Luisvilis)',
        'America/Kentucky/Louisville' => 'Šiaurės Amerikos rytų laikas (Luisvilis)',
        'America/Lower_Princes' => 'Atlanto laikas (Žemutinis Prinses Kvorteris)',
        'America/Maceio' => 'Brazilijos laikas (Masejo)',
        'America/Managua' => 'Šiaurės Amerikos centro laikas (Managva)',
        'America/Manaus' => 'Amazonės laikas (Manausas)',
        'America/Marigot' => 'Atlanto laikas (Marigo)',
        'America/Martinique' => 'Atlanto laikas (Martinika)',
        'America/Matamoros' => 'Šiaurės Amerikos centro laikas (Matamorosas)',
        'America/Mazatlan' => 'Meksikos Ramiojo vandenyno laikas (Masatlanas)',
        'America/Mendoza' => 'Argentinos laikas (Mendosa)',
        'America/Argentina/Mendoza' => 'Argentinos laikas (Mendosa)',
        'America/Menominee' => 'Šiaurės Amerikos centro laikas (Menominis)',
        'America/Merida' => 'Šiaurės Amerikos centro laikas (Merida)',
        'America/Metlakatla' => 'Aliaskos laikas (Metlakatla)',
        'America/Mexico_City' => 'Šiaurės Amerikos centro laikas (Meksikas)',
        'America/Miquelon' => 'Sen Pjero ir Mikelono laikas (Mikelonas)',
        'America/Moncton' => 'Atlanto laikas (Monktonas)',
        'America/Monterrey' => 'Šiaurės Amerikos centro laikas (Monterėjus)',
        'America/Montevideo' => 'Urugvajaus laikas (Montevidėjas)',
        'America/Montserrat' => 'Atlanto laikas (Montseratas)',
        'America/Nassau' => 'Šiaurės Amerikos rytų laikas (Nasau)',
        'America/New_York' => 'Šiaurės Amerikos rytų laikas (Niujorkas)',
        'America/Nome' => 'Aliaskos laikas (Nomas)',
        'America/Noronha' => 'Fernando de Noronjos laikas (Noronja)',
        'America/North_Dakota/Beulah' => 'Šiaurės Amerikos centro laikas (Bjula, Šiaurės Dakota)',
        'America/North_Dakota/Center' => 'Šiaurės Amerikos centro laikas (Senteris, Šiaurės Dakota)',
        'America/North_Dakota/New_Salem' => 'Šiaurės Amerikos centro laikas (Niu Seilemas, Šiaurės Dakota)',
        'America/Ojinaga' => 'Šiaurės Amerikos centro laikas (Ochinaga)',
        'America/Panama' => 'Šiaurės Amerikos rytų laikas (Panama)',
        'America/Paramaribo' => 'Surinamo laikas (Paramaribas)',
        'America/Phoenix' => 'Šiaurės Amerikos kalnų laikas (Finiksas)',
        'America/Port-au-Prince' => 'Šiaurės Amerikos rytų laikas (Port o Prensas)',
        'America/Port_of_Spain' => 'Atlanto laikas (Port of Speinas)',
        'America/Porto_Velho' => 'Amazonės laikas (Porto Veljas)',
        'America/Puerto_Rico' => 'Atlanto laikas (Puerto Rikas)',
        'America/Punta_Arenas' => 'Čilės laikas (Punta Arenasas)',
        'America/Rankin_Inlet' => 'Šiaurės Amerikos centro laikas (Rankin Inletas)',
        'America/Recife' => 'Brazilijos laikas (Resifė)',
        'America/Regina' => 'Šiaurės Amerikos centro laikas (Redžina)',
        'America/Resolute' => 'Šiaurės Amerikos centro laikas (Resolutas)',
        'America/Rio_Branco' => 'Ako laikas (Rio Brankas)',
        'America/Santarem' => 'Brazilijos laikas (Santarenas)',
        'America/Santiago' => 'Čilės laikas (Santjagas)',
        'America/Santo_Domingo' => 'Atlanto laikas (Santo Domingas)',
        'America/Sao_Paulo' => 'Brazilijos laikas (San Paulas)',
        'America/Scoresbysund' => 'Laikas: Grenlandija (Itokortormitas)',
        'America/Sitka' => 'Aliaskos laikas (Sitka)',
        'America/St_Barthelemy' => 'Atlanto laikas (Sen Bartelemi)',
        'America/St_Johns' => 'Niufaundlendo laikas (Sent Džonsas)',
        'America/St_Kitts' => 'Atlanto laikas (Sent Kitsas)',
        'America/St_Lucia' => 'Atlanto laikas (Sent Lusija)',
        'America/St_Thomas' => 'Atlanto laikas (Sent Tomasas)',
        'America/St_Vincent' => 'Atlanto laikas (Sent Vincentas)',
        'America/Swift_Current' => 'Šiaurės Amerikos centro laikas (Svift Karentas)',
        'America/Tegucigalpa' => 'Šiaurės Amerikos centro laikas (Tegusigalpa)',
        'America/Thule' => 'Atlanto laikas (Kanakas)',
        'America/Tijuana' => 'Šiaurės Amerikos Ramiojo vandenyno laikas (Tichuana)',
        'America/Toronto' => 'Šiaurės Amerikos rytų laikas (Torontas)',
        'America/Tortola' => 'Atlanto laikas (Tortola)',
        'America/Vancouver' => 'Šiaurės Amerikos Ramiojo vandenyno laikas (Vankuveris)',
        'America/Whitehorse' => 'Jukono laikas (Vaithorsas)',
        'America/Winnipeg' => 'Šiaurės Amerikos centro laikas (Vinipegas)',
        'America/Yakutat' => 'Aliaskos laikas (Jakutatas)',
        'Antarctica/Casey' => 'Vakarų Australijos laikas (Keisis)',
        'Antarctica/Davis' => 'Deiviso laikas (Deivisas)',
        'Antarctica/DumontDUrville' => 'Diumono d’Urvilio laikas (Diumonas d’Urvilis)',
        'Antarctica/Macquarie' => 'Rytų Australijos laikas (Makvoris)',
        'Antarctica/Mawson' => 'Mosono laikas (Mosonas)',
        'Antarctica/McMurdo' => 'Naujosios Zelandijos laikas (Makmerdas)',
        'Antarctica/Palmer' => 'Čilės laikas (Palmeris)',
        'Antarctica/Rothera' => 'Roteros laikas (Rotera)',
        'Antarctica/Syowa' => 'Siovos laikas (Siova)',
        'Antarctica/Troll' => 'Grinvičo laikas (Trolis)',
        'Antarctica/Vostok' => 'Vostoko laikas (Vostokas)',
        'Arctic/Longyearbyen' => 'Vidurio Europos laikas (Longjyrbienas)',
        'Asia/Aden' => 'Arabijos laikas (Adenas)',
        'Asia/Almaty' => 'Kazachstano laikas (Alma Ata)',
        'Asia/Amman' => 'Rytų Europos laikas (Amanas)',
        'Asia/Anadyr' => 'Kamčiatkos Petropavlovsko laikas (Anadyris)',
        'Asia/Aqtau' => 'Kazachstano laikas (Aktau)',
        'Asia/Aqtobe' => 'Kazachstano laikas (Aktiubinskas)',
        'Asia/Ashgabat' => 'Turkmėnistano laikas (Ašchabadas)',
        'Asia/Atyrau' => 'Kazachstano laikas (Atyrau)',
        'Asia/Baghdad' => 'Arabijos laikas (Bagdadas)',
        'Asia/Bahrain' => 'Arabijos laikas (Bahreinas)',
        'Asia/Baku' => 'Azerbaidžano laikas (Baku)',
        'Asia/Bangkok' => 'Indokinijos laikas (Bankokas)',
        'Asia/Barnaul' => 'Krasnojarsko laikas (Barnaulas)',
        'Asia/Beirut' => 'Rytų Europos laikas (Beirutas)',
        'Asia/Bishkek' => 'Kirgistano laikas (Biškekas)',
        'Asia/Brunei' => 'Brunėjaus Darusalamo laikas (Brunėjus)',
        'Asia/Calcutta' => 'Indijos laikas (Kolkata)',
        'Asia/Kolkata' => 'Indijos laikas (Kolkata)',
        'Asia/Chita' => 'Jakutsko laikas (Čita)',
        'Asia/Colombo' => 'Indijos laikas (Kolombas)',
        'Asia/Damascus' => 'Rytų Europos laikas (Damaskas)',
        'Asia/Dhaka' => 'Bangladešo laikas (Daka)',
        'Asia/Dili' => 'Rytų Timoro laikas (Dilis)',
        'Asia/Dubai' => 'Persijos įlankos laikas (Dubajus)',
        'Asia/Dushanbe' => 'Tadžikistano laikas (Dušanbė)',
        'Asia/Famagusta' => 'Rytų Europos laikas (Famagusta)',
        'Asia/Gaza' => 'Rytų Europos laikas (Gazos ruožas)',
        'Asia/Hebron' => 'Rytų Europos laikas (Hebronas)',
        'Asia/Hong_Kong' => 'Honkongo laikas (Honkongas)',
        'Asia/Hovd' => 'Hovdo laikas (Hovdas)',
        'Asia/Irkutsk' => 'Irkutsko laikas (Irkutskas)',
        'Asia/Jakarta' => 'Vakarų Indonezijos laikas (Džakarta)',
        'Asia/Jayapura' => 'Rytų Indonezijos laikas (Džajapura)',
        'Asia/Jerusalem' => 'Izraelio laikas (Jeruzalė)',
        'Asia/Kabul' => 'Afganistano laikas (Kabulas)',
        'Asia/Kamchatka' => 'Kamčiatkos Petropavlovsko laikas (Kamčiatka)',
        'Asia/Karachi' => 'Pakistano laikas (Karačis)',
        'Asia/Katmandu' => 'Nepalo laikas (Katmandu)',
        'Asia/Kathmandu' => 'Nepalo laikas (Katmandu)',
        'Asia/Khandyga' => 'Jakutsko laikas (Chandyga)',
        'Asia/Krasnoyarsk' => 'Krasnojarsko laikas (Krasnojarskas)',
        'Asia/Kuala_Lumpur' => 'Malaizijos laikas (Kvala Lumpūras)',
        'Asia/Kuching' => 'Malaizijos laikas (Kučingas)',
        'Asia/Kuwait' => 'Arabijos laikas (Kuveitas)',
        'Asia/Macau' => 'Kinijos laikas (Makao)',
        'Asia/Magadan' => 'Magadano laikas (Magadanas)',
        'Asia/Makassar' => 'Centrinės Indonezijos laikas (Makasaras)',
        'Asia/Manila' => 'Filipinų laikas (Manila)',
        'Asia/Muscat' => 'Persijos įlankos laikas (Maskatas)',
        'Asia/Nicosia' => 'Rytų Europos laikas (Nikosija)',
        'Asia/Novokuznetsk' => 'Krasnojarsko laikas (Novokuzneckas)',
        'Asia/Novosibirsk' => 'Krasnojarsko laikas (Novosibirskas)',
        'Asia/Omsk' => 'Omsko laikas (Omskas)',
        'Asia/Oral' => 'Kazachstano laikas (Uralskas)',
        'Asia/Phnom_Penh' => 'Indokinijos laikas (Pnompenis)',
        'Asia/Pontianak' => 'Vakarų Indonezijos laikas (Pontianakas)',
        'Asia/Pyongyang' => 'Korėjos laikas (Pchenjanas)',
        'Asia/Qatar' => 'Arabijos laikas (Kataras)',
        'Asia/Qostanay' => 'Kazachstano laikas (Kostanajus)',
        'Asia/Qyzylorda' => 'Kazachstano laikas (Kzyl-Orda)',
        'Asia/Rangoon' => 'Mianmaro laikas (Rangūnas)',
        'Asia/Yangon' => 'Mianmaro laikas (Rangūnas)',
        'Asia/Riyadh' => 'Arabijos laikas (Rijadas)',
        'Asia/Saigon' => 'Indokinijos laikas (Hošiminas)',
        'Asia/Ho_Chi_Minh' => 'Indokinijos laikas (Hošiminas)',
        'Asia/Sakhalin' => 'Magadano laikas (Sachalinas)',
        'Asia/Samarkand' => 'Uzbekistano laikas (Samarkandas)',
        'Asia/Seoul' => 'Korėjos laikas (Seulas)',
        'Asia/Shanghai' => 'Kinijos laikas (Šanchajus)',
        'Asia/Singapore' => 'Singapūro laikas (Singapūras)',
        'Asia/Srednekolymsk' => 'Magadano laikas (Srednekolymskas)',
        'Asia/Taipei' => 'Taipėjaus laikas (Taipėjus)',
        'Asia/Tashkent' => 'Uzbekistano laikas (Taškentas)',
        'Asia/Tbilisi' => 'Gruzijos laikas (Tbilisis)',
        'Asia/Tehran' => 'Irano laikas (Teheranas)',
        'Asia/Thimphu' => 'Butano laikas (Timpu)',
        'Asia/Tokyo' => 'Japonijos laikas (Tokijas)',
        'Asia/Tomsk' => 'Krasnojarsko laikas (Tomskas)',
        'Asia/Ulaanbaatar' => 'Ulan Batoro laikas (Ulan Batoras)',
        'Asia/Urumqi' => 'Laikas: Kinija (Urumči)',
        'Asia/Ust-Nera' => 'Vladivostoko laikas (Ust Nera)',
        'Asia/Vientiane' => 'Indokinijos laikas (Vientianas)',
        'Asia/Vladivostok' => 'Vladivostoko laikas (Vladivostokas)',
        'Asia/Yakutsk' => 'Jakutsko laikas (Jakutskas)',
        'Asia/Yekaterinburg' => 'Jekaterinburgo laikas (Jekaterinburgas)',
        'Asia/Yerevan' => 'Armėnijos laikas (Jerevanas)',
        'Atlantic/Azores' => 'Azorų Salų laikas (Azorai)',
        'Atlantic/Bermuda' => 'Atlanto laikas (Bermuda)',
        'Atlantic/Canary' => 'Vakarų Europos laikas (Kanarų salos)',
        'Atlantic/Cape_Verde' => 'Žaliojo Kyšulio laikas (Žaliasis Kyšulys)',
        'Atlantic/Faeroe' => 'Vakarų Europos laikas (Farerai)',
        'Atlantic/Faroe' => 'Vakarų Europos laikas (Farerai)',
        'Atlantic/Madeira' => 'Vakarų Europos laikas (Madeira)',
        'Atlantic/Reykjavik' => 'Grinvičo laikas (Reikjavikas)',
        'Atlantic/South_Georgia' => 'Pietų Džordžijos laikas (Pietų Džordžija)',
        'Atlantic/St_Helena' => 'Grinvičo laikas (Sent Helena)',
        'Atlantic/Stanley' => 'Folklando Salų laikas (Stenlis)',
        'Australia/Adelaide' => 'Centrinės Australijos laikas (Adelaidė)',
        'Australia/Brisbane' => 'Rytų Australijos laikas (Brisbanas)',
        'Australia/Broken_Hill' => 'Centrinės Australijos laikas (Broken Hilis)',
        'Australia/Darwin' => 'Centrinės Australijos laikas (Darvinas)',
        'Australia/Eucla' => 'Centrinės vakarų Australijos laikas (Jukla)',
        'Australia/Hobart' => 'Rytų Australijos laikas (Hobartas)',
        'Australia/Lindeman' => 'Rytų Australijos laikas (Lindemanas)',
        'Australia/Lord_Howe' => 'Lordo Hau laikas (Lordo Hau sala)',
        'Australia/Melbourne' => 'Rytų Australijos laikas (Melburnas)',
        'Australia/Perth' => 'Vakarų Australijos laikas (Pertas)',
        'Australia/Sydney' => 'Rytų Australijos laikas (Sidnėjus)',
        'Etc/GMT' => 'Grinvičo laikas',
        'Etc/UTC' => 'pasaulio suderintasis laikas',
        'Europe/Amsterdam' => 'Vidurio Europos laikas (Amsterdamas)',
        'Europe/Andorra' => 'Vidurio Europos laikas (Andora)',
        'Europe/Astrakhan' => 'Samaros laikas (Astrachanė)',
        'Europe/Athens' => 'Rytų Europos laikas (Atėnai)',
        'Europe/Belgrade' => 'Vidurio Europos laikas (Belgradas)',
        'Europe/Berlin' => 'Vidurio Europos laikas (Berlynas)',
        'Europe/Bratislava' => 'Vidurio Europos laikas (Bratislava)',
        'Europe/Brussels' => 'Vidurio Europos laikas (Briuselis)',
        'Europe/Bucharest' => 'Rytų Europos laikas (Bukareštas)',
        'Europe/Budapest' => 'Vidurio Europos laikas (Budapeštas)',
        'Europe/Busingen' => 'Vidurio Europos laikas (Biusingenas)',
        'Europe/Chisinau' => 'Rytų Europos laikas (Kišiniovas)',
        'Europe/Copenhagen' => 'Vidurio Europos laikas (Kopenhaga)',
        'Europe/Dublin' => 'Grinvičo laikas (Dublinas)',
        'Europe/Gibraltar' => 'Vidurio Europos laikas (Gibraltaras)',
        'Europe/Guernsey' => 'Grinvičo laikas (Gernsis)',
        'Europe/Helsinki' => 'Rytų Europos laikas (Helsinkis)',
        'Europe/Isle_of_Man' => 'Grinvičo laikas (Meno sala)',
        'Europe/Istanbul' => 'Turkijos laikas (Stambulas)',
        'Europe/Jersey' => 'Grinvičo laikas (Džersis)',
        'Europe/Kaliningrad' => 'Rytų Europos laikas (Kaliningradas)',
        'Europe/Kiev' => 'Rytų Europos laikas (Kijevas)',
        'Europe/Kyiv' => 'Rytų Europos laikas (Kijevas)',
        'Europe/Kirov' => 'Maskvos laikas (Kirovas)',
        'Europe/Lisbon' => 'Vakarų Europos laikas (Lisabona)',
        'Europe/Ljubljana' => 'Vidurio Europos laikas (Liubliana)',
        'Europe/London' => 'Grinvičo laikas (Londonas)',
        'Europe/Luxembourg' => 'Vidurio Europos laikas (Liuksemburgas)',
        'Europe/Madrid' => 'Vidurio Europos laikas (Madridas)',
        'Europe/Malta' => 'Vidurio Europos laikas (Malta)',
        'Europe/Mariehamn' => 'Rytų Europos laikas (Marianhamina)',
        'Europe/Minsk' => 'Maskvos laikas (Minskas)',
        'Europe/Monaco' => 'Vidurio Europos laikas (Monakas)',
        'Europe/Moscow' => 'Maskvos laikas (Maskva)',
        'Europe/Oslo' => 'Vidurio Europos laikas (Oslas)',
        'Europe/Paris' => 'Vidurio Europos laikas (Paryžius)',
        'Europe/Podgorica' => 'Vidurio Europos laikas (Podgorica)',
        'Europe/Prague' => 'Vidurio Europos laikas (Praha)',
        'Europe/Riga' => 'Rytų Europos laikas (Ryga)',
        'Europe/Rome' => 'Vidurio Europos laikas (Roma)',
        'Europe/Samara' => 'Samaros laikas (Samara)',
        'Europe/San_Marino' => 'Vidurio Europos laikas (San Marinas)',
        'Europe/Sarajevo' => 'Vidurio Europos laikas (Sarajevas)',
        'Europe/Saratov' => 'Samaros laikas (Saratovas)',
        'Europe/Simferopol' => 'Maskvos laikas (Simferopolis)',
        'Europe/Skopje' => 'Vidurio Europos laikas (Skopjė)',
        'Europe/Sofia' => 'Rytų Europos laikas (Sofija)',
        'Europe/Stockholm' => 'Vidurio Europos laikas (Stokholmas)',
        'Europe/Tallinn' => 'Rytų Europos laikas (Talinas)',
        'Europe/Tirane' => 'Vidurio Europos laikas (Tirana)',
        'Europe/Ulyanovsk' => 'Samaros laikas (Uljanovskas)',
        'Europe/Vaduz' => 'Vidurio Europos laikas (Vaducas)',
        'Europe/Vatican' => 'Vidurio Europos laikas (Vatikanas)',
        'Europe/Vienna' => 'Vidurio Europos laikas (Viena)',
        'Europe/Vilnius' => 'Rytų Europos laikas (Vilnius)',
        'Europe/Volgograd' => 'Maskvos laikas (Volgogradas)',
        'Europe/Warsaw' => 'Vidurio Europos laikas (Varšuva)',
        'Europe/Zagreb' => 'Vidurio Europos laikas (Zagrebas)',
        'Europe/Zurich' => 'Vidurio Europos laikas (Ciurichas)',
        'Indian/Antananarivo' => 'Rytų Afrikos laikas (Antananaryvas)',
        'Indian/Chagos' => 'Indijos vandenyno laikas (Čagosas)',
        'Indian/Christmas' => 'Kalėdų Salos laikas (Kalėdų Sala)',
        'Indian/Cocos' => 'Kokosų Salų laikas (Kokosų sala)',
        'Indian/Comoro' => 'Rytų Afrikos laikas (Komoras)',
        'Indian/Kerguelen' => 'Pietų Prancūzijos ir antarktinis laikas (Kergelenas)',
        'Indian/Mahe' => 'Seišelių laikas (Mahė)',
        'Indian/Maldives' => 'Maldyvų laikas (Maldyvai)',
        'Indian/Mauritius' => 'Mauricijaus laikas (Mauricijus)',
        'Indian/Mayotte' => 'Rytų Afrikos laikas (Majotas)',
        'Indian/Reunion' => 'Reunjono laikas (Reunjonas)',
        'Pacific/Apia' => 'Apijos laikas (Apija)',
        'Pacific/Auckland' => 'Naujosios Zelandijos laikas (Oklandas)',
        'Pacific/Bougainville' => 'Papua Naujosios Gvinėjos laikas (Bugenvilis)',
        'Pacific/Chatham' => 'Čatamo laikas (Čatamas)',
        'Pacific/Easter' => 'Velykų Salos laikas (Velykų sala)',
        'Pacific/Efate' => 'Vanuatu laikas (Efatė)',
        'Pacific/Enderbury' => 'Fenikso Salų laikas (Kantono sala)',
        'Pacific/Kanton' => 'Fenikso Salų laikas (Kantono sala)',
        'Pacific/Fakaofo' => 'Tokelau laikas (Fakaofas)',
        'Pacific/Fiji' => 'Fidžio laikas (Fidžis)',
        'Pacific/Funafuti' => 'Tuvalu laikas (Funafutis)',
        'Pacific/Galapagos' => 'Galapagų laikas (Galapagai)',
        'Pacific/Gambier' => 'Gambyro laikas (Gambyras)',
        'Pacific/Guadalcanal' => 'Saliamono Salų laikas (Gvadalkanalis)',
        'Pacific/Guam' => 'Čamoro laikas (Guamas)',
        'Pacific/Honolulu' => 'Havajų–Aleutų žiemos laikas (Honolulu)',
        'Pacific/Kiritimati' => 'Laino Salų laikas (Kiritimatis)',
        'Pacific/Kosrae' => 'Kosrajė laikas',
        'Pacific/Kwajalein' => 'Maršalo Salų laikas (Kvadžaleinas)',
        'Pacific/Majuro' => 'Maršalo Salų laikas (Madžūras)',
        'Pacific/Marquesas' => 'Markizo Salų laikas (Markizo salos)',
        'Pacific/Midway' => 'Samoa laikas (Midvėjus)',
        'Pacific/Nauru' => 'Nauru laikas',
        'Pacific/Niue' => 'Niujė laikas',
        'Pacific/Norfolk' => 'Norfolko Salų laikas (Norfolkas)',
        'Pacific/Noumea' => 'Naujosios Kaledonijos laikas (Numėja)',
        'Pacific/Pago_Pago' => 'Samoa laikas (Pago Pagas)',
        'Pacific/Palau' => 'Palau laikas',
        'Pacific/Pitcairn' => 'Pitkerno laikas (Pitkerno sala)',
        'Pacific/Ponape' => 'Ponapės laikas',
        'Pacific/Pohnpei' => 'Ponapės laikas',
        'Pacific/Port_Moresby' => 'Papua Naujosios Gvinėjos laikas (Port Morsbis)',
        'Pacific/Rarotonga' => 'Kuko Salų laikas (Rarotonga)',
        'Pacific/Saipan' => 'Čamoro laikas (Saipanas)',
        'Pacific/Tahiti' => 'Tahičio laikas (Taitis)',
        'Pacific/Tarawa' => 'Gilberto Salų laikas (Tarava)',
        'Pacific/Tongatapu' => 'Tongos laikas (Tongatapu)',
        'Pacific/Truk' => 'Čuko laikas (Čukas)',
        'Pacific/Chuuk' => 'Čuko laikas (Čukas)',
        'Pacific/Wake' => 'Veiko Salos laikas (Veiko sala)',
        'Pacific/Wallis' => 'Voliso ir Futūnos laikas (Volisas)',
    ],
    'Meta' => [
        'HourFormatNeg' => '−%02d:%02d',
    ],
];
