!function(){"use strict";var e={8725:function(){window.readyHandlers=[],window.ready=function(e){window.readyHandlers.push(e),handleState()},window.handleState=function(){if("interactive"===document.readyState||"complete"===document.readyState)for(;window.readyHandlers.length>0;)window.readyHandlers.shift()()},document.onreadystatechange=window.handleState},1412:function(){ready(function(){var e=document.getElementById("slowPostMessage");if(e){var t=document.getElementById("page-title"),n=e.dataset&&e.dataset.slowPostDelay||e.getAttribute("data-slow-post-delay"),o=parseInt(n,10);(!Number.isFinite(o)||o<0)&&(o=3e4),setTimeout(function(){e.classList.remove("hidden"),t&&t.classList.remove("hidden")},o)}var r=document.getElementById("postLoginSubmitButton");r&&setTimeout(function(){r.click()},0)})}},t={};function n(o){var r=t[o];if(void 0!==r)return r.exports;var a=t[o]={exports:{}};return e[o](a,a.exports,n),a.exports}n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,{a:t}),t},n.d=function(e,t){for(var o in t)n.o(t,o)&&!n.o(e,o)&&Object.defineProperty(e,o,{enumerable:!0,get:t[o]})},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n(8725),n(1412)}();
//# sourceMappingURL=post.js.map