<?php

return [
    'Names' => [
        'ARS' => [
            'ARS',
            'peso argentin',
        ],
        'AUD' => [
            '$ AU',
            'dollar australien',
        ],
        'AZN' => [
            'AZN',
            'manat azerbaïdjanais',
        ],
        'BMD' => [
            'BMD',
            'dollar bermudien',
        ],
        'BND' => [
            'BND',
            'dollar brunéien',
        ],
        'BZD' => [
            'BZD',
            'dollar bélizéen',
        ],
        'CAD' => [
            '$',
            'dollar canadien',
        ],
        'CLP' => [
            'CLP',
            'peso chilien',
        ],
        'CNY' => [
            'CN¥',
            'yuan renminbi chinois',
        ],
        'COP' => [
            'COP',
            'peso colombien',
        ],
        'CVE' => [
            'CVE',
            'escudo cap-verdien',
        ],
        'FJD' => [
            'FJD',
            'dollar fidjien',
        ],
        'FKP' => [
            'FKP',
            'livre des îles Malouines',
        ],
        'GBP' => [
            '£',
            'livre sterling',
        ],
        'GIP' => [
            'GIP',
            'livre de Gibraltar',
        ],
        'HKD' => [
            '$ HK',
            'dollar de Hong Kong',
        ],
        'ILS' => [
            'ILS',
            'nouveau shekel israélien',
        ],
        'INR' => [
            'INR',
            'roupie indienne',
        ],
        'IRR' => [
            'IRR',
            'rial iranien',
        ],
        'JPY' => [
            '¥',
            'yen japonais',
        ],
        'KRW' => [
            'KRW',
            'won sud-coréen',
        ],
        'LBP' => [
            'LBP',
            'livre libanaise',
        ],
        'MXN' => [
            'MXN',
            'peso mexicain',
        ],
        'NAD' => [
            'NAD',
            'dollar namibien',
        ],
        'NZD' => [
            '$ NZ',
            'dollar néo-zélandais',
        ],
        'OMR' => [
            'OMR',
            'rial omanais',
        ],
        'PEN' => [
            'PEN',
            'nouveau sol péruvien',
        ],
        'PGK' => [
            'PGK',
            'kina papou-néo-guinéen',
        ],
        'QAR' => [
            'QAR',
            'riyal du Qatar',
        ],
        'SAR' => [
            'SAR',
            'rial saoudien',
        ],
        'SBD' => [
            'SBD',
            'dollar des îles Salomon',
        ],
        'SGD' => [
            '$ SG',
            'dollar de Singapour',
        ],
        'SRD' => [
            'SRD',
            'dollar du Suriname',
        ],
        'TOP' => [
            'TOP',
            'pa’anga',
        ],
        'TTD' => [
            'TTD',
            'dollar de Trinité-et-Tobago',
        ],
        'USD' => [
            '$ US',
            'dollar des États-Unis',
        ],
        'UYU' => [
            'UYU',
            'peso uruguayen',
        ],
        'VND' => [
            'VND',
            'dông vietnamien',
        ],
        'VUV' => [
            'VUV',
            'vatu',
        ],
        'WST' => [
            'WST',
            'tala',
        ],
        'XAF' => [
            'XAF',
            'franc CFA (BEAC)',
        ],
        'XOF' => [
            'XOF',
            'franc CFA (BCEAO)',
        ],
        'XPF' => [
            'XPF',
            'franc CFP',
        ],
        'YER' => [
            'YER',
            'rial yéménite',
        ],
    ],
];
