<?php

return [
    'Names' => [
        'Adlm' => 'أدلم',
        'Arab' => 'العربية',
        'Aran' => 'نستعليق',
        'Armn' => 'الأرمينية',
        'Bali' => 'البالية',
        'Batk' => 'الباتاك',
        'Beng' => 'البنغالية',
        'Blis' => 'رموز بليس',
        'Bopo' => 'البوبوموفو',
        'Brah' => 'الهندوسية',
        'Brai' => 'البرايل',
        'Bugi' => 'البجينيز',
        'Buhd' => 'البهيدية',
        'Cakm' => 'شاكما',
        'Cans' => 'مقاطع كندية أصلية موحدة',
        'Cari' => 'الكارية',
        'Cham' => 'التشامية',
        'Cher' => 'الشيروكي',
        'Cirt' => 'السيرث',
        'Copt' => 'القبطية',
        'Cprt' => 'القبرصية',
        'Cyrl' => 'السيريلية',
        'Cyrs' => 'السيريلية السلافية الكنسية القديمة',
        'Deva' => 'الديفاناجاري',
        'Dsrt' => 'الديسيريت',
        'Egyd' => 'الديموطيقية',
        'Egyh' => 'الهيراطيقية',
        'Egyp' => 'الهيروغليفية',
        'Ethi' => 'الأثيوبية',
        'Geok' => 'الأبجدية الجورجية - أسومتافرلي و نسخري',
        'Geor' => 'الجورجية',
        'Glag' => 'الجلاجوليتيك',
        'Goth' => 'القوطية',
        'Grek' => 'اليونانية',
        'Gujr' => 'التاغجراتية',
        'Guru' => 'الجرمخي',
        'Hanb' => 'هانب',
        'Hang' => 'الهانغول',
        'Hani' => 'الهان',
        'Hano' => 'الهانونو',
        'Hans' => 'المبسطة',
        'Hant' => 'التقليدية',
        'Hebr' => 'العبرية',
        'Hira' => 'الهيراجانا',
        'Hmng' => 'الباهوه همونج',
        'Hrkt' => 'أبجدية مقطعية يابانية',
        'Hung' => 'المجرية القديمة',
        'Inds' => 'اندس - هارابان',
        'Ital' => 'الإيطالية القديمة',
        'Jamo' => 'جامو',
        'Java' => 'الجاوية',
        'Jpan' => 'اليابانية',
        'Kali' => 'الكياه لى',
        'Kana' => 'الكتكانا',
        'Khar' => 'الخاروشتى',
        'Khmr' => 'الخميرية',
        'Knda' => 'الكانادا',
        'Kore' => 'الكورية',
        'Lana' => 'الانا',
        'Laoo' => 'اللاو',
        'Latf' => 'اللاتينية - متغير فراكتر',
        'Latg' => 'اللاتينية - متغير غيلى',
        'Latn' => 'اللاتينية',
        'Lepc' => 'الليبتشا - رونج',
        'Limb' => 'الليمبو',
        'Lina' => 'الخطية أ',
        'Linb' => 'الخطية ب',
        'Lyci' => 'الليسية',
        'Lydi' => 'الليدية',
        'Mand' => 'المانداينية',
        'Maya' => 'المايا الهيروغليفية',
        'Mero' => 'الميرويتيك',
        'Mlym' => 'الماليالام',
        'Mong' => 'المغولية',
        'Moon' => 'مون',
        'Mtei' => 'ميتي ماييك',
        'Mymr' => 'الميانمار',
        'Narb' => 'العربية الشمالية القديمة',
        'Nkoo' => 'أنكو',
        'Ogam' => 'الأوجهام',
        'Olck' => 'أول تشيكي',
        'Orkh' => 'الأورخون',
        'Orya' => 'الأوريا',
        'Osma' => 'الأوسمانيا',
        'Perm' => 'البيرميكية القديمة',
        'Phag' => 'الفاجسبا',
        'Phnx' => 'الفينيقية',
        'Plrd' => 'الصوتيات الجماء',
        'Qaag' => 'زوجيي',
        'Rohg' => 'الحنيفي',
        'Roro' => 'رنجورنجو',
        'Runr' => 'الروني',
        'Sara' => 'الساراتي',
        'Sarb' => 'العربية الجنوبية القديمة',
        'Shaw' => 'الشواني',
        'Sinh' => 'السينهالا',
        'Sund' => 'السوندانية',
        'Sylo' => 'السيلوتي ناغري',
        'Syrc' => 'السريانية',
        'Syre' => 'السريانية الأسترنجيلية',
        'Syrj' => 'السريانية الغربية',
        'Syrn' => 'السريانية الشرقية',
        'Tagb' => 'التاجبانوا',
        'Tale' => 'التاي لي',
        'Talu' => 'التاى لى الجديد',
        'Taml' => 'التاميلية',
        'Telu' => 'التيلجو',
        'Teng' => 'التينجوار',
        'Tfng' => 'التيفيناغ',
        'Tglg' => 'التغالوغية',
        'Thaa' => 'الثعنة',
        'Thai' => 'التايلاندية',
        'Tibt' => 'التبتية',
        'Ugar' => 'الأجاريتيكية',
        'Vaii' => 'الفاي',
        'Visp' => 'الكلام المرئي',
        'Xpeo' => 'الفارسية القديمة',
        'Xsux' => 'الكتابة المسمارية الأكدية السومرية',
        'Yiii' => 'اليي',
        'Zinh' => 'الموروث',
        'Zmth' => 'تدوين رياضي',
        'Zsye' => 'إيموجي',
        'Zsym' => 'رموز',
        'Zxxx' => 'غير مكتوب',
        'Zyyy' => 'عام',
    ],
];
