<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'گرين وچ مين ٽائيم (ابي جان)',
        'Africa/Accra' => 'گرين وچ مين ٽائيم (ايڪرا)',
        'Africa/Addis_Ababa' => 'اوڀر آفريڪا جو وقت (ايڊيس اببا)',
        'Africa/Algiers' => 'مرڪزي يورپي وقت (الجيرز)',
        'Africa/Asmera' => 'اوڀر آفريڪا جو وقت (ازمارا)',
        'Africa/Asmara' => 'اوڀر آفريڪا جو وقت (ازمارا)',
        'Africa/Bamako' => 'گرين وچ مين ٽائيم (باماڪو)',
        'Africa/Bangui' => 'اولهه آفريقا جو وقت (بنگي)',
        'Africa/Banjul' => 'گرين وچ مين ٽائيم (بينجال)',
        'Africa/Bissau' => 'گرين وچ مين ٽائيم (بسائو)',
        'Africa/Blantyre' => 'مرڪزي آفريقا جو وقت (بلنٽائر)',
        'Africa/Brazzaville' => 'اولهه آفريقا جو وقت (برازاويل)',
        'Africa/Bujumbura' => 'مرڪزي آفريقا جو وقت (بوجمبورا)',
        'Africa/Cairo' => 'مشرقي يورپي وقت (قائرا)',
        'Africa/Casablanca' => 'اولهه يورپي وقت (ڪاسابلانڪا)',
        'Africa/Ceuta' => 'مرڪزي يورپي وقت (سيوٽا)',
        'Africa/Conakry' => 'گرين وچ مين ٽائيم (ڪوناڪري)',
        'Africa/Dakar' => 'گرين وچ مين ٽائيم (ڊاڪار)',
        'Africa/Dar_es_Salaam' => 'اوڀر آفريڪا جو وقت (دارالسلام)',
        'Africa/Djibouti' => 'اوڀر آفريڪا جو وقت (جبوتي)',
        'Africa/Douala' => 'اولهه آفريقا جو وقت (دوالا)',
        'Africa/El_Aaiun' => 'اولهه يورپي وقت (ال ايون)',
        'Africa/Freetown' => 'گرين وچ مين ٽائيم (فري ٽائون)',
        'Africa/Gaborone' => 'مرڪزي آفريقا جو وقت (گيبورون)',
        'Africa/Harare' => 'مرڪزي آفريقا جو وقت (هراري)',
        'Africa/Johannesburg' => 'ڏکڻ آفريڪا جو معياري وقت (جوهانسبرگ)',
        'Africa/Juba' => 'مرڪزي آفريقا جو وقت (جوبا)',
        'Africa/Kampala' => 'اوڀر آفريڪا جو وقت (ڪمپالا)',
        'Africa/Khartoum' => 'مرڪزي آفريقا جو وقت (خرطوم)',
        'Africa/Kigali' => 'مرڪزي آفريقا جو وقت (ڪيگالي)',
        'Africa/Kinshasa' => 'اولهه آفريقا جو وقت (ڪنشاسا)',
        'Africa/Lagos' => 'اولهه آفريقا جو وقت (لاگوس)',
        'Africa/Libreville' => 'اولهه آفريقا جو وقت (لیبرویلی)',
        'Africa/Lome' => 'گرين وچ مين ٽائيم (لوم)',
        'Africa/Luanda' => 'اولهه آفريقا جو وقت (لوانڊا)',
        'Africa/Lubumbashi' => 'مرڪزي آفريقا جو وقت (لوبمباشی)',
        'Africa/Lusaka' => 'مرڪزي آفريقا جو وقت (لوساڪا)',
        'Africa/Malabo' => 'اولهه آفريقا جو وقت (ملابو)',
        'Africa/Maputo' => 'مرڪزي آفريقا جو وقت (ماپوتو)',
        'Africa/Maseru' => 'ڏکڻ آفريڪا جو معياري وقت (ماسيرو)',
        'Africa/Mbabane' => 'ڏکڻ آفريڪا جو معياري وقت (مبابين)',
        'Africa/Mogadishu' => 'اوڀر آفريڪا جو وقت (موغادیشو)',
        'Africa/Monrovia' => 'گرين وچ مين ٽائيم (مونروویا)',
        'Africa/Nairobi' => 'اوڀر آفريڪا جو وقت (نيروبي)',
        'Africa/Ndjamena' => 'اولهه آفريقا جو وقت (نجامينا)',
        'Africa/Niamey' => 'اولهه آفريقا جو وقت (نيامي)',
        'Africa/Nouakchott' => 'گرين وچ مين ٽائيم (نواڪشوط)',
        'Africa/Ouagadougou' => 'گرين وچ مين ٽائيم (آئوگو ڊائوگو)',
        'Africa/Porto-Novo' => 'اولهه آفريقا جو وقت (پورٽو نوو)',
        'Africa/Sao_Tome' => 'گرين وچ مين ٽائيم (سائو ٽوم)',
        'Africa/Tripoli' => 'مشرقي يورپي وقت (ٽرپولي)',
        'Africa/Tunis' => 'مرڪزي يورپي وقت (تيونس)',
        'Africa/Windhoek' => 'مرڪزي آفريقا جو وقت (ونڊهوڪ)',
        'America/Adak' => 'هوائي اليوٽين جو وقت (ادڪ)',
        'America/Anchorage' => 'الاسڪا جو وقت (اينڪريج)',
        'America/Anguilla' => 'ايٽلانٽڪ جو وقت (انگويلا)',
        'America/Antigua' => 'ايٽلانٽڪ جو وقت (اينٽيگوا)',
        'America/Araguaina' => 'بريسيليائي وقت (اراگویانا)',
        'America/Argentina/La_Rioja' => 'ارجنٽينا جو وقت (لا ریئوجا)',
        'America/Argentina/Rio_Gallegos' => 'ارجنٽينا جو وقت (ریو گالیگوس)',
        'America/Argentina/Salta' => 'ارجنٽينا جو وقت (سالٽا)',
        'America/Argentina/San_Juan' => 'ارجنٽينا جو وقت (سان جوآن)',
        'America/Argentina/San_Luis' => 'ارجنٽينا جو وقت (سان لوئیس)',
        'America/Argentina/Tucuman' => 'ارجنٽينا جو وقت (ٽوڪومين)',
        'America/Argentina/Ushuaia' => 'ارجنٽينا جو وقت (اوشوآئیا)',
        'America/Aruba' => 'ايٽلانٽڪ جو وقت (اروبا)',
        'America/Asuncion' => 'پيراگوئي جو وقت (اسانسیون)',
        'America/Bahia' => 'بريسيليائي وقت (باحيه)',
        'America/Bahia_Banderas' => 'مرڪزي وقت (باهیا بیندراس)',
        'America/Barbados' => 'ايٽلانٽڪ جو وقت (بارباڊوس)',
        'America/Belem' => 'بريسيليائي وقت (بیلم)',
        'America/Belize' => 'مرڪزي وقت (بیلیز)',
        'America/Blanc-Sablon' => 'ايٽلانٽڪ جو وقت (بلانڪ سبلون)',
        'America/Boa_Vista' => 'ايميزون جو وقت (بائو وستا)',
        'America/Bogota' => 'ڪولمبيا جو وقت (بگوٽا)',
        'America/Boise' => 'پهاڙي وقت (بوئس)',
        'America/Buenos_Aires' => 'ارجنٽينا جو وقت (بيونوس ايئرس)',
        'America/Argentina/Buenos_Aires' => 'ارجنٽينا جو وقت (بيونوس ايئرس)',
        'America/Cambridge_Bay' => 'پهاڙي وقت (ڪيمبرج بي)',
        'America/Campo_Grande' => 'ايميزون جو وقت (ڪيمپو گرانڊي)',
        'America/Cancun' => 'مشرقي وقت (ڪانڪون)',
        'America/Caracas' => 'وينزويلا جو وقت (ڪراڪس)',
        'America/Catamarca' => 'ارجنٽينا جو وقت (ڪيٽا مارڪا)',
        'America/Argentina/Catamarca' => 'ارجنٽينا جو وقت (ڪيٽا مارڪا)',
        'America/Cayenne' => 'فرانسيسي گيانا جو وقت (ڪائين)',
        'America/Cayman' => 'مشرقي وقت (سيامن)',
        'America/Chicago' => 'مرڪزي وقت (شڪاگو)',
        'America/Chihuahua' => 'مرڪزي وقت (چي هوا هوا)',
        'America/Ciudad_Juarez' => 'پهاڙي وقت (سوڊيڊ جوريز)',
        'America/Coral_Harbour' => 'مشرقي وقت (اٽيڪوڪن)',
        'America/Atikokan' => 'مشرقي وقت (اٽيڪوڪن)',
        'America/Cordoba' => 'ارجنٽينا جو وقت (ڪارڊوبا)',
        'America/Argentina/Cordoba' => 'ارجنٽينا جو وقت (ڪارڊوبا)',
        'America/Costa_Rica' => 'مرڪزي وقت (ڪوسٽا ريڪا)',
        'America/Coyhaique' => 'چلي جو وقت (ڪوئيئيڪي)',
        'America/Creston' => 'پهاڙي وقت (ڪريسٽن)',
        'America/Cuiaba' => 'ايميزون جو وقت (ڪوئيابا)',
        'America/Curacao' => 'ايٽلانٽڪ جو وقت (ڪيوراسائو)',
        'America/Danmarkshavn' => 'گرين وچ مين ٽائيم (ڊينمارڪ شون)',
        'America/Dawson' => 'يڪون جو وقت (ڊاوسن)',
        'America/Dawson_Creek' => 'پهاڙي وقت (ڊاوسن ڪريڪ)',
        'America/Denver' => 'پهاڙي وقت (ڊينور)',
        'America/Detroit' => 'مشرقي وقت (ڊيٽرائيٽ)',
        'America/Dominica' => 'ايٽلانٽڪ جو وقت (ڊومينيڪا)',
        'America/Edmonton' => 'پهاڙي وقت (ايڊمونٽن)',
        'America/Eirunepe' => 'برازيل وقت (ايرونيپ)',
        'America/El_Salvador' => 'مرڪزي وقت (ايل سلواڊور)',
        'America/Fort_Nelson' => 'پهاڙي وقت (فورٽ نيلسن)',
        'America/Fortaleza' => 'بريسيليائي وقت (فورٽاليزا)',
        'America/Glace_Bay' => 'ايٽلانٽڪ جو وقت (گليس بي)',
        'America/Godthab' => 'گرين لينڊ وقت (نيوڪ)',
        'America/Nuuk' => 'گرين لينڊ وقت (نيوڪ)',
        'America/Goose_Bay' => 'ايٽلانٽڪ جو وقت (گوز بي)',
        'America/Grand_Turk' => 'مشرقي وقت (گرانڊ ترڪ)',
        'America/Grenada' => 'ايٽلانٽڪ جو وقت (گريناڊا)',
        'America/Guadeloupe' => 'ايٽلانٽڪ جو وقت (گواڊيلوپ)',
        'America/Guatemala' => 'مرڪزي وقت (گوئٽي مالا)',
        'America/Guayaquil' => 'ايڪواڊور جو وقت (گواياڪيل)',
        'America/Guyana' => 'گيانائي وقت',
        'America/Halifax' => 'ايٽلانٽڪ جو وقت (هيلي فيڪس)',
        'America/Havana' => 'ڪيوبا جو وقت (هوانا)',
        'America/Hermosillo' => 'ميڪسيڪن پيسيفڪ وقت (هرموسلو)',
        'America/Indiana/Knox' => 'مرڪزي وقت (ناڪس، انڊيانا)',
        'America/Indiana/Marengo' => 'مشرقي وقت (مرينگو، انڊيانا)',
        'America/Indiana/Petersburg' => 'مشرقي وقت (پيٽرسبرگ، انڊيانا)',
        'America/Indiana/Tell_City' => 'مرڪزي وقت (ٽيل سٽي، انڊيانا)',
        'America/Indiana/Vevay' => 'مشرقي وقت (ويوي، انڊيانا)',
        'America/Indiana/Vincennes' => 'مشرقي وقت (ونسینیز، انڊیانا)',
        'America/Indiana/Winamac' => 'مشرقي وقت (ويناميڪ، انڊيانا)',
        'America/Indianapolis' => 'مشرقي وقت (انڊيانا پولس)',
        'America/Indiana/Indianapolis' => 'مشرقي وقت (انڊيانا پولس)',
        'America/Inuvik' => 'پهاڙي وقت (انووڪ)',
        'America/Iqaluit' => 'مشرقي وقت (اڪالوئٽ)',
        'America/Jamaica' => 'مشرقي وقت (جمائڪا)',
        'America/Jujuy' => 'ارجنٽينا جو وقت (ڪوڪوئي)',
        'America/Argentina/Jujuy' => 'ارجنٽينا جو وقت (ڪوڪوئي)',
        'America/Juneau' => 'الاسڪا جو وقت (جونئو)',
        'America/Kentucky/Monticello' => 'مشرقي وقت (مونٽيسيلو، ڪينٽڪي)',
        'America/Kralendijk' => 'ايٽلانٽڪ جو وقت (ڪرالينڊڪ)',
        'America/La_Paz' => 'بولويائي وقت (لا پز)',
        'America/Lima' => 'پيرو جو وقت (ليما)',
        'America/Los_Angeles' => 'پيسيفڪ وقت (لاس اينجلس)',
        'America/Louisville' => 'مشرقي وقت (لوئي ويل)',
        'America/Kentucky/Louisville' => 'مشرقي وقت (لوئي ويل)',
        'America/Lower_Princes' => 'ايٽلانٽڪ جو وقت (لوئر پرنسز ڪوارٽر)',
        'America/Maceio' => 'بريسيليائي وقت (میسیئو)',
        'America/Managua' => 'مرڪزي وقت (ماناگوا)',
        'America/Manaus' => 'ايميزون جو وقت (منائوس)',
        'America/Marigot' => 'ايٽلانٽڪ جو وقت (ميريگوٽ)',
        'America/Martinique' => 'ايٽلانٽڪ جو وقت (مارٽينڪ)',
        'America/Matamoros' => 'مرڪزي وقت (متاموروس)',
        'America/Mazatlan' => 'ميڪسيڪن پيسيفڪ وقت (مزاٽلان)',
        'America/Mendoza' => 'ارجنٽينا جو وقت (مينڊوزا)',
        'America/Argentina/Mendoza' => 'ارجنٽينا جو وقت (مينڊوزا)',
        'America/Menominee' => 'مرڪزي وقت (مینومیني)',
        'America/Merida' => 'مرڪزي وقت (ميريڊا)',
        'America/Metlakatla' => 'الاسڪا جو وقت (ميٽلاڪاٽالا)',
        'America/Mexico_City' => 'مرڪزي وقت (ميڪسيڪو شهر)',
        'America/Miquelon' => 'سينٽ پيئر ۽ ميڪلون جو وقت (میڪوئیلون)',
        'America/Moncton' => 'ايٽلانٽڪ جو وقت (مانڪٽن)',
        'America/Monterrey' => 'مرڪزي وقت (مانٽيري)',
        'America/Montevideo' => 'يوروگائي جو وقت (مونٽي ويڊيو)',
        'America/Montserrat' => 'ايٽلانٽڪ جو وقت (مانٽسريٽ)',
        'America/Nassau' => 'مشرقي وقت (ناسائو)',
        'America/New_York' => 'مشرقي وقت (نيويارڪ)',
        'America/Nome' => 'الاسڪا جو وقت (نوم)',
        'America/Noronha' => 'فرنانڊو دي نورونها جو وقت (نورانهيا)',
        'America/North_Dakota/Beulah' => 'مرڪزي وقت (بيولاه، اتر ڊڪوٽا)',
        'America/North_Dakota/Center' => 'مرڪزي وقت (سينٽر، اتر ڊڪوٽا)',
        'America/North_Dakota/New_Salem' => 'مرڪزي وقت (نيو سيلم، اتر ڊڪوٽا)',
        'America/Ojinaga' => 'مرڪزي وقت (اوڪيناگا)',
        'America/Panama' => 'مشرقي وقت (پناما)',
        'America/Paramaribo' => 'سوري نام جو وقت (پيراميريبو)',
        'America/Phoenix' => 'پهاڙي وقت (فونيڪس)',
        'America/Port-au-Prince' => 'مشرقي وقت (پورٽ او پرنس)',
        'America/Port_of_Spain' => 'ايٽلانٽڪ جو وقت (اسپين جو ٻيٽ)',
        'America/Porto_Velho' => 'ايميزون جو وقت (پورٽو ويلهو)',
        'America/Puerto_Rico' => 'ايٽلانٽڪ جو وقت (پورٽو ريڪو)',
        'America/Punta_Arenas' => 'چلي جو وقت (پنٽا اريناس)',
        'America/Rankin_Inlet' => 'مرڪزي وقت (رينڪن انليٽ)',
        'America/Recife' => 'بريسيليائي وقت (هيسيفي)',
        'America/Regina' => 'مرڪزي وقت (ریجینا)',
        'America/Resolute' => 'مرڪزي وقت (ريزوليوٽ)',
        'America/Rio_Branco' => 'برازيل وقت (ريو برانڪو)',
        'America/Santarem' => 'بريسيليائي وقت (سنٽاريم)',
        'America/Santiago' => 'چلي جو وقت (سينٽياگو)',
        'America/Santo_Domingo' => 'ايٽلانٽڪ جو وقت (سينٽو ڊومينگو)',
        'America/Sao_Paulo' => 'بريسيليائي وقت (سائو پولو)',
        'America/Scoresbysund' => 'گرين لينڊ وقت (اٽوڪورٽومائٽ)',
        'America/Sitka' => 'الاسڪا جو وقت (سٽڪا)',
        'America/St_Barthelemy' => 'ايٽلانٽڪ جو وقت (سينٽ برٿليمي)',
        'America/St_Johns' => 'نيو فائونڊ لينڊ جو وقت (سينٽ جانز)',
        'America/St_Kitts' => 'ايٽلانٽڪ جو وقت (سينٽ ڪٽس)',
        'America/St_Lucia' => 'ايٽلانٽڪ جو وقت (سينٽ لوسيا)',
        'America/St_Thomas' => 'ايٽلانٽڪ جو وقت (سينٽ ٿامس)',
        'America/St_Vincent' => 'ايٽلانٽڪ جو وقت (سينٽ ونسينٽ)',
        'America/Swift_Current' => 'مرڪزي وقت (سوئفٽ ڪرنٽ)',
        'America/Tegucigalpa' => 'مرڪزي وقت (ٽيگوسيگلپا)',
        'America/Thule' => 'ايٽلانٽڪ جو وقت (ٿولي)',
        'America/Tijuana' => 'پيسيفڪ وقت (تيجوانا)',
        'America/Toronto' => 'مشرقي وقت (ٽورنٽو)',
        'America/Tortola' => 'ايٽلانٽڪ جو وقت (ٽورٽولا)',
        'America/Vancouver' => 'پيسيفڪ وقت (وينڪوور)',
        'America/Whitehorse' => 'يڪون جو وقت (وائيٽ هائوس)',
        'America/Winnipeg' => 'مرڪزي وقت (وني پيگ)',
        'America/Yakutat' => 'الاسڪا جو وقت (ياڪوتات)',
        'Antarctica/Casey' => 'مغربي آسٽريليا جو وقت (ڪيسي)',
        'Antarctica/Davis' => 'ڊيوس جو وقت',
        'Antarctica/DumontDUrville' => 'ڊومانٽ درويئل جو وقت',
        'Antarctica/Macquarie' => 'اوڀر آسٽريليا جو وقت (مڪوائري)',
        'Antarctica/Mawson' => 'مائوسن جو وقت (موسن)',
        'Antarctica/McMurdo' => 'نيوزيلينڊ جو وقت (ميڪ مرڊو)',
        'Antarctica/Palmer' => 'چلي جو وقت (پامر)',
        'Antarctica/Rothera' => 'روٿيرا جو وقت (روڌرا)',
        'Antarctica/Syowa' => 'سائيوا جو وقت (سيووا)',
        'Antarctica/Troll' => 'گرين وچ مين ٽائيم (ٽرول)',
        'Antarctica/Vostok' => 'ووسٽوڪ جو وقت (ووستوڪ)',
        'Arctic/Longyearbyen' => 'مرڪزي يورپي وقت (لانگ ائيربن)',
        'Asia/Aden' => 'عربين جو وقت (عدن)',
        'Asia/Almaty' => 'قزاقستان وقت (الماتي)',
        'Asia/Amman' => 'مشرقي يورپي وقت (امان)',
        'Asia/Anadyr' => 'روس وقت (انيدر)',
        'Asia/Aqtau' => 'قزاقستان وقت (اڪٽائو)',
        'Asia/Aqtobe' => 'قزاقستان وقت (ايڪٽوب)',
        'Asia/Ashgabat' => 'ترڪمانستان جو وقت (آشگاباد)',
        'Asia/Atyrau' => 'قزاقستان وقت (آتيرائو)',
        'Asia/Baghdad' => 'عربين جو وقت (بغداد)',
        'Asia/Bahrain' => 'عربين جو وقت (بحرين)',
        'Asia/Baku' => 'آذربائيجان جو وقت (باڪو)',
        'Asia/Bangkok' => 'انڊو چائنا جو وقت (بئنڪاڪ)',
        'Asia/Barnaul' => 'ڪریسنویارسڪ جو وقت (برنل)',
        'Asia/Beirut' => 'مشرقي يورپي وقت (بيروت)',
        'Asia/Bishkek' => 'ڪرغزستان جو وقت (بشڪيڪ)',
        'Asia/Brunei' => 'برونائي دارالسلام جو وقت',
        'Asia/Calcutta' => 'ڀارت جو معياري وقت (ڪلڪتا)',
        'Asia/Kolkata' => 'ڀارت جو معياري وقت (ڪلڪتا)',
        'Asia/Chita' => 'ياڪتسڪ جو وقت (چيتا)',
        'Asia/Colombo' => 'ڀارت جو معياري وقت (ڪولمبو)',
        'Asia/Damascus' => 'مشرقي يورپي وقت (دمشق)',
        'Asia/Dhaka' => 'بنگلاديش جو وقت (ڍاڪا)',
        'Asia/Dili' => 'اوڀر تيمور جو وقت (دلي)',
        'Asia/Dubai' => 'خليجي معياري وقت (دبئي)',
        'Asia/Dushanbe' => 'تاجڪستان جو وقت (دوشانبي)',
        'Asia/Famagusta' => 'مشرقي يورپي وقت (فاماگوستا)',
        'Asia/Gaza' => 'مشرقي يورپي وقت (غزه)',
        'Asia/Hebron' => 'مشرقي يورپي وقت (هيبرون)',
        'Asia/Hong_Kong' => 'هانگ ڪانگ جو وقت',
        'Asia/Hovd' => 'هووڊ جو وقت',
        'Asia/Irkutsk' => 'ارڪتسڪ جو وقت',
        'Asia/Jakarta' => 'اولهه انڊونيشيا جو وقت (جڪارتا)',
        'Asia/Jayapura' => 'اوڀر انڊونيشيا جو وقت (جياپورا)',
        'Asia/Jerusalem' => 'اسرائيل جو وقت (يوروشلم)',
        'Asia/Kabul' => 'افغانستان جو وقت (ڪابل)',
        'Asia/Kamchatka' => 'روس وقت (ڪمچاسڪي)',
        'Asia/Karachi' => 'پاڪستان جو وقت (ڪراچي)',
        'Asia/Katmandu' => 'نيپال جو وقت (کٽمنڊو)',
        'Asia/Kathmandu' => 'نيپال جو وقت (کٽمنڊو)',
        'Asia/Khandyga' => 'ياڪتسڪ جو وقت (کندياگا)',
        'Asia/Krasnoyarsk' => 'ڪریسنویارسڪ جو وقت (ڪريسنويارسڪ)',
        'Asia/Kuala_Lumpur' => 'ملائيشيا جو وقت (ڪوالالمپور)',
        'Asia/Kuching' => 'ملائيشيا جو وقت (کوچنگ)',
        'Asia/Kuwait' => 'عربين جو وقت (ڪويت)',
        'Asia/Macau' => 'چين جو وقت (مڪائو)',
        'Asia/Magadan' => 'مگادان جو وقت',
        'Asia/Makassar' => 'مرڪزي انڊونيشيا جو وقت (ميڪاسر)',
        'Asia/Manila' => 'فلپائن جو وقت (منيلا)',
        'Asia/Muscat' => 'خليجي معياري وقت (مسقط)',
        'Asia/Nicosia' => 'مشرقي يورپي وقت (نيڪوسيا)',
        'Asia/Novokuznetsk' => 'ڪریسنویارسڪ جو وقت (نووڪزنيتسڪ)',
        'Asia/Novosibirsk' => 'ڪریسنویارسڪ جو وقت (نوواسبئيرسڪ)',
        'Asia/Omsk' => 'اومسڪ جو وقت',
        'Asia/Oral' => 'قزاقستان وقت (زباني)',
        'Asia/Phnom_Penh' => 'انڊو چائنا جو وقت (فنام پينه)',
        'Asia/Pontianak' => 'اولهه انڊونيشيا جو وقت (پونٽيانڪ)',
        'Asia/Pyongyang' => 'ڪوريا جو وقت (شيانگ يانگ)',
        'Asia/Qatar' => 'عربين جو وقت (قطر)',
        'Asia/Qostanay' => 'قزاقستان وقت (ڪوٽانسي)',
        'Asia/Qyzylorda' => 'قزاقستان وقت (ڪيزلورڊا)',
        'Asia/Rangoon' => 'ميانمار جو وقت (رنگون)',
        'Asia/Yangon' => 'ميانمار جو وقت (رنگون)',
        'Asia/Riyadh' => 'عربين جو وقت (رياض)',
        'Asia/Saigon' => 'انڊو چائنا جو وقت (هوچي من)',
        'Asia/Ho_Chi_Minh' => 'انڊو چائنا جو وقت (هوچي من)',
        'Asia/Sakhalin' => 'مگادان جو وقت (شخالين)',
        'Asia/Samarkand' => 'ازبڪستان جو وقت (سمرقند)',
        'Asia/Seoul' => 'ڪوريا جو وقت (سيول)',
        'Asia/Shanghai' => 'چين جو وقت (شنگهائي)',
        'Asia/Singapore' => 'سنگاپور جو معياري وقت',
        'Asia/Srednekolymsk' => 'مگادان جو وقت (سريديڪوليمسڪ)',
        'Asia/Taipei' => 'تائپي جو وقت',
        'Asia/Tashkent' => 'ازبڪستان جو وقت (تاشقنت)',
        'Asia/Tbilisi' => 'جارجيا جو وقت (تبليسي)',
        'Asia/Tehran' => 'ايران جو وقت (تهران)',
        'Asia/Thimphu' => 'ڀوٽان جو وقت (ٿمفو)',
        'Asia/Tokyo' => 'جاپان جو وقت (ٽوڪيو)',
        'Asia/Tomsk' => 'ڪریسنویارسڪ جو وقت (تمسڪ)',
        'Asia/Ulaanbaatar' => 'اولان باتر جو وقت',
        'Asia/Urumqi' => 'چين وقت (يورمڪي)',
        'Asia/Ust-Nera' => 'ولادووستوڪ جو وقت (اسٽ نيرا)',
        'Asia/Vientiane' => 'انڊو چائنا جو وقت (وينٽيان)',
        'Asia/Vladivostok' => 'ولادووستوڪ جو وقت',
        'Asia/Yakutsk' => 'ياڪتسڪ جو وقت',
        'Asia/Yekaterinburg' => 'يڪاٽيرنبرگ جو وقت (یڪاٽرنبرگ)',
        'Asia/Yerevan' => 'آرمينيا جو وقت (يريوان)',
        'Atlantic/Azores' => 'ازورز جو وقت',
        'Atlantic/Bermuda' => 'ايٽلانٽڪ جو وقت (برمودا)',
        'Atlantic/Canary' => 'اولهه يورپي وقت (ڪينري)',
        'Atlantic/Cape_Verde' => 'ڪيپ ورڊ جو وقت (ڪيپ ورڊي)',
        'Atlantic/Faeroe' => 'اولهه يورپي وقت (فيرو)',
        'Atlantic/Faroe' => 'اولهه يورپي وقت (فيرو)',
        'Atlantic/Madeira' => 'اولهه يورپي وقت (ماڊيرا)',
        'Atlantic/Reykjavik' => 'گرين وچ مين ٽائيم (ريڪيوڪ)',
        'Atlantic/South_Georgia' => 'ڏکڻ جارجيا جو وقت (ڏکڻ جورجيا)',
        'Atlantic/St_Helena' => 'گرين وچ مين ٽائيم (سينٽ هيلينا)',
        'Atlantic/Stanley' => 'فاڪ لينڊ آئي لينڊ جو وقت (اسٽينلي)',
        'Australia/Adelaide' => 'مرڪزي آسٽريليا جو وقت (ايڊيليڊ)',
        'Australia/Brisbane' => 'اوڀر آسٽريليا جو وقت (برسبين)',
        'Australia/Broken_Hill' => 'مرڪزي آسٽريليا جو وقت (بروڪن هل)',
        'Australia/Darwin' => 'مرڪزي آسٽريليا جو وقت (ڊارون)',
        'Australia/Eucla' => 'آسٽريليا جو مرڪزي مغربي وقت (يوڪلا)',
        'Australia/Hobart' => 'اوڀر آسٽريليا جو وقت (هوبارٽ)',
        'Australia/Lindeman' => 'اوڀر آسٽريليا جو وقت (لنڊمين)',
        'Australia/Lord_Howe' => 'لورڊ هووي جو وقت (لارڊ هائو)',
        'Australia/Melbourne' => 'اوڀر آسٽريليا جو وقت (ميلبورن)',
        'Australia/Perth' => 'مغربي آسٽريليا جو وقت (پرٿ)',
        'Australia/Sydney' => 'اوڀر آسٽريليا جو وقت (سڊني)',
        'Etc/GMT' => 'گرين وچ مين ٽائيم',
        'Etc/UTC' => 'گڏيل دنياوي وقت',
        'Europe/Amsterdam' => 'مرڪزي يورپي وقت (ايمسٽرڊيم)',
        'Europe/Andorra' => 'مرڪزي يورپي وقت (اندورا)',
        'Europe/Astrakhan' => 'روس وقت (آستراخان)',
        'Europe/Athens' => 'مشرقي يورپي وقت (ايٿنز)',
        'Europe/Belgrade' => 'مرڪزي يورپي وقت (بلغراد)',
        'Europe/Berlin' => 'مرڪزي يورپي وقت (برلن)',
        'Europe/Bratislava' => 'مرڪزي يورپي وقت (براتيسلوا)',
        'Europe/Brussels' => 'مرڪزي يورپي وقت (برسلز)',
        'Europe/Bucharest' => 'مشرقي يورپي وقت (بخاريسٽ)',
        'Europe/Budapest' => 'مرڪزي يورپي وقت (بداپيسٽ)',
        'Europe/Busingen' => 'مرڪزي يورپي وقت (بزيجين)',
        'Europe/Chisinau' => 'مشرقي يورپي وقت (چسينائو)',
        'Europe/Copenhagen' => 'مرڪزي يورپي وقت (ڪوپن هيگن)',
        'Europe/Dublin' => 'گرين وچ مين ٽائيم (ڊبلن)',
        'Europe/Gibraltar' => 'مرڪزي يورپي وقت (جبرالٽر)',
        'Europe/Guernsey' => 'گرين وچ مين ٽائيم (گرنزي)',
        'Europe/Helsinki' => 'مشرقي يورپي وقت (هيلسنڪي)',
        'Europe/Isle_of_Man' => 'گرين وچ مين ٽائيم (آئيزل آف مين)',
        'Europe/Istanbul' => 'ترڪييي وقت (استنبول)',
        'Europe/Jersey' => 'گرين وچ مين ٽائيم (جرسي)',
        'Europe/Kaliningrad' => 'مشرقي يورپي وقت (ڪلينن گراڊ)',
        'Europe/Kiev' => 'مشرقي يورپي وقت (ڪِيو)',
        'Europe/Kyiv' => 'مشرقي يورپي وقت (ڪِيو)',
        'Europe/Kirov' => 'ماسڪو جو وقت (ڪيروف)',
        'Europe/Lisbon' => 'اولهه يورپي وقت (لسبن)',
        'Europe/Ljubljana' => 'مرڪزي يورپي وقت (لبليانا)',
        'Europe/London' => 'گرين وچ مين ٽائيم (لنڊن)',
        'Europe/Luxembourg' => 'مرڪزي يورپي وقت (لگزمبرگ)',
        'Europe/Madrid' => 'مرڪزي يورپي وقت (ميڊرڊ)',
        'Europe/Malta' => 'مرڪزي يورپي وقت (مالٽا)',
        'Europe/Mariehamn' => 'مشرقي يورپي وقت (ميريهام)',
        'Europe/Minsk' => 'ماسڪو جو وقت (منسڪ)',
        'Europe/Monaco' => 'مرڪزي يورپي وقت (موناڪو)',
        'Europe/Moscow' => 'ماسڪو جو وقت',
        'Europe/Oslo' => 'مرڪزي يورپي وقت (اوسلو)',
        'Europe/Paris' => 'مرڪزي يورپي وقت (پئرس)',
        'Europe/Podgorica' => 'مرڪزي يورپي وقت (پوڊگورسيا)',
        'Europe/Prague' => 'مرڪزي يورپي وقت (پراگ)',
        'Europe/Riga' => 'مشرقي يورپي وقت (رگا)',
        'Europe/Rome' => 'مرڪزي يورپي وقت (روم)',
        'Europe/Samara' => 'روس وقت (سمارا)',
        'Europe/San_Marino' => 'مرڪزي يورپي وقت (سين مرينو)',
        'Europe/Sarajevo' => 'مرڪزي يورپي وقت (سراجیوو)',
        'Europe/Saratov' => 'روس وقت (سراتو)',
        'Europe/Simferopol' => 'ماسڪو جو وقت (سمفروپول)',
        'Europe/Skopje' => 'مرڪزي يورپي وقت (اسڪوپي)',
        'Europe/Sofia' => 'مشرقي يورپي وقت (سوفيا)',
        'Europe/Stockholm' => 'مرڪزي يورپي وقت (اسٽاڪ هوم)',
        'Europe/Tallinn' => 'مشرقي يورپي وقت (ٽالن)',
        'Europe/Tirane' => 'مرڪزي يورپي وقت (تراني)',
        'Europe/Ulyanovsk' => 'روس وقت (اليانوسڪ)',
        'Europe/Vaduz' => 'مرڪزي يورپي وقت (وڊوز)',
        'Europe/Vatican' => 'مرڪزي يورپي وقت (وئٽيڪن)',
        'Europe/Vienna' => 'مرڪزي يورپي وقت (ويئينا)',
        'Europe/Vilnius' => 'مشرقي يورپي وقت (ويلنيس)',
        'Europe/Volgograd' => 'ماسڪو جو وقت (وولگوگراد)',
        'Europe/Warsaw' => 'مرڪزي يورپي وقت (وارسا)',
        'Europe/Zagreb' => 'مرڪزي يورپي وقت (زغرب)',
        'Europe/Zurich' => 'مرڪزي يورپي وقت (زيورخ)',
        'Indian/Antananarivo' => 'اوڀر آفريڪا جو وقت (انتاناناريوو)',
        'Indian/Chagos' => 'هند سمنڊ جو وقت (چاگوس)',
        'Indian/Christmas' => 'ڪرسمس آئي لينڊ جو وقت',
        'Indian/Cocos' => 'ڪوڪوس آئي لينڊ جو وقت',
        'Indian/Comoro' => 'اوڀر آفريڪا جو وقت (ڪومورو)',
        'Indian/Kerguelen' => 'فرانسيسي ڏاکڻيو ۽ انٽارڪٽڪ وقت (ڪرگيولين)',
        'Indian/Mahe' => 'شي شلز جو وقت (ماهي)',
        'Indian/Maldives' => 'مالديپ جو وقت',
        'Indian/Mauritius' => 'موريشيس جو وقت (موريشس)',
        'Indian/Mayotte' => 'اوڀر آفريڪا جو وقت (مياٽي)',
        'Indian/Reunion' => 'ري يونين جو وقت',
        'Pacific/Apia' => 'اپيا جو وقت',
        'Pacific/Auckland' => 'نيوزيلينڊ جو وقت (آڪلينڊ)',
        'Pacific/Bougainville' => 'پاپوا نيو گني جو وقت (بوگين ويليا)',
        'Pacific/Chatham' => 'چئٿم جو وقت',
        'Pacific/Easter' => 'ايسٽر آئي لينڊ جو وقت',
        'Pacific/Efate' => 'وانواتو جو وقت (افاتي)',
        'Pacific/Enderbury' => 'فونيڪس آئي لينڊ جو وقت (ڪانٽن ٻيٽ)',
        'Pacific/Kanton' => 'فونيڪس آئي لينڊ جو وقت (ڪانٽن ٻيٽ)',
        'Pacific/Fakaofo' => 'ٽوڪيلائو جو وقت (فڪائوفو)',
        'Pacific/Fiji' => 'فجي جو وقت',
        'Pacific/Funafuti' => 'تووالو جو وقت (فنافوٽي)',
        'Pacific/Galapagos' => 'گالاپاگوز جو وقت',
        'Pacific/Gambier' => 'گيمبيئر جو وقت',
        'Pacific/Guadalcanal' => 'سولومن آئي لينڊ جو وقت (گواڊل ڪينال)',
        'Pacific/Guam' => 'چمورو جو معياري وقت (گوام)',
        'Pacific/Honolulu' => 'هوائي اليوٽين جو معياري وقت (هونو لولو)',
        'Pacific/Kiritimati' => 'لائن آئي لينڊ جو وقت (ڪريٽمٽي)',
        'Pacific/Kosrae' => 'ڪوسرائي جو وقت',
        'Pacific/Kwajalein' => 'مارشل آئي لينڊ جو وقت (ڪواجلين)',
        'Pacific/Majuro' => 'مارشل آئي لينڊ جو وقت (مجورو)',
        'Pacific/Marquesas' => 'مرڪيوسس جو وقت',
        'Pacific/Midway' => 'ساموا جو وقت (مڊوي)',
        'Pacific/Nauru' => 'نائورو جو وقت (نائرو)',
        'Pacific/Niue' => 'نيووي جو وقت',
        'Pacific/Norfolk' => 'نار فوڪ آئي لينڊ جو وقت',
        'Pacific/Noumea' => 'نيو ڪيليڊونيا جو وقت (نائوميا)',
        'Pacific/Pago_Pago' => 'ساموا جو وقت (پاگو پاگو)',
        'Pacific/Palau' => 'پلائو جو وقت',
        'Pacific/Pitcairn' => 'پٽڪيرن جو وقت',
        'Pacific/Ponape' => 'پوناپي جو وقت (پونپیئي)',
        'Pacific/Pohnpei' => 'پوناپي جو وقت (پونپیئي)',
        'Pacific/Port_Moresby' => 'پاپوا نيو گني جو وقت (پورٽ مورسبي)',
        'Pacific/Rarotonga' => 'ڪوڪ آئي لينڊ جو وقت (راروٽونگا)',
        'Pacific/Saipan' => 'چمورو جو معياري وقت (سيپن)',
        'Pacific/Tahiti' => 'تاهيٽي جو وقت (تاهٽي)',
        'Pacific/Tarawa' => 'گلبرٽ آئي لينڊ جو وقت (تراوا)',
        'Pacific/Tongatapu' => 'ٽونگا جو وقت (ٽونگاٽاپو)',
        'Pacific/Truk' => 'چيوڪ جو وقت',
        'Pacific/Chuuk' => 'چيوڪ جو وقت',
        'Pacific/Wake' => 'ويڪ آئي لينڊ جو وقت',
        'Pacific/Wallis' => 'ويلس ۽ فتونا جو وقت',
    ],
    'Meta' => [],
];
