<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'andorrská peseta',
        ],
        'AED' => [
            'AED',
            'SAE dirham',
        ],
        'AFA' => [
            'AFA',
            'afganský afgání (1927 – 2002)',
        ],
        'AFN' => [
            'AFN',
            'afganský afgání',
        ],
        'ALK' => [
            'ALK',
            'albánsky lek (1946 – 1965)',
        ],
        'ALL' => [
            'ALL',
            'albánsky lek',
        ],
        'AMD' => [
            'AMD',
            'arménsky dram',
        ],
        'ANG' => [
            'ANG',
            'antilský gulden',
        ],
        'AOA' => [
            'AOA',
            'angolská kwanza',
        ],
        'AOK' => [
            'AOK',
            'angolská kwanza (1977 – 1990)',
        ],
        'AON' => [
            'AON',
            'angolská nová kwanza (1990 – 2000)',
        ],
        'AOR' => [
            'AOR',
            'angolská upravená kwanza (1995 – 1999)',
        ],
        'ARA' => [
            'ARA',
            'argentínsky austral',
        ],
        'ARL' => [
            'ARL',
            'argentínske peso ley (1970 – 1983)',
        ],
        'ARM' => [
            'ARM',
            'argentínske peso (1881 – 1970)',
        ],
        'ARP' => [
            'ARP',
            'argentínske peso (1983 – 1985)',
        ],
        'ARS' => [
            'ARS',
            'argentínske peso',
        ],
        'ATS' => [
            'ATS',
            'rakúsky šiling',
        ],
        'AUD' => [
            'AUD',
            'austrálsky dolár',
        ],
        'AWG' => [
            'AWG',
            'arubský gulden',
        ],
        'AZM' => [
            'AZM',
            'azerbajdžanský manat (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'azerbajdžanský manat',
        ],
        'BAD' => [
            'BAD',
            'bosniansko-hercegovinský dinár (1992 – 1994)',
        ],
        'BAM' => [
            'BAM',
            'bosniansko-hercegovinská konvertibilná marka',
        ],
        'BAN' => [
            'BAN',
            'bosniansko-hercegovinský nový dinár (1994 – 1997)',
        ],
        'BBD' => [
            'BBD',
            'barbadoský dolár',
        ],
        'BDT' => [
            'BDT',
            'bangladéšska taka',
        ],
        'BEC' => [
            'BEC',
            'belgický frank (konvertibilný)',
        ],
        'BEF' => [
            'BEF',
            'belgický frank',
        ],
        'BEL' => [
            'BEL',
            'belgický frank (finančný)',
        ],
        'BGL' => [
            'BGL',
            'bulharský tvrdý lev',
        ],
        'BGM' => [
            'BGM',
            'bulharský socialistický lev',
        ],
        'BGN' => [
            'BGN',
            'bulharský lev',
        ],
        'BGO' => [
            'BGO',
            'bulharský lev (1879 – 1952)',
        ],
        'BHD' => [
            'BHD',
            'bahrajnský dinár',
        ],
        'BIF' => [
            'BIF',
            'burundský frank',
        ],
        'BMD' => [
            'BMD',
            'bermudský dolár',
        ],
        'BND' => [
            'BND',
            'brunejský dolár',
        ],
        'BOB' => [
            'BOB',
            'bolívijské boliviano',
        ],
        'BOL' => [
            'BOL',
            'bolívijské boliviano (1863 – 1963)',
        ],
        'BOP' => [
            'BOP',
            'bolívijské peso',
        ],
        'BOV' => [
            'BOV',
            'bolívijské MVDOL',
        ],
        'BRB' => [
            'BRB',
            'brazílske nové cruzeiro (1967 – 1986)',
        ],
        'BRC' => [
            'BRC',
            'brazílske cruzado (1986 – 1989)',
        ],
        'BRE' => [
            'BRE',
            'brazílske cruzeiro (1990 – 1993)',
        ],
        'BRL' => [
            'BRL',
            'brazílsky real',
        ],
        'BRN' => [
            'BRN',
            'brazílske nové cruzado (1989 – 1990)',
        ],
        'BRR' => [
            'BRR',
            'Brazílske cruzeiro',
        ],
        'BRZ' => [
            'BRZ',
            'brazílske cruzeiro (1942 – 1967)',
        ],
        'BSD' => [
            'BSD',
            'bahamský dolár',
        ],
        'BTN' => [
            'BTN',
            'bhutánsky ngultrum',
        ],
        'BUK' => [
            'BUK',
            'barmský kyat',
        ],
        'BWP' => [
            'BWP',
            'botswanská pula',
        ],
        'BYB' => [
            'BYB',
            'bieloruský rubeľ (1994 – 1999)',
        ],
        'BYN' => [
            'BYN',
            'bieloruský rubeľ',
        ],
        'BYR' => [
            'BYR',
            'bieloruský rubeľ (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'belizský dolár',
        ],
        'CAD' => [
            'CAD',
            'kanadský dolár',
        ],
        'CDF' => [
            'CDF',
            'konžský frank',
        ],
        'CHE' => [
            'CHE',
            'švajčiarske WIR euro',
        ],
        'CHF' => [
            'CHF',
            'švajčiarsky frank',
        ],
        'CHW' => [
            'CHW',
            'švajčiarsky WIR frank',
        ],
        'CLE' => [
            'CLE',
            'čilské escudo',
        ],
        'CLF' => [
            'CLF',
            'čilská účtovná jednotka (UF)',
        ],
        'CLP' => [
            'CLP',
            'čilské peso',
        ],
        'CNH' => [
            'CNH',
            'čínsky jüan (pobrežný)',
        ],
        'CNX' => [
            'CNX',
            'čínsky dolár ČĽB',
        ],
        'CNY' => [
            'CNY',
            'čínsky jüan',
        ],
        'COP' => [
            'COP',
            'kolumbijské peso',
        ],
        'COU' => [
            'COU',
            'kolumbijská jednotka reálnej hodnoty',
        ],
        'CRC' => [
            'CRC',
            'kostarický colón',
        ],
        'CSD' => [
            'CSD',
            'srbský dinár (2002 – 2006)',
        ],
        'CSK' => [
            'CSK',
            'československá koruna',
        ],
        'CUC' => [
            'CUC',
            'kubánske konvertibilné peso',
        ],
        'CUP' => [
            'CUP',
            'kubánske peso',
        ],
        'CVE' => [
            'CVE',
            'kapverdské escudo',
        ],
        'CYP' => [
            'CYP',
            'cyperská libra',
        ],
        'CZK' => [
            'CZK',
            'česká koruna',
        ],
        'DDM' => [
            'DDM',
            'východonemecká marka',
        ],
        'DEM' => [
            'DEM',
            'nemecká marka',
        ],
        'DJF' => [
            'DJF',
            'džibutský frank',
        ],
        'DKK' => [
            'DKK',
            'dánska koruna',
        ],
        'DOP' => [
            'DOP',
            'dominikánske peso',
        ],
        'DZD' => [
            'DZD',
            'alžírsky dinár',
        ],
        'ECS' => [
            'ECS',
            'ekvádorský sucre',
        ],
        'ECV' => [
            'ECV',
            'ekvádorská jednotka konštantnej hodnoty',
        ],
        'EEK' => [
            'EEK',
            'estónska koruna',
        ],
        'EGP' => [
            'EGP',
            'egyptská libra',
        ],
        'ERN' => [
            'ERN',
            'eritrejská nakfa',
        ],
        'ESA' => [
            'ESA',
            'španielska peseta (účet A)',
        ],
        'ESB' => [
            'ESB',
            'španielska peseta (konvertibilný účet)',
        ],
        'ESP' => [
            'ESP',
            'španielska peseta',
        ],
        'ETB' => [
            'ETB',
            'etiópsky birr',
        ],
        'EUR' => [
            '€',
            'euro',
        ],
        'FIM' => [
            'FIM',
            'fínska marka',
        ],
        'FJD' => [
            'FJD',
            'fidžijský dolár',
        ],
        'FKP' => [
            'FKP',
            'falklandská libra',
        ],
        'FRF' => [
            'FRF',
            'francúzsky frank',
        ],
        'GBP' => [
            'GBP',
            'britská libra',
        ],
        'GEK' => [
            'GEK',
            'gruzínske kupónové lari',
        ],
        'GEL' => [
            'GEL',
            'gruzínske lari',
        ],
        'GHC' => [
            'GHC',
            'ghanské cedi (1979 – 2007)',
        ],
        'GHS' => [
            'GHS',
            'ghanské cedi',
        ],
        'GIP' => [
            'GIP',
            'gibraltárska libra',
        ],
        'GMD' => [
            'GMD',
            'gambijské dalasi',
        ],
        'GNF' => [
            'GNF',
            'guinejský frank',
        ],
        'GNS' => [
            'GNS',
            'guinejské syli',
        ],
        'GQE' => [
            'GQE',
            'rovníkovoguinejský ekwele',
        ],
        'GRD' => [
            'GRD',
            'grécka drachma',
        ],
        'GTQ' => [
            'GTQ',
            'guatemalský quetzal',
        ],
        'GWE' => [
            'GWE',
            'portugalsko-guinejské escudo',
        ],
        'GWP' => [
            'GWP',
            'guinejsko-bissauské peso',
        ],
        'GYD' => [
            'GYD',
            'guyanský dolár',
        ],
        'HKD' => [
            'HKD',
            'hongkonský dolár',
        ],
        'HNL' => [
            'HNL',
            'honduraská lempira',
        ],
        'HRD' => [
            'HRD',
            'chorvátsky dinár',
        ],
        'HRK' => [
            'HRK',
            'chorvátska kuna',
        ],
        'HTG' => [
            'HTG',
            'haitské gourde',
        ],
        'HUF' => [
            'HUF',
            'maďarský forint',
        ],
        'IDR' => [
            'IDR',
            'indonézska rupia',
        ],
        'IEP' => [
            'IEP',
            'írska libra',
        ],
        'ILP' => [
            'ILP',
            'izraelská libra',
        ],
        'ILR' => [
            'ILR',
            'izraelský šekel (1980 – 1985)',
        ],
        'ILS' => [
            'NIS',
            'izraelský šekel',
        ],
        'INR' => [
            'INR',
            'indická rupia',
        ],
        'IQD' => [
            'IQD',
            'iracký dinár',
        ],
        'IRR' => [
            'IRR',
            'iránsky rial',
        ],
        'ISJ' => [
            'ISJ',
            'islandská koruna (1918 – 1981)',
        ],
        'ISK' => [
            'ISK',
            'islandská koruna',
        ],
        'ITL' => [
            'ITL',
            'talianska líra',
        ],
        'JMD' => [
            'JMD',
            'jamajský dolár',
        ],
        'JOD' => [
            'JOD',
            'jordánsky dinár',
        ],
        'JPY' => [
            'JPY',
            'japonský jen',
        ],
        'KES' => [
            'KES',
            'kenský šiling',
        ],
        'KGS' => [
            'KGS',
            'kirgizský som',
        ],
        'KHR' => [
            'KHR',
            'kambodžský riel',
        ],
        'KMF' => [
            'KMF',
            'komorský frank',
        ],
        'KPW' => [
            'KPW',
            'severokórejský won',
        ],
        'KRH' => [
            'KRH',
            'juhokórejský hwan (1953 – 1962)',
        ],
        'KRO' => [
            'KRO',
            'juhokórejský won (1945 – 1953)',
        ],
        'KRW' => [
            'KRW',
            'juhokórejský won',
        ],
        'KWD' => [
            'KWD',
            'kuvajtský dinár',
        ],
        'KYD' => [
            'KYD',
            'kajmanský dolár',
        ],
        'KZT' => [
            'KZT',
            'kazašské tenge',
        ],
        'LAK' => [
            'LAK',
            'laoský kip',
        ],
        'LBP' => [
            'LBP',
            'libanonská libra',
        ],
        'LKR' => [
            'LKR',
            'srílanská rupia',
        ],
        'LRD' => [
            'LRD',
            'libérijský dolár',
        ],
        'LSL' => [
            'LSL',
            'lesothský loti',
        ],
        'LTL' => [
            'LTL',
            'litovský litas',
        ],
        'LTT' => [
            'LTT',
            'litovský talonas',
        ],
        'LUC' => [
            'LUC',
            'luxemburský frank (konvertibilný)',
        ],
        'LUF' => [
            'LUF',
            'luxemburský frank',
        ],
        'LUL' => [
            'LUL',
            'luxemburský frank (finančný)',
        ],
        'LVL' => [
            'LVL',
            'lotyšský lat',
        ],
        'LVR' => [
            'LVR',
            'lotyšský rubeľ',
        ],
        'LYD' => [
            'LYD',
            'líbyjský dinár',
        ],
        'MAD' => [
            'MAD',
            'marocký dirham',
        ],
        'MAF' => [
            'MAF',
            'marocký frank',
        ],
        'MCF' => [
            'MCF',
            'monacký frank',
        ],
        'MDC' => [
            'MDC',
            'moldavský kupón',
        ],
        'MDL' => [
            'MDL',
            'moldavský lei',
        ],
        'MGA' => [
            'MGA',
            'malgašský ariary',
        ],
        'MGF' => [
            'MGF',
            'madagaskarský frank',
        ],
        'MKD' => [
            'MKD',
            'macedónsky denár',
        ],
        'MKN' => [
            'MKN',
            'macedónsky denár (1992 – 1993)',
        ],
        'MLF' => [
            'MLF',
            'malijský frank',
        ],
        'MMK' => [
            'MMK',
            'mjanmarský kyat',
        ],
        'MNT' => [
            'MNT',
            'mongolský tugrik',
        ],
        'MOP' => [
            'MOP',
            'macajská pataca',
        ],
        'MRO' => [
            'MRO',
            'mauritánska ukija (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'mauritánska ouguiya',
        ],
        'MTL' => [
            'MTL',
            'maltská líra',
        ],
        'MTP' => [
            'MTP',
            'maltská libra',
        ],
        'MUR' => [
            'MUR',
            'maurícijská rupia',
        ],
        'MVP' => [
            'MVP',
            'maldivská rupia (1947 – 1981)',
        ],
        'MVR' => [
            'MVR',
            'maldivská rupia',
        ],
        'MWK' => [
            'MWK',
            'malawijská kwacha',
        ],
        'MXN' => [
            'MX$',
            'mexické peso',
        ],
        'MXP' => [
            'MXP',
            'mexické strieborné peso (1861 – 1992)',
        ],
        'MXV' => [
            'MXV',
            'mexická investičná jednotka',
        ],
        'MYR' => [
            'MYR',
            'malajzijský ringgit',
        ],
        'MZE' => [
            'MZE',
            'mozambické escudo',
        ],
        'MZM' => [
            'MZM',
            'mozambický metical (1980 – 2006)',
        ],
        'MZN' => [
            'MZN',
            'mozambický metical',
        ],
        'NAD' => [
            'NAD',
            'namíbijský dolár',
        ],
        'NGN' => [
            'NGN',
            'nigérijská naira',
        ],
        'NIC' => [
            'NIC',
            'nikaragujská córdoba (1988 – 1991)',
        ],
        'NIO' => [
            'NIO',
            'nikaragujská córdoba',
        ],
        'NLG' => [
            'NLG',
            'holandský gulden',
        ],
        'NOK' => [
            'NOK',
            'nórska koruna',
        ],
        'NPR' => [
            'NPR',
            'nepálska rupia',
        ],
        'NZD' => [
            'NZD',
            'novozélandský dolár',
        ],
        'OMR' => [
            'OMR',
            'ománsky rial',
        ],
        'PAB' => [
            'PAB',
            'panamská balboa',
        ],
        'PEI' => [
            'PEI',
            'peruánsky inti',
        ],
        'PEN' => [
            'PEN',
            'peruánsky sol',
        ],
        'PES' => [
            'PES',
            'peruánsky sol (1863 – 1965)',
        ],
        'PGK' => [
            'PGK',
            'papuánska kina',
        ],
        'PHP' => [
            'PHP',
            'filipínske peso',
        ],
        'PKR' => [
            'PKR',
            'pakistanská rupia',
        ],
        'PLN' => [
            'PLN',
            'poľský zlotý',
        ],
        'PLZ' => [
            'PLZ',
            'poľský zlotý (1950 – 1995)',
        ],
        'PTE' => [
            'PTE',
            'portugalské escudo',
        ],
        'PYG' => [
            'PYG',
            'paraguajské guaraní',
        ],
        'QAR' => [
            'QAR',
            'katarský rial',
        ],
        'RHD' => [
            'RHD',
            'rodézsky dolár',
        ],
        'ROL' => [
            'ROL',
            'rumunský lei (1952 – 2006)',
        ],
        'RON' => [
            'RON',
            'rumunský lei',
        ],
        'RSD' => [
            'RSD',
            'srbský dinár',
        ],
        'RUB' => [
            'RUB',
            'ruský rubeľ',
        ],
        'RUR' => [
            'RUR',
            'ruský rubeľ (1991 – 1998)',
        ],
        'RWF' => [
            'RWF',
            'rwandský frank',
        ],
        'SAR' => [
            'SAR',
            'saudskoarabský rial',
        ],
        'SBD' => [
            'SBD',
            'šalamúnsky dolár',
        ],
        'SCR' => [
            'SCR',
            'seychelská rupia',
        ],
        'SDD' => [
            'SDD',
            'sudánsky dinár (1992 – 2007)',
        ],
        'SDG' => [
            'SDG',
            'sudánska libra',
        ],
        'SDP' => [
            'SDP',
            'sudánska libra (1957 – 1998)',
        ],
        'SEK' => [
            'SEK',
            'švédska koruna',
        ],
        'SGD' => [
            'SGD',
            'singapurský dolár',
        ],
        'SHP' => [
            'SHP',
            'svätohelenská libra',
        ],
        'SIT' => [
            'SIT',
            'slovinský toliar',
        ],
        'SKK' => [
            'SKK',
            'slovenská koruna',
        ],
        'SLE' => [
            'SLE',
            'sierraleonský leone',
        ],
        'SLL' => [
            'SLL',
            'sierraleonský leone (1964 – 2022)',
        ],
        'SOS' => [
            'SOS',
            'somálsky šiling',
        ],
        'SRD' => [
            'SRD',
            'surinamský dolár',
        ],
        'SRG' => [
            'SRG',
            'surinamský zlatý',
        ],
        'SSP' => [
            'SSP',
            'juhosudánska libra',
        ],
        'STD' => [
            'STD',
            'svätotomášska dobra (1977–2017)',
        ],
        'STN' => [
            'STN',
            'svätotomášska dobra',
        ],
        'SUR' => [
            'SUR',
            'sovietsky rubeľ',
        ],
        'SVC' => [
            'SVC',
            'salvádorský colón',
        ],
        'SYP' => [
            'SYP',
            'sýrska libra',
        ],
        'SZL' => [
            'SZL',
            'svazijský lilangeni',
        ],
        'THB' => [
            'THB',
            'thajský baht',
        ],
        'TJR' => [
            'TJR',
            'tadžický rubeľ',
        ],
        'TJS' => [
            'TJS',
            'tadžické somoni',
        ],
        'TMM' => [
            'TMM',
            'turkménsky manat (1993 – 2009)',
        ],
        'TMT' => [
            'TMT',
            'turkménsky manat',
        ],
        'TND' => [
            'TND',
            'tuniský dinár',
        ],
        'TOP' => [
            'TOP',
            'tongská paʻanga',
        ],
        'TPE' => [
            'TPE',
            'timorské escudo',
        ],
        'TRL' => [
            'TRL',
            'turecká líra (1922 – 2005)',
        ],
        'TRY' => [
            'TRY',
            'turecká líra',
        ],
        'TTD' => [
            'TTD',
            'trinidadsko-tobažský dolár',
        ],
        'TWD' => [
            'TWD',
            'nový taiwanský dolár',
        ],
        'TZS' => [
            'TZS',
            'tanzánsky šiling',
        ],
        'UAH' => [
            'UAH',
            'ukrajinská hrivna',
        ],
        'UAK' => [
            'UAK',
            'ukrajinský karbovanec',
        ],
        'UGS' => [
            'UGS',
            'ugandský šiling (1966 – 1987)',
        ],
        'UGX' => [
            'UGX',
            'ugandský šiling',
        ],
        'USD' => [
            'USD',
            'americký dolár',
        ],
        'USN' => [
            'USN',
            'americký dolár (ďalší deň)',
        ],
        'USS' => [
            'USS',
            'americký dolár (rovnaký deň)',
        ],
        'UYI' => [
            'UYI',
            'uruguajské peso (v indexovaných jednotkách)',
        ],
        'UYP' => [
            'UYP',
            'uruguajské peso (1975 – 1993)',
        ],
        'UYU' => [
            'UYU',
            'uruguajské peso',
        ],
        'UZS' => [
            'UZS',
            'uzbecký sum',
        ],
        'VEB' => [
            'VEB',
            'venezuelský bolívar (1871 – 2008)',
        ],
        'VEF' => [
            'VEF',
            'venezuelský bolívar (2008–2018)',
        ],
        'VES' => [
            'VES',
            'venezuelský bolívar',
        ],
        'VND' => [
            'VND',
            'vietnamský dong',
        ],
        'VNN' => [
            'VNN',
            'vietnamský dong (1978 – 1985)',
        ],
        'VUV' => [
            'VUV',
            'vanuatské vatu',
        ],
        'WST' => [
            'WST',
            'samojská tala',
        ],
        'XAF' => [
            'FCFA',
            'stredoafrický frank',
        ],
        'XCD' => [
            'EC$',
            'východokaribský dolár',
        ],
        'XCG' => [
            'Cg',
            'karibský gulden',
        ],
        'XEU' => [
            'XEU',
            'európska menová jednotka',
        ],
        'XFO' => [
            'XFO',
            'francúzsky zlatý frank',
        ],
        'XFU' => [
            'XFU',
            'francúzsky UIC frank',
        ],
        'XOF' => [
            'F CFA',
            'západoafrický frank',
        ],
        'XPF' => [
            'CFPF',
            'CFP frank',
        ],
        'XRE' => [
            'XRE',
            'fondy RINET',
        ],
        'YDD' => [
            'YDD',
            'jemenský dinár',
        ],
        'YER' => [
            'YER',
            'jemenský rial',
        ],
        'YUD' => [
            'YUD',
            'Juhoslávsky dinár [YUD]',
        ],
        'YUM' => [
            'YUM',
            'juhoslovanský nový dinár (1994 – 2002)',
        ],
        'YUN' => [
            'YUN',
            'juhoslovanský konvertibilný dinár (1990 – 1992)',
        ],
        'YUR' => [
            'YUR',
            'juhoslovanský reformovaný dinár (1992 – 1993)',
        ],
        'ZAL' => [
            'ZAL',
            'juhoafrický rand (finančný)',
        ],
        'ZAR' => [
            'ZAR',
            'juhoafrický rand',
        ],
        'ZMK' => [
            'ZMK',
            'zambijská kwacha (1968 – 2012)',
        ],
        'ZMW' => [
            'ZMW',
            'zambijská kwacha',
        ],
        'ZRN' => [
            'ZRN',
            'zairský nový zaire (1993 – 1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'zairský zaire (1971 – 1993)',
        ],
        'ZWD' => [
            'ZWD',
            'zimbabwiansky dolár (1980 – 2008)',
        ],
        'ZWG' => [
            'ZWG',
            'zimbabwiansky zlatý',
        ],
        'ZWL' => [
            'ZWL',
            'zimbabwiansky dolár (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'zimbabwiansky dolár (2008)',
        ],
    ],
];
