<?php

declare(strict_types=1);

namespace SimpleSAML\XMLSecurity\XML\xenc11;

/**
 * A class implementing the xenc11:KeyDerivationMethod element.
 *
 * @package simplesamlphp/xml-security
 */
final class KeyDerivationMethod extends AbstractKeyDerivationMethodType
{
}
