<?php

return [
    'UserAssignedNames' => [
        'XK' => 'Kosovo',
    ],
    'Names' => [
        'AD' => 'Andoro',
        'AE' => 'Unuiĝintaj Arabaj Emirlandoj',
        'AF' => 'Afganujo',
        'AG' => 'Antigvo kaj Barbudo',
        'AI' => 'Angvilo',
        'AL' => 'Albanujo',
        'AM' => 'Armenujo',
        'AO' => 'Angolo',
        'AQ' => 'Antarkto',
        'AR' => 'Argentino',
        'AS' => 'Usona Samoo',
        'AT' => 'Aŭstrujo',
        'AU' => 'Aŭstralio',
        'AW' => 'Arubo',
        'AX' => 'Alando',
        'AZ' => 'Azerbajĝano',
        'BA' => 'Bosnujo kaj Hercegovino',
        'BB' => 'Barbado',
        'BD' => 'Bangladeŝo',
        'BE' => 'Belgujo',
        'BF' => 'Burkino',
        'BG' => 'Bulgarujo',
        'BH' => 'Barejno',
        'BI' => 'Burundo',
        'BJ' => 'Benino',
        'BL' => 'Sankta Bartolomeo',
        'BM' => 'Bermudoj',
        'BN' => 'Brunejo',
        'BO' => 'Bolivio',
        'BQ' => 'Kariba Nederlando',
        'BR' => 'Brazilo',
        'BS' => 'Bahamoj',
        'BT' => 'Butano',
        'BV' => 'Buvetinsulo',
        'BW' => 'Bocvano',
        'BY' => 'Belorusujo',
        'BZ' => 'Belizo',
        'CA' => 'Kanado',
        'CC' => 'Kokosinsuloj',
        'CD' => 'Kongo Kinŝasa',
        'CF' => 'Centr-Afriko',
        'CG' => 'Kongo Brazavila',
        'CH' => 'Svisujo',
        'CI' => 'Ebur-Bordo',
        'CK' => 'Kukinsuloj',
        'CL' => 'Ĉilio',
        'CM' => 'Kameruno',
        'CN' => 'Ĉinujo',
        'CO' => 'Kolombio',
        'CR' => 'Kostariko',
        'CU' => 'Kubo',
        'CV' => 'Kaboverdo',
        'CW' => 'Kuracao',
        'CX' => 'Kristnaskinsulo',
        'CY' => 'Kipro',
        'CZ' => 'Ĉeĥujo',
        'DE' => 'Germanujo',
        'DJ' => 'Ĝibutio',
        'DK' => 'Danujo',
        'DM' => 'Dominiko',
        'DO' => 'Dominika Respubliko',
        'DZ' => 'Alĝerio',
        'EC' => 'Ekvadoro',
        'EE' => 'Estonujo',
        'EG' => 'Egiptujo',
        'EH' => 'Okcidenta Saharo',
        'ER' => 'Eritreo',
        'ES' => 'Hispanujo',
        'ET' => 'Etiopujo',
        'FI' => 'Finnlando',
        'FJ' => 'Fiĝio',
        'FK' => 'Falklandoj',
        'FM' => 'Mikronezio',
        'FO' => 'Ferooj',
        'FR' => 'Francujo',
        'GA' => 'Gabono',
        'GB' => 'Unuiĝinta Reĝlando',
        'GD' => 'Grenado',
        'GE' => 'Kartvelujo',
        'GF' => 'Franca Gujano',
        'GG' => 'Gernezejo',
        'GH' => 'Ganao',
        'GI' => 'Ĝibraltaro',
        'GL' => 'Gronlando',
        'GM' => 'Gambio',
        'GN' => 'Gvineo',
        'GP' => 'Gvadelupo',
        'GQ' => 'Ekvatora Gvineo',
        'GR' => 'Grekujo',
        'GS' => 'Sud-Georgio kaj Sud-Sandviĉinsuloj',
        'GT' => 'Gvatemalo',
        'GU' => 'Gvamo',
        'GW' => 'Gvineo-Bisaŭo',
        'GY' => 'Gujano',
        'HK' => 'Honkongo (SAR de Ĉinujo)',
        'HM' => 'Herda kaj Makdonaldaj Insuloj',
        'HN' => 'Honduro',
        'HR' => 'Kroatujo',
        'HT' => 'Haitio',
        'HU' => 'Hungarujo',
        'ID' => 'Indonezio',
        'IE' => 'Irlando',
        'IL' => 'Israelo',
        'IM' => 'Manksinsulo',
        'IN' => 'Hindujo',
        'IO' => 'Brita Hindoceana Teritorio',
        'IQ' => 'Irako',
        'IR' => 'Irano',
        'IS' => 'Islando',
        'IT' => 'Italujo',
        'JE' => 'Ĵerzejo',
        'JM' => 'Jamajko',
        'JO' => 'Jordanio',
        'JP' => 'Japanujo',
        'KE' => 'Kenjo',
        'KG' => 'Kirgizujo',
        'KH' => 'Kamboĝo',
        'KI' => 'Kiribato',
        'KM' => 'Komoroj',
        'KN' => 'Sankta Kristoforo kaj Neviso',
        'KP' => 'Nord-Koreujo',
        'KR' => 'Sud-Koreujo',
        'KW' => 'Kuvajto',
        'KY' => 'Kajmana Insularo',
        'KZ' => 'Kazaĥujo',
        'LA' => 'Laoso',
        'LB' => 'Libano',
        'LC' => 'Sankta Lucio',
        'LI' => 'Liĥtenŝtejno',
        'LK' => 'Srilanko',
        'LR' => 'Liberio',
        'LS' => 'Lesoto',
        'LT' => 'Litovujo',
        'LU' => 'Luksemburgo',
        'LV' => 'Latvujo',
        'LY' => 'Libio',
        'MA' => 'Maroko',
        'MC' => 'Monako',
        'MD' => 'Moldavujo',
        'ME' => 'Montenegro',
        'MF' => 'Saint-Martin',
        'MG' => 'Madagaskaro',
        'MH' => 'Marŝaloj',
        'MK' => 'Nord-Makedonujo',
        'ML' => 'Malio',
        'MM' => 'Birmo',
        'MN' => 'Mongolujo',
        'MO' => 'Makao (SAR de Ĉinujo)',
        'MP' => 'Nord-Marianoj',
        'MQ' => 'Martiniko',
        'MR' => 'Maŭritanio',
        'MS' => 'Moncerato',
        'MT' => 'Malto',
        'MU' => 'Maŭricio',
        'MV' => 'Maldivoj',
        'MW' => 'Malavio',
        'MX' => 'Meksiko',
        'MY' => 'Malajzio',
        'MZ' => 'Mozambiko',
        'NA' => 'Namibio',
        'NC' => 'Nov-Kaledonio',
        'NE' => 'Niĝero',
        'NF' => 'Norfolkinsulo',
        'NG' => 'Niĝerio',
        'NI' => 'Nikaragvo',
        'NL' => 'Nederlando',
        'NO' => 'Norvegujo',
        'NP' => 'Nepalo',
        'NR' => 'Nauro',
        'NU' => 'Niuo',
        'NZ' => 'Nov-Zelando',
        'OM' => 'Omano',
        'PA' => 'Panamo',
        'PE' => 'Peruo',
        'PF' => 'Franca Polinezio',
        'PG' => 'Papuo-Nov-Gvineo',
        'PH' => 'Filipinoj',
        'PK' => 'Pakistano',
        'PL' => 'Pollando',
        'PM' => 'Sankta Piero kaj Mikelono',
        'PN' => 'Pitkarna Insulo',
        'PR' => 'Puertoriko',
        'PS' => 'Palestinaj teritorioj',
        'PT' => 'Portugalujo',
        'PW' => 'Palaŭo',
        'PY' => 'Paragvajo',
        'QA' => 'Kataro',
        'RE' => 'Reunio',
        'RO' => 'Rumanujo',
        'RS' => 'Serbujo',
        'RU' => 'Rusujo',
        'RW' => 'Ruando',
        'SA' => 'Sauda Arabujo',
        'SB' => 'Salomonoj',
        'SC' => 'Sejŝeloj',
        'SD' => 'Sudano',
        'SE' => 'Svedujo',
        'SG' => 'Singapuro',
        'SH' => 'Sankta Heleno',
        'SI' => 'Slovenujo',
        'SJ' => 'Svalbardo kaj Janmajeno',
        'SK' => 'Slovakujo',
        'SL' => 'Sieraleono',
        'SM' => 'Sanmarino',
        'SN' => 'Senegalo',
        'SO' => 'Somalujo',
        'SR' => 'Surinamo',
        'SS' => 'Sud-Sudano',
        'ST' => 'Santomeo kaj Principeo',
        'SV' => 'Salvadoro',
        'SX' => 'Sint-Maarten',
        'SY' => 'Sirio',
        'SZ' => 'Svazilando',
        'TC' => 'Turkoj kaj Kajkoj',
        'TD' => 'Ĉado',
        'TF' => 'Francaj Sudaj Teritorioj',
        'TG' => 'Togolando',
        'TH' => 'Tajlando',
        'TJ' => 'Taĝikujo',
        'TK' => 'Tokelao',
        'TL' => 'Orienta Timoro',
        'TM' => 'Turkmenujo',
        'TN' => 'Tunizio',
        'TO' => 'Tongo',
        'TR' => 'Turkujo',
        'TT' => 'Trinidado kaj Tobago',
        'TV' => 'Tuvalo',
        'TW' => 'Tajvano',
        'TZ' => 'Tanzanio',
        'UA' => 'Ukrainujo',
        'UG' => 'Ugando',
        'UM' => 'Usonaj malgrandaj insuloj',
        'US' => 'Usono',
        'UY' => 'Urugvajo',
        'UZ' => 'Uzbekujo',
        'VA' => 'Vatikano',
        'VC' => 'Sankta Vincento kaj Grenadinoj',
        'VE' => 'Venezuelo',
        'VG' => 'Britaj Virgulininsuloj',
        'VI' => 'Usonaj Virgulininsuloj',
        'VN' => 'Vjetnamujo',
        'VU' => 'Vanuatuo',
        'WF' => 'Valiso kaj Futuno',
        'WS' => 'Samoo',
        'YE' => 'Jemeno',
        'YT' => 'Majoto',
        'ZA' => 'Sud-Afriko',
        'ZM' => 'Zambio',
        'ZW' => 'Zimbabvo',
    ],
];
