<?php

return [
    'Names' => [
        'ar_PS' => 'Arabic (Palestinian territories)',
        'bn' => 'Bengali',
        'bn_BD' => 'Bengali (Bangladesh)',
        'bn_IN' => 'Bengali (India)',
        'bs_BA' => 'Bosnian (Bosnia and Herzegovina)',
        'bs_Cyrl_BA' => 'Bosnian (Cyrillic, Bosnia and Herzegovina)',
        'bs_Latn_BA' => 'Bosnian (Latin, Bosnia and Herzegovina)',
        'en_AG' => 'English (Antigua and Barbuda)',
        'en_GS' => 'English (South Georgia and South Sandwich Islands)',
        'en_KN' => 'English (Saint Kitts and Nevis)',
        'en_LC' => 'English (Saint Lucia)',
        'en_SH' => 'English (Saint Helena)',
        'en_TC' => 'English (Turks and Caicos Islands)',
        'en_TT' => 'English (Trinidad and Tobago)',
        'en_UM' => 'English (US Outlying Islands)',
        'en_VC' => 'English (Saint Vincent and the Grenadines)',
        'en_VI' => 'English (US Virgin Islands)',
        'fr_BL' => 'French (Saint-Barthélemy)',
        'fr_MF' => 'French (Saint Martin)',
        'fr_PM' => 'French (Saint-Pierre-et-Miquelon)',
        'fr_WF' => 'French (Wallis and Futuna)',
        'hr_BA' => 'Croatian (Bosnia and Herzegovina)',
        'nb_SJ' => 'Norwegian Bokmål (Svalbard and Jan Mayen)',
        'pt_ST' => 'Portuguese (São Tomé and Príncipe)',
        'sh_BA' => 'Serbo-Croatian (Bosnia and Herzegovina)',
        'sr_BA' => 'Serbian (Bosnia and Herzegovina)',
        'sr_Cyrl_BA' => 'Serbian (Cyrillic, Bosnia and Herzegovina)',
        'sr_Latn_BA' => 'Serbian (Latin, Bosnia and Herzegovina)',
    ],
];
