<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'dirhamo de Unuiĝintaj Arabaj Emirlandoj',
        ],
        'AFN' => [
            'AFN',
            'afgana afganio',
        ],
        'ALL' => [
            'ALL',
            'albana leko',
        ],
        'AMD' => [
            'AMD',
            'armena dramo',
        ],
        'ANG' => [
            'ANG',
            'nederlandantila guldeno',
        ],
        'AOA' => [
            'AOA',
            'angola kvanzo',
        ],
        'ARS' => [
            'ARS',
            'argentina peso',
        ],
        'AUD' => [
            'AUD',
            'aŭstralia dolaro',
        ],
        'AWG' => [
            'AWG',
            'aruba floreno',
        ],
        'AZN' => [
            'AZN',
            'azerbajĝana manato',
        ],
        'BAM' => [
            'BAM',
            'konvertebla marko de Bosnujo kaj Hercegovino',
        ],
        'BBD' => [
            'BBD',
            'barbada dolaro',
        ],
        'BDT' => [
            'BDT',
            'bangladeŝa tako',
        ],
        'BGN' => [
            'BGN',
            'bulgara levo',
        ],
        'BHD' => [
            'BHD',
            'barejna dinaro',
        ],
        'BIF' => [
            'BIF',
            'burunda franko',
        ],
        'BMD' => [
            'BMD',
            'bermuda dolaro',
        ],
        'BND' => [
            'BND',
            'bruneja dolaro',
        ],
        'BOB' => [
            'BOB',
            'bolivia bolivjano',
        ],
        'BRL' => [
            'BRL',
            'brazila realo',
        ],
        'BSD' => [
            'BSD',
            'bahama dolaro',
        ],
        'BTN' => [
            'BTN',
            'butana ngultrumo',
        ],
        'BWP' => [
            'BWP',
            'bocvana pulao',
        ],
        'BYN' => [
            'BYN',
            'belorusa rublo',
        ],
        'BZD' => [
            'BZD',
            'beliza dolaro',
        ],
        'CAD' => [
            'CAD',
            'kanada dolaro',
        ],
        'CDF' => [
            'CDF',
            'konga franko',
        ],
        'CHF' => [
            'CHF',
            'svisa franko',
        ],
        'CLP' => [
            'CLP',
            'ĉilia peso',
        ],
        'CNH' => [
            'CNH',
            'ĉina juano (eksterlanda uzo)',
        ],
        'CNY' => [
            'CNY',
            'ĉinaj juanoj',
        ],
        'COP' => [
            'COP',
            'kolombia peso',
        ],
        'CRC' => [
            'CRC',
            'kostarika kolumbo',
        ],
        'CUC' => [
            'CUC',
            'konvertebla kuba peso',
        ],
        'CUP' => [
            'CUP',
            'kuba peso',
        ],
        'CVE' => [
            'CVE',
            'kaboverda eskudo',
        ],
        'CZK' => [
            'CZK',
            'ĉeĥa krono',
        ],
        'DJF' => [
            'DJF',
            'ĝibutia franko',
        ],
        'DKK' => [
            'DKK',
            'dana krono',
        ],
        'DOP' => [
            'DOP',
            'dominika peso',
        ],
        'DZD' => [
            'DZD',
            'alĝeria dinaro',
        ],
        'EGP' => [
            'EGP',
            'egipta pundo',
        ],
        'ERN' => [
            'ERN',
            'eritrea nakfo',
        ],
        'ETB' => [
            'ETB',
            'etiopa birro',
        ],
        'EUR' => [
            '€',
            'eŭro',
        ],
        'FJD' => [
            'FJD',
            'fiĝia dolaro',
        ],
        'FKP' => [
            'FKP',
            'falklanda pundo',
        ],
        'GBP' => [
            'GBP',
            'brita pundo',
        ],
        'GEL' => [
            'GEL',
            'kartvela lario',
        ],
        'GHS' => [
            'GHS',
            'ganaa cedio',
        ],
        'GIP' => [
            'GIP',
            'ĝibraltara pundo',
        ],
        'GMD' => [
            'GMD',
            'gambia dalasio',
        ],
        'GNF' => [
            'GNF',
            'gvinea franko',
        ],
        'GTQ' => [
            'GTQ',
            'gvatemala kecalo',
        ],
        'GYD' => [
            'GYD',
            'gujana dolaro',
        ],
        'HKD' => [
            'HKD',
            'honkonga dolaro',
        ],
        'HNL' => [
            'HNL',
            'hondura lempiro',
        ],
        'HRK' => [
            'HRK',
            'kroata kunao',
        ],
        'HTG' => [
            'HTG',
            'haitia gurdo',
        ],
        'HUF' => [
            'HUF',
            'hungara forinto',
        ],
        'IDR' => [
            'IDR',
            'indonezia rupio',
        ],
        'ILS' => [
            'ILS',
            'israela nova siklo',
        ],
        'INR' => [
            'INR',
            'hinda rupio',
        ],
        'IQD' => [
            'IQD',
            'iraka dinaro',
        ],
        'IRR' => [
            'IRR',
            'irana rialo',
        ],
        'ISK' => [
            'ISK',
            'islanda krono',
        ],
        'JMD' => [
            'JMD',
            'jamajka dolaro',
        ],
        'JOD' => [
            'JOD',
            'jordania dinaro',
        ],
        'JPY' => [
            'JPY',
            'japana eno',
        ],
        'KES' => [
            'KES',
            'kenja ŝilingo',
        ],
        'KGS' => [
            'KGS',
            'kirgiza somo',
        ],
        'KHR' => [
            'KHR',
            'kamboĝa rielo',
        ],
        'KMF' => [
            'KMF',
            'komora franko',
        ],
        'KPW' => [
            'KPW',
            'nordkorea vono',
        ],
        'KRW' => [
            'KRW',
            'sudkorea vono',
        ],
        'KWD' => [
            'KWD',
            'kuvajta dinaro',
        ],
        'KYD' => [
            'KYD',
            'kajmana dolaro',
        ],
        'KZT' => [
            'KZT',
            'kazaĥa tengo',
        ],
        'LAK' => [
            'LAK',
            'laosa kipo',
        ],
        'LBP' => [
            'LBP',
            'libana liro',
        ],
        'LKR' => [
            'LKR',
            'srilanka rupio',
        ],
        'LRD' => [
            'LRD',
            'liberia dolaro',
        ],
        'LSL' => [
            'LSL',
            'lesota lotio',
        ],
        'LYD' => [
            'LYD',
            'libia dinaro',
        ],
        'MAD' => [
            'MAD',
            'maroka dirhamo',
        ],
        'MDL' => [
            'MDL',
            'moldava leo',
        ],
        'MGA' => [
            'MGA',
            'madagaskara ariaro',
        ],
        'MKD' => [
            'MKD',
            'makedona denaro',
        ],
        'MMK' => [
            'MMK',
            'birma kjato',
        ],
        'MNT' => [
            'MNT',
            'mongola tugriko',
        ],
        'MOP' => [
            'MOP',
            'makaa patako',
        ],
        'MRU' => [
            'MRU',
            'maŭritania uguijao',
        ],
        'MUR' => [
            'MUR',
            'maŭricia rupio',
        ],
        'MVR' => [
            'MVR',
            'maldiva rufijao',
        ],
        'MWK' => [
            'MWK',
            'malavia kvaĉo',
        ],
        'MXN' => [
            'MXN',
            'meksika peso',
        ],
        'MYR' => [
            'MYR',
            'malajzia ringito',
        ],
        'MZN' => [
            'MZN',
            'mozambika metikalo',
        ],
        'NAD' => [
            'NAD',
            'namibia dolaro',
        ],
        'NGN' => [
            'NGN',
            'niĝeria najro',
        ],
        'NIO' => [
            'NIO',
            'nikaragva kordovo',
        ],
        'NOK' => [
            'NOK',
            'norvega krono',
        ],
        'NPR' => [
            'NPR',
            'nepala rupio',
        ],
        'NZD' => [
            'NZD',
            'novzelanda dolaro',
        ],
        'OMR' => [
            'OMR',
            'omana rialo',
        ],
        'PAB' => [
            'PAB',
            'panama balboo',
        ],
        'PEN' => [
            'PEN',
            'perua suno',
        ],
        'PGK' => [
            'PGK',
            'papuonovgvinea kinao',
        ],
        'PHP' => [
            'PHP',
            'filipina peso',
        ],
        'PKR' => [
            'PKR',
            'pakistana rupio',
        ],
        'PLN' => [
            'PLN',
            'pola zloto',
        ],
        'PYG' => [
            'PYG',
            'paragvaja gvaranio',
        ],
        'QAR' => [
            'QAR',
            'katara rialo',
        ],
        'RON' => [
            'RON',
            'rumana leo',
        ],
        'RSD' => [
            'RSD',
            'serba dinaro',
        ],
        'RUB' => [
            'RUB',
            'rusa rublo',
        ],
        'RWF' => [
            'RWF',
            'ruanda franko',
        ],
        'SAR' => [
            'SAR',
            'sauda rialo',
        ],
        'SBD' => [
            'SBD',
            'salomona dolaro',
        ],
        'SCR' => [
            'SCR',
            'sejŝela rupio',
        ],
        'SDG' => [
            'SDG',
            'sudana pundo',
        ],
        'SEK' => [
            'SEK',
            'sveda krono',
        ],
        'SGD' => [
            'SGD',
            'singapura dolaro',
        ],
        'SHP' => [
            'SHP',
            'sankthelena pundo',
        ],
        'SLE' => [
            'SLE',
            'sieraleona leono',
        ],
        'SLL' => [
            'SLL',
            'sieraleona leono (1964–2022)',
        ],
        'SOS' => [
            'SOS',
            'somala ŝilingo',
        ],
        'SRD' => [
            'SRD',
            'surinama dolaro',
        ],
        'SSP' => [
            'SSP',
            'sudsudana pundo',
        ],
        'STN' => [
            'STN',
            'santomea dobro',
        ],
        'SYP' => [
            'SYP',
            'siria pundo',
        ],
        'SZL' => [
            'SZL',
            'svazilanda liliagenio',
        ],
        'THB' => [
            'THB',
            'taja bahto',
        ],
        'TJS' => [
            'TJS',
            'taĝika somonio',
        ],
        'TMT' => [
            'TMT',
            'turkmena manato',
        ],
        'TND' => [
            'TND',
            'tunizia dinaro',
        ],
        'TOP' => [
            'TOP',
            'tonga paangao',
        ],
        'TRY' => [
            'TRY',
            'turka liro',
        ],
        'TTD' => [
            'TTD',
            'trinidada dolaro',
        ],
        'TWD' => [
            'TWD',
            'tajvana nova dolaro',
        ],
        'TZS' => [
            'TZS',
            'tanzania ŝilingo',
        ],
        'UAH' => [
            'UAH',
            'ukraina hrivno',
        ],
        'UGX' => [
            'UGX',
            'uganda ŝilingo',
        ],
        'USD' => [
            'USD',
            'usona dolaro',
        ],
        'UYU' => [
            'UYU',
            'urugvaja peso',
        ],
        'UZS' => [
            'UZS',
            'uzbeka somo',
        ],
        'VES' => [
            'VES',
            'venezuela bolivaro',
        ],
        'VND' => [
            'VND',
            'vjetnama dongo',
        ],
        'VUV' => [
            'VUV',
            'vanuatua vatuo',
        ],
        'WST' => [
            'WST',
            'samoa talao',
        ],
        'XAF' => [
            'XAF',
            'ekvatorafrika franko',
        ],
        'XCD' => [
            'XCD',
            'orientkariba dolaro',
        ],
        'XCG' => [
            'XCG',
            'kariba guldeno',
        ],
        'XOF' => [
            'XOF',
            'okcidentafrika franko',
        ],
        'XPF' => [
            'XPF',
            'pacifika franko',
        ],
        'YER' => [
            'YER',
            'jemena rialo',
        ],
        'ZAR' => [
            'ZAR',
            'sudafrika rando',
        ],
        'ZMW' => [
            'ZMW',
            'zambia kvaĉo',
        ],
        'ZWG' => [
            'ZWG',
            'zimbabva oro',
        ],
    ],
];
