<?php

return [
    'Names' => [
        'de' => 'Jérman',
        'en' => 'Inggris',
        'es' => 'Spanyol',
        'fr' => 'Prancis',
        'it' => 'Italia',
        'ja' => 'Jepang',
        'pt' => 'Portugis',
        'ru' => 'Rusia',
        'su' => 'Basa Sunda',
        'zh' => 'Tiongkok',
    ],
    'LocalizedNames' => [
        'de_AT' => 'Jérman Austria',
        'de_CH' => 'Jérman Swiss Luhur',
        'en_AU' => 'Inggris Australia',
        'en_CA' => 'Inggris Kanada',
        'en_US' => 'Inggris Amerika',
        'es_419' => 'Spanyol Amérika Latin',
        'es_ES' => 'Spanyol Éropa',
        'es_MX' => 'Spanyol Méksiko',
        'fr_CA' => 'Prancis Kanada',
        'fr_CH' => 'Prancis Swiss',
        'pt_BR' => 'Portugis Brasil',
        'pt_PT' => 'Portugis Éropa',
        'zh_Hans' => 'Tiongkok Sederhana',
        'zh_Hant' => 'Tiongkok Tradisional',
    ],
];
