<?php

return [
    'UserAssignedNames' => [
        'XK' => 'کوسوا',
    ],
    'Names' => [
        'AD' => 'اندورا',
        'AG' => 'انتیگوا و باربودا',
        'AL' => 'البانیا',
        'AO' => 'انگولا',
        'AQ' => 'انترکتیکا',
        'AR' => 'ارجنتاین',
        'BA' => 'بوسنیا و هرزه‌گوینا',
        'BD' => 'بنگله‌دیش',
        'BE' => 'بلجیم',
        'BG' => 'بلغاریا',
        'BN' => 'برونی',
        'BO' => 'بولیویا',
        'BR' => 'برازیل',
        'BS' => 'بهاماس',
        'CD' => 'کانگو - کینشاسا',
        'CG' => 'کانگو - برازویل',
        'CH' => 'سویس',
        'CL' => 'چلی',
        'CO' => 'کولمبیا',
        'CR' => 'کاستریکا',
        'CU' => 'کیوبا',
        'DK' => 'دنمارک',
        'EE' => 'استونیا',
        'ER' => 'اریتریا',
        'ES' => 'هسپانیه',
        'ET' => 'ایتوپیا',
        'FI' => 'فنلند',
        'FM' => 'میکرونزیا',
        'GD' => 'گرینادا',
        'GH' => 'گانا',
        'GN' => 'گینیا',
        'GQ' => 'گینیا استوایی',
        'GT' => 'گواتیمالا',
        'GW' => 'گینیا بیسائو',
        'GY' => 'گیانا',
        'HK' => 'هانگ کانگ، ناحیهٔ ویژهٔ حکومتی چین',
        'HN' => 'هاندوراس',
        'HR' => 'کروشیا',
        'HT' => 'هایتی',
        'ID' => 'اندونیزیا',
        'IE' => 'آیرلند',
        'IS' => 'آیسلند',
        'JP' => 'جاپان',
        'KE' => 'کینیا',
        'KH' => 'کمپوچیا',
        'KP' => 'کوریای شمالی',
        'KR' => 'کوریای جنوبی',
        'LK' => 'سریلانکا',
        'LS' => 'لیسوتو',
        'LT' => 'لتوانیا',
        'LV' => 'لاتویا',
        'LY' => 'لیبیا',
        'MG' => 'مادغاسکر',
        'MN' => 'منگولیا',
        'MR' => 'موریتانیا',
        'MT' => 'مالتا',
        'MX' => 'مکسیکو',
        'MY' => 'مالیزیا',
        'MZ' => 'موزمبیق',
        'NG' => 'نیجریا',
        'NI' => 'نیکاراگوا',
        'NL' => 'هالند',
        'NO' => 'ناروی',
        'NP' => 'نیپال',
        'NZ' => 'زیلاند جدید',
        'PA' => 'پانامه',
        'PE' => 'پیرو',
        'PG' => 'پاپوا نیو گینیا',
        'PL' => 'پولند',
        'PT' => 'پرتگال',
        'PY' => 'پاراگوای',
        'RO' => 'رومانیا',
        'SE' => 'سویدن',
        'SG' => 'سینگاپور',
        'SI' => 'سلونیا',
        'SJ' => 'اسوالبارد و جان ماین',
        'SK' => 'سلواکیا',
        'SL' => 'سیرالیون',
        'SN' => 'سینیگال',
        'SO' => 'سومالیه',
        'SV' => 'السلوادور',
        'TJ' => 'تاجکستان',
        'UG' => 'یوگاندا',
        'UY' => 'یوروگوای',
        'VC' => 'سنت وینسنت و گرنادین‌ها',
        'VE' => 'ونزویلا',
        'ZW' => 'زیمبابوی',
    ],
];
