<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich Mean Time (Abidjan)',
        'Africa/Accra' => 'Greenwich Mean Time (Accra)',
        'Africa/Addis_Ababa' => 'East Africa Time (Addis Ababa)',
        'Africa/Algiers' => 'Central European Time (Algiers)',
        'Africa/Asmera' => 'East Africa Time (Asmara)',
        'Africa/Asmara' => 'East Africa Time (Asmara)',
        'Africa/Bamako' => 'Greenwich Mean Time (Bamako)',
        'Africa/Bangui' => 'West Africa Time (Bangui)',
        'Africa/Banjul' => 'Greenwich Mean Time (Banjul)',
        'Africa/Bissau' => 'Greenwich Mean Time (Bissau)',
        'Africa/Blantyre' => 'Central Africa Time (Blantyre)',
        'Africa/Brazzaville' => 'West Africa Time (Brazzaville)',
        'Africa/Bujumbura' => 'Central Africa Time (Bujumbura)',
        'Africa/Cairo' => 'Eastern European Time (Cairo)',
        'Africa/Casablanca' => 'Western European Time (Casablanca)',
        'Africa/Ceuta' => 'Central European Time (Ceuta)',
        'Africa/Conakry' => 'Greenwich Mean Time (Conakry)',
        'Africa/Dakar' => 'Greenwich Mean Time (Dakar)',
        'Africa/Dar_es_Salaam' => 'East Africa Time (Dar es Salaam)',
        'Africa/Djibouti' => 'East Africa Time (Djibouti)',
        'Africa/Douala' => 'West Africa Time (Douala)',
        'Africa/El_Aaiun' => 'Western European Time (El Aaiún)',
        'Africa/Freetown' => 'Greenwich Mean Time (Freetown)',
        'Africa/Gaborone' => 'Central Africa Time (Gaborone)',
        'Africa/Harare' => 'Central Africa Time (Harare)',
        'Africa/Johannesburg' => 'South Africa Standard Time (Johannesburg)',
        'Africa/Juba' => 'Central Africa Time (Juba)',
        'Africa/Kampala' => 'East Africa Time (Kampala)',
        'Africa/Khartoum' => 'Central Africa Time (Khartoum)',
        'Africa/Kigali' => 'Central Africa Time (Kigali)',
        'Africa/Kinshasa' => 'West Africa Time (Kinshasa)',
        'Africa/Lagos' => 'West Africa Time (Lagos)',
        'Africa/Libreville' => 'West Africa Time (Libreville)',
        'Africa/Lome' => 'Greenwich Mean Time (Lomé)',
        'Africa/Luanda' => 'West Africa Time (Luanda)',
        'Africa/Lubumbashi' => 'Central Africa Time (Lubumbashi)',
        'Africa/Lusaka' => 'Central Africa Time (Lusaka)',
        'Africa/Malabo' => 'West Africa Time (Malabo)',
        'Africa/Maputo' => 'Central Africa Time (Maputo)',
        'Africa/Maseru' => 'South Africa Standard Time (Maseru)',
        'Africa/Mbabane' => 'South Africa Standard Time (Mbabane)',
        'Africa/Mogadishu' => 'East Africa Time (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich Mean Time (Monrovia)',
        'Africa/Nairobi' => 'East Africa Time (Nairobi)',
        'Africa/Ndjamena' => 'West Africa Time (N’Djamena)',
        'Africa/Niamey' => 'West Africa Time (Niamey)',
        'Africa/Nouakchott' => 'Greenwich Mean Time (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich Mean Time (Ouagadougou)',
        'Africa/Porto-Novo' => 'West Africa Time (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich Mean Time (São Tomé)',
        'Africa/Tripoli' => 'Eastern European Time (Tripoli)',
        'Africa/Tunis' => 'Central European Time (Tunis)',
        'Africa/Windhoek' => 'Central Africa Time (Windhoek)',
        'America/Adak' => 'Hawaii-Aleutian Time (Adak)',
        'America/Anchorage' => 'Alaska Time (Anchorage)',
        'America/Anguilla' => 'Atlantic Time (Anguilla)',
        'America/Antigua' => 'Atlantic Time (Antigua)',
        'America/Araguaina' => 'Brasilia Time (Araguaína)',
        'America/Argentina/La_Rioja' => 'Argentina Time (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentina Time (Río Gallegos)',
        'America/Argentina/Salta' => 'Argentina Time (Salta)',
        'America/Argentina/San_Juan' => 'Argentina Time (San Juan)',
        'America/Argentina/San_Luis' => 'Argentina Time (San Luis)',
        'America/Argentina/Tucuman' => 'Argentina Time (Tucumán)',
        'America/Argentina/Ushuaia' => 'Argentina Time (Ushuaia)',
        'America/Aruba' => 'Atlantic Time (Aruba)',
        'America/Asuncion' => 'Paraguay Time (Asunción)',
        'America/Bahia' => 'Brasilia Time (Bahia)',
        'America/Bahia_Banderas' => 'Central Time (Bahía de Banderas)',
        'America/Barbados' => 'Atlantic Time (Barbados)',
        'America/Belem' => 'Brasilia Time (Belém)',
        'America/Belize' => 'Central Time (Belize)',
        'America/Blanc-Sablon' => 'Atlantic Time (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazon Time (Boa Vista)',
        'America/Bogota' => 'Colombia Time (Bogotá)',
        'America/Boise' => 'Mountain Time (Boise)',
        'America/Buenos_Aires' => 'Argentina Time (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Argentina Time (Buenos Aires)',
        'America/Cambridge_Bay' => 'Mountain Time (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazon Time (Campo Grande)',
        'America/Cancun' => 'Eastern Time (Cancún)',
        'America/Caracas' => 'Venezuela Time (Caracas)',
        'America/Catamarca' => 'Argentina Time (Catamarca)',
        'America/Argentina/Catamarca' => 'Argentina Time (Catamarca)',
        'America/Cayenne' => 'French Guiana Time (Cayenne)',
        'America/Cayman' => 'Eastern Time (Cayman)',
        'America/Chicago' => 'Central Time (Chicago)',
        'America/Chihuahua' => 'Central Time (Chihuahua)',
        'America/Ciudad_Juarez' => 'Mountain Time (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Eastern Time (Atikokan)',
        'America/Atikokan' => 'Eastern Time (Atikokan)',
        'America/Cordoba' => 'Argentina Time (Córdoba)',
        'America/Argentina/Cordoba' => 'Argentina Time (Córdoba)',
        'America/Costa_Rica' => 'Central Time (Costa Rica)',
        'America/Coyhaique' => 'Chile Time (Coyhaique)',
        'America/Creston' => 'Mountain Time (Creston)',
        'America/Cuiaba' => 'Amazon Time (Cuiabá)',
        'America/Curacao' => 'Atlantic Time (Curaçao)',
        'America/Danmarkshavn' => 'Greenwich Mean Time (Danmarkshavn)',
        'America/Dawson' => 'Yukon Time (Dawson)',
        'America/Dawson_Creek' => 'Mountain Time (Dawson Creek)',
        'America/Denver' => 'Mountain Time (Denver)',
        'America/Detroit' => 'Eastern Time (Detroit)',
        'America/Dominica' => 'Atlantic Time (Dominica)',
        'America/Edmonton' => 'Mountain Time (Edmonton)',
        'America/Eirunepe' => 'Acre Time (Eirunepé)',
        'America/El_Salvador' => 'Central Time (El Salvador)',
        'America/Fort_Nelson' => 'Mountain Time (Fort Nelson)',
        'America/Fortaleza' => 'Brasilia Time (Fortaleza)',
        'America/Glace_Bay' => 'Atlantic Time (Glace Bay)',
        'America/Godthab' => 'Greenland Time (Nuuk)',
        'America/Nuuk' => 'Greenland Time (Nuuk)',
        'America/Goose_Bay' => 'Atlantic Time (Goose Bay)',
        'America/Grand_Turk' => 'Eastern Time (Grand Turk)',
        'America/Grenada' => 'Atlantic Time (Grenada)',
        'America/Guadeloupe' => 'Atlantic Time (Guadeloupe)',
        'America/Guatemala' => 'Central Time (Guatemala)',
        'America/Guayaquil' => 'Ecuador Time (Guayaquil)',
        'America/Guyana' => 'Guyana Time',
        'America/Halifax' => 'Atlantic Time (Halifax)',
        'America/Havana' => 'Cuba Time (Havana)',
        'America/Hermosillo' => 'Mexican Pacific Time (Hermosillo)',
        'America/Indiana/Knox' => 'Central Time (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Eastern Time (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Eastern Time (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Central Time (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Eastern Time (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Eastern Time (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Eastern Time (Winamac, Indiana)',
        'America/Indianapolis' => 'Eastern Time (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Eastern Time (Indianapolis)',
        'America/Inuvik' => 'Mountain Time (Inuvik)',
        'America/Iqaluit' => 'Eastern Time (Iqaluit)',
        'America/Jamaica' => 'Eastern Time (Jamaica)',
        'America/Jujuy' => 'Argentina Time (Jujuy)',
        'America/Argentina/Jujuy' => 'Argentina Time (Jujuy)',
        'America/Juneau' => 'Alaska Time (Juneau)',
        'America/Kentucky/Monticello' => 'Eastern Time (Monticello, Kentucky)',
        'America/Kralendijk' => 'Atlantic Time (Kralendijk)',
        'America/La_Paz' => 'Bolivia Time (La Paz)',
        'America/Lima' => 'Peru Time (Lima)',
        'America/Los_Angeles' => 'Pacific Time (Los Angeles)',
        'America/Louisville' => 'Eastern Time (Louisville)',
        'America/Kentucky/Louisville' => 'Eastern Time (Louisville)',
        'America/Lower_Princes' => 'Atlantic Time (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasilia Time (Maceió)',
        'America/Managua' => 'Central Time (Managua)',
        'America/Manaus' => 'Amazon Time (Manaus)',
        'America/Marigot' => 'Atlantic Time (Marigot)',
        'America/Martinique' => 'Atlantic Time (Martinique)',
        'America/Matamoros' => 'Central Time (Matamoros)',
        'America/Mazatlan' => 'Mexican Pacific Time (Mazatlán)',
        'America/Mendoza' => 'Argentina Time (Mendoza)',
        'America/Argentina/Mendoza' => 'Argentina Time (Mendoza)',
        'America/Menominee' => 'Central Time (Menominee)',
        'America/Merida' => 'Central Time (Mérida)',
        'America/Metlakatla' => 'Alaska Time (Metlakatla)',
        'America/Mexico_City' => 'Central Time (Mexico City)',
        'America/Miquelon' => 'St. Pierre & Miquelon Time (Saint-Pierre)',
        'America/Moncton' => 'Atlantic Time (Moncton)',
        'America/Monterrey' => 'Central Time (Monterrey)',
        'America/Montevideo' => 'Uruguay Time (Montevideo)',
        'America/Montserrat' => 'Atlantic Time (Montserrat)',
        'America/Nassau' => 'Eastern Time (Nassau)',
        'America/New_York' => 'Eastern Time (New York)',
        'America/Nome' => 'Alaska Time (Nome)',
        'America/Noronha' => 'Fernando de Noronha Time',
        'America/North_Dakota/Beulah' => 'Central Time (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Central Time (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Central Time (New Salem, North Dakota)',
        'America/Ojinaga' => 'Central Time (Ojinaga)',
        'America/Panama' => 'Eastern Time (Panama)',
        'America/Paramaribo' => 'Suriname Time (Paramaribo)',
        'America/Phoenix' => 'Mountain Time (Phoenix)',
        'America/Port-au-Prince' => 'Eastern Time (Port-au-Prince)',
        'America/Port_of_Spain' => 'Atlantic Time (Port of Spain)',
        'America/Porto_Velho' => 'Amazon Time (Porto Velho)',
        'America/Puerto_Rico' => 'Atlantic Time (Puerto Rico)',
        'America/Punta_Arenas' => 'Chile Time (Punta Arenas)',
        'America/Rankin_Inlet' => 'Central Time (Rankin Inlet)',
        'America/Recife' => 'Brasilia Time (Recife)',
        'America/Regina' => 'Central Time (Regina)',
        'America/Resolute' => 'Central Time (Resolute)',
        'America/Rio_Branco' => 'Acre Time (Rio Branco)',
        'America/Santarem' => 'Brasilia Time (Santarém)',
        'America/Santiago' => 'Chile Time (Santiago)',
        'America/Santo_Domingo' => 'Atlantic Time (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasilia Time (São Paulo)',
        'America/Scoresbysund' => 'Greenland Time (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaska Time (Sitka)',
        'America/St_Barthelemy' => 'Atlantic Time (St. Barthélemy)',
        'America/St_Johns' => 'Newfoundland Time (St. John’s)',
        'America/St_Kitts' => 'Atlantic Time (St. Kitts)',
        'America/St_Lucia' => 'Atlantic Time (St. Lucia)',
        'America/St_Thomas' => 'Atlantic Time (St. Thomas)',
        'America/St_Vincent' => 'Atlantic Time (St. Vincent)',
        'America/Swift_Current' => 'Central Time (Swift Current)',
        'America/Tegucigalpa' => 'Central Time (Tegucigalpa)',
        'America/Thule' => 'Atlantic Time (Thule)',
        'America/Tijuana' => 'Pacific Time (Tijuana)',
        'America/Toronto' => 'Eastern Time (Toronto)',
        'America/Tortola' => 'Atlantic Time (Tortola)',
        'America/Vancouver' => 'Pacific Time (Vancouver)',
        'America/Whitehorse' => 'Yukon Time (Whitehorse)',
        'America/Winnipeg' => 'Central Time (Winnipeg)',
        'America/Yakutat' => 'Alaska Time (Yakutat)',
        'Antarctica/Casey' => 'Australian Western Time (Casey Station)',
        'Antarctica/Davis' => 'Davis Time',
        'Antarctica/DumontDUrville' => 'Dumont d’Urville Time (Dumont d’Urville Station)',
        'Antarctica/Macquarie' => 'Australian Eastern Time (Macquarie Island)',
        'Antarctica/Mawson' => 'Mawson Time (Mawson Station)',
        'Antarctica/McMurdo' => 'New Zealand Time (McMurdo Station)',
        'Antarctica/Palmer' => 'Chile Time (Palmer Land)',
        'Antarctica/Rothera' => 'Rothera Time (Rothera Station)',
        'Antarctica/Syowa' => 'Syowa Time (Showa Station)',
        'Antarctica/Troll' => 'Greenwich Mean Time (Troll Station)',
        'Antarctica/Vostok' => 'Vostok Time (Vostok Station)',
        'Arctic/Longyearbyen' => 'Central European Time (Longyearbyen)',
        'Asia/Aden' => 'Arabian Time (Aden)',
        'Asia/Almaty' => 'Kazakhstan Time (Almaty)',
        'Asia/Amman' => 'Eastern European Time (Amman)',
        'Asia/Anadyr' => 'Kamchatka Time (Anadyr)',
        'Asia/Aqtau' => 'Kazakhstan Time (Aktau)',
        'Asia/Aqtobe' => 'Kazakhstan Time (Aqtobe)',
        'Asia/Ashgabat' => 'Turkmenistan Time (Ashgabat)',
        'Asia/Atyrau' => 'Kazakhstan Time (Atyrau)',
        'Asia/Baghdad' => 'Arabian Time (Baghdad)',
        'Asia/Bahrain' => 'Arabian Time (Bahrain)',
        'Asia/Baku' => 'Azerbaijan Time (Baku)',
        'Asia/Bangkok' => 'Indochina Time (Bangkok)',
        'Asia/Barnaul' => 'Krasnoyarsk Time (Barnaul)',
        'Asia/Beirut' => 'Eastern European Time (Beirut)',
        'Asia/Bishkek' => 'Kyrgyzstan Time (Bishkek)',
        'Asia/Brunei' => 'Brunei Time',
        'Asia/Calcutta' => 'India Standard Time (Kolkata)',
        'Asia/Kolkata' => 'India Standard Time (Kolkata)',
        'Asia/Chita' => 'Yakutsk Time (Chita)',
        'Asia/Colombo' => 'India Standard Time (Colombo)',
        'Asia/Damascus' => 'Eastern European Time (Damascus)',
        'Asia/Dhaka' => 'Bangladesh Time (Dhaka)',
        'Asia/Dili' => 'Timor-Leste Time (Dili)',
        'Asia/Dubai' => 'Gulf Standard Time (Dubai)',
        'Asia/Dushanbe' => 'Tajikistan Time (Dushanbe)',
        'Asia/Famagusta' => 'Eastern European Time (Famagusta)',
        'Asia/Gaza' => 'Eastern European Time (Gaza)',
        'Asia/Hebron' => 'Eastern European Time (Hebron)',
        'Asia/Hong_Kong' => 'Hong Kong Time',
        'Asia/Hovd' => 'Khovd Time',
        'Asia/Irkutsk' => 'Irkutsk Time',
        'Asia/Jakarta' => 'Western Indonesia Time (Jakarta)',
        'Asia/Jayapura' => 'Eastern Indonesia Time (Jayapura)',
        'Asia/Jerusalem' => 'Israel Time (Jerusalem)',
        'Asia/Kabul' => 'Afghanistan Time (Kabul)',
        'Asia/Kamchatka' => 'Kamchatka Time',
        'Asia/Karachi' => 'Pakistan Time (Karachi)',
        'Asia/Katmandu' => 'Nepal Time (Kathmandu)',
        'Asia/Kathmandu' => 'Nepal Time (Kathmandu)',
        'Asia/Khandyga' => 'Yakutsk Time (Khandyga)',
        'Asia/Krasnoyarsk' => 'Krasnoyarsk Time',
        'Asia/Kuala_Lumpur' => 'Malaysia Time (Kuala Lumpur)',
        'Asia/Kuching' => 'Malaysia Time (Kuching)',
        'Asia/Kuwait' => 'Arabian Time (Kuwait)',
        'Asia/Macau' => 'China Time (Macao)',
        'Asia/Magadan' => 'Magadan Time',
        'Asia/Makassar' => 'Central Indonesia Time (Makassar)',
        'Asia/Manila' => 'Philippine Time (Manila)',
        'Asia/Muscat' => 'Gulf Standard Time (Muscat)',
        'Asia/Nicosia' => 'Eastern European Time (Nicosia)',
        'Asia/Novokuznetsk' => 'Krasnoyarsk Time (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Krasnoyarsk Time (Novosibirsk)',
        'Asia/Omsk' => 'Omsk Time',
        'Asia/Oral' => 'Kazakhstan Time (Oral)',
        'Asia/Phnom_Penh' => 'Indochina Time (Phnom Penh)',
        'Asia/Pontianak' => 'Western Indonesia Time (Pontianak)',
        'Asia/Pyongyang' => 'Korean Time (Pyongyang)',
        'Asia/Qatar' => 'Arabian Time (Qatar)',
        'Asia/Qostanay' => 'Kazakhstan Time (Kostanay)',
        'Asia/Qyzylorda' => 'Kazakhstan Time (Kyzylorda)',
        'Asia/Rangoon' => 'Myanmar Time (Yangon)',
        'Asia/Yangon' => 'Myanmar Time (Yangon)',
        'Asia/Riyadh' => 'Arabian Time (Riyadh)',
        'Asia/Saigon' => 'Indochina Time (Ho Chi Minh City)',
        'Asia/Ho_Chi_Minh' => 'Indochina Time (Ho Chi Minh City)',
        'Asia/Sakhalin' => 'Magadan Time (Sakhalin)',
        'Asia/Samarkand' => 'Uzbekistan Time (Samarkand)',
        'Asia/Seoul' => 'Korean Time (Seoul)',
        'Asia/Shanghai' => 'China Time (Shanghai)',
        'Asia/Singapore' => 'Singapore Standard Time',
        'Asia/Srednekolymsk' => 'Magadan Time (Srednekolymsk)',
        'Asia/Taipei' => 'Taiwan Time (Taipei)',
        'Asia/Tashkent' => 'Uzbekistan Time (Tashkent)',
        'Asia/Tbilisi' => 'Georgia Time (Tbilisi)',
        'Asia/Tehran' => 'Iran Time (Tehran)',
        'Asia/Thimphu' => 'Bhutan Time (Thimphu)',
        'Asia/Tokyo' => 'Japan Time (Tokyo)',
        'Asia/Tomsk' => 'Krasnoyarsk Time (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulaanbaatar Time',
        'Asia/Urumqi' => 'China Time (Ürümqi)',
        'Asia/Ust-Nera' => 'Vladivostok Time (Ust-Nera)',
        'Asia/Vientiane' => 'Indochina Time (Vientiane)',
        'Asia/Vladivostok' => 'Vladivostok Time',
        'Asia/Yakutsk' => 'Yakutsk Time',
        'Asia/Yekaterinburg' => 'Yekaterinburg Time',
        'Asia/Yerevan' => 'Armenia Time (Yerevan)',
        'Atlantic/Azores' => 'Azores Time',
        'Atlantic/Bermuda' => 'Atlantic Time (Bermuda)',
        'Atlantic/Canary' => 'Western European Time (Canaries)',
        'Atlantic/Cape_Verde' => 'Cape Verde Time',
        'Atlantic/Faeroe' => 'Western European Time (Faroes)',
        'Atlantic/Faroe' => 'Western European Time (Faroes)',
        'Atlantic/Madeira' => 'Western European Time (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich Mean Time (Reykjavik)',
        'Atlantic/South_Georgia' => 'South Georgia Time',
        'Atlantic/St_Helena' => 'Greenwich Mean Time (St. Helena)',
        'Atlantic/Stanley' => 'Falkland Islands Time (Stanley)',
        'Australia/Adelaide' => 'Australian Central Time (Adelaide)',
        'Australia/Brisbane' => 'Australian Eastern Time (Brisbane)',
        'Australia/Broken_Hill' => 'Australian Central Time (Broken Hill)',
        'Australia/Darwin' => 'Australian Central Time (Darwin)',
        'Australia/Eucla' => 'Australian Central Western Time (Eucla)',
        'Australia/Hobart' => 'Australian Eastern Time (Hobart)',
        'Australia/Lindeman' => 'Australian Eastern Time (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howe Time (Lord Howe Island)',
        'Australia/Melbourne' => 'Australian Eastern Time (Melbourne)',
        'Australia/Perth' => 'Australian Western Time (Perth)',
        'Australia/Sydney' => 'Australian Eastern Time (Sydney)',
        'Etc/GMT' => 'Greenwich Mean Time',
        'Etc/UTC' => 'Coordinated Universal Time',
        'Europe/Amsterdam' => 'Central European Time (Amsterdam)',
        'Europe/Andorra' => 'Central European Time (Andorra)',
        'Europe/Astrakhan' => 'Samara Time (Astrakhan)',
        'Europe/Athens' => 'Eastern European Time (Athens)',
        'Europe/Belgrade' => 'Central European Time (Belgrade)',
        'Europe/Berlin' => 'Central European Time (Berlin)',
        'Europe/Bratislava' => 'Central European Time (Bratislava)',
        'Europe/Brussels' => 'Central European Time (Brussels)',
        'Europe/Bucharest' => 'Eastern European Time (Bucharest)',
        'Europe/Budapest' => 'Central European Time (Budapest)',
        'Europe/Busingen' => 'Central European Time (Büsingen)',
        'Europe/Chisinau' => 'Eastern European Time (Chișinău)',
        'Europe/Copenhagen' => 'Central European Time (Copenhagen)',
        'Europe/Dublin' => 'Greenwich Mean Time (Dublin)',
        'Europe/Gibraltar' => 'Central European Time (Gibraltar)',
        'Europe/Guernsey' => 'Greenwich Mean Time (Guernsey)',
        'Europe/Helsinki' => 'Eastern European Time (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwich Mean Time (Isle of Man)',
        'Europe/Istanbul' => 'Türkiye Time (Istanbul)',
        'Europe/Jersey' => 'Greenwich Mean Time (Jersey)',
        'Europe/Kaliningrad' => 'Eastern European Time (Kaliningrad)',
        'Europe/Kiev' => 'Eastern European Time (Kyiv)',
        'Europe/Kyiv' => 'Eastern European Time (Kyiv)',
        'Europe/Kirov' => 'Moscow Time (Kirov)',
        'Europe/Lisbon' => 'Western European Time (Lisbon)',
        'Europe/Ljubljana' => 'Central European Time (Ljubljana)',
        'Europe/London' => 'Greenwich Mean Time (London)',
        'Europe/Luxembourg' => 'Central European Time (Luxembourg)',
        'Europe/Madrid' => 'Central European Time (Madrid)',
        'Europe/Malta' => 'Central European Time (Malta)',
        'Europe/Mariehamn' => 'Eastern European Time (Mariehamn)',
        'Europe/Minsk' => 'Moscow Time (Minsk)',
        'Europe/Monaco' => 'Central European Time (Monaco)',
        'Europe/Moscow' => 'Moscow Time',
        'Europe/Oslo' => 'Central European Time (Oslo)',
        'Europe/Paris' => 'Central European Time (Paris)',
        'Europe/Podgorica' => 'Central European Time (Podgorica)',
        'Europe/Prague' => 'Central European Time (Prague)',
        'Europe/Riga' => 'Eastern European Time (Riga)',
        'Europe/Rome' => 'Central European Time (Rome)',
        'Europe/Samara' => 'Samara Time',
        'Europe/San_Marino' => 'Central European Time (San Marino)',
        'Europe/Sarajevo' => 'Central European Time (Sarajevo)',
        'Europe/Saratov' => 'Samara Time (Saratov)',
        'Europe/Simferopol' => 'Moscow Time (Simferopol)',
        'Europe/Skopje' => 'Central European Time (Skopje)',
        'Europe/Sofia' => 'Eastern European Time (Sofia)',
        'Europe/Stockholm' => 'Central European Time (Stockholm)',
        'Europe/Tallinn' => 'Eastern European Time (Tallinn)',
        'Europe/Tirane' => 'Central European Time (Tirana)',
        'Europe/Ulyanovsk' => 'Samara Time (Ulyanovsk)',
        'Europe/Vaduz' => 'Central European Time (Vaduz)',
        'Europe/Vatican' => 'Central European Time (Vatican)',
        'Europe/Vienna' => 'Central European Time (Vienna)',
        'Europe/Vilnius' => 'Eastern European Time (Vilnius)',
        'Europe/Volgograd' => 'Moscow Time (Volgograd)',
        'Europe/Warsaw' => 'Central European Time (Warsaw)',
        'Europe/Zagreb' => 'Central European Time (Zagreb)',
        'Europe/Zurich' => 'Central European Time (Zurich)',
        'Indian/Antananarivo' => 'East Africa Time (Antananarivo)',
        'Indian/Chagos' => 'Indian Ocean Time (Chagos Archipelago)',
        'Indian/Christmas' => 'Christmas Island Time',
        'Indian/Cocos' => 'Cocos Islands Time',
        'Indian/Comoro' => 'East Africa Time (Comoros)',
        'Indian/Kerguelen' => 'French Southern & Antarctic Time (Kerguelen Islands)',
        'Indian/Mahe' => 'Seychelles Time (Mahé)',
        'Indian/Maldives' => 'Maldives Time',
        'Indian/Mauritius' => 'Mauritius Time',
        'Indian/Mayotte' => 'East Africa Time (Mayotte)',
        'Indian/Reunion' => 'Réunion Time',
        'Pacific/Apia' => 'Samoa Time (Apia)',
        'Pacific/Auckland' => 'New Zealand Time (Auckland)',
        'Pacific/Bougainville' => 'Papua New Guinea Time (Bougainville)',
        'Pacific/Chatham' => 'Chatham Time (Chatham Islands)',
        'Pacific/Easter' => 'Easter Island Time',
        'Pacific/Efate' => 'Vanuatu Time (Efate)',
        'Pacific/Enderbury' => 'Phoenix Islands Time (Canton Island)',
        'Pacific/Kanton' => 'Phoenix Islands Time (Canton Island)',
        'Pacific/Fakaofo' => 'Tokelau Time (Fakaofo)',
        'Pacific/Fiji' => 'Fiji Time',
        'Pacific/Funafuti' => 'Tuvalu Time (Funafuti)',
        'Pacific/Galapagos' => 'Galapagos Time (Galápagos Islands)',
        'Pacific/Gambier' => 'Gambier Time',
        'Pacific/Guadalcanal' => 'Solomon Islands Time (Guadalcanal)',
        'Pacific/Guam' => 'Chamorro Standard Time (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleutian Standard Time (Honolulu)',
        'Pacific/Kiritimati' => 'Line Islands Time (Kiritimati)',
        'Pacific/Kosrae' => 'Kosrae Time',
        'Pacific/Kwajalein' => 'Marshall Islands Time (Kwajalein Atoll)',
        'Pacific/Majuro' => 'Marshall Islands Time (Majuro)',
        'Pacific/Marquesas' => 'Marquesas Time (Marquesas Islands)',
        'Pacific/Midway' => 'American Samoa Time (Midway Atoll)',
        'Pacific/Nauru' => 'Nauru Time',
        'Pacific/Niue' => 'Niue Time',
        'Pacific/Norfolk' => 'Norfolk Island Time',
        'Pacific/Noumea' => 'New Caledonia Time (Nouméa)',
        'Pacific/Pago_Pago' => 'American Samoa Time (Pago Pago)',
        'Pacific/Palau' => 'Palau Time',
        'Pacific/Pitcairn' => 'Pitcairn Time (Pitcairn Islands)',
        'Pacific/Ponape' => 'Pohnpei Time',
        'Pacific/Pohnpei' => 'Pohnpei Time',
        'Pacific/Port_Moresby' => 'Papua New Guinea Time (Port Moresby)',
        'Pacific/Rarotonga' => 'Cook Islands Time (Rarotonga)',
        'Pacific/Saipan' => 'Chamorro Standard Time (Saipan)',
        'Pacific/Tahiti' => 'Tahiti Time',
        'Pacific/Tarawa' => 'Gilbert Islands Time (Tarawa)',
        'Pacific/Tongatapu' => 'Tonga Time (Tongatapu)',
        'Pacific/Truk' => 'Chuuk Time',
        'Pacific/Chuuk' => 'Chuuk Time',
        'Pacific/Wake' => 'Wake Island Time',
        'Pacific/Wallis' => 'Wallis & Futuna Time',
    ],
    'Meta' => [],
];
