<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'andorrská peseta',
        ],
        'AED' => [
            'AED',
            'SAE dirham',
        ],
        'AFA' => [
            'AFA',
            'afghánský afghán (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'afghánský afghán',
        ],
        'ALK' => [
            'ALK',
            'albánský lek (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'albánský lek',
        ],
        'AMD' => [
            'AMD',
            'arménský dram',
        ],
        'ANG' => [
            'ANG',
            'nizozemskoantilský gulden',
        ],
        'AOA' => [
            'AOA',
            'angolská kwanza',
        ],
        'AOK' => [
            'AOK',
            'angolská kwanza (1977–1991)',
        ],
        'AON' => [
            'AON',
            'angolská kwanza (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'angolská kwanza (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'argentinský austral',
        ],
        'ARL' => [
            'ARL',
            'argentinské peso ley (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'argentinské peso (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'argentinské peso (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'argentinské peso',
        ],
        'ATS' => [
            'ATS',
            'rakouský šilink',
        ],
        'AUD' => [
            'AU$',
            'australský dolar',
        ],
        'AWG' => [
            'AWG',
            'arubský zlatý',
        ],
        'AZM' => [
            'AZM',
            'ázerbájdžánský manat (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'ázerbájdžánský manat',
        ],
        'BAD' => [
            'BAD',
            'bosenský dinár (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'bosenská konvertibilní marka',
        ],
        'BAN' => [
            'BAN',
            'bosenský nový dinár (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'barbadoský dolar',
        ],
        'BDT' => [
            'BDT',
            'bangladéšská taka',
        ],
        'BEC' => [
            'BEC',
            'belgický konvertibilní frank',
        ],
        'BEF' => [
            'BEF',
            'belgický frank',
        ],
        'BEL' => [
            'BEL',
            'belgický finanční frank',
        ],
        'BGL' => [
            'BGL',
            'bulharský tvrdý leva',
        ],
        'BGM' => [
            'BGM',
            'bulharský socialistický leva',
        ],
        'BGN' => [
            'BGN',
            'bulharský leva',
        ],
        'BGO' => [
            'BGO',
            'bulharský lev (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'bahrajnský dinár',
        ],
        'BIF' => [
            'BIF',
            'burundský frank',
        ],
        'BMD' => [
            'BMD',
            'bermudský dolar',
        ],
        'BND' => [
            'BND',
            'brunejský dolar',
        ],
        'BOB' => [
            'BOB',
            'bolivijský boliviano',
        ],
        'BOL' => [
            'BOL',
            'bolivijský boliviano (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'bolivijské peso',
        ],
        'BOV' => [
            'BOV',
            'bolivijský mvdol',
        ],
        'BRB' => [
            'BRB',
            'brazilské nové cruzeiro (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'brazilské cruzado (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'brazilské cruzeiro (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'brazilský real',
        ],
        'BRN' => [
            'BRN',
            'brazilské nové cruzado (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'brazilské cruzeiro (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'brazilské cruzeiro (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'bahamský dolar',
        ],
        'BTN' => [
            'BTN',
            'bhútánský ngultrum',
        ],
        'BUK' => [
            'BUK',
            'barmský kyat',
        ],
        'BWP' => [
            'BWP',
            'botswanská pula',
        ],
        'BYB' => [
            'BYB',
            'běloruský rubl (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'běloruský rubl',
        ],
        'BYR' => [
            'BYR',
            'běloruský rubl (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'belizský dolar',
        ],
        'CAD' => [
            'CA$',
            'kanadský dolar',
        ],
        'CDF' => [
            'CDF',
            'konžský frank',
        ],
        'CHE' => [
            'CHE',
            'švýcarské WIR-euro',
        ],
        'CHF' => [
            'CHF',
            'švýcarský frank',
        ],
        'CHW' => [
            'CHW',
            'švýcarský WIR-frank',
        ],
        'CLE' => [
            'CLE',
            'chilské escudo',
        ],
        'CLF' => [
            'CLF',
            'chilská účetní jednotka (UF)',
        ],
        'CLP' => [
            'CLP',
            'chilské peso',
        ],
        'CNH' => [
            'CNH',
            'čínský jüan (offshore)',
        ],
        'CNX' => [
            'CNX',
            'čínský dolar ČLB',
        ],
        'CNY' => [
            'CN¥',
            'čínský jüan',
        ],
        'COP' => [
            'COP',
            'kolumbijské peso',
        ],
        'COU' => [
            'COU',
            'kolumbijská jednotka reálné hodnoty',
        ],
        'CRC' => [
            'CRC',
            'kostarický colón',
        ],
        'CSD' => [
            'CSD',
            'srbský dinár (2002–2006)',
        ],
        'CSK' => [
            'Kčs',
            'československá koruna',
        ],
        'CUC' => [
            'CUC',
            'kubánské konvertibilní peso',
        ],
        'CUP' => [
            'CUP',
            'kubánské peso',
        ],
        'CVE' => [
            'CVE',
            'kapverdské escudo',
        ],
        'CYP' => [
            'CYP',
            'kyperská libra',
        ],
        'CZK' => [
            'Kč',
            'česká koruna',
        ],
        'DDM' => [
            'DDM',
            'východoněmecká marka',
        ],
        'DEM' => [
            'DEM',
            'německá marka',
        ],
        'DJF' => [
            'DJF',
            'džibutský frank',
        ],
        'DKK' => [
            'DKK',
            'dánská koruna',
        ],
        'DOP' => [
            'DOP',
            'dominikánské peso',
        ],
        'DZD' => [
            'DZD',
            'alžírský dinár',
        ],
        'ECS' => [
            'ECS',
            'ekvádorský sucre',
        ],
        'ECV' => [
            'ECV',
            'ekvádorská jednotka konstantní hodnoty',
        ],
        'EEK' => [
            'EEK',
            'estonská koruna',
        ],
        'EGP' => [
            'EGP',
            'egyptská libra',
        ],
        'ERN' => [
            'ERN',
            'eritrejská nakfa',
        ],
        'ESA' => [
            'ESA',
            'španělská peseta („A“ účet)',
        ],
        'ESB' => [
            'ESB',
            'španělská peseta (konvertibilní účet)',
        ],
        'ESP' => [
            'ESP',
            'španělská peseta',
        ],
        'ETB' => [
            'ETB',
            'etiopský birr',
        ],
        'EUR' => [
            '€',
            'euro',
        ],
        'FIM' => [
            'FIM',
            'finská marka',
        ],
        'FJD' => [
            'FJD',
            'fidžijský dolar',
        ],
        'FKP' => [
            'FKP',
            'falklandská libra',
        ],
        'FRF' => [
            'FRF',
            'francouzský frank',
        ],
        'GBP' => [
            '£',
            'britská libra',
        ],
        'GEK' => [
            'GEK',
            'gruzínské kuponové lari',
        ],
        'GEL' => [
            'GEL',
            'gruzínské lari',
        ],
        'GHC' => [
            'GHC',
            'ghanský cedi (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'ghanský cedi',
        ],
        'GIP' => [
            'GIP',
            'gibraltarská libra',
        ],
        'GMD' => [
            'GMD',
            'gambijský dalasi',
        ],
        'GNF' => [
            'GNF',
            'guinejský frank',
        ],
        'GNS' => [
            'GNS',
            'guinejský syli',
        ],
        'GQE' => [
            'GQE',
            'rovníkovoguinejský ekwele',
        ],
        'GRD' => [
            'GRD',
            'řecká drachma',
        ],
        'GTQ' => [
            'GTQ',
            'guatemalský quetzal',
        ],
        'GWE' => [
            'GWE',
            'portugalskoguinejské escudo',
        ],
        'GWP' => [
            'GWP',
            'guinejsko-bissauské peso',
        ],
        'GYD' => [
            'GYD',
            'guyanský dolar',
        ],
        'HKD' => [
            'HK$',
            'hongkongský dolar',
        ],
        'HNL' => [
            'HNL',
            'honduraská lempira',
        ],
        'HRD' => [
            'HRD',
            'chorvatský dinár',
        ],
        'HRK' => [
            'HRK',
            'chorvatská kuna',
        ],
        'HTG' => [
            'HTG',
            'haitský gourde',
        ],
        'HUF' => [
            'HUF',
            'maďarský forint',
        ],
        'IDR' => [
            'IDR',
            'indonéská rupie',
        ],
        'IEP' => [
            'IEP',
            'irská libra',
        ],
        'ILP' => [
            'ILP',
            'izraelská libra',
        ],
        'ILR' => [
            'ILR',
            'izraelský šekel (1980–1985)',
        ],
        'ILS' => [
            'ILS',
            'izraelský nový šekel',
        ],
        'INR' => [
            'INR',
            'indická rupie',
        ],
        'IQD' => [
            'IQD',
            'irácký dinár',
        ],
        'IRR' => [
            'IRR',
            'íránský rijál',
        ],
        'ISJ' => [
            'ISJ',
            'islandská koruna (1918–1981)',
        ],
        'ISK' => [
            'ISK',
            'islandská koruna',
        ],
        'ITL' => [
            'ITL',
            'italská lira',
        ],
        'JMD' => [
            'JMD',
            'jamajský dolar',
        ],
        'JOD' => [
            'JOD',
            'jordánský dinár',
        ],
        'JPY' => [
            'JP¥',
            'japonský jen',
        ],
        'KES' => [
            'KES',
            'keňský šilink',
        ],
        'KGS' => [
            'KGS',
            'kyrgyzský som',
        ],
        'KHR' => [
            'KHR',
            'kambodžský riel',
        ],
        'KMF' => [
            'KMF',
            'komorský frank',
        ],
        'KPW' => [
            'KPW',
            'severokorejský won',
        ],
        'KRH' => [
            'KRH',
            'jihokorejský hwan (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'jihokorejský won (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'jihokorejský won',
        ],
        'KWD' => [
            'KWD',
            'kuvajtský dinár',
        ],
        'KYD' => [
            'KYD',
            'kajmanský dolar',
        ],
        'KZT' => [
            'KZT',
            'kazašské tenge',
        ],
        'LAK' => [
            'LAK',
            'laoský kip',
        ],
        'LBP' => [
            'LBP',
            'libanonská libra',
        ],
        'LKR' => [
            'LKR',
            'srílanská rupie',
        ],
        'LRD' => [
            'LRD',
            'liberijský dolar',
        ],
        'LSL' => [
            'LSL',
            'lesothský loti',
        ],
        'LTL' => [
            'LTL',
            'litevský litas',
        ],
        'LTT' => [
            'LTT',
            'litevský talonas',
        ],
        'LUC' => [
            'LUC',
            'lucemburský konvertibilní frank',
        ],
        'LUF' => [
            'LUF',
            'lucemburský frank',
        ],
        'LUL' => [
            'LUL',
            'lucemburský finanční frank',
        ],
        'LVL' => [
            'LVL',
            'lotyšský lat',
        ],
        'LVR' => [
            'LVR',
            'lotyšský rubl',
        ],
        'LYD' => [
            'LYD',
            'libyjský dinár',
        ],
        'MAD' => [
            'MAD',
            'marocký dinár',
        ],
        'MAF' => [
            'MAF',
            'marocký frank',
        ],
        'MCF' => [
            'MCF',
            'monacký frank',
        ],
        'MDC' => [
            'MDC',
            'moldavský kupon',
        ],
        'MDL' => [
            'MDL',
            'moldavský leu',
        ],
        'MGA' => [
            'MGA',
            'madagaskarský ariary',
        ],
        'MGF' => [
            'MGF',
            'madagaskarský frank',
        ],
        'MKD' => [
            'MKD',
            'makedonský denár',
        ],
        'MKN' => [
            'MKN',
            'makedonský denár (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'malijský frank',
        ],
        'MMK' => [
            'MMK',
            'myanmarský kyat',
        ],
        'MNT' => [
            'MNT',
            'mongolský tugrik',
        ],
        'MOP' => [
            'MOP',
            'macajská pataca',
        ],
        'MRO' => [
            'MRO',
            'mauritánská ouguiya (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'mauritánská ouguiya',
        ],
        'MTL' => [
            'MTL',
            'maltská lira',
        ],
        'MTP' => [
            'MTP',
            'maltská libra',
        ],
        'MUR' => [
            'MUR',
            'mauricijská rupie',
        ],
        'MVP' => [
            'MVP',
            'maledivská rupie (1947–1981)',
        ],
        'MVR' => [
            'MVR',
            'maledivská rupie',
        ],
        'MWK' => [
            'MWK',
            'malawijská kwacha',
        ],
        'MXN' => [
            'MX$',
            'mexické peso',
        ],
        'MXP' => [
            'MXP',
            'mexické stříbrné peso (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'mexická investiční jednotka',
        ],
        'MYR' => [
            'MYR',
            'malajsijský ringgit',
        ],
        'MZE' => [
            'MZE',
            'mosambický escudo',
        ],
        'MZM' => [
            'MZM',
            'mosambický metical (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'mozambický metical',
        ],
        'NAD' => [
            'NAD',
            'namibijský dolar',
        ],
        'NGN' => [
            'NGN',
            'nigerijská naira',
        ],
        'NIC' => [
            'NIC',
            'nikaragujská córdoba (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'nikaragujská córdoba',
        ],
        'NLG' => [
            'NLG',
            'nizozemský gulden',
        ],
        'NOK' => [
            'NOK',
            'norská koruna',
        ],
        'NPR' => [
            'NPR',
            'nepálská rupie',
        ],
        'NZD' => [
            'NZ$',
            'novozélandský dolar',
        ],
        'OMR' => [
            'OMR',
            'ománský rijál',
        ],
        'PAB' => [
            'PAB',
            'panamská balboa',
        ],
        'PEI' => [
            'PEI',
            'peruánská inti',
        ],
        'PEN' => [
            'PEN',
            'peruánský sol',
        ],
        'PES' => [
            'PES',
            'peruánský sol (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'papuánská nová kina',
        ],
        'PHP' => [
            'PHP',
            'filipínské peso',
        ],
        'PKR' => [
            'PKR',
            'pákistánská rupie',
        ],
        'PLN' => [
            'PLN',
            'polský zlotý',
        ],
        'PLZ' => [
            'PLZ',
            'polský zlotý (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'portugalské escudo',
        ],
        'PYG' => [
            'PYG',
            'paraguajské guarani',
        ],
        'QAR' => [
            'QAR',
            'katarský rijál',
        ],
        'RHD' => [
            'RHD',
            'rhodéský dolar',
        ],
        'ROL' => [
            'ROL',
            'rumunské leu (1952–2006)',
        ],
        'RON' => [
            'RON',
            'rumunský leu',
        ],
        'RSD' => [
            'RSD',
            'srbský dinár',
        ],
        'RUB' => [
            'RUB',
            'ruský rubl',
        ],
        'RUR' => [
            'RUR',
            'ruský rubl (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'rwandský frank',
        ],
        'SAR' => [
            'SAR',
            'saúdský rijál',
        ],
        'SBD' => [
            'SBD',
            'šalamounský dolar',
        ],
        'SCR' => [
            'SCR',
            'seychelská rupie',
        ],
        'SDD' => [
            'SDD',
            'súdánský dinár (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'súdánská libra',
        ],
        'SDP' => [
            'SDP',
            'súdánská libra (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'švédská koruna',
        ],
        'SGD' => [
            'SGD',
            'singapurský dolar',
        ],
        'SHP' => [
            'SHP',
            'svatohelenská libra',
        ],
        'SIT' => [
            'SIT',
            'slovinský tolar',
        ],
        'SKK' => [
            'SKK',
            'slovenská koruna',
        ],
        'SLE' => [
            'SLE',
            'sierraleonský leone',
        ],
        'SLL' => [
            'SLL',
            'sierraleonský leone (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'somálský šilink',
        ],
        'SRD' => [
            'SRD',
            'surinamský dolar',
        ],
        'SRG' => [
            'SRG',
            'surinamský zlatý',
        ],
        'SSP' => [
            'SSP',
            'jihosúdánská libra',
        ],
        'STD' => [
            'STD',
            'svatotomášská dobra (1977–2017)',
        ],
        'STN' => [
            'STN',
            'svatotomášská dobra',
        ],
        'SUR' => [
            'SUR',
            'sovětský rubl',
        ],
        'SVC' => [
            'SVC',
            'salvadorský colón',
        ],
        'SYP' => [
            'SYP',
            'syrská libra',
        ],
        'SZL' => [
            'SZL',
            'svazijský lilangeni',
        ],
        'THB' => [
            'THB',
            'thajský baht',
        ],
        'TJR' => [
            'TJR',
            'tádžický rubl',
        ],
        'TJS' => [
            'TJS',
            'tádžické somoni',
        ],
        'TMM' => [
            'TMM',
            'turkmenský manat (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'turkmenský manat',
        ],
        'TND' => [
            'TND',
            'tuniský dinár',
        ],
        'TOP' => [
            'TOP',
            'tonžská paanga',
        ],
        'TPE' => [
            'TPE',
            'timorské escudo',
        ],
        'TRL' => [
            'TRL',
            'turecká lira (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'turecká lira',
        ],
        'TTD' => [
            'TTD',
            'trinidadský dolar',
        ],
        'TWD' => [
            'NT$',
            'tchajwanský dolar',
        ],
        'TZS' => [
            'TZS',
            'tanzanský šilink',
        ],
        'UAH' => [
            'UAH',
            'ukrajinská hřivna',
        ],
        'UAK' => [
            'UAK',
            'ukrajinský karbovanec',
        ],
        'UGS' => [
            'UGS',
            'ugandský šilink (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'ugandský šilink',
        ],
        'USD' => [
            'US$',
            'americký dolar',
        ],
        'USN' => [
            'USN',
            'americký dolar (příští den)',
        ],
        'USS' => [
            'USS',
            'americký dolar (týž den)',
        ],
        'UYI' => [
            'UYI',
            'uruguayské peso (v indexovaných jednotkách)',
        ],
        'UYP' => [
            'UYP',
            'uruguayské peso (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'uruguayské peso',
        ],
        'UZS' => [
            'UZS',
            'uzbecký sum',
        ],
        'VEB' => [
            'VEB',
            'venezuelský bolívar (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'venezuelský bolívar (2008–2018)',
        ],
        'VES' => [
            'VES',
            'venezuelský bolívar',
        ],
        'VND' => [
            'VND',
            'vietnamský dong',
        ],
        'VNN' => [
            'VNN',
            'vietnamský dong (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'vanuatský vatu',
        ],
        'WST' => [
            'WST',
            'samojská tala',
        ],
        'XAF' => [
            'FCFA',
            'CFA/BEAC frank',
        ],
        'XCD' => [
            'EC$',
            'východokaribský dolar',
        ],
        'XCG' => [
            'Cg.',
            'karibský gulden',
        ],
        'XEU' => [
            'ECU',
            'evropská měnová jednotka',
        ],
        'XFO' => [
            'XFO',
            'francouzský zlatý frank',
        ],
        'XFU' => [
            'XFU',
            'francouzský UIC frank',
        ],
        'XOF' => [
            'F CFA',
            'CFA/BCEAO frank',
        ],
        'XPF' => [
            'CFPF',
            'CFP frank',
        ],
        'XRE' => [
            'XRE',
            'kód fondů RINET',
        ],
        'YDD' => [
            'YDD',
            'jemenský dinár',
        ],
        'YER' => [
            'YER',
            'jemenský rijál',
        ],
        'YUD' => [
            'YUD',
            'jugoslávský dinár (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'jugoslávský nový dinár (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'jugoslávský konvertibilní dinár (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'jugoslávský reformovaný dinár (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'jihoafrický finanční rand',
        ],
        'ZAR' => [
            'ZAR',
            'jihoafrický rand',
        ],
        'ZMK' => [
            'ZMK',
            'zambijská kwacha (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'zambijská kwacha',
        ],
        'ZRN' => [
            'ZRN',
            'zairský nový zaire (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'zairský zaire (1971–1993)',
        ],
        'ZWD' => [
            'ZWD',
            'zimbabwský dolar (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'zimbabwský zlatý',
        ],
        'ZWL' => [
            'ZWL',
            'zimbabwský dolar (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'zimbabwský dolar (2008)',
        ],
    ],
];
