<?php

return [
    'Names' => [
        'ab' => 'Abjasia',
        'ace' => 'Achinese',
        'ada' => 'Adangme',
        'ady' => 'Adyghe',
        'af' => 'Afrikaans Simi',
        'agq' => 'Aghem Simi',
        'ain' => 'Ainu',
        'ak' => 'Akan Simi',
        'ale' => 'Aleut',
        'alt' => 'Altai Meridional',
        'am' => 'Amarico Simi',
        'an' => 'Aragonesa',
        'ann' => 'Obolo Simi',
        'anp' => 'Angika',
        'ar' => 'Arabe Simi',
        'arn' => 'Mapuche Simi',
        'arp' => 'Arapaho',
        'ars' => 'Árabe Najdi Simi',
        'as' => 'Asames Simi',
        'asa' => 'Asu Simi',
        'ast' => 'Asturiano Simi',
        'atj' => 'Atikamekw',
        'av' => 'Avaric',
        'awa' => 'Awadhi',
        'ay' => 'Aymara Simi',
        'az' => 'Azerbaiyano Simi',
        'ba' => 'Baskir Simi',
        'bal' => 'Baluchi Simi',
        'ban' => 'Balines Simi',
        'bas' => 'Basaa Simi',
        'be' => 'Bielorruso Simi',
        'bem' => 'Bemba Simi',
        'bez' => 'Bena Simi',
        'bg' => 'Bulgaro Simi',
        'bgc' => 'Haryanvi',
        'bho' => 'Bhojpuri Simi',
        'bi' => 'Bislama',
        'bin' => 'Bini',
        'bla' => 'Siksiká Simi',
        'blo' => 'Anii Simi',
        'bm' => 'Bambara Simi',
        'bn' => 'Bangla Simi',
        'bo' => 'Tibetano Simi',
        'br' => 'Breton Simi',
        'brx' => 'Bodo Simi',
        'bs' => 'Bosnio Simi',
        'bug' => 'Buginese',
        'byn' => 'Blin',
        'ca' => 'Catalan Simi',
        'cay' => 'Cayugá',
        'ccp' => 'Chakma Simi',
        'ce' => 'Checheno Simi',
        'ceb' => 'Cebuano Simi',
        'cgg' => 'Kiga Simi',
        'ch' => 'Chamorro Simi',
        'chk' => 'Chuukese Simi',
        'chm' => 'Mari Simi',
        'cho' => 'Choctaw Simi',
        'chp' => 'Chipewyan Simi',
        'chr' => 'Cheroqui Simi',
        'chy' => 'Cheyenne',
        'ckb' => 'Chawpi Kurdo Simi',
        'clc' => 'Chilcotin Simi',
        'co' => 'Corso Simi',
        'crg' => 'Michif Simi',
        'crj' => 'Cree Este del Sur Simi',
        'crk' => 'Plains Cree Simi',
        'crl' => 'Cree del Noreste Simi',
        'crm' => 'Moose Cree Simi',
        'crr' => 'Algonquian Carolina',
        'cs' => 'Checo Simi',
        'csw' => 'Swampy Cree Simi',
        'cu' => 'Eslavo Eclesiástico Simi',
        'cv' => 'Chuvash Simi',
        'cy' => 'Gales Simi',
        'da' => 'Danes Simi',
        'dak' => 'Dakota Simi',
        'dar' => 'Dargwa Simi',
        'dav' => 'Taita Simi',
        'de' => 'Aleman Simi',
        'dgr' => 'Dogrib Simi',
        'dje' => 'Zarma Simi',
        'doi' => 'Dogri Simi',
        'dsb' => 'Bajo Sorbio Simi',
        'dua' => 'Duala Simi',
        'dv' => 'Divehi Simi',
        'dyo' => 'Jola-Fonyi Simi',
        'dz' => 'Butanés Simi',
        'dzg' => 'Dazaga Simi',
        'ebu' => 'Embu Simi',
        'ee' => 'Ewé Simi',
        'efi' => 'Efik Simi',
        'eka' => 'Ekajuk Simi',
        'el' => 'Griego Simi',
        'en' => 'Ingles Simi',
        'eo' => 'Esperanto Simi',
        'es' => 'Español Simi',
        'et' => 'Estonio Simi',
        'eu' => 'Euskera Simi',
        'ewo' => 'Ewondo Simi',
        'fa' => 'Persa Simi',
        'ff' => 'Fulah Simi',
        'fi' => 'Fines Simi',
        'fil' => 'Filipino Simi',
        'fj' => 'Fiyiano Simi',
        'fo' => 'Feroes Simi',
        'fon' => 'Fon Simi',
        'fr' => 'Frances Simi',
        'frc' => 'Francés Cajun',
        'frr' => 'Frisón del Norte Simi',
        'fur' => 'Friulano Simi',
        'fy' => 'Frison Simi',
        'ga' => 'Irlandes Simi',
        'gaa' => 'Ga Simi',
        'gd' => 'Gaelico Escoces Simi',
        'gez' => 'Geez Simi',
        'gil' => 'Gilbertese Simi',
        'gl' => 'Gallego Simi',
        'gn' => 'Guaraní Simi',
        'gor' => 'Gorontalo Simi',
        'gsw' => 'Alsaciano Simi',
        'gu' => 'Gujarati Simi',
        'guz' => 'Guzí Simi',
        'gv' => 'Manés Simi',
        'gwi' => 'Gwichʼin Simi',
        'ha' => 'Hausa Simi',
        'hai' => 'Haida Simi',
        'haw' => 'Hawaiano Simi',
        'hax' => 'Haida Meridional',
        'he' => 'Hebreo Simi',
        'hi' => 'Hindi Simi',
        'hil' => 'Hiligaynon Simi',
        'hmn' => 'Hmong Daw Simi',
        'hr' => 'Croata Simi',
        'hsb' => 'Alto Sorbio Simi',
        'ht' => 'Haitiano Criollo Simi',
        'hu' => 'Hungaro Simi',
        'hup' => 'Hupa Simi',
        'hur' => 'Halkomelem Simi',
        'hy' => 'Armenio Simi',
        'hz' => 'Herero Simi',
        'ia' => 'Interlingua Simi',
        'iba' => 'Iban Simi',
        'ibb' => 'Ibibio Simi',
        'id' => 'Indonesio Simi',
        'ie' => 'Interlingue Simi',
        'ig' => 'Igbo Simi',
        'ii' => 'Yi Simi',
        'ikt' => 'Inuktitut Simi (Canadá occidental)',
        'ilo' => 'Iloko Simi',
        'inh' => 'Ingush Simi',
        'io' => 'Ido Simi',
        'is' => 'Islandes Simi',
        'it' => 'Italiano Simi',
        'iu' => 'Inuktitut Simi',
        'ja' => 'Japones Simi',
        'jbo' => 'Lojban Simi',
        'jgo' => 'Ngomba Simi',
        'jmc' => 'Machame Simi',
        'jv' => 'Javanés Simi',
        'ka' => 'Georgiano Simi',
        'kab' => 'Cabilio Simi',
        'kac' => 'Kachin Simi',
        'kaj' => 'Jju Simi',
        'kam' => 'Kamba Simi',
        'kbd' => 'Kabardiano Simi',
        'kcg' => 'Tyap Simi',
        'kde' => 'Makonde Simi',
        'kea' => 'Caboverdiano Simi',
        'kfo' => 'Koro Simi',
        'kgp' => 'Kaingang Simi',
        'kha' => 'Khasi Simi',
        'khq' => 'Koyra Chiini Simi',
        'ki' => 'Kikuyu Simi',
        'kj' => 'Kuanyama Simi',
        'kk' => 'Kazajo Simi',
        'kkj' => 'Kako Simi',
        'kl' => 'Groenlandes Simi',
        'kln' => 'Kalenjin Simi',
        'km' => 'Khmer Simi',
        'kmb' => 'Kimbundu Simi',
        'kn' => 'Kannada Simi',
        'ko' => 'Coreano Simi',
        'kok' => 'Konkani Simi',
        'kpe' => 'Kpelle Simi',
        'kr' => 'Kanuri Simi',
        'krc' => 'Karachay-Balkar Simi',
        'krl' => 'Karelian Simi',
        'kru' => 'Kurukh Simi',
        'ks' => 'Cachemir Simi',
        'ksb' => 'Shambala Simi',
        'ksf' => 'Bafia Simi',
        'ksh' => 'Kölsch Simi',
        'ku' => 'Kurdo Simi',
        'kum' => 'Kumyk Simi',
        'kv' => 'Komi Simi',
        'kw' => 'Córnico Simi',
        'kwk' => 'Kwakʼwala Simi',
        'kxv' => 'Kuvi Simi',
        'ky' => 'Kirghiz Simi',
        'la' => 'Latín Simi',
        'lad' => 'Ladino Simi',
        'lag' => 'Langi Simi',
        'lb' => 'Luxemburgues Simi',
        'lez' => 'Lezghian Simi',
        'lg' => 'Luganda Simi',
        'li' => 'Limburgues Simi',
        'lij' => 'Liguria Simi',
        'lil' => 'Lillooet Simi',
        'lkt' => 'Lakota Simi',
        'lmo' => 'Lombardo Simi',
        'ln' => 'Lingala Simi',
        'lo' => 'Lao Simi',
        'lou' => 'Luisiana Criollo',
        'loz' => 'Lozi Simi',
        'lrc' => 'Luri septentrional Simi',
        'lsm' => 'Saamia Simi',
        'lt' => 'Lituano Simi',
        'lu' => 'Luba-Katanga Simi',
        'lua' => 'Luba-Lulua Simi',
        'lun' => 'Lunda Simi',
        'luo' => 'Luo Simi',
        'lus' => 'Mizo Simi',
        'luy' => 'Luyia Simi',
        'lv' => 'Leton Simi',
        'mad' => 'Madurese Simi',
        'mag' => 'Magahi Simi',
        'mai' => 'Maithili Simi',
        'mak' => 'Makasar Simi',
        'mas' => 'Masai Simi',
        'mdf' => 'Moksha Simi',
        'men' => 'Mende Simi',
        'mer' => 'Meru Simi',
        'mfe' => 'Mauriciano Simi',
        'mg' => 'Malgache Simi',
        'mgh' => 'Makhuwa-Meetto Simi',
        'mgo' => 'Metaʼ Simi',
        'mh' => 'Marshallese Simi',
        'mi' => 'Maori Simi',
        'mic' => 'Mi\'kmaq Simi',
        'min' => 'Minangkabau Simi',
        'mk' => 'Macedonio Simi',
        'ml' => 'Malayalam Simi',
        'mn' => 'Mongol Simi',
        'mni' => 'Manipuri Simi',
        'moe' => 'Innu-aimun Simi',
        'moh' => 'Mohawk Simi',
        'mos' => 'Mossi Simi',
        'mr' => 'Marathi Simi',
        'ms' => 'Malayo Simi',
        'mt' => 'Maltes Simi',
        'mua' => 'Mundang Simi',
        'mus' => 'Muscogee Simi',
        'mwl' => 'Mirandés Simi',
        'my' => 'Birmano Simi',
        'myv' => 'Erzya Simi',
        'mzn' => 'Mazandaraní Simi',
        'na' => 'Nauru Simi',
        'nap' => 'Neapolitan Simi',
        'naq' => 'Nama Simi',
        'nb' => 'Noruego Bokmål Simi',
        'nd' => 'Ndebele septentrional Simi',
        'nds' => 'Bajo Alemán Simi',
        'ne' => 'Nepali Simi',
        'new' => 'Newari Simi',
        'ng' => 'Ndonga Simi',
        'nia' => 'Nias Simi',
        'niu' => 'Niuean Simi',
        'nl' => 'Neerlandes Simi',
        'nmg' => 'Kwasio Ngumba Simi',
        'nn' => 'Noruego Nynorsk Simi',
        'nnh' => 'Ngiemboon Simi',
        'no' => 'Noruego Simi',
        'nog' => 'Nogai Simi',
        'nqo' => 'N’Ko Simi',
        'nr' => 'Ndebele del Sur Simi',
        'nso' => 'Sesotho Sa Leboa Simi',
        'nus' => 'Nuer Simi',
        'nv' => 'Navajo Simi',
        'ny' => 'Nyanja Simi',
        'nyn' => 'Nyankole Simi',
        'oc' => 'Occitano Simi',
        'ojb' => 'Ojibwa del noroeste Simi',
        'ojc' => 'Ojibwa Central',
        'ojs' => 'Oji-Cree Simi',
        'ojw' => 'Ojibwa Occidental',
        'oka' => 'Okanagan Simi',
        'om' => 'Oromo Simi',
        'or' => 'Odia Simi',
        'os' => 'Osetio Simi',
        'pa' => 'Punyabi Simi',
        'pag' => 'Pangasinan Simi',
        'pam' => 'Pampanga Simi',
        'pap' => 'Papiamento Simi',
        'pau' => 'Palauan Simi',
        'pcm' => 'Pidgin Nigeriano Simi',
        'pis' => 'Pijin Simi',
        'pl' => 'Polaco Simi',
        'pqm' => 'Maliseet-Passamaquoddy Simi',
        'prg' => 'Prusiano Simi',
        'ps' => 'Pashto Simi',
        'pt' => 'Portugues Simi',
        'qu' => 'Runasimi',
        'quc' => 'Kʼicheʼ Simi',
        'raj' => 'Rajasthani',
        'rap' => 'Rapanui Simi',
        'rar' => 'Rarotongan Simi',
        'rhg' => 'Rohingya Simi',
        'rm' => 'Romanche Simi',
        'rn' => 'Rundi Simi',
        'ro' => 'Rumano Simi',
        'rof' => 'Rombo Simi',
        'ru' => 'Ruso Simi',
        'rup' => 'Arrumano',
        'rw' => 'Kinyarwanda Simi',
        'rwk' => 'Rwa Simi',
        'sa' => 'Sanscrito Simi',
        'sad' => 'Sandawe Simi',
        'sah' => 'Sakha Simi',
        'saq' => 'Samburu Simi',
        'sat' => 'Santali Simi',
        'sba' => 'Ngambay Simi',
        'sbp' => 'Sangu Simi',
        'sc' => 'Sardinian Simi',
        'scn' => 'Siciliano Simi',
        'sco' => 'Scots Simi',
        'sd' => 'Sindhi Simi',
        'se' => 'Chincha Sami Simi',
        'seh' => 'Sena Simi',
        'ses' => 'Koyraboro Senni Simi',
        'sg' => 'Sango Simi',
        'shi' => 'Tashelhit Simi',
        'shn' => 'Shan Simi',
        'si' => 'Cingales Simi',
        'sk' => 'Eslovaco Simi',
        'sl' => 'Esloveno Simi',
        'slh' => 'Lushootseed Meridional',
        'sm' => 'Samoano Simi',
        'sma' => 'Qulla Sami Simi',
        'smj' => 'Sami Lule Simi',
        'smn' => 'Sami Inari Simi',
        'sms' => 'Sami Skolt Simi',
        'sn' => 'Shona Simi',
        'snk' => 'Soninke Simi',
        'so' => 'Somali Simi',
        'sq' => 'Albanes Simi',
        'sr' => 'Serbio Simi',
        'srn' => 'Sranan Tongo Simi',
        'ss' => 'Swati Simi',
        'st' => 'Soto Meridional Simi',
        'str' => 'Straits Salish Simi',
        'su' => 'Sundanés Simi',
        'suk' => 'Sukuma Simi',
        'sv' => 'Sueco Simi',
        'sw' => 'Suajili Simi',
        'swb' => 'Comorian Simi',
        'syr' => 'Siriaco Simi',
        'szl' => 'Silesiano',
        'ta' => 'Tamil Simi',
        'tce' => 'Tutchone Meridional',
        'te' => 'Telugu Simi',
        'tem' => 'Timne Simi',
        'teo' => 'Teso Simi',
        'tet' => 'Tetum Simi',
        'tg' => 'Tayiko Simi',
        'tgx' => 'Tagish Simi',
        'th' => 'Tailandes Simi',
        'tht' => 'Tahltan Simi',
        'ti' => 'Tigriña Simi',
        'tig' => 'Tigre Simi',
        'tk' => 'Turcomano Simi',
        'tlh' => 'Klingon Simi',
        'tli' => 'Tlingit Simi',
        'tn' => 'Setsuana Simi',
        'to' => 'Tongano Simi',
        'tok' => 'Toki Pona Simi',
        'tpi' => 'Tok Pisin Simi',
        'tr' => 'Turco Simi',
        'trv' => 'Taroko Simi',
        'ts' => 'Tsonga Simi',
        'tt' => 'Tartaro Simi',
        'ttm' => 'Tutchone del Norte Simi',
        'tum' => 'Tumbuka Simi',
        'tvl' => 'Tuvalu Simi',
        'twq' => 'Tasawaq Simi',
        'ty' => 'Tahití Simi',
        'tyv' => 'Tuviniano Simi',
        'tzm' => 'Tamazight Simi',
        'udm' => 'Udmurt Simi',
        'ug' => 'Uigur Simi',
        'uk' => 'Ucraniano Simi',
        'umb' => 'Umbundu Simi',
        'ur' => 'Urdu Simi',
        'uz' => 'Uzbeko Simi',
        'vai' => 'Vai Simi',
        've' => 'Venda Simi',
        'vec' => 'Veneciamanta',
        'vi' => 'Vietnamita Simi',
        'vmw' => 'Makhuwa Simi',
        'vo' => 'Volapük Simi',
        'vun' => 'Vunjo Simi',
        'wa' => 'Valona Simi',
        'wae' => 'Walser Simi',
        'wal' => 'Wolaytta Simi',
        'war' => 'Waray Simi',
        'wo' => 'Wolof Simi',
        'wuu' => 'Wu Chino',
        'xal' => 'Kalmyk Simi',
        'xh' => 'Isixhosa Simi',
        'xnr' => 'Kangri Simi',
        'xog' => 'Soga Simi',
        'yav' => 'Yangben Simi',
        'ybb' => 'Yemba Simi',
        'yi' => 'Yiddish Simi',
        'yo' => 'Yoruba Simi',
        'yrl' => 'Nheengatu Simi',
        'yue' => 'Cantonés Simi',
        'za' => 'Zhuang',
        'zgh' => 'Bereber Marroquí Estándar Simi',
        'zh' => 'Chino Simi',
        'zu' => 'Isizulu Simi',
        'zun' => 'Zuni Simi',
        'zza' => 'Zaza Simi',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Musuq Estandar Arabe Simi',
        'es_419' => 'Español Simi (Latino América)',
        'fa_AF' => 'Dari Simi',
        'nl_BE' => 'Flamenco Simi',
        'sw_CD' => 'Suajili Simi (Congo (RDC))',
        'zh_Hans' => 'Chino Simplificado Simi',
        'zh_Hant' => 'Chino Tradicional Simi',
    ],
];
