<?php

return [
    'Names' => [
        'aa' => 'afarisht',
        'ab' => 'abkazisht',
        'ace' => 'akinezisht',
        'ada' => 'andangmeisht',
        'ady' => 'adigisht',
        'af' => 'afrikanisht',
        'agq' => 'agemisht',
        'ain' => 'ajnuisht',
        'ak' => 'akanisht',
        'ale' => 'aleutisht',
        'alt' => 'altaishte jugore',
        'am' => 'amarisht',
        'an' => 'aragonezisht',
        'ann' => 'oboloisht',
        'anp' => 'angikisht',
        'ar' => 'arabisht',
        'arn' => 'mapuçisht',
        'arp' => 'arapahoisht',
        'ars' => 'arabishte naxhdi',
        'as' => 'asamezisht',
        'asa' => 'asuisht',
        'ast' => 'asturisht',
        'atj' => 'atikamekisht',
        'av' => 'avarikisht',
        'awa' => 'auadhisht',
        'ay' => 'ajmarisht',
        'az' => 'azerbajxhanisht',
        'ba' => 'bashkirisht',
        'bal' => 'balukisht',
        'ban' => 'balinezisht',
        'bas' => 'basaisht',
        'be' => 'bjellorusisht',
        'bem' => 'bembaisht',
        'bez' => 'benaisht',
        'bg' => 'bullgarisht',
        'bgc' => 'harjanvisht',
        'bgn' => 'balokishte perëndimore',
        'bho' => 'boxhpurisht',
        'bi' => 'bislamisht',
        'bin' => 'binisht',
        'bla' => 'siksikaisht',
        'blo' => 'anisht',
        'bm' => 'bambarisht',
        'bn' => 'bengalisht',
        'bo' => 'tibetisht',
        'br' => 'bretonisht',
        'brx' => 'bodoisht',
        'bs' => 'boshnjakisht',
        'bug' => 'buginezisht',
        'byn' => 'blinisht',
        'ca' => 'katalonisht',
        'cay' => 'kajugaisht',
        'ccp' => 'çakmaisht',
        'ce' => 'çeçenisht',
        'ceb' => 'sebuanisht',
        'cgg' => 'çigisht',
        'ch' => 'kamoroisht',
        'chk' => 'çukezisht',
        'chm' => 'marisht',
        'cho' => 'çoktauisht',
        'chp' => 'çipeuajanisht',
        'chr' => 'çerokisht',
        'chy' => 'çejenisht',
        'ckb' => 'kurdishte qendrore',
        'clc' => 'çilkotinisht',
        'co' => 'korsikisht',
        'crg' => 'miçifisht',
        'crj' => 'krijishte juglindore',
        'crk' => 'krijishte fusharake',
        'crl' => 'krijishte verilindore',
        'crm' => 'krijishte e Muzit',
        'crr' => 'algonkuianishte e Karolinës',
        'crs' => 'frëngjishte kreole seselve',
        'cs' => 'çekisht',
        'csw' => 'krijishte e moçaleve (Ontario)',
        'cu' => 'sllavishte kishtare',
        'cv' => 'çuvashisht',
        'cy' => 'uellsisht',
        'da' => 'danisht',
        'dak' => 'dakotisht',
        'dar' => 'darguaisht',
        'dav' => 'tajtaisht',
        'de' => 'gjermanisht',
        'dgr' => 'dogribisht',
        'dje' => 'zarmaisht',
        'doi' => 'dogrisht',
        'dsb' => 'sorbishte e poshtme',
        'dua' => 'dualaisht',
        'dv' => 'divehisht',
        'dyo' => 'xhulafonjisht',
        'dz' => 'xhongaisht',
        'dzg' => 'dazagauisht',
        'ebu' => 'embuisht',
        'ee' => 'eveisht',
        'efi' => 'efikisht',
        'eka' => 'ekajukisht',
        'el' => 'greqisht',
        'en' => 'anglisht',
        'eo' => 'esperanto',
        'es' => 'spanjisht',
        'et' => 'estonisht',
        'eu' => 'baskisht',
        'ewo' => 'euondoisht',
        'fa' => 'persisht',
        'ff' => 'fulaisht',
        'fi' => 'finlandisht',
        'fil' => 'filipinisht',
        'fj' => 'fixhianisht',
        'fo' => 'faroisht',
        'fon' => 'fonisht',
        'fr' => 'frëngjisht',
        'frc' => 'frëngjishte kajune',
        'frr' => 'frisianishte veriore',
        'fur' => 'friulianisht',
        'fy' => 'frizianishte perëndimore',
        'ga' => 'irlandisht',
        'gaa' => 'gaisht',
        'gag' => 'gagauzisht',
        'gd' => 'galishte skoceze',
        'gez' => 'gizisht',
        'gil' => 'gilbertazisht',
        'gl' => 'galicisht',
        'gn' => 'guaranisht',
        'gor' => 'gorontaloisht',
        'gsw' => 'gjermanishte zvicerane',
        'gu' => 'guxharatisht',
        'guz' => 'gusisht',
        'gv' => 'manksisht',
        'gwi' => 'guiçinisht',
        'ha' => 'hausisht',
        'hai' => 'haidaisht',
        'haw' => 'havaisht',
        'hax' => 'haidaishte jugore',
        'he' => 'hebraisht',
        'hi' => 'indisht',
        'hil' => 'hiligajnonisht',
        'hmn' => 'hmongisht',
        'hr' => 'kroatisht',
        'hsb' => 'sorbishte e sipërme',
        'ht' => 'kreolishte e Haitit',
        'hu' => 'hungarisht',
        'hup' => 'hupaisht',
        'hur' => 'halkemejlemisht',
        'hy' => 'armenisht',
        'hz' => 'hereroisht',
        'ia' => 'interlingua',
        'iba' => 'ibanisht',
        'ibb' => 'ibibioisht',
        'id' => 'indonezisht',
        'ie' => 'gjuha oksidentale',
        'ig' => 'igboisht',
        'ii' => 'sishuanisht',
        'ikt' => 'inuktitutishte kanadeze perëndimore',
        'ilo' => 'ilokoisht',
        'inh' => 'ingushisht',
        'io' => 'idoisht',
        'is' => 'islandisht',
        'it' => 'italisht',
        'iu' => 'inuktitutisht',
        'ja' => 'japonisht',
        'jbo' => 'lojbanisht',
        'jgo' => 'ngombisht',
        'jmc' => 'maçamisht',
        'jv' => 'javanisht',
        'ka' => 'gjeorgjisht',
        'kab' => 'kabilisht',
        'kac' => 'kaçinisht',
        'kaj' => 'kajeisht',
        'kam' => 'kambaisht',
        'kbd' => 'kabardianisht',
        'kcg' => 'tjapisht',
        'kde' => 'makondisht',
        'kea' => 'kreolishte e Kepit të Gjelbër',
        'kfo' => 'koroisht',
        'kgp' => 'kaingangisht',
        'kha' => 'kasisht',
        'khq' => 'kojraçinisht',
        'ki' => 'kikujuisht',
        'kj' => 'kuanjamaisht',
        'kk' => 'kazakisht',
        'kkj' => 'kakoisht',
        'kl' => 'kalalisutisht',
        'kln' => 'kalenxhinisht',
        'km' => 'kmerisht',
        'kmb' => 'kimbunduisht',
        'kn' => 'kanadisht',
        'ko' => 'koreanisht',
        'koi' => 'komi-parmjakisht',
        'kok' => 'konkanisht',
        'kpe' => 'kpeleisht',
        'kr' => 'kanurisht',
        'krc' => 'karaçaj-balkarisht',
        'krl' => 'karelianisht',
        'kru' => 'kurukisht',
        'ks' => 'kashmirisht',
        'ksb' => 'shambalisht',
        'ksf' => 'bafianisht',
        'ksh' => 'këlnisht',
        'ku' => 'kurdisht',
        'kum' => 'kumikisht',
        'kv' => 'komisht',
        'kw' => 'kornisht',
        'kwk' => 'kuakualaisht',
        'kxv' => 'kuvisht',
        'ky' => 'kirgizisht',
        'la' => 'latinisht',
        'lad' => 'ladinoisht',
        'lag' => 'langisht',
        'lb' => 'luksemburgisht',
        'lez' => 'lezgianisht',
        'lg' => 'gandaisht',
        'li' => 'limburgisht',
        'lij' => 'ligurisht',
        'lil' => 'lilluetisht',
        'lkt' => 'lakotisht',
        'lmo' => 'lombardisht',
        'ln' => 'lingalisht',
        'lo' => 'laosisht',
        'lou' => 'kreolishte e Luizianës',
        'loz' => 'lozisht',
        'lrc' => 'lurishte veriore',
        'lsm' => 'samisht',
        'lt' => 'lituanisht',
        'lu' => 'luba-katangaisht',
        'lua' => 'luba-luluaisht',
        'lun' => 'lundaisht',
        'luo' => 'luoisht',
        'lus' => 'mizoisht',
        'luy' => 'lujaisht',
        'lv' => 'letonisht',
        'mad' => 'madurezisht',
        'mag' => 'magaisht',
        'mai' => 'maitilisht',
        'mak' => 'makasarisht',
        'mas' => 'masaisht',
        'mdf' => 'mokshaisht',
        'men' => 'mendisht',
        'mer' => 'meruisht',
        'mfe' => 'morisjenisht',
        'mg' => 'madagaskarisht',
        'mgh' => 'makua-mitoisht',
        'mgo' => 'metaisht',
        'mh' => 'marshallisht',
        'mi' => 'maorisht',
        'mic' => 'mikmakisht',
        'min' => 'minangkabauisht',
        'mk' => 'maqedonisht',
        'ml' => 'malajalamisht',
        'mn' => 'mongolisht',
        'mni' => 'manipurisht',
        'moe' => 'inuaimunisht',
        'moh' => 'mohokisht',
        'mos' => 'mosisht',
        'mr' => 'maratisht',
        'ms' => 'malajisht',
        'mt' => 'maltisht',
        'mua' => 'mundangisht',
        'mus' => 'krikisht',
        'mwl' => 'mirandisht',
        'my' => 'birmanisht',
        'myv' => 'erzjaisht',
        'mzn' => 'mazanderanisht',
        'na' => 'nauruisht',
        'nap' => 'napoletanisht',
        'naq' => 'namaisht',
        'nb' => 'norvegjishte letrare',
        'nd' => 'ndebelishte veriore',
        'nds' => 'gjermanishte e vendeve të ulëta',
        'ne' => 'nepalisht',
        'new' => 'neuarisht',
        'ng' => 'ndongaisht',
        'nia' => 'niasisht',
        'niu' => 'niueanisht',
        'nl' => 'holandisht',
        'nmg' => 'kuasisht',
        'nn' => 'norvegjishte nynorsk',
        'nnh' => 'ngiembunisht',
        'no' => 'norvegjisht',
        'nog' => 'nogajisht',
        'nqo' => 'nkoisht',
        'nr' => 'ndebelishte jugore',
        'nso' => 'sotoishte veriore',
        'nus' => 'nuerisht',
        'nv' => 'navahoisht',
        'ny' => 'nianjisht',
        'nyn' => 'niankolisht',
        'oc' => 'oksitanisht',
        'ojb' => 'oxhibuaishte verilindore',
        'ojc' => 'oxhibuaishte qendrore',
        'ojs' => 'oxhikrijisht',
        'ojw' => 'oxhibuaishte perëndimore',
        'oka' => 'okanaganisht',
        'om' => 'oromoisht',
        'or' => 'odisht',
        'os' => 'osetisht',
        'pa' => 'punxhabisht',
        'pag' => 'pangasinanisht',
        'pam' => 'pampangaisht',
        'pap' => 'papiamentisht',
        'pau' => 'paluanisht',
        'pcm' => 'pixhinishte nigeriane',
        'pis' => 'pixhinisht',
        'pl' => 'polonisht',
        'pqm' => 'malisit-pasamakuadisht',
        'prg' => 'prusisht',
        'ps' => 'pashtoisht',
        'pt' => 'portugalisht',
        'qu' => 'keçuaisht',
        'quc' => 'kiçeisht',
        'raj' => 'raxhastanisht',
        'rap' => 'rapanuisht',
        'rar' => 'rarontonganisht',
        'rhg' => 'rohingiaisht',
        'rm' => 'retoromanisht',
        'rn' => 'rundisht',
        'ro' => 'rumanisht',
        'rof' => 'romboisht',
        'ru' => 'rusisht',
        'rup' => 'vllahisht',
        'rw' => 'kiniaruandisht',
        'rwk' => 'ruaisht',
        'sa' => 'sanskritisht',
        'sad' => 'sandauisht',
        'sah' => 'sakaisht',
        'saq' => 'samburisht',
        'sat' => 'santalisht',
        'sba' => 'ngambajisht',
        'sbp' => 'sanguisht',
        'sc' => 'sardenjisht',
        'scn' => 'siçilianisht',
        'sco' => 'skotisht',
        'sd' => 'sindisht',
        'sdh' => 'kurdishte jugore',
        'se' => 'samishte veriore',
        'seh' => 'senaisht',
        'ses' => 'senishte kojrabore',
        'sg' => 'sangoisht',
        'sh' => 'serbo-kroatisht',
        'shi' => 'taçelitisht',
        'shn' => 'shanisht',
        'si' => 'sinhalisht',
        'sk' => 'sllovakisht',
        'sl' => 'sllovenisht',
        'slh' => 'lashutsidishte jugore',
        'sm' => 'samoanisht',
        'sma' => 'samishte jugore',
        'smj' => 'samishte lule',
        'smn' => 'samishte inari',
        'sms' => 'samishte skolti',
        'sn' => 'shonisht',
        'snk' => 'soninkisht',
        'so' => 'somalisht',
        'sq' => 'shqip',
        'sr' => 'serbisht',
        'srn' => 'srananisht (sranantongoisht)',
        'ss' => 'suatisht',
        'ssy' => 'sahoisht',
        'st' => 'sotoishte jugore',
        'str' => 'sejlishte e Ngushticave të Rozarios',
        'su' => 'sundanisht',
        'suk' => 'sukumaisht',
        'sv' => 'suedisht',
        'sw' => 'suahilisht',
        'swb' => 'kamorianisht',
        'syr' => 'siriakisht',
        'szl' => 'silesisht',
        'ta' => 'tamilisht',
        'tce' => 'tatshonishte jugore',
        'te' => 'teluguisht',
        'tem' => 'timneisht',
        'teo' => 'tesoisht',
        'tet' => 'tetumisht',
        'tg' => 'taxhikisht',
        'tgx' => 'tagishisht',
        'th' => 'tajlandisht',
        'tht' => 'taltanisht',
        'ti' => 'tigrinjaisht',
        'tig' => 'tigreisht',
        'tk' => 'turkmenisht',
        'tlh' => 'klingonisht',
        'tli' => 'tlingitisht',
        'tn' => 'cuanaisht',
        'to' => 'tonganisht',
        'tok' => 'tokiponaisht',
        'tpi' => 'pisinishte toku',
        'tr' => 'turqisht',
        'trv' => 'torokoisht',
        'ts' => 'congaisht',
        'tt' => 'tatarisht',
        'ttm' => 'taçoneishte veriore',
        'tum' => 'tumbukaisht',
        'tvl' => 'tuvaluisht',
        'tw' => 'tuisht',
        'twq' => 'tasavakisht',
        'ty' => 'tahitisht',
        'tyv' => 'tuvinianisht',
        'tzm' => 'tamazajtisht e Atlasit Qendror',
        'udm' => 'udmurtisht',
        'ug' => 'ujgurisht',
        'uk' => 'ukrainisht',
        'umb' => 'umbunduisht',
        'ur' => 'urduisht',
        'uz' => 'uzbekisht',
        'vai' => 'vaisht',
        've' => 'vendaisht',
        'vec' => 'venetisht',
        'vi' => 'vietnamisht',
        'vmw' => 'makuvaisht',
        'vo' => 'volapykisht',
        'vun' => 'vunxhoisht',
        'wa' => 'ualunisht',
        'wae' => 'ualserisht',
        'wal' => 'ulajtaisht',
        'war' => 'uarajisht',
        'wbp' => 'uarlpirisht',
        'wo' => 'uolofisht',
        'wuu' => 'kinezishte vu',
        'xal' => 'kalmikisht',
        'xh' => 'xhosaisht',
        'xnr' => 'kangrisht',
        'xog' => 'sogisht',
        'yav' => 'jangbenisht',
        'ybb' => 'jembaisht',
        'yi' => 'jidisht',
        'yo' => 'jorubaisht',
        'yrl' => 'nejengatuisht',
        'yue' => 'kantonezisht',
        'za' => 'zhuangisht',
        'zgh' => 'tamaziatishte standarde marokene',
        'zh' => 'kinezisht',
        'zu' => 'zuluisht',
        'zun' => 'zunisht',
        'zza' => 'zazaisht',
    ],
    'LocalizedNames' => [
        'ar_001' => 'arabishte standarde moderne',
        'de_AT' => 'gjermanishte austriake',
        'de_CH' => 'gjermanishte zvicerane (dialekti i Alpeve)',
        'en_AU' => 'anglishte australiane',
        'en_CA' => 'anglishte kanadeze',
        'en_GB' => 'anglishte britanike',
        'en_US' => 'anglishte amerikane',
        'es_419' => 'spanjishte amerikano-latine',
        'es_ES' => 'spanjishte evropiane',
        'es_MX' => 'spanjishte meksikane',
        'fa_AF' => 'darisht',
        'fr_CA' => 'frëngjishte kanadeze',
        'fr_CH' => 'frëngjishte zvicerane',
        'hi_Latn' => 'hindisht (latine)',
        'nds_NL' => 'gjermanishte saksone e vendeve të ulëta',
        'nl_BE' => 'flamandisht',
        'pt_BR' => 'portugalishte braziliane',
        'pt_PT' => 'portugalishte evropiane',
        'ro_MD' => 'moldavisht',
        'sw_CD' => 'suahilishte kongoleze',
        'zh_Hans' => 'kinezishte e thjeshtuar',
        'zh_Hant' => 'kinezishte tradicionale',
    ],
];
