<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Час па Грынвічы (Абіджан)',
        'Africa/Accra' => 'Час па Грынвічы (Акра)',
        'Africa/Addis_Ababa' => 'Усходнеафрыканскі час (Адыс-Абеба)',
        'Africa/Algiers' => 'Цэнтральнаеўрапейскі час (Алжыр)',
        'Africa/Asmera' => 'Усходнеафрыканскі час (Асмара)',
        'Africa/Asmara' => 'Усходнеафрыканскі час (Асмара)',
        'Africa/Bamako' => 'Час па Грынвічы (Бамако)',
        'Africa/Bangui' => 'Заходнеафрыканскі час (Бангі)',
        'Africa/Banjul' => 'Час па Грынвічы (Банджул)',
        'Africa/Bissau' => 'Час па Грынвічы (Бісау)',
        'Africa/Blantyre' => 'Цэнтральнаафрыканскі час (Блантайр)',
        'Africa/Brazzaville' => 'Заходнеафрыканскі час (Бразавіль)',
        'Africa/Bujumbura' => 'Цэнтральнаафрыканскі час (Бужумбура)',
        'Africa/Cairo' => 'Усходнееўрапейскі час (Каір)',
        'Africa/Casablanca' => 'Заходнееўрапейскі час (Касабланка)',
        'Africa/Ceuta' => 'Цэнтральнаеўрапейскі час (Сеута)',
        'Africa/Conakry' => 'Час па Грынвічы (Конакры)',
        'Africa/Dakar' => 'Час па Грынвічы (Дакар)',
        'Africa/Dar_es_Salaam' => 'Усходнеафрыканскі час (Дар-эс-Салам)',
        'Africa/Djibouti' => 'Усходнеафрыканскі час (Джыбуці)',
        'Africa/Douala' => 'Заходнеафрыканскі час (Дуала)',
        'Africa/El_Aaiun' => 'Заходнееўрапейскі час (Эль-Аюн)',
        'Africa/Freetown' => 'Час па Грынвічы (Фрытаўн)',
        'Africa/Gaborone' => 'Цэнтральнаафрыканскі час (Габаронэ)',
        'Africa/Harare' => 'Цэнтральнаафрыканскі час (Харарэ)',
        'Africa/Johannesburg' => 'Паўднёваафрыканскі час (Яганэсбург)',
        'Africa/Juba' => 'Цэнтральнаафрыканскі час (Джуба)',
        'Africa/Kampala' => 'Усходнеафрыканскі час (Кампала)',
        'Africa/Khartoum' => 'Цэнтральнаафрыканскі час (Хартум)',
        'Africa/Kigali' => 'Цэнтральнаафрыканскі час (Кігалі)',
        'Africa/Kinshasa' => 'Заходнеафрыканскі час (Кіншаса)',
        'Africa/Lagos' => 'Заходнеафрыканскі час (Лагас)',
        'Africa/Libreville' => 'Заходнеафрыканскі час (Лібрэвіль)',
        'Africa/Lome' => 'Час па Грынвічы (Ламэ)',
        'Africa/Luanda' => 'Заходнеафрыканскі час (Луанда)',
        'Africa/Lubumbashi' => 'Цэнтральнаафрыканскі час (Лубумбашы)',
        'Africa/Lusaka' => 'Цэнтральнаафрыканскі час (Лусака)',
        'Africa/Malabo' => 'Заходнеафрыканскі час (Малаба)',
        'Africa/Maputo' => 'Цэнтральнаафрыканскі час (Мапуту)',
        'Africa/Maseru' => 'Паўднёваафрыканскі час (Масеру)',
        'Africa/Mbabane' => 'Паўднёваафрыканскі час (Мбабанэ)',
        'Africa/Mogadishu' => 'Усходнеафрыканскі час (Магадыша)',
        'Africa/Monrovia' => 'Час па Грынвічы (Манровія)',
        'Africa/Nairobi' => 'Усходнеафрыканскі час (Найробі)',
        'Africa/Ndjamena' => 'Заходнеафрыканскі час (Нджамена)',
        'Africa/Niamey' => 'Заходнеафрыканскі час (Ніямей)',
        'Africa/Nouakchott' => 'Час па Грынвічы (Нуакшот)',
        'Africa/Ouagadougou' => 'Час па Грынвічы (Уагадугу)',
        'Africa/Porto-Novo' => 'Заходнеафрыканскі час (Порта-Нова)',
        'Africa/Sao_Tome' => 'Час па Грынвічы (Сан-Тамэ)',
        'Africa/Tripoli' => 'Усходнееўрапейскі час (Трыпалі)',
        'Africa/Tunis' => 'Цэнтральнаеўрапейскі час (Туніс)',
        'Africa/Windhoek' => 'Цэнтральнаафрыканскі час (Віндхук)',
        'America/Adak' => 'Гавайска-Алеуцкі час (Адак)',
        'America/Anchorage' => 'Час Аляскі (Анкарыдж)',
        'America/Anguilla' => 'Атлантычны час (Ангілья)',
        'America/Antigua' => 'Атлантычны час (Антыгуа)',
        'America/Araguaina' => 'Бразільскі час (Арагуаіна)',
        'America/Argentina/La_Rioja' => 'Аргенцінскі час (Ла-Рыёха)',
        'America/Argentina/Rio_Gallegos' => 'Аргенцінскі час (Рыа-Гальегас)',
        'America/Argentina/Salta' => 'Аргенцінскі час (Сальта)',
        'America/Argentina/San_Juan' => 'Аргенцінскі час (Сан-Хуан)',
        'America/Argentina/San_Luis' => 'Аргенцінскі час (Сан-Луіс)',
        'America/Argentina/Tucuman' => 'Аргенцінскі час (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргенцінскі час (Ушуая)',
        'America/Aruba' => 'Атлантычны час (Аруба)',
        'America/Asuncion' => 'Час Парагвая (Асунсьён)',
        'America/Bahia' => 'Бразільскі час (Баія)',
        'America/Bahia_Banderas' => 'Паўночнаамерыканскі цэнтральны час (Баія-дэ-Бандэрас)',
        'America/Barbados' => 'Атлантычны час (Барбадас)',
        'America/Belem' => 'Бразільскі час (Белен)',
        'America/Belize' => 'Паўночнаамерыканскі цэнтральны час (Беліз)',
        'America/Blanc-Sablon' => 'Атлантычны час (Бланк-Саблон)',
        'America/Boa_Vista' => 'Амазонскі час (Боа-Віста)',
        'America/Bogota' => 'Калумбійскі час (Багата)',
        'America/Boise' => 'Паўночнаамерыканскі горны час (Бойсэ)',
        'America/Buenos_Aires' => 'Аргенцінскі час (Буэнас-Айрэс)',
        'America/Argentina/Buenos_Aires' => 'Аргенцінскі час (Буэнас-Айрэс)',
        'America/Cambridge_Bay' => 'Паўночнаамерыканскі горны час (Кембрыдж-Бей)',
        'America/Campo_Grande' => 'Амазонскі час (Кампу-Гранды)',
        'America/Cancun' => 'Паўночнаамерыканскі ўсходні час (Канкун)',
        'America/Caracas' => 'Венесуэльскі час (Каракас)',
        'America/Catamarca' => 'Аргенцінскі час (Катамарка)',
        'America/Argentina/Catamarca' => 'Аргенцінскі час (Катамарка)',
        'America/Cayenne' => 'Час Французскай Гвіяны (Каена)',
        'America/Cayman' => 'Паўночнаамерыканскі ўсходні час (Кайманавы астравы)',
        'America/Chicago' => 'Паўночнаамерыканскі цэнтральны час (Чыкага)',
        'America/Chihuahua' => 'Паўночнаамерыканскі цэнтральны час (Чыўаўа)',
        'America/Ciudad_Juarez' => 'Паўночнаамерыканскі горны час (Сьюдад-Хуарэс)',
        'America/Coral_Harbour' => 'Паўночнаамерыканскі ўсходні час (Атыкокан)',
        'America/Atikokan' => 'Паўночнаамерыканскі ўсходні час (Атыкокан)',
        'America/Cordoba' => 'Аргенцінскі час (Кордава)',
        'America/Argentina/Cordoba' => 'Аргенцінскі час (Кордава)',
        'America/Costa_Rica' => 'Паўночнаамерыканскі цэнтральны час (Коста-Рыка)',
        'America/Coyhaique' => 'Чылійскі час (Кайайке)',
        'America/Creston' => 'Паўночнаамерыканскі горны час (Крэстан)',
        'America/Cuiaba' => 'Амазонскі час (Куяба)',
        'America/Curacao' => 'Атлантычны час (Кюрасаа)',
        'America/Danmarkshavn' => 'Час па Грынвічы (Данмарксхаўн)',
        'America/Dawson' => 'Час Юкана (Доўсан)',
        'America/Dawson_Creek' => 'Паўночнаамерыканскі горны час (Досан-Крык)',
        'America/Denver' => 'Паўночнаамерыканскі горны час (Дэнвер)',
        'America/Detroit' => 'Паўночнаамерыканскі ўсходні час (Дэтройт)',
        'America/Dominica' => 'Атлантычны час (Дамініка)',
        'America/Edmonton' => 'Паўночнаамерыканскі горны час (Эдмантан)',
        'America/Eirunepe' => 'Час: Бразілія (Эйрунэпе)',
        'America/El_Salvador' => 'Паўночнаамерыканскі цэнтральны час (Сальвадор)',
        'America/Fort_Nelson' => 'Паўночнаамерыканскі горны час (Форт-Нельсан)',
        'America/Fortaleza' => 'Бразільскі час (Фарталеза)',
        'America/Glace_Bay' => 'Атлантычны час (Глэйс-Бэй)',
        'America/Godthab' => 'Час: Грэнландыя (Нук)',
        'America/Nuuk' => 'Час: Грэнландыя (Нук)',
        'America/Goose_Bay' => 'Атлантычны час (Гус-Бэй)',
        'America/Grand_Turk' => 'Паўночнаамерыканскі ўсходні час (Гранд-Цёрк)',
        'America/Grenada' => 'Атлантычны час (Грэнада)',
        'America/Guadeloupe' => 'Атлантычны час (Гвадэлупа)',
        'America/Guatemala' => 'Паўночнаамерыканскі цэнтральны час (Гватэмала)',
        'America/Guayaquil' => 'Эквадорскі час (Гуаякіль)',
        'America/Guyana' => 'Час Гаяны (Гаяна)',
        'America/Halifax' => 'Атлантычны час (Галіфакс)',
        'America/Havana' => 'Час Кубы (Гавана)',
        'America/Hermosillo' => 'Мексіканскі ціхаакіянскі час (Эрмасілья)',
        'America/Indiana/Knox' => 'Паўночнаамерыканскі цэнтральны час (Нокс, Індыяна)',
        'America/Indiana/Marengo' => 'Паўночнаамерыканскі ўсходні час (Марэнга, Індыяна)',
        'America/Indiana/Petersburg' => 'Паўночнаамерыканскі ўсходні час (Пітэрсберг, Індыяна)',
        'America/Indiana/Tell_City' => 'Паўночнаамерыканскі цэнтральны час (Тэл Сіці, Індыяна)',
        'America/Indiana/Vevay' => 'Паўночнаамерыканскі ўсходні час (Віві, Індыяна)',
        'America/Indiana/Vincennes' => 'Паўночнаамерыканскі ўсходні час (Вінсенс, Індыяна)',
        'America/Indiana/Winamac' => 'Паўночнаамерыканскі ўсходні час (Уінамак, Індыяна)',
        'America/Indianapolis' => 'Паўночнаамерыканскі ўсходні час (Індыянапаліс)',
        'America/Indiana/Indianapolis' => 'Паўночнаамерыканскі ўсходні час (Індыянапаліс)',
        'America/Inuvik' => 'Паўночнаамерыканскі горны час (Інувік)',
        'America/Iqaluit' => 'Паўночнаамерыканскі ўсходні час (Ікалуіт)',
        'America/Jamaica' => 'Паўночнаамерыканскі ўсходні час (Ямайка)',
        'America/Jujuy' => 'Аргенцінскі час (Жужуй)',
        'America/Argentina/Jujuy' => 'Аргенцінскі час (Жужуй)',
        'America/Juneau' => 'Час Аляскі (Джуна)',
        'America/Kentucky/Monticello' => 'Паўночнаамерыканскі ўсходні час (Мантысела, Кентукі)',
        'America/Kralendijk' => 'Атлантычны час (Кралендэйк)',
        'America/La_Paz' => 'Балівійскі час (Ла-Пас)',
        'America/Lima' => 'Перуанскі час (Ліма)',
        'America/Los_Angeles' => 'Ціхаакіянскі час (Лос-Анджэлес)',
        'America/Louisville' => 'Паўночнаамерыканскі ўсходні час (Луісвіл)',
        'America/Kentucky/Louisville' => 'Паўночнаамерыканскі ўсходні час (Луісвіл)',
        'America/Lower_Princes' => 'Атлантычны час (Лоўэр Прынсіз Квотэр)',
        'America/Maceio' => 'Бразільскі час (Масеё)',
        'America/Managua' => 'Паўночнаамерыканскі цэнтральны час (Манагуа)',
        'America/Manaus' => 'Амазонскі час (Манаўс)',
        'America/Marigot' => 'Атлантычны час (Марыго)',
        'America/Martinique' => 'Атлантычны час (Марцініка)',
        'America/Matamoros' => 'Паўночнаамерыканскі цэнтральны час (Матаморас)',
        'America/Mazatlan' => 'Мексіканскі ціхаакіянскі час (Масатлан)',
        'America/Mendoza' => 'Аргенцінскі час (Мендоса)',
        'America/Argentina/Mendoza' => 'Аргенцінскі час (Мендоса)',
        'America/Menominee' => 'Паўночнаамерыканскі цэнтральны час (Меноміні)',
        'America/Merida' => 'Паўночнаамерыканскі цэнтральны час (Мерыда)',
        'America/Metlakatla' => 'Час Аляскі (Метлакатла)',
        'America/Mexico_City' => 'Паўночнаамерыканскі цэнтральны час (Мехіка)',
        'America/Miquelon' => 'Час Сен-П’ер і Мікелон',
        'America/Moncton' => 'Атлантычны час (Монктан)',
        'America/Monterrey' => 'Паўночнаамерыканскі цэнтральны час (Мантэрэй)',
        'America/Montevideo' => 'Уругвайскі час (Мантэвідэа)',
        'America/Montserrat' => 'Атлантычны час (Мантсерат)',
        'America/Nassau' => 'Паўночнаамерыканскі ўсходні час (Насаў)',
        'America/New_York' => 'Паўночнаамерыканскі ўсходні час (Нью-Ёрк)',
        'America/Nome' => 'Час Аляскі (Ном)',
        'America/Noronha' => 'Час Фернанду-дзі-Наронья',
        'America/North_Dakota/Beulah' => 'Паўночнаамерыканскі цэнтральны час (Б’юла, Паўночная Дакота)',
        'America/North_Dakota/Center' => 'Паўночнаамерыканскі цэнтральны час (Сентэр, Паўночная Дакота)',
        'America/North_Dakota/New_Salem' => 'Паўночнаамерыканскі цэнтральны час (Нью-Сейлем, Паўночная Дакота)',
        'America/Ojinaga' => 'Паўночнаамерыканскі цэнтральны час (Ахінага)',
        'America/Panama' => 'Паўночнаамерыканскі ўсходні час (Панама)',
        'America/Paramaribo' => 'Час Сурынама (Парамарыба)',
        'America/Phoenix' => 'Паўночнаамерыканскі горны час (Фінікс)',
        'America/Port-au-Prince' => 'Паўночнаамерыканскі ўсходні час (Порт-о-Прэнс)',
        'America/Port_of_Spain' => 'Атлантычны час (Порт-оф-Спейн)',
        'America/Porto_Velho' => 'Амазонскі час (Порту-Велью)',
        'America/Puerto_Rico' => 'Атлантычны час (Пуэрта-Рыка)',
        'America/Punta_Arenas' => 'Чылійскі час (Пунта-Арэнас)',
        'America/Rankin_Inlet' => 'Паўночнаамерыканскі цэнтральны час (Ранкін-Інлет)',
        'America/Recife' => 'Бразільскі час (Рэсіфі)',
        'America/Regina' => 'Паўночнаамерыканскі цэнтральны час (Рэджайна)',
        'America/Resolute' => 'Паўночнаамерыканскі цэнтральны час (Рэзальют)',
        'America/Rio_Branco' => 'Час: Бразілія (Рыу-Бранку)',
        'America/Santarem' => 'Бразільскі час (Сантарэн)',
        'America/Santiago' => 'Чылійскі час (Сант’яга)',
        'America/Santo_Domingo' => 'Атлантычны час (Санта-Дамінга)',
        'America/Sao_Paulo' => 'Бразільскі час (Сан-Паўлу)',
        'America/Scoresbysund' => 'Час: Грэнландыя (Ітакартаарміт)',
        'America/Sitka' => 'Час Аляскі (Сітка)',
        'America/St_Barthelemy' => 'Атлантычны час (Сен-Бартэльмі)',
        'America/St_Johns' => 'Ньюфаўндлендскі час (Сент-Джонс)',
        'America/St_Kitts' => 'Атлантычны час (Сент-Кітс)',
        'America/St_Lucia' => 'Атлантычны час (Сент-Люсія)',
        'America/St_Thomas' => 'Атлантычны час (Сент-Томас)',
        'America/St_Vincent' => 'Атлантычны час (Сент-Вінсент)',
        'America/Swift_Current' => 'Паўночнаамерыканскі цэнтральны час (Свіфт-Керэнт)',
        'America/Tegucigalpa' => 'Паўночнаамерыканскі цэнтральны час (Тэгусігальпа)',
        'America/Thule' => 'Атлантычны час (Туле)',
        'America/Tijuana' => 'Ціхаакіянскі час (Тыхуана)',
        'America/Toronto' => 'Паўночнаамерыканскі ўсходні час (Таронта)',
        'America/Tortola' => 'Атлантычны час (Тартола)',
        'America/Vancouver' => 'Ціхаакіянскі час (Ванкувер)',
        'America/Whitehorse' => 'Час Юкана (Уайтхорс)',
        'America/Winnipeg' => 'Паўночнаамерыканскі цэнтральны час (Вініпег)',
        'America/Yakutat' => 'Час Аляскі (Якутат)',
        'Antarctica/Casey' => 'Час заходняй Аўстраліі (Кэйсі)',
        'Antarctica/Davis' => 'Час станцыі Дэйвіс',
        'Antarctica/DumontDUrville' => 'Час станцыі Дзюмон-Дзюрвіль',
        'Antarctica/Macquarie' => 'Час усходняй Аўстраліі (Макуоры)',
        'Antarctica/Mawson' => 'Час станцыі Моўсан',
        'Antarctica/McMurdo' => 'Час Новай Зеландыі (Мак-Мерда)',
        'Antarctica/Palmer' => 'Чылійскі час (Палмер)',
        'Antarctica/Rothera' => 'Час станцыі Ротэра',
        'Antarctica/Syowa' => 'Час станцыі Сёва',
        'Antarctica/Troll' => 'Час па Грынвічы (Трол)',
        'Antarctica/Vostok' => 'Час станцыі Васток',
        'Arctic/Longyearbyen' => 'Цэнтральнаеўрапейскі час (Лонгйір)',
        'Asia/Aden' => 'Час Саудаўскай Аравіі (Адэн)',
        'Asia/Almaty' => 'Казахстанскі час (Алматы)',
        'Asia/Amman' => 'Усходнееўрапейскі час (Аман (горад))',
        'Asia/Anadyr' => 'Час: Расія (Анадыр)',
        'Asia/Aqtau' => 'Казахстанскі час (Актау)',
        'Asia/Aqtobe' => 'Казахстанскі час (Актабэ)',
        'Asia/Ashgabat' => 'Час Туркменістана (Ашгабат)',
        'Asia/Atyrau' => 'Казахстанскі час (Атырау)',
        'Asia/Baghdad' => 'Час Саудаўскай Аравіі (Багдад)',
        'Asia/Bahrain' => 'Час Саудаўскай Аравіі (Бахрэйн)',
        'Asia/Baku' => 'Час Азербайджана (Баку)',
        'Asia/Bangkok' => 'Індакітайскі час (Бангкок)',
        'Asia/Barnaul' => 'Краснаярскі час (Барнаул)',
        'Asia/Beirut' => 'Усходнееўрапейскі час (Бейрут)',
        'Asia/Bishkek' => 'Час Кыргызстана (Бішкек)',
        'Asia/Brunei' => 'Час Брунея (Бруней)',
        'Asia/Calcutta' => 'Час Індыі (Калькута)',
        'Asia/Kolkata' => 'Час Індыі (Калькута)',
        'Asia/Chita' => 'Якуцкі час (Чыта)',
        'Asia/Colombo' => 'Час Індыі (Каломба)',
        'Asia/Damascus' => 'Усходнееўрапейскі час (Дамаск)',
        'Asia/Dhaka' => 'Час Бангладэш (Дака)',
        'Asia/Dili' => 'Час Усходняга Тымора (Дылі)',
        'Asia/Dubai' => 'Час Персідскага заліва (Дубай)',
        'Asia/Dushanbe' => 'Час Таджыкістана (Душанбэ)',
        'Asia/Famagusta' => 'Усходнееўрапейскі час (Фамагуста)',
        'Asia/Gaza' => 'Усходнееўрапейскі час (Газа)',
        'Asia/Hebron' => 'Усходнееўрапейскі час (Хеўрон)',
        'Asia/Hong_Kong' => 'Час Ганконга',
        'Asia/Hovd' => 'Час Хоўда',
        'Asia/Irkutsk' => 'Іркуцкі час',
        'Asia/Jakarta' => 'Заходнеінданезійскі час (Джакарта)',
        'Asia/Jayapura' => 'Усходнеінданезійскі час (Джаяпура)',
        'Asia/Jerusalem' => 'Ізраільскі час (Іерусалім)',
        'Asia/Kabul' => 'Афганістанскі час (Кабул)',
        'Asia/Kamchatka' => 'Час: Расія (Камчатка)',
        'Asia/Karachi' => 'Пакістанскі час (Карачы)',
        'Asia/Katmandu' => 'Непальскі час (Катманду)',
        'Asia/Kathmandu' => 'Непальскі час (Катманду)',
        'Asia/Khandyga' => 'Якуцкі час (Хандыга)',
        'Asia/Krasnoyarsk' => 'Краснаярскі час',
        'Asia/Kuala_Lumpur' => 'Час Малайзіі (Куала-Лумпур)',
        'Asia/Kuching' => 'Час Малайзіі (Кучынг)',
        'Asia/Kuwait' => 'Час Саудаўскай Аравіі (Кувейт)',
        'Asia/Macau' => 'Час Кітая (Макаа)',
        'Asia/Magadan' => 'Магаданскі час',
        'Asia/Makassar' => 'Цэнтральнаінданезійскі час (Макасар)',
        'Asia/Manila' => 'Філіпінскі час (Маніла)',
        'Asia/Muscat' => 'Час Персідскага заліва (Маскат)',
        'Asia/Nicosia' => 'Усходнееўрапейскі час (Нікасія)',
        'Asia/Novokuznetsk' => 'Краснаярскі час (Новакузнецк)',
        'Asia/Novosibirsk' => 'Краснаярскі час (Новасібірск)',
        'Asia/Omsk' => 'Омскі час',
        'Asia/Oral' => 'Казахстанскі час (Уральск)',
        'Asia/Phnom_Penh' => 'Індакітайскі час (Пнампень)',
        'Asia/Pontianak' => 'Заходнеінданезійскі час (Пантыянак)',
        'Asia/Pyongyang' => 'Час Карэі (Пхеньян)',
        'Asia/Qatar' => 'Час Саудаўскай Аравіі (Катар)',
        'Asia/Qostanay' => 'Казахстанскі час (Кустанай)',
        'Asia/Qyzylorda' => 'Казахстанскі час (Кзыл-Арда)',
        'Asia/Rangoon' => 'Час М’янмы (Рангун)',
        'Asia/Yangon' => 'Час М’янмы (Рангун)',
        'Asia/Riyadh' => 'Час Саудаўскай Аравіі (Эр-Рыяд)',
        'Asia/Saigon' => 'Індакітайскі час (Хашымін)',
        'Asia/Ho_Chi_Minh' => 'Індакітайскі час (Хашымін)',
        'Asia/Sakhalin' => 'Магаданскі час (Сахалін)',
        'Asia/Samarkand' => 'Час Узбекістана (Самарканд)',
        'Asia/Seoul' => 'Час Карэі (Сеул)',
        'Asia/Shanghai' => 'Час Кітая (Шанхай)',
        'Asia/Singapore' => 'Сінгапурскі час',
        'Asia/Srednekolymsk' => 'Магаданскі час (Сярэднекалымск)',
        'Asia/Taipei' => 'Час Тайбэя (Тайбэй)',
        'Asia/Tashkent' => 'Час Узбекістана (Ташкент)',
        'Asia/Tbilisi' => 'Грузінскі час (Тбілісі)',
        'Asia/Tehran' => 'Іранскі час (Тэгеран)',
        'Asia/Thimphu' => 'Час Бутана (Тхімпху)',
        'Asia/Tokyo' => 'Час Японіі (Токіа)',
        'Asia/Tomsk' => 'Краснаярскі час (Томск)',
        'Asia/Ulaanbaatar' => 'Час Улан-Батара',
        'Asia/Urumqi' => 'Час: Кітай (Урумчы)',
        'Asia/Ust-Nera' => 'Уладзівастоцкі час (Усць-Нера)',
        'Asia/Vientiane' => 'Індакітайскі час (В’енцьян)',
        'Asia/Vladivostok' => 'Уладзівастоцкі час (Уладзівасток)',
        'Asia/Yakutsk' => 'Якуцкі час',
        'Asia/Yekaterinburg' => 'Екацярынбургскі час',
        'Asia/Yerevan' => 'Час Арменіі (Ерэван)',
        'Atlantic/Azores' => 'Час Азорскіх астравоў (Азорскія астравы)',
        'Atlantic/Bermuda' => 'Атлантычны час (Бермудскія астравы)',
        'Atlantic/Canary' => 'Заходнееўрапейскі час (Канарскія астравы)',
        'Atlantic/Cape_Verde' => 'Час Каба-Вердэ',
        'Atlantic/Faeroe' => 'Заходнееўрапейскі час (Фарэрскія астравы)',
        'Atlantic/Faroe' => 'Заходнееўрапейскі час (Фарэрскія астравы)',
        'Atlantic/Madeira' => 'Заходнееўрапейскі час (Мадэйра)',
        'Atlantic/Reykjavik' => 'Час па Грынвічы (Рэйк’явік)',
        'Atlantic/South_Georgia' => 'Час Паўднёвай Георгіі (Паўднёвая Георгія)',
        'Atlantic/St_Helena' => 'Час па Грынвічы (Востраў Святой Алены)',
        'Atlantic/Stanley' => 'Час Фалклендскіх астравоў (Порт-Стэнлі)',
        'Australia/Adelaide' => 'Час цэнтральнай Аўстраліі (Адэлаіда)',
        'Australia/Brisbane' => 'Час усходняй Аўстраліі (Брысбен)',
        'Australia/Broken_Hill' => 'Час цэнтральнай Аўстраліі (Брокен-Хіл)',
        'Australia/Darwin' => 'Час цэнтральнай Аўстраліі (Дарвін)',
        'Australia/Eucla' => 'Цэнтральна-заходні час Аўстраліі (Юкла)',
        'Australia/Hobart' => 'Час усходняй Аўстраліі (Хобарт)',
        'Australia/Lindeman' => 'Час усходняй Аўстраліі (Ліндэман)',
        'Australia/Lord_Howe' => 'Час Лорд-Хау',
        'Australia/Melbourne' => 'Час усходняй Аўстраліі (Мельбурн)',
        'Australia/Perth' => 'Час заходняй Аўстраліі (Перт)',
        'Australia/Sydney' => 'Час усходняй Аўстраліі (Сідней)',
        'Etc/GMT' => 'Час па Грынвічы',
        'Etc/UTC' => 'Універсальны каардынаваны час',
        'Europe/Amsterdam' => 'Цэнтральнаеўрапейскі час (Амстэрдам)',
        'Europe/Andorra' => 'Цэнтральнаеўрапейскі час (Андора)',
        'Europe/Astrakhan' => 'Час: Расія (Астрахань)',
        'Europe/Athens' => 'Усходнееўрапейскі час (Афіны)',
        'Europe/Belgrade' => 'Цэнтральнаеўрапейскі час (Бялград)',
        'Europe/Berlin' => 'Цэнтральнаеўрапейскі час (Берлін)',
        'Europe/Bratislava' => 'Цэнтральнаеўрапейскі час (Браціслава)',
        'Europe/Brussels' => 'Цэнтральнаеўрапейскі час (Брусель)',
        'Europe/Bucharest' => 'Усходнееўрапейскі час (Бухарэст)',
        'Europe/Budapest' => 'Цэнтральнаеўрапейскі час (Будапешт)',
        'Europe/Busingen' => 'Цэнтральнаеўрапейскі час (Бюзінген)',
        'Europe/Chisinau' => 'Усходнееўрапейскі час (Кішынёў)',
        'Europe/Copenhagen' => 'Цэнтральнаеўрапейскі час (Капенгаген)',
        'Europe/Dublin' => 'Час па Грынвічы (Дублін)',
        'Europe/Gibraltar' => 'Цэнтральнаеўрапейскі час (Гібралтар)',
        'Europe/Guernsey' => 'Час па Грынвічы (Гернсі)',
        'Europe/Helsinki' => 'Усходнееўрапейскі час (Хельсінкі)',
        'Europe/Isle_of_Man' => 'Час па Грынвічы (Востраў Мэн)',
        'Europe/Istanbul' => 'Час: Турцыя (Стамбул)',
        'Europe/Jersey' => 'Час па Грынвічы (Джэрсі)',
        'Europe/Kaliningrad' => 'Усходнееўрапейскі час (Калінінград)',
        'Europe/Kiev' => 'Усходнееўрапейскі час (Кіеў)',
        'Europe/Kyiv' => 'Усходнееўрапейскі час (Кіеў)',
        'Europe/Kirov' => 'Маскоўскі час (Кіраў)',
        'Europe/Lisbon' => 'Заходнееўрапейскі час (Лісабон)',
        'Europe/Ljubljana' => 'Цэнтральнаеўрапейскі час (Любляна)',
        'Europe/London' => 'Час па Грынвічы (Лондан)',
        'Europe/Luxembourg' => 'Цэнтральнаеўрапейскі час (Люксембург)',
        'Europe/Madrid' => 'Цэнтральнаеўрапейскі час (Мадрыд)',
        'Europe/Malta' => 'Цэнтральнаеўрапейскі час (Мальта)',
        'Europe/Mariehamn' => 'Усходнееўрапейскі час (Марыянхаміна)',
        'Europe/Minsk' => 'Маскоўскі час (Мінск)',
        'Europe/Monaco' => 'Цэнтральнаеўрапейскі час (Манака)',
        'Europe/Moscow' => 'Маскоўскі час (Масква)',
        'Europe/Oslo' => 'Цэнтральнаеўрапейскі час (Осла)',
        'Europe/Paris' => 'Цэнтральнаеўрапейскі час (Парыж)',
        'Europe/Podgorica' => 'Цэнтральнаеўрапейскі час (Падгорыца)',
        'Europe/Prague' => 'Цэнтральнаеўрапейскі час (Прага)',
        'Europe/Riga' => 'Усходнееўрапейскі час (Рыга)',
        'Europe/Rome' => 'Цэнтральнаеўрапейскі час (Рым)',
        'Europe/Samara' => 'Час: Расія (Самара)',
        'Europe/San_Marino' => 'Цэнтральнаеўрапейскі час (Сан-Марына)',
        'Europe/Sarajevo' => 'Цэнтральнаеўрапейскі час (Сараева)',
        'Europe/Saratov' => 'Час: Расія (Саратаў)',
        'Europe/Simferopol' => 'Маскоўскі час (Сімферопаль)',
        'Europe/Skopje' => 'Цэнтральнаеўрапейскі час (Скоп’е)',
        'Europe/Sofia' => 'Усходнееўрапейскі час (Сафія)',
        'Europe/Stockholm' => 'Цэнтральнаеўрапейскі час (Стакгольм)',
        'Europe/Tallinn' => 'Усходнееўрапейскі час (Талін)',
        'Europe/Tirane' => 'Цэнтральнаеўрапейскі час (Тырана)',
        'Europe/Ulyanovsk' => 'Час: Расія (Ульянаўск)',
        'Europe/Vaduz' => 'Цэнтральнаеўрапейскі час (Вадуц)',
        'Europe/Vatican' => 'Цэнтральнаеўрапейскі час (Ватыкан)',
        'Europe/Vienna' => 'Цэнтральнаеўрапейскі час (Вена)',
        'Europe/Vilnius' => 'Усходнееўрапейскі час (Вільнюс)',
        'Europe/Volgograd' => 'Маскоўскі час (Валгаград)',
        'Europe/Warsaw' => 'Цэнтральнаеўрапейскі час (Варшава)',
        'Europe/Zagreb' => 'Цэнтральнаеўрапейскі час (Заграб)',
        'Europe/Zurich' => 'Цэнтральнаеўрапейскі час (Цюрых)',
        'Indian/Antananarivo' => 'Усходнеафрыканскі час (Антананарыву)',
        'Indian/Chagos' => 'Час Індыйскага акіяна (Чагас)',
        'Indian/Christmas' => 'Час вострава Каляд (Востраў Каляд)',
        'Indian/Cocos' => 'Час Какосавых астравоў (Какосавыя астравы)',
        'Indian/Comoro' => 'Усходнеафрыканскі час (Каморскія астравы)',
        'Indian/Kerguelen' => 'Час Французскай паўднёва-антарктычнай тэрыторыі (Кергелен)',
        'Indian/Mahe' => 'Час Сейшэльскіх астравоў (Маэ)',
        'Indian/Maldives' => 'Час Мальдываў (Мальдывы)',
        'Indian/Mauritius' => 'Час Маўрыкія (Маўрыкій)',
        'Indian/Mayotte' => 'Усходнеафрыканскі час (Маёта)',
        'Indian/Reunion' => 'Час Рэюньёна',
        'Pacific/Apia' => 'Час Апіі (Апія)',
        'Pacific/Auckland' => 'Час Новай Зеландыі (Окленд)',
        'Pacific/Bougainville' => 'Час Папуа-Новай Гвінеі (Бугенвіль)',
        'Pacific/Chatham' => 'Час Чатэма',
        'Pacific/Easter' => 'Час вострава Вялікадня (Вялікадня востраў)',
        'Pacific/Efate' => 'Час Вануату (Эфатэ)',
        'Pacific/Enderbury' => 'Час астравоў Фенікс (Кантон)',
        'Pacific/Kanton' => 'Час астравоў Фенікс (Кантон)',
        'Pacific/Fakaofo' => 'Час Такелау (Факаофа)',
        'Pacific/Fiji' => 'Час Фіджы',
        'Pacific/Funafuti' => 'Час Тувалу (Фунафуці)',
        'Pacific/Galapagos' => 'Стандартны час Галапагоскіх астравоў (Галапагас)',
        'Pacific/Gambier' => 'Час астравоў Гамб’е (Астравы Гамб’е)',
        'Pacific/Guadalcanal' => 'Час Саламонавых астравоў (Гуадалканал)',
        'Pacific/Guam' => 'Час Чамора (Гуам)',
        'Pacific/Honolulu' => 'Гавайска-Алеуцкі стандартны час (Ганалулу)',
        'Pacific/Kiritimati' => 'Час астравоў Лайн (Кірыцімаці)',
        'Pacific/Kosrae' => 'Час астравоў Кусаіе',
        'Pacific/Kwajalein' => 'Час Маршалавых астравоў (Кваджалейн)',
        'Pacific/Majuro' => 'Час Маршалавых астравоў (Маджура)',
        'Pacific/Marquesas' => 'Час Маркізскіх астравоў (Маркізскія астравы)',
        'Pacific/Midway' => 'Час Самоа (Мідуэй)',
        'Pacific/Nauru' => 'Час Науру',
        'Pacific/Niue' => 'Час Ніуэ',
        'Pacific/Norfolk' => 'Час вострава Норфалк',
        'Pacific/Noumea' => 'Час Новай Каледоніі (Нумеа)',
        'Pacific/Pago_Pago' => 'Час Самоа (Пага-Пага)',
        'Pacific/Palau' => 'Час Палау',
        'Pacific/Pitcairn' => 'Час вострава Піткэрн',
        'Pacific/Ponape' => 'Час вострава Панпеі',
        'Pacific/Pohnpei' => 'Час вострава Панпеі',
        'Pacific/Port_Moresby' => 'Час Папуа-Новай Гвінеі (Порт-Морсбі)',
        'Pacific/Rarotonga' => 'Час астравоў Кука (Раратонга)',
        'Pacific/Saipan' => 'Час Чамора (Сайпан)',
        'Pacific/Tahiti' => 'Час Таіці',
        'Pacific/Tarawa' => 'Час астравоў Гілберта (Тарава)',
        'Pacific/Tongatapu' => 'Час Тонга (Тангатапу)',
        'Pacific/Truk' => 'Час Трука',
        'Pacific/Chuuk' => 'Час Трука',
        'Pacific/Wake' => 'Час вострава Уэйк',
        'Pacific/Wallis' => 'Час астравоў Уоліс і Футуна',
    ],
    'Meta' => [],
];
