<?php

return [
    'Names' => [
        'Adlm' => 'adlama',
        'Aghb' => 'Kaukasoko albaniera',
        'Ahom' => 'ahomera',
        'Arab' => 'arabiarra',
        'Aran' => 'nastaliqa',
        'Armi' => 'aramiera inperiarra',
        'Armn' => 'armeniarra',
        'Avst' => 'avestera',
        'Bali' => 'baliera',
        'Bamu' => 'bamum',
        'Bass' => 'bassa vah',
        'Batk' => 'batak',
        'Beng' => 'bengalarra',
        'Bhks' => 'bhaiksuki',
        'Bopo' => 'bopomofoa',
        'Brah' => 'brahmiera',
        'Brai' => 'braillea',
        'Bugi' => 'buginera',
        'Buhd' => 'buhid',
        'Cakm' => 'txakma',
        'Cans' => 'Kanadako aborigenen silabario bateratua',
        'Cari' => 'kariera',
        'Cham' => 'txamera',
        'Cher' => 'txerokiarra',
        'Chrs' => 'korasmiera',
        'Copt' => 'koptikera',
        'Cpmn' => 'zipro-minoera',
        'Cprt' => 'ziprera',
        'Cyrl' => 'zirilikoa',
        'Deva' => 'devanagaria',
        'Diak' => 'dives akuru',
        'Dogr' => 'dogrera',
        'Dsrt' => 'deseret',
        'Dupl' => 'duployiar takigrafia',
        'Egyp' => 'egiptoar hieroglifikoak',
        'Elba' => 'elbasanera',
        'Elym' => 'elimaikera',
        'Ethi' => 'etiopiarra',
        'Geor' => 'georgiarra',
        'Glag' => 'glagolitikera',
        'Gong' => 'gunjala gondi',
        'Gonm' => 'masaram gondiera',
        'Goth' => 'gotikoa',
        'Gran' => 'grantha',
        'Grek' => 'grekoa',
        'Gujr' => 'gujaratarra',
        'Guru' => 'gurmukhia',
        'Hanb' => 'idazkera txinatarra bopomofoarekin',
        'Hang' => 'hangula',
        'Hani' => 'idazkera txinatarra',
        'Hano' => 'hanunuera',
        'Hans' => 'sinplifikatua',
        'Hant' => 'tradizionala',
        'Hatr' => 'hatreoera',
        'Hebr' => 'hebrearra',
        'Hira' => 'hiragana',
        'Hluw' => 'hieroglifiko anatoliarrak',
        'Hmng' => 'pahawh hmongera',
        'Hmnp' => 'nyiakeng puachue hmong',
        'Hrkt' => 'silabario japoniarrak',
        'Hung' => 'hungariera zaharra',
        'Ital' => 'italiera zaharra',
        'Jamo' => 'jamoa',
        'Java' => 'javaniera',
        'Jpan' => 'japoniarra',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Kawi' => 'kawi',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmertarra',
        'Khoj' => 'khojkiera',
        'Kits' => 'khitanerako script txikiak',
        'Knda' => 'kanadarra',
        'Kore' => 'korearra',
        'Kthi' => 'kaithiera',
        'Lana' => 'lannera',
        'Laoo' => 'laostarra',
        'Latn' => 'latinoa',
        'Lepc' => 'leptxa',
        'Limb' => 'linbuera',
        'Lina' => 'A linearra',
        'Linb' => 'B linearra',
        'Lisu' => 'fraserera',
        'Lyci' => 'liziera',
        'Lydi' => 'lidiera',
        'Mahj' => 'mahajaniera',
        'Maka' => 'makasarrera',
        'Mand' => 'mandaera',
        'Mani' => 'manikeoa',
        'Marc' => 'martxenera',
        'Medf' => 'medefaidrinera',
        'Mend' => 'mende',
        'Merc' => 'meroitiar etzana',
        'Mero' => 'meroitirra',
        'Mlym' => 'malabartarra',
        'Modi' => 'modiera',
        'Mong' => 'mongoliarra',
        'Mroo' => 'mroera',
        'Mtei' => 'meiteiarra',
        'Mult' => 'multaniera',
        'Mymr' => 'birmaniarra',
        'Nagm' => 'nag mundariera',
        'Nand' => 'nandinagariera',
        'Narb' => 'iparraldeko arabiera zaharra',
        'Nbat' => 'nabatera',
        'Newa' => 'newaera',
        'Nkoo' => 'n’koa',
        'Nshu' => 'nushuera',
        'Ogam' => 'oghamera',
        'Olck' => 'ol chikia',
        'Orkh' => 'orkhonera',
        'Orya' => 'oriyarra',
        'Osge' => 'osagera',
        'Osma' => 'osmaiera',
        'Ougr' => 'uigurrera zaharra',
        'Palm' => 'palmiera',
        'Pauc' => 'pau cin hau',
        'Perm' => 'permiera zaharra',
        'Phag' => 'phags-pa',
        'Phli' => 'pahlavi inskripzioak',
        'Phlp' => 'Pahlavi salmo-liburua',
        'Phnx' => 'feniziera',
        'Plrd' => 'polardera fonetikoa',
        'Prti' => 'Partiera inskripzioak',
        'Qaag' => 'zauagiera',
        'Rjng' => 'Rejang',
        'Rohg' => 'hanifia',
        'Runr' => 'errunikoa',
        'Samr' => 'samariera',
        'Sarb' => 'hegoaldeko arabiera zaharra',
        'Saur' => 'saurashtra',
        'Sgnw' => 'zeinu-idazketa',
        'Shaw' => 'shaviera',
        'Shrd' => 'sharada',
        'Sidd' => 'siddham',
        'Sind' => 'khudawadi',
        'Sinh' => 'sinhala',
        'Sogd' => 'sogdiera',
        'Sogo' => 'sogdiera zaharra',
        'Sora' => 'sora sompeng',
        'Soyo' => 'soyomboera',
        'Sund' => 'sudandarra',
        'Sylo' => 'syloti nagriera',
        'Syrc' => 'asiriarra',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takriera',
        'Tale' => 'tai le',
        'Talu' => 'tai lue berria',
        'Taml' => 'tamildarra',
        'Tang' => 'tangutera',
        'Tavt' => 'tai viet',
        'Telu' => 'teluguarra',
        'Tfng' => 'tifinagha',
        'Tglg' => 'tagaloa',
        'Thaa' => 'thaana',
        'Thai' => 'thailandiarra',
        'Tibt' => 'tibetarra',
        'Tirh' => 'tirhuta',
        'Tnsa' => 'tangsa',
        'Toto' => 'totoera',
        'Ugar' => 'ugaritiera',
        'Vaii' => 'vaiarra',
        'Vith' => 'vithkuqi',
        'Wara' => 'varang kshiti',
        'Wcho' => 'wanchoera',
        'Xpeo' => 'pertsiera zaharra',
        'Xsux' => 'sumero-akadiera kuneiformea',
        'Yezi' => 'yezidiera',
        'Yiii' => 'yiarra',
        'Zanb' => 'zanabazar koadroa',
        'Zinh' => 'heredatua',
        'Zmth' => 'matematikako notazioa',
        'Zsye' => 'emojiak',
        'Zsym' => 'ikurrak',
        'Zxxx' => 'idatzi gabea',
        'Zyyy' => 'ohikoa',
    ],
];
