<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'araba',
        'Aran' => 'nastalika',
        'Armn' => 'armena',
        'Beng' => 'bengala',
        'Bopo' => 'bopomofo',
        'Brai' => 'brajlo',
        'Cakm' => 'ĉakma',
        'Cans' => 'unuecigita indiĝen-kanadana silabaro',
        'Cher' => 'ĉeroka',
        'Cyrl' => 'cirila',
        'Deva' => 'devanagara',
        'Ethi' => 'etiopa',
        'Geor' => 'kartvela',
        'Grek' => 'greka',
        'Gujr' => 'guĝarata',
        'Guru' => 'gurmuka',
        'Hanb' => 'ĉina kun bopomofo',
        'Hang' => 'hangulo',
        'Hani' => 'ĉina',
        'Hans' => 'simpligita',
        'Hant' => 'tradicia',
        'Hebr' => 'hebrea',
        'Hira' => 'rondaj kanaoj',
        'Hrkt' => 'japanaj silabaroj',
        'Jamo' => 'jamo',
        'Java' => 'java',
        'Jpan' => 'japana',
        'Kana' => 'strekaj kanaoj',
        'Khmr' => 'kmera',
        'Knda' => 'kanara',
        'Kore' => 'korea',
        'Laoo' => 'laŭa',
        'Latn' => 'latina',
        'Mlym' => 'malajalama',
        'Mong' => 'mongola',
        'Mtei' => 'manipura',
        'Mymr' => 'birma',
        'Nkoo' => 'N’Ko',
        'Orya' => 'orija',
        'Rohg' => 'hanifi',
        'Sinh' => 'sinhala',
        'Sund' => 'sunda',
        'Syrc' => 'siria',
        'Taml' => 'tamila',
        'Telu' => 'telugua',
        'Thaa' => 'maldiva',
        'Thai' => 'taja',
        'Tibt' => 'tibeta',
        'Vaii' => 'vaja',
        'Yiii' => 'jia',
        'Zmth' => 'matematika notacio',
        'Zsye' => 'miensimboloj',
        'Zsym' => 'simboloj',
        'Zxxx' => 'neskribata',
        'Zyyy' => 'nedifinita',
    ],
];
