<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'hora del meridiano de Greenwich (Abiyán)',
        'Africa/Accra' => 'hora del meridiano de Greenwich (Acra)',
        'Africa/Addis_Ababa' => 'hora de África oriental (Adís Abeba)',
        'Africa/Algiers' => 'hora de Europa central (Argel)',
        'Africa/Asmera' => 'hora de África oriental (Asmara)',
        'Africa/Asmara' => 'hora de África oriental (Asmara)',
        'Africa/Bamako' => 'hora del meridiano de Greenwich (Bamako)',
        'Africa/Bangui' => 'hora de África occidental (Bangui)',
        'Africa/Banjul' => 'hora del meridiano de Greenwich (Banjul)',
        'Africa/Bissau' => 'hora del meridiano de Greenwich (Bisáu)',
        'Africa/Blantyre' => 'hora de África central (Blantyre)',
        'Africa/Brazzaville' => 'hora de África occidental (Brazzaville)',
        'Africa/Bujumbura' => 'hora de África central (Bujumbura)',
        'Africa/Cairo' => 'hora de Europa oriental (El Cairo)',
        'Africa/Casablanca' => 'hora de Europa occidental (Casablanca)',
        'Africa/Ceuta' => 'hora de Europa central (Ceuta)',
        'Africa/Conakry' => 'hora del meridiano de Greenwich (Conakri)',
        'Africa/Dakar' => 'hora del meridiano de Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'hora de África oriental (Dar es-Salam)',
        'Africa/Djibouti' => 'hora de África oriental (Yibuti)',
        'Africa/Douala' => 'hora de África occidental (Duala)',
        'Africa/El_Aaiun' => 'hora de Europa occidental (El Aaiún)',
        'Africa/Freetown' => 'hora del meridiano de Greenwich (Freetown)',
        'Africa/Gaborone' => 'hora de África central (Gaborone)',
        'Africa/Harare' => 'hora de África central (Harare)',
        'Africa/Johannesburg' => 'hora de Sudáfrica (Johannesburgo)',
        'Africa/Juba' => 'hora de África central (Juba)',
        'Africa/Kampala' => 'hora de África oriental (Kampala)',
        'Africa/Khartoum' => 'hora de África central (Jartum)',
        'Africa/Kigali' => 'hora de África central (Kigali)',
        'Africa/Kinshasa' => 'hora de África occidental (Kinshasa)',
        'Africa/Lagos' => 'hora de África occidental (Lagos)',
        'Africa/Libreville' => 'hora de África occidental (Libreville)',
        'Africa/Lome' => 'hora del meridiano de Greenwich (Lomé)',
        'Africa/Luanda' => 'hora de África occidental (Luanda)',
        'Africa/Lubumbashi' => 'hora de África central (Lubumbashi)',
        'Africa/Lusaka' => 'hora de África central (Lusaka)',
        'Africa/Malabo' => 'hora de África occidental (Malabo)',
        'Africa/Maputo' => 'hora de África central (Maputo)',
        'Africa/Maseru' => 'hora de Sudáfrica (Maseru)',
        'Africa/Mbabane' => 'hora de Sudáfrica (Mbabane)',
        'Africa/Mogadishu' => 'hora de África oriental (Mogadiscio)',
        'Africa/Monrovia' => 'hora del meridiano de Greenwich (Monrovia)',
        'Africa/Nairobi' => 'hora de África oriental (Nairobi)',
        'Africa/Ndjamena' => 'hora de África occidental (Yamena)',
        'Africa/Niamey' => 'hora de África occidental (Niamey)',
        'Africa/Nouakchott' => 'hora del meridiano de Greenwich (Nuakchot)',
        'Africa/Ouagadougou' => 'hora del meridiano de Greenwich (Uagadugú)',
        'Africa/Porto-Novo' => 'hora de África occidental (Portonovo)',
        'Africa/Sao_Tome' => 'hora del meridiano de Greenwich (Santo Tomé)',
        'Africa/Tripoli' => 'hora de Europa oriental (Trípoli)',
        'Africa/Tunis' => 'hora de Europa central (Túnez)',
        'Africa/Windhoek' => 'hora de África central (Windhoek)',
        'America/Adak' => 'hora de Hawái-Aleutianas (Adak)',
        'America/Anchorage' => 'hora de Alaska (Anchorage)',
        'America/Anguilla' => 'hora del Atlántico (Anguila)',
        'America/Antigua' => 'hora del Atlántico (Antigua)',
        'America/Araguaina' => 'hora de Brasilia (Araguaína)',
        'America/Argentina/La_Rioja' => 'hora de Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'hora de Argentina (Río Gallegos)',
        'America/Argentina/Salta' => 'hora de Argentina (Salta)',
        'America/Argentina/San_Juan' => 'hora de Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'hora de Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'hora de Argentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'hora de Argentina (Ushuaia)',
        'America/Aruba' => 'hora del Atlántico (Aruba)',
        'America/Asuncion' => 'hora de Paraguay (Asunción)',
        'America/Bahia' => 'hora de Brasilia (Bahía)',
        'America/Bahia_Banderas' => 'hora central (Bahía de Banderas)',
        'America/Barbados' => 'hora del Atlántico (Barbados)',
        'America/Belem' => 'hora de Brasilia (Belén)',
        'America/Belize' => 'hora central (Belice)',
        'America/Blanc-Sablon' => 'hora del Atlántico (Blanc-Sablon)',
        'America/Boa_Vista' => 'hora del Amazonas (Boa Vista)',
        'America/Bogota' => 'hora de Colombia (Bogotá)',
        'America/Boise' => 'hora de las Montañas Rocosas (Boise)',
        'America/Buenos_Aires' => 'hora de Argentina (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'hora de Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'hora de las Montañas Rocosas (Cambridge Bay)',
        'America/Campo_Grande' => 'hora del Amazonas (Campo Grande)',
        'America/Cancun' => 'hora oriental (Cancún)',
        'America/Caracas' => 'hora de Venezuela (Caracas)',
        'America/Catamarca' => 'hora de Argentina (Catamarca)',
        'America/Argentina/Catamarca' => 'hora de Argentina (Catamarca)',
        'America/Cayenne' => 'hora de la Guayana Francesa (Cayena)',
        'America/Cayman' => 'hora oriental (Caimán)',
        'America/Chicago' => 'hora central (Chicago)',
        'America/Chihuahua' => 'hora central (Chihuahua)',
        'America/Ciudad_Juarez' => 'hora de las Montañas Rocosas (Ciudad Juárez)',
        'America/Coral_Harbour' => 'hora oriental (Atikokan)',
        'America/Atikokan' => 'hora oriental (Atikokan)',
        'America/Cordoba' => 'hora de Argentina (Córdoba)',
        'America/Argentina/Cordoba' => 'hora de Argentina (Córdoba)',
        'America/Costa_Rica' => 'hora central (Costa Rica)',
        'America/Coyhaique' => 'hora de Chile (Coyhaique)',
        'America/Creston' => 'hora de las Montañas Rocosas (Creston)',
        'America/Cuiaba' => 'hora del Amazonas (Cuiabá)',
        'America/Curacao' => 'hora del Atlántico (Curazao)',
        'America/Danmarkshavn' => 'hora del meridiano de Greenwich (Danmarkshavn)',
        'America/Dawson' => 'hora de Yukón (Dawson)',
        'America/Dawson_Creek' => 'hora de las Montañas Rocosas (Dawson Creek)',
        'America/Denver' => 'hora de las Montañas Rocosas (Denver)',
        'America/Detroit' => 'hora oriental (Detroit)',
        'America/Dominica' => 'hora del Atlántico (Dominica)',
        'America/Edmonton' => 'hora de las Montañas Rocosas (Edmonton)',
        'America/Eirunepe' => 'Hora de Acre (Eirunepé)',
        'America/El_Salvador' => 'hora central (El Salvador)',
        'America/Fort_Nelson' => 'hora de las Montañas Rocosas (Fort Nelson)',
        'America/Fortaleza' => 'hora de Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'hora del Atlántico (Glace Bay)',
        'America/Godthab' => 'hora de Groenlandia (Nuuk)',
        'America/Nuuk' => 'hora de Groenlandia (Nuuk)',
        'America/Goose_Bay' => 'hora del Atlántico (Goose Bay)',
        'America/Grand_Turk' => 'hora oriental (Gran Turca)',
        'America/Grenada' => 'hora del Atlántico (Granada)',
        'America/Guadeloupe' => 'hora del Atlántico (Guadalupe)',
        'America/Guatemala' => 'hora central (Guatemala)',
        'America/Guayaquil' => 'hora de Ecuador (Guayaquil)',
        'America/Guyana' => 'hora de Guyana',
        'America/Halifax' => 'hora del Atlántico (Halifax)',
        'America/Havana' => 'hora de Cuba (La Habana)',
        'America/Hermosillo' => 'hora del Pacífico de México (Hermosillo)',
        'America/Indiana/Knox' => 'hora central (Knox, Indiana)',
        'America/Indiana/Marengo' => 'hora oriental (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'hora oriental (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'hora central (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'hora oriental (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'hora oriental (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'hora oriental (Winamac, Indiana)',
        'America/Indianapolis' => 'hora oriental (Indianápolis)',
        'America/Indiana/Indianapolis' => 'hora oriental (Indianápolis)',
        'America/Inuvik' => 'hora de las Montañas Rocosas (Inuvik)',
        'America/Iqaluit' => 'hora oriental (Iqaluit)',
        'America/Jamaica' => 'hora oriental (Jamaica)',
        'America/Jujuy' => 'hora de Argentina (Jujuy)',
        'America/Argentina/Jujuy' => 'hora de Argentina (Jujuy)',
        'America/Juneau' => 'hora de Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'hora oriental (Monticello, Kentucky)',
        'America/Kralendijk' => 'hora del Atlántico (Kralendijk)',
        'America/La_Paz' => 'hora de Bolivia (La Paz)',
        'America/Lima' => 'hora de Perú (Lima)',
        'America/Los_Angeles' => 'hora del Pacífico (Los Ángeles)',
        'America/Louisville' => 'hora oriental (Louisville)',
        'America/Kentucky/Louisville' => 'hora oriental (Louisville)',
        'America/Lower_Princes' => 'hora del Atlántico (Lower Prince’s Quarter)',
        'America/Maceio' => 'hora de Brasilia (Maceió)',
        'America/Managua' => 'hora central (Managua)',
        'America/Manaus' => 'hora del Amazonas (Manaos)',
        'America/Marigot' => 'hora del Atlántico (Marigot)',
        'America/Martinique' => 'hora del Atlántico (Martinica)',
        'America/Matamoros' => 'hora central (Matamoros)',
        'America/Mazatlan' => 'hora del Pacífico de México (Mazatlán)',
        'America/Mendoza' => 'hora de Argentina (Mendoza)',
        'America/Argentina/Mendoza' => 'hora de Argentina (Mendoza)',
        'America/Menominee' => 'hora central (Menominee)',
        'America/Merida' => 'hora central (Mérida)',
        'America/Metlakatla' => 'hora de Alaska (Metlakatla)',
        'America/Mexico_City' => 'hora central (Ciudad de México)',
        'America/Miquelon' => 'hora de San Pedro y Miquelón',
        'America/Moncton' => 'hora del Atlántico (Moncton)',
        'America/Monterrey' => 'hora central (Monterrey)',
        'America/Montevideo' => 'hora de Uruguay (Montevideo)',
        'America/Montserrat' => 'hora del Atlántico (Montserrat)',
        'America/Nassau' => 'hora oriental (Nassau)',
        'America/New_York' => 'hora oriental (Nueva York)',
        'America/Nome' => 'hora de Alaska (Nome)',
        'America/Noronha' => 'hora de Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'hora central (Beulah, Dakota del Norte)',
        'America/North_Dakota/Center' => 'hora central (Center, Dakota del Norte)',
        'America/North_Dakota/New_Salem' => 'hora central (New Salem, Dakota del Norte)',
        'America/Ojinaga' => 'hora central (Ojinaga)',
        'America/Panama' => 'hora oriental (Panamá)',
        'America/Paramaribo' => 'hora de Surinam (Paramaribo)',
        'America/Phoenix' => 'hora de las Montañas Rocosas (Phoenix)',
        'America/Port-au-Prince' => 'hora oriental (Puerto Príncipe)',
        'America/Port_of_Spain' => 'hora del Atlántico (Puerto España)',
        'America/Porto_Velho' => 'hora del Amazonas (Porto Velho)',
        'America/Puerto_Rico' => 'hora del Atlántico (Puerto Rico)',
        'America/Punta_Arenas' => 'hora de Chile (Punta Arenas)',
        'America/Rankin_Inlet' => 'hora central (Rankin Inlet)',
        'America/Recife' => 'hora de Brasilia (Recife)',
        'America/Regina' => 'hora central (Regina)',
        'America/Resolute' => 'hora central (Resolute)',
        'America/Rio_Branco' => 'Hora de Acre (Río Branco)',
        'America/Santarem' => 'hora de Brasilia (Santarém)',
        'America/Santiago' => 'hora de Chile (Santiago de Chile)',
        'America/Santo_Domingo' => 'hora del Atlántico (Santo Domingo)',
        'America/Sao_Paulo' => 'hora de Brasilia (São Paulo)',
        'America/Scoresbysund' => 'hora de Groenlandia (Ittoqqortoormiit)',
        'America/Sitka' => 'hora de Alaska (Sitka)',
        'America/St_Barthelemy' => 'hora del Atlántico (San Bartolomé)',
        'America/St_Johns' => 'hora de Terranova (San Juan de Terranova)',
        'America/St_Kitts' => 'hora del Atlántico (San Cristóbal)',
        'America/St_Lucia' => 'hora del Atlántico (Santa Lucía)',
        'America/St_Thomas' => 'hora del Atlántico (St. Thomas)',
        'America/St_Vincent' => 'hora del Atlántico (San Vicente)',
        'America/Swift_Current' => 'hora central (Swift Current)',
        'America/Tegucigalpa' => 'hora central (Tegucigalpa)',
        'America/Thule' => 'hora del Atlántico (Thule)',
        'America/Tijuana' => 'hora del Pacífico (Tijuana)',
        'America/Toronto' => 'hora oriental (Toronto)',
        'America/Tortola' => 'hora del Atlántico (Tórtola)',
        'America/Vancouver' => 'hora del Pacífico (Vancouver)',
        'America/Whitehorse' => 'hora de Yukón (Whitehorse)',
        'America/Winnipeg' => 'hora central (Winnipeg)',
        'America/Yakutat' => 'hora de Alaska (Yakutat)',
        'Antarctica/Casey' => 'hora de Australia occidental (Casey)',
        'Antarctica/Davis' => 'hora de Davis',
        'Antarctica/DumontDUrville' => 'hora de Dumont-d’Urville',
        'Antarctica/Macquarie' => 'hora de Australia oriental (Macquarie)',
        'Antarctica/Mawson' => 'hora de Mawson',
        'Antarctica/McMurdo' => 'hora de Nueva Zelanda (McMurdo)',
        'Antarctica/Palmer' => 'hora de Chile (Palmer)',
        'Antarctica/Rothera' => 'hora de Rothera',
        'Antarctica/Syowa' => 'hora de Syowa (Showa)',
        'Antarctica/Troll' => 'hora del meridiano de Greenwich (Troll)',
        'Antarctica/Vostok' => 'hora de Vostok',
        'Arctic/Longyearbyen' => 'hora de Europa central (Longyearbyen)',
        'Asia/Aden' => 'hora de Arabia (Adén)',
        'Asia/Almaty' => 'hora de Kazajistán (Almaty)',
        'Asia/Amman' => 'hora de Europa oriental (Ammán)',
        'Asia/Anadyr' => 'hora de Kamchatka (Anádyr)',
        'Asia/Aqtau' => 'hora de Kazajistán (Aktau)',
        'Asia/Aqtobe' => 'hora de Kazajistán (Aktobe)',
        'Asia/Ashgabat' => 'hora de Turkmenistán (Asjabad)',
        'Asia/Atyrau' => 'hora de Kazajistán (Atyrau)',
        'Asia/Baghdad' => 'hora de Arabia (Bagdad)',
        'Asia/Bahrain' => 'hora de Arabia (Baréin)',
        'Asia/Baku' => 'hora de Azerbaiyán (Bakú)',
        'Asia/Bangkok' => 'hora de Indochina (Bangkok)',
        'Asia/Barnaul' => 'hora de Krasnoyarsk (Barnaúl)',
        'Asia/Beirut' => 'hora de Europa oriental (Beirut)',
        'Asia/Bishkek' => 'hora de Kirguistán (Bishkek)',
        'Asia/Brunei' => 'hora de Brunéi',
        'Asia/Calcutta' => 'hora estándar de la India (Calcuta)',
        'Asia/Kolkata' => 'hora estándar de la India (Calcuta)',
        'Asia/Chita' => 'hora de Yakutsk (Chitá)',
        'Asia/Colombo' => 'hora estándar de la India (Colombo)',
        'Asia/Damascus' => 'hora de Europa oriental (Damasco)',
        'Asia/Dhaka' => 'hora de Bangladés (Daca)',
        'Asia/Dili' => 'hora de Timor Oriental (Dili)',
        'Asia/Dubai' => 'hora estándar del Golfo (Dubái)',
        'Asia/Dushanbe' => 'hora de Tayikistán (Dusambé)',
        'Asia/Famagusta' => 'hora de Europa oriental (Famagusta)',
        'Asia/Gaza' => 'hora de Europa oriental (Gaza)',
        'Asia/Hebron' => 'hora de Europa oriental (Hebrón)',
        'Asia/Hong_Kong' => 'hora de Hong Kong',
        'Asia/Hovd' => 'hora de Hovd (Khovd)',
        'Asia/Irkutsk' => 'hora de Irkutsk',
        'Asia/Jakarta' => 'hora de Indonesia occidental (Yakarta)',
        'Asia/Jayapura' => 'hora de Indonesia oriental (Jayapura)',
        'Asia/Jerusalem' => 'hora de Israel (Jerusalén)',
        'Asia/Kabul' => 'hora de Afganistán (Kabul)',
        'Asia/Kamchatka' => 'hora de Kamchatka',
        'Asia/Karachi' => 'hora de Pakistán (Karachi)',
        'Asia/Katmandu' => 'hora de Nepal (Katmandú)',
        'Asia/Kathmandu' => 'hora de Nepal (Katmandú)',
        'Asia/Khandyga' => 'hora de Yakutsk (Khandiga)',
        'Asia/Krasnoyarsk' => 'hora de Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'hora de Malasia (Kuala Lumpur)',
        'Asia/Kuching' => 'hora de Malasia (Kuching)',
        'Asia/Kuwait' => 'hora de Arabia (Kuwait)',
        'Asia/Macau' => 'hora de China (Macao)',
        'Asia/Magadan' => 'hora de Magadán',
        'Asia/Makassar' => 'hora de Indonesia central (Makasar)',
        'Asia/Manila' => 'hora de Filipinas (Manila)',
        'Asia/Muscat' => 'hora estándar del Golfo (Mascate)',
        'Asia/Nicosia' => 'hora de Europa oriental (Nicosia)',
        'Asia/Novokuznetsk' => 'hora de Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'hora de Krasnoyarsk (Novosibirsk)',
        'Asia/Omsk' => 'hora de Omsk',
        'Asia/Oral' => 'hora de Kazajistán (Oral)',
        'Asia/Phnom_Penh' => 'hora de Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'hora de Indonesia occidental (Pontianak)',
        'Asia/Pyongyang' => 'hora de Corea (Pyongyang)',
        'Asia/Qatar' => 'hora de Arabia (Catar)',
        'Asia/Qostanay' => 'hora de Kazajistán (Kostanái)',
        'Asia/Qyzylorda' => 'hora de Kazajistán (Kyzylorda)',
        'Asia/Rangoon' => 'hora de Myanmar (Yangón (Rangún))',
        'Asia/Yangon' => 'hora de Myanmar (Yangón (Rangún))',
        'Asia/Riyadh' => 'hora de Arabia (Riad)',
        'Asia/Saigon' => 'hora de Indochina (Ciudad Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'hora de Indochina (Ciudad Ho Chi Minh)',
        'Asia/Sakhalin' => 'hora de Magadán (Sajalín)',
        'Asia/Samarkand' => 'hora de Uzbekistán (Samarcanda)',
        'Asia/Seoul' => 'hora de Corea (Seúl)',
        'Asia/Shanghai' => 'hora de China (Shanghái)',
        'Asia/Singapore' => 'hora de Singapur',
        'Asia/Srednekolymsk' => 'hora de Magadán (Srednekolimsk)',
        'Asia/Taipei' => 'hora de Taipéi',
        'Asia/Tashkent' => 'hora de Uzbekistán (Taskent)',
        'Asia/Tbilisi' => 'hora de Georgia (Tiflis)',
        'Asia/Tehran' => 'hora de Irán (Teherán)',
        'Asia/Thimphu' => 'hora de Bután (Timbu)',
        'Asia/Tokyo' => 'hora de Japón (Tokio)',
        'Asia/Tomsk' => 'hora de Krasnoyarsk (Tomsk)',
        'Asia/Ulaanbaatar' => 'hora de Ulán Bator',
        'Asia/Urumqi' => 'hora de China (Ürümqi)',
        'Asia/Ust-Nera' => 'hora de Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'hora de Indochina (Vientián)',
        'Asia/Vladivostok' => 'hora de Vladivostok',
        'Asia/Yakutsk' => 'hora de Yakutsk',
        'Asia/Yekaterinburg' => 'hora de Ekaterimburgo',
        'Asia/Yerevan' => 'hora de Armenia (Ereván)',
        'Atlantic/Azores' => 'hora de las Azores',
        'Atlantic/Bermuda' => 'hora del Atlántico (Bermudas)',
        'Atlantic/Canary' => 'hora de Europa occidental (Canarias)',
        'Atlantic/Cape_Verde' => 'hora de Cabo Verde',
        'Atlantic/Faeroe' => 'hora de Europa occidental (Islas Feroe)',
        'Atlantic/Faroe' => 'hora de Europa occidental (Islas Feroe)',
        'Atlantic/Madeira' => 'hora de Europa occidental (Madeira)',
        'Atlantic/Reykjavik' => 'hora del meridiano de Greenwich (Reikiavik)',
        'Atlantic/South_Georgia' => 'hora de Georgia del Sur',
        'Atlantic/St_Helena' => 'hora del meridiano de Greenwich (Santa Elena)',
        'Atlantic/Stanley' => 'hora de las islas Malvinas (Stanley)',
        'Australia/Adelaide' => 'hora de Australia central (Adelaida)',
        'Australia/Brisbane' => 'hora de Australia oriental (Brisbane)',
        'Australia/Broken_Hill' => 'hora de Australia central (Broken Hill)',
        'Australia/Darwin' => 'hora de Australia central (Darwin)',
        'Australia/Eucla' => 'hora de Australia centroccidental (Eucla)',
        'Australia/Hobart' => 'hora de Australia oriental (Hobart)',
        'Australia/Lindeman' => 'hora de Australia oriental (Lindeman)',
        'Australia/Lord_Howe' => 'hora de Lord Howe',
        'Australia/Melbourne' => 'hora de Australia oriental (Melbourne)',
        'Australia/Perth' => 'hora de Australia occidental (Perth)',
        'Australia/Sydney' => 'hora de Australia oriental (Sídney)',
        'Etc/GMT' => 'hora del meridiano de Greenwich',
        'Etc/UTC' => 'tiempo universal coordinado',
        'Europe/Amsterdam' => 'hora de Europa central (Ámsterdam)',
        'Europe/Andorra' => 'hora de Europa central (Andorra)',
        'Europe/Astrakhan' => 'hora de Samara (Astracán)',
        'Europe/Athens' => 'hora de Europa oriental (Atenas)',
        'Europe/Belgrade' => 'hora de Europa central (Belgrado)',
        'Europe/Berlin' => 'hora de Europa central (Berlín)',
        'Europe/Bratislava' => 'hora de Europa central (Bratislava)',
        'Europe/Brussels' => 'hora de Europa central (Bruselas)',
        'Europe/Bucharest' => 'hora de Europa oriental (Bucarest)',
        'Europe/Budapest' => 'hora de Europa central (Budapest)',
        'Europe/Busingen' => 'hora de Europa central (Büsingen)',
        'Europe/Chisinau' => 'hora de Europa oriental (Chisináu)',
        'Europe/Copenhagen' => 'hora de Europa central (Copenhague)',
        'Europe/Dublin' => 'hora del meridiano de Greenwich (Dublín)',
        'Europe/Gibraltar' => 'hora de Europa central (Gibraltar)',
        'Europe/Guernsey' => 'hora del meridiano de Greenwich (Guernesey)',
        'Europe/Helsinki' => 'hora de Europa oriental (Helsinki)',
        'Europe/Isle_of_Man' => 'hora del meridiano de Greenwich (Isla de Man)',
        'Europe/Istanbul' => 'Hora de Turquía (Estambul)',
        'Europe/Jersey' => 'hora del meridiano de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'hora de Europa oriental (Kaliningrado)',
        'Europe/Kiev' => 'hora de Europa oriental (Kiev)',
        'Europe/Kyiv' => 'hora de Europa oriental (Kiev)',
        'Europe/Kirov' => 'hora de Moscú (Kírov)',
        'Europe/Lisbon' => 'hora de Europa occidental (Lisboa)',
        'Europe/Ljubljana' => 'hora de Europa central (Liubliana)',
        'Europe/London' => 'hora del meridiano de Greenwich (Londres)',
        'Europe/Luxembourg' => 'hora de Europa central (Luxemburgo)',
        'Europe/Madrid' => 'hora de Europa central (Madrid)',
        'Europe/Malta' => 'hora de Europa central (Malta)',
        'Europe/Mariehamn' => 'hora de Europa oriental (Mariehamn)',
        'Europe/Minsk' => 'hora de Moscú (Minsk)',
        'Europe/Monaco' => 'hora de Europa central (Mónaco)',
        'Europe/Moscow' => 'hora de Moscú',
        'Europe/Oslo' => 'hora de Europa central (Oslo)',
        'Europe/Paris' => 'hora de Europa central (París)',
        'Europe/Podgorica' => 'hora de Europa central (Podgorica)',
        'Europe/Prague' => 'hora de Europa central (Praga)',
        'Europe/Riga' => 'hora de Europa oriental (Riga)',
        'Europe/Rome' => 'hora de Europa central (Roma)',
        'Europe/Samara' => 'hora de Samara',
        'Europe/San_Marino' => 'hora de Europa central (San Marino)',
        'Europe/Sarajevo' => 'hora de Europa central (Sarajevo)',
        'Europe/Saratov' => 'hora de Samara (Sarátov)',
        'Europe/Simferopol' => 'hora de Moscú (Simferópol)',
        'Europe/Skopje' => 'hora de Europa central (Skopie)',
        'Europe/Sofia' => 'hora de Europa oriental (Sofía)',
        'Europe/Stockholm' => 'hora de Europa central (Estocolmo)',
        'Europe/Tallinn' => 'hora de Europa oriental (Tallin)',
        'Europe/Tirane' => 'hora de Europa central (Tirana)',
        'Europe/Ulyanovsk' => 'hora de Samara (Uliánovsk)',
        'Europe/Vaduz' => 'hora de Europa central (Vaduz)',
        'Europe/Vatican' => 'hora de Europa central (El Vaticano)',
        'Europe/Vienna' => 'hora de Europa central (Viena)',
        'Europe/Vilnius' => 'hora de Europa oriental (Vilna)',
        'Europe/Volgograd' => 'hora de Moscú (Volgogrado)',
        'Europe/Warsaw' => 'hora de Europa central (Varsovia)',
        'Europe/Zagreb' => 'hora de Europa central (Zagreb)',
        'Europe/Zurich' => 'hora de Europa central (Zúrich)',
        'Indian/Antananarivo' => 'hora de África oriental (Antananarivo)',
        'Indian/Chagos' => 'hora del océano Índico (Chagos)',
        'Indian/Christmas' => 'hora de la Isla de Navidad',
        'Indian/Cocos' => 'hora de las Islas Cocos',
        'Indian/Comoro' => 'hora de África oriental (Comoras)',
        'Indian/Kerguelen' => 'hora de Antártida y Territorios Australes Franceses (Kerguelen)',
        'Indian/Mahe' => 'hora de Seychelles (Mahé)',
        'Indian/Maldives' => 'hora de Maldivas',
        'Indian/Mauritius' => 'hora de Mauricio',
        'Indian/Mayotte' => 'hora de África oriental (Mayotte)',
        'Indian/Reunion' => 'hora de Reunión',
        'Pacific/Apia' => 'hora de Apia',
        'Pacific/Auckland' => 'hora de Nueva Zelanda (Auckland)',
        'Pacific/Bougainville' => 'hora de Papúa Nueva Guinea (Bougainville)',
        'Pacific/Chatham' => 'hora de Chatham',
        'Pacific/Easter' => 'hora de la isla de Pascua',
        'Pacific/Efate' => 'hora de Vanuatu (Efate)',
        'Pacific/Enderbury' => 'hora de las Islas Fénix (Isla Kanton)',
        'Pacific/Kanton' => 'hora de las Islas Fénix (Isla Kanton)',
        'Pacific/Fakaofo' => 'hora de Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'hora de Fiyi',
        'Pacific/Funafuti' => 'hora de Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'hora de Galápagos',
        'Pacific/Gambier' => 'hora de Gambier',
        'Pacific/Guadalcanal' => 'hora de las Islas Salomón (Guadalcanal)',
        'Pacific/Guam' => 'hora estándar de Chamorro (Guam)',
        'Pacific/Honolulu' => 'hora estándar de Hawái-Aleutianas (Honolulú)',
        'Pacific/Kiritimati' => 'hora de las Espóradas Ecuatoriales (Kiritimati)',
        'Pacific/Kosrae' => 'hora de Kosrae',
        'Pacific/Kwajalein' => 'hora de las Islas Marshall (Kwajalein)',
        'Pacific/Majuro' => 'hora de las Islas Marshall (Majuro)',
        'Pacific/Marquesas' => 'hora de Marquesas',
        'Pacific/Midway' => 'hora de Samoa (Midway)',
        'Pacific/Nauru' => 'hora de Nauru',
        'Pacific/Niue' => 'hora de Niue',
        'Pacific/Norfolk' => 'hora de la isla Norfolk',
        'Pacific/Noumea' => 'hora de Nueva Caledonia (Numea)',
        'Pacific/Pago_Pago' => 'hora de Samoa (Pago Pago)',
        'Pacific/Palau' => 'hora de Palaos',
        'Pacific/Pitcairn' => 'hora de Pitcairn',
        'Pacific/Ponape' => 'hora de Pohnpei',
        'Pacific/Pohnpei' => 'hora de Pohnpei',
        'Pacific/Port_Moresby' => 'hora de Papúa Nueva Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'hora de las Islas Cook (Rarotonga)',
        'Pacific/Saipan' => 'hora estándar de Chamorro (Saipán)',
        'Pacific/Tahiti' => 'hora de Tahití',
        'Pacific/Tarawa' => 'hora de las islas Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'hora de Tonga (Tongatapu)',
        'Pacific/Truk' => 'hora de Chuuk',
        'Pacific/Chuuk' => 'hora de Chuuk',
        'Pacific/Wake' => 'hora de la isla Wake',
        'Pacific/Wallis' => 'hora de Wallis y Futuna (Wallis & Futuna)',
    ],
    'Meta' => [],
];
