<?php

return [
    'Names' => [
        'dsb' => 'لوړے سربي',
        'fo' => 'فاروئے',
        'kha' => 'خاسے',
        'nb' => 'ناروے بوکمال',
    ],
    'LocalizedNames' => [
        'ar_001' => 'نوے معياري عربي',
    ],
];
