<p>{{ 'This is most likely a configuration problem on either the service provider or identity provider.'|trans }}</p>

<ul>
    <li>{{ 'If you are a user who received this error after following a link on a site, you should report this error to the owner of that site.'|trans }}</li>
    <li>{{ 'If you are a developer who is deploying a single sign-on solution, you have a problem with the metadata configuration. Verify that metadata is configured correctly on both the identity provider and service provider.'|trans }}</li>
</ul>

