<?php

return [
    'Names' => [
        'af' => 'afrikaangbe',
        'af_NA' => 'afrikaangbe (Namibia nutome)',
        'af_ZA' => 'afrikaangbe (Anyiehe Africa nutome)',
        'ak' => 'blugbe',
        'ak_GH' => 'blugbe (Ghana nutome)',
        'am' => 'amhariagbe',
        'am_ET' => 'amhariagbe (Etiopia nutome)',
        'ar' => 'Arabiagbe',
        'ar_001' => 'Arabiagbe (xexeme)',
        'ar_AE' => 'Arabiagbe (United Arab Emirates nutome)',
        'ar_BH' => 'Arabiagbe (Bahrain nutome)',
        'ar_DJ' => 'Arabiagbe (Dzibuti nutome)',
        'ar_DZ' => 'Arabiagbe (Algeria nutome)',
        'ar_EG' => 'Arabiagbe (Egypte nutome)',
        'ar_EH' => 'Arabiagbe (Ɣetoɖoƒe Sahara nutome)',
        'ar_ER' => 'Arabiagbe (Eritrea nutome)',
        'ar_IL' => 'Arabiagbe (Israel nutome)',
        'ar_IQ' => 'Arabiagbe (iraqdukɔ)',
        'ar_JO' => 'Arabiagbe (Yordan nutome)',
        'ar_KM' => 'Arabiagbe (Komoros nutome)',
        'ar_KW' => 'Arabiagbe (Kuwait nutome)',
        'ar_LB' => 'Arabiagbe (Lebanɔn nutome)',
        'ar_LY' => 'Arabiagbe (Libya nutome)',
        'ar_MA' => 'Arabiagbe (Moroko nutome)',
        'ar_MR' => 'Arabiagbe (Mauritania nutome)',
        'ar_OM' => 'Arabiagbe (Oman nutome)',
        'ar_PS' => 'Arabiagbe (Palestinia nutome)',
        'ar_QA' => 'Arabiagbe (Katar nutome)',
        'ar_SA' => 'Arabiagbe (Saudi Arabia nutome)',
        'ar_SD' => 'Arabiagbe (Sudan nutome)',
        'ar_SO' => 'Arabiagbe (Somalia nutome)',
        'ar_SY' => 'Arabiagbe (Siria nutome)',
        'ar_TD' => 'Arabiagbe (Tsad nutome)',
        'ar_TN' => 'Arabiagbe (Tunisia nutome)',
        'ar_YE' => 'Arabiagbe (Yemen nutome)',
        'as' => 'assamegbe',
        'as_IN' => 'assamegbe (India nutome)',
        'az' => 'azerbaijangbe',
        'az_AZ' => 'azerbaijangbe (Azerbaijan nutome)',
        'az_Cyrl' => 'azerbaijangbe (Cyrillicgbeŋɔŋlɔ)',
        'az_Cyrl_AZ' => 'azerbaijangbe (Cyrillicgbeŋɔŋlɔ, Azerbaijan nutome)',
        'az_Latn' => 'azerbaijangbe (latingbeŋɔŋlɔ)',
        'az_Latn_AZ' => 'azerbaijangbe (latingbeŋɔŋlɔ, Azerbaijan nutome)',
        'be' => 'belarusiagbe',
        'be_BY' => 'belarusiagbe (Belarus nutome)',
        'bg' => 'bulgariagbe',
        'bg_BG' => 'bulgariagbe (Bulgaria nutome)',
        'bm' => 'bambaragbe',
        'bm_ML' => 'bambaragbe (Mali nutome)',
        'bn' => 'Bengaligbe',
        'bn_BD' => 'Bengaligbe (Bangladesh nutome)',
        'bn_IN' => 'Bengaligbe (India nutome)',
        'bo' => 'tibetagbe',
        'bo_CN' => 'tibetagbe (Tsaina nutome)',
        'bo_IN' => 'tibetagbe (India nutome)',
        'br' => 'bretongbe',
        'br_FR' => 'bretongbe (France nutome)',
        'bs' => 'bosniagbe',
        'bs_BA' => 'bosniagbe (Bosnia kple Herzergovina nutome)',
        'bs_Cyrl' => 'bosniagbe (Cyrillicgbeŋɔŋlɔ)',
        'bs_Cyrl_BA' => 'bosniagbe (Cyrillicgbeŋɔŋlɔ, Bosnia kple Herzergovina nutome)',
        'bs_Latn' => 'bosniagbe (latingbeŋɔŋlɔ)',
        'bs_Latn_BA' => 'bosniagbe (latingbeŋɔŋlɔ, Bosnia kple Herzergovina nutome)',
        'ca' => 'katalagbe',
        'ca_AD' => 'katalagbe (Andorra nutome)',
        'ca_ES' => 'katalagbe (Spain nutome)',
        'ca_FR' => 'katalagbe (France nutome)',
        'ca_IT' => 'katalagbe (Italia nutome)',
        'cs' => 'tsɛkgbe',
        'cs_CZ' => 'tsɛkgbe (Tsɛk repɔblik nutome)',
        'cy' => 'walesgbe',
        'cy_GB' => 'walesgbe (United Kingdom nutome)',
        'da' => 'denmarkgbe',
        'da_DK' => 'denmarkgbe (Denmark nutome)',
        'da_GL' => 'denmarkgbe (Grinland nutome)',
        'de' => 'Germaniagbe',
        'de_AT' => 'Germaniagbe (Austria nutome)',
        'de_BE' => 'Germaniagbe (Belgium nutome)',
        'de_CH' => 'Germaniagbe (Switzerland nutome)',
        'de_DE' => 'Germaniagbe (Germania nutome)',
        'de_IT' => 'Germaniagbe (Italia nutome)',
        'de_LI' => 'Germaniagbe (Litsenstein nutome)',
        'de_LU' => 'Germaniagbe (Lazembɔg nutome)',
        'dz' => 'dzongkhagbe',
        'dz_BT' => 'dzongkhagbe (Bhutan nutome)',
        'ee' => 'eʋegbe',
        'ee_GH' => 'eʋegbe (Ghana nutome)',
        'ee_TG' => 'eʋegbe (Togo nutome)',
        'el' => 'grisigbe',
        'el_CY' => 'grisigbe (Saiprus nutome)',
        'el_GR' => 'grisigbe (Greece nutome)',
        'en' => 'iŋlisigbe',
        'en_001' => 'iŋlisigbe (xexeme)',
        'en_150' => 'iŋlisigbe (Europa nutome)',
        'en_AE' => 'iŋlisigbe (United Arab Emirates nutome)',
        'en_AG' => 'iŋlisigbe (́Antigua kple Barbuda nutome)',
        'en_AI' => 'iŋlisigbe (Anguilla nutome)',
        'en_AS' => 'iŋlisigbe (Amerika Samoa nutome)',
        'en_AT' => 'iŋlisigbe (Austria nutome)',
        'en_AU' => 'iŋlisigbe (Australia nutome)',
        'en_BB' => 'iŋlisigbe (Barbados nutome)',
        'en_BE' => 'iŋlisigbe (Belgium nutome)',
        'en_BI' => 'iŋlisigbe (Burundi nutome)',
        'en_BM' => 'iŋlisigbe (Bermuda nutome)',
        'en_BS' => 'iŋlisigbe (Bahamas nutome)',
        'en_BW' => 'iŋlisigbe (Botswana nutome)',
        'en_BZ' => 'iŋlisigbe (Belize nutome)',
        'en_CA' => 'iŋlisigbe (Canada nutome)',
        'en_CC' => 'iŋlisigbe (Kokos [Kiling] fudomekpo nutome)',
        'en_CH' => 'iŋlisigbe (Switzerland nutome)',
        'en_CK' => 'iŋlisigbe (Kook ƒudomekpo nutome)',
        'en_CM' => 'iŋlisigbe (Kamerun nutome)',
        'en_CX' => 'iŋlisigbe (Kristmas ƒudomekpo nutome)',
        'en_CY' => 'iŋlisigbe (Saiprus nutome)',
        'en_CZ' => 'iŋlisigbe (Tsɛk repɔblik nutome)',
        'en_DE' => 'iŋlisigbe (Germania nutome)',
        'en_DK' => 'iŋlisigbe (Denmark nutome)',
        'en_DM' => 'iŋlisigbe (Dominika nutome)',
        'en_EE' => 'iŋlisigbe (Estonia nutome)',
        'en_ER' => 'iŋlisigbe (Eritrea nutome)',
        'en_ES' => 'iŋlisigbe (Spain nutome)',
        'en_FI' => 'iŋlisigbe (Finland nutome)',
        'en_FJ' => 'iŋlisigbe (Fidzi nutome)',
        'en_FK' => 'iŋlisigbe (Falkland ƒudomekpowo nutome)',
        'en_FM' => 'iŋlisigbe (Mikronesia nutome)',
        'en_FR' => 'iŋlisigbe (France nutome)',
        'en_GB' => 'iŋlisigbe (United Kingdom nutome)',
        'en_GD' => 'iŋlisigbe (Grenada nutome)',
        'en_GE' => 'iŋlisigbe (Georgia nutome)',
        'en_GG' => 'iŋlisigbe (Guernse nutome)',
        'en_GH' => 'iŋlisigbe (Ghana nutome)',
        'en_GI' => 'iŋlisigbe (Gibraltar nutome)',
        'en_GM' => 'iŋlisigbe (Gambia nutome)',
        'en_GS' => 'iŋlisigbe (Anyiehe Georgia kple Anyiehe Sandwich ƒudomekpowo nutome)',
        'en_GU' => 'iŋlisigbe (Guam nutome)',
        'en_GY' => 'iŋlisigbe (Guyanadu)',
        'en_HK' => 'iŋlisigbe (Hɔng Kɔng SAR Tsaina nutome)',
        'en_HU' => 'iŋlisigbe (Hungari nutome)',
        'en_ID' => 'iŋlisigbe (Indonesia nutome)',
        'en_IE' => 'iŋlisigbe (Ireland nutome)',
        'en_IL' => 'iŋlisigbe (Israel nutome)',
        'en_IM' => 'iŋlisigbe (Aisle of Man nutome)',
        'en_IN' => 'iŋlisigbe (India nutome)',
        'en_IT' => 'iŋlisigbe (Italia nutome)',
        'en_JE' => 'iŋlisigbe (Dzɛse nutome)',
        'en_JM' => 'iŋlisigbe (Dzamaika nutome)',
        'en_JP' => 'iŋlisigbe (Dzapan nutome)',
        'en_KE' => 'iŋlisigbe (Kenya nutome)',
        'en_KI' => 'iŋlisigbe (Kiribati nutome)',
        'en_KN' => 'iŋlisigbe (Saint Kitis kple Nevis nutome)',
        'en_KY' => 'iŋlisigbe (Kayman ƒudomekpowo nutome)',
        'en_LC' => 'iŋlisigbe (Saint Lusia nutome)',
        'en_LR' => 'iŋlisigbe (Liberia nutome)',
        'en_LS' => 'iŋlisigbe (Lɛsoto nutome)',
        'en_LT' => 'iŋlisigbe (Lituania nutome)',
        'en_LV' => 'iŋlisigbe (Latvia nutome)',
        'en_MG' => 'iŋlisigbe (Madagaska nutome)',
        'en_MH' => 'iŋlisigbe (Marshal ƒudomekpowo nutome)',
        'en_MO' => 'iŋlisigbe (Macau SAR Tsaina nutome)',
        'en_MP' => 'iŋlisigbe (Dziehe Marina ƒudomekpowo nutome)',
        'en_MS' => 'iŋlisigbe (Montserrat nutome)',
        'en_MT' => 'iŋlisigbe (Malta nutome)',
        'en_MU' => 'iŋlisigbe (mauritiusdukɔ)',
        'en_MV' => 'iŋlisigbe (maldivesdukɔ)',
        'en_MW' => 'iŋlisigbe (Malawi nutome)',
        'en_MY' => 'iŋlisigbe (Malaysia nutome)',
        'en_NA' => 'iŋlisigbe (Namibia nutome)',
        'en_NF' => 'iŋlisigbe (Norfolk ƒudomekpo nutome)',
        'en_NG' => 'iŋlisigbe (Nigeria nutome)',
        'en_NL' => 'iŋlisigbe (Netherlands nutome)',
        'en_NO' => 'iŋlisigbe (Norway nutome)',
        'en_NR' => 'iŋlisigbe (Nauru nutome)',
        'en_NU' => 'iŋlisigbe (Niue nutome)',
        'en_NZ' => 'iŋlisigbe (New Zealand nutome)',
        'en_PG' => 'iŋlisigbe (Papua New Gini nutome)',
        'en_PH' => 'iŋlisigbe (Filipini nutome)',
        'en_PK' => 'iŋlisigbe (Pakistan nutome)',
        'en_PL' => 'iŋlisigbe (Poland nutome)',
        'en_PN' => 'iŋlisigbe (Pitkairn ƒudomekpo nutome)',
        'en_PR' => 'iŋlisigbe (Puerto Riko nutome)',
        'en_PT' => 'iŋlisigbe (Portugal nutome)',
        'en_PW' => 'iŋlisigbe (Palau nutome)',
        'en_RO' => 'iŋlisigbe (Romania nutome)',
        'en_RW' => 'iŋlisigbe (Rwanda nutome)',
        'en_SB' => 'iŋlisigbe (Solomon ƒudomekpowo nutome)',
        'en_SC' => 'iŋlisigbe (Seshɛls nutome)',
        'en_SD' => 'iŋlisigbe (Sudan nutome)',
        'en_SE' => 'iŋlisigbe (Sweden nutome)',
        'en_SG' => 'iŋlisigbe (Singapɔr nutome)',
        'en_SH' => 'iŋlisigbe (Saint Helena nutome)',
        'en_SI' => 'iŋlisigbe (Slovenia nutome)',
        'en_SK' => 'iŋlisigbe (Slovakia nutome)',
        'en_SL' => 'iŋlisigbe (Sierra Leone nutome)',
        'en_SZ' => 'iŋlisigbe (Swaziland nutome)',
        'en_TC' => 'iŋlisigbe (Tɛks kple Kaikos ƒudomekpowo nutome)',
        'en_TK' => 'iŋlisigbe (Tokelau nutome)',
        'en_TO' => 'iŋlisigbe (Tonga nutome)',
        'en_TT' => 'iŋlisigbe (Trinidad kple Tobago nutome)',
        'en_TV' => 'iŋlisigbe (Tuvalu nutome)',
        'en_TZ' => 'iŋlisigbe (Tanzania nutome)',
        'en_UA' => 'iŋlisigbe (Ukraine nutome)',
        'en_UG' => 'iŋlisigbe (Uganda nutome)',
        'en_UM' => 'iŋlisigbe (U.S. Minor Outlaying ƒudomekpowo nutome)',
        'en_US' => 'iŋlisigbe (USA nutome)',
        'en_VC' => 'iŋlisigbe (Saint Vincent kple Grenadine nutome)',
        'en_VG' => 'iŋlisigbe (Britaintɔwo ƒe Virgin ƒudomekpowo nutome)',
        'en_VI' => 'iŋlisigbe (U.S. Vɛrgin ƒudomekpowo nutome)',
        'en_VU' => 'iŋlisigbe (Vanuatu nutome)',
        'en_WS' => 'iŋlisigbe (Samoa nutome)',
        'en_ZA' => 'iŋlisigbe (Anyiehe Africa nutome)',
        'en_ZM' => 'iŋlisigbe (Zambia nutome)',
        'en_ZW' => 'iŋlisigbe (Zimbabwe nutome)',
        'eo' => 'esperantogbe',
        'eo_001' => 'esperantogbe (xexeme)',
        'es' => 'Spanishgbe',
        'es_419' => 'Spanishgbe (Latin Amerika nutome)',
        'es_AR' => 'Spanishgbe (Argentina nutome)',
        'es_BO' => 'Spanishgbe (Bolivia nutome)',
        'es_BR' => 'Spanishgbe (Brazil nutome)',
        'es_BZ' => 'Spanishgbe (Belize nutome)',
        'es_CL' => 'Spanishgbe (Tsile nutome)',
        'es_CO' => 'Spanishgbe (Kolombia nutome)',
        'es_CR' => 'Spanishgbe (Kosta Rika nutome)',
        'es_CU' => 'Spanishgbe (Kuba nutome)',
        'es_DO' => 'Spanishgbe (Dominika repɔblik nutome)',
        'es_EC' => 'Spanishgbe (Ekuadɔ nutome)',
        'es_ES' => 'Spanishgbe (Spain nutome)',
        'es_GQ' => 'Spanishgbe (Ekuatorial Guini nutome)',
        'es_GT' => 'Spanishgbe (Guatemala nutome)',
        'es_HN' => 'Spanishgbe (Hondurasdu)',
        'es_MX' => 'Spanishgbe (Mexico nutome)',
        'es_NI' => 'Spanishgbe (Nicaraguadukɔ)',
        'es_PA' => 'Spanishgbe (Panama nutome)',
        'es_PE' => 'Spanishgbe (Peru nutome)',
        'es_PH' => 'Spanishgbe (Filipini nutome)',
        'es_PR' => 'Spanishgbe (Puerto Riko nutome)',
        'es_PY' => 'Spanishgbe (Paragua nutome)',
        'es_SV' => 'Spanishgbe (El Salvadɔ nutome)',
        'es_US' => 'Spanishgbe (USA nutome)',
        'es_UY' => 'Spanishgbe (uruguaydukɔ)',
        'es_VE' => 'Spanishgbe (Venezuela nutome)',
        'et' => 'estoniagbe',
        'et_EE' => 'estoniagbe (Estonia nutome)',
        'eu' => 'basqugbe',
        'eu_ES' => 'basqugbe (Spain nutome)',
        'fa' => 'persiagbe',
        'fa_AF' => 'persiagbe (Afghanistan nutome)',
        'fa_IR' => 'persiagbe (Iran nutome)',
        'fi' => 'finlanɖgbe',
        'fi_FI' => 'finlanɖgbe (Finland nutome)',
        'fr' => 'Fransegbe',
        'fr_BE' => 'Fransegbe (Belgium nutome)',
        'fr_BF' => 'Fransegbe (Burkina Faso nutome)',
        'fr_BI' => 'Fransegbe (Burundi nutome)',
        'fr_BJ' => 'Fransegbe (Benin nutome)',
        'fr_BL' => 'Fransegbe (Saint Barthélemy nutome)',
        'fr_CA' => 'Fransegbe (Canada nutome)',
        'fr_CD' => 'Fransegbe (Kongo Kinshasa nutome)',
        'fr_CF' => 'Fransegbe (Titina Afrika repɔblik nutome)',
        'fr_CG' => 'Fransegbe (Kongo Brazzaville nutome)',
        'fr_CH' => 'Fransegbe (Switzerland nutome)',
        'fr_CI' => 'Fransegbe (Kote d’Ivoire nutome)',
        'fr_CM' => 'Fransegbe (Kamerun nutome)',
        'fr_DJ' => 'Fransegbe (Dzibuti nutome)',
        'fr_DZ' => 'Fransegbe (Algeria nutome)',
        'fr_FR' => 'Fransegbe (France nutome)',
        'fr_GA' => 'Fransegbe (Gabɔn nutome)',
        'fr_GF' => 'Fransegbe (Frentsi Gayana nutome)',
        'fr_GN' => 'Fransegbe (Guini nutome)',
        'fr_GP' => 'Fransegbe (Guadelupe nutome)',
        'fr_GQ' => 'Fransegbe (Ekuatorial Guini nutome)',
        'fr_HT' => 'Fransegbe (Haiti nutome)',
        'fr_KM' => 'Fransegbe (Komoros nutome)',
        'fr_LU' => 'Fransegbe (Lazembɔg nutome)',
        'fr_MA' => 'Fransegbe (Moroko nutome)',
        'fr_MC' => 'Fransegbe (Monako nutome)',
        'fr_MF' => 'Fransegbe (Saint Martin nutome)',
        'fr_MG' => 'Fransegbe (Madagaska nutome)',
        'fr_ML' => 'Fransegbe (Mali nutome)',
        'fr_MQ' => 'Fransegbe (Martiniki nutome)',
        'fr_MR' => 'Fransegbe (Mauritania nutome)',
        'fr_MU' => 'Fransegbe (mauritiusdukɔ)',
        'fr_NC' => 'Fransegbe (New Kaledonia nutome)',
        'fr_NE' => 'Fransegbe (Niger nutome)',
        'fr_PF' => 'Fransegbe (Frentsi Pɔlinesia nutome)',
        'fr_PM' => 'Fransegbe (Saint Pierre kple Mikelɔn nutome)',
        'fr_RE' => 'Fransegbe (Réunion nutome)',
        'fr_RW' => 'Fransegbe (Rwanda nutome)',
        'fr_SC' => 'Fransegbe (Seshɛls nutome)',
        'fr_SN' => 'Fransegbe (Senegal nutome)',
        'fr_SY' => 'Fransegbe (Siria nutome)',
        'fr_TD' => 'Fransegbe (Tsad nutome)',
        'fr_TG' => 'Fransegbe (Togo nutome)',
        'fr_TN' => 'Fransegbe (Tunisia nutome)',
        'fr_VU' => 'Fransegbe (Vanuatu nutome)',
        'fr_WF' => 'Fransegbe (Wallis kple Futuna nutome)',
        'fr_YT' => 'Fransegbe (Mayotte nutome)',
        'ga' => 'irelanɖgbe',
        'ga_GB' => 'irelanɖgbe (United Kingdom nutome)',
        'ga_IE' => 'irelanɖgbe (Ireland nutome)',
        'gl' => 'galatagbe',
        'gl_ES' => 'galatagbe (Spain nutome)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (India nutome)',
        'ha' => 'hausagbe',
        'ha_GH' => 'hausagbe (Ghana nutome)',
        'ha_NE' => 'hausagbe (Niger nutome)',
        'ha_NG' => 'hausagbe (Nigeria nutome)',
        'he' => 'hebrigbe',
        'he_IL' => 'hebrigbe (Israel nutome)',
        'hi' => 'Hindigbe',
        'hi_IN' => 'Hindigbe (India nutome)',
        'hi_Latn' => 'Hindigbe (latingbeŋɔŋlɔ)',
        'hi_Latn_IN' => 'Hindigbe (latingbeŋɔŋlɔ, India nutome)',
        'hr' => 'kroatiagbe',
        'hr_BA' => 'kroatiagbe (Bosnia kple Herzergovina nutome)',
        'hr_HR' => 'kroatiagbe (Kroatsia nutome)',
        'hu' => 'hungarigbe',
        'hu_HU' => 'hungarigbe (Hungari nutome)',
        'hy' => 'armeniagbe',
        'hy_AM' => 'armeniagbe (Armenia nutome)',
        'id' => 'Indonesiagbe',
        'id_ID' => 'Indonesiagbe (Indonesia nutome)',
        'ig' => 'igbogbe',
        'ig_NG' => 'igbogbe (Nigeria nutome)',
        'is' => 'icelanɖgbe',
        'is_IS' => 'icelanɖgbe (Aiseland nutome)',
        'it' => 'Italiagbe',
        'it_CH' => 'Italiagbe (Switzerland nutome)',
        'it_IT' => 'Italiagbe (Italia nutome)',
        'it_SM' => 'Italiagbe (San Marino nutome)',
        'it_VA' => 'Italiagbe (Vatikandu nutome)',
        'ja' => 'Japangbe',
        'ja_JP' => 'Japangbe (Dzapan nutome)',
        'jv' => 'dzavangbe',
        'jv_ID' => 'dzavangbe (Indonesia nutome)',
        'ka' => 'gɔgiagbe',
        'ka_GE' => 'gɔgiagbe (Georgia nutome)',
        'kk' => 'kazakhstangbe',
        'kk_Arab' => 'kazakhstangbe (Arabiagbeŋɔŋlɔ)',
        'kk_Arab_CN' => 'kazakhstangbe (Arabiagbeŋɔŋlɔ, Tsaina nutome)',
        'kk_Cyrl' => 'kazakhstangbe (Cyrillicgbeŋɔŋlɔ)',
        'kk_Cyrl_KZ' => 'kazakhstangbe (Cyrillicgbeŋɔŋlɔ, Kazakstan nutome)',
        'kk_KZ' => 'kazakhstangbe (Kazakstan nutome)',
        'km' => 'khmergbe',
        'km_KH' => 'khmergbe (Kambodia nutome)',
        'kn' => 'kannadagbe',
        'kn_IN' => 'kannadagbe (India nutome)',
        'ko' => 'Koreagbe',
        'ko_CN' => 'Koreagbe (Tsaina nutome)',
        'ko_KP' => 'Koreagbe (Dziehe Korea nutome)',
        'ko_KR' => 'Koreagbe (Anyiehe Korea nutome)',
        'ks' => 'kashmirgbe',
        'ks_Arab' => 'kashmirgbe (Arabiagbeŋɔŋlɔ)',
        'ks_Arab_IN' => 'kashmirgbe (Arabiagbeŋɔŋlɔ, India nutome)',
        'ks_Deva' => 'kashmirgbe (devanagarigbeŋɔŋlɔ)',
        'ks_Deva_IN' => 'kashmirgbe (devanagarigbeŋɔŋlɔ, India nutome)',
        'ks_IN' => 'kashmirgbe (India nutome)',
        'ku' => 'kurdiagbe',
        'ku_Latn' => 'kurdiagbe (latingbeŋɔŋlɔ)',
        'ku_Latn_IQ' => 'kurdiagbe (latingbeŋɔŋlɔ, iraqdukɔ)',
        'ku_Latn_SY' => 'kurdiagbe (latingbeŋɔŋlɔ, Siria nutome)',
        'ku_Latn_TR' => 'kurdiagbe (latingbeŋɔŋlɔ, Tɛki nutome)',
        'ku_SY' => 'kurdiagbe (Siria nutome)',
        'ku_TR' => 'kurdiagbe (Tɛki nutome)',
        'ky' => 'kirghistangbe',
        'ky_KG' => 'kirghistangbe (Kirgizstan nutome)',
        'lb' => 'laksembɔggbe',
        'lb_LU' => 'laksembɔggbe (Lazembɔg nutome)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola nutome)',
        'ln_CD' => 'lingala (Kongo Kinshasa nutome)',
        'ln_CF' => 'lingala (Titina Afrika repɔblik nutome)',
        'ln_CG' => 'lingala (Kongo Brazzaville nutome)',
        'lo' => 'laogbe',
        'lo_LA' => 'laogbe (Laos nutome)',
        'lt' => 'lithuaniagbe',
        'lt_LT' => 'lithuaniagbe (Lituania nutome)',
        'lv' => 'latviagbe',
        'lv_LV' => 'latviagbe (Latvia nutome)',
        'mg' => 'malagasegbe',
        'mg_MG' => 'malagasegbe (Madagaska nutome)',
        'mi' => 'maorgbe',
        'mi_NZ' => 'maorgbe (New Zealand nutome)',
        'mk' => 'makedoniagbe',
        'ml' => 'malayagbe',
        'ml_IN' => 'malayagbe (India nutome)',
        'mn' => 'mongoliagbe',
        'mn_MN' => 'mongoliagbe (Mongolia nutome)',
        'mr' => 'marathiagbe',
        'mr_IN' => 'marathiagbe (India nutome)',
        'ms' => 'malaygbe',
        'ms_BN' => 'malaygbe (Brunei nutome)',
        'ms_ID' => 'malaygbe (Indonesia nutome)',
        'ms_MY' => 'malaygbe (Malaysia nutome)',
        'ms_SG' => 'malaygbe (Singapɔr nutome)',
        'mt' => 'maltagbe',
        'mt_MT' => 'maltagbe (Malta nutome)',
        'my' => 'burmagbe',
        'my_MM' => 'burmagbe (Myanmar [Burma] nutome)',
        'nb' => 'nɔweigbe bokmål',
        'nb_NO' => 'nɔweigbe bokmål (Norway nutome)',
        'nb_SJ' => 'nɔweigbe bokmål (Svalbard kple Yan Mayen nutome)',
        'nd' => 'dziehe ndebelegbe',
        'nd_ZW' => 'dziehe ndebelegbe (Zimbabwe nutome)',
        'ne' => 'nepalgbe',
        'ne_IN' => 'nepalgbe (India nutome)',
        'ne_NP' => 'nepalgbe (Nepal nutome)',
        'nl' => 'Hollandgbe',
        'nl_AW' => 'Hollandgbe (Aruba nutome)',
        'nl_BE' => 'Hollandgbe (Belgium nutome)',
        'nl_NL' => 'Hollandgbe (Netherlands nutome)',
        'nl_SR' => 'Hollandgbe (Suriname nutome)',
        'nn' => 'nɔweigbe ninɔsk',
        'nn_NO' => 'nɔweigbe ninɔsk (Norway nutome)',
        'no' => 'nɔweigbe',
        'no_NO' => 'nɔweigbe (Norway nutome)',
        'or' => 'oriyagbe',
        'or_IN' => 'oriyagbe (India nutome)',
        'os' => 'ossetiagbe',
        'os_GE' => 'ossetiagbe (Georgia nutome)',
        'os_RU' => 'ossetiagbe (Russia nutome)',
        'pa' => 'pundzabgbe',
        'pa_Arab' => 'pundzabgbe (Arabiagbeŋɔŋlɔ)',
        'pa_Arab_PK' => 'pundzabgbe (Arabiagbeŋɔŋlɔ, Pakistan nutome)',
        'pa_Guru' => 'pundzabgbe (gurmukhigbeŋɔŋlɔ)',
        'pa_Guru_IN' => 'pundzabgbe (gurmukhigbeŋɔŋlɔ, India nutome)',
        'pa_IN' => 'pundzabgbe (India nutome)',
        'pa_PK' => 'pundzabgbe (Pakistan nutome)',
        'pl' => 'Polishgbe',
        'pl_PL' => 'Polishgbe (Poland nutome)',
        'ps' => 'pashtogbe',
        'ps_AF' => 'pashtogbe (Afghanistan nutome)',
        'ps_PK' => 'pashtogbe (Pakistan nutome)',
        'pt' => 'Portuguesegbe',
        'pt_AO' => 'Portuguesegbe (Angola nutome)',
        'pt_BR' => 'Portuguesegbe (Brazil nutome)',
        'pt_CH' => 'Portuguesegbe (Switzerland nutome)',
        'pt_CV' => 'Portuguesegbe (Kape Verde nutome)',
        'pt_GQ' => 'Portuguesegbe (Ekuatorial Guini nutome)',
        'pt_GW' => 'Portuguesegbe (Gini-Bisao nutome)',
        'pt_LU' => 'Portuguesegbe (Lazembɔg nutome)',
        'pt_MO' => 'Portuguesegbe (Macau SAR Tsaina nutome)',
        'pt_MZ' => 'Portuguesegbe (Mozambiki nutome)',
        'pt_PT' => 'Portuguesegbe (Portugal nutome)',
        'pt_ST' => 'Portuguesegbe (São Tomé kple Príncipe nutome)',
        'pt_TL' => 'Portuguesegbe (Timor-Leste nutome)',
        'qu' => 'kwetsuagbe',
        'qu_BO' => 'kwetsuagbe (Bolivia nutome)',
        'qu_EC' => 'kwetsuagbe (Ekuadɔ nutome)',
        'qu_PE' => 'kwetsuagbe (Peru nutome)',
        'rm' => 'romanshgbe',
        'rm_CH' => 'romanshgbe (Switzerland nutome)',
        'rn' => 'rundigbe',
        'rn_BI' => 'rundigbe (Burundi nutome)',
        'ro' => 'romaniagbe',
        'ro_MD' => 'romaniagbe (Moldova nutome)',
        'ro_RO' => 'romaniagbe (Romania nutome)',
        'ru' => 'Russiagbe',
        'ru_BY' => 'Russiagbe (Belarus nutome)',
        'ru_KG' => 'Russiagbe (Kirgizstan nutome)',
        'ru_KZ' => 'Russiagbe (Kazakstan nutome)',
        'ru_MD' => 'Russiagbe (Moldova nutome)',
        'ru_RU' => 'Russiagbe (Russia nutome)',
        'ru_UA' => 'Russiagbe (Ukraine nutome)',
        'rw' => 'ruwandagbe',
        'rw_RW' => 'ruwandagbe (Rwanda nutome)',
        'sa' => 'sanskrigbe',
        'sa_IN' => 'sanskrigbe (India nutome)',
        'sd' => 'sindhgbe',
        'sd_Arab' => 'sindhgbe (Arabiagbeŋɔŋlɔ)',
        'sd_Arab_PK' => 'sindhgbe (Arabiagbeŋɔŋlɔ, Pakistan nutome)',
        'sd_Deva' => 'sindhgbe (devanagarigbeŋɔŋlɔ)',
        'sd_Deva_IN' => 'sindhgbe (devanagarigbeŋɔŋlɔ, India nutome)',
        'sd_IN' => 'sindhgbe (India nutome)',
        'sd_PK' => 'sindhgbe (Pakistan nutome)',
        'se' => 'dziehe samigbe',
        'se_FI' => 'dziehe samigbe (Finland nutome)',
        'se_NO' => 'dziehe samigbe (Norway nutome)',
        'se_SE' => 'dziehe samigbe (Sweden nutome)',
        'sg' => 'sangogbe',
        'sg_CF' => 'sangogbe (Titina Afrika repɔblik nutome)',
        'sh' => 'serbo-croatiagbe',
        'sh_BA' => 'serbo-croatiagbe (Bosnia kple Herzergovina nutome)',
        'si' => 'sinhalgbe',
        'si_LK' => 'sinhalgbe (Sri Lanka nutome)',
        'sk' => 'slovakiagbe',
        'sk_SK' => 'slovakiagbe (Slovakia nutome)',
        'sl' => 'sloveniagbe',
        'sl_SI' => 'sloveniagbe (Slovenia nutome)',
        'sn' => 'shonagbe',
        'sn_ZW' => 'shonagbe (Zimbabwe nutome)',
        'so' => 'somaliagbe',
        'so_DJ' => 'somaliagbe (Dzibuti nutome)',
        'so_ET' => 'somaliagbe (Etiopia nutome)',
        'so_KE' => 'somaliagbe (Kenya nutome)',
        'so_SO' => 'somaliagbe (Somalia nutome)',
        'sq' => 'albaniagbe',
        'sq_AL' => 'albaniagbe (Albania nutome)',
        'sr' => 'serbiagbe',
        'sr_BA' => 'serbiagbe (Bosnia kple Herzergovina nutome)',
        'sr_Cyrl' => 'serbiagbe (Cyrillicgbeŋɔŋlɔ)',
        'sr_Cyrl_BA' => 'serbiagbe (Cyrillicgbeŋɔŋlɔ, Bosnia kple Herzergovina nutome)',
        'sr_Cyrl_ME' => 'serbiagbe (Cyrillicgbeŋɔŋlɔ, Montenegro nutome)',
        'sr_Latn' => 'serbiagbe (latingbeŋɔŋlɔ)',
        'sr_Latn_BA' => 'serbiagbe (latingbeŋɔŋlɔ, Bosnia kple Herzergovina nutome)',
        'sr_Latn_ME' => 'serbiagbe (latingbeŋɔŋlɔ, Montenegro nutome)',
        'sr_ME' => 'serbiagbe (Montenegro nutome)',
        'st' => 'anyiehe sothogbe',
        'st_LS' => 'anyiehe sothogbe (Lɛsoto nutome)',
        'st_ZA' => 'anyiehe sothogbe (Anyiehe Africa nutome)',
        'sv' => 'swedengbe',
        'sv_AX' => 'swedengbe (Åland ƒudomekpo nutome)',
        'sv_FI' => 'swedengbe (Finland nutome)',
        'sv_SE' => 'swedengbe (Sweden nutome)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Kongo Kinshasa nutome)',
        'sw_KE' => 'swahili (Kenya nutome)',
        'sw_TZ' => 'swahili (Tanzania nutome)',
        'sw_UG' => 'swahili (Uganda nutome)',
        'ta' => 'tamilgbe',
        'ta_IN' => 'tamilgbe (India nutome)',
        'ta_LK' => 'tamilgbe (Sri Lanka nutome)',
        'ta_MY' => 'tamilgbe (Malaysia nutome)',
        'ta_SG' => 'tamilgbe (Singapɔr nutome)',
        'te' => 'telegugbe',
        'te_IN' => 'telegugbe (India nutome)',
        'tg' => 'tadzikistangbe',
        'tg_TJ' => 'tadzikistangbe (Tajikistan nutome)',
        'th' => 'Thailandgbe',
        'th_TH' => 'Thailandgbe (Thailand nutome)',
        'ti' => 'tigrinyagbe',
        'ti_ER' => 'tigrinyagbe (Eritrea nutome)',
        'ti_ET' => 'tigrinyagbe (Etiopia nutome)',
        'tk' => 'tɛkmengbe',
        'tk_TM' => 'tɛkmengbe (Tɛkmenistan nutome)',
        'tl' => 'tagalogbe',
        'tl_PH' => 'tagalogbe (Filipini nutome)',
        'tn' => 'tswanagbe',
        'tn_BW' => 'tswanagbe (Botswana nutome)',
        'tn_ZA' => 'tswanagbe (Anyiehe Africa nutome)',
        'to' => 'tongagbe',
        'to_TO' => 'tongagbe (Tonga nutome)',
        'tr' => 'Turkishgbe',
        'tr_CY' => 'Turkishgbe (Saiprus nutome)',
        'tr_TR' => 'Turkishgbe (Tɛki nutome)',
        'ug' => 'uighurgbe',
        'ug_CN' => 'uighurgbe (Tsaina nutome)',
        'uk' => 'ukraingbe',
        'uk_UA' => 'ukraingbe (Ukraine nutome)',
        'ur' => 'urdugbe',
        'ur_IN' => 'urdugbe (India nutome)',
        'ur_PK' => 'urdugbe (Pakistan nutome)',
        'uz' => 'uzbekistangbe',
        'uz_AF' => 'uzbekistangbe (Afghanistan nutome)',
        'uz_Arab' => 'uzbekistangbe (Arabiagbeŋɔŋlɔ)',
        'uz_Arab_AF' => 'uzbekistangbe (Arabiagbeŋɔŋlɔ, Afghanistan nutome)',
        'uz_Cyrl' => 'uzbekistangbe (Cyrillicgbeŋɔŋlɔ)',
        'uz_Cyrl_UZ' => 'uzbekistangbe (Cyrillicgbeŋɔŋlɔ, Uzbekistan nutome)',
        'uz_Latn' => 'uzbekistangbe (latingbeŋɔŋlɔ)',
        'uz_Latn_UZ' => 'uzbekistangbe (latingbeŋɔŋlɔ, Uzbekistan nutome)',
        'uz_UZ' => 'uzbekistangbe (Uzbekistan nutome)',
        'vi' => 'vietnamgbe',
        'vi_VN' => 'vietnamgbe (Vietnam nutome)',
        'wo' => 'wolofgbe',
        'wo_SN' => 'wolofgbe (Senegal nutome)',
        'xh' => 'xhosagbe',
        'xh_ZA' => 'xhosagbe (Anyiehe Africa nutome)',
        'yo' => 'yorubagbe',
        'yo_BJ' => 'yorubagbe (Benin nutome)',
        'yo_NG' => 'yorubagbe (Nigeria nutome)',
        'zh' => 'Chinagbe',
        'zh_CN' => 'Chinagbe (Tsaina nutome)',
        'zh_HK' => 'Chinagbe (Hɔng Kɔng SAR Tsaina nutome)',
        'zh_Hans' => 'Chinagbe (Chinesegbeŋɔŋlɔ)',
        'zh_Hans_CN' => 'Chinagbe (Chinesegbeŋɔŋlɔ, Tsaina nutome)',
        'zh_Hans_HK' => 'Chinagbe (Chinesegbeŋɔŋlɔ, Hɔng Kɔng SAR Tsaina nutome)',
        'zh_Hans_MO' => 'Chinagbe (Chinesegbeŋɔŋlɔ, Macau SAR Tsaina nutome)',
        'zh_Hans_MY' => 'Chinagbe (Chinesegbeŋɔŋlɔ, Malaysia nutome)',
        'zh_Hans_SG' => 'Chinagbe (Chinesegbeŋɔŋlɔ, Singapɔr nutome)',
        'zh_Hant' => 'Chinagbe (Blema Chinesegbeŋɔŋlɔ)',
        'zh_Hant_HK' => 'Chinagbe (Blema Chinesegbeŋɔŋlɔ, Hɔng Kɔng SAR Tsaina nutome)',
        'zh_Hant_MO' => 'Chinagbe (Blema Chinesegbeŋɔŋlɔ, Macau SAR Tsaina nutome)',
        'zh_Hant_MY' => 'Chinagbe (Blema Chinesegbeŋɔŋlɔ, Malaysia nutome)',
        'zh_Hant_TW' => 'Chinagbe (Blema Chinesegbeŋɔŋlɔ, Taiwan nutome)',
        'zh_MO' => 'Chinagbe (Macau SAR Tsaina nutome)',
        'zh_SG' => 'Chinagbe (Singapɔr nutome)',
        'zh_TW' => 'Chinagbe (Taiwan nutome)',
        'zu' => 'zulugbe',
        'zu_ZA' => 'zulugbe (Anyiehe Africa nutome)',
    ],
];
