<?php

return [
    'Names' => [
        'af' => 'afrikanų',
        'af_NA' => 'afrikanų (Namibija)',
        'af_ZA' => 'afrikanų (Pietų Afrika)',
        'ak' => 'akanų',
        'ak_GH' => 'akanų (Gana)',
        'am' => 'amharų',
        'am_ET' => 'amharų (Etiopija)',
        'ar' => 'arabų',
        'ar_001' => 'arabų (pasaulis)',
        'ar_AE' => 'arabų (Jungtiniai Arabų Emyratai)',
        'ar_BH' => 'arabų (Bahreinas)',
        'ar_DJ' => 'arabų (Džibutis)',
        'ar_DZ' => 'arabų (Alžyras)',
        'ar_EG' => 'arabų (Egiptas)',
        'ar_EH' => 'arabų (Vakarų Sachara)',
        'ar_ER' => 'arabų (Eritrėja)',
        'ar_IL' => 'arabų (Izraelis)',
        'ar_IQ' => 'arabų (Irakas)',
        'ar_JO' => 'arabų (Jordanija)',
        'ar_KM' => 'arabų (Komorai)',
        'ar_KW' => 'arabų (Kuveitas)',
        'ar_LB' => 'arabų (Libanas)',
        'ar_LY' => 'arabų (Libija)',
        'ar_MA' => 'arabų (Marokas)',
        'ar_MR' => 'arabų (Mauritanija)',
        'ar_OM' => 'arabų (Omanas)',
        'ar_PS' => 'arabų (Palestinos teritorija)',
        'ar_QA' => 'arabų (Kataras)',
        'ar_SA' => 'arabų (Saudo Arabija)',
        'ar_SD' => 'arabų (Sudanas)',
        'ar_SO' => 'arabų (Somalis)',
        'ar_SS' => 'arabų (Pietų Sudanas)',
        'ar_SY' => 'arabų (Sirija)',
        'ar_TD' => 'arabų (Čadas)',
        'ar_TN' => 'arabų (Tunisas)',
        'ar_YE' => 'arabų (Jemenas)',
        'as' => 'asamų',
        'as_IN' => 'asamų (Indija)',
        'az' => 'azerbaidžaniečių',
        'az_AZ' => 'azerbaidžaniečių (Azerbaidžanas)',
        'az_Cyrl' => 'azerbaidžaniečių (kirilica)',
        'az_Cyrl_AZ' => 'azerbaidžaniečių (kirilica, Azerbaidžanas)',
        'az_Latn' => 'azerbaidžaniečių (lotynų)',
        'az_Latn_AZ' => 'azerbaidžaniečių (lotynų, Azerbaidžanas)',
        'ba' => 'baškirų',
        'ba_RU' => 'baškirų (Rusija)',
        'be' => 'baltarusių',
        'be_BY' => 'baltarusių (Baltarusija)',
        'bg' => 'bulgarų',
        'bg_BG' => 'bulgarų (Bulgarija)',
        'bm' => 'bambarų',
        'bm_ML' => 'bambarų (Malis)',
        'bn' => 'bengalų',
        'bn_BD' => 'bengalų (Bangladešas)',
        'bn_IN' => 'bengalų (Indija)',
        'bo' => 'tibetiečių',
        'bo_CN' => 'tibetiečių (Kinija)',
        'bo_IN' => 'tibetiečių (Indija)',
        'br' => 'bretonų',
        'br_FR' => 'bretonų (Prancūzija)',
        'bs' => 'bosnių',
        'bs_BA' => 'bosnių (Bosnija ir Hercegovina)',
        'bs_Cyrl' => 'bosnių (kirilica)',
        'bs_Cyrl_BA' => 'bosnių (kirilica, Bosnija ir Hercegovina)',
        'bs_Latn' => 'bosnių (lotynų)',
        'bs_Latn_BA' => 'bosnių (lotynų, Bosnija ir Hercegovina)',
        'ca' => 'katalonų',
        'ca_AD' => 'katalonų (Andora)',
        'ca_ES' => 'katalonų (Ispanija)',
        'ca_FR' => 'katalonų (Prancūzija)',
        'ca_IT' => 'katalonų (Italija)',
        'ce' => 'čečėnų',
        'ce_RU' => 'čečėnų (Rusija)',
        'cs' => 'čekų',
        'cs_CZ' => 'čekų (Čekija)',
        'cv' => 'čiuvašų',
        'cv_RU' => 'čiuvašų (Rusija)',
        'cy' => 'valų',
        'cy_GB' => 'valų (Jungtinė Karalystė)',
        'da' => 'danų',
        'da_DK' => 'danų (Danija)',
        'da_GL' => 'danų (Grenlandija)',
        'de' => 'vokiečių',
        'de_AT' => 'vokiečių (Austrija)',
        'de_BE' => 'vokiečių (Belgija)',
        'de_CH' => 'vokiečių (Šveicarija)',
        'de_DE' => 'vokiečių (Vokietija)',
        'de_IT' => 'vokiečių (Italija)',
        'de_LI' => 'vokiečių (Lichtenšteinas)',
        'de_LU' => 'vokiečių (Liuksemburgas)',
        'dz' => 'botijų',
        'dz_BT' => 'botijų (Butanas)',
        'ee' => 'evių',
        'ee_GH' => 'evių (Gana)',
        'ee_TG' => 'evių (Togas)',
        'el' => 'graikų',
        'el_CY' => 'graikų (Kipras)',
        'el_GR' => 'graikų (Graikija)',
        'en' => 'anglų',
        'en_001' => 'anglų (pasaulis)',
        'en_150' => 'anglų (Europa)',
        'en_AE' => 'anglų (Jungtiniai Arabų Emyratai)',
        'en_AG' => 'anglų (Antigva ir Barbuda)',
        'en_AI' => 'anglų (Angilija)',
        'en_AS' => 'anglų (Amerikos Samoa)',
        'en_AT' => 'anglų (Austrija)',
        'en_AU' => 'anglų (Australija)',
        'en_BB' => 'anglų (Barbadosas)',
        'en_BE' => 'anglų (Belgija)',
        'en_BI' => 'anglų (Burundis)',
        'en_BM' => 'anglų (Bermuda)',
        'en_BS' => 'anglų (Bahamos)',
        'en_BW' => 'anglų (Botsvana)',
        'en_BZ' => 'anglų (Belizas)',
        'en_CA' => 'anglų (Kanada)',
        'en_CC' => 'anglų (Kokosų [Kilingo] Salos)',
        'en_CH' => 'anglų (Šveicarija)',
        'en_CK' => 'anglų (Kuko Salos)',
        'en_CM' => 'anglų (Kamerūnas)',
        'en_CX' => 'anglų (Kalėdų Sala)',
        'en_CY' => 'anglų (Kipras)',
        'en_CZ' => 'anglų (Čekija)',
        'en_DE' => 'anglų (Vokietija)',
        'en_DK' => 'anglų (Danija)',
        'en_DM' => 'anglų (Dominika)',
        'en_EE' => 'anglų (Estija)',
        'en_ER' => 'anglų (Eritrėja)',
        'en_ES' => 'anglų (Ispanija)',
        'en_FI' => 'anglų (Suomija)',
        'en_FJ' => 'anglų (Fidžis)',
        'en_FK' => 'anglų (Folklando salos)',
        'en_FM' => 'anglų (Mikronezija)',
        'en_FR' => 'anglų (Prancūzija)',
        'en_GB' => 'anglų (Jungtinė Karalystė)',
        'en_GD' => 'anglų (Grenada)',
        'en_GE' => 'anglų (Gruzija)',
        'en_GG' => 'anglų (Gernsis)',
        'en_GH' => 'anglų (Gana)',
        'en_GI' => 'anglų (Gibraltaras)',
        'en_GM' => 'anglų (Gambija)',
        'en_GS' => 'anglų (Pietų Džordžija ir Pietų Sandvičo salos)',
        'en_GU' => 'anglų (Guamas)',
        'en_GY' => 'anglų (Gajana)',
        'en_HK' => 'anglų (Ypatingasis Administracinis Kinijos Regionas Honkongas)',
        'en_HU' => 'anglų (Vengrija)',
        'en_ID' => 'anglų (Indonezija)',
        'en_IE' => 'anglų (Airija)',
        'en_IL' => 'anglų (Izraelis)',
        'en_IM' => 'anglų (Meno Sala)',
        'en_IN' => 'anglų (Indija)',
        'en_IO' => 'anglų (Indijos Vandenyno Britų Sritis)',
        'en_IT' => 'anglų (Italija)',
        'en_JE' => 'anglų (Džersis)',
        'en_JM' => 'anglų (Jamaika)',
        'en_JP' => 'anglų (Japonija)',
        'en_KE' => 'anglų (Kenija)',
        'en_KI' => 'anglų (Kiribatis)',
        'en_KN' => 'anglų (Sent Kitsas ir Nevis)',
        'en_KY' => 'anglų (Kaimanų Salos)',
        'en_LC' => 'anglų (Sent Lusija)',
        'en_LR' => 'anglų (Liberija)',
        'en_LS' => 'anglų (Lesotas)',
        'en_LT' => 'anglų (Lietuva)',
        'en_LV' => 'anglų (Latvija)',
        'en_MG' => 'anglų (Madagaskaras)',
        'en_MH' => 'anglų (Maršalo Salos)',
        'en_MO' => 'anglų (Ypatingasis Administracinis Kinijos Regionas Makao)',
        'en_MP' => 'anglų (Marianos Šiaurinės Salos)',
        'en_MS' => 'anglų (Montseratas)',
        'en_MT' => 'anglų (Malta)',
        'en_MU' => 'anglų (Mauricijus)',
        'en_MV' => 'anglų (Maldyvai)',
        'en_MW' => 'anglų (Malavis)',
        'en_MY' => 'anglų (Malaizija)',
        'en_NA' => 'anglų (Namibija)',
        'en_NF' => 'anglų (Norfolko sala)',
        'en_NG' => 'anglų (Nigerija)',
        'en_NL' => 'anglų (Nyderlandai)',
        'en_NO' => 'anglų (Norvegija)',
        'en_NR' => 'anglų (Nauru)',
        'en_NU' => 'anglų (Niujė)',
        'en_NZ' => 'anglų (Naujoji Zelandija)',
        'en_PG' => 'anglų (Papua Naujoji Gvinėja)',
        'en_PH' => 'anglų (Filipinai)',
        'en_PK' => 'anglų (Pakistanas)',
        'en_PL' => 'anglų (Lenkija)',
        'en_PN' => 'anglų (Pitkerno salos)',
        'en_PR' => 'anglų (Puerto Rikas)',
        'en_PT' => 'anglų (Portugalija)',
        'en_PW' => 'anglų (Palau)',
        'en_RO' => 'anglų (Rumunija)',
        'en_RW' => 'anglų (Ruanda)',
        'en_SB' => 'anglų (Saliamono Salos)',
        'en_SC' => 'anglų (Seišeliai)',
        'en_SD' => 'anglų (Sudanas)',
        'en_SE' => 'anglų (Švedija)',
        'en_SG' => 'anglų (Singapūras)',
        'en_SH' => 'anglų (Šv. Elenos Sala)',
        'en_SI' => 'anglų (Slovėnija)',
        'en_SK' => 'anglų (Slovakija)',
        'en_SL' => 'anglų (Siera Leonė)',
        'en_SS' => 'anglų (Pietų Sudanas)',
        'en_SX' => 'anglų (Sint Martenas)',
        'en_SZ' => 'anglų (Svazilandas)',
        'en_TC' => 'anglų (Terkso ir Kaikoso Salos)',
        'en_TK' => 'anglų (Tokelau)',
        'en_TO' => 'anglų (Tonga)',
        'en_TT' => 'anglų (Trinidadas ir Tobagas)',
        'en_TV' => 'anglų (Tuvalu)',
        'en_TZ' => 'anglų (Tanzanija)',
        'en_UA' => 'anglų (Ukraina)',
        'en_UG' => 'anglų (Uganda)',
        'en_UM' => 'anglų (Jungtinių Valstijų Mažosios Tolimosios Salos)',
        'en_US' => 'anglų (Jungtinės Valstijos)',
        'en_VC' => 'anglų (Šventasis Vincentas ir Grenadinai)',
        'en_VG' => 'anglų (Didžiosios Britanijos Mergelių Salos)',
        'en_VI' => 'anglų (Jungtinių Valstijų Mergelių Salos)',
        'en_VU' => 'anglų (Vanuatu)',
        'en_WS' => 'anglų (Samoa)',
        'en_ZA' => 'anglų (Pietų Afrika)',
        'en_ZM' => 'anglų (Zambija)',
        'en_ZW' => 'anglų (Zimbabvė)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (pasaulis)',
        'es' => 'ispanų',
        'es_419' => 'ispanų (Lotynų Amerika)',
        'es_AR' => 'ispanų (Argentina)',
        'es_BO' => 'ispanų (Bolivija)',
        'es_BR' => 'ispanų (Brazilija)',
        'es_BZ' => 'ispanų (Belizas)',
        'es_CL' => 'ispanų (Čilė)',
        'es_CO' => 'ispanų (Kolumbija)',
        'es_CR' => 'ispanų (Kosta Rika)',
        'es_CU' => 'ispanų (Kuba)',
        'es_DO' => 'ispanų (Dominikos Respublika)',
        'es_EC' => 'ispanų (Ekvadoras)',
        'es_ES' => 'ispanų (Ispanija)',
        'es_GQ' => 'ispanų (Pusiaujo Gvinėja)',
        'es_GT' => 'ispanų (Gvatemala)',
        'es_HN' => 'ispanų (Hondūras)',
        'es_MX' => 'ispanų (Meksika)',
        'es_NI' => 'ispanų (Nikaragva)',
        'es_PA' => 'ispanų (Panama)',
        'es_PE' => 'ispanų (Peru)',
        'es_PH' => 'ispanų (Filipinai)',
        'es_PR' => 'ispanų (Puerto Rikas)',
        'es_PY' => 'ispanų (Paragvajus)',
        'es_SV' => 'ispanų (Salvadoras)',
        'es_US' => 'ispanų (Jungtinės Valstijos)',
        'es_UY' => 'ispanų (Urugvajus)',
        'es_VE' => 'ispanų (Venesuela)',
        'et' => 'estų',
        'et_EE' => 'estų (Estija)',
        'eu' => 'baskų',
        'eu_ES' => 'baskų (Ispanija)',
        'fa' => 'persų',
        'fa_AF' => 'persų (Afganistanas)',
        'fa_IR' => 'persų (Iranas)',
        'ff' => 'fulahų',
        'ff_Adlm' => 'fulahų (ADLAM)',
        'ff_Adlm_BF' => 'fulahų (ADLAM, Burkina Fasas)',
        'ff_Adlm_CM' => 'fulahų (ADLAM, Kamerūnas)',
        'ff_Adlm_GH' => 'fulahų (ADLAM, Gana)',
        'ff_Adlm_GM' => 'fulahų (ADLAM, Gambija)',
        'ff_Adlm_GN' => 'fulahų (ADLAM, Gvinėja)',
        'ff_Adlm_GW' => 'fulahų (ADLAM, Bisau Gvinėja)',
        'ff_Adlm_LR' => 'fulahų (ADLAM, Liberija)',
        'ff_Adlm_MR' => 'fulahų (ADLAM, Mauritanija)',
        'ff_Adlm_NE' => 'fulahų (ADLAM, Nigeris)',
        'ff_Adlm_NG' => 'fulahų (ADLAM, Nigerija)',
        'ff_Adlm_SL' => 'fulahų (ADLAM, Siera Leonė)',
        'ff_Adlm_SN' => 'fulahų (ADLAM, Senegalas)',
        'ff_CM' => 'fulahų (Kamerūnas)',
        'ff_GN' => 'fulahų (Gvinėja)',
        'ff_Latn' => 'fulahų (lotynų)',
        'ff_Latn_BF' => 'fulahų (lotynų, Burkina Fasas)',
        'ff_Latn_CM' => 'fulahų (lotynų, Kamerūnas)',
        'ff_Latn_GH' => 'fulahų (lotynų, Gana)',
        'ff_Latn_GM' => 'fulahų (lotynų, Gambija)',
        'ff_Latn_GN' => 'fulahų (lotynų, Gvinėja)',
        'ff_Latn_GW' => 'fulahų (lotynų, Bisau Gvinėja)',
        'ff_Latn_LR' => 'fulahų (lotynų, Liberija)',
        'ff_Latn_MR' => 'fulahų (lotynų, Mauritanija)',
        'ff_Latn_NE' => 'fulahų (lotynų, Nigeris)',
        'ff_Latn_NG' => 'fulahų (lotynų, Nigerija)',
        'ff_Latn_SL' => 'fulahų (lotynų, Siera Leonė)',
        'ff_Latn_SN' => 'fulahų (lotynų, Senegalas)',
        'ff_MR' => 'fulahų (Mauritanija)',
        'ff_SN' => 'fulahų (Senegalas)',
        'fi' => 'suomių',
        'fi_FI' => 'suomių (Suomija)',
        'fo' => 'farerų',
        'fo_DK' => 'farerų (Danija)',
        'fo_FO' => 'farerų (Farerų Salos)',
        'fr' => 'prancūzų',
        'fr_BE' => 'prancūzų (Belgija)',
        'fr_BF' => 'prancūzų (Burkina Fasas)',
        'fr_BI' => 'prancūzų (Burundis)',
        'fr_BJ' => 'prancūzų (Beninas)',
        'fr_BL' => 'prancūzų (Sen Bartelemi)',
        'fr_CA' => 'prancūzų (Kanada)',
        'fr_CD' => 'prancūzų (Kongas-Kinšasa)',
        'fr_CF' => 'prancūzų (Centrinės Afrikos Respublika)',
        'fr_CG' => 'prancūzų (Kongas-Brazavilis)',
        'fr_CH' => 'prancūzų (Šveicarija)',
        'fr_CI' => 'prancūzų (Dramblio Kaulo Krantas)',
        'fr_CM' => 'prancūzų (Kamerūnas)',
        'fr_DJ' => 'prancūzų (Džibutis)',
        'fr_DZ' => 'prancūzų (Alžyras)',
        'fr_FR' => 'prancūzų (Prancūzija)',
        'fr_GA' => 'prancūzų (Gabonas)',
        'fr_GF' => 'prancūzų (Prancūzijos Gviana)',
        'fr_GN' => 'prancūzų (Gvinėja)',
        'fr_GP' => 'prancūzų (Gvadelupa)',
        'fr_GQ' => 'prancūzų (Pusiaujo Gvinėja)',
        'fr_HT' => 'prancūzų (Haitis)',
        'fr_KM' => 'prancūzų (Komorai)',
        'fr_LU' => 'prancūzų (Liuksemburgas)',
        'fr_MA' => 'prancūzų (Marokas)',
        'fr_MC' => 'prancūzų (Monakas)',
        'fr_MF' => 'prancūzų (Sen Martenas)',
        'fr_MG' => 'prancūzų (Madagaskaras)',
        'fr_ML' => 'prancūzų (Malis)',
        'fr_MQ' => 'prancūzų (Martinika)',
        'fr_MR' => 'prancūzų (Mauritanija)',
        'fr_MU' => 'prancūzų (Mauricijus)',
        'fr_NC' => 'prancūzų (Naujoji Kaledonija)',
        'fr_NE' => 'prancūzų (Nigeris)',
        'fr_PF' => 'prancūzų (Prancūzijos Polinezija)',
        'fr_PM' => 'prancūzų (Sen Pjeras ir Mikelonas)',
        'fr_RE' => 'prancūzų (Reunjonas)',
        'fr_RW' => 'prancūzų (Ruanda)',
        'fr_SC' => 'prancūzų (Seišeliai)',
        'fr_SN' => 'prancūzų (Senegalas)',
        'fr_SY' => 'prancūzų (Sirija)',
        'fr_TD' => 'prancūzų (Čadas)',
        'fr_TG' => 'prancūzų (Togas)',
        'fr_TN' => 'prancūzų (Tunisas)',
        'fr_VU' => 'prancūzų (Vanuatu)',
        'fr_WF' => 'prancūzų (Volisas ir Futūna)',
        'fr_YT' => 'prancūzų (Majotas)',
        'fy' => 'vakarų fryzų',
        'fy_NL' => 'vakarų fryzų (Nyderlandai)',
        'ga' => 'airių',
        'ga_GB' => 'airių (Jungtinė Karalystė)',
        'ga_IE' => 'airių (Airija)',
        'gd' => 'škotų [gėlų]',
        'gd_GB' => 'škotų [gėlų] (Jungtinė Karalystė)',
        'gl' => 'galisų',
        'gl_ES' => 'galisų (Ispanija)',
        'gu' => 'gudžaratų',
        'gu_IN' => 'gudžaratų (Indija)',
        'gv' => 'meniečių',
        'gv_IM' => 'meniečių (Meno Sala)',
        'ha' => 'hausų',
        'ha_GH' => 'hausų (Gana)',
        'ha_NE' => 'hausų (Nigeris)',
        'ha_NG' => 'hausų (Nigerija)',
        'he' => 'hebrajų',
        'he_IL' => 'hebrajų (Izraelis)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (Indija)',
        'hi_Latn' => 'hindi (lotynų)',
        'hi_Latn_IN' => 'hindi (lotynų, Indija)',
        'hr' => 'kroatų',
        'hr_BA' => 'kroatų (Bosnija ir Hercegovina)',
        'hr_HR' => 'kroatų (Kroatija)',
        'hu' => 'vengrų',
        'hu_HU' => 'vengrų (Vengrija)',
        'hy' => 'armėnų',
        'hy_AM' => 'armėnų (Armėnija)',
        'ia' => 'tarpinė',
        'ia_001' => 'tarpinė (pasaulis)',
        'id' => 'indoneziečių',
        'id_ID' => 'indoneziečių (Indonezija)',
        'ie' => 'interkalba',
        'ie_EE' => 'interkalba (Estija)',
        'ig' => 'igbų',
        'ig_NG' => 'igbų (Nigerija)',
        'ii' => 'sičuan ji',
        'ii_CN' => 'sičuan ji (Kinija)',
        'is' => 'islandų',
        'is_IS' => 'islandų (Islandija)',
        'it' => 'italų',
        'it_CH' => 'italų (Šveicarija)',
        'it_IT' => 'italų (Italija)',
        'it_SM' => 'italų (San Marinas)',
        'it_VA' => 'italų (Vatikano Miesto Valstybė)',
        'ja' => 'japonų',
        'ja_JP' => 'japonų (Japonija)',
        'jv' => 'javiečių',
        'jv_ID' => 'javiečių (Indonezija)',
        'ka' => 'gruzinų',
        'ka_GE' => 'gruzinų (Gruzija)',
        'ki' => 'kikujų',
        'ki_KE' => 'kikujų (Kenija)',
        'kk' => 'kazachų',
        'kk_Arab' => 'kazachų (arabų)',
        'kk_Arab_CN' => 'kazachų (arabų, Kinija)',
        'kk_Cyrl' => 'kazachų (kirilica)',
        'kk_Cyrl_KZ' => 'kazachų (kirilica, Kazachstanas)',
        'kk_KZ' => 'kazachų (Kazachstanas)',
        'kl' => 'kalalisut',
        'kl_GL' => 'kalalisut (Grenlandija)',
        'km' => 'khmerų',
        'km_KH' => 'khmerų (Kambodža)',
        'kn' => 'kanadų',
        'kn_IN' => 'kanadų (Indija)',
        'ko' => 'korėjiečių',
        'ko_CN' => 'korėjiečių (Kinija)',
        'ko_KP' => 'korėjiečių (Šiaurės Korėja)',
        'ko_KR' => 'korėjiečių (Pietų Korėja)',
        'ks' => 'kašmyrų',
        'ks_Arab' => 'kašmyrų (arabų)',
        'ks_Arab_IN' => 'kašmyrų (arabų, Indija)',
        'ks_Deva' => 'kašmyrų (devanagari)',
        'ks_Deva_IN' => 'kašmyrų (devanagari, Indija)',
        'ks_IN' => 'kašmyrų (Indija)',
        'ku' => 'kurdų',
        'ku_Latn' => 'kurdų (lotynų)',
        'ku_Latn_IQ' => 'kurdų (lotynų, Irakas)',
        'ku_Latn_SY' => 'kurdų (lotynų, Sirija)',
        'ku_Latn_TR' => 'kurdų (lotynų, Turkija)',
        'ku_SY' => 'kurdų (Sirija)',
        'ku_TR' => 'kurdų (Turkija)',
        'kw' => 'kornų',
        'kw_GB' => 'kornų (Jungtinė Karalystė)',
        'ky' => 'kirgizų',
        'ky_KG' => 'kirgizų (Kirgizija)',
        'lb' => 'liuksemburgiečių',
        'lb_LU' => 'liuksemburgiečių (Liuksemburgas)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'ngalų',
        'ln_AO' => 'ngalų (Angola)',
        'ln_CD' => 'ngalų (Kongas-Kinšasa)',
        'ln_CF' => 'ngalų (Centrinės Afrikos Respublika)',
        'ln_CG' => 'ngalų (Kongas-Brazavilis)',
        'lo' => 'laosiečių',
        'lo_LA' => 'laosiečių (Laosas)',
        'lt' => 'lietuvių',
        'lt_LT' => 'lietuvių (Lietuva)',
        'lu' => 'luba katanga',
        'lu_CD' => 'luba katanga (Kongas-Kinšasa)',
        'lv' => 'latvių',
        'lv_LV' => 'latvių (Latvija)',
        'mg' => 'malagasų',
        'mg_MG' => 'malagasų (Madagaskaras)',
        'mi' => 'maorių',
        'mi_NZ' => 'maorių (Naujoji Zelandija)',
        'mk' => 'makedonų',
        'mk_MK' => 'makedonų (Šiaurės Makedonija)',
        'ml' => 'malajalių',
        'ml_IN' => 'malajalių (Indija)',
        'mn' => 'mongolų',
        'mn_MN' => 'mongolų (Mongolija)',
        'mr' => 'maratų',
        'mr_IN' => 'maratų (Indija)',
        'ms' => 'malajiečių',
        'ms_BN' => 'malajiečių (Brunėjus)',
        'ms_ID' => 'malajiečių (Indonezija)',
        'ms_MY' => 'malajiečių (Malaizija)',
        'ms_SG' => 'malajiečių (Singapūras)',
        'mt' => 'maltiečių',
        'mt_MT' => 'maltiečių (Malta)',
        'my' => 'birmiečių',
        'my_MM' => 'birmiečių (Mianmaras [Birma])',
        'nb' => 'norvegų bukmolas',
        'nb_NO' => 'norvegų bukmolas (Norvegija)',
        'nb_SJ' => 'norvegų bukmolas (Svalbardas ir Janas Majenas)',
        'nd' => 'šiaurės ndebelų',
        'nd_ZW' => 'šiaurės ndebelų (Zimbabvė)',
        'ne' => 'nepaliečių',
        'ne_IN' => 'nepaliečių (Indija)',
        'ne_NP' => 'nepaliečių (Nepalas)',
        'nl' => 'olandų',
        'nl_AW' => 'olandų (Aruba)',
        'nl_BE' => 'olandų (Belgija)',
        'nl_BQ' => 'olandų (Karibų Nyderlandai)',
        'nl_CW' => 'olandų (Kiurasao)',
        'nl_NL' => 'olandų (Nyderlandai)',
        'nl_SR' => 'olandų (Surinamas)',
        'nl_SX' => 'olandų (Sint Martenas)',
        'nn' => 'naujoji norvegų',
        'nn_NO' => 'naujoji norvegų (Norvegija)',
        'no' => 'norvegų',
        'no_NO' => 'norvegų (Norvegija)',
        'oc' => 'očitarų',
        'oc_ES' => 'očitarų (Ispanija)',
        'oc_FR' => 'očitarų (Prancūzija)',
        'om' => 'oromų',
        'om_ET' => 'oromų (Etiopija)',
        'om_KE' => 'oromų (Kenija)',
        'or' => 'odijų',
        'or_IN' => 'odijų (Indija)',
        'os' => 'osetinų',
        'os_GE' => 'osetinų (Gruzija)',
        'os_RU' => 'osetinų (Rusija)',
        'pa' => 'pendžabų',
        'pa_Arab' => 'pendžabų (arabų)',
        'pa_Arab_PK' => 'pendžabų (arabų, Pakistanas)',
        'pa_Guru' => 'pendžabų (gurmuki)',
        'pa_Guru_IN' => 'pendžabų (gurmuki, Indija)',
        'pa_IN' => 'pendžabų (Indija)',
        'pa_PK' => 'pendžabų (Pakistanas)',
        'pl' => 'lenkų',
        'pl_PL' => 'lenkų (Lenkija)',
        'ps' => 'puštūnų',
        'ps_AF' => 'puštūnų (Afganistanas)',
        'ps_PK' => 'puštūnų (Pakistanas)',
        'pt' => 'portugalų',
        'pt_AO' => 'portugalų (Angola)',
        'pt_BR' => 'portugalų (Brazilija)',
        'pt_CH' => 'portugalų (Šveicarija)',
        'pt_CV' => 'portugalų (Žaliasis Kyšulys)',
        'pt_GQ' => 'portugalų (Pusiaujo Gvinėja)',
        'pt_GW' => 'portugalų (Bisau Gvinėja)',
        'pt_LU' => 'portugalų (Liuksemburgas)',
        'pt_MO' => 'portugalų (Ypatingasis Administracinis Kinijos Regionas Makao)',
        'pt_MZ' => 'portugalų (Mozambikas)',
        'pt_PT' => 'portugalų (Portugalija)',
        'pt_ST' => 'portugalų (San Tomė ir Prinsipė)',
        'pt_TL' => 'portugalų (Rytų Timoras)',
        'qu' => 'kečujų',
        'qu_BO' => 'kečujų (Bolivija)',
        'qu_EC' => 'kečujų (Ekvadoras)',
        'qu_PE' => 'kečujų (Peru)',
        'rm' => 'retoromanų',
        'rm_CH' => 'retoromanų (Šveicarija)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundis)',
        'ro' => 'rumunų',
        'ro_MD' => 'rumunų (Moldova)',
        'ro_RO' => 'rumunų (Rumunija)',
        'ru' => 'rusų',
        'ru_BY' => 'rusų (Baltarusija)',
        'ru_KG' => 'rusų (Kirgizija)',
        'ru_KZ' => 'rusų (Kazachstanas)',
        'ru_MD' => 'rusų (Moldova)',
        'ru_RU' => 'rusų (Rusija)',
        'ru_UA' => 'rusų (Ukraina)',
        'rw' => 'kinjaruandų',
        'rw_RW' => 'kinjaruandų (Ruanda)',
        'sa' => 'sanskritas',
        'sa_IN' => 'sanskritas (Indija)',
        'sc' => 'sardiniečių',
        'sc_IT' => 'sardiniečių (Italija)',
        'sd' => 'sindų',
        'sd_Arab' => 'sindų (arabų)',
        'sd_Arab_PK' => 'sindų (arabų, Pakistanas)',
        'sd_Deva' => 'sindų (devanagari)',
        'sd_Deva_IN' => 'sindų (devanagari, Indija)',
        'sd_IN' => 'sindų (Indija)',
        'sd_PK' => 'sindų (Pakistanas)',
        'se' => 'šiaurės samių',
        'se_FI' => 'šiaurės samių (Suomija)',
        'se_NO' => 'šiaurės samių (Norvegija)',
        'se_SE' => 'šiaurės samių (Švedija)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Centrinės Afrikos Respublika)',
        'sh' => 'serbų-kroatų',
        'sh_BA' => 'serbų-kroatų (Bosnija ir Hercegovina)',
        'si' => 'sinhalų',
        'si_LK' => 'sinhalų (Šri Lanka)',
        'sk' => 'slovakų',
        'sk_SK' => 'slovakų (Slovakija)',
        'sl' => 'slovėnų',
        'sl_SI' => 'slovėnų (Slovėnija)',
        'sn' => 'šonų',
        'sn_ZW' => 'šonų (Zimbabvė)',
        'so' => 'somaliečių',
        'so_DJ' => 'somaliečių (Džibutis)',
        'so_ET' => 'somaliečių (Etiopija)',
        'so_KE' => 'somaliečių (Kenija)',
        'so_SO' => 'somaliečių (Somalis)',
        'sq' => 'albanų',
        'sq_AL' => 'albanų (Albanija)',
        'sq_MK' => 'albanų (Šiaurės Makedonija)',
        'sr' => 'serbų',
        'sr_BA' => 'serbų (Bosnija ir Hercegovina)',
        'sr_Cyrl' => 'serbų (kirilica)',
        'sr_Cyrl_BA' => 'serbų (kirilica, Bosnija ir Hercegovina)',
        'sr_Cyrl_ME' => 'serbų (kirilica, Juodkalnija)',
        'sr_Cyrl_RS' => 'serbų (kirilica, Serbija)',
        'sr_Latn' => 'serbų (lotynų)',
        'sr_Latn_BA' => 'serbų (lotynų, Bosnija ir Hercegovina)',
        'sr_Latn_ME' => 'serbų (lotynų, Juodkalnija)',
        'sr_Latn_RS' => 'serbų (lotynų, Serbija)',
        'sr_ME' => 'serbų (Juodkalnija)',
        'sr_RS' => 'serbų (Serbija)',
        'st' => 'pietų Soto',
        'st_LS' => 'pietų Soto (Lesotas)',
        'st_ZA' => 'pietų Soto (Pietų Afrika)',
        'su' => 'sundų',
        'su_ID' => 'sundų (Indonezija)',
        'su_Latn' => 'sundų (lotynų)',
        'su_Latn_ID' => 'sundų (lotynų, Indonezija)',
        'sv' => 'švedų',
        'sv_AX' => 'švedų (Alandų Salos)',
        'sv_FI' => 'švedų (Suomija)',
        'sv_SE' => 'švedų (Švedija)',
        'sw' => 'suahilių',
        'sw_CD' => 'suahilių (Kongas-Kinšasa)',
        'sw_KE' => 'suahilių (Kenija)',
        'sw_TZ' => 'suahilių (Tanzanija)',
        'sw_UG' => 'suahilių (Uganda)',
        'ta' => 'tamilų',
        'ta_IN' => 'tamilų (Indija)',
        'ta_LK' => 'tamilų (Šri Lanka)',
        'ta_MY' => 'tamilų (Malaizija)',
        'ta_SG' => 'tamilų (Singapūras)',
        'te' => 'telugų',
        'te_IN' => 'telugų (Indija)',
        'tg' => 'tadžikų',
        'tg_TJ' => 'tadžikų (Tadžikija)',
        'th' => 'tajų',
        'th_TH' => 'tajų (Tailandas)',
        'ti' => 'tigrajų',
        'ti_ER' => 'tigrajų (Eritrėja)',
        'ti_ET' => 'tigrajų (Etiopija)',
        'tk' => 'turkmėnų',
        'tk_TM' => 'turkmėnų (Turkmėnistanas)',
        'tl' => 'tagalogų',
        'tl_PH' => 'tagalogų (Filipinai)',
        'tn' => 'tsvanų',
        'tn_BW' => 'tsvanų (Botsvana)',
        'tn_ZA' => 'tsvanų (Pietų Afrika)',
        'to' => 'tonganų',
        'to_TO' => 'tonganų (Tonga)',
        'tr' => 'turkų',
        'tr_CY' => 'turkų (Kipras)',
        'tr_TR' => 'turkų (Turkija)',
        'tt' => 'totorių',
        'tt_RU' => 'totorių (Rusija)',
        'ug' => 'uigūrų',
        'ug_CN' => 'uigūrų (Kinija)',
        'uk' => 'ukrainiečių',
        'uk_UA' => 'ukrainiečių (Ukraina)',
        'ur' => 'urdų',
        'ur_IN' => 'urdų (Indija)',
        'ur_PK' => 'urdų (Pakistanas)',
        'uz' => 'uzbekų',
        'uz_AF' => 'uzbekų (Afganistanas)',
        'uz_Arab' => 'uzbekų (arabų)',
        'uz_Arab_AF' => 'uzbekų (arabų, Afganistanas)',
        'uz_Cyrl' => 'uzbekų (kirilica)',
        'uz_Cyrl_UZ' => 'uzbekų (kirilica, Uzbekistanas)',
        'uz_Latn' => 'uzbekų (lotynų)',
        'uz_Latn_UZ' => 'uzbekų (lotynų, Uzbekistanas)',
        'uz_UZ' => 'uzbekų (Uzbekistanas)',
        'vi' => 'vietnamiečių',
        'vi_VN' => 'vietnamiečių (Vietnamas)',
        'wo' => 'volofų',
        'wo_SN' => 'volofų (Senegalas)',
        'xh' => 'kosų',
        'xh_ZA' => 'kosų (Pietų Afrika)',
        'yi' => 'jidiš',
        'yi_UA' => 'jidiš (Ukraina)',
        'yo' => 'jorubų',
        'yo_BJ' => 'jorubų (Beninas)',
        'yo_NG' => 'jorubų (Nigerija)',
        'za' => 'chuang',
        'za_CN' => 'chuang (Kinija)',
        'zh' => 'kinų',
        'zh_CN' => 'kinų (Kinija)',
        'zh_HK' => 'kinų (Ypatingasis Administracinis Kinijos Regionas Honkongas)',
        'zh_Hans' => 'kinų (supaprastinti)',
        'zh_Hans_CN' => 'kinų (supaprastinti, Kinija)',
        'zh_Hans_HK' => 'kinų (supaprastinti, Ypatingasis Administracinis Kinijos Regionas Honkongas)',
        'zh_Hans_MO' => 'kinų (supaprastinti, Ypatingasis Administracinis Kinijos Regionas Makao)',
        'zh_Hans_MY' => 'kinų (supaprastinti, Malaizija)',
        'zh_Hans_SG' => 'kinų (supaprastinti, Singapūras)',
        'zh_Hant' => 'kinų (tradiciniai)',
        'zh_Hant_HK' => 'kinų (tradiciniai, Ypatingasis Administracinis Kinijos Regionas Honkongas)',
        'zh_Hant_MO' => 'kinų (tradiciniai, Ypatingasis Administracinis Kinijos Regionas Makao)',
        'zh_Hant_MY' => 'kinų (tradiciniai, Malaizija)',
        'zh_Hant_TW' => 'kinų (tradiciniai, Taivanas)',
        'zh_MO' => 'kinų (Ypatingasis Administracinis Kinijos Regionas Makao)',
        'zh_SG' => 'kinų (Singapūras)',
        'zh_TW' => 'kinų (Taivanas)',
        'zu' => 'zulų',
        'zu_ZA' => 'zulų (Pietų Afrika)',
    ],
];
