<?php

return [
    'Names' => [
        'Adlm' => 'آدلام',
        'Aghb' => 'آلبانیایی قفقازی',
        'Arab' => 'عربی',
        'Aran' => 'آران',
        'Armi' => 'آرامی هخامنشی',
        'Armn' => 'ارمنی',
        'Avst' => 'اوستایی',
        'Bali' => 'بالیایی',
        'Batk' => 'باتاکی',
        'Beng' => 'بنگالی',
        'Blis' => 'نمادهای بلیس',
        'Bopo' => 'بوپوموفو',
        'Brah' => 'براهمی',
        'Brai' => 'بریل',
        'Bugi' => 'بوگیایی',
        'Buhd' => 'بوهید',
        'Cakm' => 'چاکمایی',
        'Cans' => 'زبان‌های سیلابی بومی‌های متحد کانادایی',
        'Cari' => 'کاری',
        'Cham' => 'چمی',
        'Cher' => 'چروکی',
        'Cirt' => 'کرت',
        'Copt' => 'قبطی',
        'Cprt' => 'قبرسی',
        'Cyrl' => 'سیریلی',
        'Deva' => 'دوناگری',
        'Dsrt' => 'دیسرتی',
        'Egyh' => 'کاهنی مصری',
        'Egyp' => 'هیروگلیف مصری',
        'Ethi' => 'اتیوپیایی',
        'Geok' => 'گرجی خوتسوری',
        'Geor' => 'گرجی',
        'Glag' => 'گلاگولیتی',
        'Goth' => 'گوتی',
        'Grek' => 'یونانی',
        'Gujr' => 'گجراتی',
        'Guru' => 'گورومخی',
        'Hanb' => 'هان با بوموپوفو',
        'Hang' => 'هانگول',
        'Hani' => 'هان',
        'Hano' => 'هانونویی',
        'Hans' => 'ساده‌شده',
        'Hant' => 'سنتی',
        'Hebr' => 'عبری',
        'Hira' => 'هیراگانا',
        'Hluw' => 'هیروگلیف آناتولی',
        'Hrkt' => 'هجانگاری ژاپنی',
        'Hung' => 'مجاری باستان',
        'Inds' => 'ایندوس',
        'Ital' => 'ایتالی باستان',
        'Jamo' => 'جامو',
        'Java' => 'جاوه‌ای',
        'Jpan' => 'ژاپنی',
        'Kali' => 'کایالی',
        'Kana' => 'کاتاکانا',
        'Khmr' => 'خمری',
        'Khoj' => 'خواجکی',
        'Knda' => 'کانارا',
        'Kore' => 'کره‌ای',
        'Kthi' => 'کثی',
        'Lana' => 'لانایی',
        'Laoo' => 'لائوسی',
        'Latf' => 'لاتینی فراکتور',
        'Latg' => 'لاتینی گیلی',
        'Latn' => 'لاتین',
        'Limb' => 'لیمبایی',
        'Lina' => 'خطی الف',
        'Linb' => 'خطی ب',
        'Lyci' => 'لسیایی',
        'Lydi' => 'لدیایی',
        'Mand' => 'منده‌ای',
        'Mani' => 'مانوی',
        'Maya' => 'هیروگلیف مایایی',
        'Mero' => 'مروییتی',
        'Mlym' => 'مالایالامی',
        'Mong' => 'مغولی',
        'Moon' => 'مونی',
        'Mtei' => 'مایک میتی',
        'Mymr' => 'میانمار',
        'Narb' => 'عربی شمالی باستان',
        'Nbat' => 'نبطی',
        'Nkoo' => 'اِن کو',
        'Ogam' => 'اوگامی',
        'Olck' => 'اول چیکی',
        'Orkh' => 'اورخونی',
        'Orya' => 'اودیه',
        'Palm' => 'پالمیرایی',
        'Perm' => 'پرمی باستان',
        'Phli' => 'پهلوی کتیبه‌ای',
        'Phlp' => 'پهلوی زبوری',
        'Phlv' => 'پهلوی کتابی',
        'Phnx' => 'فنیقی',
        'Prti' => 'پارتی کتیبه‌ای',
        'Rjng' => 'رجنگی',
        'Rohg' => 'حنیفی',
        'Runr' => 'رونی',
        'Samr' => 'سامری',
        'Sara' => 'ساراتی',
        'Sarb' => 'عربی جنوبی باستان',
        'Saur' => 'سوراشترایی',
        'Shaw' => 'شاوی',
        'Sinh' => 'سینهالی',
        'Sund' => 'سوندانی',
        'Sylo' => 'سیلوتی نگاری',
        'Syrc' => 'سریانی',
        'Syre' => 'سریانی سطرنجیلی',
        'Syrj' => 'سریانی غربی',
        'Syrn' => 'سریانی شرقی',
        'Tagb' => 'تگبنوایی',
        'Taml' => 'تامیلی',
        'Telu' => 'تلوگویی',
        'Teng' => 'تنگوار',
        'Tfng' => 'تیفیناغی',
        'Tglg' => 'تاگالوگی',
        'Thaa' => 'تانا',
        'Thai' => 'تایلندی',
        'Tibt' => 'تبتی',
        'Ugar' => 'اوگاریتی',
        'Vaii' => 'ویایی',
        'Visp' => 'گفتار قابل مشاهده',
        'Xpeo' => 'فارسی باستان',
        'Xsux' => 'میخی سومری‐اکدی',
        'Yiii' => 'یی',
        'Zinh' => 'موروثی',
        'Zmth' => 'علائم ریاضی',
        'Zsye' => 'اموجی',
        'Zsym' => 'علائم',
        'Zxxx' => 'نانوشته',
        'Zyyy' => 'مشترک',
    ],
];
