{% set pagetitle = 'Select an authentication source'|trans %}
{% extends "base.twig" %}

{% block content %}
    <h2>{{ 'Select an authentication source'|trans }}</h2>
    <p>{{ 'The selected authentication source will be used to authenticate you and to create a valid session.'|trans }}</p>

    <form>
        <input type="hidden" name="AuthState" value="{{ authstate }}">
        <ul>
        {% for key, source in sources %}
            {% set button = ('button-' ~ key) %}
	    <li class="{{ source.css_class|default('') }} authsource">
              <input type="submit" name="sourceChoice[{{ key }}]"
                {%- if key == preferred %}
                    class="pure-button pure-button-active" autofocus
                {%- else %}
                    class="pure-button"
                {% endif %}
                id="{{ button }}" value="{{ source.text is defined ? source.text|translateFromArray : key }}">
              {% if source.help is defined %}
                <p>{{ source.help|translateFromArray }}</p>
              {% endif %}
            </li>
        {% endfor %}
        </ul>
    </form>
{% endblock %}
