<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibia)',
        'af_ZA' => 'afrikaans (Sydafrika)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amhariska',
        'am_ET' => 'amhariska (Etiopien)',
        'ar' => 'arabiska',
        'ar_001' => 'arabiska (världen)',
        'ar_AE' => 'arabiska (Förenade Arabemiraten)',
        'ar_BH' => 'arabiska (Bahrain)',
        'ar_DJ' => 'arabiska (Djibouti)',
        'ar_DZ' => 'arabiska (Algeriet)',
        'ar_EG' => 'arabiska (Egypten)',
        'ar_EH' => 'arabiska (Västsahara)',
        'ar_ER' => 'arabiska (Eritrea)',
        'ar_IL' => 'arabiska (Israel)',
        'ar_IQ' => 'arabiska (Irak)',
        'ar_JO' => 'arabiska (Jordanien)',
        'ar_KM' => 'arabiska (Komorerna)',
        'ar_KW' => 'arabiska (Kuwait)',
        'ar_LB' => 'arabiska (Libanon)',
        'ar_LY' => 'arabiska (Libyen)',
        'ar_MA' => 'arabiska (Marocko)',
        'ar_MR' => 'arabiska (Mauretanien)',
        'ar_OM' => 'arabiska (Oman)',
        'ar_PS' => 'arabiska (Palestinska territorierna)',
        'ar_QA' => 'arabiska (Qatar)',
        'ar_SA' => 'arabiska (Saudiarabien)',
        'ar_SD' => 'arabiska (Sudan)',
        'ar_SO' => 'arabiska (Somalia)',
        'ar_SS' => 'arabiska (Sydsudan)',
        'ar_SY' => 'arabiska (Syrien)',
        'ar_TD' => 'arabiska (Tchad)',
        'ar_TN' => 'arabiska (Tunisien)',
        'ar_YE' => 'arabiska (Jemen)',
        'as' => 'assamesiska',
        'as_IN' => 'assamesiska (Indien)',
        'az' => 'azerbajdzjanska',
        'az_AZ' => 'azerbajdzjanska (Azerbajdzjan)',
        'az_Cyrl' => 'azerbajdzjanska (kyrilliska)',
        'az_Cyrl_AZ' => 'azerbajdzjanska (kyrilliska, Azerbajdzjan)',
        'az_Latn' => 'azerbajdzjanska (latinska)',
        'az_Latn_AZ' => 'azerbajdzjanska (latinska, Azerbajdzjan)',
        'ba' => 'basjkiriska',
        'ba_RU' => 'basjkiriska (Ryssland)',
        'be' => 'belarusiska',
        'be_BY' => 'belarusiska (Belarus)',
        'bg' => 'bulgariska',
        'bg_BG' => 'bulgariska (Bulgarien)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengali',
        'bn_BD' => 'bengali (Bangladesh)',
        'bn_IN' => 'bengali (Indien)',
        'bo' => 'tibetanska',
        'bo_CN' => 'tibetanska (Kina)',
        'bo_IN' => 'tibetanska (Indien)',
        'br' => 'bretonska',
        'br_FR' => 'bretonska (Frankrike)',
        'bs' => 'bosniska',
        'bs_BA' => 'bosniska (Bosnien och Hercegovina)',
        'bs_Cyrl' => 'bosniska (kyrilliska)',
        'bs_Cyrl_BA' => 'bosniska (kyrilliska, Bosnien och Hercegovina)',
        'bs_Latn' => 'bosniska (latinska)',
        'bs_Latn_BA' => 'bosniska (latinska, Bosnien och Hercegovina)',
        'ca' => 'katalanska',
        'ca_AD' => 'katalanska (Andorra)',
        'ca_ES' => 'katalanska (Spanien)',
        'ca_FR' => 'katalanska (Frankrike)',
        'ca_IT' => 'katalanska (Italien)',
        'ce' => 'tjetjenska',
        'ce_RU' => 'tjetjenska (Ryssland)',
        'cs' => 'tjeckiska',
        'cs_CZ' => 'tjeckiska (Tjeckien)',
        'cv' => 'tjuvasjiska',
        'cv_RU' => 'tjuvasjiska (Ryssland)',
        'cy' => 'walesiska',
        'cy_GB' => 'walesiska (Storbritannien)',
        'da' => 'danska',
        'da_DK' => 'danska (Danmark)',
        'da_GL' => 'danska (Grönland)',
        'de' => 'tyska',
        'de_AT' => 'tyska (Österrike)',
        'de_BE' => 'tyska (Belgien)',
        'de_CH' => 'tyska (Schweiz)',
        'de_DE' => 'tyska (Tyskland)',
        'de_IT' => 'tyska (Italien)',
        'de_LI' => 'tyska (Liechtenstein)',
        'de_LU' => 'tyska (Luxemburg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhutan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'grekiska',
        'el_CY' => 'grekiska (Cypern)',
        'el_GR' => 'grekiska (Grekland)',
        'en' => 'engelska',
        'en_001' => 'engelska (världen)',
        'en_150' => 'engelska (Europa)',
        'en_AE' => 'engelska (Förenade Arabemiraten)',
        'en_AG' => 'engelska (Antigua och Barbuda)',
        'en_AI' => 'engelska (Anguilla)',
        'en_AS' => 'engelska (Amerikanska Samoa)',
        'en_AT' => 'engelska (Österrike)',
        'en_AU' => 'engelska (Australien)',
        'en_BB' => 'engelska (Barbados)',
        'en_BE' => 'engelska (Belgien)',
        'en_BI' => 'engelska (Burundi)',
        'en_BM' => 'engelska (Bermuda)',
        'en_BS' => 'engelska (Bahamas)',
        'en_BW' => 'engelska (Botswana)',
        'en_BZ' => 'engelska (Belize)',
        'en_CA' => 'engelska (Kanada)',
        'en_CC' => 'engelska (Kokosöarna)',
        'en_CH' => 'engelska (Schweiz)',
        'en_CK' => 'engelska (Cooköarna)',
        'en_CM' => 'engelska (Kamerun)',
        'en_CX' => 'engelska (Julön)',
        'en_CY' => 'engelska (Cypern)',
        'en_CZ' => 'engelska (Tjeckien)',
        'en_DE' => 'engelska (Tyskland)',
        'en_DK' => 'engelska (Danmark)',
        'en_DM' => 'engelska (Dominica)',
        'en_EE' => 'engelska (Estland)',
        'en_ER' => 'engelska (Eritrea)',
        'en_ES' => 'engelska (Spanien)',
        'en_FI' => 'engelska (Finland)',
        'en_FJ' => 'engelska (Fiji)',
        'en_FK' => 'engelska (Falklandsöarna)',
        'en_FM' => 'engelska (Mikronesien)',
        'en_FR' => 'engelska (Frankrike)',
        'en_GB' => 'engelska (Storbritannien)',
        'en_GD' => 'engelska (Grenada)',
        'en_GE' => 'engelska (Georgien)',
        'en_GG' => 'engelska (Guernsey)',
        'en_GH' => 'engelska (Ghana)',
        'en_GI' => 'engelska (Gibraltar)',
        'en_GM' => 'engelska (Gambia)',
        'en_GS' => 'engelska (Sydgeorgien och Sydsandwichöarna)',
        'en_GU' => 'engelska (Guam)',
        'en_GY' => 'engelska (Guyana)',
        'en_HK' => 'engelska (Hongkong SAR)',
        'en_HU' => 'engelska (Ungern)',
        'en_ID' => 'engelska (Indonesien)',
        'en_IE' => 'engelska (Irland)',
        'en_IL' => 'engelska (Israel)',
        'en_IM' => 'engelska (Isle of Man)',
        'en_IN' => 'engelska (Indien)',
        'en_IO' => 'engelska (Brittiska territoriet i Indiska oceanen)',
        'en_IT' => 'engelska (Italien)',
        'en_JE' => 'engelska (Jersey)',
        'en_JM' => 'engelska (Jamaica)',
        'en_JP' => 'engelska (Japan)',
        'en_KE' => 'engelska (Kenya)',
        'en_KI' => 'engelska (Kiribati)',
        'en_KN' => 'engelska (S:t Kitts och Nevis)',
        'en_KY' => 'engelska (Caymanöarna)',
        'en_LC' => 'engelska (S:t Lucia)',
        'en_LR' => 'engelska (Liberia)',
        'en_LS' => 'engelska (Lesotho)',
        'en_LT' => 'engelska (Litauen)',
        'en_LV' => 'engelska (Lettland)',
        'en_MG' => 'engelska (Madagaskar)',
        'en_MH' => 'engelska (Marshallöarna)',
        'en_MO' => 'engelska (Macao SAR)',
        'en_MP' => 'engelska (Nordmarianerna)',
        'en_MS' => 'engelska (Montserrat)',
        'en_MT' => 'engelska (Malta)',
        'en_MU' => 'engelska (Mauritius)',
        'en_MV' => 'engelska (Maldiverna)',
        'en_MW' => 'engelska (Malawi)',
        'en_MY' => 'engelska (Malaysia)',
        'en_NA' => 'engelska (Namibia)',
        'en_NF' => 'engelska (Norfolkön)',
        'en_NG' => 'engelska (Nigeria)',
        'en_NL' => 'engelska (Nederländerna)',
        'en_NO' => 'engelska (Norge)',
        'en_NR' => 'engelska (Nauru)',
        'en_NU' => 'engelska (Niue)',
        'en_NZ' => 'engelska (Nya Zeeland)',
        'en_PG' => 'engelska (Papua Nya Guinea)',
        'en_PH' => 'engelska (Filippinerna)',
        'en_PK' => 'engelska (Pakistan)',
        'en_PL' => 'engelska (Polen)',
        'en_PN' => 'engelska (Pitcairnöarna)',
        'en_PR' => 'engelska (Puerto Rico)',
        'en_PT' => 'engelska (Portugal)',
        'en_PW' => 'engelska (Palau)',
        'en_RO' => 'engelska (Rumänien)',
        'en_RW' => 'engelska (Rwanda)',
        'en_SB' => 'engelska (Salomonöarna)',
        'en_SC' => 'engelska (Seychellerna)',
        'en_SD' => 'engelska (Sudan)',
        'en_SE' => 'engelska (Sverige)',
        'en_SG' => 'engelska (Singapore)',
        'en_SH' => 'engelska (S:t Helena)',
        'en_SI' => 'engelska (Slovenien)',
        'en_SK' => 'engelska (Slovakien)',
        'en_SL' => 'engelska (Sierra Leone)',
        'en_SS' => 'engelska (Sydsudan)',
        'en_SX' => 'engelska (Sint Maarten)',
        'en_SZ' => 'engelska (Eswatini)',
        'en_TC' => 'engelska (Turks- och Caicosöarna)',
        'en_TK' => 'engelska (Tokelauöarna)',
        'en_TO' => 'engelska (Tonga)',
        'en_TT' => 'engelska (Trinidad och Tobago)',
        'en_TV' => 'engelska (Tuvalu)',
        'en_TZ' => 'engelska (Tanzania)',
        'en_UA' => 'engelska (Ukraina)',
        'en_UG' => 'engelska (Uganda)',
        'en_UM' => 'engelska (USA:s yttre öar)',
        'en_US' => 'engelska (USA)',
        'en_VC' => 'engelska (S:t Vincent och Grenadinerna)',
        'en_VG' => 'engelska (Brittiska Jungfruöarna)',
        'en_VI' => 'engelska (Amerikanska Jungfruöarna)',
        'en_VU' => 'engelska (Vanuatu)',
        'en_WS' => 'engelska (Samoa)',
        'en_ZA' => 'engelska (Sydafrika)',
        'en_ZM' => 'engelska (Zambia)',
        'en_ZW' => 'engelska (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (världen)',
        'es' => 'spanska',
        'es_419' => 'spanska (Latinamerika)',
        'es_AR' => 'spanska (Argentina)',
        'es_BO' => 'spanska (Bolivia)',
        'es_BR' => 'spanska (Brasilien)',
        'es_BZ' => 'spanska (Belize)',
        'es_CL' => 'spanska (Chile)',
        'es_CO' => 'spanska (Colombia)',
        'es_CR' => 'spanska (Costa Rica)',
        'es_CU' => 'spanska (Kuba)',
        'es_DO' => 'spanska (Dominikanska republiken)',
        'es_EC' => 'spanska (Ecuador)',
        'es_ES' => 'spanska (Spanien)',
        'es_GQ' => 'spanska (Ekvatorialguinea)',
        'es_GT' => 'spanska (Guatemala)',
        'es_HN' => 'spanska (Honduras)',
        'es_MX' => 'spanska (Mexiko)',
        'es_NI' => 'spanska (Nicaragua)',
        'es_PA' => 'spanska (Panama)',
        'es_PE' => 'spanska (Peru)',
        'es_PH' => 'spanska (Filippinerna)',
        'es_PR' => 'spanska (Puerto Rico)',
        'es_PY' => 'spanska (Paraguay)',
        'es_SV' => 'spanska (El Salvador)',
        'es_US' => 'spanska (USA)',
        'es_UY' => 'spanska (Uruguay)',
        'es_VE' => 'spanska (Venezuela)',
        'et' => 'estniska',
        'et_EE' => 'estniska (Estland)',
        'eu' => 'baskiska',
        'eu_ES' => 'baskiska (Spanien)',
        'fa' => 'persiska',
        'fa_AF' => 'persiska (Afghanistan)',
        'fa_IR' => 'persiska (Iran)',
        'ff' => 'fulani',
        'ff_Adlm' => 'fulani (adlamiska)',
        'ff_Adlm_BF' => 'fulani (adlamiska, Burkina Faso)',
        'ff_Adlm_CM' => 'fulani (adlamiska, Kamerun)',
        'ff_Adlm_GH' => 'fulani (adlamiska, Ghana)',
        'ff_Adlm_GM' => 'fulani (adlamiska, Gambia)',
        'ff_Adlm_GN' => 'fulani (adlamiska, Guinea)',
        'ff_Adlm_GW' => 'fulani (adlamiska, Guinea-Bissau)',
        'ff_Adlm_LR' => 'fulani (adlamiska, Liberia)',
        'ff_Adlm_MR' => 'fulani (adlamiska, Mauretanien)',
        'ff_Adlm_NE' => 'fulani (adlamiska, Niger)',
        'ff_Adlm_NG' => 'fulani (adlamiska, Nigeria)',
        'ff_Adlm_SL' => 'fulani (adlamiska, Sierra Leone)',
        'ff_Adlm_SN' => 'fulani (adlamiska, Senegal)',
        'ff_CM' => 'fulani (Kamerun)',
        'ff_GN' => 'fulani (Guinea)',
        'ff_Latn' => 'fulani (latinska)',
        'ff_Latn_BF' => 'fulani (latinska, Burkina Faso)',
        'ff_Latn_CM' => 'fulani (latinska, Kamerun)',
        'ff_Latn_GH' => 'fulani (latinska, Ghana)',
        'ff_Latn_GM' => 'fulani (latinska, Gambia)',
        'ff_Latn_GN' => 'fulani (latinska, Guinea)',
        'ff_Latn_GW' => 'fulani (latinska, Guinea-Bissau)',
        'ff_Latn_LR' => 'fulani (latinska, Liberia)',
        'ff_Latn_MR' => 'fulani (latinska, Mauretanien)',
        'ff_Latn_NE' => 'fulani (latinska, Niger)',
        'ff_Latn_NG' => 'fulani (latinska, Nigeria)',
        'ff_Latn_SL' => 'fulani (latinska, Sierra Leone)',
        'ff_Latn_SN' => 'fulani (latinska, Senegal)',
        'ff_MR' => 'fulani (Mauretanien)',
        'ff_SN' => 'fulani (Senegal)',
        'fi' => 'finska',
        'fi_FI' => 'finska (Finland)',
        'fo' => 'färöiska',
        'fo_DK' => 'färöiska (Danmark)',
        'fo_FO' => 'färöiska (Färöarna)',
        'fr' => 'franska',
        'fr_BE' => 'franska (Belgien)',
        'fr_BF' => 'franska (Burkina Faso)',
        'fr_BI' => 'franska (Burundi)',
        'fr_BJ' => 'franska (Benin)',
        'fr_BL' => 'franska (S:t Barthélemy)',
        'fr_CA' => 'franska (Kanada)',
        'fr_CD' => 'franska (Kongo-Kinshasa)',
        'fr_CF' => 'franska (Centralafrikanska republiken)',
        'fr_CG' => 'franska (Kongo-Brazzaville)',
        'fr_CH' => 'franska (Schweiz)',
        'fr_CI' => 'franska (Elfenbenskusten)',
        'fr_CM' => 'franska (Kamerun)',
        'fr_DJ' => 'franska (Djibouti)',
        'fr_DZ' => 'franska (Algeriet)',
        'fr_FR' => 'franska (Frankrike)',
        'fr_GA' => 'franska (Gabon)',
        'fr_GF' => 'franska (Franska Guyana)',
        'fr_GN' => 'franska (Guinea)',
        'fr_GP' => 'franska (Guadeloupe)',
        'fr_GQ' => 'franska (Ekvatorialguinea)',
        'fr_HT' => 'franska (Haiti)',
        'fr_KM' => 'franska (Komorerna)',
        'fr_LU' => 'franska (Luxemburg)',
        'fr_MA' => 'franska (Marocko)',
        'fr_MC' => 'franska (Monaco)',
        'fr_MF' => 'franska (Saint-Martin)',
        'fr_MG' => 'franska (Madagaskar)',
        'fr_ML' => 'franska (Mali)',
        'fr_MQ' => 'franska (Martinique)',
        'fr_MR' => 'franska (Mauretanien)',
        'fr_MU' => 'franska (Mauritius)',
        'fr_NC' => 'franska (Nya Kaledonien)',
        'fr_NE' => 'franska (Niger)',
        'fr_PF' => 'franska (Franska Polynesien)',
        'fr_PM' => 'franska (S:t Pierre och Miquelon)',
        'fr_RE' => 'franska (Réunion)',
        'fr_RW' => 'franska (Rwanda)',
        'fr_SC' => 'franska (Seychellerna)',
        'fr_SN' => 'franska (Senegal)',
        'fr_SY' => 'franska (Syrien)',
        'fr_TD' => 'franska (Tchad)',
        'fr_TG' => 'franska (Togo)',
        'fr_TN' => 'franska (Tunisien)',
        'fr_VU' => 'franska (Vanuatu)',
        'fr_WF' => 'franska (Wallis- och Futunaöarna)',
        'fr_YT' => 'franska (Mayotte)',
        'fy' => 'västfrisiska',
        'fy_NL' => 'västfrisiska (Nederländerna)',
        'ga' => 'iriska',
        'ga_GB' => 'iriska (Storbritannien)',
        'ga_IE' => 'iriska (Irland)',
        'gd' => 'skotsk gaeliska',
        'gd_GB' => 'skotsk gaeliska (Storbritannien)',
        'gl' => 'galiciska',
        'gl_ES' => 'galiciska (Spanien)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (Indien)',
        'gv' => 'manx',
        'gv_IM' => 'manx (Isle of Man)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'hebreiska',
        'he_IL' => 'hebreiska (Israel)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (Indien)',
        'hi_Latn' => 'hindi (latinska)',
        'hi_Latn_IN' => 'hindi (latinska, Indien)',
        'hr' => 'kroatiska',
        'hr_BA' => 'kroatiska (Bosnien och Hercegovina)',
        'hr_HR' => 'kroatiska (Kroatien)',
        'hu' => 'ungerska',
        'hu_HU' => 'ungerska (Ungern)',
        'hy' => 'armeniska',
        'hy_AM' => 'armeniska (Armenien)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (världen)',
        'id' => 'indonesiska',
        'id_ID' => 'indonesiska (Indonesien)',
        'ie' => 'interlingue',
        'ie_EE' => 'interlingue (Estland)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeria)',
        'ii' => 'szezuan i',
        'ii_CN' => 'szezuan i (Kina)',
        'is' => 'isländska',
        'is_IS' => 'isländska (Island)',
        'it' => 'italienska',
        'it_CH' => 'italienska (Schweiz)',
        'it_IT' => 'italienska (Italien)',
        'it_SM' => 'italienska (San Marino)',
        'it_VA' => 'italienska (Vatikanstaten)',
        'ja' => 'japanska',
        'ja_JP' => 'japanska (Japan)',
        'jv' => 'javanesiska',
        'jv_ID' => 'javanesiska (Indonesien)',
        'ka' => 'georgiska',
        'ka_GE' => 'georgiska (Georgien)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenya)',
        'kk' => 'kazakiska',
        'kk_Arab' => 'kazakiska (arabiska)',
        'kk_Arab_CN' => 'kazakiska (arabiska, Kina)',
        'kk_Cyrl' => 'kazakiska (kyrilliska)',
        'kk_Cyrl_KZ' => 'kazakiska (kyrilliska, Kazakstan)',
        'kk_KZ' => 'kazakiska (Kazakstan)',
        'kl' => 'grönländska',
        'kl_GL' => 'grönländska (Grönland)',
        'km' => 'kambodjanska',
        'km_KH' => 'kambodjanska (Kambodja)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (Indien)',
        'ko' => 'koreanska',
        'ko_CN' => 'koreanska (Kina)',
        'ko_KP' => 'koreanska (Nordkorea)',
        'ko_KR' => 'koreanska (Sydkorea)',
        'ks' => 'kashmiriska',
        'ks_Arab' => 'kashmiriska (arabiska)',
        'ks_Arab_IN' => 'kashmiriska (arabiska, Indien)',
        'ks_Deva' => 'kashmiriska (devanagari)',
        'ks_Deva_IN' => 'kashmiriska (devanagari, Indien)',
        'ks_IN' => 'kashmiriska (Indien)',
        'ku' => 'kurdiska',
        'ku_Latn' => 'kurdiska (latinska)',
        'ku_Latn_IQ' => 'kurdiska (latinska, Irak)',
        'ku_Latn_SY' => 'kurdiska (latinska, Syrien)',
        'ku_Latn_TR' => 'kurdiska (latinska, Turkiet)',
        'ku_SY' => 'kurdiska (Syrien)',
        'ku_TR' => 'kurdiska (Turkiet)',
        'kw' => 'korniska',
        'kw_GB' => 'korniska (Storbritannien)',
        'ky' => 'kirgiziska',
        'ky_KG' => 'kirgiziska (Kirgizistan)',
        'lb' => 'luxemburgiska',
        'lb_LU' => 'luxemburgiska (Luxemburg)',
        'lg' => 'luganda',
        'lg_UG' => 'luganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongo-Kinshasa)',
        'ln_CF' => 'lingala (Centralafrikanska republiken)',
        'ln_CG' => 'lingala (Kongo-Brazzaville)',
        'lo' => 'laotiska',
        'lo_LA' => 'laotiska (Laos)',
        'lt' => 'litauiska',
        'lt_LT' => 'litauiska (Litauen)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Kongo-Kinshasa)',
        'lv' => 'lettiska',
        'lv_LV' => 'lettiska (Lettland)',
        'mg' => 'malagassiska',
        'mg_MG' => 'malagassiska (Madagaskar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Nya Zeeland)',
        'mk' => 'makedonska',
        'mk_MK' => 'makedonska (Nordmakedonien)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (Indien)',
        'mn' => 'mongoliska',
        'mn_MN' => 'mongoliska (Mongoliet)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (Indien)',
        'ms' => 'malajiska',
        'ms_BN' => 'malajiska (Brunei)',
        'ms_ID' => 'malajiska (Indonesien)',
        'ms_MY' => 'malajiska (Malaysia)',
        'ms_SG' => 'malajiska (Singapore)',
        'mt' => 'maltesiska',
        'mt_MT' => 'maltesiska (Malta)',
        'my' => 'burmesiska',
        'my_MM' => 'burmesiska (Myanmar [Burma])',
        'nb' => 'norskt bokmål',
        'nb_NO' => 'norskt bokmål (Norge)',
        'nb_SJ' => 'norskt bokmål (Svalbard och Jan Mayen)',
        'nd' => 'nordndebele',
        'nd_ZW' => 'nordndebele (Zimbabwe)',
        'ne' => 'nepalesiska',
        'ne_IN' => 'nepalesiska (Indien)',
        'ne_NP' => 'nepalesiska (Nepal)',
        'nl' => 'nederländska',
        'nl_AW' => 'nederländska (Aruba)',
        'nl_BE' => 'nederländska (Belgien)',
        'nl_BQ' => 'nederländska (Karibiska Nederländerna)',
        'nl_CW' => 'nederländska (Curaçao)',
        'nl_NL' => 'nederländska (Nederländerna)',
        'nl_SR' => 'nederländska (Surinam)',
        'nl_SX' => 'nederländska (Sint Maarten)',
        'nn' => 'nynorska',
        'nn_NO' => 'nynorska (Norge)',
        'no' => 'norska',
        'no_NO' => 'norska (Norge)',
        'oc' => 'occitanska',
        'oc_ES' => 'occitanska (Spanien)',
        'oc_FR' => 'occitanska (Frankrike)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiopien)',
        'om_KE' => 'oromo (Kenya)',
        'or' => 'oriya',
        'or_IN' => 'oriya (Indien)',
        'os' => 'ossetiska',
        'os_GE' => 'ossetiska (Georgien)',
        'os_RU' => 'ossetiska (Ryssland)',
        'pa' => 'punjabi',
        'pa_Arab' => 'punjabi (arabiska)',
        'pa_Arab_PK' => 'punjabi (arabiska, Pakistan)',
        'pa_Guru' => 'punjabi (gurmukhiska)',
        'pa_Guru_IN' => 'punjabi (gurmukhiska, Indien)',
        'pa_IN' => 'punjabi (Indien)',
        'pa_PK' => 'punjabi (Pakistan)',
        'pl' => 'polska',
        'pl_PL' => 'polska (Polen)',
        'ps' => 'afghanska',
        'ps_AF' => 'afghanska (Afghanistan)',
        'ps_PK' => 'afghanska (Pakistan)',
        'pt' => 'portugisiska',
        'pt_AO' => 'portugisiska (Angola)',
        'pt_BR' => 'portugisiska (Brasilien)',
        'pt_CH' => 'portugisiska (Schweiz)',
        'pt_CV' => 'portugisiska (Kap Verde)',
        'pt_GQ' => 'portugisiska (Ekvatorialguinea)',
        'pt_GW' => 'portugisiska (Guinea-Bissau)',
        'pt_LU' => 'portugisiska (Luxemburg)',
        'pt_MO' => 'portugisiska (Macao SAR)',
        'pt_MZ' => 'portugisiska (Moçambique)',
        'pt_PT' => 'portugisiska (Portugal)',
        'pt_ST' => 'portugisiska (São Tomé och Príncipe)',
        'pt_TL' => 'portugisiska (Östtimor)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolivia)',
        'qu_EC' => 'quechua (Ecuador)',
        'qu_PE' => 'quechua (Peru)',
        'rm' => 'rätoromanska',
        'rm_CH' => 'rätoromanska (Schweiz)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'rumänska',
        'ro_MD' => 'rumänska (Moldavien)',
        'ro_RO' => 'rumänska (Rumänien)',
        'ru' => 'ryska',
        'ru_BY' => 'ryska (Belarus)',
        'ru_KG' => 'ryska (Kirgizistan)',
        'ru_KZ' => 'ryska (Kazakstan)',
        'ru_MD' => 'ryska (Moldavien)',
        'ru_RU' => 'ryska (Ryssland)',
        'ru_UA' => 'ryska (Ukraina)',
        'rw' => 'kinjarwanda',
        'rw_RW' => 'kinjarwanda (Rwanda)',
        'sa' => 'sanskrit',
        'sa_IN' => 'sanskrit (Indien)',
        'sc' => 'sardinska',
        'sc_IT' => 'sardinska (Italien)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arabiska)',
        'sd_Arab_PK' => 'sindhi (arabiska, Pakistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, Indien)',
        'sd_IN' => 'sindhi (Indien)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'nordsamiska',
        'se_FI' => 'nordsamiska (Finland)',
        'se_NO' => 'nordsamiska (Norge)',
        'se_SE' => 'nordsamiska (Sverige)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Centralafrikanska republiken)',
        'sh' => 'serbokroatiska',
        'sh_BA' => 'serbokroatiska (Bosnien och Hercegovina)',
        'si' => 'singalesiska',
        'si_LK' => 'singalesiska (Sri Lanka)',
        'sk' => 'slovakiska',
        'sk_SK' => 'slovakiska (Slovakien)',
        'sl' => 'slovenska',
        'sl_SI' => 'slovenska (Slovenien)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabwe)',
        'so' => 'somaliska',
        'so_DJ' => 'somaliska (Djibouti)',
        'so_ET' => 'somaliska (Etiopien)',
        'so_KE' => 'somaliska (Kenya)',
        'so_SO' => 'somaliska (Somalia)',
        'sq' => 'albanska',
        'sq_AL' => 'albanska (Albanien)',
        'sq_MK' => 'albanska (Nordmakedonien)',
        'sr' => 'serbiska',
        'sr_BA' => 'serbiska (Bosnien och Hercegovina)',
        'sr_Cyrl' => 'serbiska (kyrilliska)',
        'sr_Cyrl_BA' => 'serbiska (kyrilliska, Bosnien och Hercegovina)',
        'sr_Cyrl_ME' => 'serbiska (kyrilliska, Montenegro)',
        'sr_Cyrl_RS' => 'serbiska (kyrilliska, Serbien)',
        'sr_Latn' => 'serbiska (latinska)',
        'sr_Latn_BA' => 'serbiska (latinska, Bosnien och Hercegovina)',
        'sr_Latn_ME' => 'serbiska (latinska, Montenegro)',
        'sr_Latn_RS' => 'serbiska (latinska, Serbien)',
        'sr_ME' => 'serbiska (Montenegro)',
        'sr_RS' => 'serbiska (Serbien)',
        'st' => 'sydsotho',
        'st_LS' => 'sydsotho (Lesotho)',
        'st_ZA' => 'sydsotho (Sydafrika)',
        'su' => 'sundanesiska',
        'su_ID' => 'sundanesiska (Indonesien)',
        'su_Latn' => 'sundanesiska (latinska)',
        'su_Latn_ID' => 'sundanesiska (latinska, Indonesien)',
        'sv' => 'svenska',
        'sv_AX' => 'svenska (Åland)',
        'sv_FI' => 'svenska (Finland)',
        'sv_SE' => 'svenska (Sverige)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Kongo-Kinshasa)',
        'sw_KE' => 'swahili (Kenya)',
        'sw_TZ' => 'swahili (Tanzania)',
        'sw_UG' => 'swahili (Uganda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (Indien)',
        'ta_LK' => 'tamil (Sri Lanka)',
        'ta_MY' => 'tamil (Malaysia)',
        'ta_SG' => 'tamil (Singapore)',
        'te' => 'telugu',
        'te_IN' => 'telugu (Indien)',
        'tg' => 'tadzjikiska',
        'tg_TJ' => 'tadzjikiska (Tadzjikistan)',
        'th' => 'thailändska',
        'th_TH' => 'thailändska (Thailand)',
        'ti' => 'tigrinja',
        'ti_ER' => 'tigrinja (Eritrea)',
        'ti_ET' => 'tigrinja (Etiopien)',
        'tk' => 'turkmeniska',
        'tk_TM' => 'turkmeniska (Turkmenistan)',
        'tl' => 'tagalog',
        'tl_PH' => 'tagalog (Filippinerna)',
        'tn' => 'tswana',
        'tn_BW' => 'tswana (Botswana)',
        'tn_ZA' => 'tswana (Sydafrika)',
        'to' => 'tonganska',
        'to_TO' => 'tonganska (Tonga)',
        'tr' => 'turkiska',
        'tr_CY' => 'turkiska (Cypern)',
        'tr_TR' => 'turkiska (Turkiet)',
        'tt' => 'tatariska',
        'tt_RU' => 'tatariska (Ryssland)',
        'ug' => 'uiguriska',
        'ug_CN' => 'uiguriska (Kina)',
        'uk' => 'ukrainska',
        'uk_UA' => 'ukrainska (Ukraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (Indien)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'uzbekiska',
        'uz_AF' => 'uzbekiska (Afghanistan)',
        'uz_Arab' => 'uzbekiska (arabiska)',
        'uz_Arab_AF' => 'uzbekiska (arabiska, Afghanistan)',
        'uz_Cyrl' => 'uzbekiska (kyrilliska)',
        'uz_Cyrl_UZ' => 'uzbekiska (kyrilliska, Uzbekistan)',
        'uz_Latn' => 'uzbekiska (latinska)',
        'uz_Latn_UZ' => 'uzbekiska (latinska, Uzbekistan)',
        'uz_UZ' => 'uzbekiska (Uzbekistan)',
        'vi' => 'vietnamesiska',
        'vi_VN' => 'vietnamesiska (Vietnam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Sydafrika)',
        'yi' => 'jiddisch',
        'yi_UA' => 'jiddisch (Ukraina)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benin)',
        'yo_NG' => 'yoruba (Nigeria)',
        'za' => 'zhuang',
        'za_CN' => 'zhuang (Kina)',
        'zh' => 'kinesiska',
        'zh_CN' => 'kinesiska (Kina)',
        'zh_HK' => 'kinesiska (Hongkong SAR)',
        'zh_Hans' => 'kinesiska (förenklad)',
        'zh_Hans_CN' => 'kinesiska (förenklad, Kina)',
        'zh_Hans_HK' => 'kinesiska (förenklad, Hongkong SAR)',
        'zh_Hans_MO' => 'kinesiska (förenklad, Macao SAR)',
        'zh_Hans_MY' => 'kinesiska (förenklad, Malaysia)',
        'zh_Hans_SG' => 'kinesiska (förenklad, Singapore)',
        'zh_Hant' => 'kinesiska (traditionell)',
        'zh_Hant_HK' => 'kinesiska (traditionell, Hongkong SAR)',
        'zh_Hant_MO' => 'kinesiska (traditionell, Macao SAR)',
        'zh_Hant_MY' => 'kinesiska (traditionell, Malaysia)',
        'zh_Hant_TW' => 'kinesiska (traditionell, Taiwan)',
        'zh_MO' => 'kinesiska (Macao SAR)',
        'zh_SG' => 'kinesiska (Singapore)',
        'zh_TW' => 'kinesiska (Taiwan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Sydafrika)',
    ],
];
