<?php

return [
    'UserAssignedNames' => [],
    'Names' => [
        'AE' => 'Объединенные Арабские Эмираты',
        'BV' => 'О-в Буве',
        'CK' => 'О-ва Кука',
        'CX' => 'О-в Рождества',
        'HM' => 'О-ва Херд и Макдональд',
        'NF' => 'О-в Норфолк',
        'TL' => 'Тимор-Лесте',
        'UM' => 'Малые Тихоокеанские Отдаленные Острова США',
    ],
];
