<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ग्रीनविच मिन समय (अविड्जान)',
        'Africa/Accra' => 'ग्रीनविच मिन समय (अक्रा)',
        'Africa/Addis_Ababa' => 'पूर्वी अफ्रिकी समय (एड्डिस आबाबा)',
        'Africa/Algiers' => 'केन्द्रीय युरोपेली समय (अल्जियर्स)',
        'Africa/Asmera' => 'पूर्वी अफ्रिकी समय (आस्मारा)',
        'Africa/Asmara' => 'पूर्वी अफ्रिकी समय (आस्मारा)',
        'Africa/Bamako' => 'ग्रीनविच मिन समय (बोमाको)',
        'Africa/Bangui' => 'पश्चिम अफ्रिकी समय (बाङ्गुवी)',
        'Africa/Banjul' => 'ग्रीनविच मिन समय (बन्जुल)',
        'Africa/Bissau' => 'ग्रीनविच मिन समय (बिसाउ)',
        'Africa/Blantyre' => 'केन्द्रीय अफ्रिकी समय (ब्लान्टायर)',
        'Africa/Brazzaville' => 'पश्चिम अफ्रिकी समय (ब्राजाभिल्ले)',
        'Africa/Bujumbura' => 'केन्द्रीय अफ्रिकी समय (बुजुम्बुरा)',
        'Africa/Cairo' => 'पूर्वी युरोपेली समय (काइरो)',
        'Africa/Casablanca' => 'पश्चिमी युरोपेली समय (कासाब्लान्का)',
        'Africa/Ceuta' => 'केन्द्रीय युरोपेली समय (सेउटा)',
        'Africa/Conakry' => 'ग्रीनविच मिन समय (कोनाक्री)',
        'Africa/Dakar' => 'ग्रीनविच मिन समय (डाकार)',
        'Africa/Dar_es_Salaam' => 'पूर्वी अफ्रिकी समय (डार एस् सलाम)',
        'Africa/Djibouti' => 'पूर्वी अफ्रिकी समय (जिबौंटी)',
        'Africa/Douala' => 'पश्चिम अफ्रिकी समय (डोउआला)',
        'Africa/El_Aaiun' => 'पश्चिमी युरोपेली समय (एल् आइयुन)',
        'Africa/Freetown' => 'ग्रीनविच मिन समय (फ्रिटाउन)',
        'Africa/Gaborone' => 'केन्द्रीय अफ्रिकी समय (गावोरोन)',
        'Africa/Harare' => 'केन्द्रीय अफ्रिकी समय (हरारे)',
        'Africa/Johannesburg' => 'दक्षिण अफ्रिकी समय (जोहानेसवर्ग)',
        'Africa/Juba' => 'केन्द्रीय अफ्रिकी समय (जुबा)',
        'Africa/Kampala' => 'पूर्वी अफ्रिकी समय (काम्पाला)',
        'Africa/Khartoum' => 'केन्द्रीय अफ्रिकी समय (खार्टउम)',
        'Africa/Kigali' => 'केन्द्रीय अफ्रिकी समय (किगाली)',
        'Africa/Kinshasa' => 'पश्चिम अफ्रिकी समय (किन्शासा)',
        'Africa/Lagos' => 'पश्चिम अफ्रिकी समय (लागोस)',
        'Africa/Libreville' => 'पश्चिम अफ्रिकी समय (लिब्रेभिल्ले)',
        'Africa/Lome' => 'ग्रीनविच मिन समय (लोम)',
        'Africa/Luanda' => 'पश्चिम अफ्रिकी समय (लुवान्डा)',
        'Africa/Lubumbashi' => 'केन्द्रीय अफ्रिकी समय (लुबुम्बासी)',
        'Africa/Lusaka' => 'केन्द्रीय अफ्रिकी समय (लुसाका)',
        'Africa/Malabo' => 'पश्चिम अफ्रिकी समय (मालाबो)',
        'Africa/Maputo' => 'केन्द्रीय अफ्रिकी समय (मापुतो)',
        'Africa/Maseru' => 'दक्षिण अफ्रिकी समय (मासेरू)',
        'Africa/Mbabane' => 'दक्षिण अफ्रिकी समय (एमबाबेन)',
        'Africa/Mogadishu' => 'पूर्वी अफ्रिकी समय (मोगाडिशु)',
        'Africa/Monrovia' => 'ग्रीनविच मिन समय (मोन्रोभिया)',
        'Africa/Nairobi' => 'पूर्वी अफ्रिकी समय (नाइरोबी)',
        'Africa/Ndjamena' => 'पश्चिम अफ्रिकी समय (एन्‌जामेना)',
        'Africa/Niamey' => 'पश्चिम अफ्रिकी समय (नायमे)',
        'Africa/Nouakchott' => 'ग्रीनविच मिन समय (नोउआकचोट)',
        'Africa/Ouagadougou' => 'ग्रीनविच मिन समय (औआगाडौगौ)',
        'Africa/Porto-Novo' => 'पश्चिम अफ्रिकी समय (पोर्टो-नोभो)',
        'Africa/Sao_Tome' => 'ग्रीनविच मिन समय (साओ टोमे)',
        'Africa/Tripoli' => 'पूर्वी युरोपेली समय (त्रिपोली)',
        'Africa/Tunis' => 'केन्द्रीय युरोपेली समय (टुनिस)',
        'Africa/Windhoek' => 'केन्द्रीय अफ्रिकी समय (विन्डहोएक)',
        'America/Adak' => 'हवाई-एलुटियन समय (आडाक)',
        'America/Anchorage' => 'अलस्काको समय (एङ्कोरेज)',
        'America/Anguilla' => 'एट्लान्टिक समय (एङ्ग्विल्ला)',
        'America/Antigua' => 'एट्लान्टिक समय (एन्टिगुवा)',
        'America/Araguaina' => 'ब्राजिलीया समय (आरागुवाना)',
        'America/Argentina/La_Rioja' => 'अर्जेनटिनी समय (ला रियोजा)',
        'America/Argentina/Rio_Gallegos' => 'अर्जेनटिनी समय (रियो ग्यालेगोस)',
        'America/Argentina/Salta' => 'अर्जेनटिनी समय (साल्टा)',
        'America/Argentina/San_Juan' => 'अर्जेनटिनी समय (सान जुवान)',
        'America/Argentina/San_Luis' => 'अर्जेनटिनी समय (सान लुइस)',
        'America/Argentina/Tucuman' => 'अर्जेनटिनी समय (टुकुमान)',
        'America/Argentina/Ushuaia' => 'अर्जेनटिनी समय (उशुआइआ)',
        'America/Aruba' => 'एट्लान्टिक समय (अरुबा)',
        'America/Asuncion' => 'पाराग्वे समय (असन्सियन)',
        'America/Bahia' => 'ब्राजिलीया समय (बाहिया)',
        'America/Bahia_Banderas' => 'केन्द्रीय समय (बाहिया बान्डेराश)',
        'America/Barbados' => 'एट्लान्टिक समय (बार्बाडोस)',
        'America/Belem' => 'ब्राजिलीया समय (बेलेम)',
        'America/Belize' => 'केन्द्रीय समय (बेलिज)',
        'America/Blanc-Sablon' => 'एट्लान्टिक समय (ब्लान्क-साब्लोन)',
        'America/Boa_Vista' => 'एमाजोन समय (बोआ भिष्टा)',
        'America/Bogota' => 'कोलम्बियाली समय (बोगोटा)',
        'America/Boise' => 'हिमाली समय (बोइज)',
        'America/Buenos_Aires' => 'अर्जेनटिनी समय (ब्यनेश आयर्स)',
        'America/Argentina/Buenos_Aires' => 'अर्जेनटिनी समय (ब्यनेश आयर्स)',
        'America/Cambridge_Bay' => 'हिमाली समय (क्याम्ब्रिज बे)',
        'America/Campo_Grande' => 'एमाजोन समय (क्याम्पो ग्रान्डे)',
        'America/Cancun' => 'पूर्वी समय (कानकुन)',
        'America/Caracas' => 'भेनेज्युएला समय (काराकास)',
        'America/Catamarca' => 'अर्जेनटिनी समय (कातामार्का)',
        'America/Argentina/Catamarca' => 'अर्जेनटिनी समय (कातामार्का)',
        'America/Cayenne' => 'फ्रेन्च ग्वाना समय (कायेन्ने)',
        'America/Cayman' => 'पूर्वी समय (केम्यान)',
        'America/Chicago' => 'केन्द्रीय समय (शिकागो)',
        'America/Chihuahua' => 'केन्द्रीय समय (चिहुवाहुवा)',
        'America/Ciudad_Juarez' => 'हिमाली समय (जुआरेज सहर)',
        'America/Coral_Harbour' => 'पूर्वी समय (एटिकोकान)',
        'America/Atikokan' => 'पूर्वी समय (एटिकोकान)',
        'America/Cordoba' => 'अर्जेनटिनी समय (कोरडोवा)',
        'America/Argentina/Cordoba' => 'अर्जेनटिनी समय (कोरडोवा)',
        'America/Costa_Rica' => 'केन्द्रीय समय (कोष्टा रिका)',
        'America/Coyhaique' => 'चिली समय (कोहाक्व)',
        'America/Creston' => 'हिमाली समय (क्रेस्टन)',
        'America/Cuiaba' => 'एमाजोन समय (क्युइआबा)',
        'America/Curacao' => 'एट्लान्टिक समय (कुराकाओ)',
        'America/Danmarkshavn' => 'ग्रीनविच मिन समय (डान्मार्कशाभन)',
        'America/Dawson' => 'युकोनको समय (डसन)',
        'America/Dawson_Creek' => 'हिमाली समय (डसन क्रिक)',
        'America/Denver' => 'हिमाली समय (डेन्भर)',
        'America/Detroit' => 'पूर्वी समय (डिट्रोइट)',
        'America/Dominica' => 'एट्लान्टिक समय (डोमिनिका)',
        'America/Edmonton' => 'हिमाली समय (एड्मोन्टन)',
        'America/Eirunepe' => 'ब्राजिल समय (आइरनेपे)',
        'America/El_Salvador' => 'केन्द्रीय समय (एल् साल्भाडोर)',
        'America/Fort_Nelson' => 'हिमाली समय (फोर्ट नेल्सन)',
        'America/Fortaleza' => 'ब्राजिलीया समय (फोर्टालेजा)',
        'America/Glace_Bay' => 'एट्लान्टिक समय (ग्लेस बे)',
        'America/Godthab' => 'ग्रिनल्याण्ड समय (नूक)',
        'America/Nuuk' => 'ग्रिनल्याण्ड समय (नूक)',
        'America/Goose_Bay' => 'एट्लान्टिक समय (गुज बे)',
        'America/Grand_Turk' => 'पूर्वी समय (ग्रान्ड टर्क)',
        'America/Grenada' => 'एट्लान्टिक समय (ग्रेनाडा)',
        'America/Guadeloupe' => 'एट्लान्टिक समय (ग्वाडेलुप)',
        'America/Guatemala' => 'केन्द्रीय समय (ग्वाटेमाला)',
        'America/Guayaquil' => 'ईक्वोडोर समय (गुयाक्विल)',
        'America/Guyana' => 'गुयाना समय',
        'America/Halifax' => 'एट्लान्टिक समय (ह्यालिफ्याक्स)',
        'America/Havana' => 'क्यूबाको समय (हभाना)',
        'America/Hermosillo' => 'मेक्सिकन प्यासिफिक समय (हेर्मोसिल्लो)',
        'America/Indiana/Knox' => 'केन्द्रीय समय (नोक्स इन्डियाना)',
        'America/Indiana/Marengo' => 'पूर्वी समय (मारेन्गो, इन्डियाना)',
        'America/Indiana/Petersburg' => 'पूर्वी समय (पिटर्सबर्ग, इन्डियाना)',
        'America/Indiana/Tell_City' => 'केन्द्रीय समय (टेल सिटी, इन्डियाना)',
        'America/Indiana/Vevay' => 'पूर्वी समय (भेभे, इन्डियाना)',
        'America/Indiana/Vincennes' => 'पूर्वी समय (भिन्सेन्स)',
        'America/Indiana/Winamac' => 'पूर्वी समय (विनामाक, इन्डियाना)',
        'America/Indianapolis' => 'पूर्वी समय (इन्डियानापोलिस)',
        'America/Indiana/Indianapolis' => 'पूर्वी समय (इन्डियानापोलिस)',
        'America/Inuvik' => 'हिमाली समय (इनुभिक)',
        'America/Iqaluit' => 'पूर्वी समय (इक्वालुइट)',
        'America/Jamaica' => 'पूर्वी समय (जमाइका)',
        'America/Jujuy' => 'अर्जेनटिनी समय (जुजुई)',
        'America/Argentina/Jujuy' => 'अर्जेनटिनी समय (जुजुई)',
        'America/Juneau' => 'अलस्काको समय (जुनिउ)',
        'America/Kentucky/Monticello' => 'पूर्वी समय (मोन्टिसेल्लो,केन्टकी)',
        'America/Kralendijk' => 'एट्लान्टिक समय (कालेन्देजिक)',
        'America/La_Paz' => 'बोलिभिया समय (ला पाज)',
        'America/Lima' => 'पेरु समय (लिमा)',
        'America/Los_Angeles' => 'प्यासिफिक समय (लस् एन्जेलस)',
        'America/Louisville' => 'पूर्वी समय (लुइसभिल्ले)',
        'America/Kentucky/Louisville' => 'पूर्वी समय (लुइसभिल्ले)',
        'America/Lower_Princes' => 'एट्लान्टिक समय (लोअर प्रिन्स्स क्वार्टर)',
        'America/Maceio' => 'ब्राजिलीया समय (मासेइओ)',
        'America/Managua' => 'केन्द्रीय समय (मानागुवा)',
        'America/Manaus' => 'एमाजोन समय (मानाउस)',
        'America/Marigot' => 'एट्लान्टिक समय (म्यारिगट)',
        'America/Martinique' => 'एट्लान्टिक समय (मार्टिनिक)',
        'America/Matamoros' => 'केन्द्रीय समय (माट्तामोरोस्)',
        'America/Mazatlan' => 'मेक्सिकन प्यासिफिक समय (माजाट्लान)',
        'America/Mendoza' => 'अर्जेनटिनी समय (मेन्डोजा)',
        'America/Argentina/Mendoza' => 'अर्जेनटिनी समय (मेन्डोजा)',
        'America/Menominee' => 'केन्द्रीय समय (मेनोमिनी)',
        'America/Merida' => 'केन्द्रीय समय (मेरिडा)',
        'America/Metlakatla' => 'अलस्काको समय (मेट्लाक्टला)',
        'America/Mexico_City' => 'केन्द्रीय समय (मेक्सिको सिटी)',
        'America/Miquelon' => 'सेन्ट पियर्रे र मिक्युलोनको समय (मिक्विलन)',
        'America/Moncton' => 'एट्लान्टिक समय (मोन्कटन)',
        'America/Monterrey' => 'केन्द्रीय समय (मोन्टेर्रे)',
        'America/Montevideo' => 'उरुग्वे समय (मोन्टेभिडियो)',
        'America/Montserrat' => 'एट्लान्टिक समय (मन्टसेर्राट)',
        'America/Nassau' => 'पूर्वी समय (नास्साउ)',
        'America/New_York' => 'पूर्वी समय (न्युयोर्क)',
        'America/Nome' => 'अलस्काको समय (नोम)',
        'America/Noronha' => 'फर्नान्डो डे नोरोन्हा समय',
        'America/North_Dakota/Beulah' => 'केन्द्रीय समय (बेउला, उत्तर डाकोटा)',
        'America/North_Dakota/Center' => 'केन्द्रीय समय (उत्तर डाकोटा, केन्द्र)',
        'America/North_Dakota/New_Salem' => 'केन्द्रीय समय (नयाँ सालेम, उत्तर डाकोटा)',
        'America/Ojinaga' => 'केन्द्रीय समय (ओजिनागा)',
        'America/Panama' => 'पूर्वी समय (पानामा)',
        'America/Paramaribo' => 'सुरिनामा समय (पारामारिवो)',
        'America/Phoenix' => 'हिमाली समय (फिनिक्स)',
        'America/Port-au-Prince' => 'पूर्वी समय (पोर्ट-अउ-प्रिन्स)',
        'America/Port_of_Spain' => 'एट्लान्टिक समय (पोर्ट अफ् स्पेन)',
        'America/Porto_Velho' => 'एमाजोन समय (पोर्टो भेल्हो)',
        'America/Puerto_Rico' => 'एट्लान्टिक समय (प्युर्टो रिको)',
        'America/Punta_Arenas' => 'चिली समय (पुन्टा अरिनाज)',
        'America/Rankin_Inlet' => 'केन्द्रीय समय (रान्किन इन्लेट)',
        'America/Recife' => 'ब्राजिलीया समय (रिसाइफ)',
        'America/Regina' => 'केन्द्रीय समय (रेजिना)',
        'America/Resolute' => 'केन्द्रीय समय (रिजोलुट)',
        'America/Rio_Branco' => 'ब्राजिल समय (रियो ब्रान्को)',
        'America/Santarem' => 'ब्राजिलीया समय (सान्टारेम)',
        'America/Santiago' => 'चिली समय (सान्टिआगो)',
        'America/Santo_Domingo' => 'एट्लान्टिक समय (सान्टो डोमिङ्गो)',
        'America/Sao_Paulo' => 'ब्राजिलीया समय (साओ पाउलो)',
        'America/Scoresbysund' => 'ग्रिनल्याण्ड समय (ईट्टोक्कोरटूर्मिट)',
        'America/Sitka' => 'अलस्काको समय (सिट्का)',
        'America/St_Barthelemy' => 'एट्लान्टिक समय (सेन्ट बार्थेलेमी)',
        'America/St_Johns' => 'न्यूफाउन्डल्यान्डको समय (सेन्ट जोन्स)',
        'America/St_Kitts' => 'एट्लान्टिक समय (सेन्ट् किट्स)',
        'America/St_Lucia' => 'एट्लान्टिक समय (सेन्ट लुसिया)',
        'America/St_Thomas' => 'एट्लान्टिक समय (सेन्ट थोमस)',
        'America/St_Vincent' => 'एट्लान्टिक समय (सेन्ट भिन्सेन्ट)',
        'America/Swift_Current' => 'केन्द्रीय समय (स्विफ्ट करेन्ट)',
        'America/Tegucigalpa' => 'केन्द्रीय समय (टेगुसिगाल्पा)',
        'America/Thule' => 'एट्लान्टिक समय (थुले)',
        'America/Tijuana' => 'प्यासिफिक समय (तिजुआना)',
        'America/Toronto' => 'पूर्वी समय (टोरोन्टो)',
        'America/Tortola' => 'एट्लान्टिक समय (टार्टोला)',
        'America/Vancouver' => 'प्यासिफिक समय (भ्यानकोभर)',
        'America/Whitehorse' => 'युकोनको समय (ह्वाइटहर्स)',
        'America/Winnipeg' => 'केन्द्रीय समय (विन्निपेग)',
        'America/Yakutat' => 'अलस्काको समय (याकुटाट)',
        'Antarctica/Casey' => 'पश्चिमी अस्ट्रेलिया समय (केजे)',
        'Antarctica/Davis' => 'डेभिस समय',
        'Antarctica/DumontDUrville' => 'डुमोन्ट-डी‘ उर्भिले समय (दुमोन्ट डि उर्भेल्ले)',
        'Antarctica/Macquarie' => 'पूर्वी अस्ट्रेलिया समय (मक्वारिई)',
        'Antarctica/Mawson' => 'म्वसन समय (माउसन)',
        'Antarctica/McMurdo' => 'न्यूजिल्यान्ड समय (माकमुर्डो)',
        'Antarctica/Palmer' => 'चिली समय (पाल्मेर)',
        'Antarctica/Rothera' => 'रोथेरा समय',
        'Antarctica/Syowa' => 'स्योवा समय (सिओआ)',
        'Antarctica/Troll' => 'ग्रीनविच मिन समय (ट्रोल)',
        'Antarctica/Vostok' => 'भास्टोक समय',
        'Arctic/Longyearbyen' => 'केन्द्रीय युरोपेली समय (लङयिअरबाइएन)',
        'Asia/Aden' => 'अरबी समय (एडेन)',
        'Asia/Almaty' => 'काजकस्तानको समय (आल्माटी)',
        'Asia/Amman' => 'पूर्वी युरोपेली समय (आम्मान)',
        'Asia/Anadyr' => 'रूस समय (आनाडियर)',
        'Asia/Aqtau' => 'काजकस्तानको समय (आक्टाउ)',
        'Asia/Aqtobe' => 'काजकस्तानको समय (आक्टोब)',
        'Asia/Ashgabat' => 'तुर्कमेनिस्तान समय (अस्काबाट)',
        'Asia/Atyrau' => 'काजकस्तानको समय (अटिराउ)',
        'Asia/Baghdad' => 'अरबी समय (बगदाद)',
        'Asia/Bahrain' => 'अरबी समय (बहराईन)',
        'Asia/Baku' => 'अजरबैजान समय (बाकु)',
        'Asia/Bangkok' => 'इन्डोचाइना समय (बैंकक)',
        'Asia/Barnaul' => 'क्रासनोयार्क समय (बरनौल)',
        'Asia/Beirut' => 'पूर्वी युरोपेली समय (बेईरुट)',
        'Asia/Bishkek' => 'किर्गिस्तान समय (बिसकेक्)',
        'Asia/Brunei' => 'ब्रुनाइ दारूस्सलम समय',
        'Asia/Calcutta' => 'भारतीय मानक समय (कोलकाता)',
        'Asia/Kolkata' => 'भारतीय मानक समय (कोलकाता)',
        'Asia/Chita' => 'याकुस्ट समय (चिता)',
        'Asia/Colombo' => 'भारतीय मानक समय (कोलम्बो)',
        'Asia/Damascus' => 'पूर्वी युरोपेली समय (दामास्कस्)',
        'Asia/Dhaka' => 'बंगलादेशी समय (ढाका)',
        'Asia/Dili' => 'पूर्वी टिमोर समय (दिल्ली)',
        'Asia/Dubai' => 'खाडी मानक समय (दुबही)',
        'Asia/Dushanbe' => 'ताजिकस्तान समय (दस्सान्बे)',
        'Asia/Famagusta' => 'पूर्वी युरोपेली समय (फामागुस्ता)',
        'Asia/Gaza' => 'पूर्वी युरोपेली समय (गाजा)',
        'Asia/Hebron' => 'पूर्वी युरोपेली समय (हिब्रोन)',
        'Asia/Hong_Kong' => 'हङकङ समय',
        'Asia/Hovd' => 'होब्ड समय (होभ्ड)',
        'Asia/Irkutsk' => 'ईर्कुट्स्क समय (इर्कुत्स्क)',
        'Asia/Jakarta' => 'पश्चिमी इन्डोनेशिया समय (जाकार्ता)',
        'Asia/Jayapura' => 'पूर्वी इन्डोनेशिया समय (जयापुरा)',
        'Asia/Jerusalem' => 'इजरायल समय (जेरुसलेम)',
        'Asia/Kabul' => 'अफगानिस्तान समय (काबुल)',
        'Asia/Kamchatka' => 'रूस समय (कामचट्का)',
        'Asia/Karachi' => 'पाकिस्तानी समय (कराची)',
        'Asia/Katmandu' => 'नेपाली समय (काठमाण्डौं)',
        'Asia/Kathmandu' => 'नेपाली समय (काठमाण्डौं)',
        'Asia/Khandyga' => 'याकुस्ट समय (खान्दिगा)',
        'Asia/Krasnoyarsk' => 'क्रासनोयार्क समय (क्रास्नोयार्स्क)',
        'Asia/Kuala_Lumpur' => 'मलेसिया समय (कुआ लाम्पुर)',
        'Asia/Kuching' => 'मलेसिया समय (कुचिङ)',
        'Asia/Kuwait' => 'अरबी समय (कुवेत)',
        'Asia/Macau' => 'चीन समय (मकाउ)',
        'Asia/Magadan' => 'मागादान समय (मागाडान)',
        'Asia/Makassar' => 'केन्द्रीय इन्डोनेशिया समय (माकास्सार)',
        'Asia/Manila' => 'फिलिपिनी समय (मनिला)',
        'Asia/Muscat' => 'खाडी मानक समय (मस्क्याट)',
        'Asia/Nicosia' => 'पूर्वी युरोपेली समय (निकोसिया)',
        'Asia/Novokuznetsk' => 'क्रासनोयार्क समय (नेभोकुजनेस्क)',
        'Asia/Novosibirsk' => 'क्रासनोयार्क समय (नोबोसिबिर्स्क)',
        'Asia/Omsk' => 'ओम्स्क समय',
        'Asia/Oral' => 'काजकस्तानको समय (ओरल)',
        'Asia/Phnom_Penh' => 'इन्डोचाइना समय (फेनोम फेन)',
        'Asia/Pontianak' => 'पश्चिमी इन्डोनेशिया समय (पोन्टिआनाक)',
        'Asia/Pyongyang' => 'कोरियाली समय (प्योङयाङ)',
        'Asia/Qatar' => 'अरबी समय (कतार)',
        'Asia/Qostanay' => 'काजकस्तानको समय (कस्टाने)',
        'Asia/Qyzylorda' => 'काजकस्तानको समय (किजिलोर्डा)',
        'Asia/Rangoon' => 'म्यानमार समय (रान्गुन)',
        'Asia/Yangon' => 'म्यानमार समय (रान्गुन)',
        'Asia/Riyadh' => 'अरबी समय (रियाद)',
        'Asia/Saigon' => 'इन्डोचाइना समय (हो ची मिन्ह शहर)',
        'Asia/Ho_Chi_Minh' => 'इन्डोचाइना समय (हो ची मिन्ह शहर)',
        'Asia/Sakhalin' => 'मागादान समय (साखालिन)',
        'Asia/Samarkand' => 'उज्बेकिस्तान समय (समारकण्ड)',
        'Asia/Seoul' => 'कोरियाली समय (सिओल)',
        'Asia/Shanghai' => 'चीन समय (सान्घाई)',
        'Asia/Singapore' => 'सिंगापुर मानक समय',
        'Asia/Srednekolymsk' => 'मागादान समय (स्रेद्निकोलिम्स्क)',
        'Asia/Taipei' => 'ताइपेइ समय (ताईपे)',
        'Asia/Tashkent' => 'उज्बेकिस्तान समय (तास्केन्ट)',
        'Asia/Tbilisi' => 'जर्जिया समय (तिबिलिसी)',
        'Asia/Tehran' => 'इरानी समय (तेहेरान)',
        'Asia/Thimphu' => 'भुटानी समय (थिम्पु)',
        'Asia/Tokyo' => 'जापान समय (टोकियो)',
        'Asia/Tomsk' => 'क्रासनोयार्क समय (टोम्स्क)',
        'Asia/Ulaanbaatar' => 'उलान बाटोर समय (उलानबटार)',
        'Asia/Urumqi' => 'चीन समय (उरूम्की)',
        'Asia/Ust-Nera' => 'भ्लादिभास्टोक समय (उस्ट-नेरा)',
        'Asia/Vientiane' => 'इन्डोचाइना समय (भियन्तिन)',
        'Asia/Vladivostok' => 'भ्लादिभास्टोक समय (भ्लाडिभास्टोक)',
        'Asia/Yakutsk' => 'याकुस्ट समय (याकुत्स्क)',
        'Asia/Yekaterinburg' => 'येकाटेरिनबर्ग समय (एकटरिनबुर्ग)',
        'Asia/Yerevan' => 'अर्मेनिया समय (येरेभान)',
        'Atlantic/Azores' => 'एजोरेस् समय (आजोर्स)',
        'Atlantic/Bermuda' => 'एट्लान्टिक समय (बर्मुडा)',
        'Atlantic/Canary' => 'पश्चिमी युरोपेली समय (क्यानारी)',
        'Atlantic/Cape_Verde' => 'केप भर्दे समय (केप भर्डे)',
        'Atlantic/Faeroe' => 'पश्चिमी युरोपेली समय (फारोइ)',
        'Atlantic/Faroe' => 'पश्चिमी युरोपेली समय (फारोइ)',
        'Atlantic/Madeira' => 'पश्चिमी युरोपेली समय (माडेइरा)',
        'Atlantic/Reykjavik' => 'ग्रीनविच मिन समय (रेक्जाभिक)',
        'Atlantic/South_Georgia' => 'दक्षिण जर्जिया समय',
        'Atlantic/St_Helena' => 'ग्रीनविच मिन समय (सेन्ट हेलेना)',
        'Atlantic/Stanley' => 'फल्कल्यान्ड टापू समय (स्ट्यान्ली)',
        'Australia/Adelaide' => 'केन्द्रीय अस्ट्रेलिया समय (एडेलेड)',
        'Australia/Brisbane' => 'पूर्वी अस्ट्रेलिया समय (ब्रिस्बेन)',
        'Australia/Broken_Hill' => 'केन्द्रीय अस्ट्रेलिया समय (ब्रोकन हिल)',
        'Australia/Darwin' => 'केन्द्रीय अस्ट्रेलिया समय (डार्विन)',
        'Australia/Eucla' => 'केन्द्रीय पश्चिमी अस्ट्रेलिया समय (इयुक्ला)',
        'Australia/Hobart' => 'पूर्वी अस्ट्रेलिया समय (होभार्ट)',
        'Australia/Lindeman' => 'पूर्वी अस्ट्रेलिया समय (लिन्डेम्यान)',
        'Australia/Lord_Howe' => 'लर्ड हावे समय (लर्ड होवे)',
        'Australia/Melbourne' => 'पूर्वी अस्ट्रेलिया समय (मेल्बर्न)',
        'Australia/Perth' => 'पश्चिमी अस्ट्रेलिया समय (पर्थ)',
        'Australia/Sydney' => 'पूर्वी अस्ट्रेलिया समय (सिड्नी)',
        'Etc/GMT' => 'ग्रीनविच मिन समय',
        'Etc/UTC' => 'समन्वित विश्व समय',
        'Europe/Amsterdam' => 'केन्द्रीय युरोपेली समय (एम्स्ट्र्डम)',
        'Europe/Andorra' => 'केन्द्रीय युरोपेली समय (आन्डोर्रा)',
        'Europe/Astrakhan' => 'रूस समय (अस्त्रखान)',
        'Europe/Athens' => 'पूर्वी युरोपेली समय (एथेन्स)',
        'Europe/Belgrade' => 'केन्द्रीय युरोपेली समय (बेलग्रेड)',
        'Europe/Berlin' => 'केन्द्रीय युरोपेली समय (बर्लिन)',
        'Europe/Bratislava' => 'केन्द्रीय युरोपेली समय (ब्राटिस्लाभा)',
        'Europe/Brussels' => 'केन्द्रीय युरोपेली समय (ब्रसेल्स)',
        'Europe/Bucharest' => 'पूर्वी युरोपेली समय (वुचारेस्ट)',
        'Europe/Budapest' => 'केन्द्रीय युरोपेली समय (बुडापेस्ट)',
        'Europe/Busingen' => 'केन्द्रीय युरोपेली समय (बुसिन्नगन)',
        'Europe/Chisinau' => 'पूर्वी युरोपेली समय (चिसिनाउ)',
        'Europe/Copenhagen' => 'केन्द्रीय युरोपेली समय (कोपेनह्यागन)',
        'Europe/Dublin' => 'ग्रीनविच मिन समय (डब्लिन)',
        'Europe/Gibraltar' => 'केन्द्रीय युरोपेली समय (जिब्राल्टार)',
        'Europe/Guernsey' => 'ग्रीनविच मिन समय (गुएर्नसे)',
        'Europe/Helsinki' => 'पूर्वी युरोपेली समय (हेल्सिन्की)',
        'Europe/Isle_of_Man' => 'ग्रीनविच मिन समय (इजल अफ् म्यान)',
        'Europe/Istanbul' => 'तुर्किये समय (ईस्टानबुल)',
        'Europe/Jersey' => 'ग्रीनविच मिन समय (जर्सी)',
        'Europe/Kaliningrad' => 'पूर्वी युरोपेली समय (कालिनिनग्राद)',
        'Europe/Kiev' => 'पूर्वी युरोपेली समय (किभ)',
        'Europe/Kyiv' => 'पूर्वी युरोपेली समय (किभ)',
        'Europe/Kirov' => 'मस्को समय (किरोभ)',
        'Europe/Lisbon' => 'पश्चिमी युरोपेली समय (लिस्बोन)',
        'Europe/Ljubljana' => 'केन्द्रीय युरोपेली समय (लजुबिजाना)',
        'Europe/London' => 'ग्रीनविच मिन समय (लण्डन)',
        'Europe/Luxembourg' => 'केन्द्रीय युरोपेली समय (लक्जेम्वर्ग)',
        'Europe/Madrid' => 'केन्द्रीय युरोपेली समय (म्याड्रिड)',
        'Europe/Malta' => 'केन्द्रीय युरोपेली समय (माल्टा)',
        'Europe/Mariehamn' => 'पूर्वी युरोपेली समय (म्यारिह्याम्न)',
        'Europe/Minsk' => 'मस्को समय (मिन्स्क)',
        'Europe/Monaco' => 'केन्द्रीय युरोपेली समय (मोनाको)',
        'Europe/Moscow' => 'मस्को समय',
        'Europe/Oslo' => 'केन्द्रीय युरोपेली समय (ओस्लो)',
        'Europe/Paris' => 'केन्द्रीय युरोपेली समय (पेरिस)',
        'Europe/Podgorica' => 'केन्द्रीय युरोपेली समय (पड्गोरिका)',
        'Europe/Prague' => 'केन्द्रीय युरोपेली समय (प्राग)',
        'Europe/Riga' => 'पूर्वी युरोपेली समय (रिगा)',
        'Europe/Rome' => 'केन्द्रीय युरोपेली समय (रोम)',
        'Europe/Samara' => 'रूस समय (सामारा)',
        'Europe/San_Marino' => 'केन्द्रीय युरोपेली समय (सान मारिनो)',
        'Europe/Sarajevo' => 'केन्द्रीय युरोपेली समय (साराजेभो)',
        'Europe/Saratov' => 'रूस समय (साराटोभ)',
        'Europe/Simferopol' => 'मस्को समय (सिम्फेरोपोल)',
        'Europe/Skopje' => 'केन्द्रीय युरोपेली समय (स्कोपजे)',
        'Europe/Sofia' => 'पूर्वी युरोपेली समय (सोफिया)',
        'Europe/Stockholm' => 'केन्द्रीय युरोपेली समय (स्टकहोल्म)',
        'Europe/Tallinn' => 'पूर्वी युरोपेली समय (ताल्लिन)',
        'Europe/Tirane' => 'केन्द्रीय युरोपेली समय (टिराने)',
        'Europe/Ulyanovsk' => 'रूस समय (उल्यानोभ्स्क)',
        'Europe/Vaduz' => 'केन्द्रीय युरोपेली समय (भाडुज)',
        'Europe/Vatican' => 'केन्द्रीय युरोपेली समय (भ्याटिकन)',
        'Europe/Vienna' => 'केन्द्रीय युरोपेली समय (भियना)',
        'Europe/Vilnius' => 'पूर्वी युरोपेली समय (भिल्निअस)',
        'Europe/Volgograd' => 'मस्को समय (भोल्गोग्राद)',
        'Europe/Warsaw' => 'केन्द्रीय युरोपेली समय (वारसअ)',
        'Europe/Zagreb' => 'केन्द्रीय युरोपेली समय (जाग्रेब)',
        'Europe/Zurich' => 'केन्द्रीय युरोपेली समय (जुरिक)',
        'Indian/Antananarivo' => 'पूर्वी अफ्रिकी समय (अन्टानारिभो)',
        'Indian/Chagos' => 'हिन्द महासागर समय (चागोस)',
        'Indian/Christmas' => 'क्रिस्मस टापु समय (ख्रिस्टमस)',
        'Indian/Cocos' => 'कोकोस टापु समय',
        'Indian/Comoro' => 'पूर्वी अफ्रिकी समय (कोमोरो)',
        'Indian/Kerguelen' => 'फ्रेन्च दक्षिणी र अन्टार्टिक समय (केर्गुएलेन)',
        'Indian/Mahe' => 'सेयेचेलास् समय (माहे)',
        'Indian/Maldives' => 'माल्दिभ्स समय',
        'Indian/Mauritius' => 'मउरिटस समय (मउरिटिअस)',
        'Indian/Mayotte' => 'पूर्वी अफ्रिकी समय (मायोट्टे)',
        'Indian/Reunion' => 'रियुनियन समय',
        'Pacific/Apia' => 'आपिया समय (अपिया)',
        'Pacific/Auckland' => 'न्यूजिल्यान्ड समय (अकल्यान्ड)',
        'Pacific/Bougainville' => 'पपूवा न्यू गिनी समय (बुगेनभिल्ले)',
        'Pacific/Chatham' => 'चाथाम समय',
        'Pacific/Easter' => 'इस्टर टापू समय',
        'Pacific/Efate' => 'भानुआतु समय (ईफाते)',
        'Pacific/Enderbury' => 'फिनिक्स टापु समय (कान्टोन)',
        'Pacific/Kanton' => 'फिनिक्स टापु समय (कान्टोन)',
        'Pacific/Fakaofo' => 'तोकेलाउ समय (फाकाओफो)',
        'Pacific/Fiji' => 'फिजी समय',
        'Pacific/Funafuti' => 'टुभालु समय (फुनाफुति)',
        'Pacific/Galapagos' => 'गालापागोस् समय (गलापागोस)',
        'Pacific/Gambier' => 'ग्याम्बियर समय',
        'Pacific/Guadalcanal' => 'सोलोमोन टापु समय (गुअडालकनाल)',
        'Pacific/Guam' => 'चामोर्रो मानक समय (गुवाम)',
        'Pacific/Honolulu' => 'हवाई-एलुटियन मानक समय (होनोलुलु)',
        'Pacific/Kiritimati' => 'लाइन टापु समय (किरितिमाटी)',
        'Pacific/Kosrae' => 'कोसराए समय (कोस्राए)',
        'Pacific/Kwajalein' => 'मार्शल टापु समय (क्वाजालेइन)',
        'Pacific/Majuro' => 'मार्शल टापु समय (माजुरो)',
        'Pacific/Marquesas' => 'मार्किसस समय (मार्केसास)',
        'Pacific/Midway' => 'सामोअ समय (मिडवे)',
        'Pacific/Nauru' => 'नाउरु समय',
        'Pacific/Niue' => 'निउए समय (निउई)',
        'Pacific/Norfolk' => 'नोर्फोक टापूको समय (नरफोल्क)',
        'Pacific/Noumea' => 'नयाँ कालेदोनिया समय (नोउमेअ)',
        'Pacific/Pago_Pago' => 'सामोअ समय (पागो पागो)',
        'Pacific/Palau' => 'पालाउ समय (पलाउ)',
        'Pacific/Pitcairn' => 'पिटकैरण समय (पितकाईरन)',
        'Pacific/Ponape' => 'पोनापे समय',
        'Pacific/Pohnpei' => 'पोनापे समय',
        'Pacific/Port_Moresby' => 'पपूवा न्यू गिनी समय (पोर्ट मोरेस्बी)',
        'Pacific/Rarotonga' => 'कुक टापु समय (राओतोंगा)',
        'Pacific/Saipan' => 'चामोर्रो मानक समय (साईपन)',
        'Pacific/Tahiti' => 'ताहिती समय',
        'Pacific/Tarawa' => 'गिल्बर्ट टापु समय (तरवा)',
        'Pacific/Tongatapu' => 'टोंगा समय (टंगातपु)',
        'Pacific/Truk' => 'चुउक समय (चूक)',
        'Pacific/Chuuk' => 'चुउक समय (चूक)',
        'Pacific/Wake' => 'वेक टापु समय',
        'Pacific/Wallis' => 'वालिस् र फुटुना समय',
    ],
    'Meta' => [],
];
