<?php

return [
    'Names' => [
        'Adlm' => 'ادلام جازۋى',
        'Aghb' => 'اگۆان جازۋى',
        'Ahom' => 'احوم جازۋى',
        'Arab' => 'اراب جازۋى',
        'Aran' => 'ناستاليك جازۋى',
        'Armi' => 'ارامەي جازۋى',
        'Armn' => 'ارميان جازۋى',
        'Avst' => 'اۆەستا جازۋى',
        'Bali' => 'بالي جازۋى',
        'Bamu' => 'بامۋم جازۋى',
        'Bass' => 'باسسا جازۋى',
        'Batk' => 'باتاك جازۋى',
        'Beng' => 'بەنگال جازۋى',
        'Berf' => 'زاگاۋا جازۋى',
        'Bhks' => 'بحايسۋكى جازۋى',
        'Bopo' => 'بوپوموفو جازۋى',
        'Brah' => 'براحمي جازۋى',
        'Brai' => 'برايل جازۋى',
        'Bugi' => 'بۋگي جازۋى',
        'Buhd' => 'بۋحيد جازۋى',
        'Cakm' => 'چاكما جازۋى',
        'Cans' => 'كانادالىق بۋىن جۇيەلى جازۋ',
        'Cari' => 'كاري جازۋى',
        'Cham' => 'چام جازۋى',
        'Cher' => 'چەروكي جازۋى',
        'Chrs' => 'حورەزم جازۋى',
        'Copt' => 'كوپت جازۋى',
        'Cpmn' => 'كيپر-مينوي جازۋى',
        'Cprt' => 'كيپر جازۋى',
        'Cyrl' => 'كيريل جازۋى',
        'Cyrs' => 'كونە ورىس جازۋى',
        'Deva' => 'دەۆاناگاري جازۋى',
        'Diak' => 'ديۆەحي اكۋرۋ جازۋى',
        'Dogr' => 'دوگرا جازۋى',
        'Dsrt' => 'دەسەرەت جازۋى',
        'Dupl' => 'دۋپلويە جازۋى',
        'Egyp' => 'مىسىر جازۋى',
        'Elba' => 'ەلباسان جازۋى',
        'Elym' => 'ەليماي جازۋى',
        'Ethi' => 'ەفيوپيالىق جازۋ',
        'Gara' => 'گاراي جازۋى',
        'Geor' => 'گرۋزين جازۋى',
        'Glag' => 'گلاگول جازۋى',
        'Gong' => 'گۋنجالا گوندي جازۋى',
        'Gonm' => 'ماسارام گوندي جازۋى',
        'Goth' => 'گوت جازۋى',
        'Gran' => 'گرانتحا جازۋى',
        'Grek' => 'گرەك جازۋى',
        'Gujr' => 'گۋجاراتي جازۋى',
        'Gukh' => 'گۋرۋڭ كحەما جازۋى',
        'Guru' => 'گۋرمۋكحي جازۋى',
        'Hanb' => 'حانب جازۋى',
        'Hang' => 'حانگىل جازۋى',
        'Hani' => 'قىتاي جازۋى',
        'Hano' => 'حانۋنۋ جازۋى',
        'Hans' => 'جەڭىلدەتىلگەن جازۋ',
        'Hant' => 'ءداستۇرلى جازۋ',
        'Hatr' => 'حاترا جازۋى',
        'Hebr' => 'يۆريت جازۋى',
        'Hira' => 'حيراگانا جازۋى',
        'Hluw' => 'انادولى جازۋى',
        'Hmng' => 'پاحاۋ جازۋى',
        'Hmnp' => 'نياكەڭ پۋاچۋە حموڭ جازۋى',
        'Hrkt' => 'حيراگانا نەمەسە كاتاكانا',
        'Hung' => 'ماجار رۋناسى',
        'Ital' => 'ەسكى يتالياجازۋى',
        'Jamo' => 'جامو جازۋى',
        'Java' => 'ياۆا جازۋى',
        'Jpan' => 'جاپون جازۋى',
        'Kali' => 'كايا-لي جازۋى',
        'Kana' => 'كاتاكانا جازۋى',
        'Kawi' => 'كاۋي جازۋى',
        'Khar' => 'كحاروشتحي جازۋى',
        'Khmr' => 'كحمەر جازۋى',
        'Khoj' => 'حوجيكي جازۋى',
        'Kits' => 'شاعىن كيدان جازۋى',
        'Knda' => 'كاننادا جازۋى',
        'Kore' => 'كورەي جازۋى',
        'Krai' => 'كيرات راي جازۋى',
        'Kthi' => 'كايتحي جازۋى',
        'Lana' => 'لاننا جازۋى',
        'Laoo' => 'لاوس جازۋى',
        'Latf' => 'فراكتۋر لاتىن جازۋى',
        'Latg' => 'گاەل لاتىن جازۋى',
        'Latn' => 'لاتىن جازۋى',
        'Lepc' => 'لەپچا جازۋى',
        'Limb' => 'ليمبۋ جازۋى',
        'Lina' => 'سىزىقتىق A جازۋى',
        'Linb' => 'سىزىقتىق B جازۋى',
        'Lisu' => 'فرايسەر جازۋى',
        'Lyci' => 'ليكي جازۋى',
        'Lydi' => 'ليدي جازۋى',
        'Mahj' => 'ماحاجاني جازۋى',
        'Maka' => 'ماكاسار جازۋى',
        'Mand' => 'ماندەي جازۋى',
        'Mani' => 'مانيحەي جازۋى',
        'Marc' => 'مارچەن جازۋى',
        'Medf' => 'مەدەفايدرين جازۋى',
        'Mend' => 'مەندە جازۋى',
        'Merc' => 'مەرويت قيعاش جازۋى',
        'Mero' => 'مەرويت جازۋى',
        'Mlym' => 'مالايالام جازۋى',
        'Modi' => 'مودي جازۋى',
        'Mong' => 'موڭعول جازۋى',
        'Mroo' => 'مرو جازۋى',
        'Mtei' => 'مەيتەي جازۋى',
        'Mult' => 'مۋلتاني جازۋى',
        'Mymr' => 'ميانما جازۋى',
        'Nagm' => 'ناگ مۋنداري جازۋى',
        'Nand' => 'نانديناگاري جازۋى',
        'Narb' => 'كونە سولتۇستىك اراب جازۋى',
        'Nbat' => 'ناباتەي جازۋى',
        'Newa' => 'نيۋا جازۋى',
        'Nkoo' => 'نكو جازۋى',
        'Nshu' => 'نيۋ-شۋ جازۋى',
        'Ogam' => 'وگام جازۋى',
        'Olck' => 'ول-چيكي جازۋى',
        'Onao' => 'ول-ونال جازۋى',
        'Orkh' => 'كونە تۇركى جازۋى',
        'Orya' => 'وريا جازۋى',
        'Osge' => 'وسەيج جازۋى',
        'Osma' => 'يسمانيا جازۋى',
        'Ougr' => 'كونە ۇيعىر جازۋى',
        'Palm' => 'پالمير جازۋى',
        'Pauc' => 'پاۋ سين حاۋ جازۋى',
        'Perm' => 'كونە پەرم جازۋى',
        'Phag' => 'تيبەر-موڭعول جازۋى',
        'Phli' => 'جازبا پاحلاۆي',
        'Phlp' => 'پاحلاۆي جازۋى',
        'Phnx' => 'فينيكيا جازۋى',
        'Plrd' => 'پوللارد فونەتيكالىق جازۋى',
        'Prti' => 'جازبا پارفيا',
        'Qaag' => 'زوجي جازۋى',
        'Rjng' => 'رەجاڭ جازۋى',
        'Rohg' => 'حانيفي جازۋى',
        'Runr' => 'رۋنا',
        'Samr' => 'ساماريا جازۋى',
        'Sarb' => 'وڭتۇستىك اراب جازۋى',
        'Saur' => 'ساۋراشترا جازۋى',
        'Sgnw' => 'جازۋ',
        'Shaw' => 'شوۋ جازۋى',
        'Shrd' => 'شارادا جازۋى',
        'Sidd' => 'سيدحام جازۋى',
        'Sidt' => 'سيدەت جازۋى',
        'Sind' => 'كحۋداۋادي جازۋى',
        'Sinh' => 'سينگال جازۋى',
        'Sogd' => 'سوعدى جازۋى',
        'Sogo' => 'كونە سوعدى جازۋى',
        'Sora' => 'سورا سومپەڭ جازۋى',
        'Soyo' => 'سويومبو جازۋى',
        'Sund' => 'سۋند جازۋى',
        'Sunu' => 'سۋنۋار جازۋى',
        'Sylo' => 'سيلحەت ناگاري جازۋى',
        'Syrc' => 'سيريا جازۋى',
        'Syre' => 'ەسترانگەلو سيري جازۋى',
        'Syrj' => 'باتىس سيري جازۋى',
        'Syrn' => 'شىعىس سيري جازۋى',
        'Tagb' => 'تاگبانۋا جازۋى',
        'Takr' => 'تاكري جازۋى',
        'Tale' => 'تاي لى جازۋى',
        'Talu' => 'جاڭا تاي لى جازۋى',
        'Taml' => 'تاميل جازۋى',
        'Tang' => 'تانعۇت جازۋى',
        'Tavt' => 'تاي ۆيەت جازۋى',
        'Tayo' => 'لاي تاي جازۋى',
        'Telu' => 'تەلۋگۋ جازۋى',
        'Tfng' => 'تيفيناگ جازۋى',
        'Tglg' => 'بايبايىن جازۋى',
        'Thaa' => 'تانا جازۋى',
        'Thai' => 'تاي جازۋى',
        'Tibt' => 'تيبەت جازۋى',
        'Tirh' => 'تيرحۋتا جازۋى',
        'Tnsa' => 'تاڭسا جازۋى',
        'Todr' => 'تودحري جازۋى',
        'Tols' => 'تولوڭ سيكي جازۋى',
        'Toto' => 'توتو جازۋى',
        'Tutg' => 'تۋلۋ-تيگالاري جازۋى',
        'Ugar' => 'ۋگاريت جازۋى',
        'Vaii' => 'ۆاي جازۋى',
        'Vith' => 'ۆيتكۋتي جازۋى',
        'Wara' => 'ۆاراڭ كشيتي جازۋى',
        'Wcho' => 'ۋانچو جازۋى',
        'Xpeo' => 'كونە پارسى جازۋو',
        'Xsux' => 'شۋمەر-اككاد سىنا جازۋى',
        'Yezi' => 'ەزيد جازۋى',
        'Yiii' => 'ي جازۋى',
        'Zanb' => 'زانابازار شارشى جازۋى',
        'Zinh' => 'مۇرا ەتىلگەن',
        'Zmth' => 'ماتەماتيكالىق جازۋ',
        'Zsye' => 'ەموجي',
        'Zsym' => 'تاڭبالار',
        'Zxxx' => 'جازۋسىز',
        'Zyyy' => 'جالپى',
    ],
];
