<?php

return [
    '🐕‍🦺' => 'asǝŋkaŋakanama',
    '🐈‍⬛' => 'ganyaʊ gaɖono',
    '🐻‍❄' => 'ursifɔnɔ',
    '🐦‍⬛' => 'gasapɩ́ gaɖono',
    '🐦‍🔥' => 'gasapɩ́ fenis',
    '🦵' => 'ʊkei',
    '👂' => 'gʊtɔ',
    '👃' => 'gɩŋʊnʊ',
    '🧠' => 'gʊfaŋa',
    '🫀' => 'gɩfolu',
    '🫁' => 'akufɛrɛfɛrɛ',
    '🦷' => 'gʊnyoo',
    '🦴' => 'ŋkǝwa',
    '👀' => 'ɩnyine',
    '👁' => 'gɩnyine',
    '👅' => 'gɩɖanʊ',
    '👄' => 'ganɔ',
    '🐵' => 'akʊná agayɛ',
    '🐒' => 'akʊná',
    '🦍' => 'goril',
    '🦧' => 'ʊrantan',
    '🐶' => 'asna agayɛ',
    '🐕' => 'asna',
    '🦮' => 'asǝntoŋokafɔnɔrɛ',
    '🐩' => 'asna ɩsana pùùù',
    '🐺' => 'Asnaŋɔnja abʊmbɔnɔ',
    '🦊' => 'asnaŋɔnja ajala',
    '🦝' => 'ursijalɩ',
    '🐱' => 'ganyaʊ kaayɛ',
    '🐈' => 'ganyaʊ',
    '🦁' => 'guuni agayɛ',
    '🐯' => 'atabɩyarɩ ɩsǝnayar agayɛ',
    '🐅' => 'atabɩyarɩ ɩsǝnayar',
    '🐆' => 'atabɩyarɩ',
    '🐴' => 'asuko agayɛ',
    '🫎' => 'ayʊlʊkpatɩ',
    '🫏' => 'gakɔŋkɔŋɔ́',
    '🐎' => 'asuko',
    '🦄' => 'asuko gʊyʊlʊyar',
    '🦓' => 'gakɔŋkɔŋɔ́ ɩsǝnayar',
    '🦌' => 'gajagʊyʊlʊ',
    '🦬' => 'bisɔn',
    '🐮' => 'nnanarɩ kaayɛ',
    '🐂' => 'nnakoro',
    '🐃' => 'ʊkó',
    '🐄' => 'nnanarɩ',
    '🐷' => 'ʊkuruci agayɛ',
    '🐖' => 'ʊkuruci',
    '🐗' => 'ʊkuruci aŋɔnja',
    '🐽' => 'ʊkuruci agɩŋʊnʊ',
    '🐏' => 'nraŋkoro',
    '🐑' => 'arama',
    '🐐' => 'ʊce',
    '🐪' => 'Raakum',
    '🐫' => 'Raakum ɩjɩmaajɩmaayar',
    '🦙' => 'lamaa',
    '🦒' => 'abɔrɩ ʊɖɔlamakayar',
    '🐘' => 'abʊrʊ',
    '🦣' => 'mamuuf',
    '🦏' => 'abʊrʊ gɩŋʊnʊyʊlʊyar',
    '🦛' => 'atubʊrʊ',
    '🐭' => 'ʊfulǝ agayɛ',
    '🐁' => 'ʊfulǝ',
    '🐀' => 'ʊshiresʊra',
    '🐹' => 'ʊfulǝɖǝuka',
    '🐰' => 'garomo kaayɛ',
    '🐇' => 'Garomo',
    '🐿' => 'gakɔmbɩlɩ',
    '🦔' => 'gasǝnɩshɩnʊ',
    '🦇' => 'gʊjǝmasʊra',
    '🐻' => 'ursi',
    '🐨' => 'ursi koalaa',
    '🐼' => 'ursi panɖaa',
    '🦥' => 'gafunfambɔrɩ',
    '🦦' => 'lutǝr',
    '🦨' => 'mufɛɛtɩ',
    '🦘' => 'abɔrɩ ncǝnfǝlǝyar',
    '🦡' => 'bɩlɛroo',
    '🐾' => 'ɩbɔrɩ banaŋa',
    '🦃' => 'tolotolo',
    '🐔' => 'ncɩrɩnarɩ',
    '🐓' => 'acɩrɩsoro',
    '🐣' => 'gacɩrɩpiri gapika',
    '🐤' => 'gacɩrɩpiri',
    '🐥' => 'gacɩrɩpiri kaayɛ',
    '🐦' => 'gasapɩ́',
    '🐧' => 'gaprakǝlisapɩ',
    '🕊' => 'alikuku afɔnɔ',
    '🦅' => 'asáʊ',
    '🦆' => 'kpakpafɩʊ',
    '🦢' => 'kpakpafɩʊ ʊɖɔlamakayar',
    '🦉' => 'nrǝnrǝmǝ',
    '🦤' => 'kpakpafɩʊ ɖoóɖoó',
    '🪶' => 'gɩsanà',
    '🦩' => 'fǝlamiŋgo',
    '🦚' => 'tolotolo bʊcǝma',
    '🦜' => 'akoo',
    '🪽' => 'gʊpra',
    '🪿' => 'kpakpafɩʊ atuja',
    '🐸' => 'gʊromò',
    '🐊' => 'ayɩwa',
    '🐢' => 'abʊŋajakpa',
    '🦎' => 'ʊwǝgǝu',
    '🐍' => 'ʊbu',
    '🐲' => 'nsampǝnnyanawili kaayɛ',
    '🐉' => 'nsampǝnnyanawili',
    '🦕' => 'asampǝmbʊrʊ soropooɖɩ',
    '🦖' => 'gʊyarɩsampǝmbʊrʊ',
];
