<?php

return [
    'Names' => [
        'aa' => 'афар',
        'ab' => 'абхаз',
        'ace' => 'ачин',
        'ada' => 'адангмэ',
        'ady' => 'адигэ',
        'af' => 'африкаанс',
        'agq' => 'агем',
        'ain' => 'айну',
        'ak' => 'акан',
        'ale' => 'алют',
        'alt' => 'өмнөд алтай',
        'am' => 'амхар',
        'an' => 'арагон',
        'ann' => 'оболо',
        'anp' => 'ангик',
        'ar' => 'араб',
        'arn' => 'мапүчи',
        'arp' => 'арапаго',
        'ars' => 'наджи араб',
        'as' => 'ассам',
        'asa' => 'асу',
        'ast' => 'астури',
        'atj' => 'атикамек',
        'av' => 'авар',
        'awa' => 'авадхи',
        'ay' => 'аймара',
        'az' => 'азербайжан',
        'ba' => 'башкир',
        'bal' => 'балучи',
        'ban' => 'бали',
        'bas' => 'басаа',
        'be' => 'беларусь',
        'bem' => 'бемба',
        'bez' => 'бена',
        'bg' => 'болгар',
        'bgc' => 'харьянви',
        'bho' => 'божпури',
        'bi' => 'бислам',
        'bin' => 'бини',
        'bla' => 'сиксика',
        'blo' => 'Ани',
        'bm' => 'бамбара',
        'bn' => 'бенгал',
        'bo' => 'төвд',
        'br' => 'бретон',
        'brx' => 'бодо',
        'bs' => 'босни',
        'bug' => 'буги',
        'byn' => 'блин',
        'ca' => 'каталан',
        'cay' => 'кайюга хэл',
        'ccp' => 'чакма',
        'ce' => 'чечень',
        'ceb' => 'себуано',
        'cgg' => 'чига',
        'ch' => 'чаморро',
        'chk' => 'чуук',
        'chm' => 'мари хэл',
        'cho' => 'чоктау',
        'chp' => 'чипевайан',
        'chr' => 'чероки',
        'chy' => 'чэенн',
        'ckb' => 'төв курд',
        'clc' => 'чилкотин',
        'co' => 'корсик',
        'crg' => 'мичиф',
        'crj' => 'зүүн өмнөд кри',
        'crk' => 'плэйн кри',
        'crl' => 'зүүн хойд кри',
        'crm' => 'мүүс кри',
        'crr' => 'каролина алгонкинск хэл',
        'crs' => 'сеселва креол франц',
        'cs' => 'чех',
        'csw' => 'свампи кри',
        'cu' => 'сүмийн славян',
        'cv' => 'чуваш',
        'cy' => 'уэльс',
        'da' => 'дани',
        'dak' => 'дакота',
        'dar' => 'даргва',
        'dav' => 'тайта',
        'de' => 'герман',
        'dgr' => 'догриб',
        'dje' => 'зарма',
        'doi' => 'догри',
        'dsb' => 'доод сорби',
        'dua' => 'дуала',
        'dv' => 'дивехи',
        'dyo' => 'жола-фони',
        'dz' => 'зонха',
        'dzg' => 'дазага',
        'ebu' => 'эмбу',
        'ee' => 'эвэ',
        'efi' => 'эфик',
        'eka' => 'экажук',
        'el' => 'грек',
        'en' => 'англи',
        'eo' => 'эсперанто',
        'es' => 'испани',
        'et' => 'эстони',
        'eu' => 'баск',
        'ewo' => 'эвондо',
        'fa' => 'перс',
        'ff' => 'фула',
        'fi' => 'фин',
        'fil' => 'филипино',
        'fj' => 'фижи',
        'fo' => 'фарер',
        'fon' => 'фон',
        'fr' => 'франц',
        'frc' => 'франц, кажун',
        'frr' => 'хойд фриз',
        'fur' => 'фриулан',
        'fy' => 'баруун фриз',
        'ga' => 'ирланд',
        'gaa' => 'га',
        'gag' => 'гагуз',
        'gd' => 'шотландын гел',
        'gez' => 'гийз',
        'gil' => 'гилберт',
        'gl' => 'галего',
        'gn' => 'гуарани',
        'gor' => 'горонтало',
        'gsw' => 'швейцари-герман',
        'gu' => 'гужарати',
        'guz' => 'гузы',
        'gv' => 'манкс',
        'gwi' => 'гвичин',
        'ha' => 'хауса',
        'hai' => 'хайда',
        'haw' => 'хавай',
        'hax' => 'өмнөд хайда',
        'he' => 'еврей',
        'hi' => 'хинди',
        'hil' => 'хилигайнон',
        'hmn' => 'хмонг',
        'hr' => 'хорват',
        'hsb' => 'дээд сорби',
        'ht' => 'Гаитийн креол',
        'hu' => 'мажар',
        'hup' => 'хупа',
        'hur' => 'халкомелем',
        'hy' => 'армен',
        'hz' => 'хереро',
        'ia' => 'интерлингво',
        'iba' => 'ибан',
        'ibb' => 'ибибио',
        'id' => 'индонези',
        'ie' => 'нэгдмэл хэл',
        'ig' => 'игбо',
        'ii' => 'сычуань и',
        'ikt' => 'баруун канадын инуктитут',
        'ilo' => 'илоко',
        'inh' => 'ингуш',
        'io' => 'идо',
        'is' => 'исланд',
        'it' => 'итали',
        'iu' => 'инуктитут',
        'ja' => 'япон',
        'jbo' => 'ложбан',
        'jgo' => 'нгомба',
        'jmc' => 'мачамэ',
        'jv' => 'ява',
        'ka' => 'гүрж',
        'kab' => 'кабиле',
        'kac' => 'качин',
        'kaj' => 'жжу',
        'kam' => 'камба',
        'kbd' => 'кабардин',
        'kcg' => 'тяп',
        'kde' => 'маконде',
        'kea' => 'кабүвердиану',
        'kfo' => 'коро',
        'kgp' => 'кайнганг',
        'kha' => 'каси',
        'khq' => 'койра чини',
        'ki' => 'кикуюү',
        'kj' => 'куаньяма',
        'kk' => 'казах',
        'kkj' => 'како',
        'kl' => 'калалисут',
        'kln' => 'каленжин',
        'km' => 'кхмер',
        'kmb' => 'кимбунду',
        'kn' => 'каннада',
        'ko' => 'солонгос',
        'koi' => 'коми-пермяк',
        'kok' => 'конкани',
        'kpe' => 'кпелле',
        'kr' => 'канури',
        'krc' => 'карачай-балкар',
        'krl' => 'карель',
        'kru' => 'курук',
        'ks' => 'кашмир',
        'ksb' => 'шамбал',
        'ksf' => 'бафиа',
        'ksh' => 'кёльш',
        'ku' => 'курд',
        'kum' => 'кумук',
        'kv' => 'коми',
        'kw' => 'корн',
        'kwk' => 'квак вала',
        'kxv' => 'куви',
        'ky' => 'киргиз',
        'la' => 'латин',
        'lad' => 'ладин',
        'lag' => 'ланги',
        'lb' => 'люксембург',
        'lez' => 'лезги',
        'lg' => 'ганда',
        'li' => 'лимбург',
        'lij' => 'лигури',
        'lil' => 'лиллуэт',
        'lkt' => 'лакота',
        'lmo' => 'ломбард',
        'ln' => 'лингала',
        'lo' => 'лаос',
        'lou' => 'луизиана креоле',
        'loz' => 'лози',
        'lrc' => 'хойд лури',
        'lsm' => 'самиа',
        'lt' => 'литва',
        'lu' => 'луба-катанга',
        'lua' => 'луба-лулуа',
        'lun' => 'лунда',
        'luo' => 'луо',
        'lus' => 'мизо',
        'luy' => 'луяа',
        'lv' => 'латви',
        'mad' => 'мадури хэл',
        'mag' => 'магахи',
        'mai' => 'май',
        'mak' => 'макасар',
        'mas' => 'масай',
        'mdf' => 'мокша',
        'men' => 'менде',
        'mer' => 'меру',
        'mfe' => 'морисен',
        'mg' => 'малагаси',
        'mgh' => 'макува-мито',
        'mgo' => 'мета',
        'mh' => 'маршалл',
        'mi' => 'маори',
        'mic' => 'микмак',
        'min' => 'минангкабау',
        'mk' => 'македон',
        'ml' => 'малаялам',
        'mn' => 'монгол',
        'mni' => 'манипури',
        'moe' => 'инну-аймун',
        'moh' => 'мохаук',
        'mos' => 'мосси',
        'mr' => 'марати',
        'ms' => 'малай',
        'mt' => 'малта',
        'mua' => 'мунданг',
        'mus' => 'крик',
        'mwl' => 'меранди',
        'my' => 'бирм',
        'myv' => 'эрзя',
        'mzn' => 'мазандерани',
        'na' => 'науру',
        'nap' => 'неаполитан',
        'naq' => 'нама',
        'nb' => 'норвегийн букмол',
        'nd' => 'хойд ндебеле',
        'nds' => 'доод герман',
        'ne' => 'балба',
        'new' => 'невари',
        'ng' => 'ндонга',
        'nia' => 'ниас хэл',
        'niu' => 'ниуэ',
        'nl' => 'нидерланд',
        'nmg' => 'квазио',
        'nn' => 'норвегийн нинорск',
        'nnh' => 'нгиембүүн',
        'no' => 'норвег',
        'nog' => 'ногаи',
        'nqo' => 'нко',
        'nr' => 'өмнөд ндебеле',
        'nso' => 'хойд сото',
        'nus' => 'нуер',
        'nv' => 'навахо',
        'ny' => 'нянжа',
        'nyn' => 'нянколе',
        'oc' => 'окситан',
        'ojb' => 'баруун хойд ожибва',
        'ojc' => 'төв ожибва',
        'ojs' => 'ожи кри',
        'ojw' => 'баруун ожибва',
        'oka' => 'оканаган',
        'om' => 'оромо',
        'or' => 'ория',
        'os' => 'оссетин',
        'pa' => 'панжаби',
        'pag' => 'пангасин',
        'pam' => 'пампанга',
        'pap' => 'папьяменто',
        'pau' => 'палау',
        'pcm' => 'нигерийн пиджин',
        'pis' => 'пижин',
        'pl' => 'польш',
        'pqm' => 'малесит-пассамакводди',
        'prg' => 'прусс',
        'ps' => 'пушту',
        'pt' => 'португал',
        'qu' => 'кечуа',
        'quc' => 'киче',
        'raj' => 'ражастани',
        'rap' => 'рапануи',
        'rar' => 'раротонг',
        'rhg' => 'рохинжа',
        'rm' => 'романш',
        'rn' => 'рунди',
        'ro' => 'румын',
        'rof' => 'ромбо',
        'ru' => 'орос',
        'rup' => 'ароманы',
        'rw' => 'киньяруанда',
        'rwk' => 'рва',
        'sa' => 'санскрит',
        'sad' => 'сандавэ',
        'sah' => 'саха',
        'saq' => 'самбүрү',
        'sat' => 'сантали',
        'sba' => 'нгамбай',
        'sbp' => 'сангү',
        'sc' => 'сардин',
        'scn' => 'сицил',
        'sco' => 'шотланд',
        'sd' => 'синдхи',
        'se' => 'хойд сами',
        'seh' => 'сена',
        'ses' => 'кёраборо сени',
        'sg' => 'санго',
        'sh' => 'хорватын серб',
        'shi' => 'тачелхит',
        'shn' => 'шань',
        'si' => 'синхала',
        'sk' => 'словак',
        'sl' => 'словени',
        'slh' => 'өмнөд лушуцид',
        'sm' => 'самоа',
        'sma' => 'өмнөд сами',
        'smj' => 'люле сами',
        'smn' => 'инари сами',
        'sms' => 'сколт сами',
        'sn' => 'шона',
        'snk' => 'сонинке',
        'so' => 'сомали',
        'sq' => 'албани',
        'sr' => 'серб',
        'srn' => 'сранан тонго',
        'ss' => 'свати',
        'ssy' => 'сахо',
        'st' => 'сесото',
        'str' => 'стрейтс салиш',
        'su' => 'сундан',
        'suk' => 'сукума',
        'sv' => 'швед',
        'sw' => 'свахили',
        'swb' => 'комори',
        'syr' => 'сири',
        'szl' => 'силез',
        'ta' => 'тамил',
        'tce' => 'өмнөд тутчоне',
        'te' => 'тэлүгү',
        'tem' => 'тимн',
        'teo' => 'тэсо',
        'tet' => 'тетум',
        'tg' => 'тажик',
        'tgx' => 'тагиш',
        'th' => 'тай',
        'tht' => 'талтан',
        'ti' => 'тигринья',
        'tig' => 'тигр',
        'tk' => 'туркмен',
        'tlh' => 'клингон',
        'tli' => 'тлингит',
        'tn' => 'цвана',
        'to' => 'тонга',
        'tok' => 'токипона',
        'tpi' => 'ток писин',
        'tr' => 'турк',
        'trv' => 'тароко',
        'ts' => 'цонга',
        'tt' => 'татар',
        'ttm' => 'хойд тутчоне',
        'tum' => 'тумбула',
        'tvl' => 'тувалу',
        'tw' => 'тви',
        'twq' => 'тасавак',
        'ty' => 'таити',
        'tyv' => 'тува',
        'tzm' => 'Төв Атласын тамазигхт',
        'udm' => 'удмурт',
        'ug' => 'уйгур',
        'uk' => 'украин',
        'umb' => 'умбунду',
        'ur' => 'урду',
        'uz' => 'узбек',
        'vai' => 'вай',
        've' => 'венда',
        'vec' => 'венец',
        'vi' => 'вьетнам',
        'vmw' => 'макуа',
        'vo' => 'волапюк',
        'vun' => 'вунжо',
        'wa' => 'уоллун',
        'wae' => 'уолсэр',
        'wal' => 'уоллайтта',
        'war' => 'варай',
        'wo' => 'волоф',
        'wuu' => 'хятад, ву хэл',
        'xal' => 'халимаг',
        'xh' => 'хоса',
        'xnr' => 'кангри',
        'xog' => 'сога',
        'yav' => 'янгбен',
        'ybb' => 'емба',
        'yi' => 'иддиш',
        'yo' => 'ёруба',
        'yrl' => 'ньенгату',
        'yue' => 'кантон',
        'za' => 'чжуанг',
        'zgh' => 'стандарт тамазайт (Морокко)',
        'zh' => 'хятад',
        'zu' => 'зулу',
        'zun' => 'зуни',
        'zza' => 'заза',
    ],
    'LocalizedNames' => [
        'ar_001' => 'стандарт араб',
        'en_AU' => 'австрали-англи',
        'en_CA' => 'канад-англи',
        'en_GB' => 'британи-англи',
        'en_US' => 'америк-англи',
        'es_419' => 'испани хэл (Латин Америк)',
        'es_ES' => 'испани хэл (Европ)',
        'es_MX' => 'испани хэл (Мексик)',
        'nl_BE' => 'фламанд',
        'pt_BR' => 'португал хэл (Бразил)',
        'pt_PT' => 'португал хэл (Европ)',
        'ro_MD' => 'молдав',
        'sw_CD' => 'конгогийн свахили',
        'zh_Hans' => 'хялбаршуулсан хятад',
        'zh_Hant' => 'уламжлалт хятад',
    ],
];
