<?php

return [
    'Names' => [
        'Arab' => 'Arabiffa',
        'Cyrl' => 'Saayiriilik',
        'Hans' => 'Salphifame',
        'Hant' => 'Kan Durii',
        'Jpan' => 'Afaan Jaappaan',
        'Kore' => 'Afaan Kooriyaa',
        'Latn' => 'Laatinii',
        'Zxxx' => 'Kan Hin Barreeffamne',
    ],
];
