<?php

declare(strict_types=1);

namespace SimpleSAML\XMLSecurity\Alg\KeyTransport;

use SimpleSAML\XMLSecurity\Alg\Encryption\EncryptionAlgorithmInterface;

/**
 * An interface representing algorithms that can be used for key transport.
 *
 * @package simplesamlphp/xml-security
 */
interface KeyTransportAlgorithmInterface extends EncryptionAlgorithmInterface
{
}
