<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'ئاندورران پېسېتاسى',
        ],
        'AED' => [
            'AED',
            'ئەرەب بىرلەشمە خەلىپىلىكى دەرھەمى',
        ],
        'AFA' => [
            'AFA',
            'ئافغان ئافغانى (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'ئافغان ئافغانى',
        ],
        'ALK' => [
            'ALK',
            'ئالبانىيە لېكى (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'ئالبانىيە لېكى',
        ],
        'AMD' => [
            'AMD',
            'ئەرمېنىيە دىرامى',
        ],
        'ANG' => [
            'ANG',
            'گوللاندىيەگە قاراشلىق ئانتىللېن گۇلدېنى',
        ],
        'AOA' => [
            'AOA',
            'ئانگولا كۇۋانزاسى',
        ],
        'AOK' => [
            'AOK',
            'ئانگولا كۇۋانزاسى (1977–1991)',
        ],
        'AON' => [
            'AON',
            'ئانگولا يېڭى كۇۋانزاسى (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'ئانگولا قايتا تەڭشەلگەن كۇۋانزاسى (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'ئارگېنتىنا ئاۋسترالى',
        ],
        'ARL' => [
            'ARL',
            'ئارگېنتىنا پېسو لېيى (1970–1983)',
        ],
        'ARM' => [
            'ARM',
            'ئارگېنتىنا پېسوسى (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'ئارگېنتىنا پېسوسى (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'ئارگېنتىنا پېسوسى',
        ],
        'ATS' => [
            'ATS',
            'ئاۋسترىيە شىللىڭى',
        ],
        'AUD' => [
            'A$',
            'ئاۋسترالىيە دوللىرى',
        ],
        'AWG' => [
            'AWG',
            'ئارۇبان فىلورۇنى',
        ],
        'AZM' => [
            'AZM',
            'ئەزەربەيجان ماناتى (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'ئەزەربەيجان ماناتى',
        ],
        'BAD' => [
            'BAD',
            'بوسنىيە-خېرتسېگوۋىنا دىنارى (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'بوسنىيە-خېرتسېگوۋىنا ئالماشتۇرۇشچان ماركى',
        ],
        'BAN' => [
            'BAN',
            'بوسنىيە-خېرتسېگوۋىنا يېڭى دىنارى (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'باربادوس دوللىرى',
        ],
        'BDT' => [
            'BDT',
            'باڭلادىش تاكاسى',
        ],
        'BEC' => [
            'BEC',
            'بېلگىيە فرانكى (ئالماشتۇرۇشچان)',
        ],
        'BEF' => [
            'BEF',
            'بېلگىيە فرانكى',
        ],
        'BEL' => [
            'BEL',
            'بېلگىيە فرانكى (پۇل–مۇئامىلە)',
        ],
        'BGL' => [
            'BGL',
            'بۇلغارىيە قاتتىق لېۋاسى',
        ],
        'BGM' => [
            'BGM',
            'بۇلغارىيە ئىجتىمائىي لېۋاسى',
        ],
        'BGN' => [
            'BGN',
            'بۇلغارىيە لېۋاسى',
        ],
        'BGO' => [
            'BGO',
            'بۇلغارىيە لېۋاسى (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'بەھرەين دىنارى',
        ],
        'BIF' => [
            'BIF',
            'بۇرۇندى فرانكى',
        ],
        'BMD' => [
            'BMD',
            'بېرمۇدا دوللىرى',
        ],
        'BND' => [
            'BND',
            'بىرۇنېي دوللىرى',
        ],
        'BOB' => [
            'BOB',
            'بولىۋىيە بولىۋىيانوسى',
        ],
        'BOL' => [
            'BOL',
            'بولىۋىيە بولىۋىيانوسى (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'بولىۋىيە پىسوسى',
        ],
        'BOV' => [
            'BOV',
            'بولىۋىيە مۇدولى',
        ],
        'BRB' => [
            'BRB',
            'بىرازىلىيە يېڭى كرۇزېروسى (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'بىرازىلىيە كرۇزادوسى (1986–1989)',
        ],
        'BRE' => [
            'BRE',
            'بىرازىلىيە يېڭى كرۇزېروسى (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'بىرازىلىيە رىيالى',
        ],
        'BRN' => [
            'BRN',
            'بىرازىلىيە يېڭى كرۇزادوسى (1989–1990)',
        ],
        'BRR' => [
            'BRR',
            'بىرازىلىيە كرۇزېروسى (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'بىرازىلىيە كرۇزېروسى (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'باھاما دوللىرى',
        ],
        'BTN' => [
            'BTN',
            'بۇتان نگۇلترۇمى',
        ],
        'BUK' => [
            'BUK',
            'بىرما كىياتى',
        ],
        'BWP' => [
            'BWP',
            'بوتسۋانا پۇلاسى',
        ],
        'BYB' => [
            'BYB',
            'بېلارۇسىيە يېڭى رۇبلىسى (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'بېلارۇسىيە رۇبلىسى',
        ],
        'BYR' => [
            'BYR',
            'بېلارۇسىيە رۇبلىسى (۲۰۰۰–۲۰۱۶)',
        ],
        'BZD' => [
            'BZD',
            'بېلىز دوللىرى',
        ],
        'CAD' => [
            'CA$',
            'كانادا دوللىرى',
        ],
        'CDF' => [
            'CDF',
            'كونگو فرانكى',
        ],
        'CHE' => [
            'CHE',
            'WIR ياۋرو',
        ],
        'CHF' => [
            'CHF',
            'شىۋېتسىيە فرانكى',
        ],
        'CHW' => [
            'CHW',
            'WIR فرانكى',
        ],
        'CLE' => [
            'CLE',
            'چىلى ئېسكۇدوسى',
        ],
        'CLF' => [
            'CLF',
            'چىلى ھېسابات بىرلىكى (UF)',
        ],
        'CLP' => [
            'CLP',
            'چىلى پېسوسى',
        ],
        'CNX' => [
            'CNX',
            'جۇڭگو خەلق بانكىسى دوللىرى',
        ],
        'CNY' => [
            '￥',
            'جۇڭگو يۈەنى',
        ],
        'COP' => [
            'COP',
            'كولومبىيە پېسوسى',
        ],
        'COU' => [
            'COU',
            'كولومبىيە ھەقىقىي قىممەت بىرلىكى',
        ],
        'CRC' => [
            'CRC',
            'كوستارىكا كولونى',
        ],
        'CSD' => [
            'CSD',
            'سېربىيە دىنارى (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'چېخسىلوۋاكىيە قاتتىق كورۇناسى',
        ],
        'CUC' => [
            'CUC',
            'كۇبا ئالماشتۇرۇشچان پېسوسى',
        ],
        'CUP' => [
            'CUP',
            'كۇبا پېسوسى',
        ],
        'CVE' => [
            'CVE',
            'يېشىل تۇمشۇق ئېسكۇدوسى',
        ],
        'CYP' => [
            'CYP',
            'سىپرۇس فوند ستېرلىڭى',
        ],
        'CZK' => [
            'CZK',
            'چېخ جۇمھۇرىيىتى كورۇناسى',
        ],
        'DDM' => [
            'DDM',
            'شەرقىي گېرمانىيە ماركى',
        ],
        'DEM' => [
            'DEM',
            'گېرمانىيە ماركى',
        ],
        'DJF' => [
            'DJF',
            'جىبۇتى فرانكى',
        ],
        'DKK' => [
            'DKK',
            'دانىيە كرونى',
        ],
        'DOP' => [
            'DOP',
            'دومىنىكا پېسوسى',
        ],
        'DZD' => [
            'DZD',
            'ئالجىرىيە دىنارى',
        ],
        'ECS' => [
            'ECS',
            'ئېكۋادور سۇكرېسى',
        ],
        'ECV' => [
            'ECV',
            'ئېكۋادور تۇراقلىق قىممەت بىرلىكى',
        ],
        'EEK' => [
            'EEK',
            'ئېستونىيە كرۇنى',
        ],
        'EGP' => [
            'EGP',
            'مىسىر فوند سىتېرلىڭى',
        ],
        'ERN' => [
            'ERN',
            'ئېرىترېيە ناكفاسى',
        ],
        'ESA' => [
            'ESA',
            'ئىسپانىيە پېسېتاسى (A ھېسابات)',
        ],
        'ESB' => [
            'ESB',
            'ئىسپانىيە پېسېتاسى (ئالماشتۇرۇش ھېساباتى)',
        ],
        'ESP' => [
            'ESP',
            'ئىسپانىيە پېسېتاسى',
        ],
        'ETB' => [
            'ETB',
            'ئېفىيوپىيە بىررى',
        ],
        'EUR' => [
            '€',
            'ياۋرو',
        ],
        'FIM' => [
            'FIM',
            'فىنلاندىيە مارككاسى',
        ],
        'FJD' => [
            'FJD',
            'فىجى دوللىرى',
        ],
        'FKP' => [
            'FKP',
            'فالكلاند ئاراللىرى فوند سىتېرلىڭى',
        ],
        'FRF' => [
            'FRF',
            'فىرانسىيە فرانكى',
        ],
        'GBP' => [
            '£',
            'ئەنگلىيە فوند سىتېرلىڭى',
        ],
        'GEK' => [
            'GEK',
            'گىرۇزىيە كۇپون لارىتى',
        ],
        'GEL' => [
            'GEL',
            'گىرۇزىيە لارىسى',
        ],
        'GHC' => [
            'GHC',
            'گانا سېدىسى (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'گانا سېدىسى',
        ],
        'GIP' => [
            'GIP',
            'جەبىلتارىق فوند سىتېرلىڭى',
        ],
        'GMD' => [
            'GMD',
            'گامبىيە دالاسى',
        ],
        'GNF' => [
            'GNF',
            'گىۋىنېيە فرانكى',
        ],
        'GNS' => [
            'GNS',
            'گىۋىنېيە سىلىسى',
        ],
        'GQE' => [
            'GQE',
            'ئېكۋاتور گىۋىنېيە ئېكۋېلېسى',
        ],
        'GRD' => [
            'GRD',
            'گىرېتسىيە دراخماسى',
        ],
        'GTQ' => [
            'GTQ',
            'گىۋاتېمالا كۇۋېتزالى',
        ],
        'GWE' => [
            'GWE',
            'پورتۇگالىيە گىۋىنېيە ئېسكۇدوسى',
        ],
        'GWP' => [
            'GWP',
            'گىۋىنېيە-بىسسائۇ پېسوسى',
        ],
        'GYD' => [
            'GYD',
            'گىۋىئانا دوللىرى',
        ],
        'HKD' => [
            'HK$',
            'شياڭگاڭ دوللىرى',
        ],
        'HNL' => [
            'HNL',
            'ھوندۇراس لېمپىراسى',
        ],
        'HRD' => [
            'HRD',
            'كىرودىيە دىنارى',
        ],
        'HRK' => [
            'HRK',
            'كىرودىيە كۇناسى',
        ],
        'HTG' => [
            'HTG',
            'ھايتى گۇردېسى',
        ],
        'HUF' => [
            'HUF',
            'ۋېنگىرىيە فورېنتى',
        ],
        'IDR' => [
            'IDR',
            'ھىندونېزىيە رۇپىيەسى',
        ],
        'IEP' => [
            'IEP',
            'ئىرېلاندىيە فوندستېرلىڭى',
        ],
        'ILP' => [
            'ILP',
            'ئىسرائىلىيە فوندستېرلىڭى',
        ],
        'ILR' => [
            'ILR',
            'ئىسرائىل شېكېلى (1980–1985)',
        ],
        'ILS' => [
            '₪',
            'ئىسرائىل يېڭى شېكېلى',
        ],
        'INR' => [
            '₹',
            'ھىندىستان رۇپىسى',
        ],
        'IQD' => [
            'IQD',
            'ئىراق دىنارى',
        ],
        'IRR' => [
            'IRR',
            'ئىران رىيالى',
        ],
        'ISJ' => [
            'ISJ',
            'ئىسلاندىيە كروناسى (1918–1981)',
        ],
        'ISK' => [
            'ISK',
            'ئىسلاندىيە كروناسى',
        ],
        'ITL' => [
            'ITL',
            'ئىتالىيە لىراسى',
        ],
        'JMD' => [
            'JMD',
            'يامايكا دوللىرى',
        ],
        'JOD' => [
            'JOD',
            'ئىيوردانىيە دىنارى',
        ],
        'JPY' => [
            'JP¥',
            'ياپونىيە يېنى',
        ],
        'KES' => [
            'KES',
            'كېنىيە شىللىڭى',
        ],
        'KGS' => [
            'KGS',
            'قىرغىزىستان سومى',
        ],
        'KHR' => [
            'KHR',
            'كامبودژا رىئېلى',
        ],
        'KMF' => [
            'KMF',
            'كومورو فرانكى',
        ],
        'KPW' => [
            'KPW',
            'شىمالىي كورېيە ۋونى',
        ],
        'KRH' => [
            'KRH',
            'جەنۇبىي كورېيە خۋانى (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'جەنۇبىي كورېيە ۋونى (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'جەنۇبىي كورېيە ۋونى',
        ],
        'KWD' => [
            'KWD',
            'كۇۋەيت دىنارى',
        ],
        'KYD' => [
            'KYD',
            'كايمان ئاراللىرى دوللىرى',
        ],
        'KZT' => [
            'KZT',
            'قازاقىستان تەڭگىسى',
        ],
        'LAK' => [
            'LAK',
            'لائوس كىپى',
        ],
        'LBP' => [
            'LBP',
            'لىۋان فوند سىتېرلىڭى',
        ],
        'LKR' => [
            'LKR',
            'سىرىلانكا رۇپىسى',
        ],
        'LRD' => [
            'LRD',
            'لىبېرىيە دوللىرى',
        ],
        'LSL' => [
            'LSL',
            'لېسوتو لوتىسى',
        ],
        'LTL' => [
            'LTL',
            'لىتۋا لىتاسى',
        ],
        'LTT' => [
            'LTT',
            'لىتۋا تالوناسى',
        ],
        'LUC' => [
            'LUC',
            'ليۇكسېمبۇرگ ئالماشتۇرۇشچان پېسوسى',
        ],
        'LUF' => [
            'LUF',
            'ليۇكسېمبۇرگ فرانكى',
        ],
        'LUL' => [
            'LUL',
            'لىيۇكسېمبۇرگ پۇل-مۇئامىلە فرانكى',
        ],
        'LVL' => [
            'LVL',
            'لاتۋىيە لاتى',
        ],
        'LVR' => [
            'LVR',
            'لاتۋىيە رۇبلىسى',
        ],
        'LYD' => [
            'LYD',
            'لىۋىيە دىنارى',
        ],
        'MAD' => [
            'MAD',
            'ماراكەش دىرھەمى',
        ],
        'MAF' => [
            'MAF',
            'ماراكەش فرانكى',
        ],
        'MCF' => [
            'MCF',
            'موناكو فرانكى',
        ],
        'MDC' => [
            'MDC',
            'مولدوۋا كۇپونى',
        ],
        'MDL' => [
            'MDL',
            'مولدوۋا لېۋى',
        ],
        'MGA' => [
            'MGA',
            'ماداغاسقار ئارىئارىسى',
        ],
        'MGF' => [
            'MGF',
            'ماداغاسقار فرانكى',
        ],
        'MKD' => [
            'MKD',
            'ماكېدونىيە دىنارى',
        ],
        'MKN' => [
            'MKN',
            'ماكېدونىيە دىنارى (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'مالى فرانكى',
        ],
        'MMK' => [
            'MMK',
            'مىيانمار كىياتى',
        ],
        'MNT' => [
            'MNT',
            'موڭغۇلىيە تۈگرىكى',
        ],
        'MOP' => [
            'MOP',
            'ئاۋمېن پاتاكاسى',
        ],
        'MRO' => [
            'MRO',
            'ماۋرىتانىيە ئۇگىيەسى (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'ماۋرىتانىيە ئۇگىيەسى',
        ],
        'MTL' => [
            'MTL',
            'مالتا لىراسى',
        ],
        'MTP' => [
            'MTP',
            'مالتا فوندستېرلىڭى',
        ],
        'MUR' => [
            'MUR',
            'ماۋرىتىئۇس رۇپىسى',
        ],
        'MVP' => [
            'MVP',
            'مالدىۋى رۇپىسى',
        ],
        'MVR' => [
            'MVR',
            'مالدىۋى رۇفىياسى',
        ],
        'MWK' => [
            'MWK',
            'مالاۋى كۋاچاسى',
        ],
        'MXN' => [
            'MX$',
            'مېكسىكا پېسوسى',
        ],
        'MXP' => [
            'MXP',
            'مېكسىكا كۈمۈش پېسوسى (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'مېكسىكا مەبلەغ بىرلىكى',
        ],
        'MYR' => [
            'MYR',
            'مالايشىيا رىڭگىتى',
        ],
        'MZE' => [
            'MZE',
            'موزامبىك ئېسكۇدوسى',
        ],
        'MZM' => [
            'MZM',
            'موزامبىك مېتىكالى (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'موزامبىك مېتىكالى',
        ],
        'NAD' => [
            'NAD',
            'نامىبىيە دوللىرى',
        ],
        'NGN' => [
            'NGN',
            'نىگېرىيە نايراسى',
        ],
        'NIC' => [
            'NIC',
            'نىگېرىيە كوردوباسى (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'نىگېرىيە كوردوباسى',
        ],
        'NLG' => [
            'NLG',
            'گوللاندىيە گۈلدىنى',
        ],
        'NOK' => [
            'NOK',
            'نورۋېگىيە كرونى',
        ],
        'NPR' => [
            'NPR',
            'نېپال رۇپىسى',
        ],
        'NZD' => [
            'NZ$',
            'يېڭى زېلاندىيە دوللىرى',
        ],
        'OMR' => [
            'OMR',
            'ئومان رىيالى',
        ],
        'PAB' => [
            'PAB',
            'پاناما بالبوئاسى',
        ],
        'PEI' => [
            'PEI',
            'پېرۇ ئىنتىسى',
        ],
        'PEN' => [
            'PEN',
            'پېرۇ سولى',
        ],
        'PES' => [
            'PES',
            'پېرۇ سولى (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'پاپۇئا يېڭى گىۋىنېيە كىناسى',
        ],
        'PHP' => [
            '₱',
            'فىلىپپىن پېسوسى',
        ],
        'PKR' => [
            'PKR',
            'پاكىستان رۇپىسى',
        ],
        'PLN' => [
            'PLN',
            'پولشا زىلوتى',
        ],
        'PLZ' => [
            'PLZ',
            'پولشا زىلوتى (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'پورتۇگالىيە ئېسكۇدوسى',
        ],
        'PYG' => [
            'PYG',
            'پاراگۋاي گۇئارانىسى',
        ],
        'QAR' => [
            'QAR',
            'قاتار رىيالى',
        ],
        'RHD' => [
            'RHD',
            'رودېزىيە دوللىرى',
        ],
        'ROL' => [
            'ROL',
            'رۇمىنىيە لېيى (1952–2006)',
        ],
        'RON' => [
            'RON',
            'رۇمىنىيە لېيى',
        ],
        'RSD' => [
            'RSD',
            'سېربىيە دىنارى',
        ],
        'RUB' => [
            'RUB',
            'رۇسىيە رۇبلىسى',
        ],
        'RUR' => [
            'RUR',
            'رۇسىيە رۇبلىسى (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'رۋاندا فرانكى',
        ],
        'SAR' => [
            'SAR',
            'سەئۇدى رىيالى',
        ],
        'SBD' => [
            'SBD',
            'سولومون ئاراللىرى دوللىرى',
        ],
        'SCR' => [
            'SCR',
            'سېيشېل رۇپىسى',
        ],
        'SDD' => [
            'SDD',
            'سۇدان دىنارى (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'سۇدان فوندستېرلىڭى',
        ],
        'SDP' => [
            'SDP',
            'سۇدان فوندستېرلىڭى (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'شىۋېتسىيە كروناسى',
        ],
        'SGD' => [
            'SGD',
            'سىنگاپور دوللىرى',
        ],
        'SHP' => [
            'SHP',
            'ساينىت-ھېلېنا فوندستېرلىڭى',
        ],
        'SIT' => [
            'SIT',
            'سىلوۋېنىيە تولارى',
        ],
        'SKK' => [
            'SKK',
            'سىلوۋاكىيە كورۇناسى',
        ],
        'SLE' => [
            'SLE',
            'سېررالېئون لېئونېسى',
        ],
        'SLL' => [
            'SLL',
            'سېررالېئون لېئونېسى - 1964-2022',
        ],
        'SOS' => [
            'SOS',
            'سومالى شىللىڭى',
        ],
        'SRD' => [
            'SRD',
            'سۇرىنام دوللىرى',
        ],
        'SRG' => [
            'SRG',
            'سۇرىنام گۈلدىنى',
        ],
        'SSP' => [
            'SSP',
            'جەنۇبىي سۇدان فوندستېرلىڭى',
        ],
        'STD' => [
            'STD',
            'سان-تومې ۋە پىرىنسىپى دوبراسى (1977–2017)',
        ],
        'STN' => [
            'STN',
            'سان-تومې ۋە پىرىنسىپى دوبراسى',
        ],
        'SUR' => [
            'SUR',
            'سوۋىت رۇبلىسى',
        ],
        'SVC' => [
            'SVC',
            'سالۋادور كولونى',
        ],
        'SYP' => [
            'SYP',
            'سۈرىيە فوندستېرلىڭى',
        ],
        'SZL' => [
            'SZL',
            'سىۋېزىلاند لىلانگېنى',
        ],
        'THB' => [
            'THB',
            'تايلاند باختى',
        ],
        'TJR' => [
            'TJR',
            'تاجىكىستان رۇبلىسى',
        ],
        'TJS' => [
            'TJS',
            'تاجىكىستان سومونىسى',
        ],
        'TMM' => [
            'TMM',
            'تۈركمەنىستان ماناتى (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'تۈركمەنىستان ماناتى',
        ],
        'TND' => [
            'TND',
            'تۇنىس دىنارى',
        ],
        'TOP' => [
            'TOP',
            'تونگا پائانگاسى',
        ],
        'TPE' => [
            'TPE',
            'تىمور ئېسكۇدوسى',
        ],
        'TRL' => [
            'TRL',
            'تۈركىيە لىراسى (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'تۈركىيە لىراسى',
        ],
        'TTD' => [
            'TTD',
            'تىرىنىداد ۋە توباگو دوللىرى',
        ],
        'TWD' => [
            'NT$',
            'يېڭى تەيۋەن دوللىرى',
        ],
        'TZS' => [
            'TZS',
            'تانزانىيە شىللىڭى',
        ],
        'UAH' => [
            'UAH',
            'ئۇكرائىنا خرىۋناسى',
        ],
        'UAK' => [
            'UAK',
            'ئۇكرائىنا كاربوۋانېتسى',
        ],
        'UGS' => [
            'UGS',
            'ئۇگاندا شىللىڭى (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'ئۇگاندا شىللىڭى',
        ],
        'USD' => [
            '$',
            'ئامېرىكا دوللىرى',
        ],
        'USN' => [
            'USN',
            'ئامېرىكا دوللىرى (كېيىنكى كۈن)',
        ],
        'USS' => [
            'USS',
            'ئامېرىكا دوللىرى (ئوخشاش كۈن)',
        ],
        'UYI' => [
            'UYI',
            'ئۇرۇگۋاي پېسوسى (ئىندېكىسلاش بىرلىكى)',
        ],
        'UYP' => [
            'UYP',
            'ئۇرۇگۋاي پېسوسى (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'ئۇرۇگۋاي پېسوسى',
        ],
        'UZS' => [
            'UZS',
            'ئۆزبېكىستان سومى',
        ],
        'VEB' => [
            'VEB',
            'ۋېنېزۇئېلا بولىۋارى (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'ۋېنېزۇئېلا بولىۋارى (2008–2018)',
        ],
        'VES' => [
            'VES',
            'ۋېنېزۇئېلا بولىۋارى',
        ],
        'VND' => [
            '₫',
            'ۋىيېتنام دوڭى',
        ],
        'VNN' => [
            'VNN',
            'ۋىيېتنام دوڭى (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'ۋانۇئاتۇ ۋاتۇسى',
        ],
        'WST' => [
            'WST',
            'ساموئا تالاسى',
        ],
        'XAF' => [
            'FCFA',
            'ئافرىقا قىتئەسى پۇل-مۇئامىلە ئىتتىپاقى فرانكى',
        ],
        'XCD' => [
            'EC$',
            'شەرقىي كارىب دوللىرى',
        ],
        'XEU' => [
            'XEU',
            'ياۋروپا پۇل بىرلىكى',
        ],
        'XFO' => [
            'XFO',
            'فىرانسىيە ئالتۇن فرانكى',
        ],
        'XFU' => [
            'XFU',
            'فىرانسىيە UIC فرانكى',
        ],
        'XOF' => [
            'F CFA',
            'ئافرىقا قىتئەسى پۇل-مۇئامىلە ئىتتىپاقى فرانكى (BCEAO)',
        ],
        'XPF' => [
            'CFPF',
            'تىنچ ئوكيان پۇل-مۇئامىلە ئورتاق گەۋدىسى فرانكى',
        ],
        'XRE' => [
            'XRE',
            'RINET فوندى',
        ],
        'YDD' => [
            'YDD',
            'يەمەن دىنارى',
        ],
        'YER' => [
            'YER',
            'يەمەن رىيالى',
        ],
        'YUD' => [
            'YUD',
            'يۇگوسلاۋىيە قاتتىق دىنارى (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'يۇگوسلاۋىيە يېڭى دىنارى (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'يۇگوسلاۋىيە ئالماشتۇرۇشچان دىنارى (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'يۇگوسلاۋىيە ئىسلاھات دىنارى (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'جەنۇبىي ئافرىقا راندى (پۇل–مۇئامىلە)',
        ],
        'ZAR' => [
            'ZAR',
            'جەنۇبىي ئافرىقا راندى',
        ],
        'ZMK' => [
            'ZMK',
            'زامبىيە كۋاچاسى (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'زامبىيە كۋاچاسى',
        ],
        'ZRN' => [
            'ZRN',
            'زايىر يېڭى زايىرى (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'زايىر زايىرى (1971–1993)',
        ],
        'ZWD' => [
            'ZWD',
            'زىمبابۋې دوللىرى (1980–2008)',
        ],
        'ZWL' => [
            'ZWL',
            'زىمبابۋې دوللىرى (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'زىمبابۋې دوللىرى (2008)',
        ],
    ],
];
