<?php

return [
    'Names' => [
        'Adlm' => 'adlamiska',
        'Afak' => 'afakiska',
        'Aghb' => 'kaukasiska albanska',
        'Ahom' => 'ahom',
        'Arab' => 'arabiska',
        'Aran' => 'nastaliq',
        'Armi' => 'imperisk arameiska',
        'Armn' => 'armeniska',
        'Avst' => 'avestiska',
        'Bali' => 'balinesiska',
        'Bamu' => 'bamunska',
        'Bass' => 'bassaiska vah',
        'Batk' => 'batak',
        'Beng' => 'bengaliska',
        'Bhks' => 'bhaiksukiska',
        'Blis' => 'blissymboler',
        'Bopo' => 'bopomofo',
        'Brah' => 'brami',
        'Brai' => 'punktskrift',
        'Bugi' => 'buginesiska',
        'Buhd' => 'buhid',
        'Cakm' => 'chakma',
        'Cans' => 'kanadensiska stavelsetecken',
        'Cari' => 'kariska',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Chrs' => 'khwarezmiska',
        'Cirt' => 'cirt',
        'Copt' => 'koptiska',
        'Cpmn' => 'cypro-minoisk skrift',
        'Cprt' => 'cypriotiska',
        'Cyrl' => 'kyrilliska',
        'Cyrs' => 'fornkyrkoslavisk kyrilliska',
        'Deva' => 'devanagari',
        'Diak' => 'dives akuru',
        'Dogr' => 'dogriska',
        'Dsrt' => 'deseret',
        'Dupl' => 'Duployéstenografiska',
        'Egyd' => 'demotiska',
        'Egyh' => 'hieratiska',
        'Egyp' => 'egyptiska hieroglyfer',
        'Elba' => 'elbasiska',
        'Elym' => 'elymaiska',
        'Ethi' => 'etiopiska',
        'Geok' => 'kutsuri',
        'Geor' => 'georgiska',
        'Glag' => 'glagolitiska',
        'Gong' => 'gunjalgondiska',
        'Gonm' => 'masaram-gondi',
        'Goth' => 'gotiska',
        'Gran' => 'gammaltamilska',
        'Grek' => 'grekiska',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhiska',
        'Hanb' => 'han med bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunó’o',
        'Hans' => 'förenklad',
        'Hant' => 'traditionell',
        'Hatr' => 'hatran',
        'Hebr' => 'hebreiska',
        'Hira' => 'hiragana',
        'Hluw' => 'hittitiska hieroglyfer',
        'Hmng' => 'pahaw mong',
        'Hmnp' => 'nyiakeng puachue hmong',
        'Hrkt' => 'katakana/hiragana',
        'Hung' => 'fornungerska',
        'Inds' => 'indus',
        'Ital' => 'fornitaliska',
        'Jamo' => 'jamo',
        'Java' => 'javanska',
        'Jpan' => 'japanska',
        'Jurc' => 'jurchenska',
        'Kali' => 'kaya li',
        'Kana' => 'katakana',
        'Khar' => 'kharoshti',
        'Khmr' => 'khmeriska',
        'Khoj' => 'khojkiska',
        'Kits' => 'khitanska',
        'Knda' => 'kanaresiska',
        'Kore' => 'koreanska',
        'Kpel' => 'kpellé',
        'Kthi' => 'kaithiska',
        'Lana' => 'lanna',
        'Laoo' => 'laotiska',
        'Latf' => 'frakturlatin',
        'Latg' => 'gaeliskt latin',
        'Latn' => 'latinska',
        'Lepc' => 'rong',
        'Limb' => 'limbu',
        'Lina' => 'linjär A',
        'Linb' => 'linjär B',
        'Lisu' => 'Fraser',
        'Loma' => 'loma',
        'Lyci' => 'lykiska',
        'Lydi' => 'lydiska',
        'Mahj' => 'mahajaniska',
        'Maka' => 'makasariska',
        'Mand' => 'mandaéiska',
        'Mani' => 'manikeanska',
        'Marc' => 'marchenska',
        'Maya' => 'mayahieroglyfer',
        'Medf' => 'medefaidrin',
        'Mend' => 'mende',
        'Merc' => 'kursiv-meroitiska',
        'Mero' => 'meroitiska',
        'Mlym' => 'malayalam',
        'Modi' => 'modiska',
        'Mong' => 'mongoliska',
        'Moon' => 'moon',
        'Mroo' => 'mru',
        'Mtei' => 'meitei-mayek',
        'Mult' => 'multaniska',
        'Mymr' => 'burmesiska',
        'Nand' => 'nandinagari',
        'Narb' => 'fornnordarabiska',
        'Nbat' => 'nabateiska',
        'Newa' => 'newariska',
        'Nkgb' => 'naxi geba',
        'Nkoo' => 'n-kå',
        'Nshu' => 'nüshu',
        'Ogam' => 'ogham',
        'Olck' => 'ol-chiki',
        'Orkh' => 'orkon',
        'Orya' => 'oriya',
        'Osge' => 'osage',
        'Osma' => 'osmanja',
        'Palm' => 'palmyreniska',
        'Pauc' => 'Pau Cin Hau-skrift',
        'Perm' => 'fornpermiska',
        'Phag' => 'phags-pa',
        'Phli' => 'tidig pahlavi',
        'Phlp' => 'psaltaren-pahlavi',
        'Phlv' => 'bokpahlavi',
        'Phnx' => 'feniciska',
        'Plrd' => 'pollardtecken',
        'Prti' => 'tidig parthianska',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifiska',
        'Roro' => 'rongo-rongo',
        'Runr' => 'runor',
        'Samr' => 'samaritiska',
        'Sara' => 'sarati',
        'Sarb' => 'fornsydarabiska',
        'Saur' => 'saurashtra',
        'Sgnw' => 'teckningsskrift',
        'Shaw' => 'shawiska',
        'Shrd' => 'sharada',
        'Sidd' => 'siddhamska',
        'Sind' => 'sindhiska',
        'Sinh' => 'singalesiska',
        'Sogd' => 'sogdiska',
        'Sogo' => 'gammalsogdiska',
        'Sora' => 'sora sompeng',
        'Soyo' => 'soyombo',
        'Sund' => 'sundanesiska',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'syriska',
        'Syre' => 'estrangelosyriska',
        'Syrj' => 'västsyriska',
        'Syrn' => 'östsyriska',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takritiska',
        'Tale' => 'tai le',
        'Talu' => 'tai lue',
        'Taml' => 'tamilska',
        'Tang' => 'tangutiska',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinaghiska',
        'Tglg' => 'tagalog',
        'Thaa' => 'taana',
        'Thai' => 'thailändska',
        'Tibt' => 'tibetanska',
        'Tirh' => 'tirhuta',
        'Ugar' => 'ugaritiska',
        'Vaii' => 'vaj',
        'Visp' => 'synligt tal',
        'Wara' => 'varang kshiti',
        'Wcho' => 'wancho',
        'Wole' => 'woleai',
        'Xpeo' => 'fornpersiska',
        'Xsux' => 'sumero-akkadisk kilskrift',
        'Yezi' => 'yazidiska',
        'Yiii' => 'yi',
        'Zanb' => 'zanabazar kvadratisk skrift',
        'Zinh' => 'ärvda',
        'Zmth' => 'matematisk notation',
        'Zsye' => 'emoji',
        'Zsym' => 'symboler',
        'Zxxx' => 'oskrivet språk',
        'Zyyy' => 'gemensamma',
    ],
];
