<?php

return [
    'Names' => [
        'Adlm' => 'Chữ Adlam',
        'Afak' => 'Chữ Afaka',
        'Arab' => 'Chữ Ả Rập',
        'Aran' => 'Chữ Nastaliq',
        'Armi' => 'Chữ Imperial Aramaic',
        'Armn' => 'Chữ Armenia',
        'Avst' => 'Chữ Avestan',
        'Bali' => 'Chữ Bali',
        'Bamu' => 'Chữ Bamum',
        'Bass' => 'Chữ Bassa Vah',
        'Batk' => 'Chữ Batak',
        'Beng' => 'Chữ Bangla',
        'Blis' => 'Chữ Blissymbols',
        'Bopo' => 'Chữ Bopomofo',
        'Brah' => 'Chữ Brahmi',
        'Brai' => 'Chữ nổi Braille',
        'Bugi' => 'Chữ Bugin',
        'Buhd' => 'Chữ Buhid',
        'Cakm' => 'Chữ Chakma',
        'Cans' => 'Âm tiết Thổ dân Canada Hợp nhất',
        'Cari' => 'Chữ Caria',
        'Cham' => 'Chữ Chăm',
        'Cher' => 'Chữ Cherokee',
        'Cirt' => 'Chữ Cirth',
        'Copt' => 'Chữ Coptic',
        'Cprt' => 'Chứ Síp',
        'Cyrl' => 'Chữ Kirin',
        'Cyrs' => 'Chữ Kirin Slavơ Nhà thờ cổ',
        'Deva' => 'Chữ Devanagari',
        'Dsrt' => 'Chữ Deseret',
        'Dupl' => 'Chữ tốc ký Duployan',
        'Egyd' => 'Chữ Ai Cập bình dân',
        'Egyh' => 'Chữ Ai Cập thày tu',
        'Egyp' => 'Chữ tượng hình Ai Cập',
        'Ethi' => 'Chữ Ethiopia',
        'Geok' => 'Chữ Khutsuri Georgia',
        'Geor' => 'Chữ Georgia',
        'Glag' => 'Chữ Glagolitic',
        'Goth' => 'Chữ Gô-tích',
        'Gran' => 'Chữ Grantha',
        'Grek' => 'Chữ Hy Lạp',
        'Gujr' => 'Chữ Gujarati',
        'Guru' => 'Chữ Gurmukhi',
        'Hanb' => 'Chữ Hán có chú âm',
        'Hang' => 'Chữ Hàn',
        'Hani' => 'Chữ Hán',
        'Hano' => 'Chữ Hanunoo',
        'Hans' => 'Giản thể',
        'Hant' => 'Phồn thể',
        'Hebr' => 'Chữ Do Thái',
        'Hira' => 'Chữ Hiragana',
        'Hluw' => 'Chữ tượng hình Anatolia',
        'Hmng' => 'Chữ Pahawh Hmong',
        'Hrkt' => 'Bảng ký hiệu âm tiết Tiếng Nhật',
        'Hung' => 'Chữ Hungary cổ',
        'Inds' => 'Chữ Indus',
        'Ital' => 'Chữ Italic cổ',
        'Jamo' => 'Chữ Jamo',
        'Java' => 'Chữ Java',
        'Jpan' => 'Chữ Nhật Bản',
        'Jurc' => 'Chữ Jurchen',
        'Kali' => 'Chữ Kayah Li',
        'Kana' => 'Chữ Katakana',
        'Khar' => 'Chữ Kharoshthi',
        'Khmr' => 'Chữ Khơ-me',
        'Khoj' => 'Chữ Khojki',
        'Knda' => 'Chữ Kannada',
        'Kore' => 'Chữ Hàn Quốc',
        'Kpel' => 'Chữ Kpelle',
        'Kthi' => 'Chữ Kaithi',
        'Lana' => 'Chữ Lanna',
        'Laoo' => 'Chữ Lào',
        'Latf' => 'Chữ La-tinh Fraktur',
        'Latg' => 'Chữ La-tinh Xcốt-len',
        'Latn' => 'Chữ La tinh',
        'Lepc' => 'Chữ Lepcha',
        'Limb' => 'Chữ Limbu',
        'Lina' => 'Chữ Linear A',
        'Linb' => 'Chữ Linear B',
        'Lisu' => 'Chữ Fraser',
        'Loma' => 'Chữ Loma',
        'Lyci' => 'Chữ Lycia',
        'Lydi' => 'Chữ Lydia',
        'Mand' => 'Chữ Mandaean',
        'Mani' => 'Chữ Manichaean',
        'Maya' => 'Chữ tượng hình Maya',
        'Mend' => 'Chữ Mende',
        'Merc' => 'Chữ Meroitic Nét thảo',
        'Mero' => 'Chữ Meroitic',
        'Mlym' => 'Chữ Malayalam',
        'Mong' => 'Chữ Mông Cổ',
        'Moon' => 'Chữ nổi Moon',
        'Mroo' => 'Chữ Mro',
        'Mtei' => 'Chữ Meitei Mayek',
        'Mymr' => 'Chữ Myanmar',
        'Narb' => 'Chữ Bắc Ả Rập cổ',
        'Nbat' => 'Chữ Nabataean',
        'Nkgb' => 'Chữ Naxi Geba',
        'Nkoo' => 'Chữ N’Ko',
        'Nshu' => 'Chữ Nüshu',
        'Ogam' => 'Chữ Ogham',
        'Olck' => 'Chữ Ol Chiki',
        'Orkh' => 'Chữ Orkhon',
        'Orya' => 'Chữ Odia',
        'Osma' => 'Chữ Osmanya',
        'Palm' => 'Chữ Palmyrene',
        'Perm' => 'Chữ Permic cổ',
        'Phag' => 'Chữ Phags-pa',
        'Phli' => 'Chữ Pahlavi Văn bia',
        'Phlp' => 'Chữ Pahlavi Thánh ca',
        'Phlv' => 'Chữ Pahlavi Sách',
        'Phnx' => 'Chữ Phoenicia',
        'Plrd' => 'Ngữ âm Pollard',
        'Prti' => 'Chữ Parthia Văn bia',
        'Qaag' => 'Chữ Zawgyi',
        'Rjng' => 'Chữ Rejang',
        'Rohg' => 'Chữ Hanifi',
        'Roro' => 'Chữ Rongorongo',
        'Runr' => 'Chữ Runic',
        'Samr' => 'Chữ Samaritan',
        'Sara' => 'Chữ Sarati',
        'Sarb' => 'Chữ Nam Ả Rập cổ',
        'Saur' => 'Chữ Saurashtra',
        'Sgnw' => 'Chữ viết Ký hiệu',
        'Shaw' => 'Chữ Shavian',
        'Shrd' => 'Chữ Sharada',
        'Sind' => 'Chữ Khudawadi',
        'Sinh' => 'Chữ Sinhala',
        'Sora' => 'Chữ Sora Sompeng',
        'Sund' => 'Chữ Xu-đăng',
        'Sylo' => 'Chữ Syloti Nagri',
        'Syrc' => 'Chữ Syria',
        'Syre' => 'Chữ Estrangelo Syriac',
        'Syrj' => 'Chữ Tây Syria',
        'Syrn' => 'Chữ Đông Syria',
        'Tagb' => 'Chữ Tagbanwa',
        'Takr' => 'Chữ Takri',
        'Tale' => 'Chữ Thái Na',
        'Talu' => 'Chữ Thái Lặc mới',
        'Taml' => 'Chữ Tamil',
        'Tang' => 'Chữ Tangut',
        'Tavt' => 'Chữ Thái Việt',
        'Telu' => 'Chữ Telugu',
        'Teng' => 'Chữ Tengwar',
        'Tfng' => 'Chữ Tifinagh',
        'Tglg' => 'Chữ Tagalog',
        'Thaa' => 'Chữ Thaana',
        'Thai' => 'Chữ Thái',
        'Tibt' => 'Chữ Tây Tạng',
        'Tirh' => 'Chữ Tirhuta',
        'Ugar' => 'Chữ Ugarit',
        'Vaii' => 'Chữ Vai',
        'Visp' => 'Tiếng nói Nhìn thấy được',
        'Wara' => 'Chữ Varang Kshiti',
        'Wole' => 'Chữ Woleai',
        'Xpeo' => 'Chữ Ba Tư cổ',
        'Xsux' => 'Chữ hình nêm Sumero-Akkadian',
        'Yiii' => 'Chữ Di',
        'Zinh' => 'Chữ Kế thừa',
        'Zmth' => 'Ký hiệu Toán học',
        'Zsye' => 'Biểu tượng cảm xúc',
        'Zsym' => 'Biểu tượng | Ký hiệu',
        'Zxxx' => 'Chưa có chữ viết',
        'Zyyy' => 'Chung',
    ],
];
