<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଆବିଦଜାନ)',
        'Africa/Accra' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଆକାରା)',
        'Africa/Addis_Ababa' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (ଆଦିସ୍‌ ଆବାବା)',
        'Africa/Algiers' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଅଲଜିୟର୍ସ)',
        'Africa/Asmera' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (ଅସମରା)',
        'Africa/Asmara' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (ଅସମରା)',
        'Africa/Bamako' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ବାମାକୋ)',
        'Africa/Bangui' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ବାଙ୍ଗୁଇ)',
        'Africa/Banjul' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ବାଞ୍ଜୁଲ)',
        'Africa/Bissau' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ବିସାଉ)',
        'Africa/Blantyre' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ବ୍ଲାଣ୍ଟାୟାର୍‌)',
        'Africa/Brazzaville' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ବ୍ରାଜାଭିଲ୍ଲେ)',
        'Africa/Bujumbura' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ବୁଜୁମ୍ବୁରା)',
        'Africa/Cairo' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (କାଇରୋ)',
        'Africa/Casablanca' => 'ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (କାସାବ୍ଲାଙ୍କା)',
        'Africa/Ceuta' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ସେଉଟା)',
        'Africa/Conakry' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (କୋନାକ୍ରି)',
        'Africa/Dakar' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଡକାର)',
        'Africa/Dar_es_Salaam' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (ଡର୍‌ ଇସ୍‌ ସାଲାମ)',
        'Africa/Djibouti' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (ଜିବୋଟି)',
        'Africa/Douala' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ଡଉଲା)',
        'Africa/El_Aaiun' => 'ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଏଲ୍‌ ଏୟନ୍)',
        'Africa/Freetown' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଫ୍ରିଟାଉନ୍‌)',
        'Africa/Gaborone' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ଗାବୋର୍ଣ୍ଣ)',
        'Africa/Harare' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ହରାରେ)',
        'Africa/Johannesburg' => 'ଦକ୍ଷିଣ ଆଫ୍ରିକା ମାନାଙ୍କ ସମୟ (ଜୋହାନ୍ସବର୍ଗ)',
        'Africa/Juba' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ଜୁବା)',
        'Africa/Kampala' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (କାମ୍ପାଲା)',
        'Africa/Khartoum' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ଖରଟୌମ୍‌)',
        'Africa/Kigali' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (କିଗାଲି)',
        'Africa/Kinshasa' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (କିନସାସ୍‌)',
        'Africa/Lagos' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ଲାଗୋସ୍‌)',
        'Africa/Libreville' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ଲିବ୍ରେଭିଲ୍ଲେ)',
        'Africa/Lome' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଲୋମ୍‌)',
        'Africa/Luanda' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ଲୁଆଣ୍ଡା)',
        'Africa/Lubumbashi' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ଲୁବୁମ୍ବାଶି)',
        'Africa/Lusaka' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ଲୁସାକା)',
        'Africa/Malabo' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ମାଲାବୋ)',
        'Africa/Maputo' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ମାପୁତୋ)',
        'Africa/Maseru' => 'ଦକ୍ଷିଣ ଆଫ୍ରିକା ମାନାଙ୍କ ସମୟ (ମେସେରୁ)',
        'Africa/Mbabane' => 'ଦକ୍ଷିଣ ଆଫ୍ରିକା ମାନାଙ୍କ ସମୟ (ବାବେନ୍‌)',
        'Africa/Mogadishu' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (ମୋଗାଦିଶୁ)',
        'Africa/Monrovia' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ମନରୋଭିଆ)',
        'Africa/Nairobi' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (ନାଇରୋବି)',
        'Africa/Ndjamena' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ଜାମେନା)',
        'Africa/Niamey' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ନିଆମି)',
        'Africa/Nouakchott' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ନୌକାଚୋଟ)',
        'Africa/Ouagadougou' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଅଉଗାଡଉଗଉ)',
        'Africa/Porto-Novo' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ (ପୋର୍ଟୋ-ନୋଭୋ)',
        'Africa/Sao_Tome' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ସାଓ ଟୋମେ)',
        'Africa/Tripoli' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ତ୍ରିପୋଲି)',
        'Africa/Tunis' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଟୁନିସ୍‌)',
        'Africa/Windhoek' => 'ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ (ୱିଣ୍ଡହୋଏକ୍)',
        'America/Adak' => 'ହୱାଇ-ଆଲେଉଟିୟ ସମୟ (ଆଡାକ୍)',
        'America/Anchorage' => 'ଆଲାସ୍କା ସମୟ (ଆଙ୍କରେଜ୍)',
        'America/Anguilla' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଆଙ୍ଗୁଇଲା)',
        'America/Antigua' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଆଣ୍ଟିଗୁଆ)',
        'America/Araguaina' => 'ବ୍ରାସିଲିଆ ସମୟ (ଆରାଗୁଆନା)',
        'America/Argentina/La_Rioja' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ଲା ରିଓଜା)',
        'America/Argentina/Rio_Gallegos' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ରିଓ ଗାଲ୍ଲେଗସ୍‌)',
        'America/Argentina/Salta' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ସଲ୍ଟା)',
        'America/Argentina/San_Juan' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ସାନ୍‌ ଜୁଆନ)',
        'America/Argentina/San_Luis' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ସାନ୍‌ ଲୁଇସ୍‌)',
        'America/Argentina/Tucuman' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ଟୁକୁମାନ୍‌)',
        'America/Argentina/Ushuaia' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ଉଶୁୟା)',
        'America/Aruba' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଆରୁବା)',
        'America/Asuncion' => 'ପାରାଗୁଏ ସମୟ (ଆସନସିଅନ୍‌)',
        'America/Bahia' => 'ବ୍ରାସିଲିଆ ସମୟ (ବାହିଆ)',
        'America/Bahia_Banderas' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ବାହିଆ ବ୍ୟାଣ୍ଡେରାସ୍)',
        'America/Barbados' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ବାର୍ବାଡୋସ୍)',
        'America/Belem' => 'ବ୍ରାସିଲିଆ ସମୟ (ବେଲେମ)',
        'America/Belize' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ବେଲିଜେ)',
        'America/Blanc-Sablon' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ବ୍ଲାଙ୍କ-ସାବଲୋନ୍)',
        'America/Boa_Vista' => 'ଆମାଜନ୍ ସମୟ (ବୋଆ ଭିଷ୍ଟା)',
        'America/Bogota' => 'କଲମ୍ବିଆ ସମୟ (ବୋଗୋଟା)',
        'America/Boise' => 'ପାର୍ବତ୍ୟ ସମୟ (ବୋଇସେ)',
        'America/Buenos_Aires' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ବୁଏନସ୍‌ ଏରିସ୍‌)',
        'America/Argentina/Buenos_Aires' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ବୁଏନସ୍‌ ଏରିସ୍‌)',
        'America/Cambridge_Bay' => 'ପାର୍ବତ୍ୟ ସମୟ (କେମ୍ଵ୍ରିଜ୍ ବେ)',
        'America/Campo_Grande' => 'ଆମାଜନ୍ ସମୟ (କାମ୍ପୋ ଗ୍ରାଣ୍ଡେ)',
        'America/Cancun' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (କାନକୁନ୍)',
        'America/Caracas' => 'ଭେନିଜୁଏଲା ସମୟ (କାରକାସ୍‌)',
        'America/Catamarca' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (କାଟାମାର୍କା)',
        'America/Argentina/Catamarca' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (କାଟାମାର୍କା)',
        'America/Cayenne' => 'ଫ୍ରେଞ୍ଚ ଗୁଆନା ସମୟ (କେୟେନ୍ନି)',
        'America/Cayman' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (କାୟମ୍ୟାନ୍)',
        'America/Chicago' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ଚିକାଗୋ)',
        'America/Chihuahua' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ଚିହୁଆହୁଆ)',
        'America/Ciudad_Juarez' => 'ପାର୍ବତ୍ୟ ସମୟ (ସିଉଡାଡ୍ ଜୁଆରେଜ୍)',
        'America/Coral_Harbour' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଆଟିକୋକାନ୍)',
        'America/Atikokan' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଆଟିକୋକାନ୍)',
        'America/Cordoba' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (କୋର୍ଡୋବା)',
        'America/Argentina/Cordoba' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (କୋର୍ଡୋବା)',
        'America/Costa_Rica' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (କୋଷ୍ଟା ରିକା)',
        'America/Coyhaique' => 'ଚିଲି ସମୟ (କୋୟାଇକେ)',
        'America/Creston' => 'ପାର୍ବତ୍ୟ ସମୟ (କ୍ରେଷ୍ଟୋନ୍)',
        'America/Cuiaba' => 'ଆମାଜନ୍ ସମୟ (କୁଇବା)',
        'America/Curacao' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (କୁରାକୋ)',
        'America/Danmarkshavn' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଡାନମାର୍କସାଭନ୍)',
        'America/Dawson' => 'ୟୁକୋନ୍ ସମୟ (ଡସନ୍‌)',
        'America/Dawson_Creek' => 'ପାର୍ବତ୍ୟ ସମୟ (ଡୱସନ୍ କ୍ରିକ୍)',
        'America/Denver' => 'ପାର୍ବତ୍ୟ ସମୟ (ଡେନଭିର୍)',
        'America/Detroit' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଡେଟ୍ରୋଇଟ୍)',
        'America/Dominica' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଡୋମିନିକା)',
        'America/Edmonton' => 'ପାର୍ବତ୍ୟ ସମୟ (ଏଡମୋନଟୋନ୍)',
        'America/Eirunepe' => 'ଆକା ସମୟ (ଇରୁନେପେ)',
        'America/El_Salvador' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ଏଲ୍ ସାଲଭାଡୋର୍)',
        'America/Fort_Nelson' => 'ପାର୍ବତ୍ୟ ସମୟ (ଫୋର୍ଟ୍ ନେଲସନ୍)',
        'America/Fortaleza' => 'ବ୍ରାସିଲିଆ ସମୟ (ଫୋର୍ଟେଲେଜା)',
        'America/Glace_Bay' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଗ୍ଲାସେ ବେ)',
        'America/Godthab' => 'ଗ୍ରୀନଲ୍ୟାଣ୍ଡ ସମୟ (ନୁଉକ୍)',
        'America/Nuuk' => 'ଗ୍ରୀନଲ୍ୟାଣ୍ଡ ସମୟ (ନୁଉକ୍)',
        'America/Goose_Bay' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଗୁସ୍ ବେ)',
        'America/Grand_Turk' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଗ୍ରାଣ୍ଡ୍ ଟର୍କ୍)',
        'America/Grenada' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଗ୍ରେନାଡା)',
        'America/Guadeloupe' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଗୁଆଡେଲୋପ୍‌)',
        'America/Guatemala' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ଗୁଆଟେମାଲା)',
        'America/Guayaquil' => 'ଇକ୍ୱେଡର ସମୟ (ଗୁୟାକ୍ୱିଲ)',
        'America/Guyana' => 'ଗୁଏନା ସମୟ',
        'America/Halifax' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ହାଲିଫ୍ୟାକ୍ସ୍)',
        'America/Havana' => 'କ୍ୟୁବା ସମୟ (ହାଭାନା)',
        'America/Hermosillo' => 'ମେକ୍ସିକାନ୍ ପାସିଫିକ୍ ସମୟ (ହେରମୋସିଲୋ)',
        'America/Indiana/Knox' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (କ୍ନୋକ୍ସ, ଇଣ୍ଡିଆନା)',
        'America/Indiana/Marengo' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ମାରେନଗୋ, ଇଣ୍ଡିଆନା)',
        'America/Indiana/Petersburg' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ପେଟେର୍ସବର୍ଗ୍, ଇଣ୍ଡିଆନା)',
        'America/Indiana/Tell_City' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ଟେଲ୍ ସିଟି, ଇଣ୍ଡିଆନା)',
        'America/Indiana/Vevay' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଭେଭାୟ, ଇଣ୍ଡିଆନା)',
        'America/Indiana/Vincennes' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଭିନସେନ୍ନେସ୍, ଇଣ୍ଡିଆନା)',
        'America/Indiana/Winamac' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ୱିନାମାକ୍, ଇଣ୍ଡିଆନା)',
        'America/Indianapolis' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଇଣ୍ଡିଆନାପୋଲିସ୍)',
        'America/Indiana/Indianapolis' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଇଣ୍ଡିଆନାପୋଲିସ୍)',
        'America/Inuvik' => 'ପାର୍ବତ୍ୟ ସମୟ (ଇନୁଭିକ୍)',
        'America/Iqaluit' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଇକ୍ଵାଲୁଇଟ୍)',
        'America/Jamaica' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଜାମାଇକା)',
        'America/Jujuy' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ଜୁଜୁଇ)',
        'America/Argentina/Jujuy' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ଜୁଜୁଇ)',
        'America/Juneau' => 'ଆଲାସ୍କା ସମୟ (ଜୁନେଆଉ)',
        'America/Kentucky/Monticello' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ମୋଣ୍ଟିସେଲୋ, କେଣ୍ଟଉକିକେ)',
        'America/Kralendijk' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (କ୍ରାଲେଣ୍ଡଜିକ)',
        'America/La_Paz' => 'ବଲିଭିଆ ସମୟ (ଲା ପାଜ୍‌)',
        'America/Lima' => 'ପେରୁ ସମୟ (ଲିମା)',
        'America/Los_Angeles' => 'ପାସିଫିକ୍ ସମୟ (ଲସ୍ ଏଞ୍ଜେଲେସ୍)',
        'America/Louisville' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଲୁଇଭିଲ୍ଲେ)',
        'America/Kentucky/Louisville' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଲୁଇଭିଲ୍ଲେ)',
        'America/Lower_Princes' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ନିମ୍ନ ପ୍ରିନ୍ସ’ର କ୍ଵାଟର୍)',
        'America/Maceio' => 'ବ୍ରାସିଲିଆ ସମୟ (ମାସିଓ)',
        'America/Managua' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ମାନାଗୁଆ)',
        'America/Manaus' => 'ଆମାଜନ୍ ସମୟ (ମାନାଉସ୍‌)',
        'America/Marigot' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ମାରିଗୋଟ୍)',
        'America/Martinique' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ମାର୍ଟିନିକ୍ୟୁ)',
        'America/Matamoros' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ମାଟାମୋରୋସ୍)',
        'America/Mazatlan' => 'ମେକ୍ସିକାନ୍ ପାସିଫିକ୍ ସମୟ (ମାନାଟଲାନ୍)',
        'America/Mendoza' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ମେଣ୍ଡୋଜା)',
        'America/Argentina/Mendoza' => 'ଆର୍ଜେଣ୍ଟିନା ସମୟ (ମେଣ୍ଡୋଜା)',
        'America/Menominee' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ମେନୋମିନି)',
        'America/Merida' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ମେରିଡା)',
        'America/Metlakatla' => 'ଆଲାସ୍କା ସମୟ (ମାଟଲାକାଟଲା)',
        'America/Mexico_City' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ମେକ୍ସିକୋ ସିଟି)',
        'America/Miquelon' => 'ସେଣ୍ଟ. ପିଏରେ ଏବଂ ମିକ୍ୟୁଲୋନ୍ ସମୟ (ମିକ୍ଵେଲୋନ୍)',
        'America/Moncton' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ମାନକଟୋନ୍)',
        'America/Monterrey' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ମୋନଟେରିଏ)',
        'America/Montevideo' => 'ଉରୁଗୁଏ ସମୟ (ମଣ୍ଟେଭିଡିଓ)',
        'America/Montserrat' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ମୋନଟସେରରାଟ୍)',
        'America/Nassau' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ନାସାଉ)',
        'America/New_York' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ନ୍ୟୁ ୟୋର୍କ୍)',
        'America/Nome' => 'ଆଲାସ୍କା ସମୟ (ନୋମେ)',
        'America/Noronha' => 'ଫର୍ଣ୍ଣାଣ୍ଡୋ ଡି ନୋରୋନ୍ନା ସମୟ',
        'America/North_Dakota/Beulah' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ବେଉଲାହ, ଉତ୍ତର ଡାକୋଟା)',
        'America/North_Dakota/Center' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (କେନ୍ଦ୍ର, ଉତ୍ତର ଡାକୋଟା)',
        'America/North_Dakota/New_Salem' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ନ୍ୟୁ ସାଲେମ୍, ଉତ୍ତର ଡାକୋଟା)',
        'America/Ojinaga' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ଓଜିନାଗା)',
        'America/Panama' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ପାନାମା)',
        'America/Paramaribo' => 'ସୁରିନେମ୍‌ ସମୟ (ପାରାମାରିବୋ)',
        'America/Phoenix' => 'ପାର୍ବତ୍ୟ ସମୟ (ଫୋଇନିକ୍ସ)',
        'America/Port-au-Prince' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ପୋର୍ଟ୍-ଏୟୁ-ପ୍ରିନ୍ସ)',
        'America/Port_of_Spain' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ପୋର୍ଟ୍ ଅଫ୍ ସ୍ପେନ୍)',
        'America/Porto_Velho' => 'ଆମାଜନ୍ ସମୟ (ପୋର୍ଟୋ ଭେଲୋ)',
        'America/Puerto_Rico' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ପୁଏର୍ତୋ ରିକୋ)',
        'America/Punta_Arenas' => 'ଚିଲି ସମୟ (ପୁଣ୍ଟା ଏରିନାସ୍‌)',
        'America/Rankin_Inlet' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ରାନକିନ୍ ଇନଲେଟ୍)',
        'America/Recife' => 'ବ୍ରାସିଲିଆ ସମୟ (ରେସିଫି)',
        'America/Regina' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ରେଗିନା)',
        'America/Resolute' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ରିସୋଲୁଟେ)',
        'America/Rio_Branco' => 'ଆକା ସମୟ (ରିଓ ବ୍ରାଙ୍କୋ)',
        'America/Santarem' => 'ବ୍ରାସିଲିଆ ସମୟ (ସାଣ୍ଟାରେମ୍‌)',
        'America/Santiago' => 'ଚିଲି ସମୟ (ସାଣ୍ଟିଆଗୋ)',
        'America/Santo_Domingo' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ସାଣ୍ଟୋ ଡୋମିଙ୍ଗୋ)',
        'America/Sao_Paulo' => 'ବ୍ରାସିଲିଆ ସମୟ (ସାଓ ପାଓଲୋ)',
        'America/Scoresbysund' => 'ଗ୍ରୀନଲ୍ୟାଣ୍ଡ ସମୟ (ଇଟ୍ଟୋକ୍ଵୋରଟୋରମିଟ୍)',
        'America/Sitka' => 'ଆଲାସ୍କା ସମୟ (ସିଟକା)',
        'America/St_Barthelemy' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ସେଣ୍ଟ୍. ବାର୍ଥେଲେମି)',
        'America/St_Johns' => 'ନ୍ୟୁଫାଉଣ୍ଡଲ୍ୟାଣ୍ଡ୍ ସମୟ (ସେଣ୍ଟ୍. ଜନସ୍)',
        'America/St_Kitts' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ସେଣ୍ଟ୍ କିଟ୍ସ୍)',
        'America/St_Lucia' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ସେଣ୍ଟ୍. ଲୁସିଆ)',
        'America/St_Thomas' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ସେଣ୍ଟ୍. ଥୋମାସ୍)',
        'America/St_Vincent' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ସେଣ୍ଟ୍. ଭିନସେଣ୍ଟ୍)',
        'America/Swift_Current' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ସୁଇଫ୍ଟ୍ କରେଣ୍ଟ୍)',
        'America/Tegucigalpa' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ଟେଗୁସିଗାଲପା)',
        'America/Thule' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଥୁଲେ)',
        'America/Tijuana' => 'ପାସିଫିକ୍ ସମୟ (ତିଜୁଆନା)',
        'America/Toronto' => 'ପୂର୍ବାଞ୍ଚଳ ସମୟ (ଟୋରୋଣ୍ଟୋ)',
        'America/Tortola' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ଟୋରଟୋଲା)',
        'America/Vancouver' => 'ପାସିଫିକ୍ ସମୟ (ଭାଙ୍କୁଭର୍)',
        'America/Whitehorse' => 'ୟୁକୋନ୍ ସମୟ (ହ୍ଵାଇଟହର୍ସ୍)',
        'America/Winnipeg' => 'କେନ୍ଦ୍ରୀୟ ସମୟ (ୱିନିପେଗ୍)',
        'America/Yakutat' => 'ଆଲାସ୍କା ସମୟ (ୟାକୁଟାଟ୍)',
        'Antarctica/Casey' => 'ପଶ୍ଚିମ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (କାସେ)',
        'Antarctica/Davis' => 'ଡେଭିସ୍‌ ସମୟ',
        'Antarctica/DumontDUrville' => 'ଡୁମୋଣ୍ଟ-ଡି‘ଉରଭିଲ୍ଲେ ସମୟ',
        'Antarctica/Macquarie' => 'ପୂର୍ବ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ମାକ୍ୱେରୀ)',
        'Antarctica/Mawson' => 'ମାୱସନ୍‌ ସମୟ',
        'Antarctica/McMurdo' => 'ନ୍ୟୁଜିଲାଣ୍ଡ ସମୟ (ମ୍ୟାକ୍‌ମୁର୍ଡୋ)',
        'Antarctica/Palmer' => 'ଚିଲି ସମୟ (ପାଲମର୍‌)',
        'Antarctica/Rothera' => 'ରୋଥେରା ସମୟ',
        'Antarctica/Syowa' => 'ସୋୱା ସମୟ',
        'Antarctica/Troll' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଟ୍ରୋଲ୍)',
        'Antarctica/Vostok' => 'ଭୋଷ୍ଟୋକ୍‌ ସମୟ',
        'Arctic/Longyearbyen' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଲଙ୍ଗୟେଆରବୟେନ୍)',
        'Asia/Aden' => 'ଆରବୀୟ ସମୟ (ଏଡେନ୍‌)',
        'Asia/Almaty' => 'କାଜାକସ୍ତାନ୍ ସମୟ (ଅଲମାଟି)',
        'Asia/Amman' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଅମ୍ମାନ)',
        'Asia/Anadyr' => 'ପେଟ୍ରୋପାଭଲୋଭ୍ସକ-କମଚଟସ୍କି ସମୟ (ଆନାଡୟାର୍)',
        'Asia/Aqtau' => 'କାଜାକସ୍ତାନ୍ ସମୟ (ଆକଟାଉ)',
        'Asia/Aqtobe' => 'କାଜାକସ୍ତାନ୍ ସମୟ (ଆକଟୋବ୍‌)',
        'Asia/Ashgabat' => 'ତୁର୍କମେନିସ୍ତାନ ସମୟ (ଆଶ୍‌ଗାବୋଟ୍‌)',
        'Asia/Atyrau' => 'କାଜାକସ୍ତାନ୍ ସମୟ (ଅତିରାଉ)',
        'Asia/Baghdad' => 'ଆରବୀୟ ସମୟ (ବାଗଦାଦ୍‌)',
        'Asia/Bahrain' => 'ଆରବୀୟ ସମୟ (ବାହାରିନ୍)',
        'Asia/Baku' => 'ଆଜେରବାଇଜାନ ସମୟ (ବାକୁ)',
        'Asia/Bangkok' => 'ଇଣ୍ଡୋଚାଇନା ସମୟ (ବ୍ୟାଙ୍ଗକକ୍‌)',
        'Asia/Barnaul' => 'କ୍ରାସନୋୟାରସ୍କ ସମୟ (ବାରନାଉଲ୍)',
        'Asia/Beirut' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ବୀରୁଟ୍‌)',
        'Asia/Bishkek' => 'କିର୍ଗିସ୍ତାନ ସମୟ (ବିଶକେକ୍‌)',
        'Asia/Brunei' => 'ବ୍ରୁନେଇ ଡାରୁସାଲାମ ସମୟ',
        'Asia/Calcutta' => 'ଭାରତୀୟ ମାନକ ସମୟ (କୋଲକାତା)',
        'Asia/Kolkata' => 'ଭାରତୀୟ ମାନକ ସମୟ (କୋଲକାତା)',
        'Asia/Chita' => 'ୟାକୁଟସ୍କ ସମୟ (ଚିଟା)',
        'Asia/Colombo' => 'ଭାରତୀୟ ମାନକ ସମୟ (କଲମ୍ବୋ)',
        'Asia/Damascus' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଡାମାସକସ୍‌)',
        'Asia/Dhaka' => 'ବାଂଲାଦେଶ ସମୟ (ଢାକା)',
        'Asia/Dili' => 'ପୂର୍ବ ତିମୋର୍‌ ସମୟ (ଦିଲ୍ଲୀ)',
        'Asia/Dubai' => 'ଗଲ୍ଫ ମାନାଙ୍କ ସମୟ (ଦୁବାଇ)',
        'Asia/Dushanbe' => 'ତାଜିକିସ୍ତାନ ସମୟ (ଦୁଶାନବେ)',
        'Asia/Famagusta' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଫାମାଗୁଷ୍ଟା)',
        'Asia/Gaza' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଗାଜା)',
        'Asia/Hebron' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ହେବ୍ରନ୍‌)',
        'Asia/Hong_Kong' => 'ହଂ କଂ ସମୟ',
        'Asia/Hovd' => 'ହୋଭଡ୍‌ ସମୟ',
        'Asia/Irkutsk' => 'ଇଅରକୁଟସ୍କ ସମୟ (ଇରକୁଟସ୍କ)',
        'Asia/Jakarta' => 'ପଶ୍ଚିମ ଇଣ୍ଡୋନେସିଆ ସମୟ (ଜାକର୍ତ୍ତା)',
        'Asia/Jayapura' => 'ପୂର୍ବ ଇଣ୍ଡୋନେସିଆ ସମୟ (ଜୟପୁରା)',
        'Asia/Jerusalem' => 'ଇସ୍ରାଏଲ ସମୟ (ଜେରୁଜେଲମ)',
        'Asia/Kabul' => 'ଆଫଗାନିସ୍ତାନ ସମୟ (କାବୁଲ)',
        'Asia/Kamchatka' => 'ପେଟ୍ରୋପାଭଲୋଭ୍ସକ-କମଚଟସ୍କି ସମୟ (କାମଚାଟକା)',
        'Asia/Karachi' => 'ପାକିସ୍ତାନ ସମୟ (କରାଚି)',
        'Asia/Katmandu' => 'ନେପାଳ ସମୟ (କାଠମାଣ୍ଡୁ)',
        'Asia/Kathmandu' => 'ନେପାଳ ସମୟ (କାଠମାଣ୍ଡୁ)',
        'Asia/Khandyga' => 'ୟାକୁଟସ୍କ ସମୟ (ଖାନଡ୍ୟାଗା)',
        'Asia/Krasnoyarsk' => 'କ୍ରାସନୋୟାରସ୍କ ସମୟ',
        'Asia/Kuala_Lumpur' => 'ମାଲେସିଆ ସମୟ (କ୍ୱାଲାଲମ୍ପୁର)',
        'Asia/Kuching' => 'ମାଲେସିଆ ସମୟ (କୁଚିଂ)',
        'Asia/Kuwait' => 'ଆରବୀୟ ସମୟ (କୁଏତ)',
        'Asia/Macau' => 'ଚୀନ ସମୟ (ମାକାଉ)',
        'Asia/Magadan' => 'ମାଗାଡାନ୍ ସମୟ',
        'Asia/Makassar' => 'ମଧ୍ୟ ଇଣ୍ଡୋନେସିଆ ସମୟ (ମାକାସାର୍‌)',
        'Asia/Manila' => 'ଫିଲିପାଇନ୍‌ ସମୟ (ମାନିଲା)',
        'Asia/Muscat' => 'ଗଲ୍ଫ ମାନାଙ୍କ ସମୟ (ମସ୍କାଟ୍‌)',
        'Asia/Nicosia' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ନିକୋସିଆ)',
        'Asia/Novokuznetsk' => 'କ୍ରାସନୋୟାରସ୍କ ସମୟ (ନୋଭୋକୁଜନେଟସ୍କ)',
        'Asia/Novosibirsk' => 'କ୍ରାସନୋୟାରସ୍କ ସମୟ (ନୋଭୋସିବିରସ୍କ)',
        'Asia/Omsk' => 'ଓମସ୍କ ସମୟ',
        'Asia/Oral' => 'କାଜାକସ୍ତାନ୍ ସମୟ (ଓରାଲ୍‌)',
        'Asia/Phnom_Penh' => 'ଇଣ୍ଡୋଚାଇନା ସମୟ (ଫନୋମ୍‌ ପେନହ)',
        'Asia/Pontianak' => 'ପଶ୍ଚିମ ଇଣ୍ଡୋନେସିଆ ସମୟ (ପୋଣ୍ଟିଆନାକ୍‌)',
        'Asia/Pyongyang' => 'କୋରିୟ ସମୟ (ପୋୟଙ୍ଗୟାଙ୍ଗ)',
        'Asia/Qatar' => 'ଆରବୀୟ ସମୟ (କତାର୍)',
        'Asia/Qostanay' => 'କାଜାକସ୍ତାନ୍ ସମୟ (କୋଷ୍ଟନେ)',
        'Asia/Qyzylorda' => 'କାଜାକସ୍ତାନ୍ ସମୟ (କୀଜିଲୋର୍ଡା)',
        'Asia/Rangoon' => 'ମିଆଁମାର୍‌ ସମୟ (ୟାଙ୍ଗୁନ୍‌)',
        'Asia/Yangon' => 'ମିଆଁମାର୍‌ ସମୟ (ୟାଙ୍ଗୁନ୍‌)',
        'Asia/Riyadh' => 'ଆରବୀୟ ସମୟ (ରିଆଦ)',
        'Asia/Saigon' => 'ଇଣ୍ଡୋଚାଇନା ସମୟ (ହୋ ଚି ମିନ୍‌ ସିଟି)',
        'Asia/Ho_Chi_Minh' => 'ଇଣ୍ଡୋଚାଇନା ସମୟ (ହୋ ଚି ମିନ୍‌ ସିଟି)',
        'Asia/Sakhalin' => 'ମାଗାଡାନ୍ ସମୟ (ସଖାଲିନ୍)',
        'Asia/Samarkand' => 'ଉଜବେକିସ୍ତାନ ସମୟ (ସମରକନ୍ଦ)',
        'Asia/Seoul' => 'କୋରିୟ ସମୟ (ସିଓଲ)',
        'Asia/Shanghai' => 'ଚୀନ ସମୟ (ସାଂଘାଇ)',
        'Asia/Singapore' => 'ସିଙ୍ଗାପୁର୍‌ ମାନକ ସମୟ',
        'Asia/Srednekolymsk' => 'ମାଗାଡାନ୍ ସମୟ (ସ୍ରେଡନେକୋଲୟମସ୍କ)',
        'Asia/Taipei' => 'ତାଇପେଇ ସମୟ',
        'Asia/Tashkent' => 'ଉଜବେକିସ୍ତାନ ସମୟ (ତାଶକେଣ୍ଟ)',
        'Asia/Tbilisi' => 'ଜର୍ଜିଆ ସମୟ (ଟିବିଲିସି)',
        'Asia/Tehran' => 'ଇରାନ ସମୟ (ତେହେରାନ୍)',
        'Asia/Thimphu' => 'ଭୁଟାନ ସମୟ (ଥିମ୍ପୁ)',
        'Asia/Tokyo' => 'ଜାପାନ ସମୟ (ଟୋକିଓ)',
        'Asia/Tomsk' => 'କ୍ରାସନୋୟାରସ୍କ ସମୟ (ଟୋମସ୍କ)',
        'Asia/Ulaanbaatar' => 'ଉଲାନ୍‌ବାଟର୍‌ ସମୟ',
        'Asia/Urumqi' => 'ଚୀନ୍‌ ସମୟ (ଉରୁମକି)',
        'Asia/Ust-Nera' => 'ଭ୍ଲାଡିଭୋଷ୍ଟୋକ୍ ସମୟ (ୟୁଷ୍ଟ-ନେରା)',
        'Asia/Vientiane' => 'ଇଣ୍ଡୋଚାଇନା ସମୟ (ଭିଏଣ୍ଟିଏନ୍‌)',
        'Asia/Vladivostok' => 'ଭ୍ଲାଡିଭୋଷ୍ଟୋକ୍ ସମୟ',
        'Asia/Yakutsk' => 'ୟାକୁଟସ୍କ ସମୟ',
        'Asia/Yekaterinburg' => 'ୟେକାଟେରିନବର୍ଗ୍ ସମୟ',
        'Asia/Yerevan' => 'ଆର୍ମେନିଆ ସମୟ (ୟେରେଭାନ୍)',
        'Atlantic/Azores' => 'ଆଜୋରେସ୍ ସମୟ',
        'Atlantic/Bermuda' => 'ଆଟଲାଣ୍ଟିକ୍ ସମୟ (ବର୍ମୁଡା)',
        'Atlantic/Canary' => 'ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (କାନାରେ)',
        'Atlantic/Cape_Verde' => 'କେପ୍‌ ଭର୍ଦେ ସମୟ',
        'Atlantic/Faeroe' => 'ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଫାରୋଏ)',
        'Atlantic/Faroe' => 'ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଫାରୋଏ)',
        'Atlantic/Madeira' => 'ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ମାଡେଇରା)',
        'Atlantic/Reykjavik' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ରେୟକଜାଭିକ୍)',
        'Atlantic/South_Georgia' => 'ଦକ୍ଷିଣ ଜର୍ଜିଆ ସମୟ',
        'Atlantic/St_Helena' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ସେଣ୍ଟ୍‌ ହେଲିନା)',
        'Atlantic/Stanley' => 'ଫକଲ୍ୟାଣ୍ଡ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ (ଷ୍ଟାନଲି)',
        'Australia/Adelaide' => 'ମଧ୍ୟ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ଆଡିଲେଡ୍‌)',
        'Australia/Brisbane' => 'ପୂର୍ବ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ବ୍ରିସବେନ୍‌)',
        'Australia/Broken_Hill' => 'ମଧ୍ୟ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ବ୍ରୋକେନ୍‌ ହିଲ୍‌)',
        'Australia/Darwin' => 'ମଧ୍ୟ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ଡାରୱିନ୍‌)',
        'Australia/Eucla' => 'ଅଷ୍ଟ୍ରେଲିୟ ମଧ୍ୟ ପଶ୍ଚିମ ସମୟ (ୟୁକଲା)',
        'Australia/Hobart' => 'ପୂର୍ବ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ହୋବାର୍ଟ୍‌)',
        'Australia/Lindeman' => 'ପୂର୍ବ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ଲିଣ୍ଡେମ୍ୟାନ୍‌)',
        'Australia/Lord_Howe' => 'ଲର୍ଡ ହୋୱେ ସମୟ',
        'Australia/Melbourne' => 'ପୂର୍ବ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ମେଲବୋର୍ଣ୍ଣ)',
        'Australia/Perth' => 'ପଶ୍ଚିମ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ପର୍ଥ୍‌)',
        'Australia/Sydney' => 'ପୂର୍ବ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ (ସିଡନୀ)',
        'Etc/GMT' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ',
        'Etc/UTC' => 'ସମନ୍ୱିତ ସାର୍ବଜନୀନ ସମୟ',
        'Europe/Amsterdam' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଆମଷ୍ଟରଡାମ୍)',
        'Europe/Andorra' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଆନଡୋରା)',
        'Europe/Astrakhan' => 'ସମାରା ସମୟ (ଆଷ୍ଟ୍ରାଖାନ୍)',
        'Europe/Athens' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଏଥେନ୍ସ)',
        'Europe/Belgrade' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ବେଲଗ୍ରେଡ୍‌)',
        'Europe/Berlin' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ବର୍ଲିନ୍)',
        'Europe/Bratislava' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ବ୍ରାଟିସଲାଭା)',
        'Europe/Brussels' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ବ୍ରସଲ୍ସ୍)',
        'Europe/Bucharest' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ବୁଚାରେଷ୍ଟ୍)',
        'Europe/Budapest' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ବୁଡାପେଷ୍ଟ୍)',
        'Europe/Busingen' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ବୁସିନଗେନ୍)',
        'Europe/Chisinau' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଚିସିନୌ)',
        'Europe/Copenhagen' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (କୋପେନହାଗେନ୍)',
        'Europe/Dublin' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଡବଲିନ୍)',
        'Europe/Gibraltar' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଜିବ୍ରାଲଟର୍‌)',
        'Europe/Guernsey' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଗୁଏରନସେ)',
        'Europe/Helsinki' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ହେଲସିନକି)',
        'Europe/Isle_of_Man' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଇସଲେ ଅଫ୍ ମେନ୍)',
        'Europe/Istanbul' => 'ତୁର୍କୀ ସମୟ (ଇସ୍ତାନବୁଲ)',
        'Europe/Jersey' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଜର୍ସି)',
        'Europe/Kaliningrad' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (କାଲିନିନଗ୍ରାଡ୍)',
        'Europe/Kiev' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (କିଏଭ୍)',
        'Europe/Kyiv' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (କିଏଭ୍)',
        'Europe/Kirov' => 'ମସ୍କୋ ସମୟ (କିରୋଭ)',
        'Europe/Lisbon' => 'ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଲିସବୋନ୍)',
        'Europe/Ljubljana' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଲଜୁବ୍ଲଜାନ୍)',
        'Europe/London' => 'ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ (ଲଣ୍ଡନ୍)',
        'Europe/Luxembourg' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଲକ୍ସମବର୍ଗ)',
        'Europe/Madrid' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ମାଡ୍ରିଡ୍)',
        'Europe/Malta' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ମାଲଟା)',
        'Europe/Mariehamn' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ମାରିଏହାମନ୍)',
        'Europe/Minsk' => 'ମସ୍କୋ ସମୟ (ମିନସ୍କ)',
        'Europe/Monaco' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ମୋନାକୋ)',
        'Europe/Moscow' => 'ମସ୍କୋ ସମୟ',
        'Europe/Oslo' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଓସଲୋ)',
        'Europe/Paris' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ପେରିସ୍)',
        'Europe/Podgorica' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ପୋଡଗୋରିକା)',
        'Europe/Prague' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ପ୍ରାଗ୍)',
        'Europe/Riga' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ରିଗା)',
        'Europe/Rome' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ରୋମ୍)',
        'Europe/Samara' => 'ସମାରା ସମୟ (ସାମାରା)',
        'Europe/San_Marino' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ସାନ୍ ମାରିନୋ)',
        'Europe/Sarajevo' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ସାରାଜେଭୋ)',
        'Europe/Saratov' => 'ସମାରା ସମୟ (ସାରାଟୋଭ୍)',
        'Europe/Simferopol' => 'ମସ୍କୋ ସମୟ (ସିମଫେରୋପୋଲ୍)',
        'Europe/Skopje' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ସ୍କୋପଜେ)',
        'Europe/Sofia' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ସୋଫିଆ)',
        'Europe/Stockholm' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଷ୍ଟକହୋମ୍‌)',
        'Europe/Tallinn' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଟାଲିନ୍ନ)',
        'Europe/Tirane' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଟିରାନେ)',
        'Europe/Ulyanovsk' => 'ସମାରା ସମୟ (ୟୁଲୟାନୋଭସ୍କ)',
        'Europe/Vaduz' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଭାଡୁଜ)',
        'Europe/Vatican' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଭାଟିକାନ୍)',
        'Europe/Vienna' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଭିଏନା)',
        'Europe/Vilnius' => 'ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ (ଭିଲନିଉସ୍)',
        'Europe/Volgograd' => 'ମସ୍କୋ ସମୟ (ଭୋଲଗୋଗ୍ରାଡ୍)',
        'Europe/Warsaw' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ୱାରସୱା)',
        'Europe/Zagreb' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଜାଗ୍ରେବ୍)',
        'Europe/Zurich' => 'କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ (ଜୁରିକ୍)',
        'Indian/Antananarivo' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (ଆଣ୍ଟାନାନାରିଭୋ)',
        'Indian/Chagos' => 'ଭାରତ ମାହାସାଗର ସମୟ (ଚାଗୋସ୍‌)',
        'Indian/Christmas' => 'ଖ୍ରୀଷ୍ଟମାସ ଦ୍ୱୀପ ସମୟ',
        'Indian/Cocos' => 'କୋକୋସ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ',
        'Indian/Comoro' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (କୋମୋରୋ)',
        'Indian/Kerguelen' => 'ଫ୍ରେଞ୍ଚ ଦକ୍ଷିଣ ଏବଂ ଆଣ୍ଟାର୍କାଟିକ୍‌ ସମୟ (କେରୁଗେଲେନ)',
        'Indian/Mahe' => 'ସେଚେଲ୍ଲେସ୍‌ ସମୟ (ମାହେ)',
        'Indian/Maldives' => 'ମାଳଦ୍ୱୀପ ସମୟ',
        'Indian/Mauritius' => 'ମୌରିସସ୍‌ ସମୟ',
        'Indian/Mayotte' => 'ପୂର୍ବ ଆଫ୍ରିକା ସମୟ (ମାୟୋଟେ)',
        'Indian/Reunion' => 'ରିୟୁନିଅନ୍‌ ସମୟ',
        'Pacific/Apia' => 'ଆପିଆ ସମୟ',
        'Pacific/Auckland' => 'ନ୍ୟୁଜିଲାଣ୍ଡ ସମୟ (ଅକଲାଣ୍ଡ)',
        'Pacific/Bougainville' => 'ପପୁଆ ନ୍ୟୁ ଗିନି ସମୟ (ବୌଗେନ୍‌ଭିଲ୍ଲେ)',
        'Pacific/Chatham' => 'ଚାଥାମ୍‌ ସମୟ',
        'Pacific/Easter' => 'ଇଷ୍ଟର୍‌ ଆଇଲ୍ୟାଣ୍ଡ ସମୟ',
        'Pacific/Efate' => 'ଭାନୁଆଟୁ ସମୟ (ଇଫେଟ୍‌)',
        'Pacific/Enderbury' => 'ଫିନିକ୍ସ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ (କ୍ୟାଣ୍ଟନ)',
        'Pacific/Kanton' => 'ଫିନିକ୍ସ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ (କ୍ୟାଣ୍ଟନ)',
        'Pacific/Fakaofo' => 'ଟୋକେଲାଉ ସମୟ (ଫାକାଓଫୋ)',
        'Pacific/Fiji' => 'ଫିଜି ସମୟ',
        'Pacific/Funafuti' => 'ତୁଭାଲୁ ସମୟ (ଫୁନାଫୁଟି)',
        'Pacific/Galapagos' => 'ଗାଲାପାଗୋସ୍ ସମୟ',
        'Pacific/Gambier' => 'ଗାମ୍ବିୟର୍ ସମୟ (ଗାମ୍ବିୟର୍‌)',
        'Pacific/Guadalcanal' => 'ସୋଲୋମନ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ (ଗୁଆଡାଲକାନାଲ)',
        'Pacific/Guam' => 'ଚାମୋରୋ ମାନକ ସମୟ (ଗୁଆମ)',
        'Pacific/Honolulu' => 'ହୱାଇ-ଆଲେଉଟିୟ ମାନାଙ୍କ ସମୟ (ହୋନୋଲୁଲୁ)',
        'Pacific/Kiritimati' => 'ଲାଇନ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ (କିରିତିମାଟି)',
        'Pacific/Kosrae' => 'କୋସରେଇ ସମୟ',
        'Pacific/Kwajalein' => 'ମାର୍ଶାଲ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ (କ୍ୱାଜାଲେଇନ୍)',
        'Pacific/Majuro' => 'ମାର୍ଶାଲ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ (ମାଜୁରୋ)',
        'Pacific/Marquesas' => 'ମାର୍କ୍ୱେସାସ୍‌ ସମୟ',
        'Pacific/Midway' => 'ସାମୋଆ ସମୟ (ମିଡ୍‌ୱେ)',
        'Pacific/Nauru' => 'ନାଉରୁ ସମୟ',
        'Pacific/Niue' => 'ନିୟୁ ସମୟ (ନିୟୂ)',
        'Pacific/Norfolk' => 'ନରଫୋକ୍‌ ଦ୍ୱୀପ ସମୟ',
        'Pacific/Noumea' => 'ନ୍ୟୁ କାଲେଡୋନିଆ ସମୟ (ନୌମିୟ)',
        'Pacific/Pago_Pago' => 'ସାମୋଆ ସମୟ (ପାଗୋ ପାଗୋ)',
        'Pacific/Palau' => 'ପାଲାଉ ସମୟ',
        'Pacific/Pitcairn' => 'ପିଟକେର୍ନ୍‌ ସମୟ (ପିଟକାରିନ୍‌)',
        'Pacific/Ponape' => 'ପୋନାପେ ସମୟ (ପୋହନପେଇ)',
        'Pacific/Pohnpei' => 'ପୋନାପେ ସମୟ (ପୋହନପେଇ)',
        'Pacific/Port_Moresby' => 'ପପୁଆ ନ୍ୟୁ ଗିନି ସମୟ (ପୋର୍ଟ୍‌ ମୋରେସବି)',
        'Pacific/Rarotonga' => 'କୁକ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ (ରାରୋଟୋଙ୍ଗା)',
        'Pacific/Saipan' => 'ଚାମୋରୋ ମାନକ ସମୟ (ସାଇପାନ୍)',
        'Pacific/Tahiti' => 'ତାହିତି ସମୟ',
        'Pacific/Tarawa' => 'ଗିଲବର୍ଟ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ (ତାରୱା)',
        'Pacific/Tongatapu' => 'ଟୋଙ୍ଗା ସମୟ (ଟୋଙ୍ଗାଟାପୁ)',
        'Pacific/Truk' => 'ଚୂକ୍‌ ସମୟ',
        'Pacific/Chuuk' => 'ଚୂକ୍‌ ସମୟ',
        'Pacific/Wake' => 'ୱେକ୍‌ ଦ୍ୱୀପ ସମୟ',
        'Pacific/Wallis' => 'ୱାଲିସ୍‌ ଏବଂ ଫୁଟୁନା ସମୟ',
    ],
    'Meta' => [],
];
