<?php

return [
    'Names' => [
        'af' => 'افریقی',
        'af_NA' => 'افریقی (نامیبیا)',
        'af_ZA' => 'افریقی (جنوبی افریقہ)',
        'ak' => 'اکان',
        'ak_GH' => 'اکان (گھانا)',
        'am' => 'امہاری',
        'am_ET' => 'امہاری (ایتھوپیا)',
        'ar' => 'عربی',
        'ar_001' => 'عربی (دنیا)',
        'ar_AE' => 'عربی (متحدہ عرب امارات)',
        'ar_BH' => 'عربی (بحرین)',
        'ar_DJ' => 'عربی (جبوتی)',
        'ar_DZ' => 'عربی (الجیریا)',
        'ar_EG' => 'عربی (مصر)',
        'ar_EH' => 'عربی (مغربی صحارا)',
        'ar_ER' => 'عربی (اریٹیریا)',
        'ar_IL' => 'عربی (اسرائیل)',
        'ar_IQ' => 'عربی (عراق)',
        'ar_JO' => 'عربی (اردن)',
        'ar_KM' => 'عربی (کوموروس)',
        'ar_KW' => 'عربی (کویت)',
        'ar_LB' => 'عربی (لبنان)',
        'ar_LY' => 'عربی (لیبیا)',
        'ar_MA' => 'عربی (مراکش)',
        'ar_MR' => 'عربی (موریطانیہ)',
        'ar_OM' => 'عربی (عمان)',
        'ar_PS' => 'عربی (فلسطینی خطے)',
        'ar_QA' => 'عربی (قطر)',
        'ar_SA' => 'عربی (سعودی عرب)',
        'ar_SD' => 'عربی (سوڈان)',
        'ar_SO' => 'عربی (صومالیہ)',
        'ar_SS' => 'عربی (جنوبی سوڈان)',
        'ar_SY' => 'عربی (شام)',
        'ar_TD' => 'عربی (چاڈ)',
        'ar_TN' => 'عربی (تونس)',
        'ar_YE' => 'عربی (یمن)',
        'as' => 'آسامی',
        'as_IN' => 'آسامی (بھارت)',
        'az' => 'آذربائیجانی',
        'az_AZ' => 'آذربائیجانی (آذربائیجان)',
        'az_Cyrl' => 'آذربائیجانی (سیریلک)',
        'az_Cyrl_AZ' => 'آذربائیجانی (سیریلک،آذربائیجان)',
        'az_Latn' => 'آذربائیجانی (لاطینی)',
        'az_Latn_AZ' => 'آذربائیجانی (لاطینی،آذربائیجان)',
        'ba' => 'باشکیر',
        'ba_RU' => 'باشکیر (روس)',
        'be' => 'بیلاروسی',
        'be_BY' => 'بیلاروسی (بیلاروس)',
        'bg' => 'بلغاری',
        'bg_BG' => 'بلغاری (بلغاریہ)',
        'bm' => 'بمبارا',
        'bm_ML' => 'بمبارا (مالی)',
        'bn' => 'بنگلہ',
        'bn_BD' => 'بنگلہ (بنگلہ دیش)',
        'bn_IN' => 'بنگلہ (بھارت)',
        'bo' => 'تبتی',
        'bo_CN' => 'تبتی (چین)',
        'bo_IN' => 'تبتی (بھارت)',
        'br' => 'بریٹن',
        'br_FR' => 'بریٹن (فرانس)',
        'bs' => 'بوسنیائی',
        'bs_BA' => 'بوسنیائی (بوسنیا اور ہرزیگووینا)',
        'bs_Cyrl' => 'بوسنیائی (سیریلک)',
        'bs_Cyrl_BA' => 'بوسنیائی (سیریلک،بوسنیا اور ہرزیگووینا)',
        'bs_Latn' => 'بوسنیائی (لاطینی)',
        'bs_Latn_BA' => 'بوسنیائی (لاطینی،بوسنیا اور ہرزیگووینا)',
        'ca' => 'کیٹالان',
        'ca_AD' => 'کیٹالان (انڈورا)',
        'ca_ES' => 'کیٹالان (ہسپانیہ)',
        'ca_FR' => 'کیٹالان (فرانس)',
        'ca_IT' => 'کیٹالان (اٹلی)',
        'ce' => 'چیچن',
        'ce_RU' => 'چیچن (روس)',
        'cs' => 'چیک',
        'cs_CZ' => 'چیک (چیکیا)',
        'cv' => 'چوواش',
        'cv_RU' => 'چوواش (روس)',
        'cy' => 'ویلش',
        'cy_GB' => 'ویلش (سلطنت متحدہ)',
        'da' => 'ڈینش',
        'da_DK' => 'ڈینش (ڈنمارک)',
        'da_GL' => 'ڈینش (گرین لینڈ)',
        'de' => 'جرمن',
        'de_AT' => 'جرمن (آسٹریا)',
        'de_BE' => 'جرمن (بیلجیم)',
        'de_CH' => 'جرمن (سوئٹزر لینڈ)',
        'de_DE' => 'جرمن (جرمنی)',
        'de_IT' => 'جرمن (اٹلی)',
        'de_LI' => 'جرمن (لیشٹنسٹائن)',
        'de_LU' => 'جرمن (لکسمبرگ)',
        'dz' => 'ژونگکھا',
        'dz_BT' => 'ژونگکھا (بھوٹان)',
        'ee' => 'ایو',
        'ee_GH' => 'ایو (گھانا)',
        'ee_TG' => 'ایو (ٹوگو)',
        'el' => 'یونانی',
        'el_CY' => 'یونانی (قبرص)',
        'el_GR' => 'یونانی (یونان)',
        'en' => 'انگریزی',
        'en_001' => 'انگریزی (دنیا)',
        'en_150' => 'انگریزی (یورپ)',
        'en_AE' => 'انگریزی (متحدہ عرب امارات)',
        'en_AG' => 'انگریزی (انٹیگوا اور باربودا)',
        'en_AI' => 'انگریزی (انگوئیلا)',
        'en_AS' => 'انگریزی (امریکی ساموآ)',
        'en_AT' => 'انگریزی (آسٹریا)',
        'en_AU' => 'انگریزی (آسٹریلیا)',
        'en_BB' => 'انگریزی (بارباڈوس)',
        'en_BE' => 'انگریزی (بیلجیم)',
        'en_BI' => 'انگریزی (برونڈی)',
        'en_BM' => 'انگریزی (برمودا)',
        'en_BS' => 'انگریزی (بہاماس)',
        'en_BW' => 'انگریزی (بوتسوانا)',
        'en_BZ' => 'انگریزی (بیلائز)',
        'en_CA' => 'انگریزی (کینیڈا)',
        'en_CC' => 'انگریزی (کوکوس [کیلنگ] جزائر)',
        'en_CH' => 'انگریزی (سوئٹزر لینڈ)',
        'en_CK' => 'انگریزی (کک آئلینڈز)',
        'en_CM' => 'انگریزی (کیمرون)',
        'en_CX' => 'انگریزی (جزیرہ کرسمس)',
        'en_CY' => 'انگریزی (قبرص)',
        'en_CZ' => 'انگریزی (چیکیا)',
        'en_DE' => 'انگریزی (جرمنی)',
        'en_DK' => 'انگریزی (ڈنمارک)',
        'en_DM' => 'انگریزی (ڈومنیکا)',
        'en_EE' => 'انگریزی (اسٹونیا)',
        'en_ER' => 'انگریزی (اریٹیریا)',
        'en_ES' => 'انگریزی (ہسپانیہ)',
        'en_FI' => 'انگریزی (فن لینڈ)',
        'en_FJ' => 'انگریزی (فجی)',
        'en_FK' => 'انگریزی (فاکلینڈ جزائر)',
        'en_FM' => 'انگریزی (مائکرونیشیا)',
        'en_FR' => 'انگریزی (فرانس)',
        'en_GB' => 'انگریزی (سلطنت متحدہ)',
        'en_GD' => 'انگریزی (گریناڈا)',
        'en_GE' => 'انگریزی (جارجیا)',
        'en_GG' => 'انگریزی (گوئرنسی)',
        'en_GH' => 'انگریزی (گھانا)',
        'en_GI' => 'انگریزی (جبل الطارق)',
        'en_GM' => 'انگریزی (گیمبیا)',
        'en_GS' => 'انگریزی (جنوبی جارجیا اور جنوبی سینڈوچ جزائر)',
        'en_GU' => 'انگریزی (گوام)',
        'en_GY' => 'انگریزی (گیانا)',
        'en_HK' => 'انگریزی (ہانگ کانگ SAR چین)',
        'en_HU' => 'انگریزی (ہنگری)',
        'en_ID' => 'انگریزی (انڈونیشیا)',
        'en_IE' => 'انگریزی (آئرلینڈ)',
        'en_IL' => 'انگریزی (اسرائیل)',
        'en_IM' => 'انگریزی (آئل آف مین)',
        'en_IN' => 'انگریزی (بھارت)',
        'en_IO' => 'انگریزی (برطانوی بحر ہند کا علاقہ)',
        'en_IT' => 'انگریزی (اٹلی)',
        'en_JE' => 'انگریزی (جرسی)',
        'en_JM' => 'انگریزی (جمائیکا)',
        'en_JP' => 'انگریزی (جاپان)',
        'en_KE' => 'انگریزی (کینیا)',
        'en_KI' => 'انگریزی (کریباتی)',
        'en_KN' => 'انگریزی (سینٹ کٹس اور نیویس)',
        'en_KY' => 'انگریزی (کیمین آئلینڈز)',
        'en_LC' => 'انگریزی (سینٹ لوسیا)',
        'en_LR' => 'انگریزی (لائبیریا)',
        'en_LS' => 'انگریزی (لیسوتھو)',
        'en_LT' => 'انگریزی (لیتھونیا)',
        'en_LV' => 'انگریزی (لٹویا)',
        'en_MG' => 'انگریزی (مڈغاسکر)',
        'en_MH' => 'انگریزی (مارشل آئلینڈز)',
        'en_MO' => 'انگریزی (مکاؤ SAR چین)',
        'en_MP' => 'انگریزی (شمالی ماریانا آئلینڈز)',
        'en_MS' => 'انگریزی (مونٹسیراٹ)',
        'en_MT' => 'انگریزی (مالٹا)',
        'en_MU' => 'انگریزی (ماریشس)',
        'en_MV' => 'انگریزی (مالدیپ)',
        'en_MW' => 'انگریزی (ملاوی)',
        'en_MY' => 'انگریزی (ملائشیا)',
        'en_NA' => 'انگریزی (نامیبیا)',
        'en_NF' => 'انگریزی (نارفوک آئلینڈ)',
        'en_NG' => 'انگریزی (نائجیریا)',
        'en_NL' => 'انگریزی (نیدر لینڈز)',
        'en_NO' => 'انگریزی (ناروے)',
        'en_NR' => 'انگریزی (نؤرو)',
        'en_NU' => 'انگریزی (نیئو)',
        'en_NZ' => 'انگریزی (نیوزی لینڈ)',
        'en_PG' => 'انگریزی (پاپوآ نیو گنی)',
        'en_PH' => 'انگریزی (فلپائن)',
        'en_PK' => 'انگریزی (پاکستان)',
        'en_PL' => 'انگریزی (پولینڈ)',
        'en_PN' => 'انگریزی (پٹکائرن جزائر)',
        'en_PR' => 'انگریزی (پیورٹو ریکو)',
        'en_PT' => 'انگریزی (پرتگال)',
        'en_PW' => 'انگریزی (پلاؤ)',
        'en_RO' => 'انگریزی (رومانیہ)',
        'en_RW' => 'انگریزی (روانڈا)',
        'en_SB' => 'انگریزی (سولومن آئلینڈز)',
        'en_SC' => 'انگریزی (سشلیز)',
        'en_SD' => 'انگریزی (سوڈان)',
        'en_SE' => 'انگریزی (سویڈن)',
        'en_SG' => 'انگریزی (سنگاپور)',
        'en_SH' => 'انگریزی (سینٹ ہیلینا)',
        'en_SI' => 'انگریزی (سلووینیا)',
        'en_SK' => 'انگریزی (سلوواکیہ)',
        'en_SL' => 'انگریزی (سیرالیون)',
        'en_SS' => 'انگریزی (جنوبی سوڈان)',
        'en_SX' => 'انگریزی (سنٹ مارٹن)',
        'en_SZ' => 'انگریزی (سواتنی)',
        'en_TC' => 'انگریزی (ٹرکس اور کیکوس جزائر)',
        'en_TK' => 'انگریزی (ٹوکیلاؤ)',
        'en_TO' => 'انگریزی (ٹونگا)',
        'en_TT' => 'انگریزی (ترینیداد اور ٹوباگو)',
        'en_TV' => 'انگریزی (ٹووالو)',
        'en_TZ' => 'انگریزی (تنزانیہ)',
        'en_UA' => 'انگریزی (یوکرین)',
        'en_UG' => 'انگریزی (یوگنڈا)',
        'en_UM' => 'انگریزی (امریکہ سے باہر کے چھوٹے جزائز)',
        'en_US' => 'انگریزی (ریاست ہائے متحدہ امریکہ)',
        'en_VC' => 'انگریزی (سینٹ ونسنٹ اور گرینیڈائنز)',
        'en_VG' => 'انگریزی (برٹش ورجن آئلینڈز)',
        'en_VI' => 'انگریزی (امریکی ورجن آئلینڈز)',
        'en_VU' => 'انگریزی (وینوآٹو)',
        'en_WS' => 'انگریزی (ساموآ)',
        'en_ZA' => 'انگریزی (جنوبی افریقہ)',
        'en_ZM' => 'انگریزی (زامبیا)',
        'en_ZW' => 'انگریزی (زمبابوے)',
        'eo' => 'ایسپرانٹو',
        'eo_001' => 'ایسپرانٹو (دنیا)',
        'es' => 'ہسپانوی',
        'es_419' => 'ہسپانوی (لاطینی امریکہ)',
        'es_AR' => 'ہسپانوی (ارجنٹینا)',
        'es_BO' => 'ہسپانوی (بولیویا)',
        'es_BR' => 'ہسپانوی (برازیل)',
        'es_BZ' => 'ہسپانوی (بیلائز)',
        'es_CL' => 'ہسپانوی (چلی)',
        'es_CO' => 'ہسپانوی (کولمبیا)',
        'es_CR' => 'ہسپانوی (کوسٹا ریکا)',
        'es_CU' => 'ہسپانوی (کیوبا)',
        'es_DO' => 'ہسپانوی (جمہوریہ ڈومينيکن)',
        'es_EC' => 'ہسپانوی (ایکواڈور)',
        'es_ES' => 'ہسپانوی (ہسپانیہ)',
        'es_GQ' => 'ہسپانوی (استوائی گیانا)',
        'es_GT' => 'ہسپانوی (گواٹے مالا)',
        'es_HN' => 'ہسپانوی (ہونڈاروس)',
        'es_MX' => 'ہسپانوی (میکسیکو)',
        'es_NI' => 'ہسپانوی (نکاراگووا)',
        'es_PA' => 'ہسپانوی (پانامہ)',
        'es_PE' => 'ہسپانوی (پیرو)',
        'es_PH' => 'ہسپانوی (فلپائن)',
        'es_PR' => 'ہسپانوی (پیورٹو ریکو)',
        'es_PY' => 'ہسپانوی (پیراگوئے)',
        'es_SV' => 'ہسپانوی (ال سلواڈور)',
        'es_US' => 'ہسپانوی (ریاست ہائے متحدہ امریکہ)',
        'es_UY' => 'ہسپانوی (یوروگوئے)',
        'es_VE' => 'ہسپانوی (وینزوئیلا)',
        'et' => 'اسٹونین',
        'et_EE' => 'اسٹونین (اسٹونیا)',
        'eu' => 'باسکی',
        'eu_ES' => 'باسکی (ہسپانیہ)',
        'fa' => 'فارسی',
        'fa_AF' => 'فارسی (افغانستان)',
        'fa_IR' => 'فارسی (ایران)',
        'ff' => 'فولہ',
        'ff_Adlm' => 'فولہ (ایڈلم)',
        'ff_Adlm_BF' => 'فولہ (ایڈلم،برکینا فاسو)',
        'ff_Adlm_CM' => 'فولہ (ایڈلم،کیمرون)',
        'ff_Adlm_GH' => 'فولہ (ایڈلم،گھانا)',
        'ff_Adlm_GM' => 'فولہ (ایڈلم،گیمبیا)',
        'ff_Adlm_GN' => 'فولہ (ایڈلم،گنی)',
        'ff_Adlm_GW' => 'فولہ (ایڈلم،گنی بساؤ)',
        'ff_Adlm_LR' => 'فولہ (ایڈلم،لائبیریا)',
        'ff_Adlm_MR' => 'فولہ (ایڈلم،موریطانیہ)',
        'ff_Adlm_NE' => 'فولہ (ایڈلم،نائجر)',
        'ff_Adlm_NG' => 'فولہ (ایڈلم،نائجیریا)',
        'ff_Adlm_SL' => 'فولہ (ایڈلم،سیرالیون)',
        'ff_Adlm_SN' => 'فولہ (ایڈلم،سینیگل)',
        'ff_CM' => 'فولہ (کیمرون)',
        'ff_GN' => 'فولہ (گنی)',
        'ff_Latn' => 'فولہ (لاطینی)',
        'ff_Latn_BF' => 'فولہ (لاطینی،برکینا فاسو)',
        'ff_Latn_CM' => 'فولہ (لاطینی،کیمرون)',
        'ff_Latn_GH' => 'فولہ (لاطینی،گھانا)',
        'ff_Latn_GM' => 'فولہ (لاطینی،گیمبیا)',
        'ff_Latn_GN' => 'فولہ (لاطینی،گنی)',
        'ff_Latn_GW' => 'فولہ (لاطینی،گنی بساؤ)',
        'ff_Latn_LR' => 'فولہ (لاطینی،لائبیریا)',
        'ff_Latn_MR' => 'فولہ (لاطینی،موریطانیہ)',
        'ff_Latn_NE' => 'فولہ (لاطینی،نائجر)',
        'ff_Latn_NG' => 'فولہ (لاطینی،نائجیریا)',
        'ff_Latn_SL' => 'فولہ (لاطینی،سیرالیون)',
        'ff_Latn_SN' => 'فولہ (لاطینی،سینیگل)',
        'ff_MR' => 'فولہ (موریطانیہ)',
        'ff_SN' => 'فولہ (سینیگل)',
        'fi' => 'فینیش',
        'fi_FI' => 'فینیش (فن لینڈ)',
        'fo' => 'فیروئیز',
        'fo_DK' => 'فیروئیز (ڈنمارک)',
        'fo_FO' => 'فیروئیز (جزائر فارو)',
        'fr' => 'فرانسیسی',
        'fr_BE' => 'فرانسیسی (بیلجیم)',
        'fr_BF' => 'فرانسیسی (برکینا فاسو)',
        'fr_BI' => 'فرانسیسی (برونڈی)',
        'fr_BJ' => 'فرانسیسی (بینن)',
        'fr_BL' => 'فرانسیسی (سینٹ برتھلیمی)',
        'fr_CA' => 'فرانسیسی (کینیڈا)',
        'fr_CD' => 'فرانسیسی (کانگو - کنشاسا)',
        'fr_CF' => 'فرانسیسی (وسط افریقی جمہوریہ)',
        'fr_CG' => 'فرانسیسی (کانگو - برازاویلے)',
        'fr_CH' => 'فرانسیسی (سوئٹزر لینڈ)',
        'fr_CI' => 'فرانسیسی (کوٹ ڈی آئیوری)',
        'fr_CM' => 'فرانسیسی (کیمرون)',
        'fr_DJ' => 'فرانسیسی (جبوتی)',
        'fr_DZ' => 'فرانسیسی (الجیریا)',
        'fr_FR' => 'فرانسیسی (فرانس)',
        'fr_GA' => 'فرانسیسی (گیبون)',
        'fr_GF' => 'فرانسیسی (فرینچ گیانا)',
        'fr_GN' => 'فرانسیسی (گنی)',
        'fr_GP' => 'فرانسیسی (گواڈیلوپ)',
        'fr_GQ' => 'فرانسیسی (استوائی گیانا)',
        'fr_HT' => 'فرانسیسی (ہیٹی)',
        'fr_KM' => 'فرانسیسی (کوموروس)',
        'fr_LU' => 'فرانسیسی (لکسمبرگ)',
        'fr_MA' => 'فرانسیسی (مراکش)',
        'fr_MC' => 'فرانسیسی (موناکو)',
        'fr_MF' => 'فرانسیسی (سینٹ مارٹن)',
        'fr_MG' => 'فرانسیسی (مڈغاسکر)',
        'fr_ML' => 'فرانسیسی (مالی)',
        'fr_MQ' => 'فرانسیسی (مارٹینک)',
        'fr_MR' => 'فرانسیسی (موریطانیہ)',
        'fr_MU' => 'فرانسیسی (ماریشس)',
        'fr_NC' => 'فرانسیسی (نیو کلیڈونیا)',
        'fr_NE' => 'فرانسیسی (نائجر)',
        'fr_PF' => 'فرانسیسی (فرانسیسی پولینیشیا)',
        'fr_PM' => 'فرانسیسی (سینٹ پیئر اور میکلیئون)',
        'fr_RE' => 'فرانسیسی (ری یونین)',
        'fr_RW' => 'فرانسیسی (روانڈا)',
        'fr_SC' => 'فرانسیسی (سشلیز)',
        'fr_SN' => 'فرانسیسی (سینیگل)',
        'fr_SY' => 'فرانسیسی (شام)',
        'fr_TD' => 'فرانسیسی (چاڈ)',
        'fr_TG' => 'فرانسیسی (ٹوگو)',
        'fr_TN' => 'فرانسیسی (تونس)',
        'fr_VU' => 'فرانسیسی (وینوآٹو)',
        'fr_WF' => 'فرانسیسی (ویلیز اور فیوٹیونا)',
        'fr_YT' => 'فرانسیسی (مایوٹ)',
        'fy' => 'مغربی فریسیئن',
        'fy_NL' => 'مغربی فریسیئن (نیدر لینڈز)',
        'ga' => 'آئرش',
        'ga_GB' => 'آئرش (سلطنت متحدہ)',
        'ga_IE' => 'آئرش (آئرلینڈ)',
        'gd' => 'سکاٹش گیلک',
        'gd_GB' => 'سکاٹش گیلک (سلطنت متحدہ)',
        'gl' => 'گالیشیائی',
        'gl_ES' => 'گالیشیائی (ہسپانیہ)',
        'gu' => 'گجراتی',
        'gu_IN' => 'گجراتی (بھارت)',
        'gv' => 'مینکس',
        'gv_IM' => 'مینکس (آئل آف مین)',
        'ha' => 'ہؤسا',
        'ha_GH' => 'ہؤسا (گھانا)',
        'ha_NE' => 'ہؤسا (نائجر)',
        'ha_NG' => 'ہؤسا (نائجیریا)',
        'he' => 'عبرانی',
        'he_IL' => 'عبرانی (اسرائیل)',
        'hi' => 'ہندی',
        'hi_IN' => 'ہندی (بھارت)',
        'hi_Latn' => 'ہندی (لاطینی)',
        'hi_Latn_IN' => 'ہندی (لاطینی،بھارت)',
        'hr' => 'کراتی',
        'hr_BA' => 'کراتی (بوسنیا اور ہرزیگووینا)',
        'hr_HR' => 'کراتی (کروشیا)',
        'hu' => 'ہنگیرین',
        'hu_HU' => 'ہنگیرین (ہنگری)',
        'hy' => 'آرمینیائی',
        'hy_AM' => 'آرمینیائی (آرمینیا)',
        'ia' => 'بین لسانیات',
        'ia_001' => 'بین لسانیات (دنیا)',
        'id' => 'انڈونیثیائی',
        'id_ID' => 'انڈونیثیائی (انڈونیشیا)',
        'ie' => 'غربی',
        'ie_EE' => 'غربی (اسٹونیا)',
        'ig' => 'اِگبو',
        'ig_NG' => 'اِگبو (نائجیریا)',
        'ii' => 'سچوان ای',
        'ii_CN' => 'سچوان ای (چین)',
        'is' => 'آئس لینڈک',
        'is_IS' => 'آئس لینڈک (آئس لینڈ)',
        'it' => 'اطالوی',
        'it_CH' => 'اطالوی (سوئٹزر لینڈ)',
        'it_IT' => 'اطالوی (اٹلی)',
        'it_SM' => 'اطالوی (سان مارینو)',
        'it_VA' => 'اطالوی (ویٹیکن سٹی)',
        'ja' => 'جاپانی',
        'ja_JP' => 'جاپانی (جاپان)',
        'jv' => 'جاوی',
        'jv_ID' => 'جاوی (انڈونیشیا)',
        'ka' => 'جارجیائی',
        'ka_GE' => 'جارجیائی (جارجیا)',
        'ki' => 'کیکویو',
        'ki_KE' => 'کیکویو (کینیا)',
        'kk' => 'قزاخ',
        'kk_Arab' => 'قزاخ (عربی)',
        'kk_Arab_CN' => 'قزاخ (عربی،چین)',
        'kk_Cyrl' => 'قزاخ (سیریلک)',
        'kk_Cyrl_KZ' => 'قزاخ (سیریلک،قزاخستان)',
        'kk_KZ' => 'قزاخ (قزاخستان)',
        'kl' => 'کالاليست',
        'kl_GL' => 'کالاليست (گرین لینڈ)',
        'km' => 'خمیر',
        'km_KH' => 'خمیر (کمبوڈیا)',
        'kn' => 'کنّاڈا',
        'kn_IN' => 'کنّاڈا (بھارت)',
        'ko' => 'کوریائی',
        'ko_CN' => 'کوریائی (چین)',
        'ko_KP' => 'کوریائی (شمالی کوریا)',
        'ko_KR' => 'کوریائی (جنوبی کوریا)',
        'ks' => 'کشمیری',
        'ks_Arab' => 'کشمیری (عربی)',
        'ks_Arab_IN' => 'کشمیری (عربی،بھارت)',
        'ks_Deva' => 'کشمیری (دیوناگری)',
        'ks_Deva_IN' => 'کشمیری (دیوناگری،بھارت)',
        'ks_IN' => 'کشمیری (بھارت)',
        'ku' => 'کردی',
        'ku_Latn' => 'کردی (لاطینی)',
        'ku_Latn_IQ' => 'کردی (لاطینی،عراق)',
        'ku_Latn_SY' => 'کردی (لاطینی،شام)',
        'ku_Latn_TR' => 'کردی (لاطینی،ترکیہ)',
        'ku_SY' => 'کردی (شام)',
        'ku_TR' => 'کردی (ترکیہ)',
        'kw' => 'کورنش',
        'kw_GB' => 'کورنش (سلطنت متحدہ)',
        'ky' => 'کرغیزی',
        'ky_KG' => 'کرغیزی (کرغزستان)',
        'lb' => 'لکسمبرگیش',
        'lb_LU' => 'لکسمبرگیش (لکسمبرگ)',
        'lg' => 'گینڈا',
        'lg_UG' => 'گینڈا (یوگنڈا)',
        'ln' => 'لِنگَلا',
        'ln_AO' => 'لِنگَلا (انگولا)',
        'ln_CD' => 'لِنگَلا (کانگو - کنشاسا)',
        'ln_CF' => 'لِنگَلا (وسط افریقی جمہوریہ)',
        'ln_CG' => 'لِنگَلا (کانگو - برازاویلے)',
        'lo' => 'لاؤ',
        'lo_LA' => 'لاؤ (لاؤس)',
        'lt' => 'لیتھوینین',
        'lt_LT' => 'لیتھوینین (لیتھونیا)',
        'lu' => 'لبا-کاتانجا',
        'lu_CD' => 'لبا-کاتانجا (کانگو - کنشاسا)',
        'lv' => 'لیٹوین',
        'lv_LV' => 'لیٹوین (لٹویا)',
        'mg' => 'ملاگاسی',
        'mg_MG' => 'ملاگاسی (مڈغاسکر)',
        'mi' => 'ماؤری',
        'mi_NZ' => 'ماؤری (نیوزی لینڈ)',
        'mk' => 'مقدونیائی',
        'mk_MK' => 'مقدونیائی (شمالی مقدونیہ)',
        'ml' => 'ملیالم',
        'ml_IN' => 'ملیالم (بھارت)',
        'mn' => 'منگولین',
        'mn_MN' => 'منگولین (منگولیا)',
        'mr' => 'مراٹھی',
        'mr_IN' => 'مراٹھی (بھارت)',
        'ms' => 'مالے',
        'ms_BN' => 'مالے (برونائی)',
        'ms_ID' => 'مالے (انڈونیشیا)',
        'ms_MY' => 'مالے (ملائشیا)',
        'ms_SG' => 'مالے (سنگاپور)',
        'mt' => 'مالٹی',
        'mt_MT' => 'مالٹی (مالٹا)',
        'my' => 'برمی',
        'my_MM' => 'برمی (میانمار [برما])',
        'nb' => 'نارویجین بوکمل',
        'nb_NO' => 'نارویجین بوکمل (ناروے)',
        'nb_SJ' => 'نارویجین بوکمل (سوالبرڈ اور جان ماین)',
        'nd' => 'شمالی دبیل',
        'nd_ZW' => 'شمالی دبیل (زمبابوے)',
        'ne' => 'نیپالی',
        'ne_IN' => 'نیپالی (بھارت)',
        'ne_NP' => 'نیپالی (نیپال)',
        'nl' => 'ڈچ',
        'nl_AW' => 'ڈچ (اروبا)',
        'nl_BE' => 'ڈچ (بیلجیم)',
        'nl_BQ' => 'ڈچ (کریبیائی نیدرلینڈز)',
        'nl_CW' => 'ڈچ (کیوراکاؤ)',
        'nl_NL' => 'ڈچ (نیدر لینڈز)',
        'nl_SR' => 'ڈچ (سورینام)',
        'nl_SX' => 'ڈچ (سنٹ مارٹن)',
        'nn' => 'نارویجین نینورسک',
        'nn_NO' => 'نارویجین نینورسک (ناروے)',
        'no' => 'نارویجین',
        'no_NO' => 'نارویجین (ناروے)',
        'oc' => 'آکسیٹان',
        'oc_ES' => 'آکسیٹان (ہسپانیہ)',
        'oc_FR' => 'آکسیٹان (فرانس)',
        'om' => 'اورومو',
        'om_ET' => 'اورومو (ایتھوپیا)',
        'om_KE' => 'اورومو (کینیا)',
        'or' => 'اڑیہ',
        'or_IN' => 'اڑیہ (بھارت)',
        'os' => 'اوسیٹک',
        'os_GE' => 'اوسیٹک (جارجیا)',
        'os_RU' => 'اوسیٹک (روس)',
        'pa' => 'پنجابی',
        'pa_Arab' => 'پنجابی (عربی)',
        'pa_Arab_PK' => 'پنجابی (عربی،پاکستان)',
        'pa_Guru' => 'پنجابی (گرمکھی)',
        'pa_Guru_IN' => 'پنجابی (گرمکھی،بھارت)',
        'pa_IN' => 'پنجابی (بھارت)',
        'pa_PK' => 'پنجابی (پاکستان)',
        'pl' => 'پولش',
        'pl_PL' => 'پولش (پولینڈ)',
        'ps' => 'پشتو',
        'ps_AF' => 'پشتو (افغانستان)',
        'ps_PK' => 'پشتو (پاکستان)',
        'pt' => 'پُرتگالی',
        'pt_AO' => 'پُرتگالی (انگولا)',
        'pt_BR' => 'پُرتگالی (برازیل)',
        'pt_CH' => 'پُرتگالی (سوئٹزر لینڈ)',
        'pt_CV' => 'پُرتگالی (کیپ ورڈی)',
        'pt_GQ' => 'پُرتگالی (استوائی گیانا)',
        'pt_GW' => 'پُرتگالی (گنی بساؤ)',
        'pt_LU' => 'پُرتگالی (لکسمبرگ)',
        'pt_MO' => 'پُرتگالی (مکاؤ SAR چین)',
        'pt_MZ' => 'پُرتگالی (موزمبیق)',
        'pt_PT' => 'پُرتگالی (پرتگال)',
        'pt_ST' => 'پُرتگالی (ساؤ ٹومے اور پرنسپے)',
        'pt_TL' => 'پُرتگالی (تیمور لیسٹ)',
        'qu' => 'کویچوآ',
        'qu_BO' => 'کویچوآ (بولیویا)',
        'qu_EC' => 'کویچوآ (ایکواڈور)',
        'qu_PE' => 'کویچوآ (پیرو)',
        'rm' => 'رومانش',
        'rm_CH' => 'رومانش (سوئٹزر لینڈ)',
        'rn' => 'رونڈی',
        'rn_BI' => 'رونڈی (برونڈی)',
        'ro' => 'رومینین',
        'ro_MD' => 'رومینین (مالدووا)',
        'ro_RO' => 'رومینین (رومانیہ)',
        'ru' => 'روسی',
        'ru_BY' => 'روسی (بیلاروس)',
        'ru_KG' => 'روسی (کرغزستان)',
        'ru_KZ' => 'روسی (قزاخستان)',
        'ru_MD' => 'روسی (مالدووا)',
        'ru_RU' => 'روسی (روس)',
        'ru_UA' => 'روسی (یوکرین)',
        'rw' => 'کینیاروانڈا',
        'rw_RW' => 'کینیاروانڈا (روانڈا)',
        'sa' => 'سنسکرت',
        'sa_IN' => 'سنسکرت (بھارت)',
        'sc' => 'سردینین',
        'sc_IT' => 'سردینین (اٹلی)',
        'sd' => 'سندھی',
        'sd_Arab' => 'سندھی (عربی)',
        'sd_Arab_PK' => 'سندھی (عربی،پاکستان)',
        'sd_Deva' => 'سندھی (دیوناگری)',
        'sd_Deva_IN' => 'سندھی (دیوناگری،بھارت)',
        'sd_IN' => 'سندھی (بھارت)',
        'sd_PK' => 'سندھی (پاکستان)',
        'se' => 'شمالی سامی',
        'se_FI' => 'شمالی سامی (فن لینڈ)',
        'se_NO' => 'شمالی سامی (ناروے)',
        'se_SE' => 'شمالی سامی (سویڈن)',
        'sg' => 'ساںغو',
        'sg_CF' => 'ساںغو (وسط افریقی جمہوریہ)',
        'sh' => 'سربو-کروئیشین',
        'sh_BA' => 'سربو-کروئیشین (بوسنیا اور ہرزیگووینا)',
        'si' => 'سنہالا',
        'si_LK' => 'سنہالا (سری لنکا)',
        'sk' => 'سلوواک',
        'sk_SK' => 'سلوواک (سلوواکیہ)',
        'sl' => 'سلووینیائی',
        'sl_SI' => 'سلووینیائی (سلووینیا)',
        'sn' => 'شونا',
        'sn_ZW' => 'شونا (زمبابوے)',
        'so' => 'صومالی',
        'so_DJ' => 'صومالی (جبوتی)',
        'so_ET' => 'صومالی (ایتھوپیا)',
        'so_KE' => 'صومالی (کینیا)',
        'so_SO' => 'صومالی (صومالیہ)',
        'sq' => 'البانی',
        'sq_AL' => 'البانی (البانیہ)',
        'sq_MK' => 'البانی (شمالی مقدونیہ)',
        'sr' => 'سربین',
        'sr_BA' => 'سربین (بوسنیا اور ہرزیگووینا)',
        'sr_Cyrl' => 'سربین (سیریلک)',
        'sr_Cyrl_BA' => 'سربین (سیریلک،بوسنیا اور ہرزیگووینا)',
        'sr_Cyrl_ME' => 'سربین (سیریلک،مونٹے نیگرو)',
        'sr_Cyrl_RS' => 'سربین (سیریلک،سربیا)',
        'sr_Latn' => 'سربین (لاطینی)',
        'sr_Latn_BA' => 'سربین (لاطینی،بوسنیا اور ہرزیگووینا)',
        'sr_Latn_ME' => 'سربین (لاطینی،مونٹے نیگرو)',
        'sr_Latn_RS' => 'سربین (لاطینی،سربیا)',
        'sr_ME' => 'سربین (مونٹے نیگرو)',
        'sr_RS' => 'سربین (سربیا)',
        'st' => 'جنوبی سوتھو',
        'st_LS' => 'جنوبی سوتھو (لیسوتھو)',
        'st_ZA' => 'جنوبی سوتھو (جنوبی افریقہ)',
        'su' => 'سنڈانیز',
        'su_ID' => 'سنڈانیز (انڈونیشیا)',
        'su_Latn' => 'سنڈانیز (لاطینی)',
        'su_Latn_ID' => 'سنڈانیز (لاطینی،انڈونیشیا)',
        'sv' => 'سویڈش',
        'sv_AX' => 'سویڈش (آلینڈ آئلینڈز)',
        'sv_FI' => 'سویڈش (فن لینڈ)',
        'sv_SE' => 'سویڈش (سویڈن)',
        'sw' => 'سواحلی',
        'sw_CD' => 'سواحلی (کانگو - کنشاسا)',
        'sw_KE' => 'سواحلی (کینیا)',
        'sw_TZ' => 'سواحلی (تنزانیہ)',
        'sw_UG' => 'سواحلی (یوگنڈا)',
        'ta' => 'تمل',
        'ta_IN' => 'تمل (بھارت)',
        'ta_LK' => 'تمل (سری لنکا)',
        'ta_MY' => 'تمل (ملائشیا)',
        'ta_SG' => 'تمل (سنگاپور)',
        'te' => 'تیلگو',
        'te_IN' => 'تیلگو (بھارت)',
        'tg' => 'تاجک',
        'tg_TJ' => 'تاجک (تاجکستان)',
        'th' => 'تھائی',
        'th_TH' => 'تھائی (تھائی لینڈ)',
        'ti' => 'ٹگرینیا',
        'ti_ER' => 'ٹگرینیا (اریٹیریا)',
        'ti_ET' => 'ٹگرینیا (ایتھوپیا)',
        'tk' => 'ترکمان',
        'tk_TM' => 'ترکمان (ترکمانستان)',
        'tl' => 'ٹیگا لوگ',
        'tl_PH' => 'ٹیگا لوگ (فلپائن)',
        'tn' => 'سوانا',
        'tn_BW' => 'سوانا (بوتسوانا)',
        'tn_ZA' => 'سوانا (جنوبی افریقہ)',
        'to' => 'ٹونگن',
        'to_TO' => 'ٹونگن (ٹونگا)',
        'tr' => 'ترکی',
        'tr_CY' => 'ترکی (قبرص)',
        'tr_TR' => 'ترکی (ترکیہ)',
        'tt' => 'تاتار',
        'tt_RU' => 'تاتار (روس)',
        'ug' => 'یوئگہر',
        'ug_CN' => 'یوئگہر (چین)',
        'uk' => 'یوکرینیائی',
        'uk_UA' => 'یوکرینیائی (یوکرین)',
        'ur' => 'اردو',
        'ur_IN' => 'اردو (بھارت)',
        'ur_PK' => 'اردو (پاکستان)',
        'uz' => 'ازبیک',
        'uz_AF' => 'ازبیک (افغانستان)',
        'uz_Arab' => 'ازبیک (عربی)',
        'uz_Arab_AF' => 'ازبیک (عربی،افغانستان)',
        'uz_Cyrl' => 'ازبیک (سیریلک)',
        'uz_Cyrl_UZ' => 'ازبیک (سیریلک،ازبکستان)',
        'uz_Latn' => 'ازبیک (لاطینی)',
        'uz_Latn_UZ' => 'ازبیک (لاطینی،ازبکستان)',
        'uz_UZ' => 'ازبیک (ازبکستان)',
        'vi' => 'ویتنامی',
        'vi_VN' => 'ویتنامی (ویتنام)',
        'wo' => 'وولوف',
        'wo_SN' => 'وولوف (سینیگل)',
        'xh' => 'ژوسا',
        'xh_ZA' => 'ژوسا (جنوبی افریقہ)',
        'yi' => 'یدش',
        'yi_UA' => 'یدش (یوکرین)',
        'yo' => 'یوروبا',
        'yo_BJ' => 'یوروبا (بینن)',
        'yo_NG' => 'یوروبا (نائجیریا)',
        'za' => 'ژوانگی',
        'za_CN' => 'ژوانگی (چین)',
        'zh' => 'چینی',
        'zh_CN' => 'چینی (چین)',
        'zh_HK' => 'چینی (ہانگ کانگ SAR چین)',
        'zh_Hans' => 'چینی (آسان)',
        'zh_Hans_CN' => 'چینی (آسان،چین)',
        'zh_Hans_HK' => 'چینی (آسان،ہانگ کانگ SAR چین)',
        'zh_Hans_MO' => 'چینی (آسان،مکاؤ SAR چین)',
        'zh_Hans_MY' => 'چینی (آسان،ملائشیا)',
        'zh_Hans_SG' => 'چینی (آسان،سنگاپور)',
        'zh_Hant' => 'چینی (روایتی)',
        'zh_Hant_HK' => 'چینی (روایتی،ہانگ کانگ SAR چین)',
        'zh_Hant_MO' => 'چینی (روایتی،مکاؤ SAR چین)',
        'zh_Hant_MY' => 'چینی (روایتی،ملائشیا)',
        'zh_Hant_TW' => 'چینی (روایتی،تائیوان)',
        'zh_MO' => 'چینی (مکاؤ SAR چین)',
        'zh_SG' => 'چینی (سنگاپور)',
        'zh_TW' => 'چینی (تائیوان)',
        'zu' => 'زولو',
        'zu_ZA' => 'زولو (جنوبی افریقہ)',
    ],
];
