<?php

return [
    'Names' => [
        'Adlm' => 'адлам ҫырулӑхӗ',
        'Aghb' => 'агван ҫырулӑхӗ',
        'Ahom' => 'ахом ҫырулӑхӗ',
        'Arab' => 'араб ҫырулӑхӗ',
        'Aran' => 'насталик ҫырулӑхӗ',
        'Armi' => 'арамей ҫырулӑхӗ',
        'Armn' => 'эрмен ҫырулӑхӗ',
        'Avst' => 'авести ҫырулӑхӗ',
        'Bali' => 'бали ҫырулӑхӗ',
        'Bamu' => 'бамум ҫырулӑхӗ',
        'Bass' => 'басса (вах) ҫырулӑхӗ',
        'Batk' => 'батак ҫырулӑхӗ',
        'Beng' => 'бенгал ҫырулӑхӗ',
        'Berf' => 'бэри ҫырулӑхӗ',
        'Bhks' => 'бхайксуки ҫырулӑхӗ',
        'Bopo' => 'бопомофо ҫырулӑхӗ',
        'Brah' => 'брахми ҫырулӑхӗ',
        'Brai' => 'брайль ҫырулӑхӗ',
        'Bugi' => 'бугинизи ҫырулӑхӗ',
        'Buhd' => 'бухид ҫырулӑхӗ',
        'Cakm' => 'чакма ҫырулӑхӗ',
        'Cans' => 'канада сыпӑклӑ ҫырулӑхӗ',
        'Cari' => 'кари ҫырулӑхӗ',
        'Cham' => 'чам ҫырулӑхӗ',
        'Cher' => 'чероки ҫырулӑхӗ',
        'Chrs' => 'хорезм ҫырулӑхӗ',
        'Copt' => 'копт ҫырулӑхӗ',
        'Cpmn' => 'кипр-миной ҫырулӑхӗ',
        'Cprt' => 'кипр ҫырулӑхӗ',
        'Cyrl' => 'кирилл ҫырулӑхӗ',
        'Cyrs' => 'авалхи славян ҫырулӑхӗ',
        'Deva' => 'деванагари ҫырулӑхӗ',
        'Diak' => 'дивехи-акуру ҫырулӑхӗ',
        'Dogr' => 'догри ҫырулӑхӗ',
        'Dsrt' => 'дезерет ҫырулӑхӗ',
        'Dupl' => 'дюплойе ҫырулӑхӗ',
        'Egyp' => 'египет ҫырулӑхӗ',
        'Elba' => 'эльбасан ҫырулӑхӗ',
        'Elym' => 'элам ҫырулӑхӗ',
        'Ethi' => 'эфиоп ҫырулӑхӗ',
        'Gara' => 'гарай ҫырулӑхӗ',
        'Geor' => 'грузин ҫырулӑхӗ',
        'Glag' => 'глагол ҫырулӑхӗ',
        'Gong' => 'гунджала-гонди ҫырулӑхӗ',
        'Gonm' => 'масарам-гонди ҫырулӑхӗ',
        'Goth' => 'гот ҫырулӑхӗ',
        'Gran' => 'грантха ҫырулӑхӗ',
        'Grek' => 'грек ҫырулӑхӗ',
        'Gujr' => 'гуджарати ҫырулӑхӗ',
        'Gukh' => 'кхема ҫырулӑхӗ',
        'Guru' => 'гурмукхи ҫырулӑхӗ',
        'Hanb' => 'ханьпа бопомофо ҫырулӑхӗ',
        'Hang' => 'хангыль ҫырулӑхӗ',
        'Hani' => 'китай ҫырулӑхӗ',
        'Hano' => 'хануну ҫырулӑхӗ',
        'Hans' => 'ҫӑмӑллатнӑ китай ҫырулӑхӗ',
        'Hant' => 'йӑлана кӗнӗ китай ҫырулӑхӗ',
        'Hatr' => 'хатра ҫырулӑхӗ',
        'Hebr' => 'еврей ҫырулӑхӗ',
        'Hira' => 'хирагана ҫырулӑхӗ',
        'Hluw' => 'луви ҫырулӑхӗ',
        'Hmng' => 'пахау ҫырулӑхӗ',
        'Hmnp' => 'ньякенг-пуачуэ ҫырулӑхӗ',
        'Hrkt' => 'катаканапа хирагана ҫырулӑхӗ',
        'Hung' => 'авалхи венгр ҫырулӑхӗ',
        'Ital' => 'авалхи итальян ҫырулӑхӗ',
        'Jamo' => 'джамо ҫырулӑхӗ',
        'Java' => 'яван ҫырулӑхӗ',
        'Jpan' => 'япон ҫырулӑхӗ',
        'Kali' => 'кая-ли ҫырулӑхӗ',
        'Kana' => 'катакана ҫырулӑхӗ',
        'Kawi' => 'кави ҫырулӑхӗ',
        'Khar' => 'кхароштхи ҫырулӑхӗ',
        'Khmr' => 'кхмер ҫырулӑхӗ',
        'Khoj' => 'ходжики ҫырулӑхӗ',
        'Kits' => 'пӗчӗк кидань ҫырулӑхӗ',
        'Knda' => 'каннада ҫырулӑхӗ',
        'Kore' => 'корей ҫырулӑхӗ',
        'Krai' => 'кират-рай ҫырулӑхӗ',
        'Kthi' => 'кайтхи ҫырулӑхӗ',
        'Lana' => 'ланна ҫырулӑхӗ',
        'Laoo' => 'лаос ҫырулӑхӗ',
        'Latf' => 'латин фрактура ҫырулӑхӗ',
        'Latg' => 'гэл латин ҫырулӑхӗ',
        'Latn' => 'латин ҫырулӑхӗ',
        'Lepc' => 'лепча ҫырулӑхӗ',
        'Limb' => 'лимбу ҫырулӑхӗ',
        'Lina' => 'А йӗрлӗ ҫырулӑх',
        'Linb' => 'Ӑ йӗрлӗ ҫырулӑх',
        'Lisu' => 'лису ҫырулӑхӗ',
        'Lyci' => 'лики ҫырулӑхӗ',
        'Lydi' => 'лиди ҫырулӑхӗ',
        'Mahj' => 'махаджани ҫырулӑхӗ',
        'Maka' => 'макасар ҫырулӑхӗ',
        'Mand' => 'мандей ҫырулӑхӗ',
        'Mani' => 'манихей ҫырулӑхӗ',
        'Marc' => 'марчхен ҫырулӑхӗ',
        'Medf' => 'обэри-окаимэ ҫырулӑхӗ',
        'Mend' => 'менде ҫырулӑхӗ',
        'Merc' => 'чалӑш мероит ҫырулӑхӗ',
        'Mero' => 'мероит ҫырулӑхӗ',
        'Mlym' => 'малаялам ҫырулӑхӗ',
        'Modi' => 'моди ҫырулӑхӗ',
        'Mong' => 'монгол ҫырулӑхӗ',
        'Mroo' => 'мро ҫырулӑхӗ',
        'Mtei' => 'манипури ҫырулӑхӗ',
        'Mult' => 'мултани ҫырулӑхӗ',
        'Mymr' => 'мьянма ҫырулӑхӗ',
        'Nagm' => 'наг-мундари ҫырулӑхӗ',
        'Nand' => 'нандинагари ҫырулӑхӗ',
        'Narb' => 'авалхи ҫур ҫӗр араб ҫырулӑхӗ',
        'Nbat' => 'набатей ҫырулӑхӗ',
        'Newa' => 'нева ҫырулӑхӗ',
        'Nkoo' => 'нко ҫырулӑхӗ',
        'Nshu' => 'нюй-шу ҫырулӑхӗ',
        'Ogam' => 'огам ҫырулӑхӗ',
        'Olck' => 'ол-чики ҫырулӑхӗ',
        'Onao' => 'ол-онал ҫырулӑхӗ',
        'Orkh' => 'авалхи тӗрӗк ҫырулӑхӗ',
        'Orya' => 'ори ҫырулӑхӗ',
        'Osge' => 'осейдж ҫырулӑхӗ',
        'Osma' => 'осман ҫырулӑхӗ',
        'Ougr' => 'авалхи уйгур ҫырулӑхӗ',
        'Palm' => 'пальмир ҫырулӑхӗ',
        'Pauc' => 'паун-чжин-хаук ҫырулӑхӗ',
        'Perm' => 'авалхи пермь ҫырулӑхӗ',
        'Phag' => 'пагспа ҫырулӑхӗ',
        'Phli' => 'пехлеви ҫырулӑхӗ',
        'Phlp' => 'пехлеви псалтырь ҫырулӑхӗ',
        'Phnx' => 'финики ҫырулӑхӗ',
        'Plrd' => 'мяо ҫырулӑхӗ',
        'Prti' => 'парфян ҫырулӑхӗ',
        'Qaag' => 'зоджи ҫырулӑхӗ',
        'Rjng' => 'реджанг ҫырулӑхӗ',
        'Rohg' => 'ханифи ҫырулӑхӗ',
        'Runr' => 'руна ҫырулӑхӗ',
        'Samr' => 'самаритян ҫырулӑхӗ',
        'Sarb' => 'авалхи кӑнтӑр араб ҫырулӑхӗ',
        'Saur' => 'саураштра ҫырулӑхӗ',
        'Sgnw' => 'паллӑ ҫырулӑхӗ',
        'Shaw' => 'шоу ҫырулӑхӗ',
        'Shrd' => 'шарада ҫырулӑхӗ',
        'Sidd' => 'сиддхам ҫырулӑхӗ',
        'Sidt' => 'сидет ҫырулӑхӗ',
        'Sind' => 'кхудавади ҫырулӑхӗ',
        'Sinh' => 'сингал ҫырулӑхӗ',
        'Sogd' => 'согди ҫырулӑхӗ',
        'Sogo' => 'авалхи согди ҫырулӑхӗ',
        'Sora' => 'сора-сонпенг ҫырулӑхӗ',
        'Soyo' => 'соёмбо ҫырулӑхӗ',
        'Sund' => 'сундан ҫырулӑхӗ',
        'Sunu' => 'сунвар ҫырулӑхӗ',
        'Sylo' => 'силоти-нагри ҫырулӑхӗ',
        'Syrc' => 'сири ҫырулӑхӗ',
        'Syre' => 'сири эстрангело ҫырулӑхӗ',
        'Syrj' => 'анӑҫ сири ҫырулӑхӗ',
        'Syrn' => 'тухӑҫ сири ҫырулӑхӗ',
        'Tagb' => 'тагбанва ҫырулӑхӗ',
        'Takr' => 'такри ҫырулӑхӗ',
        'Tale' => 'тай-ныа ҫырулӑхӗ',
        'Talu' => 'ҫӗнӗ тай-ныа ҫырулӑхӗ',
        'Taml' => 'тамил ҫырулӑхӗ',
        'Tang' => 'тангут ҫырулӑхӗ',
        'Tavt' => 'тай-вьет ҫырулӑхӗ',
        'Tayo' => 'тай-йо ҫырулӑхӗ',
        'Telu' => 'телугу ҫырулӑхӗ',
        'Tfng' => 'тифинаг ҫырулӑхӗ',
        'Tglg' => 'тагалог ҫырулӑхӗ',
        'Thaa' => 'таана ҫырулӑхӗ',
        'Thai' => 'тай ҫырулӑхӗ',
        'Tibt' => 'тибет ҫырулӑхӗ',
        'Tirh' => 'тирхута ҫырулӑхӗ',
        'Tnsa' => 'тангса ҫырулӑхӗ',
        'Todr' => 'тодри ҫырулӑхӗ',
        'Tols' => 'толонг-сики ҫырулӑхӗ',
        'Toto' => 'тото ҫырулӑхӗ',
        'Tutg' => 'тулу-тигалари ҫырулӑхӗ',
        'Ugar' => 'угарит ҫырулӑхӗ',
        'Vaii' => 'вай ҫырулӑхӗ',
        'Vith' => 'виткути ҫырулӑхӗ',
        'Wara' => 'варанг-кшити ҫырулӑхӗ',
        'Wcho' => 'ванчо ҫырулӑхӗ',
        'Xpeo' => 'авалхи перс ҫырулӑхӗ',
        'Xsux' => 'шумер-аккад савӑл ҫырулӑхӗ',
        'Yezi' => 'езид ҫырулӑхӗ',
        'Yiii' => 'и ҫырулӑхӗ',
        'Zanb' => 'тӑваткал забазар ҫырулӑхӗ',
        'Zinh' => 'еткерленӗ ҫырулӑх',
        'Zmth' => 'математика паллисем',
        'Zsye' => 'эмодзи',
        'Zsym' => 'паллӑсем',
        'Zxxx' => 'ҫырулӑхсӑр',
        'Zyyy' => 'пӗтӗмӗшле йышӑннӑ ҫырулӑх',
    ],
];
