<?php

return [
    'Names' => [
        'Indian/Kerguelen' => 'French Southern and Antarctic Time (Kerguelen Islands)',
        'Pacific/Wallis' => 'Wallis & Futuna Time (Wallis and Futuna)',
    ],
    'Meta' => [],
];
