<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'af_NA' => 'африкаанс (Намибия)',
        'af_ZA' => 'африкаанс (Жанубий Африка Республикаси)',
        'ak' => 'аканча',
        'ak_GH' => 'аканча (Гана)',
        'am' => 'амхарча',
        'am_ET' => 'амхарча (Эфиопия)',
        'ar' => 'арабча',
        'ar_001' => 'арабча (Дунё)',
        'ar_AE' => 'арабча (Бирлашган Араб Амирликлари)',
        'ar_BH' => 'арабча (Баҳрайн)',
        'ar_DJ' => 'арабча (Жибути)',
        'ar_DZ' => 'арабча (Жазоир)',
        'ar_EG' => 'арабча (Миср)',
        'ar_EH' => 'арабча (Ғарбий Саҳрои Кабир)',
        'ar_ER' => 'арабча (Эритрея)',
        'ar_IL' => 'арабча (Исроил)',
        'ar_IQ' => 'арабча (Ироқ)',
        'ar_JO' => 'арабча (Иордания)',
        'ar_KM' => 'арабча (Комор ороллари)',
        'ar_KW' => 'арабча (Қувайт)',
        'ar_LB' => 'арабча (Ливан)',
        'ar_LY' => 'арабча (Ливия)',
        'ar_MA' => 'арабча (Марокаш)',
        'ar_MR' => 'арабча (Мавритания)',
        'ar_OM' => 'арабча (Уммон)',
        'ar_PS' => 'арабча (Фаластин ҳудуди)',
        'ar_QA' => 'арабча (Қатар)',
        'ar_SA' => 'арабча (Саудия Арабистони)',
        'ar_SD' => 'арабча (Судан)',
        'ar_SO' => 'арабча (Сомали)',
        'ar_SS' => 'арабча (Жанубий Судан)',
        'ar_SY' => 'арабча (Сурия)',
        'ar_TD' => 'арабча (Чад)',
        'ar_TN' => 'арабча (Тунис)',
        'ar_YE' => 'арабча (Яман)',
        'as' => 'ассомча',
        'as_IN' => 'ассомча (Ҳиндистон)',
        'az' => 'озарбайжонча',
        'az_AZ' => 'озарбайжонча (Озарбайжон)',
        'az_Cyrl' => 'озарбайжонча (Кирил)',
        'az_Cyrl_AZ' => 'озарбайжонча (Кирил, Озарбайжон)',
        'az_Latn' => 'озарбайжонча (Лотин)',
        'az_Latn_AZ' => 'озарбайжонча (Лотин, Озарбайжон)',
        'ba' => 'бошқирдча',
        'ba_RU' => 'бошқирдча (Россия)',
        'be' => 'беларусча',
        'be_BY' => 'беларусча (Беларус)',
        'bg' => 'болгарча',
        'bg_BG' => 'болгарча (Болгария)',
        'bm' => 'бамбарча',
        'bm_ML' => 'бамбарча (Мали)',
        'bn' => 'бенгалча',
        'bn_BD' => 'бенгалча (Бангладеш)',
        'bn_IN' => 'бенгалча (Ҳиндистон)',
        'bo' => 'тибетча',
        'bo_CN' => 'тибетча (Хитой)',
        'bo_IN' => 'тибетча (Ҳиндистон)',
        'br' => 'бретонча',
        'br_FR' => 'бретонча (Франция)',
        'bs' => 'боснийча',
        'bs_BA' => 'боснийча (Босния ва Герцеговина)',
        'bs_Cyrl' => 'боснийча (Кирил)',
        'bs_Cyrl_BA' => 'боснийча (Кирил, Босния ва Герцеговина)',
        'bs_Latn' => 'боснийча (Лотин)',
        'bs_Latn_BA' => 'боснийча (Лотин, Босния ва Герцеговина)',
        'ca' => 'каталонча',
        'ca_AD' => 'каталонча (Андорра)',
        'ca_ES' => 'каталонча (Испания)',
        'ca_FR' => 'каталонча (Франция)',
        'ca_IT' => 'каталонча (Италия)',
        'ce' => 'чечен тили',
        'ce_RU' => 'чечен тили (Россия)',
        'cs' => 'чехча',
        'cs_CZ' => 'чехча (Чехия)',
        'cv' => 'чуваш тили',
        'cv_RU' => 'чуваш тили (Россия)',
        'cy' => 'уэлсча',
        'cy_GB' => 'уэлсча (Буюк Британия)',
        'da' => 'датча',
        'da_DK' => 'датча (Дания)',
        'da_GL' => 'датча (Гренландия)',
        'de' => 'немисча',
        'de_AT' => 'немисча (Австрия)',
        'de_BE' => 'немисча (Бельгия)',
        'de_CH' => 'немисча (Швейцария)',
        'de_DE' => 'немисча (Германия)',
        'de_IT' => 'немисча (Италия)',
        'de_LI' => 'немисча (Лихтенштейн)',
        'de_LU' => 'немисча (Люксембург)',
        'dz' => 'дзонгка',
        'dz_BT' => 'дзонгка (Бутан)',
        'ee' => 'эвеча',
        'ee_GH' => 'эвеча (Гана)',
        'ee_TG' => 'эвеча (Того)',
        'el' => 'грекча',
        'el_CY' => 'грекча (Кипр)',
        'el_GR' => 'грекча (Греция)',
        'en' => 'инглизча',
        'en_001' => 'инглизча (Дунё)',
        'en_150' => 'инглизча (Европа)',
        'en_AE' => 'инглизча (Бирлашган Араб Амирликлари)',
        'en_AG' => 'инглизча (Антигуа ва Барбуда)',
        'en_AI' => 'инглизча (Ангилья)',
        'en_AS' => 'инглизча (Америка Самоаси)',
        'en_AT' => 'инглизча (Австрия)',
        'en_AU' => 'инглизча (Австралия)',
        'en_BB' => 'инглизча (Барбадос)',
        'en_BE' => 'инглизча (Бельгия)',
        'en_BI' => 'инглизча (Бурунди)',
        'en_BM' => 'инглизча (Бермуда)',
        'en_BS' => 'инглизча (Багама ороллари)',
        'en_BW' => 'инглизча (Ботсванна)',
        'en_BZ' => 'инглизча (Белиз)',
        'en_CA' => 'инглизча (Канада)',
        'en_CC' => 'инглизча (Кокос [Килинг] ороллари)',
        'en_CH' => 'инглизча (Швейцария)',
        'en_CK' => 'инглизча (Кук ороллари)',
        'en_CM' => 'инглизча (Камерун)',
        'en_CX' => 'инглизча (Рождество ороли)',
        'en_CY' => 'инглизча (Кипр)',
        'en_CZ' => 'инглизча (Чехия)',
        'en_DE' => 'инглизча (Германия)',
        'en_DK' => 'инглизча (Дания)',
        'en_DM' => 'инглизча (Доминика)',
        'en_EE' => 'инглизча (Эстония)',
        'en_ER' => 'инглизча (Эритрея)',
        'en_ES' => 'инглизча (Испания)',
        'en_FI' => 'инглизча (Финляндия)',
        'en_FJ' => 'инглизча (Фижи)',
        'en_FK' => 'инглизча (Фолкленд ороллари)',
        'en_FM' => 'инглизча (Микронезия)',
        'en_FR' => 'инглизча (Франция)',
        'en_GB' => 'инглизча (Буюк Британия)',
        'en_GD' => 'инглизча (Гренада)',
        'en_GE' => 'инглизча (Грузия)',
        'en_GG' => 'инглизча (Гернси)',
        'en_GH' => 'инглизча (Гана)',
        'en_GI' => 'инглизча (Гибралтар)',
        'en_GM' => 'инглизча (Гамбия)',
        'en_GS' => 'инглизча (Жанубий Георгия ва Жанубий Сендвич ороллари)',
        'en_GU' => 'инглизча (Гуам)',
        'en_GY' => 'инглизча (Гаяна)',
        'en_HK' => 'инглизча (Гонконг [Хитой ММҲ])',
        'en_HU' => 'инглизча (Венгрия)',
        'en_ID' => 'инглизча (Индонезия)',
        'en_IE' => 'инглизча (Ирландия)',
        'en_IL' => 'инглизча (Исроил)',
        'en_IM' => 'инглизча (Мэн ороли)',
        'en_IN' => 'инглизча (Ҳиндистон)',
        'en_IO' => 'инглизча (Britaniyaning Hind okeanidagi hududi)',
        'en_IT' => 'инглизча (Италия)',
        'en_JE' => 'инглизча (Жерси)',
        'en_JM' => 'инглизча (Ямайка)',
        'en_JP' => 'инглизча (Япония)',
        'en_KE' => 'инглизча (Кения)',
        'en_KI' => 'инглизча (Кирибати)',
        'en_KN' => 'инглизча (Сент-Китс ва Невис)',
        'en_KY' => 'инглизча (Кайман ороллари)',
        'en_LC' => 'инглизча (Сент-Люсия)',
        'en_LR' => 'инглизча (Либерия)',
        'en_LS' => 'инглизча (Лесото)',
        'en_LT' => 'инглизча (Литва)',
        'en_LV' => 'инглизча (Латвия)',
        'en_MG' => 'инглизча (Мадагаскар)',
        'en_MH' => 'инглизча (Маршал ороллари)',
        'en_MO' => 'инглизча (Макао [Хитой ММҲ])',
        'en_MP' => 'инглизча (Шимолий Марианна ороллари)',
        'en_MS' => 'инглизча (Монтсеррат)',
        'en_MT' => 'инглизча (Мальта)',
        'en_MU' => 'инглизча (Маврикий)',
        'en_MV' => 'инглизча (Мальдив ороллари)',
        'en_MW' => 'инглизча (Малави)',
        'en_MY' => 'инглизча (Малайзия)',
        'en_NA' => 'инглизча (Намибия)',
        'en_NF' => 'инглизча (Норфолк ороллари)',
        'en_NG' => 'инглизча (Нигерия)',
        'en_NL' => 'инглизча (Нидерландия)',
        'en_NO' => 'инглизча (Норвегия)',
        'en_NR' => 'инглизча (Науру)',
        'en_NU' => 'инглизча (Ниуэ)',
        'en_NZ' => 'инглизча (Янги Зеландия)',
        'en_PG' => 'инглизча (Папуа - Янги Гвинея)',
        'en_PH' => 'инглизча (Филиппин)',
        'en_PK' => 'инглизча (Покистон)',
        'en_PL' => 'инглизча (Польша)',
        'en_PN' => 'инглизча (Питкэрн ороллари)',
        'en_PR' => 'инглизча (Пуэрто-Рико)',
        'en_PT' => 'инглизча (Португалия)',
        'en_PW' => 'инглизча (Палау)',
        'en_RO' => 'инглизча (Руминия)',
        'en_RW' => 'инглизча (Руанда)',
        'en_SB' => 'инглизча (Соломон ороллари)',
        'en_SC' => 'инглизча (Сейшел ороллари)',
        'en_SD' => 'инглизча (Судан)',
        'en_SE' => 'инглизча (Швеция)',
        'en_SG' => 'инглизча (Сингапур)',
        'en_SH' => 'инглизча (Муқаддас Елена ороли)',
        'en_SI' => 'инглизча (Словения)',
        'en_SK' => 'инглизча (Словакия)',
        'en_SL' => 'инглизча (Сьерра-Леоне)',
        'en_SS' => 'инглизча (Жанубий Судан)',
        'en_SX' => 'инглизча (Синт-Мартен)',
        'en_SZ' => 'инглизча (Свазиленд)',
        'en_TC' => 'инглизча (Туркс ва Кайкос ороллари)',
        'en_TK' => 'инглизча (Токелау)',
        'en_TO' => 'инглизча (Тонга)',
        'en_TT' => 'инглизча (Тринидад ва Тобаго)',
        'en_TV' => 'инглизча (Тувалу)',
        'en_TZ' => 'инглизча (Танзания)',
        'en_UA' => 'инглизча (Украина)',
        'en_UG' => 'инглизча (Уганда)',
        'en_UM' => 'инглизча (АҚШ ёндош ороллари)',
        'en_US' => 'инглизча (Америка Қўшма Штатлари)',
        'en_VC' => 'инглизча (Сент-Винсент ва Гренадин)',
        'en_VG' => 'инглизча (Британия Виргин ороллари)',
        'en_VI' => 'инглизча (АҚШ Виргин ороллари)',
        'en_VU' => 'инглизча (Вануату)',
        'en_WS' => 'инглизча (Самоа)',
        'en_ZA' => 'инглизча (Жанубий Африка Республикаси)',
        'en_ZM' => 'инглизча (Замбия)',
        'en_ZW' => 'инглизча (Зимбабве)',
        'eo' => 'эсперанто',
        'eo_001' => 'эсперанто (Дунё)',
        'es' => 'испанча',
        'es_419' => 'испанча (Лотин Америкаси)',
        'es_AR' => 'испанча (Аргентина)',
        'es_BO' => 'испанча (Боливия)',
        'es_BR' => 'испанча (Бразилия)',
        'es_BZ' => 'испанча (Белиз)',
        'es_CL' => 'испанча (Чили)',
        'es_CO' => 'испанча (Колумбия)',
        'es_CR' => 'испанча (Коста-Рика)',
        'es_CU' => 'испанча (Куба)',
        'es_DO' => 'испанча (Доминикан Республикаси)',
        'es_EC' => 'испанча (Эквадор)',
        'es_ES' => 'испанча (Испания)',
        'es_GQ' => 'испанча (Экваториал Гвинея)',
        'es_GT' => 'испанча (Гватемала)',
        'es_HN' => 'испанча (Гондурас)',
        'es_MX' => 'испанча (Мексика)',
        'es_NI' => 'испанча (Никарагуа)',
        'es_PA' => 'испанча (Панама)',
        'es_PE' => 'испанча (Перу)',
        'es_PH' => 'испанча (Филиппин)',
        'es_PR' => 'испанча (Пуэрто-Рико)',
        'es_PY' => 'испанча (Парагвай)',
        'es_SV' => 'испанча (Салвадор)',
        'es_US' => 'испанча (Америка Қўшма Штатлари)',
        'es_UY' => 'испанча (Уругвай)',
        'es_VE' => 'испанча (Венесуэла)',
        'et' => 'эстонча',
        'et_EE' => 'эстонча (Эстония)',
        'eu' => 'баскча',
        'eu_ES' => 'баскча (Испания)',
        'fa' => 'форсий',
        'fa_AF' => 'форсий (Афғонистон)',
        'fa_IR' => 'форсий (Эрон)',
        'ff' => 'фулаҳ',
        'ff_Adlm' => 'фулаҳ (adlam)',
        'ff_Adlm_BF' => 'фулаҳ (adlam, Буркина-Фасо)',
        'ff_Adlm_CM' => 'фулаҳ (adlam, Камерун)',
        'ff_Adlm_GH' => 'фулаҳ (adlam, Гана)',
        'ff_Adlm_GM' => 'фулаҳ (adlam, Гамбия)',
        'ff_Adlm_GN' => 'фулаҳ (adlam, Гвинея)',
        'ff_Adlm_GW' => 'фулаҳ (adlam, Гвинея-Бисау)',
        'ff_Adlm_LR' => 'фулаҳ (adlam, Либерия)',
        'ff_Adlm_MR' => 'фулаҳ (adlam, Мавритания)',
        'ff_Adlm_NE' => 'фулаҳ (adlam, Нигер)',
        'ff_Adlm_NG' => 'фулаҳ (adlam, Нигерия)',
        'ff_Adlm_SL' => 'фулаҳ (adlam, Сьерра-Леоне)',
        'ff_Adlm_SN' => 'фулаҳ (adlam, Сенегал)',
        'ff_CM' => 'фулаҳ (Камерун)',
        'ff_GN' => 'фулаҳ (Гвинея)',
        'ff_Latn' => 'фулаҳ (Лотин)',
        'ff_Latn_BF' => 'фулаҳ (Лотин, Буркина-Фасо)',
        'ff_Latn_CM' => 'фулаҳ (Лотин, Камерун)',
        'ff_Latn_GH' => 'фулаҳ (Лотин, Гана)',
        'ff_Latn_GM' => 'фулаҳ (Лотин, Гамбия)',
        'ff_Latn_GN' => 'фулаҳ (Лотин, Гвинея)',
        'ff_Latn_GW' => 'фулаҳ (Лотин, Гвинея-Бисау)',
        'ff_Latn_LR' => 'фулаҳ (Лотин, Либерия)',
        'ff_Latn_MR' => 'фулаҳ (Лотин, Мавритания)',
        'ff_Latn_NE' => 'фулаҳ (Лотин, Нигер)',
        'ff_Latn_NG' => 'фулаҳ (Лотин, Нигерия)',
        'ff_Latn_SL' => 'фулаҳ (Лотин, Сьерра-Леоне)',
        'ff_Latn_SN' => 'фулаҳ (Лотин, Сенегал)',
        'ff_MR' => 'фулаҳ (Мавритания)',
        'ff_SN' => 'фулаҳ (Сенегал)',
        'fi' => 'финча',
        'fi_FI' => 'финча (Финляндия)',
        'fo' => 'фарерча',
        'fo_DK' => 'фарерча (Дания)',
        'fo_FO' => 'фарерча (Фарер ороллари)',
        'fr' => 'французча',
        'fr_BE' => 'французча (Бельгия)',
        'fr_BF' => 'французча (Буркина-Фасо)',
        'fr_BI' => 'французча (Бурунди)',
        'fr_BJ' => 'французча (Бенин)',
        'fr_BL' => 'французча (Сен-Бартелеми)',
        'fr_CA' => 'французча (Канада)',
        'fr_CD' => 'французча (Конго-Киншаса)',
        'fr_CF' => 'французча (Марказий Африка Республикаси)',
        'fr_CG' => 'французча (Конго Браззавиль)',
        'fr_CH' => 'французча (Швейцария)',
        'fr_CI' => 'французча (Кот-д’Ивуар)',
        'fr_CM' => 'французча (Камерун)',
        'fr_DJ' => 'французча (Жибути)',
        'fr_DZ' => 'французча (Жазоир)',
        'fr_FR' => 'французча (Франция)',
        'fr_GA' => 'французча (Габон)',
        'fr_GF' => 'французча (Француз Гвианаси)',
        'fr_GN' => 'французча (Гвинея)',
        'fr_GP' => 'французча (Гваделупе)',
        'fr_GQ' => 'французча (Экваториал Гвинея)',
        'fr_HT' => 'французча (Гаити)',
        'fr_KM' => 'французча (Комор ороллари)',
        'fr_LU' => 'французча (Люксембург)',
        'fr_MA' => 'французча (Марокаш)',
        'fr_MC' => 'французча (Монако)',
        'fr_MF' => 'французча (Сент-Мартин)',
        'fr_MG' => 'французча (Мадагаскар)',
        'fr_ML' => 'французча (Мали)',
        'fr_MQ' => 'французча (Мартиника)',
        'fr_MR' => 'французча (Мавритания)',
        'fr_MU' => 'французча (Маврикий)',
        'fr_NC' => 'французча (Янги Каледония)',
        'fr_NE' => 'французча (Нигер)',
        'fr_PF' => 'французча (Француз Полинезияси)',
        'fr_PM' => 'французча (Сент-Пьер ва Микелон)',
        'fr_RE' => 'французча (Реюнион)',
        'fr_RW' => 'французча (Руанда)',
        'fr_SC' => 'французча (Сейшел ороллари)',
        'fr_SN' => 'французча (Сенегал)',
        'fr_SY' => 'французча (Сурия)',
        'fr_TD' => 'французча (Чад)',
        'fr_TG' => 'французча (Того)',
        'fr_TN' => 'французча (Тунис)',
        'fr_VU' => 'французча (Вануату)',
        'fr_WF' => 'французча (Уоллис ва Футуна)',
        'fr_YT' => 'французча (Майотта)',
        'fy' => 'ғарбий фризча',
        'fy_NL' => 'ғарбий фризча (Нидерландия)',
        'ga' => 'ирландча',
        'ga_GB' => 'ирландча (Буюк Британия)',
        'ga_IE' => 'ирландча (Ирландия)',
        'gd' => 'шотландча гаелик',
        'gd_GB' => 'шотландча гаелик (Буюк Британия)',
        'gl' => 'галицийча',
        'gl_ES' => 'галицийча (Испания)',
        'gu' => 'гужаротча',
        'gu_IN' => 'гужаротча (Ҳиндистон)',
        'gv' => 'мэнча',
        'gv_IM' => 'мэнча (Мэн ороли)',
        'ha' => 'хауса',
        'ha_GH' => 'хауса (Гана)',
        'ha_NE' => 'хауса (Нигер)',
        'ha_NG' => 'хауса (Нигерия)',
        'he' => 'иброний',
        'he_IL' => 'иброний (Исроил)',
        'hi' => 'ҳинди',
        'hi_IN' => 'ҳинди (Ҳиндистон)',
        'hi_Latn' => 'ҳинди (Лотин)',
        'hi_Latn_IN' => 'ҳинди (Лотин, Ҳиндистон)',
        'hr' => 'хорватча',
        'hr_BA' => 'хорватча (Босния ва Герцеговина)',
        'hr_HR' => 'хорватча (Хорватия)',
        'hu' => 'венгерча',
        'hu_HU' => 'венгерча (Венгрия)',
        'hy' => 'арманча',
        'hy_AM' => 'арманча (Арманистон)',
        'ia' => 'интерлингва',
        'ia_001' => 'интерлингва (Дунё)',
        'id' => 'индонезча',
        'id_ID' => 'индонезча (Индонезия)',
        'ie_EE' => 'interlingve (Эстония)',
        'ig' => 'игбо',
        'ig_NG' => 'игбо (Нигерия)',
        'ii_CN' => 'sichuan (Хитой)',
        'is' => 'исландча',
        'is_IS' => 'исландча (Исландия)',
        'it' => 'италянча',
        'it_CH' => 'италянча (Швейцария)',
        'it_IT' => 'италянча (Италия)',
        'it_SM' => 'италянча (Сан-Марино)',
        'it_VA' => 'италянча (Ватикан)',
        'ja' => 'японча',
        'ja_JP' => 'японча (Япония)',
        'jv' => 'яванча',
        'jv_ID' => 'яванча (Индонезия)',
        'ka' => 'грузинча',
        'ka_GE' => 'грузинча (Грузия)',
        'ki' => 'кикую',
        'ki_KE' => 'кикую (Кения)',
        'kk' => 'қозоқча',
        'kk_Arab' => 'қозоқча (Араб)',
        'kk_Arab_CN' => 'қозоқча (Араб, Хитой)',
        'kk_Cyrl' => 'қозоқча (Кирил)',
        'kk_Cyrl_KZ' => 'қозоқча (Кирил, Қозоғистон)',
        'kk_KZ' => 'қозоқча (Қозоғистон)',
        'kl' => 'гренландча',
        'kl_GL' => 'гренландча (Гренландия)',
        'km' => 'хмерча',
        'km_KH' => 'хмерча (Камбоджа)',
        'kn' => 'каннада',
        'kn_IN' => 'каннада (Ҳиндистон)',
        'ko' => 'корейсча',
        'ko_CN' => 'корейсча (Хитой)',
        'ko_KP' => 'корейсча (Шимолий Корея)',
        'ko_KR' => 'корейсча (Жанубий Корея)',
        'ks' => 'кашмирча',
        'ks_Arab' => 'кашмирча (Араб)',
        'ks_Arab_IN' => 'кашмирча (Араб, Ҳиндистон)',
        'ks_Deva' => 'кашмирча (Девангари)',
        'ks_Deva_IN' => 'кашмирча (Девангари, Ҳиндистон)',
        'ks_IN' => 'кашмирча (Ҳиндистон)',
        'ku' => 'курдча',
        'ku_Latn' => 'курдча (Лотин)',
        'ku_Latn_IQ' => 'курдча (Лотин, Ироқ)',
        'ku_Latn_SY' => 'курдча (Лотин, Сурия)',
        'ku_Latn_TR' => 'курдча (Лотин, Туркия)',
        'ku_SY' => 'курдча (Сурия)',
        'ku_TR' => 'курдча (Туркия)',
        'kw' => 'корнча',
        'kw_GB' => 'корнча (Буюк Британия)',
        'ky' => 'қирғизча',
        'ky_KG' => 'қирғизча (Қирғизистон)',
        'lb' => 'люксембургча',
        'lb_LU' => 'люксембургча (Люксембург)',
        'lg' => 'гандача',
        'lg_UG' => 'гандача (Уганда)',
        'ln' => 'лингалча',
        'ln_AO' => 'лингалча (Ангола)',
        'ln_CD' => 'лингалча (Конго-Киншаса)',
        'ln_CF' => 'лингалча (Марказий Африка Республикаси)',
        'ln_CG' => 'лингалча (Конго Браззавиль)',
        'lo' => 'лаосча',
        'lo_LA' => 'лаосча (Лаос)',
        'lt' => 'литвача',
        'lt_LT' => 'литвача (Литва)',
        'lu' => 'луба-катанга',
        'lu_CD' => 'луба-катанга (Конго-Киншаса)',
        'lv' => 'латишча',
        'lv_LV' => 'латишча (Латвия)',
        'mg' => 'малагасийча',
        'mg_MG' => 'малагасийча (Мадагаскар)',
        'mi' => 'маори',
        'mi_NZ' => 'маори (Янги Зеландия)',
        'mk' => 'македонча',
        'mk_MK' => 'македонча (Шимолий Македония)',
        'ml' => 'малаялам',
        'ml_IN' => 'малаялам (Ҳиндистон)',
        'mn' => 'мўғулча',
        'mn_MN' => 'мўғулча (Монголия)',
        'mr' => 'маратхи',
        'mr_IN' => 'маратхи (Ҳиндистон)',
        'ms' => 'малай тил',
        'ms_BN' => 'малай тил (Бруней)',
        'ms_ID' => 'малай тил (Индонезия)',
        'ms_MY' => 'малай тил (Малайзия)',
        'ms_SG' => 'малай тил (Сингапур)',
        'mt' => 'малтача',
        'mt_MT' => 'малтача (Мальта)',
        'my' => 'бирманча',
        'my_MM' => 'бирманча (Мьянма [Бирма])',
        'nb' => 'норвегча бокмал',
        'nb_NO' => 'норвегча бокмал (Норвегия)',
        'nb_SJ' => 'норвегча бокмал (Свалбард ва Ян-Майен)',
        'nd' => 'шимолий ндебеле',
        'nd_ZW' => 'шимолий ндебеле (Зимбабве)',
        'ne' => 'непалча',
        'ne_IN' => 'непалча (Ҳиндистон)',
        'ne_NP' => 'непалча (Непал)',
        'nl' => 'голландча',
        'nl_AW' => 'голландча (Аруба)',
        'nl_BE' => 'голландча (Бельгия)',
        'nl_BQ' => 'голландча (Бонейр, Синт-Эстатиус ва Саба)',
        'nl_CW' => 'голландча (Кюрасао)',
        'nl_NL' => 'голландча (Нидерландия)',
        'nl_SR' => 'голландча (Суринам)',
        'nl_SX' => 'голландча (Синт-Мартен)',
        'nn' => 'норвегча нюнорск',
        'nn_NO' => 'норвегча нюнорск (Норвегия)',
        'no_NO' => 'norveg (Норвегия)',
        'oc' => 'окситанча',
        'oc_ES' => 'окситанча (Испания)',
        'oc_FR' => 'окситанча (Франция)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Эфиопия)',
        'om_KE' => 'оромо (Кения)',
        'or' => 'одия',
        'or_IN' => 'одия (Ҳиндистон)',
        'os_GE' => 'osetin (Грузия)',
        'os_RU' => 'osetin (Россия)',
        'pa' => 'панжобча',
        'pa_Arab' => 'панжобча (Араб)',
        'pa_Arab_PK' => 'панжобча (Араб, Покистон)',
        'pa_Guru' => 'панжобча (Гурмухи)',
        'pa_Guru_IN' => 'панжобча (Гурмухи, Ҳиндистон)',
        'pa_IN' => 'панжобча (Ҳиндистон)',
        'pa_PK' => 'панжобча (Покистон)',
        'pl' => 'полякча',
        'pl_PL' => 'полякча (Польша)',
        'ps' => 'пушту',
        'ps_AF' => 'пушту (Афғонистон)',
        'ps_PK' => 'пушту (Покистон)',
        'pt' => 'португалча',
        'pt_AO' => 'португалча (Ангола)',
        'pt_BR' => 'португалча (Бразилия)',
        'pt_CH' => 'португалча (Швейцария)',
        'pt_CV' => 'португалча (Кабо-Верде)',
        'pt_GQ' => 'португалча (Экваториал Гвинея)',
        'pt_GW' => 'португалча (Гвинея-Бисау)',
        'pt_LU' => 'португалча (Люксембург)',
        'pt_MO' => 'португалча (Макао [Хитой ММҲ])',
        'pt_MZ' => 'португалча (Мозамбик)',
        'pt_PT' => 'португалча (Португалия)',
        'pt_ST' => 'португалча (Сан-Томе ва Принсипи)',
        'pt_TL' => 'португалча (Тимор-Лесте)',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Боливия)',
        'qu_EC' => 'кечуа (Эквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'романшча',
        'rm_CH' => 'романшча (Швейцария)',
        'rn' => 'рунди',
        'rn_BI' => 'рунди (Бурунди)',
        'ro' => 'руминча',
        'ro_MD' => 'руминча (Молдова)',
        'ro_RO' => 'руминча (Руминия)',
        'ru' => 'русча',
        'ru_BY' => 'русча (Беларус)',
        'ru_KG' => 'русча (Қирғизистон)',
        'ru_KZ' => 'русча (Қозоғистон)',
        'ru_MD' => 'русча (Молдова)',
        'ru_RU' => 'русча (Россия)',
        'ru_UA' => 'русча (Украина)',
        'rw' => 'киняруанда',
        'rw_RW' => 'киняруанда (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (Ҳиндистон)',
        'sc_IT' => 'sardin (Италия)',
        'sd' => 'синдҳи',
        'sd_Arab' => 'синдҳи (Араб)',
        'sd_Arab_PK' => 'синдҳи (Араб, Покистон)',
        'sd_Deva' => 'синдҳи (Девангари)',
        'sd_Deva_IN' => 'синдҳи (Девангари, Ҳиндистон)',
        'sd_IN' => 'синдҳи (Ҳиндистон)',
        'sd_PK' => 'синдҳи (Покистон)',
        'se' => 'шимолий саамча',
        'se_FI' => 'шимолий саамча (Финляндия)',
        'se_NO' => 'шимолий саамча (Норвегия)',
        'se_SE' => 'шимолий саамча (Швеция)',
        'sg' => 'санго',
        'sg_CF' => 'санго (Марказий Африка Республикаси)',
        'si' => 'сингалча',
        'si_LK' => 'сингалча (Шри-Ланка)',
        'sk' => 'словакча',
        'sk_SK' => 'словакча (Словакия)',
        'sl' => 'словенча',
        'sl_SI' => 'словенча (Словения)',
        'sn' => 'шона',
        'sn_ZW' => 'шона (Зимбабве)',
        'so' => 'сомалича',
        'so_DJ' => 'сомалича (Жибути)',
        'so_ET' => 'сомалича (Эфиопия)',
        'so_KE' => 'сомалича (Кения)',
        'so_SO' => 'сомалича (Сомали)',
        'sq' => 'албанча',
        'sq_AL' => 'албанча (Албания)',
        'sq_MK' => 'албанча (Шимолий Македония)',
        'sr' => 'сербча',
        'sr_BA' => 'сербча (Босния ва Герцеговина)',
        'sr_Cyrl' => 'сербча (Кирил)',
        'sr_Cyrl_BA' => 'сербча (Кирил, Босния ва Герцеговина)',
        'sr_Cyrl_ME' => 'сербча (Кирил, Черногория)',
        'sr_Cyrl_RS' => 'сербча (Кирил, Сербия)',
        'sr_Latn' => 'сербча (Лотин)',
        'sr_Latn_BA' => 'сербча (Лотин, Босния ва Герцеговина)',
        'sr_Latn_ME' => 'сербча (Лотин, Черногория)',
        'sr_Latn_RS' => 'сербча (Лотин, Сербия)',
        'sr_ME' => 'сербча (Черногория)',
        'sr_RS' => 'сербча (Сербия)',
        'st_LS' => 'janubiy soto (Лесото)',
        'st_ZA' => 'janubiy soto (Жанубий Африка Республикаси)',
        'su' => 'сунданча',
        'su_ID' => 'сунданча (Индонезия)',
        'su_Latn' => 'сунданча (Лотин)',
        'su_Latn_ID' => 'сунданча (Лотин, Индонезия)',
        'sv' => 'шведча',
        'sv_AX' => 'шведча (Аланд ороллари)',
        'sv_FI' => 'шведча (Финляндия)',
        'sv_SE' => 'шведча (Швеция)',
        'sw' => 'суахили',
        'sw_CD' => 'суахили (Конго-Киншаса)',
        'sw_KE' => 'суахили (Кения)',
        'sw_TZ' => 'суахили (Танзания)',
        'sw_UG' => 'суахили (Уганда)',
        'ta' => 'тамилча',
        'ta_IN' => 'тамилча (Ҳиндистон)',
        'ta_LK' => 'тамилча (Шри-Ланка)',
        'ta_MY' => 'тамилча (Малайзия)',
        'ta_SG' => 'тамилча (Сингапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (Ҳиндистон)',
        'tg' => 'тожикча',
        'tg_TJ' => 'тожикча (Тожикистон)',
        'th' => 'тайча',
        'th_TH' => 'тайча (Таиланд)',
        'ti' => 'тигриняча',
        'ti_ER' => 'тигриняча (Эритрея)',
        'ti_ET' => 'тигриняча (Эфиопия)',
        'tk' => 'туркманча',
        'tk_TM' => 'туркманча (Туркманистон)',
        'tn_BW' => 'tsvana (Ботсванна)',
        'tn_ZA' => 'tsvana (Жанубий Африка Республикаси)',
        'to' => 'тонганча',
        'to_TO' => 'тонганча (Тонга)',
        'tr' => 'туркча',
        'tr_CY' => 'туркча (Кипр)',
        'tr_TR' => 'туркча (Туркия)',
        'tt' => 'татарча',
        'tt_RU' => 'татарча (Россия)',
        'ug' => 'уйғурча',
        'ug_CN' => 'уйғурча (Хитой)',
        'uk' => 'украинча',
        'uk_UA' => 'украинча (Украина)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Ҳиндистон)',
        'ur_PK' => 'урду (Покистон)',
        'uz' => 'ўзбекча',
        'uz_AF' => 'ўзбекча (Афғонистон)',
        'uz_Arab' => 'ўзбекча (Араб)',
        'uz_Arab_AF' => 'ўзбекча (Араб, Афғонистон)',
        'uz_Cyrl' => 'ўзбекча (Кирил)',
        'uz_Cyrl_UZ' => 'ўзбекча (Кирил, Ўзбекистон)',
        'uz_Latn' => 'ўзбекча (Лотин)',
        'uz_Latn_UZ' => 'ўзбекча (Лотин, Ўзбекистон)',
        'uz_UZ' => 'ўзбекча (Ўзбекистон)',
        'vi' => 'ветнамча',
        'vi_VN' => 'ветнамча (Вьетнам)',
        'wo' => 'волофча',
        'wo_SN' => 'волофча (Сенегал)',
        'xh' => 'хоса',
        'xh_ZA' => 'хоса (Жанубий Африка Республикаси)',
        'yi' => 'иддиш',
        'yi_UA' => 'иддиш (Украина)',
        'yo' => 'йоруба',
        'yo_BJ' => 'йоруба (Бенин)',
        'yo_NG' => 'йоруба (Нигерия)',
        'za_CN' => 'Chjuan (Хитой)',
        'zh' => 'хитойча',
        'zh_CN' => 'хитойча (Хитой)',
        'zh_HK' => 'хитойча (Гонконг [Хитой ММҲ])',
        'zh_Hans' => 'хитойча (Соддалаштирилган)',
        'zh_Hans_CN' => 'хитойча (Соддалаштирилган, Хитой)',
        'zh_Hans_HK' => 'хитойча (Соддалаштирилган, Гонконг [Хитой ММҲ])',
        'zh_Hans_MO' => 'хитойча (Соддалаштирилган, Макао [Хитой ММҲ])',
        'zh_Hans_MY' => 'хитойча (Соддалаштирилган, Малайзия)',
        'zh_Hans_SG' => 'хитойча (Соддалаштирилган, Сингапур)',
        'zh_Hant' => 'хитойча (Анъанавий)',
        'zh_Hant_HK' => 'хитойча (Анъанавий, Гонконг [Хитой ММҲ])',
        'zh_Hant_MO' => 'хитойча (Анъанавий, Макао [Хитой ММҲ])',
        'zh_Hant_MY' => 'хитойча (Анъанавий, Малайзия)',
        'zh_Hant_TW' => 'хитойча (Анъанавий, Тайван)',
        'zh_MO' => 'хитойча (Макао [Хитой ММҲ])',
        'zh_SG' => 'хитойча (Сингапур)',
        'zh_TW' => 'хитойча (Тайван)',
        'zu' => 'зулу',
        'zu_ZA' => 'зулу (Жанубий Африка Республикаси)',
    ],
];
