<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibia)',
        'af_ZA' => 'afrikaans (Africa del Sud)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amharico',
        'am_ET' => 'amharico (Ethiopia)',
        'ar' => 'arabe',
        'ar_001' => 'arabe (mundo)',
        'ar_AE' => 'arabe (Emiratos Arabe Unite)',
        'ar_BH' => 'arabe (Bahrain)',
        'ar_DJ' => 'arabe (Djibuti)',
        'ar_DZ' => 'arabe (Algeria)',
        'ar_EG' => 'arabe (Egypto)',
        'ar_EH' => 'arabe (Sahara occidental)',
        'ar_ER' => 'arabe (Eritrea)',
        'ar_IL' => 'arabe (Israel)',
        'ar_IQ' => 'arabe (Irak)',
        'ar_JO' => 'arabe (Jordania)',
        'ar_KM' => 'arabe (Comoros)',
        'ar_KW' => 'arabe (Kuwait)',
        'ar_LB' => 'arabe (Libano)',
        'ar_LY' => 'arabe (Libya)',
        'ar_MA' => 'arabe (Marocco)',
        'ar_MR' => 'arabe (Mauritania)',
        'ar_OM' => 'arabe (Oman)',
        'ar_PS' => 'arabe (Territorios palestin)',
        'ar_QA' => 'arabe (Qatar)',
        'ar_SA' => 'arabe (Arabia Saudita)',
        'ar_SD' => 'arabe (Sudan)',
        'ar_SO' => 'arabe (Somalia)',
        'ar_SS' => 'arabe (Sudan del Sud)',
        'ar_SY' => 'arabe (Syria)',
        'ar_TD' => 'arabe (Tchad)',
        'ar_TN' => 'arabe (Tunisia)',
        'ar_YE' => 'arabe (Yemen)',
        'as' => 'assamese',
        'as_IN' => 'assamese (India)',
        'az' => 'azerbaidzhano',
        'az_AZ' => 'azerbaidzhano (Azerbaidzhan)',
        'az_Cyrl' => 'azerbaidzhano (cyrillic)',
        'az_Cyrl_AZ' => 'azerbaidzhano (cyrillic, Azerbaidzhan)',
        'az_Latn' => 'azerbaidzhano (latin)',
        'az_Latn_AZ' => 'azerbaidzhano (latin, Azerbaidzhan)',
        'ba' => 'bashkir',
        'ba_RU' => 'bashkir (Russia)',
        'be' => 'bielorusso',
        'be_BY' => 'bielorusso (Bielorussia)',
        'bg' => 'bulgaro',
        'bg_BG' => 'bulgaro (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengalese',
        'bn_BD' => 'bengalese (Bangladesh)',
        'bn_IN' => 'bengalese (India)',
        'bo' => 'tibetano',
        'bo_CN' => 'tibetano (China)',
        'bo_IN' => 'tibetano (India)',
        'br' => 'breton',
        'br_FR' => 'breton (Francia)',
        'bs' => 'bosniaco',
        'bs_BA' => 'bosniaco (Bosnia e Herzegovina)',
        'bs_Cyrl' => 'bosniaco (cyrillic)',
        'bs_Cyrl_BA' => 'bosniaco (cyrillic, Bosnia e Herzegovina)',
        'bs_Latn' => 'bosniaco (latin)',
        'bs_Latn_BA' => 'bosniaco (latin, Bosnia e Herzegovina)',
        'ca' => 'catalano',
        'ca_AD' => 'catalano (Andorra)',
        'ca_ES' => 'catalano (Espania)',
        'ca_FR' => 'catalano (Francia)',
        'ca_IT' => 'catalano (Italia)',
        'ce' => 'checheno',
        'ce_RU' => 'checheno (Russia)',
        'cs' => 'checo',
        'cs_CZ' => 'checo (Chechia)',
        'cv' => 'chuvash',
        'cv_RU' => 'chuvash (Russia)',
        'cy' => 'gallese',
        'cy_GB' => 'gallese (Regno Unite)',
        'da' => 'danese',
        'da_DK' => 'danese (Danmark)',
        'da_GL' => 'danese (Groenlandia)',
        'de' => 'germano',
        'de_AT' => 'germano (Austria)',
        'de_BE' => 'germano (Belgica)',
        'de_CH' => 'germano (Suissa)',
        'de_DE' => 'germano (Germania)',
        'de_IT' => 'germano (Italia)',
        'de_LI' => 'germano (Liechtenstein)',
        'de_LU' => 'germano (Luxemburg)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bhutan)',
        'ee' => 'ewe',
        'ee_GH' => 'ewe (Ghana)',
        'ee_TG' => 'ewe (Togo)',
        'el' => 'greco',
        'el_CY' => 'greco (Cypro)',
        'el_GR' => 'greco (Grecia)',
        'en' => 'anglese',
        'en_001' => 'anglese (mundo)',
        'en_150' => 'anglese (Europa)',
        'en_AE' => 'anglese (Emiratos Arabe Unite)',
        'en_AG' => 'anglese (Antigua e Barbuda)',
        'en_AI' => 'anglese (Anguilla)',
        'en_AS' => 'anglese (Samoa american)',
        'en_AT' => 'anglese (Austria)',
        'en_AU' => 'anglese (Australia)',
        'en_BB' => 'anglese (Barbados)',
        'en_BE' => 'anglese (Belgica)',
        'en_BI' => 'anglese (Burundi)',
        'en_BM' => 'anglese (Bermuda)',
        'en_BS' => 'anglese (Bahamas)',
        'en_BW' => 'anglese (Botswana)',
        'en_BZ' => 'anglese (Belize)',
        'en_CA' => 'anglese (Canada)',
        'en_CC' => 'anglese (Insulas Cocos [Keeling])',
        'en_CH' => 'anglese (Suissa)',
        'en_CK' => 'anglese (Insulas Cook)',
        'en_CM' => 'anglese (Camerun)',
        'en_CX' => 'anglese (Insula de Natal)',
        'en_CY' => 'anglese (Cypro)',
        'en_CZ' => 'anglese (Chechia)',
        'en_DE' => 'anglese (Germania)',
        'en_DK' => 'anglese (Danmark)',
        'en_DM' => 'anglese (Dominica)',
        'en_EE' => 'anglese (Estonia)',
        'en_ER' => 'anglese (Eritrea)',
        'en_ES' => 'anglese (Espania)',
        'en_FI' => 'anglese (Finlandia)',
        'en_FJ' => 'anglese (Fiji)',
        'en_FK' => 'anglese (Insulas Falkland)',
        'en_FM' => 'anglese (Micronesia)',
        'en_FR' => 'anglese (Francia)',
        'en_GB' => 'anglese (Regno Unite)',
        'en_GD' => 'anglese (Grenada)',
        'en_GE' => 'anglese (Georgia)',
        'en_GG' => 'anglese (Guernsey)',
        'en_GH' => 'anglese (Ghana)',
        'en_GI' => 'anglese (Gibraltar)',
        'en_GM' => 'anglese (Gambia)',
        'en_GS' => 'anglese (Georgia del Sud e Insulas Sandwich Austral)',
        'en_GU' => 'anglese (Guam)',
        'en_GY' => 'anglese (Guyana)',
        'en_HK' => 'anglese (Hongkong, R.A.S. de China)',
        'en_HU' => 'anglese (Hungaria)',
        'en_ID' => 'anglese (Indonesia)',
        'en_IE' => 'anglese (Irlanda)',
        'en_IL' => 'anglese (Israel)',
        'en_IM' => 'anglese (Insula de Man)',
        'en_IN' => 'anglese (India)',
        'en_IO' => 'anglese (Territorio oceanic britanno-indian)',
        'en_IT' => 'anglese (Italia)',
        'en_JE' => 'anglese (Jersey)',
        'en_JM' => 'anglese (Jamaica)',
        'en_JP' => 'anglese (Japon)',
        'en_KE' => 'anglese (Kenya)',
        'en_KI' => 'anglese (Kiribati)',
        'en_KN' => 'anglese (Sancte Christophoro e Nevis)',
        'en_KY' => 'anglese (Insulas de Caiman)',
        'en_LC' => 'anglese (Sancte Lucia)',
        'en_LR' => 'anglese (Liberia)',
        'en_LS' => 'anglese (Lesotho)',
        'en_LT' => 'anglese (Lituania)',
        'en_LV' => 'anglese (Lettonia)',
        'en_MG' => 'anglese (Madagascar)',
        'en_MH' => 'anglese (Insulas Marshall)',
        'en_MO' => 'anglese (Macao, R.A.S. de China)',
        'en_MP' => 'anglese (Insulas Marianna del Nord)',
        'en_MS' => 'anglese (Montserrat)',
        'en_MT' => 'anglese (Malta)',
        'en_MU' => 'anglese (Mauritio)',
        'en_MV' => 'anglese (Maldivas)',
        'en_MW' => 'anglese (Malawi)',
        'en_MY' => 'anglese (Malaysia)',
        'en_NA' => 'anglese (Namibia)',
        'en_NF' => 'anglese (Insula Norfolk)',
        'en_NG' => 'anglese (Nigeria)',
        'en_NL' => 'anglese (Nederlandia)',
        'en_NO' => 'anglese (Norvegia)',
        'en_NR' => 'anglese (Nauru)',
        'en_NU' => 'anglese (Niue)',
        'en_NZ' => 'anglese (Nove Zelanda)',
        'en_PG' => 'anglese (Papua Nove Guinea)',
        'en_PH' => 'anglese (Philippinas)',
        'en_PK' => 'anglese (Pakistan)',
        'en_PL' => 'anglese (Polonia)',
        'en_PN' => 'anglese (Insulas Pitcairn)',
        'en_PR' => 'anglese (Porto Rico)',
        'en_PT' => 'anglese (Portugal)',
        'en_PW' => 'anglese (Palau)',
        'en_RO' => 'anglese (Romania)',
        'en_RW' => 'anglese (Ruanda)',
        'en_SB' => 'anglese (Insulas Solomon)',
        'en_SC' => 'anglese (Seychelles)',
        'en_SD' => 'anglese (Sudan)',
        'en_SE' => 'anglese (Svedia)',
        'en_SG' => 'anglese (Singapur)',
        'en_SH' => 'anglese (Sancte Helena)',
        'en_SI' => 'anglese (Slovenia)',
        'en_SK' => 'anglese (Slovachia)',
        'en_SL' => 'anglese (Sierra Leone)',
        'en_SS' => 'anglese (Sudan del Sud)',
        'en_SX' => 'anglese (Sancte Martino nederlandese)',
        'en_SZ' => 'anglese (Eswatini)',
        'en_TC' => 'anglese (Insulas Turcos e Caicos)',
        'en_TK' => 'anglese (Tokelau)',
        'en_TO' => 'anglese (Tonga)',
        'en_TT' => 'anglese (Trinidad e Tobago)',
        'en_TV' => 'anglese (Tuvalu)',
        'en_TZ' => 'anglese (Tanzania)',
        'en_UA' => 'anglese (Ukraina)',
        'en_UG' => 'anglese (Uganda)',
        'en_UM' => 'anglese (Insulas peripheric del SUA)',
        'en_US' => 'anglese (Statos Unite)',
        'en_VC' => 'anglese (Sancte Vincente e le Grenadinas)',
        'en_VG' => 'anglese (Insulas Virgine britannic)',
        'en_VI' => 'anglese (Insulas Virgine statounitese)',
        'en_VU' => 'anglese (Vanuatu)',
        'en_WS' => 'anglese (Samoa)',
        'en_ZA' => 'anglese (Africa del Sud)',
        'en_ZM' => 'anglese (Zambia)',
        'en_ZW' => 'anglese (Zimbabwe)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (mundo)',
        'es' => 'espaniol',
        'es_419' => 'espaniol (America latin)',
        'es_AR' => 'espaniol (Argentina)',
        'es_BO' => 'espaniol (Bolivia)',
        'es_BR' => 'espaniol (Brasil)',
        'es_BZ' => 'espaniol (Belize)',
        'es_CL' => 'espaniol (Chile)',
        'es_CO' => 'espaniol (Colombia)',
        'es_CR' => 'espaniol (Costa Rica)',
        'es_CU' => 'espaniol (Cuba)',
        'es_DO' => 'espaniol (Republica Dominican)',
        'es_EC' => 'espaniol (Ecuador)',
        'es_ES' => 'espaniol (Espania)',
        'es_GQ' => 'espaniol (Guinea equatorial)',
        'es_GT' => 'espaniol (Guatemala)',
        'es_HN' => 'espaniol (Honduras)',
        'es_MX' => 'espaniol (Mexico)',
        'es_NI' => 'espaniol (Nicaragua)',
        'es_PA' => 'espaniol (Panama)',
        'es_PE' => 'espaniol (Peru)',
        'es_PH' => 'espaniol (Philippinas)',
        'es_PR' => 'espaniol (Porto Rico)',
        'es_PY' => 'espaniol (Paraguay)',
        'es_SV' => 'espaniol (El Salvador)',
        'es_US' => 'espaniol (Statos Unite)',
        'es_UY' => 'espaniol (Uruguay)',
        'es_VE' => 'espaniol (Venezuela)',
        'et' => 'estoniano',
        'et_EE' => 'estoniano (Estonia)',
        'eu' => 'basco',
        'eu_ES' => 'basco (Espania)',
        'fa' => 'persa',
        'fa_AF' => 'persa (Afghanistan)',
        'fa_IR' => 'persa (Iran)',
        'ff' => 'fula',
        'ff_CM' => 'fula (Camerun)',
        'ff_GN' => 'fula (Guinea)',
        'ff_Latn' => 'fula (latin)',
        'ff_Latn_BF' => 'fula (latin, Burkina Faso)',
        'ff_Latn_CM' => 'fula (latin, Camerun)',
        'ff_Latn_GH' => 'fula (latin, Ghana)',
        'ff_Latn_GM' => 'fula (latin, Gambia)',
        'ff_Latn_GN' => 'fula (latin, Guinea)',
        'ff_Latn_GW' => 'fula (latin, Guinea-Bissau)',
        'ff_Latn_LR' => 'fula (latin, Liberia)',
        'ff_Latn_MR' => 'fula (latin, Mauritania)',
        'ff_Latn_NE' => 'fula (latin, Niger)',
        'ff_Latn_NG' => 'fula (latin, Nigeria)',
        'ff_Latn_SL' => 'fula (latin, Sierra Leone)',
        'ff_Latn_SN' => 'fula (latin, Senegal)',
        'ff_MR' => 'fula (Mauritania)',
        'ff_SN' => 'fula (Senegal)',
        'fi' => 'finnese',
        'fi_FI' => 'finnese (Finlandia)',
        'fo' => 'feroese',
        'fo_DK' => 'feroese (Danmark)',
        'fo_FO' => 'feroese (Insulas Feroe)',
        'fr' => 'francese',
        'fr_BE' => 'francese (Belgica)',
        'fr_BF' => 'francese (Burkina Faso)',
        'fr_BI' => 'francese (Burundi)',
        'fr_BJ' => 'francese (Benin)',
        'fr_BL' => 'francese (Sancte Bartholomeo)',
        'fr_CA' => 'francese (Canada)',
        'fr_CD' => 'francese (Congo - Kinshasa)',
        'fr_CF' => 'francese (Republica African Central)',
        'fr_CG' => 'francese (Congo - Brazzaville)',
        'fr_CH' => 'francese (Suissa)',
        'fr_CI' => 'francese (Costa de Ebore)',
        'fr_CM' => 'francese (Camerun)',
        'fr_DJ' => 'francese (Djibuti)',
        'fr_DZ' => 'francese (Algeria)',
        'fr_FR' => 'francese (Francia)',
        'fr_GA' => 'francese (Gabon)',
        'fr_GF' => 'francese (Guyana francese)',
        'fr_GN' => 'francese (Guinea)',
        'fr_GP' => 'francese (Guadeloupe)',
        'fr_GQ' => 'francese (Guinea equatorial)',
        'fr_HT' => 'francese (Haiti)',
        'fr_KM' => 'francese (Comoros)',
        'fr_LU' => 'francese (Luxemburg)',
        'fr_MA' => 'francese (Marocco)',
        'fr_MC' => 'francese (Monaco)',
        'fr_MF' => 'francese (Sancte Martino francese)',
        'fr_MG' => 'francese (Madagascar)',
        'fr_ML' => 'francese (Mali)',
        'fr_MQ' => 'francese (Martinica)',
        'fr_MR' => 'francese (Mauritania)',
        'fr_MU' => 'francese (Mauritio)',
        'fr_NC' => 'francese (Nove Caledonia)',
        'fr_NE' => 'francese (Niger)',
        'fr_PF' => 'francese (Polynesia francese)',
        'fr_PM' => 'francese (St. Pierre e Miquelon)',
        'fr_RE' => 'francese (Reunion)',
        'fr_RW' => 'francese (Ruanda)',
        'fr_SC' => 'francese (Seychelles)',
        'fr_SN' => 'francese (Senegal)',
        'fr_SY' => 'francese (Syria)',
        'fr_TD' => 'francese (Tchad)',
        'fr_TG' => 'francese (Togo)',
        'fr_TN' => 'francese (Tunisia)',
        'fr_VU' => 'francese (Vanuatu)',
        'fr_WF' => 'francese (Wallis e Futuna)',
        'fr_YT' => 'francese (Mayotte)',
        'fy' => 'frison occidental',
        'fy_NL' => 'frison occidental (Nederlandia)',
        'ga' => 'irlandese',
        'ga_GB' => 'irlandese (Regno Unite)',
        'ga_IE' => 'irlandese (Irlanda)',
        'gd' => 'gaelico scotese',
        'gd_GB' => 'gaelico scotese (Regno Unite)',
        'gl' => 'galleco',
        'gl_ES' => 'galleco (Espania)',
        'gu' => 'gujarati',
        'gu_IN' => 'gujarati (India)',
        'gv' => 'mannese',
        'gv_IM' => 'mannese (Insula de Man)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Niger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'hebreo',
        'he_IL' => 'hebreo (Israel)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (India)',
        'hi_Latn' => 'hindi (latin)',
        'hi_Latn_IN' => 'hindi (latin, India)',
        'hr' => 'croato',
        'hr_BA' => 'croato (Bosnia e Herzegovina)',
        'hr_HR' => 'croato (Croatia)',
        'hu' => 'hungaro',
        'hu_HU' => 'hungaro (Hungaria)',
        'hy' => 'armenio',
        'hy_AM' => 'armenio (Armenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (mundo)',
        'id' => 'indonesiano',
        'id_ID' => 'indonesiano (Indonesia)',
        'ie' => 'interlingue',
        'ie_EE' => 'interlingue (Estonia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeria)',
        'ii' => 'yi de Sichuan',
        'ii_CN' => 'yi de Sichuan (China)',
        'is' => 'islandese',
        'is_IS' => 'islandese (Islanda)',
        'it' => 'italiano',
        'it_CH' => 'italiano (Suissa)',
        'it_IT' => 'italiano (Italia)',
        'it_SM' => 'italiano (San Marino)',
        'it_VA' => 'italiano (Citate del Vaticano)',
        'ja' => 'japonese',
        'ja_JP' => 'japonese (Japon)',
        'jv' => 'javanese',
        'jv_ID' => 'javanese (Indonesia)',
        'ka' => 'georgiano',
        'ka_GE' => 'georgiano (Georgia)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenya)',
        'kk' => 'kazakh',
        'kk_Arab' => 'kazakh (arabe)',
        'kk_Arab_CN' => 'kazakh (arabe, China)',
        'kk_Cyrl' => 'kazakh (cyrillic)',
        'kk_Cyrl_KZ' => 'kazakh (cyrillic, Kazakhstan)',
        'kk_KZ' => 'kazakh (Kazakhstan)',
        'kl' => 'groenlandese',
        'kl_GL' => 'groenlandese (Groenlandia)',
        'km' => 'khmer',
        'km_KH' => 'khmer (Cambodgia)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (India)',
        'ko' => 'coreano',
        'ko_CN' => 'coreano (China)',
        'ko_KP' => 'coreano (Corea del Nord)',
        'ko_KR' => 'coreano (Corea del Sud)',
        'ks' => 'kashmiri',
        'ks_Arab' => 'kashmiri (arabe)',
        'ks_Arab_IN' => 'kashmiri (arabe, India)',
        'ks_Deva' => 'kashmiri (devanagari)',
        'ks_Deva_IN' => 'kashmiri (devanagari, India)',
        'ks_IN' => 'kashmiri (India)',
        'ku' => 'kurdo',
        'ku_Latn' => 'kurdo (latin)',
        'ku_Latn_IQ' => 'kurdo (latin, Irak)',
        'ku_Latn_SY' => 'kurdo (latin, Syria)',
        'ku_Latn_TR' => 'kurdo (latin, Turchia)',
        'ku_SY' => 'kurdo (Syria)',
        'ku_TR' => 'kurdo (Turchia)',
        'kw' => 'cornico',
        'kw_GB' => 'cornico (Regno Unite)',
        'ky' => 'kirghizo',
        'ky_KG' => 'kirghizo (Kirghizistan)',
        'lb' => 'luxemburgese',
        'lb_LU' => 'luxemburgese (Luxemburg)',
        'lg' => 'luganda',
        'lg_UG' => 'luganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Congo - Kinshasa)',
        'ln_CF' => 'lingala (Republica African Central)',
        'ln_CG' => 'lingala (Congo - Brazzaville)',
        'lo' => 'laotiano',
        'lo_LA' => 'laotiano (Laos)',
        'lt' => 'lithuano',
        'lt_LT' => 'lithuano (Lituania)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Congo - Kinshasa)',
        'lv' => 'letton',
        'lv_LV' => 'letton (Lettonia)',
        'mg' => 'malgache',
        'mg_MG' => 'malgache (Madagascar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Nove Zelanda)',
        'mk' => 'macedone',
        'mk_MK' => 'macedone (Macedonia del Nord)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (India)',
        'mn' => 'mongol',
        'mn_MN' => 'mongol (Mongolia)',
        'mr' => 'marathi',
        'mr_IN' => 'marathi (India)',
        'ms' => 'malay',
        'ms_BN' => 'malay (Brunei)',
        'ms_ID' => 'malay (Indonesia)',
        'ms_MY' => 'malay (Malaysia)',
        'ms_SG' => 'malay (Singapur)',
        'mt' => 'maltese',
        'mt_MT' => 'maltese (Malta)',
        'my' => 'birmano',
        'my_MM' => 'birmano (Myanmar [Birmania])',
        'nb' => 'norvegiano bokmål',
        'nb_NO' => 'norvegiano bokmål (Norvegia)',
        'nb_SJ' => 'norvegiano bokmål (Svalbard e Jan Mayen)',
        'nd' => 'ndebele del nord',
        'nd_ZW' => 'ndebele del nord (Zimbabwe)',
        'ne' => 'nepalese',
        'ne_IN' => 'nepalese (India)',
        'ne_NP' => 'nepalese (Nepal)',
        'nl' => 'nederlandese',
        'nl_AW' => 'nederlandese (Aruba)',
        'nl_BE' => 'nederlandese (Belgica)',
        'nl_BQ' => 'nederlandese (Paises Basse caribe)',
        'nl_CW' => 'nederlandese (Curaçao)',
        'nl_NL' => 'nederlandese (Nederlandia)',
        'nl_SR' => 'nederlandese (Suriname)',
        'nl_SX' => 'nederlandese (Sancte Martino nederlandese)',
        'nn' => 'norvegiano nynorsk',
        'nn_NO' => 'norvegiano nynorsk (Norvegia)',
        'no' => 'norvegiano',
        'no_NO' => 'norvegiano (Norvegia)',
        'oc' => 'occitano',
        'oc_ES' => 'occitano (Espania)',
        'oc_FR' => 'occitano (Francia)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Ethiopia)',
        'om_KE' => 'oromo (Kenya)',
        'or' => 'oriya',
        'or_IN' => 'oriya (India)',
        'os' => 'osseto',
        'os_GE' => 'osseto (Georgia)',
        'os_RU' => 'osseto (Russia)',
        'pa' => 'punjabi',
        'pa_Arab' => 'punjabi (arabe)',
        'pa_Arab_PK' => 'punjabi (arabe, Pakistan)',
        'pa_Guru' => 'punjabi (gurmukhi)',
        'pa_Guru_IN' => 'punjabi (gurmukhi, India)',
        'pa_IN' => 'punjabi (India)',
        'pa_PK' => 'punjabi (Pakistan)',
        'pl' => 'polonese',
        'pl_PL' => 'polonese (Polonia)',
        'ps' => 'pashto',
        'ps_AF' => 'pashto (Afghanistan)',
        'ps_PK' => 'pashto (Pakistan)',
        'pt' => 'portugese',
        'pt_AO' => 'portugese (Angola)',
        'pt_BR' => 'portugese (Brasil)',
        'pt_CH' => 'portugese (Suissa)',
        'pt_CV' => 'portugese (Capo Verde)',
        'pt_GQ' => 'portugese (Guinea equatorial)',
        'pt_GW' => 'portugese (Guinea-Bissau)',
        'pt_LU' => 'portugese (Luxemburg)',
        'pt_MO' => 'portugese (Macao, R.A.S. de China)',
        'pt_MZ' => 'portugese (Mozambique)',
        'pt_PT' => 'portugese (Portugal)',
        'pt_ST' => 'portugese (São Tomé e Príncipe)',
        'pt_TL' => 'portugese (Timor del Est)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolivia)',
        'qu_EC' => 'quechua (Ecuador)',
        'qu_PE' => 'quechua (Peru)',
        'rm' => 'romanche',
        'rm_CH' => 'romanche (Suissa)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'romaniano',
        'ro_MD' => 'romaniano (Moldavia)',
        'ro_RO' => 'romaniano (Romania)',
        'ru' => 'russo',
        'ru_BY' => 'russo (Bielorussia)',
        'ru_KG' => 'russo (Kirghizistan)',
        'ru_KZ' => 'russo (Kazakhstan)',
        'ru_MD' => 'russo (Moldavia)',
        'ru_RU' => 'russo (Russia)',
        'ru_UA' => 'russo (Ukraina)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Ruanda)',
        'sa' => 'sanscrito',
        'sa_IN' => 'sanscrito (India)',
        'sc' => 'sardo',
        'sc_IT' => 'sardo (Italia)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arabe)',
        'sd_Arab_PK' => 'sindhi (arabe, Pakistan)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, India)',
        'sd_IN' => 'sindhi (India)',
        'sd_PK' => 'sindhi (Pakistan)',
        'se' => 'sami del nord',
        'se_FI' => 'sami del nord (Finlandia)',
        'se_NO' => 'sami del nord (Norvegia)',
        'se_SE' => 'sami del nord (Svedia)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Republica African Central)',
        'sh' => 'serbocroato',
        'sh_BA' => 'serbocroato (Bosnia e Herzegovina)',
        'si' => 'cingalese',
        'si_LK' => 'cingalese (Sri Lanka)',
        'sk' => 'slovaco',
        'sk_SK' => 'slovaco (Slovachia)',
        'sl' => 'sloveno',
        'sl_SI' => 'sloveno (Slovenia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabwe)',
        'so' => 'somali',
        'so_DJ' => 'somali (Djibuti)',
        'so_ET' => 'somali (Ethiopia)',
        'so_KE' => 'somali (Kenya)',
        'so_SO' => 'somali (Somalia)',
        'sq' => 'albanese',
        'sq_AL' => 'albanese (Albania)',
        'sq_MK' => 'albanese (Macedonia del Nord)',
        'sr' => 'serbo',
        'sr_BA' => 'serbo (Bosnia e Herzegovina)',
        'sr_Cyrl' => 'serbo (cyrillic)',
        'sr_Cyrl_BA' => 'serbo (cyrillic, Bosnia e Herzegovina)',
        'sr_Cyrl_ME' => 'serbo (cyrillic, Montenegro)',
        'sr_Cyrl_RS' => 'serbo (cyrillic, Serbia)',
        'sr_Latn' => 'serbo (latin)',
        'sr_Latn_BA' => 'serbo (latin, Bosnia e Herzegovina)',
        'sr_Latn_ME' => 'serbo (latin, Montenegro)',
        'sr_Latn_RS' => 'serbo (latin, Serbia)',
        'sr_ME' => 'serbo (Montenegro)',
        'sr_RS' => 'serbo (Serbia)',
        'st' => 'sotho del sud',
        'st_LS' => 'sotho del sud (Lesotho)',
        'st_ZA' => 'sotho del sud (Africa del Sud)',
        'su' => 'sundanese',
        'su_ID' => 'sundanese (Indonesia)',
        'su_Latn' => 'sundanese (latin)',
        'su_Latn_ID' => 'sundanese (latin, Indonesia)',
        'sv' => 'svedese',
        'sv_AX' => 'svedese (Insulas Åland)',
        'sv_FI' => 'svedese (Finlandia)',
        'sv_SE' => 'svedese (Svedia)',
        'sw' => 'swahili',
        'sw_CD' => 'swahili (Congo - Kinshasa)',
        'sw_KE' => 'swahili (Kenya)',
        'sw_TZ' => 'swahili (Tanzania)',
        'sw_UG' => 'swahili (Uganda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (India)',
        'ta_LK' => 'tamil (Sri Lanka)',
        'ta_MY' => 'tamil (Malaysia)',
        'ta_SG' => 'tamil (Singapur)',
        'te' => 'telugu',
        'te_IN' => 'telugu (India)',
        'tg' => 'tajiko',
        'tg_TJ' => 'tajiko (Tadzhikistan)',
        'th' => 'thai',
        'th_TH' => 'thai (Thailandia)',
        'ti' => 'tigrinya',
        'ti_ER' => 'tigrinya (Eritrea)',
        'ti_ET' => 'tigrinya (Ethiopia)',
        'tk' => 'turkmeno',
        'tk_TM' => 'turkmeno (Turkmenistan)',
        'tn' => 'tswana',
        'tn_BW' => 'tswana (Botswana)',
        'tn_ZA' => 'tswana (Africa del Sud)',
        'to' => 'tongano',
        'to_TO' => 'tongano (Tonga)',
        'tr' => 'turco',
        'tr_CY' => 'turco (Cypro)',
        'tr_TR' => 'turco (Turchia)',
        'tt' => 'tataro',
        'tt_RU' => 'tataro (Russia)',
        'ug' => 'uighur',
        'ug_CN' => 'uighur (China)',
        'uk' => 'ukrainiano',
        'uk_UA' => 'ukrainiano (Ukraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (India)',
        'ur_PK' => 'urdu (Pakistan)',
        'uz' => 'uzbeko',
        'uz_AF' => 'uzbeko (Afghanistan)',
        'uz_Arab' => 'uzbeko (arabe)',
        'uz_Arab_AF' => 'uzbeko (arabe, Afghanistan)',
        'uz_Cyrl' => 'uzbeko (cyrillic)',
        'uz_Cyrl_UZ' => 'uzbeko (cyrillic, Uzbekistan)',
        'uz_Latn' => 'uzbeko (latin)',
        'uz_Latn_UZ' => 'uzbeko (latin, Uzbekistan)',
        'uz_UZ' => 'uzbeko (Uzbekistan)',
        'vi' => 'vietnamese',
        'vi_VN' => 'vietnamese (Vietnam)',
        'wo' => 'wolof',
        'wo_SN' => 'wolof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Africa del Sud)',
        'yi' => 'yiddish',
        'yi_UA' => 'yiddish (Ukraina)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benin)',
        'yo_NG' => 'yoruba (Nigeria)',
        'za' => 'zhuang',
        'za_CN' => 'zhuang (China)',
        'zh' => 'chinese',
        'zh_CN' => 'chinese (China)',
        'zh_HK' => 'chinese (Hongkong, R.A.S. de China)',
        'zh_Hans' => 'chinese (simplificate)',
        'zh_Hans_CN' => 'chinese (simplificate, China)',
        'zh_Hans_HK' => 'chinese (simplificate, Hongkong, R.A.S. de China)',
        'zh_Hans_MO' => 'chinese (simplificate, Macao, R.A.S. de China)',
        'zh_Hans_MY' => 'chinese (simplificate, Malaysia)',
        'zh_Hans_SG' => 'chinese (simplificate, Singapur)',
        'zh_Hant' => 'chinese (traditional)',
        'zh_Hant_HK' => 'chinese (traditional, Hongkong, R.A.S. de China)',
        'zh_Hant_MO' => 'chinese (traditional, Macao, R.A.S. de China)',
        'zh_Hant_MY' => 'chinese (traditional, Malaysia)',
        'zh_Hant_TW' => 'chinese (traditional, Taiwan)',
        'zh_MO' => 'chinese (Macao, R.A.S. de China)',
        'zh_SG' => 'chinese (Singapur)',
        'zh_TW' => 'chinese (Taiwan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Africa del Sud)',
    ],
];
