<?php

return [
    'Names' => [
        'Aran' => 'nasta’liq',
        'Armn' => 'arménio',
        'Beng' => 'bengalês',
        'Cakm' => 'chakma',
        'Cans' => 'escrita silábica unificada dos aborígenes canadianos',
        'Egyd' => 'egípcio demótico',
        'Egyh' => 'egípcio hierático',
        'Ethi' => 'etíope',
        'Hanb' => 'han com bopomofo',
        'Inds' => 'indus',
        'Orya' => 'odia',
        'Sylo' => 'siloti nagri',
        'Tale' => 'tai le',
        'Telu' => 'telugu',
        'Zsym' => 'símbolos',
        'Zxxx' => 'não escrito',
    ],
];
