<?php

return [
    '🇦🇨' => 'bendèra: Pulo Kenaèkan',
    '🇦🇩' => 'bendèra: Andora',
    '🇦🇪' => 'bendèra: Imarat Arab Rempug',
    '🇦🇫' => 'bendèra: Apganistan',
    '🇦🇬' => 'bendèra: Antigua èn Barbuda',
    '🇦🇮' => 'bendèra: Angguila',
    '🇦🇱' => 'bendèra: Albani',
    '🇦🇲' => 'bendèra: Lemènder',
    '🇦🇴' => 'bendèra: Anggola',
    '🇦🇶' => 'bendèra: Kutub Kidul',
    '🇦🇷' => 'bendèra: Argèntina',
    '🇦🇸' => 'bendèra: Samoa Amrik',
    '🇦🇹' => 'bendèra: Ostenrèk',
    '🇦🇺' => 'bendèra: Ostrali',
    '🇦🇼' => 'bendèra: Aruba',
    '🇦🇽' => 'bendèra: Pulo Olan',
    '🇦🇿' => 'bendèra: Asèrbaijan',
    '🇧🇦' => 'bendèra: Bosni èn Hèrségowina',
    '🇧🇧' => 'bendèra: Barbados',
    '🇧🇩' => 'bendèra: Benggaladésa',
    '🇧🇪' => 'bendèra: Bèlgi',
    '🇧🇫' => 'bendèra: Burkina Paso',
    '🇧🇬' => 'bendèra: Bulgari',
    '🇧🇭' => 'bendèra: Bahrén',
    '🇧🇮' => 'bendèra: Burundi',
    '🇧🇯' => 'bendèra: Bénin',
    '🇧🇱' => 'bendèra: Sint-Bartoloméus',
    '🇧🇲' => 'bendèra: Bermuda',
    '🇧🇳' => 'bendèra: Bruné',
    '🇧🇴' => 'bendèra: Boliwi',
    '🇧🇶' => 'bendèra: Welanda Karaiben',
    '🇧🇷' => 'bendèra: Brasil',
    '🇧🇸' => 'bendèra: Bahama',
    '🇧🇹' => 'bendèra: Butan',
    '🇧🇻' => 'bendèra: Pulo Buwèt',
    '🇧🇼' => 'bendèra: Boswana',
    '🇧🇾' => 'bendèra: Ruslan Puti',
    '🇧🇿' => 'bendèra: Bélis',
    '🇨🇦' => 'bendèra: Kanada',
    '🇨🇨' => 'bendèra: Pulo Kokos (Keeling)',
    '🇨🇩' => 'bendèra: Kongo - Kinsasa',
    '🇨🇫' => 'bendèra: Kiblik Aprika Tenga',
    '🇨🇬' => 'bendèra: Kongo - Brasawil',
    '🇨🇭' => 'bendèra: Switserlan',
    '🇨🇮' => 'bendèra: Panté Gading',
    '🇨🇰' => 'bendèra: Pulo Cook',
    '🇨🇱' => 'bendèra: Cili',
    '🇨🇲' => 'bendèra: Kamérun',
    '🇨🇳' => 'bendèra: Tiongkok',
    '🇨🇴' => 'bendèra: Kolombia',
    '🇨🇵' => 'bendèra: Pulo Kliperten',
    '🇨🇶' => 'bendèra: Sarek',
    '🇨🇷' => 'bendèra: Kosta Rika',
    '🇨🇺' => 'bendèra: Kuba',
    '🇨🇻' => 'bendèra: Tanjung Ijo',
    '🇨🇼' => 'bendèra: Kurasao',
    '🇨🇽' => 'bendèra: Pulo Natal',
    '🇨🇾' => 'bendèra: Sipres',
    '🇨🇿' => 'bendèra: Cèki',
    '🇩🇪' => 'bendèra: Dètslan',
    '🇩🇬' => 'bendèra: Diégo Garsia',
    '🇩🇯' => 'bendèra: Jibuti',
    '🇩🇰' => 'bendèra: Dènemarken',
    '🇩🇲' => 'bendèra: Dominika',
    '🇩🇴' => 'bendèra: Kiblik Dominika',
    '🇩🇿' => 'bendèra: Aljajaèr',
    '🇪🇦' => 'bendèra: Sabtah èn Mélila',
    '🇪🇨' => 'bendèra: Èkuador',
    '🇪🇪' => 'bendèra: Èstlan',
    '🇪🇬' => 'bendèra: Mesir',
    '🇪🇭' => 'bendèra: Sahara Kulon',
    '🇪🇷' => 'bendèra: Èritréa',
    '🇪🇸' => 'bendèra: Spanyol',
    '🇪🇹' => 'bendèra: Habsi (Ètiopi)',
    '🇪🇺' => 'bendèra: Uni Èropa',
    '🇫🇮' => 'bendèra: Pinlan',
    '🇫🇯' => 'bendèra: Piji',
    '🇫🇰' => 'bendèra: Pulo Paklan',
    '🇫🇲' => 'bendèra: Mikronési',
    '🇫🇴' => 'bendèra: Pulo Pèrower',
    '🇫🇷' => 'bendèra: Prasman',
    '🇬🇦' => 'bendèra: Gabon',
    '🇬🇧' => 'bendèra: Kerajaan Rempug',
    '🇬🇩' => 'bendèra: Grénada',
    '🇬🇪' => 'bendèra: Géorgi',
    '🇬🇫' => 'bendèra: Guyana Prasman',
    '🇬🇬' => 'bendèra: Gèrensi',
    '🇬🇭' => 'bendèra: Gana',
    '🇬🇮' => 'bendèra: Jabal Tarik',
    '🇬🇱' => 'bendèra: Grunlan',
    '🇬🇲' => 'bendèra: Gambia',
    '🇬🇳' => 'bendèra: Giné',
    '🇬🇵' => 'bendèra: Guadelup',
    '🇬🇶' => 'bendèra: Giné Katulistiwa',
    '🇬🇷' => 'bendèra: Yunani',
    '🇬🇸' => 'bendèra: Géorgi Kidul èn Pulo Sènwit Kidul',
    '🇬🇹' => 'bendèra: Guatémala',
    '🇬🇺' => 'bendèra: Guam',
    '🇬🇼' => 'bendèra: Giné-Biso',
    '🇬🇾' => 'bendèra: Guyana',
    '🇭🇰' => 'bendèra: Daèrah Bestir Istimèwa Hongkong',
    '🇭🇲' => 'bendèra: Pulo Hered èn MikDonal',
    '🇭🇳' => 'bendèra: Honduras',
    '🇭🇷' => 'bendèra: Kroasi',
    '🇭🇹' => 'bendèra: Haiti',
    '🇭🇺' => 'bendèra: Honggari',
    '🇮🇨' => 'bendèra: Pulo Kenari',
    '🇮🇩' => 'bendèra: Indonésia',
    '🇮🇪' => 'bendèra: Irlan',
    '🇮🇱' => 'bendèra: Israèl',
    '🇮🇲' => 'bendèra: Pulo Man',
    '🇮🇳' => 'bendèra: Hindi',
    '🇮🇴' => 'bendèra: Wilayah Britani di Laotan Hindi',
    '🇮🇶' => 'bendèra: Irak',
    '🇮🇷' => 'bendèra: Iran',
    '🇮🇸' => 'bendèra: Èslan',
    '🇮🇹' => 'bendèra: Itali',
    '🇯🇪' => 'bendèra: Jèrsi',
    '🇯🇲' => 'bendèra: Jamaika',
    '🇯🇴' => 'bendèra: Urdun',
    '🇯🇵' => 'bendèra: Jepang',
    '🇰🇪' => 'bendèra: Kénia',
    '🇰🇬' => 'bendèra: Kirgistan',
    '🇰🇭' => 'bendèra: Kemboja',
    '🇰🇮' => 'bendèra: Kiribati',
    '🇰🇲' => 'bendèra: Komoro',
    '🇰🇳' => 'bendèra: Sint-Kristoper èn Nèwis',
    '🇰🇵' => 'bendèra: Koréa Lor',
    '🇰🇷' => 'bendèra: Koréa Kidul',
    '🇰🇼' => 'bendèra: Kuwét',
    '🇰🇾' => 'bendèra: Pulo Kaèman',
    '🇰🇿' => 'bendèra: Kasakstan',
    '🇱🇦' => 'bendèra: Laos',
    '🇱🇧' => 'bendèra: Lèbanon',
    '🇱🇨' => 'bendèra: Sint Lusia',
    '🇱🇮' => 'bendèra: Lihtenstèn',
    '🇱🇰' => 'bendèra: Sri Langka',
    '🇱🇷' => 'bendèra: Libéria',
    '🇱🇸' => 'bendèra: Lésoto',
    '🇱🇹' => 'bendèra: Litowen',
    '🇱🇺' => 'bendèra: Leksembereh',
    '🇱🇻' => 'bendèra: Lètlan',
    '🇱🇾' => 'bendèra: Libi',
    '🇲🇦' => 'bendèra: Maroko',
    '🇲🇨' => 'bendèra: Monako',
    '🇲🇩' => 'bendèra: Moldawi',
    '🇲🇪' => 'bendèra: Gunung Item (Montenègro)',
    '🇲🇫' => 'bendèra: Sint-Martèn (Prasman)',
    '🇲🇬' => 'bendèra: Madagaskar',
    '🇲🇭' => 'bendèra: Pulo Marsal',
    '🇲🇰' => 'bendèra: Makédoni Lor',
    '🇲🇱' => 'bendèra: Mali',
    '🇲🇲' => 'bendèra: Mianmar (Birma)',
    '🇲🇳' => 'bendèra: Monggoli',
    '🇲🇴' => 'bendèra: Daèrah Bestir Istimèwa Makao',
    '🇲🇵' => 'bendèra: Pulo Mariana Lor',
    '🇲🇶' => 'bendèra: Martinik',
    '🇲🇷' => 'bendèra: Moritani',
    '🇲🇸' => 'bendèra: Monsèrat',
    '🇲🇹' => 'bendèra: Malta',
    '🇲🇺' => 'bendèra: Moritius',
    '🇲🇻' => 'bendèra: Maladéwa',
    '🇲🇼' => 'bendèra: Malawi',
    '🇲🇽' => 'bendèra: Mèksiko',
    '🇲🇾' => 'bendèra: Malésia',
    '🇲🇿' => 'bendèra: Mosambik',
    '🇳🇦' => 'bendèra: Namibi',
    '🇳🇨' => 'bendèra: Kalédoni Baru',
    '🇳🇪' => 'bendèra: Nigèr',
    '🇳🇫' => 'bendèra: Pulo Norpolek',
    '🇳🇬' => 'bendèra: Nigéria',
    '🇳🇮' => 'bendèra: Nikaragua',
    '🇳🇱' => 'bendèra: Welanda',
    '🇳🇴' => 'bendèra: Norwèhen',
    '🇳🇵' => 'bendèra: Népal',
    '🇳🇷' => 'bendèra: Nauru',
    '🇳🇺' => 'bendèra: Niué',
    '🇳🇿' => 'bendèra: Sélan Baru',
    '🇴🇲' => 'bendèra: Oman',
    '🇵🇦' => 'bendèra: Panama',
    '🇵🇪' => 'bendèra: Péru',
    '🇵🇫' => 'bendèra: Polinési Prasman',
    '🇵🇬' => 'bendèra: Papua Giné Baru (Papua Nugini)',
    '🇵🇭' => 'bendèra: Pilipénen (Pilipina)',
    '🇵🇰' => 'bendèra: Pakistan',
    '🇵🇱' => 'bendèra: Polen',
    '🇵🇲' => 'bendèra: Sint-Pièr èn Mikélon',
    '🇵🇳' => 'bendèra: Pulo Pitkèren',
    '🇵🇷' => 'bendèra: Porto Riko',
    '🇵🇸' => 'bendèra: Wilayah Palestèn',
    '🇵🇹' => 'bendèra: Portugal',
    '🇵🇼' => 'bendèra: Palau',
    '🇵🇾' => 'bendèra: Paragué',
    '🇶🇦' => 'bendèra: Katar',
    '🇷🇪' => 'bendèra: Réunion',
    '🇷🇴' => 'bendèra: Ruméni',
    '🇷🇸' => 'bendèra: Sèrwi',
    '🇷🇺' => 'bendèra: Ruslan',
    '🇷🇼' => 'bendèra: Ruanda',
    '🇸🇦' => 'bendèra: Arab Saudi',
    '🇸🇧' => 'bendèra: Pulo Suléman',
    '🇸🇨' => 'bendèra: Sésèl',
    '🇸🇩' => 'bendèra: Sudan',
    '🇸🇪' => 'bendèra: Swèden',
    '🇸🇬' => 'bendèra: Singapur',
    '🇸🇭' => 'bendèra: Sint-Héléna',
    '🇸🇮' => 'bendèra: Slowéni',
    '🇸🇯' => 'bendèra: Spitbèrhen & Jan Mayen',
    '🇸🇰' => 'bendèra: Slowaki',
    '🇸🇱' => 'bendèra: Gunung Singa (Sièra Léon)',
    '🇸🇲' => 'bendèra: San Marino',
    '🇸🇳' => 'bendèra: Sénégal',
    '🇸🇴' => 'bendèra: Somali',
    '🇸🇷' => 'bendèra: Suriname',
    '🇸🇸' => 'bendèra: Sudan Kidul',
    '🇸🇹' => 'bendèra: Sint-Tomas èn Prins',
    '🇸🇻' => 'bendèra: Salbador',
    '🇸🇽' => 'bendèra: Sint-Martèn (Welanda)',
    '🇸🇾' => 'bendèra: Suriah',
    '🇸🇿' => 'bendèra: Èswatini',
    '🇹🇦' => 'bendèra: Tristang da Kunya',
    '🇹🇨' => 'bendèra: Pulo Turks èn Kaikos',
    '🇹🇩' => 'bendèra: Cad',
    '🇹🇫' => 'bendèra: Wilayah Kidul Prasman',
    '🇹🇬' => 'bendèra: Togo',
    '🇹🇭' => 'bendèra: Siam',
    '🇹🇯' => 'bendèra: Tajikistan',
    '🇹🇰' => 'bendèra: Tokélau',
    '🇹🇱' => 'bendèra: Timor Wètan',
    '🇹🇲' => 'bendèra: Turkmènistan',
    '🇹🇳' => 'bendèra: Tunis',
    '🇹🇴' => 'bendèra: Tonga',
    '🇹🇷' => 'bendèra: Turki',
    '🇹🇹' => 'bendèra: Trinidad èn Tobago',
    '🇹🇻' => 'bendèra: Tuwalu',
    '🇹🇼' => 'bendèra: Taiwan',
    '🇹🇿' => 'bendèra: Tansania',
    '🇺🇦' => 'bendèra: Ukrain',
    '🇺🇬' => 'bendèra: Uganda',
    '🇺🇲' => 'bendèra: Kepuloan Mentil AS Luar',
    '🇺🇳' => 'bendèra: Peserèkatan Bangsa-Bangsa',
    '🇺🇸' => 'bendèra: Amrik Serèkat',
    '🇺🇾' => 'bendèra: Urugué',
    '🇺🇿' => 'bendèra: Usbèkistan',
    '🇻🇦' => 'bendèra: Kota Watikan',
    '🇻🇨' => 'bendèra: Sint-Winsèn èn Grénadin',
    '🇻🇪' => 'bendèra: Bénésuèla',
    '🇻🇬' => 'bendèra: Pulo Perawan Britani',
    '🇻🇮' => 'bendèra: Pulo Perawan Amrik',
    '🇻🇳' => 'bendèra: Piètnam',
    '🇻🇺' => 'bendèra: Wanuatu',
    '🇼🇫' => 'bendèra: Walis èn Putuna',
    '🇼🇸' => 'bendèra: Samoa',
    '🇽🇰' => 'bendèra: Kosowa',
    '🇾🇪' => 'bendèra: Yaman',
    '🇾🇹' => 'bendèra: Méot',
    '🇿🇦' => 'bendèra: Aprika Kidul',
    '🇿🇲' => 'bendèra: Sambia',
    '🇿🇼' => 'bendèra: Jimbabwé',
    '😀' => 'muka girang',
    '😃' => 'muka nyengir lèbar',
    '😄' => 'muka girang mata ketutup',
    '😁' => 'muka nyengir',
    '😆' => 'muka ketawa merem',
    '😅' => 'muka girang keringetan',
    '🤣' => 'ngakak',
    '😂' => 'muka nangis seneng',
    '🙂' => 'muka mèsem biasa',
    '🙃' => 'muka kebalik',
    '🫠' => 'muka melèlèh',
    '😉' => 'muka ngedip',
    '😊' => 'muka nahan malu girang',
    '😇' => 'muka malaèkat',
    '🥰' => 'muka senyum kedemenan',
    '😍' => 'muka cinta',
    '🤩' => 'muka seneng mata bintang',
    '😘' => 'muka niupin sun',
    '😗' => 'muka ngesun',
    '☺' => 'muka mèsem seneng',
    '😚' => 'muka ngesun merem pipi mèra',
    '😙' => 'muka ngesun merem',
    '🥲' => 'muka haru',
    '😋' => 'muka lejat',
    '😛' => 'muka mèlèd',
    '😜' => 'muka mèlèd ngedip',
    '🤪' => 'muka pè’a',
    '😝' => 'muka mèlèd merem',
    '🤑' => 'muka napsu duit',
];
