<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Giờ Trung bình Greenwich (Abidjan)',
        'Africa/Accra' => 'Giờ Trung bình Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'Giờ Đông Phi (Addis Ababa)',
        'Africa/Algiers' => 'Giờ Trung Âu (Algiers)',
        'Africa/Asmera' => 'Giờ Đông Phi (Asmara)',
        'Africa/Asmara' => 'Giờ Đông Phi (Asmara)',
        'Africa/Bamako' => 'Giờ Trung bình Greenwich (Bamako)',
        'Africa/Bangui' => 'Giờ Tây Phi (Bangui)',
        'Africa/Banjul' => 'Giờ Trung bình Greenwich (Banjul)',
        'Africa/Bissau' => 'Giờ Trung bình Greenwich (Bissau)',
        'Africa/Blantyre' => 'Giờ Trung Phi (Blantyre)',
        'Africa/Brazzaville' => 'Giờ Tây Phi (Brazzaville)',
        'Africa/Bujumbura' => 'Giờ Trung Phi (Bujumbura)',
        'Africa/Cairo' => 'Giờ Đông Âu (Cairo)',
        'Africa/Casablanca' => 'Giờ Tây Âu (Casablanca)',
        'Africa/Ceuta' => 'Giờ Trung Âu (Ceuta)',
        'Africa/Conakry' => 'Giờ Trung bình Greenwich (Conakry)',
        'Africa/Dakar' => 'Giờ Trung bình Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Giờ Đông Phi (Dar es Salaam)',
        'Africa/Djibouti' => 'Giờ Đông Phi (Djibouti)',
        'Africa/Douala' => 'Giờ Tây Phi (Douala)',
        'Africa/El_Aaiun' => 'Giờ Tây Âu (El Aaiún)',
        'Africa/Freetown' => 'Giờ Trung bình Greenwich (Freetown)',
        'Africa/Gaborone' => 'Giờ Trung Phi (Gaborone)',
        'Africa/Harare' => 'Giờ Trung Phi (Harare)',
        'Africa/Johannesburg' => 'Giờ Chuẩn Nam Phi (Johannesburg)',
        'Africa/Juba' => 'Giờ Trung Phi (Juba)',
        'Africa/Kampala' => 'Giờ Đông Phi (Kampala)',
        'Africa/Khartoum' => 'Giờ Trung Phi (Khartoum)',
        'Africa/Kigali' => 'Giờ Trung Phi (Kigali)',
        'Africa/Kinshasa' => 'Giờ Tây Phi (Kinshasa)',
        'Africa/Lagos' => 'Giờ Tây Phi (Lagos)',
        'Africa/Libreville' => 'Giờ Tây Phi (Libreville)',
        'Africa/Lome' => 'Giờ Trung bình Greenwich (Lomé)',
        'Africa/Luanda' => 'Giờ Tây Phi (Luanda)',
        'Africa/Lubumbashi' => 'Giờ Trung Phi (Lubumbashi)',
        'Africa/Lusaka' => 'Giờ Trung Phi (Lusaka)',
        'Africa/Malabo' => 'Giờ Tây Phi (Malabo)',
        'Africa/Maputo' => 'Giờ Trung Phi (Maputo)',
        'Africa/Maseru' => 'Giờ Chuẩn Nam Phi (Maseru)',
        'Africa/Mbabane' => 'Giờ Chuẩn Nam Phi (Mbabane)',
        'Africa/Mogadishu' => 'Giờ Đông Phi (Mogadishu)',
        'Africa/Monrovia' => 'Giờ Trung bình Greenwich (Monrovia)',
        'Africa/Nairobi' => 'Giờ Đông Phi (Nairobi)',
        'Africa/Ndjamena' => 'Giờ Tây Phi (N’Djamena)',
        'Africa/Niamey' => 'Giờ Tây Phi (Niamey)',
        'Africa/Nouakchott' => 'Giờ Trung bình Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Giờ Trung bình Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Giờ Tây Phi (Porto-Novo)',
        'Africa/Sao_Tome' => 'Giờ Trung bình Greenwich (São Tomé)',
        'Africa/Tripoli' => 'Giờ Đông Âu (Tripoli)',
        'Africa/Tunis' => 'Giờ Trung Âu (Tunis)',
        'Africa/Windhoek' => 'Giờ Trung Phi (Windhoek)',
        'America/Adak' => 'Giờ Hawaii-Aleut (Adak)',
        'America/Anchorage' => 'Giờ Alaska (Anchorage)',
        'America/Anguilla' => 'Giờ Đại Tây Dương (Anguilla)',
        'America/Antigua' => 'Giờ Đại Tây Dương (Antigua)',
        'America/Araguaina' => 'Giờ Brasilia (Araguaína)',
        'America/Argentina/La_Rioja' => 'Giờ Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Giờ Argentina (Río Gallegos)',
        'America/Argentina/Salta' => 'Giờ Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Giờ Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Giờ Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Giờ Argentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'Giờ Argentina (Ushuaia)',
        'America/Aruba' => 'Giờ Đại Tây Dương (Aruba)',
        'America/Asuncion' => 'Giờ Paraguay (Asunción)',
        'America/Bahia' => 'Giờ Brasilia (Bahia)',
        'America/Bahia_Banderas' => 'Giờ miền Trung (Bahia Banderas)',
        'America/Barbados' => 'Giờ Đại Tây Dương (Barbados)',
        'America/Belem' => 'Giờ Brasilia (Belém)',
        'America/Belize' => 'Giờ miền Trung (Belize)',
        'America/Blanc-Sablon' => 'Giờ Đại Tây Dương (Blanc-Sablon)',
        'America/Boa_Vista' => 'Giờ Amazon (Boa Vista)',
        'America/Bogota' => 'Giờ Colombia (Bogotá)',
        'America/Boise' => 'Giờ miền núi (Boise)',
        'America/Buenos_Aires' => 'Giờ Argentina (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Giờ Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Giờ miền núi (Cambridge Bay)',
        'America/Campo_Grande' => 'Giờ Amazon (Campo Grande)',
        'America/Cancun' => 'Giờ miền Đông (Cancun)',
        'America/Caracas' => 'Giờ Venezuela (Caracas)',
        'America/Catamarca' => 'Giờ Argentina (Catamarca)',
        'America/Argentina/Catamarca' => 'Giờ Argentina (Catamarca)',
        'America/Cayenne' => 'Giờ Guiana thuộc Pháp (Cayenne)',
        'America/Cayman' => 'Giờ miền Đông (Cayman)',
        'America/Chicago' => 'Giờ miền Trung (Chicago)',
        'America/Chihuahua' => 'Giờ miền Trung (Chihuahua)',
        'America/Ciudad_Juarez' => 'Giờ miền núi (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Giờ miền Đông (Atikokan)',
        'America/Atikokan' => 'Giờ miền Đông (Atikokan)',
        'America/Cordoba' => 'Giờ Argentina (Córdoba)',
        'America/Argentina/Cordoba' => 'Giờ Argentina (Córdoba)',
        'America/Costa_Rica' => 'Giờ miền Trung (Costa Rica)',
        'America/Coyhaique' => 'Giờ Chile (Coyhaique)',
        'America/Creston' => 'Giờ miền núi (Creston)',
        'America/Cuiaba' => 'Giờ Amazon (Cuiabá)',
        'America/Curacao' => 'Giờ Đại Tây Dương (Curaçao)',
        'America/Danmarkshavn' => 'Giờ Trung bình Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Giờ Yukon (Dawson)',
        'America/Dawson_Creek' => 'Giờ miền núi (Dawson Creek)',
        'America/Denver' => 'Giờ miền núi (Denver)',
        'America/Detroit' => 'Giờ miền Đông (Detroit)',
        'America/Dominica' => 'Giờ Đại Tây Dương (Dominica)',
        'America/Edmonton' => 'Giờ miền núi (Edmonton)',
        'America/Eirunepe' => 'Giờ Acre (Eirunepé)',
        'America/El_Salvador' => 'Giờ miền Trung (El Salvador)',
        'America/Fort_Nelson' => 'Giờ miền núi (Fort Nelson)',
        'America/Fortaleza' => 'Giờ Brasilia (Fortaleza)',
        'America/Glace_Bay' => 'Giờ Đại Tây Dương (Glace Bay)',
        'America/Godthab' => 'Giờ Greenland (Nuuk)',
        'America/Nuuk' => 'Giờ Greenland (Nuuk)',
        'America/Goose_Bay' => 'Giờ Đại Tây Dương (Goose Bay)',
        'America/Grand_Turk' => 'Giờ miền Đông (Grand Turk)',
        'America/Grenada' => 'Giờ Đại Tây Dương (Grenada)',
        'America/Guadeloupe' => 'Giờ Đại Tây Dương (Guadeloupe)',
        'America/Guatemala' => 'Giờ miền Trung (Guatemala)',
        'America/Guayaquil' => 'Giờ Ecuador (Guayaquil)',
        'America/Guyana' => 'Giờ Guyana',
        'America/Halifax' => 'Giờ Đại Tây Dương (Halifax)',
        'America/Havana' => 'Giờ Cuba (Havana)',
        'America/Hermosillo' => 'Giờ Thái Bình Dương Mexico (Hermosillo)',
        'America/Indiana/Knox' => 'Giờ miền Trung (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Giờ miền Đông (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Giờ miền Đông (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Giờ miền Trung (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Giờ miền Đông (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Giờ miền Đông (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Giờ miền Đông (Winamac, Indiana)',
        'America/Indianapolis' => 'Giờ miền Đông (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Giờ miền Đông (Indianapolis)',
        'America/Inuvik' => 'Giờ miền núi (Inuvik)',
        'America/Iqaluit' => 'Giờ miền Đông (Iqaluit)',
        'America/Jamaica' => 'Giờ miền Đông (Jamaica)',
        'America/Jujuy' => 'Giờ Argentina (Jujuy)',
        'America/Argentina/Jujuy' => 'Giờ Argentina (Jujuy)',
        'America/Juneau' => 'Giờ Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Giờ miền Đông (Monticello, Kentucky)',
        'America/Kralendijk' => 'Giờ Đại Tây Dương (Kralendijk)',
        'America/La_Paz' => 'Giờ Bolivia (La Paz)',
        'America/Lima' => 'Giờ Peru (Lima)',
        'America/Los_Angeles' => 'Giờ Thái Bình Dương (Los Angeles)',
        'America/Louisville' => 'Giờ miền Đông (Louisville)',
        'America/Kentucky/Louisville' => 'Giờ miền Đông (Louisville)',
        'America/Lower_Princes' => 'Giờ Đại Tây Dương (Lower Prince’s Quarter)',
        'America/Maceio' => 'Giờ Brasilia (Maceió)',
        'America/Managua' => 'Giờ miền Trung (Managua)',
        'America/Manaus' => 'Giờ Amazon (Manaus)',
        'America/Marigot' => 'Giờ Đại Tây Dương (Marigot)',
        'America/Martinique' => 'Giờ Đại Tây Dương (Martinique)',
        'America/Matamoros' => 'Giờ miền Trung (Matamoros)',
        'America/Mazatlan' => 'Giờ Thái Bình Dương Mexico (Mazatlán)',
        'America/Mendoza' => 'Giờ Argentina (Mendoza)',
        'America/Argentina/Mendoza' => 'Giờ Argentina (Mendoza)',
        'America/Menominee' => 'Giờ miền Trung (Menominee)',
        'America/Merida' => 'Giờ miền Trung (Merida)',
        'America/Metlakatla' => 'Giờ Alaska (Metlakatla)',
        'America/Mexico_City' => 'Giờ miền Trung (Ciudad de México)',
        'America/Miquelon' => 'Giờ St. Pierre và Miquelon (Saint-Pierre)',
        'America/Moncton' => 'Giờ Đại Tây Dương (Moncton)',
        'America/Monterrey' => 'Giờ miền Trung (Monterrey)',
        'America/Montevideo' => 'Giờ Uruguay (Montevideo)',
        'America/Montserrat' => 'Giờ Đại Tây Dương (Montserrat)',
        'America/Nassau' => 'Giờ miền Đông (Nassau)',
        'America/New_York' => 'Giờ miền Đông (New York)',
        'America/Nome' => 'Giờ Alaska (Nome)',
        'America/Noronha' => 'Giờ Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Giờ miền Trung (Beulah, Bắc Dakota)',
        'America/North_Dakota/Center' => 'Giờ miền Trung (Center, Bắc Dakota)',
        'America/North_Dakota/New_Salem' => 'Giờ miền Trung (New Salem, Bắc Dakota)',
        'America/Ojinaga' => 'Giờ miền Trung (Ojinaga)',
        'America/Panama' => 'Giờ miền Đông (Panama)',
        'America/Paramaribo' => 'Giờ Suriname (Paramaribo)',
        'America/Phoenix' => 'Giờ miền núi (Phoenix)',
        'America/Port-au-Prince' => 'Giờ miền Đông (Port-au-Prince)',
        'America/Port_of_Spain' => 'Giờ Đại Tây Dương (Port of Spain)',
        'America/Porto_Velho' => 'Giờ Amazon (Porto Velho)',
        'America/Puerto_Rico' => 'Giờ Đại Tây Dương (Puerto Rico)',
        'America/Punta_Arenas' => 'Giờ Chile (Punta Arenas)',
        'America/Rankin_Inlet' => 'Giờ miền Trung (Rankin Inlet)',
        'America/Recife' => 'Giờ Brasilia (Recife)',
        'America/Regina' => 'Giờ miền Trung (Regina)',
        'America/Resolute' => 'Giờ miền Trung (Resolute)',
        'America/Rio_Branco' => 'Giờ Acre (Rio Branco)',
        'America/Santarem' => 'Giờ Brasilia (Santarém)',
        'America/Santiago' => 'Giờ Chile (Santiago)',
        'America/Santo_Domingo' => 'Giờ Đại Tây Dương (Santo Domingo)',
        'America/Sao_Paulo' => 'Giờ Brasilia (São Paulo)',
        'America/Scoresbysund' => 'Giờ Greenland (Ittoqqortoormiit)',
        'America/Sitka' => 'Giờ Alaska (Sitka)',
        'America/St_Barthelemy' => 'Giờ Đại Tây Dương (St. Barthélemy)',
        'America/St_Johns' => 'Giờ Newfoundland (St. John’s)',
        'America/St_Kitts' => 'Giờ Đại Tây Dương (St. Kitts)',
        'America/St_Lucia' => 'Giờ Đại Tây Dương (St. Lucia)',
        'America/St_Thomas' => 'Giờ Đại Tây Dương (St. Thomas)',
        'America/St_Vincent' => 'Giờ Đại Tây Dương (St. Vincent)',
        'America/Swift_Current' => 'Giờ miền Trung (Swift Current)',
        'America/Tegucigalpa' => 'Giờ miền Trung (Tegucigalpa)',
        'America/Thule' => 'Giờ Đại Tây Dương (Thule)',
        'America/Tijuana' => 'Giờ Thái Bình Dương (Tijuana)',
        'America/Toronto' => 'Giờ miền Đông (Toronto)',
        'America/Tortola' => 'Giờ Đại Tây Dương (Tortola)',
        'America/Vancouver' => 'Giờ Thái Bình Dương (Vancouver)',
        'America/Whitehorse' => 'Giờ Yukon (Whitehorse)',
        'America/Winnipeg' => 'Giờ miền Trung (Winnipeg)',
        'America/Yakutat' => 'Giờ Alaska (Yakutat)',
        'Antarctica/Casey' => 'Giờ Miền Tây Australia (Casey)',
        'Antarctica/Davis' => 'Giờ Davis',
        'Antarctica/DumontDUrville' => 'Giờ Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Giờ Miền Đông Australia (Macquarie)',
        'Antarctica/Mawson' => 'Giờ Mawson',
        'Antarctica/McMurdo' => 'Giờ New Zealand (McMurdo)',
        'Antarctica/Palmer' => 'Giờ Chile (Palmer)',
        'Antarctica/Rothera' => 'Giờ Rothera',
        'Antarctica/Syowa' => 'Giờ Syowa (Showa)',
        'Antarctica/Troll' => 'Giờ Trung bình Greenwich (Troll)',
        'Antarctica/Vostok' => 'Giờ Vostok',
        'Arctic/Longyearbyen' => 'Giờ Trung Âu (Longyearbyen)',
        'Asia/Aden' => 'Giờ Ả Rập (Aden)',
        'Asia/Almaty' => 'Giờ Kazakhstan (Almaty)',
        'Asia/Amman' => 'Giờ Đông Âu (Amman)',
        'Asia/Anadyr' => 'Giờ Petropavlovsk-Kamchatski (Anadyr)',
        'Asia/Aqtau' => 'Giờ Kazakhstan (Aqtau)',
        'Asia/Aqtobe' => 'Giờ Kazakhstan (Aqtobe)',
        'Asia/Ashgabat' => 'Giờ Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'Giờ Kazakhstan (Atyrau)',
        'Asia/Baghdad' => 'Giờ Ả Rập (Baghdad)',
        'Asia/Bahrain' => 'Giờ Ả Rập (Bahrain)',
        'Asia/Baku' => 'Giờ Azerbaijan (Baku)',
        'Asia/Bangkok' => 'Giờ Đông Dương (Bangkok)',
        'Asia/Barnaul' => 'Giờ Krasnoyarsk (Barnaul)',
        'Asia/Beirut' => 'Giờ Đông Âu (Beirut)',
        'Asia/Bishkek' => 'Giờ Kyrgystan (Bishkek)',
        'Asia/Brunei' => 'Giờ Brunei Darussalam',
        'Asia/Calcutta' => 'Giờ Chuẩn Ấn Độ (Kolkata)',
        'Asia/Kolkata' => 'Giờ Chuẩn Ấn Độ (Kolkata)',
        'Asia/Chita' => 'Giờ Yakutsk (Chita)',
        'Asia/Colombo' => 'Giờ Chuẩn Ấn Độ (Colombo)',
        'Asia/Damascus' => 'Giờ Đông Âu (Damascus)',
        'Asia/Dhaka' => 'Giờ Bangladesh (Dhaka)',
        'Asia/Dili' => 'Giờ Đông Timor (Dili)',
        'Asia/Dubai' => 'Giờ Chuẩn Vùng Vịnh (Dubai)',
        'Asia/Dushanbe' => 'Giờ Tajikistan (Dushanbe)',
        'Asia/Famagusta' => 'Giờ Đông Âu (Famagusta)',
        'Asia/Gaza' => 'Giờ Đông Âu (Gaza)',
        'Asia/Hebron' => 'Giờ Đông Âu (Hebron)',
        'Asia/Hong_Kong' => 'Giờ Hồng Kông',
        'Asia/Hovd' => 'Giờ Hovd (Khovd)',
        'Asia/Irkutsk' => 'Giờ Irkutsk',
        'Asia/Jakarta' => 'Giờ Miền Tây Indonesia (Jakarta)',
        'Asia/Jayapura' => 'Giờ Miền Đông Indonesia (Jayapura)',
        'Asia/Jerusalem' => 'Giờ Israel (Jerusalem)',
        'Asia/Kabul' => 'Giờ Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'Giờ Petropavlovsk-Kamchatski (Kamchatka)',
        'Asia/Karachi' => 'Giờ Pakistan (Karachi)',
        'Asia/Katmandu' => 'Giờ Nepal (Kathmandu)',
        'Asia/Kathmandu' => 'Giờ Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Giờ Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Giờ Krasnoyarsk',
        'Asia/Kuala_Lumpur' => 'Giờ Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'Giờ Malaysia (Kuching)',
        'Asia/Kuwait' => 'Giờ Ả Rập (Kuwait)',
        'Asia/Macau' => 'Giờ Trung Quốc (Ma Cao)',
        'Asia/Magadan' => 'Giờ Magadan',
        'Asia/Makassar' => 'Giờ Miền Trung Indonesia (Makassar)',
        'Asia/Manila' => 'Giờ Philippin (Manila)',
        'Asia/Muscat' => 'Giờ Chuẩn Vùng Vịnh (Muscat)',
        'Asia/Nicosia' => 'Giờ Đông Âu (Nicosia)',
        'Asia/Novokuznetsk' => 'Giờ Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Giờ Krasnoyarsk (Novosibirsk)',
        'Asia/Omsk' => 'Giờ Omsk',
        'Asia/Oral' => 'Giờ Kazakhstan (Oral)',
        'Asia/Phnom_Penh' => 'Giờ Đông Dương (Phnom Penh)',
        'Asia/Pontianak' => 'Giờ Miền Tây Indonesia (Pontianak)',
        'Asia/Pyongyang' => 'Giờ Hàn Quốc (Bình Nhưỡng)',
        'Asia/Qatar' => 'Giờ Ả Rập (Qatar)',
        'Asia/Qostanay' => 'Giờ Kazakhstan (Kostanay)',
        'Asia/Qyzylorda' => 'Giờ Kazakhstan (Qyzylorda)',
        'Asia/Rangoon' => 'Giờ Myanmar (Rangoon)',
        'Asia/Yangon' => 'Giờ Myanmar (Rangoon)',
        'Asia/Riyadh' => 'Giờ Ả Rập (Riyadh)',
        'Asia/Saigon' => 'Giờ Đông Dương (TP Hồ Chí Minh)',
        'Asia/Ho_Chi_Minh' => 'Giờ Đông Dương (TP Hồ Chí Minh)',
        'Asia/Sakhalin' => 'Giờ Magadan (Sakhalin)',
        'Asia/Samarkand' => 'Giờ Uzbekistan (Samarkand)',
        'Asia/Seoul' => 'Giờ Hàn Quốc (Seoul)',
        'Asia/Shanghai' => 'Giờ Trung Quốc (Thượng Hải)',
        'Asia/Singapore' => 'Giờ Singapore',
        'Asia/Srednekolymsk' => 'Giờ Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Giờ Đài Bắc',
        'Asia/Tashkent' => 'Giờ Uzbekistan (Tashkent)',
        'Asia/Tbilisi' => 'Giờ Georgia (Tbilisi)',
        'Asia/Tehran' => 'Giờ Iran (Tehran)',
        'Asia/Thimphu' => 'Giờ Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Giờ Nhật Bản (Tokyo)',
        'Asia/Tomsk' => 'Giờ Krasnoyarsk (Tomsk)',
        'Asia/Ulaanbaatar' => 'Giờ Ulan Bator',
        'Asia/Urumqi' => 'Giờ Trung Quốc (Ürümqi)',
        'Asia/Ust-Nera' => 'Giờ Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Giờ Đông Dương (Viêng Chăn)',
        'Asia/Vladivostok' => 'Giờ Vladivostok',
        'Asia/Yakutsk' => 'Giờ Yakutsk',
        'Asia/Yekaterinburg' => 'Giờ Yekaterinburg',
        'Asia/Yerevan' => 'Giờ Armenia (Yerevan)',
        'Atlantic/Azores' => 'Giờ Azores',
        'Atlantic/Bermuda' => 'Giờ Đại Tây Dương (Bermuda)',
        'Atlantic/Canary' => 'Giờ Tây Âu (Canarias)',
        'Atlantic/Cape_Verde' => 'Giờ Cape Verde',
        'Atlantic/Faeroe' => 'Giờ Tây Âu (Faroe)',
        'Atlantic/Faroe' => 'Giờ Tây Âu (Faroe)',
        'Atlantic/Madeira' => 'Giờ Tây Âu (Madeira)',
        'Atlantic/Reykjavik' => 'Giờ Trung bình Greenwich (Reykjavik)',
        'Atlantic/South_Georgia' => 'Giờ Nam Georgia',
        'Atlantic/St_Helena' => 'Giờ Trung bình Greenwich (St. Helena)',
        'Atlantic/Stanley' => 'Giờ Quần Đảo Falkland (Stanley)',
        'Australia/Adelaide' => 'Giờ Miền Trung Australia (Adelaide)',
        'Australia/Brisbane' => 'Giờ Miền Đông Australia (Brisbane)',
        'Australia/Broken_Hill' => 'Giờ Miền Trung Australia (Broken Hill)',
        'Australia/Darwin' => 'Giờ Miền Trung Australia (Darwin)',
        'Australia/Eucla' => 'Giờ Miền Trung Tây Australia (Eucla)',
        'Australia/Hobart' => 'Giờ Miền Đông Australia (Hobart)',
        'Australia/Lindeman' => 'Giờ Miền Đông Australia (Lindeman)',
        'Australia/Lord_Howe' => 'Giờ Lord Howe',
        'Australia/Melbourne' => 'Giờ Miền Đông Australia (Melbourne)',
        'Australia/Perth' => 'Giờ Miền Tây Australia (Perth)',
        'Australia/Sydney' => 'Giờ Miền Đông Australia (Sydney)',
        'Etc/GMT' => 'Giờ Trung bình Greenwich',
        'Etc/UTC' => 'Giờ Phối hợp Quốc tế',
        'Europe/Amsterdam' => 'Giờ Trung Âu (Amsterdam)',
        'Europe/Andorra' => 'Giờ Trung Âu (Andorra)',
        'Europe/Astrakhan' => 'Giờ Samara (Astrakhan)',
        'Europe/Athens' => 'Giờ Đông Âu (Athens)',
        'Europe/Belgrade' => 'Giờ Trung Âu (Belgrade)',
        'Europe/Berlin' => 'Giờ Trung Âu (Berlin)',
        'Europe/Bratislava' => 'Giờ Trung Âu (Bratislava)',
        'Europe/Brussels' => 'Giờ Trung Âu (Brussels)',
        'Europe/Bucharest' => 'Giờ Đông Âu (Bucharest)',
        'Europe/Budapest' => 'Giờ Trung Âu (Budapest)',
        'Europe/Busingen' => 'Giờ Trung Âu (Büsingen)',
        'Europe/Chisinau' => 'Giờ Đông Âu (Chișinău)',
        'Europe/Copenhagen' => 'Giờ Trung Âu (Copenhagen)',
        'Europe/Dublin' => 'Giờ Trung bình Greenwich (Dublin)',
        'Europe/Gibraltar' => 'Giờ Trung Âu (Gibraltar)',
        'Europe/Guernsey' => 'Giờ Trung bình Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Giờ Đông Âu (Helsinki)',
        'Europe/Isle_of_Man' => 'Giờ Trung bình Greenwich (Đảo Man)',
        'Europe/Istanbul' => 'Giờ Thổ Nhĩ Kỳ (Istanbul)',
        'Europe/Jersey' => 'Giờ Trung bình Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Giờ Đông Âu (Kaliningrad)',
        'Europe/Kiev' => 'Giờ Đông Âu (Kiev)',
        'Europe/Kyiv' => 'Giờ Đông Âu (Kiev)',
        'Europe/Kirov' => 'Giờ Matxcơva (Kirov)',
        'Europe/Lisbon' => 'Giờ Tây Âu (Lisbon)',
        'Europe/Ljubljana' => 'Giờ Trung Âu (Ljubljana)',
        'Europe/London' => 'Giờ Trung bình Greenwich (London)',
        'Europe/Luxembourg' => 'Giờ Trung Âu (Luxembourg)',
        'Europe/Madrid' => 'Giờ Trung Âu (Madrid)',
        'Europe/Malta' => 'Giờ Trung Âu (Malta)',
        'Europe/Mariehamn' => 'Giờ Đông Âu (Mariehamn)',
        'Europe/Minsk' => 'Giờ Matxcơva (Minsk)',
        'Europe/Monaco' => 'Giờ Trung Âu (Monaco)',
        'Europe/Moscow' => 'Giờ Matxcơva (Mát-xcơ-va)',
        'Europe/Oslo' => 'Giờ Trung Âu (Oslo)',
        'Europe/Paris' => 'Giờ Trung Âu (Paris)',
        'Europe/Podgorica' => 'Giờ Trung Âu (Podgorica)',
        'Europe/Prague' => 'Giờ Trung Âu (Praha)',
        'Europe/Riga' => 'Giờ Đông Âu (Riga)',
        'Europe/Rome' => 'Giờ Trung Âu (Rome)',
        'Europe/Samara' => 'Giờ Samara',
        'Europe/San_Marino' => 'Giờ Trung Âu (San Marino)',
        'Europe/Sarajevo' => 'Giờ Trung Âu (Sarajevo)',
        'Europe/Saratov' => 'Giờ Samara (Saratov)',
        'Europe/Simferopol' => 'Giờ Matxcơva (Simferopol)',
        'Europe/Skopje' => 'Giờ Trung Âu (Skopje)',
        'Europe/Sofia' => 'Giờ Đông Âu (Sofia)',
        'Europe/Stockholm' => 'Giờ Trung Âu (Stockholm)',
        'Europe/Tallinn' => 'Giờ Đông Âu (Tallinn)',
        'Europe/Tirane' => 'Giờ Trung Âu (Tirana)',
        'Europe/Ulyanovsk' => 'Giờ Samara (Ulyanovsk)',
        'Europe/Vaduz' => 'Giờ Trung Âu (Vaduz)',
        'Europe/Vatican' => 'Giờ Trung Âu (Vatican)',
        'Europe/Vienna' => 'Giờ Trung Âu (Vienna)',
        'Europe/Vilnius' => 'Giờ Đông Âu (Vilnius)',
        'Europe/Volgograd' => 'Giờ Matxcơva (Volgograd)',
        'Europe/Warsaw' => 'Giờ Trung Âu (Warsaw)',
        'Europe/Zagreb' => 'Giờ Trung Âu (Zagreb)',
        'Europe/Zurich' => 'Giờ Trung Âu (Zurich)',
        'Indian/Antananarivo' => 'Giờ Đông Phi (Antananarivo)',
        'Indian/Chagos' => 'Giờ Ấn Độ Dương (Chagos)',
        'Indian/Christmas' => 'Giờ Đảo Christmas',
        'Indian/Cocos' => 'Giờ Quần Đảo Cocos',
        'Indian/Comoro' => 'Giờ Đông Phi (Comores)',
        'Indian/Kerguelen' => 'Giờ Nam Cực và Nam Nước Pháp (Kerguelen)',
        'Indian/Mahe' => 'Giờ Seychelles (Mahé)',
        'Indian/Maldives' => 'Giờ Maldives',
        'Indian/Mauritius' => 'Giờ Mauritius',
        'Indian/Mayotte' => 'Giờ Đông Phi (Mayotte)',
        'Indian/Reunion' => 'Giờ Reunion (Réunion)',
        'Pacific/Apia' => 'Giờ Apia',
        'Pacific/Auckland' => 'Giờ New Zealand (Auckland)',
        'Pacific/Bougainville' => 'Giờ Papua New Guinea (Bougainville)',
        'Pacific/Chatham' => 'Giờ Chatham',
        'Pacific/Easter' => 'Giờ Đảo Phục Sinh (Easter)',
        'Pacific/Efate' => 'Giờ Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Giờ Quần Đảo Phoenix (Đảo Canton)',
        'Pacific/Kanton' => 'Giờ Quần Đảo Phoenix (Đảo Canton)',
        'Pacific/Fakaofo' => 'Giờ Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Giờ Fiji',
        'Pacific/Funafuti' => 'Giờ Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Giờ Galapagos (Galápagos)',
        'Pacific/Gambier' => 'Giờ Gambier',
        'Pacific/Guadalcanal' => 'Giờ Quần Đảo Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Giờ Chamorro (Guam)',
        'Pacific/Honolulu' => 'Giờ Chuẩn Hawaii-Aleut (Honolulu)',
        'Pacific/Kiritimati' => 'Giờ Quần Đảo Line (Kiritimati)',
        'Pacific/Kosrae' => 'Giờ Kosrae',
        'Pacific/Kwajalein' => 'Giờ Quần Đảo Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Giờ Quần Đảo Marshall (Majuro)',
        'Pacific/Marquesas' => 'Giờ Marquesas',
        'Pacific/Midway' => 'Giờ Samoa (Midway)',
        'Pacific/Nauru' => 'Giờ Nauru',
        'Pacific/Niue' => 'Giờ Niue',
        'Pacific/Norfolk' => 'Giờ Đảo Norfolk',
        'Pacific/Noumea' => 'Giờ New Caledonia (Nouméa)',
        'Pacific/Pago_Pago' => 'Giờ Samoa (Pago Pago)',
        'Pacific/Palau' => 'Giờ Palau',
        'Pacific/Pitcairn' => 'Giờ Pitcairn',
        'Pacific/Ponape' => 'Giờ Ponape (Pohnpei)',
        'Pacific/Pohnpei' => 'Giờ Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Giờ Papua New Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Giờ Quần Đảo Cook (Rarotonga)',
        'Pacific/Saipan' => 'Giờ Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Giờ Tahiti',
        'Pacific/Tarawa' => 'Giờ Quần Đảo Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Giờ Tonga (Tongatapu)',
        'Pacific/Truk' => 'Giờ Chuuk',
        'Pacific/Chuuk' => 'Giờ Chuuk',
        'Pacific/Wake' => 'Giờ Đảo Wake',
        'Pacific/Wallis' => 'Giờ Wallis và Futuna (Wallis & Futuna)',
    ],
    'Meta' => [],
];
