<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'گرينۆيچ ۋاقىتى (ابيدجان)',
        'Africa/Accra' => 'گرينۆيچ ۋاقىتى (اككرا)',
        'Africa/Addis_Ababa' => 'شىعىس افريكا ۋاقىتى (ادديس-ابەبا)',
        'Africa/Algiers' => 'ورتالىق ەۋروپا ۋاقىتى (الجير)',
        'Africa/Asmera' => 'شىعىس افريكا ۋاقىتى (اسمارا)',
        'Africa/Asmara' => 'شىعىس افريكا ۋاقىتى (اسمارا)',
        'Africa/Bamako' => 'گرينۆيچ ۋاقىتى (باماكو)',
        'Africa/Bangui' => 'باتىس افريكا ۋاقىتى (بانگي)',
        'Africa/Banjul' => 'گرينۆيچ ۋاقىتى (بانجۋل)',
        'Africa/Bissau' => 'گرينۆيچ ۋاقىتى (بيساۋ)',
        'Africa/Blantyre' => 'ورتالىق افريكا ۋاقىتى (بلانتاير)',
        'Africa/Brazzaville' => 'باتىس افريكا ۋاقىتى (براززاۆيل)',
        'Africa/Bujumbura' => 'ورتالىق افريكا ۋاقىتى (بۋجۋمبۋرا)',
        'Africa/Cairo' => 'شىعىس ەۋروپا ۋاقىتى (كاير)',
        'Africa/Casablanca' => 'باتىس ەۋروپا ۋاقىتى (كاسابلانكا)',
        'Africa/Ceuta' => 'ورتالىق ەۋروپا ۋاقىتى (سەۋتا)',
        'Africa/Conakry' => 'گرينۆيچ ۋاقىتى (كوناكري)',
        'Africa/Dakar' => 'گرينۆيچ ۋاقىتى (داكار)',
        'Africa/Dar_es_Salaam' => 'شىعىس افريكا ۋاقىتى (دار-ەس-سالام)',
        'Africa/Djibouti' => 'شىعىس افريكا ۋاقىتى (جيبۋتي)',
        'Africa/Douala' => 'باتىس افريكا ۋاقىتى (دۋالا)',
        'Africa/El_Aaiun' => 'باتىس ەۋروپا ۋاقىتى (ەل-ايۋن)',
        'Africa/Freetown' => 'گرينۆيچ ۋاقىتى (فريتاۋن)',
        'Africa/Gaborone' => 'ورتالىق افريكا ۋاقىتى (گابورونە)',
        'Africa/Harare' => 'ورتالىق افريكا ۋاقىتى (حارارە)',
        'Africa/Johannesburg' => 'وڭتۇستىك افريكا ستاندارتتى ۋاقىتى (يوحاننەسبۋرگ)',
        'Africa/Juba' => 'ورتالىق افريكا ۋاقىتى (جۋبا)',
        'Africa/Kampala' => 'شىعىس افريكا ۋاقىتى (كامپالا)',
        'Africa/Khartoum' => 'ورتالىق افريكا ۋاقىتى (حارتۋم)',
        'Africa/Kigali' => 'ورتالىق افريكا ۋاقىتى (كيگالي)',
        'Africa/Kinshasa' => 'باتىس افريكا ۋاقىتى (كينشاسا)',
        'Africa/Lagos' => 'باتىس افريكا ۋاقىتى (لاگوس)',
        'Africa/Libreville' => 'باتىس افريكا ۋاقىتى (ليبرەۆيل)',
        'Africa/Lome' => 'گرينۆيچ ۋاقىتى (لومە)',
        'Africa/Luanda' => 'باتىس افريكا ۋاقىتى (لۋاندا)',
        'Africa/Lubumbashi' => 'ورتالىق افريكا ۋاقىتى (لۋبۋمباشي)',
        'Africa/Lusaka' => 'ورتالىق افريكا ۋاقىتى (لۋساكا)',
        'Africa/Malabo' => 'باتىس افريكا ۋاقىتى (مالابو)',
        'Africa/Maputo' => 'ورتالىق افريكا ۋاقىتى (ماپۋتۋ)',
        'Africa/Maseru' => 'وڭتۇستىك افريكا ستاندارتتى ۋاقىتى (ماسەرۋ)',
        'Africa/Mbabane' => 'وڭتۇستىك افريكا ستاندارتتى ۋاقىتى (مبابەنە)',
        'Africa/Mogadishu' => 'شىعىس افريكا ۋاقىتى (موگاديشۋ)',
        'Africa/Monrovia' => 'گرينۆيچ ۋاقىتى (مونروۆيا)',
        'Africa/Nairobi' => 'شىعىس افريكا ۋاقىتى (نايروبي)',
        'Africa/Ndjamena' => 'باتىس افريكا ۋاقىتى (ندجامەنا)',
        'Africa/Niamey' => 'باتىس افريكا ۋاقىتى (نيامەي)',
        'Africa/Nouakchott' => 'گرينۆيچ ۋاقىتى (نۋاكشوت)',
        'Africa/Ouagadougou' => 'گرينۆيچ ۋاقىتى (ۋاگادۋگۋ)',
        'Africa/Porto-Novo' => 'باتىس افريكا ۋاقىتى (پورتو-نوۆو)',
        'Africa/Sao_Tome' => 'گرينۆيچ ۋاقىتى (سان-تومە)',
        'Africa/Tripoli' => 'شىعىس ەۋروپا ۋاقىتى (تريپولي)',
        'Africa/Tunis' => 'ورتالىق ەۋروپا ۋاقىتى (تۋنيس)',
        'Africa/Windhoek' => 'ورتالىق افريكا ۋاقىتى (ۆيندحۋك)',
        'America/Adak' => 'گاۆاي جانە الەۋت ارالدارى ۋاقىتى (اداك)',
        'America/Anchorage' => 'الاسكا ۋاقىتى (انكوريج)',
        'America/Anguilla' => 'اتلانتيكا ۋاقىتى (انگيليا)',
        'America/Antigua' => 'اتلانتيكا ۋاقىتى (انتيگۋا)',
        'America/Araguaina' => 'برازيليا ۋاقىتى (اراگۋاينا)',
        'America/Argentina/La_Rioja' => 'ارگەنتينا ۋاقىتى (لا-ريوحا)',
        'America/Argentina/Rio_Gallegos' => 'ارگەنتينا ۋاقىتى (ريو-گالەگوس)',
        'America/Argentina/Salta' => 'ارگەنتينا ۋاقىتى (سالتا)',
        'America/Argentina/San_Juan' => 'ارگەنتينا ۋاقىتى (سان-حۋان)',
        'America/Argentina/San_Luis' => 'ارگەنتينا ۋاقىتى (سان-لۋيس)',
        'America/Argentina/Tucuman' => 'ارگەنتينا ۋاقىتى (تۋكۋمان)',
        'America/Argentina/Ushuaia' => 'ارگەنتينا ۋاقىتى (ۋشۋايا)',
        'America/Aruba' => 'اتلانتيكا ۋاقىتى (ارۋبا)',
        'America/Asuncion' => 'پاراگۆاي ۋاقىتى (اسۋنسيون)',
        'America/Bahia' => 'برازيليا ۋاقىتى (بايا)',
        'America/Bahia_Banderas' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (بايا-دە-باندەراس)',
        'America/Barbados' => 'اتلانتيكا ۋاقىتى (باربادوس)',
        'America/Belem' => 'برازيليا ۋاقىتى (بەلەم)',
        'America/Belize' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (بەليز)',
        'America/Blanc-Sablon' => 'اتلانتيكا ۋاقىتى (بلانك-سابلون)',
        'America/Boa_Vista' => 'امازون ۋاقىتى (باو-ۆيستا)',
        'America/Bogota' => 'كولۋمبيا ۋاقىتى (بوگوتا)',
        'America/Boise' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (بويسە)',
        'America/Buenos_Aires' => 'ارگەنتينا ۋاقىتى (بۋەنوس-ايروس)',
        'America/Argentina/Buenos_Aires' => 'ارگەنتينا ۋاقىتى (بۋەنوس-ايروس)',
        'America/Cambridge_Bay' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (كەمبريج-بەي)',
        'America/Campo_Grande' => 'امازون ۋاقىتى (كامپۋ-گراندە)',
        'America/Cancun' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (كانكۋن)',
        'America/Caracas' => 'ۆەنەسۋەلا ۋاقىتى (كاراكاس)',
        'America/Catamarca' => 'ارگەنتينا ۋاقىتى (كاتاماركا)',
        'America/Argentina/Catamarca' => 'ارگەنتينا ۋاقىتى (كاتاماركا)',
        'America/Cayenne' => 'فرانتسۋز گۆياناسى ۋاقىتى (كايەننا)',
        'America/Cayman' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (كايمان ارالدارى)',
        'America/Chicago' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (چيكاگو)',
        'America/Chihuahua' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (چيۋاۋا)',
        'America/Ciudad_Juarez' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (سيۋداد-حۋارەس)',
        'America/Coral_Harbour' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (اتيكوكان)',
        'America/Atikokan' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (اتيكوكان)',
        'America/Cordoba' => 'ارگەنتينا ۋاقىتى (كوردوبا)',
        'America/Argentina/Cordoba' => 'ارگەنتينا ۋاقىتى (كوردوبا)',
        'America/Costa_Rica' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (كوستا-ريكا)',
        'America/Coyhaique' => 'چيلي ۋاقىتى (كويايكە)',
        'America/Creston' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (كرەستون)',
        'America/Cuiaba' => 'امازون ۋاقىتى (كۋيابا)',
        'America/Curacao' => 'اتلانتيكا ۋاقىتى (كيۋراساو)',
        'America/Danmarkshavn' => 'گرينۆيچ ۋاقىتى (دانماركسحاۆن)',
        'America/Dawson' => 'يۋكون ۋاقىتى (دوۋسون)',
        'America/Dawson_Creek' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (دوۋسون-كريك)',
        'America/Denver' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (دەنۆەر)',
        'America/Detroit' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (دەترويد)',
        'America/Dominica' => 'اتلانتيكا ۋاقىتى (دومينيكا)',
        'America/Edmonton' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (ەدمونتون)',
        'America/Eirunepe' => 'برازيليا ۋاقىتى (ەيرۋنەپە)',
        'America/El_Salvador' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (سالۆادور)',
        'America/Fort_Nelson' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (فورت-نەلسون)',
        'America/Fortaleza' => 'برازيليا ۋاقىتى (فورتالەزا)',
        'America/Glace_Bay' => 'اتلانتيكا ۋاقىتى (گلەيس-بەي)',
        'America/Godthab' => 'گرەنلانديا ۋاقىتى (نۋۋك)',
        'America/Nuuk' => 'گرەنلانديا ۋاقىتى (نۋۋك)',
        'America/Goose_Bay' => 'اتلانتيكا ۋاقىتى (گۋس-بەي)',
        'America/Grand_Turk' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (گراند-تەرك)',
        'America/Grenada' => 'اتلانتيكا ۋاقىتى (گرەنادا)',
        'America/Guadeloupe' => 'اتلانتيكا ۋاقىتى (گۆادەلۇپا)',
        'America/Guatemala' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (گۆاتەمالا)',
        'America/Guayaquil' => 'ەكۆادور ۋاقىتى (گۋاياكيل)',
        'America/Guyana' => 'گايانا ۋاقىتى',
        'America/Halifax' => 'اتلانتيكا ۋاقىتى (گاليفاكس)',
        'America/Havana' => 'كۋبا ۋاقىتى (گاۆانا)',
        'America/Hermosillo' => 'مەكسيكا تىنىق مۇحيت ۋاقىتى (ەرموسيلو)',
        'America/Indiana/Knox' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (نوكس، ينديانا)',
        'America/Indiana/Marengo' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (مارەنگو، ينديانا)',
        'America/Indiana/Petersburg' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (پيتەرسبەرگ، ينديانا)',
        'America/Indiana/Tell_City' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (تەلل-سيتي، ينديانا)',
        'America/Indiana/Vevay' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (ۆيۆەي، ينديانا)',
        'America/Indiana/Vincennes' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (ۆينسەننەس، ينديانا)',
        'America/Indiana/Winamac' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (ۋيناماك، ينديانا)',
        'America/Indianapolis' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (يندياناپوليس)',
        'America/Indiana/Indianapolis' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (يندياناپوليس)',
        'America/Inuvik' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (ينۋۆيك)',
        'America/Iqaluit' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (يكالۋيت)',
        'America/Jamaica' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (يامايكا)',
        'America/Jujuy' => 'ارگەنتينا ۋاقىتى (جۋجۋي)',
        'America/Argentina/Jujuy' => 'ارگەنتينا ۋاقىتى (جۋجۋي)',
        'America/Juneau' => 'الاسكا ۋاقىتى (جۋنو)',
        'America/Kentucky/Monticello' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (مونتيسەللو، كەنتۋككي)',
        'America/Kralendijk' => 'اتلانتيكا ۋاقىتى (كرالەندەيك)',
        'America/La_Paz' => 'بوليۆيا ۋاقىتى (لا-پاس)',
        'America/Lima' => 'پەرۋ ۋاقىتى (ليما)',
        'America/Los_Angeles' => 'سولتۇستىك امەريكا تىنىق مۇحيتى ۋاقىتى (لوس-انجەلەس)',
        'America/Louisville' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (لۋيسۆيل)',
        'America/Kentucky/Louisville' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (لۋيسۆيل)',
        'America/Lower_Princes' => 'اتلانتيكا ۋاقىتى (لوۋەر-پرينس-كۋوتەر)',
        'America/Maceio' => 'برازيليا ۋاقىتى (ماسەيو)',
        'America/Managua' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (ماناگۋا)',
        'America/Manaus' => 'امازون ۋاقىتى (ماناۋس)',
        'America/Marigot' => 'اتلانتيكا ۋاقىتى (ماريگو)',
        'America/Martinique' => 'اتلانتيكا ۋاقىتى (مارتينيكا)',
        'America/Matamoros' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (ماتاموروس)',
        'America/Mazatlan' => 'مەكسيكا تىنىق مۇحيت ۋاقىتى (ماساتلان)',
        'America/Mendoza' => 'ارگەنتينا ۋاقىتى (مەندوزا)',
        'America/Argentina/Mendoza' => 'ارگەنتينا ۋاقىتى (مەندوزا)',
        'America/Menominee' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (مەنوميني)',
        'America/Merida' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (مەريدا)',
        'America/Metlakatla' => 'الاسكا ۋاقىتى (مەتلاكاتلا)',
        'America/Mexico_City' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (مەحيكو)',
        'America/Miquelon' => 'سەن-پەر جانە ميكەلون ۋاقىتى',
        'America/Moncton' => 'اتلانتيكا ۋاقىتى (مونكتون)',
        'America/Monterrey' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (مونتەررەي)',
        'America/Montevideo' => 'ۋرۋگۆاي ۋاقىتى (مونتەۆيدەو)',
        'America/Montserrat' => 'اتلانتيكا ۋاقىتى (مونتسەررات)',
        'America/Nassau' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (ناسساۋ)',
        'America/New_York' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (نيۋ-يورك)',
        'America/Nome' => 'الاسكا ۋاقىتى (نوم)',
        'America/Noronha' => 'فەرناندۋ-دي-نورونيا ۋاقىتى',
        'America/North_Dakota/Beulah' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (بويلا، سولتۇستىك داكوتا)',
        'America/North_Dakota/Center' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (سەنتەر، سولتۇستىك داكوتا)',
        'America/North_Dakota/New_Salem' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (نيۋ-سەيلەم، سولتۇستىك داكوتا)',
        'America/Ojinaga' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (وحيناگا)',
        'America/Panama' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (پاناما)',
        'America/Paramaribo' => 'سۋرينام ۋاقىتى (پاراماريبو)',
        'America/Phoenix' => 'سولتۇستىك امەريكا تاۋ ۋاقىتى (فينيكس)',
        'America/Port-au-Prince' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (پورت-وف-پرەنس)',
        'America/Port_of_Spain' => 'اتلانتيكا ۋاقىتى (پورت-وف-سپاين)',
        'America/Porto_Velho' => 'امازون ۋاقىتى (پورتو-ۆەليۋ)',
        'America/Puerto_Rico' => 'اتلانتيكا ۋاقىتى (پۋەرتو-ريكو)',
        'America/Punta_Arenas' => 'چيلي ۋاقىتى (پۋنتا-ارەناس)',
        'America/Rankin_Inlet' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (رانكين-ينلەت)',
        'America/Recife' => 'برازيليا ۋاقىتى (رەسيفي)',
        'America/Regina' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (رەجاينا)',
        'America/Resolute' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (رەزوليۋت)',
        'America/Rio_Branco' => 'برازيليا ۋاقىتى (ريۋ-برانكۋ)',
        'America/Santarem' => 'برازيليا ۋاقىتى (سانتارەن)',
        'America/Santiago' => 'چيلي ۋاقىتى (سانتياگو)',
        'America/Santo_Domingo' => 'اتلانتيكا ۋاقىتى (سانتو-دومينگو)',
        'America/Sao_Paulo' => 'برازيليا ۋاقىتى (سان-پۋالۋ)',
        'America/Scoresbysund' => 'گرەنلانديا ۋاقىتى (يللوككورتوورميۋت)',
        'America/Sitka' => 'الاسكا ۋاقىتى (سيتكا)',
        'America/St_Barthelemy' => 'اتلانتيكا ۋاقىتى (سەن-بارتەلەمي)',
        'America/St_Johns' => 'نيۋفاۋندلەند ۋاقىتى (سەنت-جونس)',
        'America/St_Kitts' => 'اتلانتيكا ۋاقىتى (سەنت-كيتس)',
        'America/St_Lucia' => 'اتلانتيكا ۋاقىتى (سەنت-ليۋسيا)',
        'America/St_Thomas' => 'اتلانتيكا ۋاقىتى (سەنت-توماس)',
        'America/St_Vincent' => 'اتلانتيكا ۋاقىتى (سەنت-ۆينسەنت)',
        'America/Swift_Current' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (سۋيات-كاررەنت)',
        'America/Tegucigalpa' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (تەگۋسيگالپا)',
        'America/Thule' => 'اتلانتيكا ۋاقىتى (تۋلە)',
        'America/Tijuana' => 'سولتۇستىك امەريكا تىنىق مۇحيتى ۋاقىتى (تيحۋانا)',
        'America/Toronto' => 'سولتۇستىك امەريكا شىعىس ۋاقىتى (تورونتو)',
        'America/Tortola' => 'اتلانتيكا ۋاقىتى (تورتولا)',
        'America/Vancouver' => 'سولتۇستىك امەريكا تىنىق مۇحيتى ۋاقىتى (ۆانكۋۆەر)',
        'America/Whitehorse' => 'يۋكون ۋاقىتى (ۋايتحورس)',
        'America/Winnipeg' => 'سولتۇستىك امەريكا ورتالىق ۋاقىتى (ۆيننيپەگ)',
        'America/Yakutat' => 'الاسكا ۋاقىتى (ياكۋتات)',
        'Antarctica/Casey' => 'باتىس اۋستراليا ۋاقىتى (كەيسي)',
        'Antarctica/Davis' => 'دەيۆيس ۋاقىتى',
        'Antarctica/DumontDUrville' => 'ديۋمون-ديۋرۆيل ۋاقىتى',
        'Antarctica/Macquarie' => 'شىعىس اۋستراليا ۋاقىتى (ماككۋوري)',
        'Antarctica/Mawson' => 'موۋسون ۋاقىتى',
        'Antarctica/McMurdo' => 'جاڭا زەلانديا ۋاقىتى (ماك-مەردو)',
        'Antarctica/Palmer' => 'چيلي ۋاقىتى (پالمەر)',
        'Antarctica/Rothera' => 'روتەرا ۋقىتى',
        'Antarctica/Syowa' => 'سەۆا ۋاقىتى',
        'Antarctica/Troll' => 'گرينۆيچ ۋاقىتى (ترول)',
        'Antarctica/Vostok' => 'ۆوستوك ۋاقىتى',
        'Arctic/Longyearbyen' => 'ورتالىق ەۋروپا ۋاقىتى (لونگير)',
        'Asia/Aden' => 'ساۋد ارابياسى ۋاقىتى (ادەن)',
        'Asia/Almaty' => 'قازاق ەلى ۋاقىتى (الماتى)',
        'Asia/Amman' => 'شىعىس ەۋروپا ۋاقىتى (اممان)',
        'Asia/Anadyr' => 'حەسەي ۋاقىتى (انادىر)',
        'Asia/Aqtau' => 'قازاق ەلى ۋاقىتى (اقتاۋ)',
        'Asia/Aqtobe' => 'قازاق ەلى ۋاقىتى (اقتوبە)',
        'Asia/Ashgabat' => 'تۇرىكمەنستان ۋاقىتى (اشحابات)',
        'Asia/Atyrau' => 'قازاق ەلى ۋاقىتى (اتىراۋ)',
        'Asia/Baghdad' => 'ساۋد ارابياسى ۋاقىتى (باگدات)',
        'Asia/Bahrain' => 'ساۋد ارابياسى ۋاقىتى (باحرەين)',
        'Asia/Baku' => 'ءازىربايجان ۋاقىتى (باكۋ)',
        'Asia/Bangkok' => 'ءۇندى-قىتاي ۋاقىتى (باڭكوك)',
        'Asia/Barnaul' => 'كراسنويارسك ۋاقىتى (بارناۋىل)',
        'Asia/Beirut' => 'شىعىس ەۋروپا ۋاقىتى (بەيرۋت)',
        'Asia/Bishkek' => 'قىرعىزستان ۋاقىتى (بىشكەك)',
        'Asia/Brunei' => 'برۋنەي-دارۋسسالام ۋاقىتى',
        'Asia/Calcutta' => 'ءۇندىستان ستاندارتتى ۋاقىتى (كالكۋتا)',
        'Asia/Kolkata' => 'ءۇندىستان ستاندارتتى ۋاقىتى (كالكۋتا)',
        'Asia/Chita' => 'ياكۋتسك ۋاقىتى (چيتا)',
        'Asia/Colombo' => 'ءۇندىستان ستاندارتتى ۋاقىتى (كولومبو)',
        'Asia/Damascus' => 'شىعىس ەۋروپا ۋاقىتى (داماسك)',
        'Asia/Dhaka' => 'بانگلادەش ۋاقىتى (داككا)',
        'Asia/Dili' => 'شىعىس تيمور ۋاقىتى (ديلي)',
        'Asia/Dubai' => 'پارسى شىعاناعى ستاندارتتى ۋاقىتى (دۋباي)',
        'Asia/Dushanbe' => 'تاجىكستان ۋاقىتى (دۋشانبە)',
        'Asia/Famagusta' => 'شىعىس ەۋروپا ۋاقىتى (فاماگۋستا)',
        'Asia/Gaza' => 'شىعىس ەۋروپا ۋاقىتى (گازا)',
        'Asia/Hebron' => 'شىعىس ەۋروپا ۋاقىتى (حەۆرون)',
        'Asia/Hong_Kong' => 'حوڭكوڭ ۋاقىتى',
        'Asia/Hovd' => 'حوۆد ۋاقىتى',
        'Asia/Irkutsk' => 'يركۋتسك ۋاقىتى',
        'Asia/Jakarta' => 'باتىس يندونەزيا ۋاقىتى (جاكارتا)',
        'Asia/Jayapura' => 'شىعىس يندونەزيا ۋاقىتى (جاياپۋرا)',
        'Asia/Jerusalem' => 'يزرايل ۋاقىتى (يەرۋساليم)',
        'Asia/Kabul' => 'اۋعانستان ۋاقىتى (كابۋل)',
        'Asia/Kamchatka' => 'حەسەي ۋاقىتى (كامچاتكا)',
        'Asia/Karachi' => 'پاكىستان ۋاقىتى (كاراچا)',
        'Asia/Katmandu' => 'نەپال ۋاقىتى (كاتماندۋ)',
        'Asia/Kathmandu' => 'نەپال ۋاقىتى (كاتماندۋ)',
        'Asia/Khandyga' => 'ياكۋتسك ۋاقىتى (حاندىگا)',
        'Asia/Krasnoyarsk' => 'كراسنويارسك ۋاقىتى',
        'Asia/Kuala_Lumpur' => 'مالايزيا ۋاقىتى (كۋالا-لۋمپۋر)',
        'Asia/Kuching' => 'مالايزيا ۋاقىتى (كۋچيڭ)',
        'Asia/Kuwait' => 'ساۋد ارابياسى ۋاقىتى (كۋۆەيت)',
        'Asia/Macau' => 'قىتاي ۋاقىتى (ماكاو)',
        'Asia/Magadan' => 'ماگادان ۋاقىتى',
        'Asia/Makassar' => 'ورتالىق يندونەزيا ۋاقىتى (ماكاسار)',
        'Asia/Manila' => 'فيليپين ارالدارى ۋاقىتى (مانيلا)',
        'Asia/Muscat' => 'پارسى شىعاناعى ستاندارتتى ۋاقىتى (ماسكات)',
        'Asia/Nicosia' => 'شىعىس ەۋروپا ۋاقىتى (نيكوسيا)',
        'Asia/Novokuznetsk' => 'كراسنويارسك ۋاقىتى (نوۆوكۋزنەتسك)',
        'Asia/Novosibirsk' => 'كراسنويارسك ۋاقىتى (جاڭاسىبىر)',
        'Asia/Omsk' => 'ومبى ۋاقىتى',
        'Asia/Oral' => 'قازاق ەلى ۋاقىتى (ورال)',
        'Asia/Phnom_Penh' => 'ءۇندى-قىتاي ۋاقىتى (پنومپەن)',
        'Asia/Pontianak' => 'باتىس يندونەزيا ۋاقىتى (پونتياناك)',
        'Asia/Pyongyang' => 'كورەيا ۋاقىتى (پحەنيان)',
        'Asia/Qatar' => 'ساۋد ارابياسى ۋاقىتى (كاتار)',
        'Asia/Qostanay' => 'قازاق ەلى ۋاقىتى (قوستاناي)',
        'Asia/Qyzylorda' => 'قازاق ەلى ۋاقىتى (قىزىلوردا)',
        'Asia/Rangoon' => 'ميانما ۋاقىتى (يانگون)',
        'Asia/Yangon' => 'ميانما ۋاقىتى (يانگون)',
        'Asia/Riyadh' => 'ساۋد ارابياسى ۋاقىتى (ەر-رياد)',
        'Asia/Saigon' => 'ءۇندى-قىتاي ۋاقىتى (حوشيمين)',
        'Asia/Ho_Chi_Minh' => 'ءۇندى-قىتاي ۋاقىتى (حوشيمين)',
        'Asia/Sakhalin' => 'ماگادان ۋاقىتى (ساحالين)',
        'Asia/Samarkand' => 'وزبەكستان ۋاقىتى (سامارقاند)',
        'Asia/Seoul' => 'كورەيا ۋاقىتى (سەۋل)',
        'Asia/Shanghai' => 'قىتاي ۋاقىتى (شانحاي)',
        'Asia/Singapore' => 'سينگاپۋر ستاندارتتى ۋاقىتى',
        'Asia/Srednekolymsk' => 'ماگادان ۋاقىتى (سرەدنەكولىمسك)',
        'Asia/Taipei' => 'تايبەي ۋاقىتى',
        'Asia/Tashkent' => 'وزبەكستان ۋاقىتى (تاشكەنت)',
        'Asia/Tbilisi' => 'گرۋزيا ۋاقىتى (تبيليسي)',
        'Asia/Tehran' => 'يران ۋاقىتى (تەگەران)',
        'Asia/Thimphu' => 'بۋتان ۋاقىتى (تحيمپحۋ)',
        'Asia/Tokyo' => 'جاپونيا ۋاقىتى (توكيو)',
        'Asia/Tomsk' => 'كراسنويارسك ۋاقىتى (تۋمەن)',
        'Asia/Ulaanbaatar' => 'ۇلانباتىر ۋاقىتى',
        'Asia/Urumqi' => 'قىتاي ۋاقىتى (ءۇرىمشى)',
        'Asia/Ust-Nera' => 'ۆلاديۆوستوك ۋاقىتى (ۋست-نەرا)',
        'Asia/Vientiane' => 'ءۇندى-قىتاي ۋاقىتى (ۆەنتيان)',
        'Asia/Vladivostok' => 'ۆلاديۆوستوك ۋاقىتى (ۆلاديۆاستوك)',
        'Asia/Yakutsk' => 'ياكۋتسك ۋاقىتى',
        'Asia/Yekaterinburg' => 'ەكاتەرينبۋرگ ۋاقىتى',
        'Asia/Yerevan' => 'ارمەنيا ۋاقىتى (يەرەۆان)',
        'Atlantic/Azores' => 'ازور ارالدارى ۋاقىتى',
        'Atlantic/Bermuda' => 'اتلانتيكا ۋاقىتى (بەرمۋد ارالدارى)',
        'Atlantic/Canary' => 'باتىس ەۋروپا ۋاقىتى (كانار ارالدارى)',
        'Atlantic/Cape_Verde' => 'كابو-ۆەردە ۋاقىتى',
        'Atlantic/Faeroe' => 'باتىس ەۋروپا ۋاقىتى (فارەر ارالدارى)',
        'Atlantic/Faroe' => 'باتىس ەۋروپا ۋاقىتى (فارەر ارالدارى)',
        'Atlantic/Madeira' => 'باتىس ەۋروپا ۋاقىتى (مادەيرا)',
        'Atlantic/Reykjavik' => 'گرينۆيچ ۋاقىتى (رەيكياۆيك)',
        'Atlantic/South_Georgia' => 'وڭتۇستىك گەورگيا ۋاقىتى',
        'Atlantic/St_Helena' => 'گرينۆيچ ۋاقىتى (اۋليە ەلەنا ارالى)',
        'Atlantic/Stanley' => 'فولكلەند ارالدارى ۋاقىتى (ستەنلي)',
        'Australia/Adelaide' => 'ورتالىق اۋستراليا ۋاقىتى (ادەلايدا)',
        'Australia/Brisbane' => 'شىعىس اۋستراليا ۋاقىتى (بريسبەن)',
        'Australia/Broken_Hill' => 'ورتالىق اۋستراليا ۋاقىتى (بروكەن-حيل)',
        'Australia/Darwin' => 'ورتالىق اۋستراليا ۋاقىتى (دارۆين)',
        'Australia/Eucla' => 'اۋستراليا ورتالىق-باتىس ۋاقىتى (يۋكلا)',
        'Australia/Hobart' => 'شىعىس اۋستراليا ۋاقىتى (حوبارت)',
        'Australia/Lindeman' => 'شىعىس اۋستراليا ۋاقىتى (ليندەمان)',
        'Australia/Lord_Howe' => 'لورد-حاۋ ۋاقىتى',
        'Australia/Melbourne' => 'شىعىس اۋستراليا ۋاقىتى (مەلبۋرن)',
        'Australia/Perth' => 'باتىس اۋستراليا ۋاقىتى (پەرت)',
        'Australia/Sydney' => 'شىعىس اۋستراليا ۋاقىتى (سيدنەي)',
        'Etc/GMT' => 'گرينۆيچ ۋاقىتى',
        'Etc/UTC' => 'دۇنيەجۇزىلىك ۇيلەستىرىلگەن ۋاقىت',
        'Europe/Amsterdam' => 'ورتالىق ەۋروپا ۋاقىتى (امستەردام)',
        'Europe/Andorra' => 'ورتالىق ەۋروپا ۋاقىتى (اندوررا)',
        'Europe/Astrakhan' => 'حەسەي ۋاقىتى (استراحان)',
        'Europe/Athens' => 'شىعىس ەۋروپا ۋاقىتى (افينا)',
        'Europe/Belgrade' => 'ورتالىق ەۋروپا ۋاقىتى (بەلگراد)',
        'Europe/Berlin' => 'ورتالىق ەۋروپا ۋاقىتى (بەرلين)',
        'Europe/Bratislava' => 'ورتالىق ەۋروپا ۋاقىتى (براتيسلاۆا)',
        'Europe/Brussels' => 'ورتالىق ەۋروپا ۋاقىتى (بريۋسەل)',
        'Europe/Bucharest' => 'شىعىس ەۋروپا ۋاقىتى (بۋحارەست)',
        'Europe/Budapest' => 'ورتالىق ەۋروپا ۋاقىتى (بۋداپەشت)',
        'Europe/Busingen' => 'ورتالىق ەۋروپا ۋاقىتى (بيۋزينگەن)',
        'Europe/Chisinau' => 'شىعىس ەۋروپا ۋاقىتى (كيشينەۆ)',
        'Europe/Copenhagen' => 'ورتالىق ەۋروپا ۋاقىتى (كوپەنگاگەن)',
        'Europe/Dublin' => 'گرينۆيچ ۋاقىتى (دۋبلين)',
        'Europe/Gibraltar' => 'ورتالىق ەۋروپا ۋاقىتى (گيبرالتال)',
        'Europe/Guernsey' => 'گرينۆيچ ۋاقىتى (گەرنسي)',
        'Europe/Helsinki' => 'شىعىس ەۋروپا ۋاقىتى (حەلسينكي)',
        'Europe/Isle_of_Man' => 'گرينۆيچ ۋاقىتى (مەن ارالى)',
        'Europe/Istanbul' => 'تۇركيا ۋاقىتى (ستامبۇل)',
        'Europe/Jersey' => 'گرينۆيچ ۋاقىتى (جەرسەي)',
        'Europe/Kaliningrad' => 'شىعىس ەۋروپا ۋاقىتى (كالينينگراد)',
        'Europe/Kiev' => 'شىعىس ەۋروپا ۋاقىتى (كيەۆ)',
        'Europe/Kyiv' => 'شىعىس ەۋروپا ۋاقىتى (كيەۆ)',
        'Europe/Kirov' => 'ماسكەۋ ۋاقىتى (كيروۆ)',
        'Europe/Lisbon' => 'باتىس ەۋروپا ۋاقىتى (ليسابون)',
        'Europe/Ljubljana' => 'ورتالىق ەۋروپا ۋاقىتى (ليۋبليانا)',
        'Europe/London' => 'گرينۆيچ ۋاقىتى (لوندون)',
        'Europe/Luxembourg' => 'ورتالىق ەۋروپا ۋاقىتى (ليۋكسەمبۋرگ)',
        'Europe/Madrid' => 'ورتالىق ەۋروپا ۋاقىتى (مادريد)',
        'Europe/Malta' => 'ورتالىق ەۋروپا ۋاقىتى (مالتا)',
        'Europe/Mariehamn' => 'شىعىس ەۋروپا ۋاقىتى (ماريەحامن)',
        'Europe/Minsk' => 'ماسكەۋ ۋاقىتى (مينسك)',
        'Europe/Monaco' => 'ورتالىق ەۋروپا ۋاقىتى (موناكو)',
        'Europe/Moscow' => 'ماسكەۋ ۋاقىتى',
        'Europe/Oslo' => 'ورتالىق ەۋروپا ۋاقىتى (وسلو)',
        'Europe/Paris' => 'ورتالىق ەۋروپا ۋاقىتى (پاريج)',
        'Europe/Podgorica' => 'ورتالىق ەۋروپا ۋاقىتى (پودگوريسا)',
        'Europe/Prague' => 'ورتالىق ەۋروپا ۋاقىتى (پراگا)',
        'Europe/Riga' => 'شىعىس ەۋروپا ۋاقىتى (ريگا)',
        'Europe/Rome' => 'ورتالىق ەۋروپا ۋاقىتى (ريم)',
        'Europe/Samara' => 'حەسەي ۋاقىتى (سامارا)',
        'Europe/San_Marino' => 'ورتالىق ەۋروپا ۋاقىتى (سان-مارينو)',
        'Europe/Sarajevo' => 'ورتالىق ەۋروپا ۋاقىتى (ساراەۆو)',
        'Europe/Saratov' => 'حەسەي ۋاقىتى (سارىتاۋ)',
        'Europe/Simferopol' => 'ماسكەۋ ۋاقىتى (سيمفەرول)',
        'Europe/Skopje' => 'ورتالىق ەۋروپا ۋاقىتى (سكوپيە)',
        'Europe/Sofia' => 'شىعىس ەۋروپا ۋاقىتى (سوفيا)',
        'Europe/Stockholm' => 'ورتالىق ەۋروپا ۋاقىتى (ستوكگولىم)',
        'Europe/Tallinn' => 'شىعىس ەۋروپا ۋاقىتى (تاللين)',
        'Europe/Tirane' => 'ورتالىق ەۋروپا ۋاقىتى (تيرانا)',
        'Europe/Ulyanovsk' => 'حەسەي ۋاقىتى (ۋليانوۆسك)',
        'Europe/Vaduz' => 'ورتالىق ەۋروپا ۋاقىتى (ۆادۋس)',
        'Europe/Vatican' => 'ورتالىق ەۋروپا ۋاقىتى (ۆاتيكان)',
        'Europe/Vienna' => 'ورتالىق ەۋروپا ۋاقىتى (ۆەنا)',
        'Europe/Vilnius' => 'شىعىس ەۋروپا ۋاقىتى (ۆينيۋس)',
        'Europe/Volgograd' => 'ماسكەۋ ۋاقىتى (ۆولگوگراد)',
        'Europe/Warsaw' => 'ورتالىق ەۋروپا ۋاقىتى (ۆارشاۆا)',
        'Europe/Zagreb' => 'ورتالىق ەۋروپا ۋاقىتى (زاگرەب)',
        'Europe/Zurich' => 'ورتالىق ەۋروپا ۋاقىتى (سيۋريح)',
        'Indian/Antananarivo' => 'شىعىس افريكا ۋاقىتى (انتاناناريۆۋ)',
        'Indian/Chagos' => 'ءۇندى مۇحيتى ۋاقىتى (چاگوس)',
        'Indian/Christmas' => 'كريستماس ارالىنىڭ ۋاقىتى (كريستماس ارالدارى)',
        'Indian/Cocos' => 'كوكوس ارالدارىنىڭ ۋاقىتى',
        'Indian/Comoro' => 'شىعىس افريكا ۋاقىتى (كومور ارالدارى)',
        'Indian/Kerguelen' => 'فرانتسيانىڭ وڭتۇستىك ايماعى جانە انتاركتيكا ۋاقىتى (كەرگەلەن)',
        'Indian/Mahe' => 'سەيشەل ارالدارى ۋاقىتى (ماە)',
        'Indian/Maldives' => 'مالديۆ ارالدارى ۋاقىتى',
        'Indian/Mauritius' => 'ماۆريكيي ۋاقىتى',
        'Indian/Mayotte' => 'شىعىس افريكا ۋاقىتى (مايوتتا)',
        'Indian/Reunion' => 'رەيۋنون ۋاقىتى (رەيۋنيون)',
        'Pacific/Apia' => 'اپيا ۋاقىتى',
        'Pacific/Auckland' => 'جاڭا زەلانديا ۋاقىتى (وكلەند)',
        'Pacific/Bougainville' => 'پاپۋا – جاڭا گۆينەيا ۋاقىتى (بۋگەنۆيل)',
        'Pacific/Chatham' => 'چاتەم ۋاقىتى',
        'Pacific/Easter' => 'پاسحا ارالى ۋاقىتى',
        'Pacific/Efate' => 'ۆانۋاتۋ ۋاقىتى (ەفاتە)',
        'Pacific/Enderbury' => 'فەنيكس ارالدارى ۋاقىتى (كانتون)',
        'Pacific/Kanton' => 'فەنيكس ارالدارى ۋاقىتى (كانتون)',
        'Pacific/Fakaofo' => 'توكەلاۋ ۋاقىتى (فاكاوفو)',
        'Pacific/Fiji' => 'فيجي ۋاقىتى',
        'Pacific/Funafuti' => 'تۋۆالۋ ۋاقىتى (فۋنافۋتي)',
        'Pacific/Galapagos' => 'گالاپاگوس ۋاقىتى',
        'Pacific/Gambier' => 'گامبە ۋاقىتى (گامبيە)',
        'Pacific/Guadalcanal' => 'سولومون ارالدارى ۋاقىتى (گۋادالكانال)',
        'Pacific/Guam' => 'چاموررو ستاندارتتى ۋاقىتى (گۋام)',
        'Pacific/Honolulu' => 'گاۆاي جانە الەۋت ارالدارى ستاندارتتى ۋاقىتى (Гонолулу)',
        'Pacific/Kiritimati' => 'لاين ارالدارى ۋاقىتى (كيريتيماتي)',
        'Pacific/Kosrae' => 'كۋسايە ۋاقىتى',
        'Pacific/Kwajalein' => 'مارشال ارالدارى ۋاقىتى (كۆاجالەيىن)',
        'Pacific/Majuro' => 'مارشال ارالدارى ۋاقىتى (ماجۋرو)',
        'Pacific/Marquesas' => 'ماركيز ارالدارى ۋاقىتى',
        'Pacific/Midway' => 'ساموا ۋاقىتى (ميدۋەي)',
        'Pacific/Nauru' => 'ناۋرۋ ۋاقىتى',
        'Pacific/Niue' => 'نيۋە ۋاقىتى',
        'Pacific/Norfolk' => 'نورفولك ارالى ۋاقىتى',
        'Pacific/Noumea' => 'جاڭا كالەدونيا ۋاقىتى (نۋمەا)',
        'Pacific/Pago_Pago' => 'ساموا ۋاقىتى (پاگو-پاگو)',
        'Pacific/Palau' => 'پالاۋ ۋاقىتى',
        'Pacific/Pitcairn' => 'پيتكەرن ۋاقىتى',
        'Pacific/Ponape' => 'پونپەي ۋاقىتى (پوناپە)',
        'Pacific/Pohnpei' => 'پونپەي ۋاقىتى (پوناپە)',
        'Pacific/Port_Moresby' => 'پاپۋا – جاڭا گۆينەيا ۋاقىتى (پورت-مورسبي)',
        'Pacific/Rarotonga' => 'كۋك ارالدارىنىڭ ۋاقىتى (راروتونگا)',
        'Pacific/Saipan' => 'چاموررو ستاندارتتى ۋاقىتى (سايپان)',
        'Pacific/Tahiti' => 'تايتي ۋاقىتى',
        'Pacific/Tarawa' => 'گيلبەرت ارالدارىنىڭ ۋاقىتى (تاراۋا)',
        'Pacific/Tongatapu' => 'تونگا ۋاقىتى (تونگاتاپۋ)',
        'Pacific/Truk' => 'ترۋك ۋاقىتى',
        'Pacific/Chuuk' => 'ترۋك ۋاقىتى',
        'Pacific/Wake' => 'ۋەيك ارالى ۋاقىتى',
        'Pacific/Wallis' => 'ۋولليس جانە فۋتۋنا ۋاقىتى',
    ],
    'Meta' => [],
];
