<?php

return [
    'Names' => [
        'BAM' => [
            'КМ',
            'Босанскохерцеговачка конвертибилна марка',
        ],
        'BYN' => [
            'BYN',
            'Бјелоруска рубља',
        ],
        'KPW' => [
            'KPW',
            'Сјевернокорејски вон',
        ],
        'NIO' => [
            'NIO',
            'Никарагванска златна кордоба',
        ],
    ],
];
