<?php

return [
    'UserAssignedNames' => [],
    'Names' => [
        'AX' => 'Islas Åland',
        'BA' => 'Bosnia-Herzegovina',
        'CG' => 'República del Congo',
        'CI' => 'Costa de Marfil',
        'GS' => 'Islas Georgia del Sur y Sándwich del Sur',
        'RO' => 'Rumania',
        'SA' => 'Arabia Saudita',
        'TL' => 'Timor Oriental',
        'UM' => 'Islas Ultramarinas de EE.UU.',
    ],
];
