<?php

return [
    'Names' => [
        'af' => 'afrikáans',
        'af_NA' => 'afrikáans (Namibia)',
        'af_ZA' => 'afrikáans (Sudáfrica)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Ghana)',
        'am' => 'amárico',
        'am_ET' => 'amárico (Etiopía)',
        'ar' => 'árabe',
        'ar_001' => 'árabe (Mundo)',
        'ar_AE' => 'árabe (Emiratos Árabes Unidos)',
        'ar_BH' => 'árabe (Baréin)',
        'ar_DJ' => 'árabe (Yibuti)',
        'ar_DZ' => 'árabe (Argelia)',
        'ar_EG' => 'árabe (Egipto)',
        'ar_EH' => 'árabe (Sáhara Occidental)',
        'ar_ER' => 'árabe (Eritrea)',
        'ar_IL' => 'árabe (Israel)',
        'ar_IQ' => 'árabe (Irak)',
        'ar_JO' => 'árabe (Jordania)',
        'ar_KM' => 'árabe (Comoras)',
        'ar_KW' => 'árabe (Kuwait)',
        'ar_LB' => 'árabe (Líbano)',
        'ar_LY' => 'árabe (Libia)',
        'ar_MA' => 'árabe (Marruecos)',
        'ar_MR' => 'árabe (Mauritania)',
        'ar_OM' => 'árabe (Omán)',
        'ar_PS' => 'árabe (Territorios Palestinos)',
        'ar_QA' => 'árabe (Catar)',
        'ar_SA' => 'árabe (Arabia Saudí)',
        'ar_SD' => 'árabe (Sudán)',
        'ar_SO' => 'árabe (Somalia)',
        'ar_SS' => 'árabe (Sudán del Sur)',
        'ar_SY' => 'árabe (Siria)',
        'ar_TD' => 'árabe (Chad)',
        'ar_TN' => 'árabe (Túnez)',
        'ar_YE' => 'árabe (Yemen)',
        'as' => 'asamés',
        'as_IN' => 'asamés (India)',
        'az' => 'azerbaiyano',
        'az_AZ' => 'azerbaiyano (Azerbaiyán)',
        'az_Cyrl' => 'azerbaiyano (cirílico)',
        'az_Cyrl_AZ' => 'azerbaiyano (cirílico, Azerbaiyán)',
        'az_Latn' => 'azerbaiyano (latino)',
        'az_Latn_AZ' => 'azerbaiyano (latino, Azerbaiyán)',
        'ba' => 'baskir',
        'ba_RU' => 'baskir (Rusia)',
        'be' => 'bielorruso',
        'be_BY' => 'bielorruso (Bielorrusia)',
        'bg' => 'búlgaro',
        'bg_BG' => 'búlgaro (Bulgaria)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengalí',
        'bn_BD' => 'bengalí (Bangladés)',
        'bn_IN' => 'bengalí (India)',
        'bo' => 'tibetano',
        'bo_CN' => 'tibetano (China)',
        'bo_IN' => 'tibetano (India)',
        'br' => 'bretón',
        'br_FR' => 'bretón (Francia)',
        'bs' => 'bosnio',
        'bs_BA' => 'bosnio (Bosnia y Herzegovina)',
        'bs_Cyrl' => 'bosnio (cirílico)',
        'bs_Cyrl_BA' => 'bosnio (cirílico, Bosnia y Herzegovina)',
        'bs_Latn' => 'bosnio (latino)',
        'bs_Latn_BA' => 'bosnio (latino, Bosnia y Herzegovina)',
        'ca' => 'catalán',
        'ca_AD' => 'catalán (Andorra)',
        'ca_ES' => 'catalán (España)',
        'ca_FR' => 'catalán (Francia)',
        'ca_IT' => 'catalán (Italia)',
        'ce' => 'checheno',
        'ce_RU' => 'checheno (Rusia)',
        'cs' => 'checo',
        'cs_CZ' => 'checo (Chequia)',
        'cv' => 'chuvasio',
        'cv_RU' => 'chuvasio (Rusia)',
        'cy' => 'galés',
        'cy_GB' => 'galés (Reino Unido)',
        'da' => 'danés',
        'da_DK' => 'danés (Dinamarca)',
        'da_GL' => 'danés (Groenlandia)',
        'de' => 'alemán',
        'de_AT' => 'alemán (Austria)',
        'de_BE' => 'alemán (Bélgica)',
        'de_CH' => 'alemán (Suiza)',
        'de_DE' => 'alemán (Alemania)',
        'de_IT' => 'alemán (Italia)',
        'de_LI' => 'alemán (Liechtenstein)',
        'de_LU' => 'alemán (Luxemburgo)',
        'dz' => 'dzongkha',
        'dz_BT' => 'dzongkha (Bután)',
        'ee' => 'ewé',
        'ee_GH' => 'ewé (Ghana)',
        'ee_TG' => 'ewé (Togo)',
        'el' => 'griego',
        'el_CY' => 'griego (Chipre)',
        'el_GR' => 'griego (Grecia)',
        'en' => 'inglés',
        'en_001' => 'inglés (Mundo)',
        'en_150' => 'inglés (Europa)',
        'en_AE' => 'inglés (Emiratos Árabes Unidos)',
        'en_AG' => 'inglés (Antigua y Barbuda)',
        'en_AI' => 'inglés (Anguila)',
        'en_AS' => 'inglés (Samoa Americana)',
        'en_AT' => 'inglés (Austria)',
        'en_AU' => 'inglés (Australia)',
        'en_BB' => 'inglés (Barbados)',
        'en_BE' => 'inglés (Bélgica)',
        'en_BI' => 'inglés (Burundi)',
        'en_BM' => 'inglés (Bermudas)',
        'en_BS' => 'inglés (Bahamas)',
        'en_BW' => 'inglés (Botsuana)',
        'en_BZ' => 'inglés (Belice)',
        'en_CA' => 'inglés (Canadá)',
        'en_CC' => 'inglés (Islas Cocos)',
        'en_CH' => 'inglés (Suiza)',
        'en_CK' => 'inglés (Islas Cook)',
        'en_CM' => 'inglés (Camerún)',
        'en_CX' => 'inglés (Isla de Navidad)',
        'en_CY' => 'inglés (Chipre)',
        'en_CZ' => 'inglés (Chequia)',
        'en_DE' => 'inglés (Alemania)',
        'en_DK' => 'inglés (Dinamarca)',
        'en_DM' => 'inglés (Dominica)',
        'en_EE' => 'inglés (Estonia)',
        'en_ER' => 'inglés (Eritrea)',
        'en_ES' => 'inglés (España)',
        'en_FI' => 'inglés (Finlandia)',
        'en_FJ' => 'inglés (Fiyi)',
        'en_FK' => 'inglés (Islas Malvinas)',
        'en_FM' => 'inglés (Micronesia)',
        'en_FR' => 'inglés (Francia)',
        'en_GB' => 'inglés (Reino Unido)',
        'en_GD' => 'inglés (Granada)',
        'en_GE' => 'inglés (Georgia)',
        'en_GG' => 'inglés (Guernesey)',
        'en_GH' => 'inglés (Ghana)',
        'en_GI' => 'inglés (Gibraltar)',
        'en_GM' => 'inglés (Gambia)',
        'en_GS' => 'inglés (Islas Georgia del Sur y Sandwich del Sur)',
        'en_GU' => 'inglés (Guam)',
        'en_GY' => 'inglés (Guyana)',
        'en_HK' => 'inglés (RAE de Hong Kong [China])',
        'en_HU' => 'inglés (Hungría)',
        'en_ID' => 'inglés (Indonesia)',
        'en_IE' => 'inglés (Irlanda)',
        'en_IL' => 'inglés (Israel)',
        'en_IM' => 'inglés (Isla de Man)',
        'en_IN' => 'inglés (India)',
        'en_IO' => 'inglés (Territorio Británico del Océano Índico)',
        'en_IT' => 'inglés (Italia)',
        'en_JE' => 'inglés (Jersey)',
        'en_JM' => 'inglés (Jamaica)',
        'en_JP' => 'inglés (Japón)',
        'en_KE' => 'inglés (Kenia)',
        'en_KI' => 'inglés (Kiribati)',
        'en_KN' => 'inglés (San Cristóbal y Nieves)',
        'en_KY' => 'inglés (Islas Caimán)',
        'en_LC' => 'inglés (Santa Lucía)',
        'en_LR' => 'inglés (Liberia)',
        'en_LS' => 'inglés (Lesoto)',
        'en_LT' => 'inglés (Lituania)',
        'en_LV' => 'inglés (Letonia)',
        'en_MG' => 'inglés (Madagascar)',
        'en_MH' => 'inglés (Islas Marshall)',
        'en_MO' => 'inglés (RAE de Macao [China])',
        'en_MP' => 'inglés (Islas Marianas del Norte)',
        'en_MS' => 'inglés (Montserrat)',
        'en_MT' => 'inglés (Malta)',
        'en_MU' => 'inglés (Mauricio)',
        'en_MV' => 'inglés (Maldivas)',
        'en_MW' => 'inglés (Malaui)',
        'en_MY' => 'inglés (Malasia)',
        'en_NA' => 'inglés (Namibia)',
        'en_NF' => 'inglés (Isla Norfolk)',
        'en_NG' => 'inglés (Nigeria)',
        'en_NL' => 'inglés (Países Bajos)',
        'en_NO' => 'inglés (Noruega)',
        'en_NR' => 'inglés (Nauru)',
        'en_NU' => 'inglés (Niue)',
        'en_NZ' => 'inglés (Nueva Zelanda)',
        'en_PG' => 'inglés (Papúa Nueva Guinea)',
        'en_PH' => 'inglés (Filipinas)',
        'en_PK' => 'inglés (Pakistán)',
        'en_PL' => 'inglés (Polonia)',
        'en_PN' => 'inglés (Islas Pitcairn)',
        'en_PR' => 'inglés (Puerto Rico)',
        'en_PT' => 'inglés (Portugal)',
        'en_PW' => 'inglés (Palaos)',
        'en_RO' => 'inglés (Rumanía)',
        'en_RW' => 'inglés (Ruanda)',
        'en_SB' => 'inglés (Islas Salomón)',
        'en_SC' => 'inglés (Seychelles)',
        'en_SD' => 'inglés (Sudán)',
        'en_SE' => 'inglés (Suecia)',
        'en_SG' => 'inglés (Singapur)',
        'en_SH' => 'inglés (Santa Elena)',
        'en_SI' => 'inglés (Eslovenia)',
        'en_SK' => 'inglés (Eslovaquia)',
        'en_SL' => 'inglés (Sierra Leona)',
        'en_SS' => 'inglés (Sudán del Sur)',
        'en_SX' => 'inglés (Sint Maarten)',
        'en_SZ' => 'inglés (Esuatini)',
        'en_TC' => 'inglés (Islas Turcas y Caicos)',
        'en_TK' => 'inglés (Tokelau)',
        'en_TO' => 'inglés (Tonga)',
        'en_TT' => 'inglés (Trinidad y Tobago)',
        'en_TV' => 'inglés (Tuvalu)',
        'en_TZ' => 'inglés (Tanzania)',
        'en_UA' => 'inglés (Ucrania)',
        'en_UG' => 'inglés (Uganda)',
        'en_UM' => 'inglés (Islas menores alejadas de EE. UU.)',
        'en_US' => 'inglés (Estados Unidos)',
        'en_VC' => 'inglés (San Vicente y las Granadinas)',
        'en_VG' => 'inglés (Islas Vírgenes Británicas)',
        'en_VI' => 'inglés (Islas Vírgenes de EE. UU.)',
        'en_VU' => 'inglés (Vanuatu)',
        'en_WS' => 'inglés (Samoa)',
        'en_ZA' => 'inglés (Sudáfrica)',
        'en_ZM' => 'inglés (Zambia)',
        'en_ZW' => 'inglés (Zimbabue)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Mundo)',
        'es' => 'español',
        'es_419' => 'español (Latinoamérica)',
        'es_AR' => 'español (Argentina)',
        'es_BO' => 'español (Bolivia)',
        'es_BR' => 'español (Brasil)',
        'es_BZ' => 'español (Belice)',
        'es_CL' => 'español (Chile)',
        'es_CO' => 'español (Colombia)',
        'es_CR' => 'español (Costa Rica)',
        'es_CU' => 'español (Cuba)',
        'es_DO' => 'español (República Dominicana)',
        'es_EC' => 'español (Ecuador)',
        'es_ES' => 'español (España)',
        'es_GQ' => 'español (Guinea Ecuatorial)',
        'es_GT' => 'español (Guatemala)',
        'es_HN' => 'español (Honduras)',
        'es_MX' => 'español (México)',
        'es_NI' => 'español (Nicaragua)',
        'es_PA' => 'español (Panamá)',
        'es_PE' => 'español (Perú)',
        'es_PH' => 'español (Filipinas)',
        'es_PR' => 'español (Puerto Rico)',
        'es_PY' => 'español (Paraguay)',
        'es_SV' => 'español (El Salvador)',
        'es_US' => 'español (Estados Unidos)',
        'es_UY' => 'español (Uruguay)',
        'es_VE' => 'español (Venezuela)',
        'et' => 'estonio',
        'et_EE' => 'estonio (Estonia)',
        'eu' => 'euskera',
        'eu_ES' => 'euskera (España)',
        'fa' => 'persa',
        'fa_AF' => 'persa (Afganistán)',
        'fa_IR' => 'persa (Irán)',
        'ff' => 'fula',
        'ff_Adlm' => 'fula (ádlam)',
        'ff_Adlm_BF' => 'fula (ádlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fula (ádlam, Camerún)',
        'ff_Adlm_GH' => 'fula (ádlam, Ghana)',
        'ff_Adlm_GM' => 'fula (ádlam, Gambia)',
        'ff_Adlm_GN' => 'fula (ádlam, Guinea)',
        'ff_Adlm_GW' => 'fula (ádlam, Guinea-Bisáu)',
        'ff_Adlm_LR' => 'fula (ádlam, Liberia)',
        'ff_Adlm_MR' => 'fula (ádlam, Mauritania)',
        'ff_Adlm_NE' => 'fula (ádlam, Níger)',
        'ff_Adlm_NG' => 'fula (ádlam, Nigeria)',
        'ff_Adlm_SL' => 'fula (ádlam, Sierra Leona)',
        'ff_Adlm_SN' => 'fula (ádlam, Senegal)',
        'ff_CM' => 'fula (Camerún)',
        'ff_GN' => 'fula (Guinea)',
        'ff_Latn' => 'fula (latino)',
        'ff_Latn_BF' => 'fula (latino, Burkina Faso)',
        'ff_Latn_CM' => 'fula (latino, Camerún)',
        'ff_Latn_GH' => 'fula (latino, Ghana)',
        'ff_Latn_GM' => 'fula (latino, Gambia)',
        'ff_Latn_GN' => 'fula (latino, Guinea)',
        'ff_Latn_GW' => 'fula (latino, Guinea-Bisáu)',
        'ff_Latn_LR' => 'fula (latino, Liberia)',
        'ff_Latn_MR' => 'fula (latino, Mauritania)',
        'ff_Latn_NE' => 'fula (latino, Níger)',
        'ff_Latn_NG' => 'fula (latino, Nigeria)',
        'ff_Latn_SL' => 'fula (latino, Sierra Leona)',
        'ff_Latn_SN' => 'fula (latino, Senegal)',
        'ff_MR' => 'fula (Mauritania)',
        'ff_SN' => 'fula (Senegal)',
        'fi' => 'finés',
        'fi_FI' => 'finés (Finlandia)',
        'fo' => 'feroés',
        'fo_DK' => 'feroés (Dinamarca)',
        'fo_FO' => 'feroés (Islas Feroe)',
        'fr' => 'francés',
        'fr_BE' => 'francés (Bélgica)',
        'fr_BF' => 'francés (Burkina Faso)',
        'fr_BI' => 'francés (Burundi)',
        'fr_BJ' => 'francés (Benín)',
        'fr_BL' => 'francés (San Bartolomé)',
        'fr_CA' => 'francés (Canadá)',
        'fr_CD' => 'francés (República Democrática del Congo)',
        'fr_CF' => 'francés (República Centroafricana)',
        'fr_CG' => 'francés (Congo)',
        'fr_CH' => 'francés (Suiza)',
        'fr_CI' => 'francés (Côte d’Ivoire)',
        'fr_CM' => 'francés (Camerún)',
        'fr_DJ' => 'francés (Yibuti)',
        'fr_DZ' => 'francés (Argelia)',
        'fr_FR' => 'francés (Francia)',
        'fr_GA' => 'francés (Gabón)',
        'fr_GF' => 'francés (Guayana Francesa)',
        'fr_GN' => 'francés (Guinea)',
        'fr_GP' => 'francés (Guadalupe)',
        'fr_GQ' => 'francés (Guinea Ecuatorial)',
        'fr_HT' => 'francés (Haití)',
        'fr_KM' => 'francés (Comoras)',
        'fr_LU' => 'francés (Luxemburgo)',
        'fr_MA' => 'francés (Marruecos)',
        'fr_MC' => 'francés (Mónaco)',
        'fr_MF' => 'francés (San Martín)',
        'fr_MG' => 'francés (Madagascar)',
        'fr_ML' => 'francés (Mali)',
        'fr_MQ' => 'francés (Martinica)',
        'fr_MR' => 'francés (Mauritania)',
        'fr_MU' => 'francés (Mauricio)',
        'fr_NC' => 'francés (Nueva Caledonia)',
        'fr_NE' => 'francés (Níger)',
        'fr_PF' => 'francés (Polinesia Francesa)',
        'fr_PM' => 'francés (San Pedro y Miquelón)',
        'fr_RE' => 'francés (Reunión)',
        'fr_RW' => 'francés (Ruanda)',
        'fr_SC' => 'francés (Seychelles)',
        'fr_SN' => 'francés (Senegal)',
        'fr_SY' => 'francés (Siria)',
        'fr_TD' => 'francés (Chad)',
        'fr_TG' => 'francés (Togo)',
        'fr_TN' => 'francés (Túnez)',
        'fr_VU' => 'francés (Vanuatu)',
        'fr_WF' => 'francés (Wallis y Futuna)',
        'fr_YT' => 'francés (Mayotte)',
        'fy' => 'frisón occidental',
        'fy_NL' => 'frisón occidental (Países Bajos)',
        'ga' => 'irlandés',
        'ga_GB' => 'irlandés (Reino Unido)',
        'ga_IE' => 'irlandés (Irlanda)',
        'gd' => 'gaélico escocés',
        'gd_GB' => 'gaélico escocés (Reino Unido)',
        'gl' => 'gallego',
        'gl_ES' => 'gallego (España)',
        'gu' => 'guyaratí',
        'gu_IN' => 'guyaratí (India)',
        'gv' => 'manés',
        'gv_IM' => 'manés (Isla de Man)',
        'ha' => 'hausa',
        'ha_GH' => 'hausa (Ghana)',
        'ha_NE' => 'hausa (Níger)',
        'ha_NG' => 'hausa (Nigeria)',
        'he' => 'hebreo',
        'he_IL' => 'hebreo (Israel)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (India)',
        'hi_Latn' => 'hindi (latino)',
        'hi_Latn_IN' => 'hindi (latino, India)',
        'hr' => 'croata',
        'hr_BA' => 'croata (Bosnia y Herzegovina)',
        'hr_HR' => 'croata (Croacia)',
        'hu' => 'húngaro',
        'hu_HU' => 'húngaro (Hungría)',
        'hy' => 'armenio',
        'hy_AM' => 'armenio (Armenia)',
        'ia' => 'interlingua',
        'ia_001' => 'interlingua (Mundo)',
        'id' => 'indonesio',
        'id_ID' => 'indonesio (Indonesia)',
        'ie' => 'interlingue',
        'ie_EE' => 'interlingue (Estonia)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeria)',
        'ii' => 'yi de Sichuán',
        'ii_CN' => 'yi de Sichuán (China)',
        'is' => 'islandés',
        'is_IS' => 'islandés (Islandia)',
        'it' => 'italiano',
        'it_CH' => 'italiano (Suiza)',
        'it_IT' => 'italiano (Italia)',
        'it_SM' => 'italiano (San Marino)',
        'it_VA' => 'italiano (Ciudad del Vaticano)',
        'ja' => 'japonés',
        'ja_JP' => 'japonés (Japón)',
        'jv' => 'javanés',
        'jv_ID' => 'javanés (Indonesia)',
        'ka' => 'georgiano',
        'ka_GE' => 'georgiano (Georgia)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Kenia)',
        'kk' => 'kazajo',
        'kk_Arab' => 'kazajo (árabe)',
        'kk_Arab_CN' => 'kazajo (árabe, China)',
        'kk_Cyrl' => 'kazajo (cirílico)',
        'kk_Cyrl_KZ' => 'kazajo (cirílico, Kazajistán)',
        'kk_KZ' => 'kazajo (Kazajistán)',
        'kl' => 'groenlandés',
        'kl_GL' => 'groenlandés (Groenlandia)',
        'km' => 'jemer',
        'km_KH' => 'jemer (Camboya)',
        'kn' => 'canarés',
        'kn_IN' => 'canarés (India)',
        'ko' => 'coreano',
        'ko_CN' => 'coreano (China)',
        'ko_KP' => 'coreano (Corea del Norte)',
        'ko_KR' => 'coreano (Corea del Sur)',
        'ks' => 'cachemir',
        'ks_Arab' => 'cachemir (árabe)',
        'ks_Arab_IN' => 'cachemir (árabe, India)',
        'ks_Deva' => 'cachemir (devanagari)',
        'ks_Deva_IN' => 'cachemir (devanagari, India)',
        'ks_IN' => 'cachemir (India)',
        'ku' => 'kurdo',
        'ku_Latn' => 'kurdo (latino)',
        'ku_Latn_IQ' => 'kurdo (latino, Irak)',
        'ku_Latn_SY' => 'kurdo (latino, Siria)',
        'ku_Latn_TR' => 'kurdo (latino, Turquía)',
        'ku_SY' => 'kurdo (Siria)',
        'ku_TR' => 'kurdo (Turquía)',
        'kw' => 'córnico',
        'kw_GB' => 'córnico (Reino Unido)',
        'ky' => 'kirguís',
        'ky_KG' => 'kirguís (Kirguistán)',
        'lb' => 'luxemburgués',
        'lb_LU' => 'luxemburgués (Luxemburgo)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (República Democrática del Congo)',
        'ln_CF' => 'lingala (República Centroafricana)',
        'ln_CG' => 'lingala (Congo)',
        'lo' => 'lao',
        'lo_LA' => 'lao (Laos)',
        'lt' => 'lituano',
        'lt_LT' => 'lituano (Lituania)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (República Democrática del Congo)',
        'lv' => 'letón',
        'lv_LV' => 'letón (Letonia)',
        'mg' => 'malgache',
        'mg_MG' => 'malgache (Madagascar)',
        'mi' => 'maorí',
        'mi_NZ' => 'maorí (Nueva Zelanda)',
        'mk' => 'macedonio',
        'mk_MK' => 'macedonio (Macedonia del Norte)',
        'ml' => 'malayálam',
        'ml_IN' => 'malayálam (India)',
        'mn' => 'mongol',
        'mn_MN' => 'mongol (Mongolia)',
        'mr' => 'maratí',
        'mr_IN' => 'maratí (India)',
        'ms' => 'malayo',
        'ms_BN' => 'malayo (Brunéi)',
        'ms_ID' => 'malayo (Indonesia)',
        'ms_MY' => 'malayo (Malasia)',
        'ms_SG' => 'malayo (Singapur)',
        'mt' => 'maltés',
        'mt_MT' => 'maltés (Malta)',
        'my' => 'birmano',
        'my_MM' => 'birmano (Myanmar [Birmania])',
        'nb' => 'noruego bokmal',
        'nb_NO' => 'noruego bokmal (Noruega)',
        'nb_SJ' => 'noruego bokmal (Svalbard y Jan Mayen)',
        'nd' => 'ndebele septentrional',
        'nd_ZW' => 'ndebele septentrional (Zimbabue)',
        'ne' => 'nepalí',
        'ne_IN' => 'nepalí (India)',
        'ne_NP' => 'nepalí (Nepal)',
        'nl' => 'neerlandés',
        'nl_AW' => 'neerlandés (Aruba)',
        'nl_BE' => 'neerlandés (Bélgica)',
        'nl_BQ' => 'neerlandés (Caribe neerlandés)',
        'nl_CW' => 'neerlandés (Curazao)',
        'nl_NL' => 'neerlandés (Países Bajos)',
        'nl_SR' => 'neerlandés (Surinam)',
        'nl_SX' => 'neerlandés (Sint Maarten)',
        'nn' => 'noruego nynorsk',
        'nn_NO' => 'noruego nynorsk (Noruega)',
        'no' => 'noruego',
        'no_NO' => 'noruego (Noruega)',
        'oc' => 'occitano',
        'oc_ES' => 'occitano (España)',
        'oc_FR' => 'occitano (Francia)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Etiopía)',
        'om_KE' => 'oromo (Kenia)',
        'or' => 'oriya',
        'or_IN' => 'oriya (India)',
        'os' => 'osético',
        'os_GE' => 'osético (Georgia)',
        'os_RU' => 'osético (Rusia)',
        'pa' => 'punyabí',
        'pa_Arab' => 'punyabí (árabe)',
        'pa_Arab_PK' => 'punyabí (árabe, Pakistán)',
        'pa_Guru' => 'punyabí (gurmuji)',
        'pa_Guru_IN' => 'punyabí (gurmuji, India)',
        'pa_IN' => 'punyabí (India)',
        'pa_PK' => 'punyabí (Pakistán)',
        'pl' => 'polaco',
        'pl_PL' => 'polaco (Polonia)',
        'ps' => 'pastún',
        'ps_AF' => 'pastún (Afganistán)',
        'ps_PK' => 'pastún (Pakistán)',
        'pt' => 'portugués',
        'pt_AO' => 'portugués (Angola)',
        'pt_BR' => 'portugués (Brasil)',
        'pt_CH' => 'portugués (Suiza)',
        'pt_CV' => 'portugués (Cabo Verde)',
        'pt_GQ' => 'portugués (Guinea Ecuatorial)',
        'pt_GW' => 'portugués (Guinea-Bisáu)',
        'pt_LU' => 'portugués (Luxemburgo)',
        'pt_MO' => 'portugués (RAE de Macao [China])',
        'pt_MZ' => 'portugués (Mozambique)',
        'pt_PT' => 'portugués (Portugal)',
        'pt_ST' => 'portugués (Santo Tomé y Príncipe)',
        'pt_TL' => 'portugués (Timor-Leste)',
        'qu' => 'quechua',
        'qu_BO' => 'quechua (Bolivia)',
        'qu_EC' => 'quechua (Ecuador)',
        'qu_PE' => 'quechua (Perú)',
        'rm' => 'romanche',
        'rm_CH' => 'romanche (Suiza)',
        'rn' => 'kirundi',
        'rn_BI' => 'kirundi (Burundi)',
        'ro' => 'rumano',
        'ro_MD' => 'rumano (Moldavia)',
        'ro_RO' => 'rumano (Rumanía)',
        'ru' => 'ruso',
        'ru_BY' => 'ruso (Bielorrusia)',
        'ru_KG' => 'ruso (Kirguistán)',
        'ru_KZ' => 'ruso (Kazajistán)',
        'ru_MD' => 'ruso (Moldavia)',
        'ru_RU' => 'ruso (Rusia)',
        'ru_UA' => 'ruso (Ucrania)',
        'rw' => 'kinyarwanda',
        'rw_RW' => 'kinyarwanda (Ruanda)',
        'sa' => 'sánscrito',
        'sa_IN' => 'sánscrito (India)',
        'sc' => 'sardo',
        'sc_IT' => 'sardo (Italia)',
        'sd' => 'sindi',
        'sd_Arab' => 'sindi (árabe)',
        'sd_Arab_PK' => 'sindi (árabe, Pakistán)',
        'sd_Deva' => 'sindi (devanagari)',
        'sd_Deva_IN' => 'sindi (devanagari, India)',
        'sd_IN' => 'sindi (India)',
        'sd_PK' => 'sindi (Pakistán)',
        'se' => 'sami septentrional',
        'se_FI' => 'sami septentrional (Finlandia)',
        'se_NO' => 'sami septentrional (Noruega)',
        'se_SE' => 'sami septentrional (Suecia)',
        'sg' => 'sango',
        'sg_CF' => 'sango (República Centroafricana)',
        'sh' => 'serbocroata',
        'sh_BA' => 'serbocroata (Bosnia y Herzegovina)',
        'si' => 'cingalés',
        'si_LK' => 'cingalés (Sri Lanka)',
        'sk' => 'eslovaco',
        'sk_SK' => 'eslovaco (Eslovaquia)',
        'sl' => 'esloveno',
        'sl_SI' => 'esloveno (Eslovenia)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabue)',
        'so' => 'somalí',
        'so_DJ' => 'somalí (Yibuti)',
        'so_ET' => 'somalí (Etiopía)',
        'so_KE' => 'somalí (Kenia)',
        'so_SO' => 'somalí (Somalia)',
        'sq' => 'albanés',
        'sq_AL' => 'albanés (Albania)',
        'sq_MK' => 'albanés (Macedonia del Norte)',
        'sr' => 'serbio',
        'sr_BA' => 'serbio (Bosnia y Herzegovina)',
        'sr_Cyrl' => 'serbio (cirílico)',
        'sr_Cyrl_BA' => 'serbio (cirílico, Bosnia y Herzegovina)',
        'sr_Cyrl_ME' => 'serbio (cirílico, Montenegro)',
        'sr_Cyrl_RS' => 'serbio (cirílico, Serbia)',
        'sr_Latn' => 'serbio (latino)',
        'sr_Latn_BA' => 'serbio (latino, Bosnia y Herzegovina)',
        'sr_Latn_ME' => 'serbio (latino, Montenegro)',
        'sr_Latn_RS' => 'serbio (latino, Serbia)',
        'sr_ME' => 'serbio (Montenegro)',
        'sr_RS' => 'serbio (Serbia)',
        'st' => 'sotho meridional',
        'st_LS' => 'sotho meridional (Lesoto)',
        'st_ZA' => 'sotho meridional (Sudáfrica)',
        'su' => 'sundanés',
        'su_ID' => 'sundanés (Indonesia)',
        'su_Latn' => 'sundanés (latino)',
        'su_Latn_ID' => 'sundanés (latino, Indonesia)',
        'sv' => 'sueco',
        'sv_AX' => 'sueco (Islas Aland)',
        'sv_FI' => 'sueco (Finlandia)',
        'sv_SE' => 'sueco (Suecia)',
        'sw' => 'suajili',
        'sw_CD' => 'suajili (República Democrática del Congo)',
        'sw_KE' => 'suajili (Kenia)',
        'sw_TZ' => 'suajili (Tanzania)',
        'sw_UG' => 'suajili (Uganda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (India)',
        'ta_LK' => 'tamil (Sri Lanka)',
        'ta_MY' => 'tamil (Malasia)',
        'ta_SG' => 'tamil (Singapur)',
        'te' => 'telugu',
        'te_IN' => 'telugu (India)',
        'tg' => 'tayiko',
        'tg_TJ' => 'tayiko (Tayikistán)',
        'th' => 'tailandés',
        'th_TH' => 'tailandés (Tailandia)',
        'ti' => 'tigriña',
        'ti_ER' => 'tigriña (Eritrea)',
        'ti_ET' => 'tigriña (Etiopía)',
        'tk' => 'turcomano',
        'tk_TM' => 'turcomano (Turkmenistán)',
        'tl' => 'tagalo',
        'tl_PH' => 'tagalo (Filipinas)',
        'tn' => 'setsuana',
        'tn_BW' => 'setsuana (Botsuana)',
        'tn_ZA' => 'setsuana (Sudáfrica)',
        'to' => 'tongano',
        'to_TO' => 'tongano (Tonga)',
        'tr' => 'turco',
        'tr_CY' => 'turco (Chipre)',
        'tr_TR' => 'turco (Turquía)',
        'tt' => 'tártaro',
        'tt_RU' => 'tártaro (Rusia)',
        'ug' => 'uigur',
        'ug_CN' => 'uigur (China)',
        'uk' => 'ucraniano',
        'uk_UA' => 'ucraniano (Ucrania)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (India)',
        'ur_PK' => 'urdu (Pakistán)',
        'uz' => 'uzbeko',
        'uz_AF' => 'uzbeko (Afganistán)',
        'uz_Arab' => 'uzbeko (árabe)',
        'uz_Arab_AF' => 'uzbeko (árabe, Afganistán)',
        'uz_Cyrl' => 'uzbeko (cirílico)',
        'uz_Cyrl_UZ' => 'uzbeko (cirílico, Uzbekistán)',
        'uz_Latn' => 'uzbeko (latino)',
        'uz_Latn_UZ' => 'uzbeko (latino, Uzbekistán)',
        'uz_UZ' => 'uzbeko (Uzbekistán)',
        'vi' => 'vietnamita',
        'vi_VN' => 'vietnamita (Vietnam)',
        'wo' => 'wólof',
        'wo_SN' => 'wólof (Senegal)',
        'xh' => 'xhosa',
        'xh_ZA' => 'xhosa (Sudáfrica)',
        'yi' => 'yidis',
        'yi_UA' => 'yidis (Ucrania)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benín)',
        'yo_NG' => 'yoruba (Nigeria)',
        'za' => 'zhuang',
        'za_CN' => 'zhuang (China)',
        'zh' => 'chino',
        'zh_CN' => 'chino (China)',
        'zh_HK' => 'chino (RAE de Hong Kong [China])',
        'zh_Hans' => 'chino (simplificado)',
        'zh_Hans_CN' => 'chino (simplificado, China)',
        'zh_Hans_HK' => 'chino (simplificado, RAE de Hong Kong [China])',
        'zh_Hans_MO' => 'chino (simplificado, RAE de Macao [China])',
        'zh_Hans_MY' => 'chino (simplificado, Malasia)',
        'zh_Hans_SG' => 'chino (simplificado, Singapur)',
        'zh_Hant' => 'chino (tradicional)',
        'zh_Hant_HK' => 'chino (tradicional, RAE de Hong Kong [China])',
        'zh_Hant_MO' => 'chino (tradicional, RAE de Macao [China])',
        'zh_Hant_MY' => 'chino (tradicional, Malasia)',
        'zh_Hant_TW' => 'chino (tradicional, Taiwán)',
        'zh_MO' => 'chino (RAE de Macao [China])',
        'zh_SG' => 'chino (Singapur)',
        'zh_TW' => 'chino (Taiwán)',
        'zu' => 'zulú',
        'zu_ZA' => 'zulú (Sudáfrica)',
    ],
];
