<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'Arap elipbiýi',
        'Aran' => 'Nastalik ýazuwy',
        'Armn' => 'Ermeni elipbiýi',
        'Beng' => 'Bengal elipbiýi',
        'Bopo' => 'Bopomofo elipbiýi',
        'Brai' => 'Braýl elipbiýi',
        'Cakm' => 'çakma',
        'Cans' => 'Kanadanyň ýerlileriniň bogunlarynyň bitewileşdirilen ulgamy',
        'Cher' => 'çeroki',
        'Cyrl' => 'Kiril elipbiýi',
        'Deva' => 'Dewanagari elipbiýi',
        'Ethi' => 'Efiop elipbiýi',
        'Geor' => 'Gruzin elipbiýi',
        'Grek' => 'Grek elipbiýi',
        'Gujr' => 'Gujarati elipbiýi',
        'Guru' => 'Gurmuhi elipbiýi',
        'Hanb' => 'Bopomofo han elipbiýi',
        'Hang' => 'Hangyl elipbiýi',
        'Hani' => 'Han elipbiýi',
        'Hans' => 'Ýönekeýleşdirilen',
        'Hant' => 'Adaty',
        'Hebr' => 'Ýewreý elipbiýi',
        'Hira' => 'Hiragana elipbiýi',
        'Hrkt' => 'Ýapon bogun elipbiýleri',
        'Jamo' => 'Jamo elipbiýi',
        'Jpan' => 'Ýapon elipbiýi',
        'Kana' => 'Katakana elipbiýi',
        'Khmr' => 'Khmer elipbiýi',
        'Knda' => 'Kannada elipbiýi',
        'Kore' => 'Koreý elipbiýi',
        'Laoo' => 'Laos elipbiýi',
        'Latn' => 'Latyn elipbiýi',
        'Mlym' => 'Malaýalam elipbiýi',
        'Mong' => 'Mongol elipbiýi',
        'Mtei' => 'meýteý-maýek',
        'Mymr' => 'Mýanma elipbiýi',
        'Nkoo' => 'nko',
        'Olck' => 'ol-çiki',
        'Orya' => 'Oriýa elipbiýi',
        'Rohg' => 'hanifi',
        'Sinh' => 'Singal elipbiýi',
        'Sund' => 'Sundanez ýazuwy',
        'Syrc' => 'Siriýa ýazuwy',
        'Taml' => 'Tamil elipbiýi',
        'Telu' => 'Telugu elipbiýi',
        'Tfng' => 'Tifinag ýazuwy',
        'Thaa' => 'Taana elipbiýi',
        'Thai' => 'Taý elipbiýi',
        'Tibt' => 'Tibet elipbiýi',
        'Vaii' => 'Waý ýazuwy',
        'Yiii' => 'Ýi ýazuwy',
        'Zmth' => 'Matematiki belgiler',
        'Zsye' => 'Emoji',
        'Zsym' => 'Nyşanlar',
        'Zxxx' => 'Ýazuwsyz',
        'Zyyy' => 'Umumy',
    ],
];
