<?php

return [
    '🇦🇨' => 'bandera: Islla Ascensión',
    '🇦🇩' => 'bandera: Andorra',
    '🇦🇪' => 'bandera: Emiratos Árabes Xuníos',
    '🇦🇫' => 'bandera: Afganistán',
    '🇦🇬' => 'bandera: Antigua y Barbuda',
    '🇦🇮' => 'bandera: Anguila',
    '🇦🇱' => 'bandera: Albania',
    '🇦🇲' => 'bandera: Armenia',
    '🇦🇴' => 'bandera: Angola',
    '🇦🇶' => 'bandera: L’Antártida',
    '🇦🇷' => 'bandera: Arxentina',
    '🇦🇸' => 'bandera: Samoa Americana',
    '🇦🇹' => 'bandera: Austria',
    '🇦🇺' => 'bandera: Australia',
    '🇦🇼' => 'bandera: Aruba',
    '🇦🇽' => 'bandera: Islles Aland',
    '🇦🇿' => 'bandera: Azerbaixán',
    '🇧🇦' => 'bandera: Bosnia y Herzegovina',
    '🇧🇧' => 'bandera: Barbados',
    '🇧🇩' => 'bandera: Bangladex',
    '🇧🇪' => 'bandera: Bélxica',
    '🇧🇫' => 'bandera: Burkina Fasu',
    '🇧🇬' => 'bandera: Bulgaria',
    '🇧🇭' => 'bandera: Baḥréin',
    '🇧🇮' => 'bandera: Burundi',
    '🇧🇯' => 'bandera: Benín',
    '🇧🇱' => 'bandera: San Bartolomé',
    '🇧🇲' => 'bandera: Les Bermudes',
    '🇧🇳' => 'bandera: Brunéi',
    '🇧🇴' => 'bandera: Bolivia',
    '🇧🇶' => 'bandera: Caribe neerlandés',
    '🇧🇷' => 'bandera: Brasil',
    '🇧🇸' => 'bandera: Les Bahames',
    '🇧🇹' => 'bandera: Bután',
    '🇧🇻' => 'bandera: Islla Bouvet',
    '🇧🇼' => 'bandera: Botsuana',
    '🇧🇾' => 'bandera: Bielorrusia',
    '🇧🇿' => 'bandera: Belize',
    '🇨🇦' => 'bandera: Canadá',
    '🇨🇨' => 'bandera: Islles Cocos (Keeling)',
    '🇨🇩' => 'bandera: Congu - Kinxasa',
    '🇨🇫' => 'bandera: República Centroafricana',
    '🇨🇬' => 'bandera: Congu - Brazzaville',
    '🇨🇭' => 'bandera: Suiza',
    '🇨🇮' => 'bandera: Costa de Marfil',
    '🇨🇰' => 'bandera: Islles Cook',
    '🇨🇱' => 'bandera: Chile',
    '🇨🇲' => 'bandera: Camerún',
    '🇨🇳' => 'bandera: China',
    '🇨🇴' => 'bandera: Colombia',
    '🇨🇵' => 'bandera: Islla Clipperton',
    '🇨🇷' => 'bandera: Costa Rica',
    '🇨🇺' => 'bandera: Cuba',
    '🇨🇻' => 'bandera: Cabu Verde',
    '🇨🇼' => 'bandera: Curaçao',
    '🇨🇽' => 'bandera: Islla Christmas',
    '🇨🇾' => 'bandera: Xipre',
    '🇨🇿' => 'bandera: Chequia',
    '🇩🇪' => 'bandera: Alemaña',
    '🇩🇬' => 'bandera: Diego Garcia',
    '🇩🇯' => 'bandera: Xibuti',
    '🇩🇰' => 'bandera: Dinamarca',
    '🇩🇲' => 'bandera: Dominica',
    '🇩🇴' => 'bandera: República Dominicana',
    '🇩🇿' => 'bandera: Arxelia',
    '🇪🇦' => 'bandera: Ceuta y Melilla',
    '🇪🇨' => 'bandera: Ecuador',
    '🇪🇪' => 'bandera: Estonia',
    '🇪🇬' => 'bandera: Exiptu',
    '🇪🇭' => 'bandera: Sáḥara Occidental',
    '🇪🇷' => 'bandera: Eritrea',
    '🇪🇸' => 'bandera: España',
    '🇪🇹' => 'bandera: Etiopía',
    '🇪🇺' => 'bandera: Xunión Europea',
    '🇫🇮' => 'bandera: Finlandia',
    '🇫🇯' => 'bandera: Islles Fixi',
    '🇫🇰' => 'bandera: Falkland Islands',
    '🇫🇲' => 'bandera: Micronesia',
    '🇫🇴' => 'bandera: Islles Feroe',
    '🇫🇷' => 'bandera: Francia',
    '🇬🇦' => 'bandera: Gabón',
    '🇬🇧' => 'bandera: Reinu Xuníu',
    '🇬🇩' => 'bandera: Granada',
    '🇬🇪' => 'bandera: Xeorxa',
    '🇬🇫' => 'bandera: Guyana Francesa',
    '🇬🇬' => 'bandera: Guernsey',
    '🇬🇭' => 'bandera: Ghana',
    '🇬🇮' => 'bandera: Xibraltar',
    '🇬🇱' => 'bandera: Groenlandia',
    '🇬🇲' => 'bandera: Gambia',
    '🇬🇳' => 'bandera: Guinea',
    '🇬🇵' => 'bandera: Guadalupe',
    '🇬🇶' => 'bandera: Guinea Ecuatorial',
    '🇬🇷' => 'bandera: Grecia',
    '🇬🇸' => 'bandera: Islles Xeorxa del Sur y Sandwich del Sur',
    '🇬🇹' => 'bandera: Guatemala',
    '🇬🇺' => 'bandera: Guam',
    '🇬🇼' => 'bandera: Guinea-Bisáu',
    '🇬🇾' => 'bandera: Guyana',
    '🇭🇰' => 'bandera: ARE China de Ḥong Kong',
    '🇭🇲' => 'bandera: Islles Heard y McDonald',
    '🇭🇳' => 'bandera: Hondures',
    '🇭🇷' => 'bandera: Croacia',
    '🇭🇹' => 'bandera: Haití',
    '🇭🇺' => 'bandera: Hungría',
    '🇮🇨' => 'bandera: Islles Canaries',
    '🇮🇩' => 'bandera: Indonesia',
    '🇮🇪' => 'bandera: Irlanda',
    '🇮🇱' => 'bandera: Israel',
    '🇮🇲' => 'bandera: Islla de Man',
    '🇮🇳' => 'bandera: India',
    '🇮🇴' => 'bandera: Territoriu Británicu del Océanu Índicu',
    '🇮🇶' => 'bandera: Iraq',
    '🇮🇷' => 'bandera: Irán',
    '🇮🇸' => 'bandera: Islandia',
    '🇮🇹' => 'bandera: Italia',
    '🇯🇪' => 'bandera: Jersey',
    '🇯🇲' => 'bandera: Xamaica',
    '🇯🇴' => 'bandera: Xordania',
    '🇯🇵' => 'bandera: Xapón',
    '🇰🇪' => 'bandera: Kenia',
    '🇰🇬' => 'bandera: Kirguistán',
    '🇰🇭' => 'bandera: Camboya',
    '🇰🇮' => 'bandera: Kiribati',
    '🇰🇲' => 'bandera: Les Comores',
    '🇰🇳' => 'bandera: Saint Kitts y Nevis',
    '🇰🇵' => 'bandera: Corea del Norte',
    '🇰🇷' => 'bandera: Corea del Sur',
    '🇰🇼' => 'bandera: Kuwait',
    '🇰🇾' => 'bandera: Islles Caimán',
    '🇰🇿' => 'bandera: Kazakstán',
    '🇱🇦' => 'bandera: Laos',
    '🇱🇧' => 'bandera: Líbanu',
    '🇱🇨' => 'bandera: Santa Llucía',
    '🇱🇮' => 'bandera: Liechtenstein',
    '🇱🇰' => 'bandera: Sri Lanka',
    '🇱🇷' => 'bandera: Liberia',
    '🇱🇸' => 'bandera: Lesothu',
    '🇱🇹' => 'bandera: Lituania',
    '🇱🇺' => 'bandera: Luxemburgu',
    '🇱🇻' => 'bandera: Letonia',
    '🇱🇾' => 'bandera: Libia',
    '🇲🇦' => 'bandera: Marruecos',
    '🇲🇨' => 'bandera: Mónacu',
    '🇲🇩' => 'bandera: Moldavia',
    '🇲🇪' => 'bandera: Montenegru',
    '🇲🇫' => 'bandera: Saint Martin',
    '🇲🇬' => 'bandera: Madagascar',
    '🇲🇭' => 'bandera: Islles Marshall',
    '🇲🇱' => 'bandera: Malí',
    '🇲🇲' => 'bandera: Myanmar (Birmania)',
    '🇲🇳' => 'bandera: Mongolia',
    '🇲🇴' => 'bandera: ARE China de Macáu',
    '🇲🇵' => 'bandera: Islles Marianes del Norte',
    '🇲🇶' => 'bandera: La Martinica',
    '🇲🇷' => 'bandera: Mauritania',
    '🇲🇸' => 'bandera: Montserrat',
    '🇲🇹' => 'bandera: Malta',
    '🇲🇺' => 'bandera: Mauriciu',
    '🇲🇻' => 'bandera: Les Maldives',
    '🇲🇼' => 'bandera: Malaui',
    '🇲🇽' => 'bandera: Méxicu',
    '🇲🇾' => 'bandera: Malasia',
    '🇲🇿' => 'bandera: Mozambique',
    '🇳🇦' => 'bandera: Namibia',
    '🇳🇨' => 'bandera: Nueva Caledonia',
    '🇳🇪' => 'bandera: El Níxer',
    '🇳🇫' => 'bandera: Islla Norfolk',
    '🇳🇬' => 'bandera: Nixeria',
    '🇳🇮' => 'bandera: Nicaragua',
    '🇳🇱' => 'bandera: Países Baxos',
    '🇳🇴' => 'bandera: Noruega',
    '🇳🇵' => 'bandera: Nepal',
    '🇳🇷' => 'bandera: Nauru',
    '🇳🇺' => 'bandera: Niue',
    '🇳🇿' => 'bandera: Nueva Zelanda',
    '🇴🇲' => 'bandera: Omán',
    '🇵🇦' => 'bandera: Panamá',
    '🇵🇪' => 'bandera: Perú',
    '🇵🇫' => 'bandera: Polinesia Francesa',
    '🇵🇬' => 'bandera: Papúa Nueva Guinea',
    '🇵🇭' => 'bandera: Filipines',
    '🇵🇰' => 'bandera: Paquistán',
    '🇵🇱' => 'bandera: Polonia',
    '🇵🇲' => 'bandera: Saint Pierre y Miquelon',
    '🇵🇳' => 'bandera: Islles Pitcairn',
    '🇵🇷' => 'bandera: Puertu Ricu',
    '🇵🇸' => 'bandera: Territorios Palestinos',
    '🇵🇹' => 'bandera: Portugal',
    '🇵🇼' => 'bandera: Paláu',
    '🇵🇾' => 'bandera: Paraguái',
    '🇶🇦' => 'bandera: Qatar',
    '🇷🇪' => 'bandera: Reunión',
    '🇷🇴' => 'bandera: Rumanía',
    '🇷🇸' => 'bandera: Serbia',
    '🇷🇺' => 'bandera: Rusia',
    '🇷🇼' => 'bandera: Ruanda',
    '🇸🇦' => 'bandera: Arabia Saudita',
    '🇸🇧' => 'bandera: Islles Salomón',
    '🇸🇨' => 'bandera: Les Seixeles',
    '🇸🇩' => 'bandera: Sudán',
    '🇸🇪' => 'bandera: Suecia',
    '🇸🇬' => 'bandera: Singapur',
    '🇸🇭' => 'bandera: Santa Helena',
    '🇸🇮' => 'bandera: Eslovenia',
    '🇸🇯' => 'bandera: Svalbard ya Islla Jan Mayen',
    '🇸🇰' => 'bandera: Eslovaquia',
    '🇸🇱' => 'bandera: Sierra Lleona',
    '🇸🇲' => 'bandera: San Marín',
    '🇸🇳' => 'bandera: Senegal',
    '🇸🇴' => 'bandera: Somalia',
    '🇸🇷' => 'bandera: Surinam',
    '🇸🇸' => 'bandera: Sudán del Sur',
    '🇸🇹' => 'bandera: Santu Tomé y Príncipe',
    '🇸🇻' => 'bandera: El Salvador',
    '🇸🇽' => 'bandera: Sint Maarten',
    '🇸🇾' => 'bandera: Siria',
    '🇸🇿' => 'bandera: Suazilandia',
    '🇹🇦' => 'bandera: Tristán da Cunha',
    '🇹🇨' => 'bandera: Islles Turques y Caicos',
    '🇹🇩' => 'bandera: Chad',
    '🇹🇫' => 'bandera: Tierres Australes Franceses',
    '🇹🇬' => 'bandera: Togu',
    '🇹🇭' => 'bandera: Tailandia',
    '🇹🇯' => 'bandera: Taxiquistán',
    '🇹🇰' => 'bandera: Tokeláu',
    '🇹🇱' => 'bandera: Timor Oriental',
    '🇹🇲' => 'bandera: Turkmenistán',
    '🇹🇳' => 'bandera: Tunicia',
    '🇹🇴' => 'bandera: Tonga',
    '🇹🇷' => 'bandera: Turquía',
    '🇹🇹' => 'bandera: Trinidá y Tobagu',
    '🇹🇻' => 'bandera: Tuvalu',
    '🇹🇼' => 'bandera: Taiwán',
    '🇹🇿' => 'bandera: Tanzania',
    '🇺🇦' => 'bandera: Ucraína',
    '🇺🇬' => 'bandera: Uganda',
    '🇺🇲' => 'bandera: Islles Perifériques Menores de los EE.XX.',
    '🇺🇳' => 'bandera: Naciones Xuníes',
    '🇺🇸' => 'bandera: Estaos Xuníos',
    '🇺🇾' => 'bandera: Uruguái',
    '🇺🇿' => 'bandera: Uzbequistán',
    '🇻🇦' => 'bandera: Ciudá del Vaticanu',
    '🇻🇨' => 'bandera: San Vicente y Granadines',
    '🇻🇪' => 'bandera: Venezuela',
    '🇻🇬' => 'bandera: Islles Vírxenes Britániques',
    '🇻🇮' => 'bandera: Islles Vírxenes Americanes',
    '🇻🇳' => 'bandera: Vietnam',
    '🇻🇺' => 'bandera: Vanuatu',
    '🇼🇫' => 'bandera: Wallis y Futuna',
    '🇼🇸' => 'bandera: Samoa',
    '🇽🇰' => 'bandera: Kosovu',
    '🇾🇪' => 'bandera: Yemen',
    '🇾🇹' => 'bandera: Mayotte',
    '🇿🇦' => 'bandera: Sudáfrica',
    '🇿🇲' => 'bandera: Zambia',
    '🇿🇼' => 'bandera: Zimbabue',
    '🔟' => 'tecles: 10',
    '🤣' => 'rodando pel suelu de risa',
    '😂' => 'cara llorando d’allegría',
    '😘' => 'cara tirando un besu',
    '😗' => 'cara besando',
    '☺' => 'cara sorriendo',
    '🤳' => 'selfie',
    '👅' => 'llingua',
    '👄' => 'boca',
    '💏' => 'besu',
    '👪' => 'familia',
    '💍' => 'aniellu',
    '💎' => 'piedra preciosa',
];
