<?php

return [
    'Names' => [
        'ak' => 'chiAkani',
        'ak_GH' => 'chiAkani (Ghana)',
        'am' => 'chiAmaric',
        'am_ET' => 'chiAmaric (Etiopia)',
        'ar' => 'chiArabu',
        'ar_AE' => 'chiArabu (United Arab Emirates)',
        'ar_BH' => 'chiArabu (Bahareni)',
        'ar_DJ' => 'chiArabu (Djibouti)',
        'ar_DZ' => 'chiArabu (Aljeria)',
        'ar_EG' => 'chiArabu (Egypt)',
        'ar_ER' => 'chiArabu (Eritrea)',
        'ar_IL' => 'chiArabu (Izuraeri)',
        'ar_IQ' => 'chiArabu (Iraq)',
        'ar_JO' => 'chiArabu (Jordan)',
        'ar_KM' => 'chiArabu (Komoro)',
        'ar_KW' => 'chiArabu (Kuwait)',
        'ar_LB' => 'chiArabu (Lebanon)',
        'ar_LY' => 'chiArabu (Libya)',
        'ar_MA' => 'chiArabu (Morocco)',
        'ar_MR' => 'chiArabu (Mauritania)',
        'ar_OM' => 'chiArabu (Oman)',
        'ar_QA' => 'chiArabu (Qatar)',
        'ar_SA' => 'chiArabu (Saudi Arabia)',
        'ar_SD' => 'chiArabu (Sudan)',
        'ar_SO' => 'chiArabu (Somalia)',
        'ar_SY' => 'chiArabu (Syria)',
        'ar_TD' => 'chiArabu (Chadi)',
        'ar_TN' => 'chiArabu (Tunisia)',
        'ar_YE' => 'chiArabu (Yemen)',
        'be' => 'chiBelarusi',
        'be_BY' => 'chiBelarusi (Belarusi)',
        'bg' => 'chiBulgarian',
        'bg_BG' => 'chiBulgarian (Bulgaria)',
        'bn' => 'chiBengali',
        'bn_BD' => 'chiBengali (Bangladeshi)',
        'bn_IN' => 'chiBengali (India)',
        'cs' => 'chiCzech',
        'cs_CZ' => 'chiCzech (Czech Republic)',
        'de' => 'chiJerimani',
        'de_AT' => 'chiJerimani (Austria)',
        'de_BE' => 'chiJerimani (Beljium)',
        'de_CH' => 'chiJerimani (Switzerland)',
        'de_DE' => 'chiJerimani (Germany)',
        'de_IT' => 'chiJerimani (Italy)',
        'de_LI' => 'chiJerimani (Liechtenstein)',
        'de_LU' => 'chiJerimani (Luxembourg)',
        'el' => 'chiGreek',
        'el_CY' => 'chiGreek (Cyprus)',
        'el_GR' => 'chiGreek (Greece)',
        'en' => 'Chirungu',
        'en_AE' => 'Chirungu (United Arab Emirates)',
        'en_AG' => 'Chirungu (Antigua ne Barbuda)',
        'en_AI' => 'Chirungu (Anguila)',
        'en_AS' => 'Chirungu (Samoa ye Amerika)',
        'en_AT' => 'Chirungu (Austria)',
        'en_AU' => 'Chirungu (Australia)',
        'en_BB' => 'Chirungu (Barbados)',
        'en_BE' => 'Chirungu (Beljium)',
        'en_BI' => 'Chirungu (Burundi)',
        'en_BM' => 'Chirungu (Bermuda)',
        'en_BS' => 'Chirungu (Bahama)',
        'en_BW' => 'Chirungu (Botswana)',
        'en_BZ' => 'Chirungu (Belize)',
        'en_CA' => 'Chirungu (Kanada)',
        'en_CH' => 'Chirungu (Switzerland)',
        'en_CK' => 'Chirungu (Zvitsuwa zveCook)',
        'en_CM' => 'Chirungu (Kameruni)',
        'en_CY' => 'Chirungu (Cyprus)',
        'en_CZ' => 'Chirungu (Czech Republic)',
        'en_DE' => 'Chirungu (Germany)',
        'en_DK' => 'Chirungu (Denmark)',
        'en_DM' => 'Chirungu (Dominica)',
        'en_EE' => 'Chirungu (Estonia)',
        'en_ER' => 'Chirungu (Eritrea)',
        'en_ES' => 'Chirungu (Spain)',
        'en_FI' => 'Chirungu (Finland)',
        'en_FJ' => 'Chirungu (Fiji)',
        'en_FK' => 'Chirungu (Zvitsuwa zveFalklands)',
        'en_FM' => 'Chirungu (Micronesia)',
        'en_FR' => 'Chirungu (France)',
        'en_GB' => 'Chirungu (United Kingdom)',
        'en_GD' => 'Chirungu (Grenada)',
        'en_GE' => 'Chirungu (Georgia)',
        'en_GH' => 'Chirungu (Ghana)',
        'en_GI' => 'Chirungu (Gibraltar)',
        'en_GM' => 'Chirungu (Gambia)',
        'en_GU' => 'Chirungu (Guam)',
        'en_GY' => 'Chirungu (Guyana)',
        'en_HU' => 'Chirungu (Hungary)',
        'en_ID' => 'Chirungu (Indonesia)',
        'en_IE' => 'Chirungu (Ireland)',
        'en_IL' => 'Chirungu (Izuraeri)',
        'en_IN' => 'Chirungu (India)',
        'en_IT' => 'Chirungu (Italy)',
        'en_JM' => 'Chirungu (Jamaica)',
        'en_JP' => 'Chirungu (Japan)',
        'en_KE' => 'Chirungu (Kenya)',
        'en_KI' => 'Chirungu (Kiribati)',
        'en_KN' => 'Chirungu (Saint Kitts and Nevis)',
        'en_KY' => 'Chirungu (Zvitsuwa zveCayman)',
        'en_LC' => 'Chirungu (Saint Lucia)',
        'en_LR' => 'Chirungu (Liberia)',
        'en_LS' => 'Chirungu (Lesotho)',
        'en_LT' => 'Chirungu (Lithuania)',
        'en_LV' => 'Chirungu (Latvia)',
        'en_MG' => 'Chirungu (Madagascar)',
        'en_MH' => 'Chirungu (Zvitsuwa zveMarshall)',
        'en_MP' => 'Chirungu (Zvitsuwa zvekumaodzanyemba eMariana)',
        'en_MS' => 'Chirungu (Montserrat)',
        'en_MT' => 'Chirungu (Malta)',
        'en_MU' => 'Chirungu (Mauritius)',
        'en_MV' => 'Chirungu (Maldives)',
        'en_MW' => 'Chirungu (Malawi)',
        'en_MY' => 'Chirungu (Malaysia)',
        'en_NA' => 'Chirungu (Namibia)',
        'en_NF' => 'Chirungu (Chitsuwa cheNorfolk)',
        'en_NG' => 'Chirungu (Nigeria)',
        'en_NL' => 'Chirungu (Netherlands)',
        'en_NO' => 'Chirungu (Norway)',
        'en_NR' => 'Chirungu (Nauru)',
        'en_NU' => 'Chirungu (Niue)',
        'en_NZ' => 'Chirungu (New Zealand)',
        'en_PG' => 'Chirungu (Papua New Guinea)',
        'en_PH' => 'Chirungu (Philippines)',
        'en_PK' => 'Chirungu (Pakistan)',
        'en_PL' => 'Chirungu (Poland)',
        'en_PN' => 'Chirungu (Pitcairn)',
        'en_PR' => 'Chirungu (Puerto Rico)',
        'en_PT' => 'Chirungu (Portugal)',
        'en_PW' => 'Chirungu (Palau)',
        'en_RO' => 'Chirungu (Romania)',
        'en_RW' => 'Chirungu (Rwanda)',
        'en_SB' => 'Chirungu (Zvitsuwa zvaSolomon)',
        'en_SC' => 'Chirungu (Seychelles)',
        'en_SD' => 'Chirungu (Sudan)',
        'en_SE' => 'Chirungu (Sweden)',
        'en_SG' => 'Chirungu (Singapore)',
        'en_SH' => 'Chirungu (Saint Helena)',
        'en_SI' => 'Chirungu (Slovenia)',
        'en_SK' => 'Chirungu (Slovakia)',
        'en_SL' => 'Chirungu (Sierra Leone)',
        'en_SZ' => 'Chirungu (Swaziland)',
        'en_TC' => 'Chirungu (Zvitsuwa zveTurk neCaico)',
        'en_TK' => 'Chirungu (Tokelau)',
        'en_TO' => 'Chirungu (Tonga)',
        'en_TT' => 'Chirungu (Trinidad and Tobago)',
        'en_TV' => 'Chirungu (Tuvalu)',
        'en_TZ' => 'Chirungu (Tanzania)',
        'en_UA' => 'Chirungu (Ukraine)',
        'en_UG' => 'Chirungu (Uganda)',
        'en_US' => 'Chirungu (Amerika)',
        'en_VC' => 'Chirungu (Saint Vincent and the Grenadines)',
        'en_VG' => 'Chirungu (Zvitsuwa zveHingirandi)',
        'en_VI' => 'Chirungu (Zvitsuwa zveAmerika)',
        'en_VU' => 'Chirungu (Vanuatu)',
        'en_WS' => 'Chirungu (Samoa)',
        'en_ZA' => 'Chirungu (South Africa)',
        'en_ZM' => 'Chirungu (Zambia)',
        'en_ZW' => 'Chirungu (Zimbabwe)',
        'es' => 'chiSpanish',
        'es_AR' => 'chiSpanish (Ajentina)',
        'es_BO' => 'chiSpanish (Bolivia)',
        'es_BR' => 'chiSpanish (Brazil)',
        'es_BZ' => 'chiSpanish (Belize)',
        'es_CL' => 'chiSpanish (Chile)',
        'es_CO' => 'chiSpanish (Kolombia)',
        'es_CR' => 'chiSpanish (Kostarika)',
        'es_CU' => 'chiSpanish (Cuba)',
        'es_DO' => 'chiSpanish (Dominican Republic)',
        'es_EC' => 'chiSpanish (Ecuador)',
        'es_ES' => 'chiSpanish (Spain)',
        'es_GQ' => 'chiSpanish (Equatorial Guinea)',
        'es_GT' => 'chiSpanish (Guatemala)',
        'es_HN' => 'chiSpanish (Honduras)',
        'es_MX' => 'chiSpanish (Mexico)',
        'es_NI' => 'chiSpanish (Nicaragua)',
        'es_PA' => 'chiSpanish (Panama)',
        'es_PE' => 'chiSpanish (Peru)',
        'es_PH' => 'chiSpanish (Philippines)',
        'es_PR' => 'chiSpanish (Puerto Rico)',
        'es_PY' => 'chiSpanish (Paraguay)',
        'es_SV' => 'chiSpanish (El Salvador)',
        'es_US' => 'chiSpanish (Amerika)',
        'es_UY' => 'chiSpanish (Uruguay)',
        'es_VE' => 'chiSpanish (Venezuela)',
        'fa' => 'chiPeshiya',
        'fa_AF' => 'chiPeshiya (Afuganistani)',
        'fa_IR' => 'chiPeshiya (Iran)',
        'fr' => 'chiFurenchi',
        'fr_BE' => 'chiFurenchi (Beljium)',
        'fr_BF' => 'chiFurenchi (Bukinafaso)',
        'fr_BI' => 'chiFurenchi (Burundi)',
        'fr_BJ' => 'chiFurenchi (Benini)',
        'fr_CA' => 'chiFurenchi (Kanada)',
        'fr_CD' => 'chiFurenchi (Democratic Republic of the Congo)',
        'fr_CF' => 'chiFurenchi (Central African Republic)',
        'fr_CG' => 'chiFurenchi (Kongo)',
        'fr_CH' => 'chiFurenchi (Switzerland)',
        'fr_CI' => 'chiFurenchi (Ivory Coast)',
        'fr_CM' => 'chiFurenchi (Kameruni)',
        'fr_DJ' => 'chiFurenchi (Djibouti)',
        'fr_DZ' => 'chiFurenchi (Aljeria)',
        'fr_FR' => 'chiFurenchi (France)',
        'fr_GA' => 'chiFurenchi (Gabon)',
        'fr_GF' => 'chiFurenchi (French Guiana)',
        'fr_GN' => 'chiFurenchi (Guinea)',
        'fr_GP' => 'chiFurenchi (Guadeloupe)',
        'fr_GQ' => 'chiFurenchi (Equatorial Guinea)',
        'fr_HT' => 'chiFurenchi (Haiti)',
        'fr_KM' => 'chiFurenchi (Komoro)',
        'fr_LU' => 'chiFurenchi (Luxembourg)',
        'fr_MA' => 'chiFurenchi (Morocco)',
        'fr_MC' => 'chiFurenchi (Monaco)',
        'fr_MG' => 'chiFurenchi (Madagascar)',
        'fr_ML' => 'chiFurenchi (Mali)',
        'fr_MQ' => 'chiFurenchi (Martinique)',
        'fr_MR' => 'chiFurenchi (Mauritania)',
        'fr_MU' => 'chiFurenchi (Mauritius)',
        'fr_NC' => 'chiFurenchi (New Caledonia)',
        'fr_NE' => 'chiFurenchi (Niger)',
        'fr_PF' => 'chiFurenchi (French Polynesia)',
        'fr_PM' => 'chiFurenchi (Saint Pierre and Miquelon)',
        'fr_RE' => 'chiFurenchi (Réunion)',
        'fr_RW' => 'chiFurenchi (Rwanda)',
        'fr_SC' => 'chiFurenchi (Seychelles)',
        'fr_SN' => 'chiFurenchi (Senegal)',
        'fr_SY' => 'chiFurenchi (Syria)',
        'fr_TD' => 'chiFurenchi (Chadi)',
        'fr_TG' => 'chiFurenchi (Togo)',
        'fr_TN' => 'chiFurenchi (Tunisia)',
        'fr_VU' => 'chiFurenchi (Vanuatu)',
        'fr_WF' => 'chiFurenchi (Wallis and Futuna)',
        'fr_YT' => 'chiFurenchi (Mayotte)',
        'ha' => 'chiHausa',
        'ha_GH' => 'chiHausa (Ghana)',
        'ha_NE' => 'chiHausa (Niger)',
        'ha_NG' => 'chiHausa (Nigeria)',
        'hi' => 'chiHindi',
        'hi_IN' => 'chiHindi (India)',
        'hu' => 'chiHungari',
        'hu_HU' => 'chiHungari (Hungary)',
        'id' => 'chiIndonesia',
        'id_ID' => 'chiIndonesia (Indonesia)',
        'ig' => 'chiIgbo',
        'ig_NG' => 'chiIgbo (Nigeria)',
        'it' => 'chiTariana',
        'it_CH' => 'chiTariana (Switzerland)',
        'it_IT' => 'chiTariana (Italy)',
        'it_SM' => 'chiTariana (San Marino)',
        'it_VA' => 'chiTariana (Vatican State)',
        'ja' => 'chiJapani',
        'ja_JP' => 'chiJapani (Japan)',
        'jv' => 'chiJava',
        'jv_ID' => 'chiJava (Indonesia)',
        'km' => 'chiKhema',
        'km_KH' => 'chiKhema (Kambodia)',
        'ko' => 'chiKoria',
        'ko_CN' => 'chiKoria (China)',
        'ko_KP' => 'chiKoria (Korea, North)',
        'ko_KR' => 'chiKoria (Korea, South)',
        'ms' => 'chiMalay',
        'ms_BN' => 'chiMalay (Burunei)',
        'ms_ID' => 'chiMalay (Indonesia)',
        'ms_MY' => 'chiMalay (Malaysia)',
        'ms_SG' => 'chiMalay (Singapore)',
        'my' => 'chiBurma',
        'my_MM' => 'chiBurma (Myanmar)',
        'ne' => 'chiNepali',
        'ne_IN' => 'chiNepali (India)',
        'ne_NP' => 'chiNepali (Nepal)',
        'nl' => 'chiDutch',
        'nl_AW' => 'chiDutch (Arubha)',
        'nl_BE' => 'chiDutch (Beljium)',
        'nl_NL' => 'chiDutch (Netherlands)',
        'nl_SR' => 'chiDutch (Suriname)',
        'pa' => 'chiPunjabi',
        'pa_IN' => 'chiPunjabi (India)',
        'pa_PK' => 'chiPunjabi (Pakistan)',
        'pl' => 'chiPolish',
        'pl_PL' => 'chiPolish (Poland)',
        'pt' => 'chiPutukezi',
        'pt_AO' => 'chiPutukezi (Angola)',
        'pt_BR' => 'chiPutukezi (Brazil)',
        'pt_CH' => 'chiPutukezi (Switzerland)',
        'pt_CV' => 'chiPutukezi (Zvitsuwa zveCape Verde)',
        'pt_GQ' => 'chiPutukezi (Equatorial Guinea)',
        'pt_GW' => 'chiPutukezi (Guinea-Bissau)',
        'pt_LU' => 'chiPutukezi (Luxembourg)',
        'pt_MZ' => 'chiPutukezi (Mozambique)',
        'pt_PT' => 'chiPutukezi (Portugal)',
        'pt_ST' => 'chiPutukezi (São Tomé and Príncipe)',
        'pt_TL' => 'chiPutukezi (East Timor)',
        'ro' => 'chiRomanian',
        'ro_MD' => 'chiRomanian (Moldova)',
        'ro_RO' => 'chiRomanian (Romania)',
        'ru' => 'chiRashiya',
        'ru_BY' => 'chiRashiya (Belarusi)',
        'ru_KG' => 'chiRashiya (Kyrgyzstan)',
        'ru_KZ' => 'chiRashiya (Kazakhstan)',
        'ru_MD' => 'chiRashiya (Moldova)',
        'ru_RU' => 'chiRashiya (Russia)',
        'ru_UA' => 'chiRashiya (Ukraine)',
        'rw' => 'chiRwanda',
        'rw_RW' => 'chiRwanda (Rwanda)',
        'sn' => 'chiShona',
        'sn_ZW' => 'chiShona (Zimbabwe)',
        'so' => 'chiSomali',
        'so_DJ' => 'chiSomali (Djibouti)',
        'so_ET' => 'chiSomali (Etiopia)',
        'so_KE' => 'chiSomali (Kenya)',
        'so_SO' => 'chiSomali (Somalia)',
        'sv' => 'chiSwedish',
        'sv_FI' => 'chiSwedish (Finland)',
        'sv_SE' => 'chiSwedish (Sweden)',
        'ta' => 'chiTamil',
        'ta_IN' => 'chiTamil (India)',
        'ta_LK' => 'chiTamil (Sri Lanka)',
        'ta_MY' => 'chiTamil (Malaysia)',
        'ta_SG' => 'chiTamil (Singapore)',
        'th' => 'chiThai',
        'th_TH' => 'chiThai (Thailand)',
        'tr' => 'chiTurkish',
        'tr_CY' => 'chiTurkish (Cyprus)',
        'tr_TR' => 'chiTurkish (Turkey)',
        'uk' => 'chiUkrenia',
        'uk_UA' => 'chiUkrenia (Ukraine)',
        'ur' => 'chiUrdu',
        'ur_IN' => 'chiUrdu (India)',
        'ur_PK' => 'chiUrdu (Pakistan)',
        'vi' => 'chiVietnam',
        'vi_VN' => 'chiVietnam (Vietnam)',
        'yo' => 'chiYoruba',
        'yo_BJ' => 'chiYoruba (Benini)',
        'yo_NG' => 'chiYoruba (Nigeria)',
        'zh' => 'chiChinese',
        'zh_CN' => 'chiChinese (China)',
        'zh_SG' => 'chiChinese (Singapore)',
        'zh_TW' => 'chiChinese (Taiwan)',
        'zu' => 'chiZulu',
        'zu_ZA' => 'chiZulu (South Africa)',
    ],
];
