<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Dirham na Haɗaɗɗiyar Daular Larabawa',
        ],
        'AFN' => [
            'AFN',
            'Afghani na ƙasar Afghanistan',
        ],
        'ALL' => [
            'ALL',
            'Lek na Albania',
        ],
        'AMD' => [
            'AMD',
            'Dram na Armeniya',
        ],
        'ANG' => [
            'ANG',
            'Antillean Guilder na ƙasar Netherlands',
        ],
        'AOA' => [
            'AOA',
            'Kwanza na Angola',
        ],
        'ARS' => [
            'ARS',
            'Peso na ƙasar Argentina',
        ],
        'AUD' => [
            'A$',
            'Dalar Ostareliya',
        ],
        'AWG' => [
            'AWG',
            'Florin na yankin Aruba',
        ],
        'AZN' => [
            'AZN',
            'Manat na Azebaijan',
        ],
        'BAM' => [
            'BAM',
            'Kuɗaɗen Bosnia da Herzegovina',
        ],
        'BBD' => [
            'BBD',
            'Dalar ƙasar Barbados',
        ],
        'BDT' => [
            'BDT',
            'Taka na ƙasar Bangladesh',
        ],
        'BGN' => [
            'BGN',
            'Lev na Bulgeria',
        ],
        'BHD' => [
            'BHD',
            'Zinaren Bahrain',
        ],
        'BIF' => [
            'BIF',
            'Franc na Burundi',
        ],
        'BMD' => [
            'BMD',
            'Dalar ƙasar Bermuda',
        ],
        'BND' => [
            'BND',
            'Dalar Brunei',
        ],
        'BOB' => [
            'BOB',
            'Boloviano na ƙasar Bolivia',
        ],
        'BRL' => [
            'R$',
            'Ril Kudin Birazil',
        ],
        'BSD' => [
            'BSD',
            'Dalar ƙasar Bahamas',
        ],
        'BTN' => [
            'BTN',
            'Ngultrum na ƙasar Bhutan',
        ],
        'BWP' => [
            'BWP',
            'Pula na Batsuwana',
        ],
        'BYN' => [
            'BYN',
            'Ruble na Belarus',
        ],
        'BZD' => [
            'BZD',
            'Dalar ƙasar Belize',
        ],
        'CAD' => [
            'CA$',
            'Dalar Kanada',
        ],
        'CDF' => [
            'CDF',
            'Franc na Kongo',
        ],
        'CHF' => [
            'CHF',
            'Franc na Suwizilan',
        ],
        'CLP' => [
            'CLP',
            'Peso na ƙasar Chile',
        ],
        'CNH' => [
            'CNH',
            'Yuwan na ƙasar Sin (na wajen ƙasa)',
        ],
        'CNY' => [
            'CN¥',
            'Yuwan na ƙasar Sin',
        ],
        'COP' => [
            'COP',
            'Peso na ƙasar Columbia',
        ],
        'CRC' => [
            'CRC',
            'Colón na ƙasar Costa Rica',
        ],
        'CUC' => [
            'CUC',
            'Peso mai fuska biyu na ƙasar Kuba',
        ],
        'CUP' => [
            'CUP',
            'Peso na ƙasar Kuba',
        ],
        'CVE' => [
            'CVE',
            'Escudo na Cape Verde',
        ],
        'CZK' => [
            'CZK',
            'Koruna na Czech',
        ],
        'DJF' => [
            'DJF',
            'Franc na Djibouti',
        ],
        'DKK' => [
            'DKK',
            'Krone na ƙasar Denmark',
        ],
        'DOP' => [
            'DOP',
            'Peso na jamhuriyar Dominica',
        ],
        'DZD' => [
            'DZD',
            'Dinarin Aljeriya',
        ],
        'EGP' => [
            'EGP',
            'Fam na Masar',
        ],
        'ERN' => [
            'ERN',
            'Kuɗin Eritireya',
        ],
        'ETB' => [
            'ETB',
            'Birr na Habasha',
        ],
        'EUR' => [
            '€',
            'Yuro',
        ],
        'FJD' => [
            'FJD',
            'Dalar Fiji',
        ],
        'FKP' => [
            'FKP',
            'Fam na ƙasar Tsibirai na Falkland',
        ],
        'GBP' => [
            '£',
            'Fam na Ingila',
        ],
        'GEL' => [
            'GEL',
            'Lari na Georgia',
        ],
        'GHC' => [
            'GHC',
            'Cedi',
        ],
        'GHS' => [
            'GHS',
            'Sidi na Ghana',
        ],
        'GIP' => [
            'GIP',
            'Fam na Gibraltar',
        ],
        'GMD' => [
            'GMD',
            'Dalasi na Gambiya',
        ],
        'GNF' => [
            'GNF',
            'Franc na Guinea',
        ],
        'GNS' => [
            'GNS',
            'Kuɗin Gini',
        ],
        'GTQ' => [
            'GTQ',
            'Quetzal na ƙasar Guatemala',
        ],
        'GYD' => [
            'GYD',
            'Dalar Guyana',
        ],
        'HKD' => [
            'HK$',
            'Dalar Hong Kong',
        ],
        'HNL' => [
            'HNL',
            'Lempira na ƙasar Honduras',
        ],
        'HRK' => [
            'HRK',
            'Kuna na Croatia',
        ],
        'HTG' => [
            'HTG',
            'Gourde na ƙasar Haiti',
        ],
        'HUF' => [
            'HUF',
            'Forint na Hungary',
        ],
        'IDR' => [
            'IDR',
            'Rupiah na ƙasar Indonesia',
        ],
        'ILS' => [
            '₪',
            'Sabon shekel na Israʼila',
        ],
        'INR' => [
            '₹',
            'Rupee na ƙasar Indiya',
        ],
        'IQD' => [
            'IQD',
            'Dinarin Iraqi',
        ],
        'IRR' => [
            'IRR',
            'Riyal na ƙasar Iran',
        ],
        'ISK' => [
            'ISK',
            'Króna na ƙasar Iceland',
        ],
        'JMD' => [
            'JMD',
            'Dalar Jamaica',
        ],
        'JOD' => [
            'JOD',
            'Dinarin Jordan',
        ],
        'JPY' => [
            '¥',
            'Yen na ƙasar Japan',
        ],
        'KES' => [
            'KES',
            'Sulen Kenya',
        ],
        'KGS' => [
            'KGS',
            'Som na ƙasar Kyrgystani',
        ],
        'KHR' => [
            'KHR',
            'Riel na ƙasar Cambodia',
        ],
        'KMF' => [
            'KMF',
            'Franc na Kwamoras',
        ],
        'KPW' => [
            'KPW',
            'Won na ƙasar Koriya ta Arewa',
        ],
        'KRW' => [
            '₩',
            'Won na Koriya ta Kudu',
        ],
        'KWD' => [
            'KWD',
            'Dinarin Kuwaiti',
        ],
        'KYD' => [
            'KYD',
            'Dalar ƙasar Tsibirai na Cayman',
        ],
        'KZT' => [
            'KZT',
            'Tenge na ƙasar Kazkhstan',
        ],
        'LAK' => [
            'LAK',
            'Kip na ƙasar Laos',
        ],
        'LBP' => [
            'LBP',
            'Fam na Lebanon',
        ],
        'LKR' => [
            'LKR',
            'Rupee na ƙasar Sri Lanka',
        ],
        'LRD' => [
            'LRD',
            'Dalar Laberiya',
        ],
        'LSL' => [
            'LSL',
            'Loti na Lesoto',
        ],
        'LYD' => [
            'LYD',
            'Dinarin Libya',
        ],
        'MAD' => [
            'MAD',
            'Dirhamin Moroko',
        ],
        'MDL' => [
            'MDL',
            'Leu na Moldova',
        ],
        'MGA' => [
            'MGA',
            'Ariary na Malagasy',
        ],
        'MKD' => [
            'MKD',
            'Dinarin Macedonia',
        ],
        'MMK' => [
            'MMK',
            'Kyat na ƙasar Myanmar',
        ],
        'MNT' => [
            'MNT',
            'Tugrik na Mongolia',
        ],
        'MOP' => [
            'MOP',
            'Pataca na ƙasar Macao',
        ],
        'MRO' => [
            'MRO',
            'Kuɗin Moritaniya (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Ouguiya na Moritaniya',
        ],
        'MUR' => [
            'MUR',
            'Rupee na Moritus',
        ],
        'MVR' => [
            'MVR',
            'Rufiyaa na ƙasar Maldives',
        ],
        'MWK' => [
            'MWK',
            'Kwacha na Malawi',
        ],
        'MXN' => [
            'MX$',
            'Peso na ƙasar Mekziko',
        ],
        'MYR' => [
            'MYR',
            'Ringgit na ƙasar Malaysia',
        ],
        'MZM' => [
            'MZM',
            'Kuɗin Mozambik',
        ],
        'MZN' => [
            'MZN',
            'Metical na ƙasar Mozambique',
        ],
        'NAD' => [
            'NAD',
            'Dalar Namibiya',
        ],
        'NGN' => [
            '₦',
            'Nairar Najeriya',
        ],
        'NIO' => [
            'NIO',
            'Córdoba na ƙasar Nicaragua',
        ],
        'NOK' => [
            'NOK',
            'Krone na ƙasar Norway',
        ],
        'NPR' => [
            'NPR',
            'Rupee na Nepal',
        ],
        'NZD' => [
            'NZ$',
            'Dalar New Zealand',
        ],
        'OMR' => [
            'OMR',
            'Riyal ɗin Oman',
        ],
        'PAB' => [
            'PAB',
            'Balboa na ƙasar Panama',
        ],
        'PEN' => [
            'PEN',
            'Sol na ƙasar Peru',
        ],
        'PGK' => [
            'PGK',
            'Kina na ƙasar Papua New Guinea',
        ],
        'PHP' => [
            '₱',
            'Peso na ƙasar Philippine',
        ],
        'PKR' => [
            'PKR',
            'Rupee na ƙasar Pakistan',
        ],
        'PLN' => [
            'PLN',
            'Zloty na Polan',
        ],
        'PYG' => [
            'PYG',
            'Guarani na ƙasar Paraguay',
        ],
        'QAR' => [
            'QAR',
            'Riyal ɗin Qatar',
        ],
        'RON' => [
            'RON',
            'Leu na Romania',
        ],
        'RSD' => [
            'RSD',
            'Dinarin Serbia',
        ],
        'RUB' => [
            'RUB',
            'Ruble na ƙasar Rasha',
        ],
        'RWF' => [
            'RWF',
            'Franc na Ruwanda',
        ],
        'SAR' => [
            'SAR',
            'Riyal ɗin Saudiyya',
        ],
        'SBD' => [
            'SBD',
            'Dalar Tsibiran Solomon',
        ],
        'SCR' => [
            'SCR',
            'Rupee na Seychellois',
        ],
        'SDG' => [
            'SDG',
            'Fam na Sudan',
        ],
        'SEK' => [
            'SEK',
            'Krona na ƙasar Sweden',
        ],
        'SGD' => [
            'SGD',
            'Dalar Singapore',
        ],
        'SHP' => [
            'SHP',
            'Fam na San Helena',
        ],
        'SLE' => [
            'SLE',
            'Leone na Saliyo',
        ],
        'SLL' => [
            'SLL',
            'Leone na Saliyo (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Sulen Somaliya',
        ],
        'SRD' => [
            'SRD',
            'Dalar ƙasar Suriname',
        ],
        'SSP' => [
            'SSP',
            'Fam na Kudancin Sudan',
        ],
        'STD' => [
            'STD',
            'Kuɗin Sawo Tome da Paransip (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Dobra na Sawo Tome',
        ],
        'SYP' => [
            'SYP',
            'Fam ɗin Siriya',
        ],
        'SZL' => [
            'SZL',
            'Emalangeni na Swazi',
        ],
        'THB' => [
            'THB',
            'Baht na ƙasar Thailand',
        ],
        'TJS' => [
            'TJS',
            'Somoni na ƙasar Tajikistan',
        ],
        'TMT' => [
            'TMT',
            'Manat na ƙasar Turkmenistan',
        ],
        'TND' => [
            'TND',
            'Dinarin Tunusiya',
        ],
        'TOP' => [
            'TOP',
            'Paʻanga na ƙasar Tonga',
        ],
        'TRY' => [
            'TRY',
            'Lira na Turkiyya',
        ],
        'TTD' => [
            'TTD',
            'Dalar ƙasar Trinidad da Tobago',
        ],
        'TWD' => [
            'NT$',
            'Sabuwar Dalar Taiwan',
        ],
        'TZS' => [
            'TZS',
            'Sulen Tanzaniya',
        ],
        'UAH' => [
            'UAH',
            'Hryvnia na Ukrain',
        ],
        'UGX' => [
            'UGX',
            'Sulen Yuganda',
        ],
        'USD' => [
            '$',
            'Dalar Amurka',
        ],
        'UYU' => [
            'UYU',
            'Peso na ƙasar Uruguay',
        ],
        'UZS' => [
            'UZS',
            'Som na ƙasar Uzbekistan',
        ],
        'VES' => [
            'VES',
            'Bolívar na ƙasar Venezuela',
        ],
        'VND' => [
            '₫',
            'Dong na ƙasar Vietnam',
        ],
        'VUV' => [
            'VUV',
            'Vatu da ƙasar Vanuatu',
        ],
        'WST' => [
            'WST',
            'Tala na ƙasar Samoa',
        ],
        'XAF' => [
            'FCFA',
            'Kuɗin Sefa na Afirka Ta Tsakiya',
        ],
        'XCD' => [
            'EC$',
            'Dalar Gabashin Karebiyan',
        ],
        'XCG' => [
            'Cg.',
            'Guilder na Caribbean',
        ],
        'XOF' => [
            'F CFA',
            'Kuɗin Sefa na Afirka Ta Yamma',
        ],
        'XPF' => [
            'CFPF',
            'Kuɗin CFP franc',
        ],
        'YER' => [
            'YER',
            'Riyal ɗin Yemen',
        ],
        'ZAR' => [
            'ZAR',
            'Rand na Afirka ta Kudu',
        ],
        'ZMK' => [
            'ZMK',
            'Kuɗin Zambiya (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Kwacha na Zambiya',
        ],
        'ZWD' => [
            'ZWD',
            'Dalar zimbabuwe',
        ],
        'ZWG' => [
            'ZWG',
            'Zinaren Zimbabwe',
        ],
    ],
];
