<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Берләшкән Гарәп Әмирлекләре дирхамы',
        ],
        'AFN' => [
            'AFN',
            'Әфган әфганы',
        ],
        'ALL' => [
            'ALL',
            'Албания Леке',
        ],
        'AMD' => [
            'AMD',
            'Армения драмы',
        ],
        'ANG' => [
            'ANG',
            'Нидерланд Антиль утраулары гульдены',
        ],
        'AOA' => [
            'AOA',
            'Ангола кванзасы',
        ],
        'ARS' => [
            'ARS',
            'Аргентина песосы',
        ],
        'AUD' => [
            'A$',
            'Австралия доллары',
        ],
        'AWG' => [
            'AWG',
            'Арубан Флорины',
        ],
        'AZN' => [
            'AZN',
            'Әзербайҗан манаты',
        ],
        'BAM' => [
            'BAM',
            'Босния һәм Герцеговинаның конвертацияләнә торган маркасы',
        ],
        'BBD' => [
            'BBD',
            'Барбадос доллары',
        ],
        'BDT' => [
            'BDT',
            'Бангладеш такасы',
        ],
        'BGN' => [
            'BGN',
            'Болгар Левы',
        ],
        'BHD' => [
            'BHD',
            'Бахрейн динары',
        ],
        'BIF' => [
            'BIF',
            'Бурунди франкы',
        ],
        'BMD' => [
            'BMD',
            'Бермуд доллары',
        ],
        'BND' => [
            'BND',
            'Бруней доллары',
        ],
        'BOB' => [
            'BOB',
            'Боливиа боливианосы',
        ],
        'BRL' => [
            'R$',
            'Бразилия реалы',
        ],
        'BSD' => [
            'BSD',
            'Багам доллары',
        ],
        'BTN' => [
            'BTN',
            'Бутан нгултрумы',
        ],
        'BWP' => [
            'BWP',
            'Ботсвана пуласы',
        ],
        'BYN' => [
            'BYN',
            'Беларус сумы',
        ],
        'BZD' => [
            'BZD',
            'Белиз доллары',
        ],
        'CAD' => [
            'CA$',
            'Канада доллары',
        ],
        'CDF' => [
            'CDF',
            'Конголез франкы',
        ],
        'CHF' => [
            'CHF',
            'Швейцария франкы',
        ],
        'CLP' => [
            'CLP',
            'Чили песосы',
        ],
        'CNH' => [
            'CNH',
            'Кытай Юане (оффшор)',
        ],
        'CNY' => [
            'CN¥',
            'кытай юане',
        ],
        'COP' => [
            'COP',
            'Колумбия песосы',
        ],
        'CRC' => [
            'CRC',
            'Коста-Рика колоны',
        ],
        'CUC' => [
            'CUC',
            'Куба конвертацияләнә торган песосы',
        ],
        'CUP' => [
            'CUP',
            'Куба песосы',
        ],
        'CVE' => [
            'CVE',
            'Кабо-Верде эскудосы',
        ],
        'CZK' => [
            'CZK',
            'Чех кронасы',
        ],
        'DJF' => [
            'DJF',
            'Җибути франкы',
        ],
        'DKK' => [
            'DKK',
            'Дания Кронасы',
        ],
        'DOP' => [
            'DOP',
            'Доминикана песосы',
        ],
        'DZD' => [
            'DZD',
            'Алжир динары',
        ],
        'EGP' => [
            'EGP',
            'Мисыр фунты',
        ],
        'ERN' => [
            'ERN',
            'Эритрея накфасы',
        ],
        'ETB' => [
            'ETB',
            'Эфиопия быры',
        ],
        'EUR' => [
            '€',
            'евро',
        ],
        'FJD' => [
            'FJD',
            'Фиджи доллары',
        ],
        'FKP' => [
            'FKP',
            'Фолкленд утраулары фунты',
        ],
        'GBP' => [
            '£',
            'фунт стерлинг',
        ],
        'GEL' => [
            'GEL',
            'Грузия ларие',
        ],
        'GHS' => [
            'GHS',
            'Гана седие',
        ],
        'GIP' => [
            'GIP',
            'Гибралтар фунты',
        ],
        'GMD' => [
            'GMD',
            'Гамбия даласие',
        ],
        'GNF' => [
            'GNF',
            'Гвинея франкы',
        ],
        'GTQ' => [
            'GTQ',
            'Гватемала кетсалы',
        ],
        'GYD' => [
            'GYD',
            'Гайана доллары',
        ],
        'HKD' => [
            'HK$',
            'Гонконг доллары',
        ],
        'HNL' => [
            'HNL',
            'Гондурас лемпиры',
        ],
        'HRK' => [
            'HRK',
            'Хорватия кунасы',
        ],
        'HTG' => [
            'HTG',
            'Гаити гурды',
        ],
        'HUF' => [
            'HUF',
            'Венгрия форинты',
        ],
        'IDR' => [
            'IDR',
            'Индонезия рупиясе',
        ],
        'ILS' => [
            '₪',
            'Израиль яңа шекеле',
        ],
        'INR' => [
            '₹',
            'Индия рупиясе',
        ],
        'IQD' => [
            'IQD',
            'Ирак динары',
        ],
        'IRR' => [
            'IRR',
            'Иран риалы',
        ],
        'ISK' => [
            'ISK',
            'Исландия Кронасы',
        ],
        'JMD' => [
            'JMD',
            'Ямайка доллары',
        ],
        'JOD' => [
            'JOD',
            'Иордания динары',
        ],
        'JPY' => [
            'JP¥',
            'япон иенасы',
        ],
        'KES' => [
            'KES',
            'Кения шиллингы',
        ],
        'KGS' => [
            'KGS',
            'Ккргызстан сомы',
        ],
        'KHR' => [
            'KHR',
            'Камбоджа риелы',
        ],
        'KMF' => [
            'KMF',
            'Комор утраулары франкы',
        ],
        'KPW' => [
            'KPW',
            'Төньяк Корея Вонасы',
        ],
        'KRW' => [
            '₩',
            'Көньяк Корея Вонасы',
        ],
        'KWD' => [
            'KWD',
            'Кувейт динары',
        ],
        'KYD' => [
            'KYD',
            'Кайман утраулары доллары',
        ],
        'KZT' => [
            'KZT',
            'Казахстан тәңкәсе',
        ],
        'LAK' => [
            'LAK',
            'Лаос кипы',
        ],
        'LBP' => [
            'LBP',
            'Ливан фунты',
        ],
        'LKR' => [
            'LKR',
            'Шри-Ланка рупиясе',
        ],
        'LRD' => [
            'LRD',
            'Либерия доллары',
        ],
        'LSL' => [
            'LSL',
            'Лесото лотисы',
        ],
        'LYD' => [
            'LYD',
            'Ливия динары',
        ],
        'MAD' => [
            'MAD',
            'Марокко дирхамы',
        ],
        'MDL' => [
            'MDL',
            'Молдавия Лее',
        ],
        'MGA' => [
            'MGA',
            'Малагаси ариариясе',
        ],
        'MKD' => [
            'MKD',
            'Македония денары',
        ],
        'MMK' => [
            'MMK',
            'Мьянма кьяты',
        ],
        'MNT' => [
            'MNT',
            'Монголия тугрикы',
        ],
        'MOP' => [
            'MOP',
            'Макао патакы',
        ],
        'MRU' => [
            'MRU',
            'Мавритан угиясы',
        ],
        'MUR' => [
            'MUR',
            'Маврикий рупие',
        ],
        'MVR' => [
            'MVR',
            'Мальдив руфиясе',
        ],
        'MWK' => [
            'MWK',
            'Малавия квачие',
        ],
        'MXN' => [
            'MX$',
            'Мексика песосы',
        ],
        'MYR' => [
            'MYR',
            'Малайзия ринггиты',
        ],
        'MZN' => [
            'MZN',
            'Мозамбик метикалы',
        ],
        'NAD' => [
            'NAD',
            'Намибия доллары',
        ],
        'NGN' => [
            'NGN',
            'Нигерия найрасы',
        ],
        'NIO' => [
            'NIO',
            'Никарагуа кордовасы',
        ],
        'NOK' => [
            'NOK',
            'Норвегия Кронасы',
        ],
        'NPR' => [
            'NPR',
            'Непал рупиясе',
        ],
        'NZD' => [
            'NZ$',
            'Яңа Зеландия доллары',
        ],
        'OMR' => [
            'OMR',
            'Оман риалы',
        ],
        'PAB' => [
            'PAB',
            'Панама бальбоасы',
        ],
        'PEN' => [
            'PEN',
            'Перу солы',
        ],
        'PGK' => [
            'PGK',
            'Папуа Яңа Гвинея Кинасы',
        ],
        'PHP' => [
            '₱',
            'Филиппин песосы',
        ],
        'PKR' => [
            'PKR',
            'Пакистан рупиясе',
        ],
        'PLN' => [
            'PLN',
            'Польша злотые',
        ],
        'PYG' => [
            'PYG',
            'Парагвай гуаранисы',
        ],
        'QAR' => [
            'QAR',
            'Катар риалы',
        ],
        'RON' => [
            'RON',
            'Румыния Лее',
        ],
        'RSD' => [
            'RSD',
            'Сербия динары',
        ],
        'RUB' => [
            '₽',
            'Россия сумы',
        ],
        'RWF' => [
            'RWF',
            'Руанда франкы',
        ],
        'SAR' => [
            'SAR',
            'Согуд Гарәбстаны риалы',
        ],
        'SBD' => [
            'SBD',
            'Соломон утраулары доллары',
        ],
        'SCR' => [
            'SCR',
            'Сейшел утраулары рупиясы',
        ],
        'SDG' => [
            'SDG',
            'Судан фунты',
        ],
        'SEK' => [
            'SEK',
            'Швеция Кронасы',
        ],
        'SGD' => [
            'SGD',
            'Сингапур доллары',
        ],
        'SHP' => [
            'SHP',
            'Изге Елена утравы фунты',
        ],
        'SLE' => [
            'SLE',
            'Сьерра-Леон леоны',
        ],
        'SLL' => [
            'SLL',
            'Сьерра-Леоне леоны (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Сомали шиллингы',
        ],
        'SRD' => [
            'SRD',
            'Суринам доллары',
        ],
        'SSP' => [
            'SSP',
            'Көньяк Судан фунты',
        ],
        'STN' => [
            'STN',
            'Сан-Томе һәм Принсипи добрасы',
        ],
        'SYP' => [
            'SYP',
            'Сурия фунты',
        ],
        'SZL' => [
            'SZL',
            'Свази эмалангенисы',
        ],
        'THB' => [
            'THB',
            'Тайвань Баты',
        ],
        'TJS' => [
            'TJS',
            'Таҗикстан сомонисы',
        ],
        'TMT' => [
            'TMT',
            'Төркмәнстан Манаты',
        ],
        'TND' => [
            'TND',
            'Тунис динары',
        ],
        'TOP' => [
            'TOP',
            'Тонга Паангасы',
        ],
        'TRY' => [
            'TRY',
            'Төркия Лирасы',
        ],
        'TTD' => [
            'TTD',
            'Тринидад һәм Тобаго доллары',
        ],
        'TWD' => [
            'NT$',
            'Яңа Тайвань доллары',
        ],
        'TZS' => [
            'TZS',
            'Танзания шиллингы',
        ],
        'UAH' => [
            'UAH',
            'Украина гривнасы',
        ],
        'UGX' => [
            'UGX',
            'Уганда шиллингы',
        ],
        'USD' => [
            '$',
            'АКШ доллары',
        ],
        'UYU' => [
            'UYU',
            'Уругвай песосы',
        ],
        'UZS' => [
            'UZS',
            'Үзбәкстан Сомы',
        ],
        'VES' => [
            'VES',
            'Венесуэла боливары',
        ],
        'VND' => [
            '₫',
            'Вьетнам Донгы',
        ],
        'VUV' => [
            'VUV',
            'Вануату ваты',
        ],
        'WST' => [
            'WST',
            'Самоа Таласы',
        ],
        'XAF' => [
            'FCFA',
            'Үзәк Африка франкы КФА',
        ],
        'XCD' => [
            'EC$',
            'Көнчыгыш Кариб доллары',
        ],
        'XCG' => [
            'Cg.',
            'кариб гульдены',
        ],
        'XOF' => [
            'F CFA',
            'Көнбатыш Африка КФА франкы',
        ],
        'XPF' => [
            'CFPF',
            'Франциянең диңгез аръягы җәмгыятьләре франкы',
        ],
        'YER' => [
            'YER',
            'Йәмән риалы',
        ],
        'ZAR' => [
            'ZAR',
            'Көньяк Африка Рэнды',
        ],
        'ZMW' => [
            'ZMW',
            'Замбия квачасы',
        ],
        'ZWG' => [
            'ZWG',
            'Зимбабве алтыны',
        ],
    ],
];
