<?php

return [
    'Names' => [
        'aa' => 'Afar',
        'ab' => 'Abhazca',
        'ace' => 'Açece',
        'ach' => 'Acoli',
        'ada' => 'Adangme',
        'ady' => 'Adigece',
        'ae' => 'Avestçe',
        'aeb' => 'Tunus Arapçası',
        'af' => 'Afrikaanca',
        'afh' => 'Afrihili',
        'agq' => 'Aghem',
        'ain' => 'Aynuca',
        'ak' => 'Akan',
        'akk' => 'Akad Dili',
        'akz' => 'Alabamaca',
        'ale' => 'Aleut dili',
        'aln' => 'Gheg Arnavutçası',
        'alt' => 'Güney Altayca',
        'am' => 'Amharca',
        'an' => 'Aragonca',
        'ang' => 'Eski İngilizce',
        'ann' => 'Obolo dili',
        'anp' => 'Angika',
        'ar' => 'Arapça',
        'arc' => 'Aramice',
        'arn' => 'Mapuçe dili',
        'aro' => 'Araona',
        'arp' => 'Arapaho dili',
        'arq' => 'Cezayir Arapçası',
        'ars' => 'Necd Arapçası',
        'arw' => 'Arawak Dili',
        'ary' => 'Fas Arapçası',
        'arz' => 'Mısır Arapçası',
        'as' => 'Assamca',
        'asa' => 'Asu',
        'ase' => 'Amerikan İşaret Dili',
        'ast' => 'Asturyasça',
        'atj' => 'Atikamekçe',
        'av' => 'Avar dili',
        'avk' => 'Kotava',
        'awa' => 'Awadhi',
        'ay' => 'Aymara',
        'az' => 'Azerbaycan dili',
        'ba' => 'Başkırtça',
        'bal' => 'Beluçça',
        'ban' => 'Bali dili',
        'bar' => 'Bavyera dili',
        'bas' => 'Basa Dili',
        'bax' => 'Bamun',
        'bbc' => 'Batak Toba',
        'bbj' => 'Ghomala',
        'be' => 'Belarusça',
        'bej' => 'Beja dili',
        'bem' => 'Bemba',
        'bew' => 'Betawi',
        'bez' => 'Bena',
        'bfd' => 'Bafut',
        'bfq' => 'Badaga',
        'bg' => 'Bulgarca',
        'bgc' => 'Haryanvi dili',
        'bgn' => 'Batı Balochi',
        'bho' => 'Arayanice',
        'bi' => 'Bislama',
        'bik' => 'Bikol',
        'bin' => 'Bini',
        'bjn' => 'Banjar Dili',
        'bkm' => 'Kom',
        'bla' => 'Karaayak dili',
        'blo' => 'Aniice',
        'bm' => 'Bambara',
        'bn' => 'Bengalce',
        'bo' => 'Tibetçe',
        'bpy' => 'Bishnupriya',
        'bqi' => 'Bahtiyari',
        'br' => 'Bretonca',
        'bra' => 'Braj',
        'brh' => 'Brohice',
        'brx' => 'Bodo',
        'bs' => 'Boşnakça',
        'bss' => 'Akoose',
        'bua' => 'Buryatça',
        'bug' => 'Bugis',
        'bum' => 'Bulu',
        'byn' => 'Blin',
        'byv' => 'Medumba',
        'ca' => 'Katalanca',
        'cad' => 'Kado dili',
        'car' => 'Carib',
        'cay' => 'Kayuga dili',
        'cch' => 'Atsam',
        'ccp' => 'Chakma',
        'ce' => 'Çeçence',
        'ceb' => 'Sebuano dili',
        'cgg' => 'Kiga',
        'ch' => 'Çamorro dili',
        'chb' => 'Çibça dili',
        'chg' => 'Çağatayca',
        'chk' => 'Chuukese',
        'chm' => 'Mari dili',
        'chn' => 'Çinuk dili',
        'cho' => 'Çoktav dili',
        'chp' => 'Çipevya dili',
        'chr' => 'Çerokice',
        'chy' => 'Şayence',
        'ckb' => 'Orta Kürtçe',
        'clc' => 'Çilkotince',
        'co' => 'Korsikaca',
        'cop' => 'Kıptice',
        'cps' => 'Capiznon',
        'cr' => 'Krice',
        'crg' => 'Michif dili',
        'crh' => 'Kırım Tatarcası',
        'crj' => 'Güney Doğu Kricesi',
        'crk' => 'Ova Kricesi',
        'crl' => 'Kuzey Doğu Kricesi',
        'crm' => 'Moose Kricesi',
        'crr' => 'Carolina Algonkin dili',
        'crs' => 'Seselwa Kreole Fransızcası',
        'cs' => 'Çekçe',
        'csb' => 'Kashubian',
        'csw' => 'Bataklık Kricesi',
        'cu' => 'Kilise Slavcası',
        'cv' => 'Çuvaşça',
        'cy' => 'Galce',
        'da' => 'Danca',
        'dak' => 'Dakotaca',
        'dar' => 'Dargince',
        'dav' => 'Taita',
        'de' => 'Almanca',
        'del' => 'Delaware',
        'den' => 'Slavey dili',
        'dgr' => 'Dogrib',
        'din' => 'Dinka dili',
        'dje' => 'Zarma',
        'doi' => 'Dogri',
        'dsb' => 'Aşağı Sorbça',
        'dtp' => 'Orta Kadazan',
        'dua' => 'Duala',
        'dum' => 'Ortaçağ Felemenkçesi',
        'dv' => 'Divehi dili',
        'dyo' => 'Jola-Fonyi',
        'dyu' => 'Dyula',
        'dz' => 'Dzongkha',
        'dzg' => 'Dazaga',
        'ebu' => 'Embu',
        'ee' => 'Ewe',
        'efi' => 'Efik',
        'egl' => 'Emilia Dili',
        'egy' => 'Eski Mısır Dili',
        'eka' => 'Ekajuk',
        'el' => 'Yunanca',
        'elx' => 'Elam',
        'en' => 'İngilizce',
        'enm' => 'Ortaçağ İngilizcesi',
        'eo' => 'Esperanto',
        'es' => 'İspanyolca',
        'esu' => 'Merkezi Yupikçe',
        'et' => 'Estonca',
        'eu' => 'Baskça',
        'ewo' => 'Ewondo',
        'ext' => 'Ekstremadura Dili',
        'fa' => 'Farsça',
        'fan' => 'Fang',
        'fat' => 'Fanti',
        'ff' => 'Fula dili',
        'fi' => 'Fince',
        'fil' => 'Filipince',
        'fit' => 'Tornedalin Fincesi',
        'fj' => 'Fiji dili',
        'fo' => 'Faroe dili',
        'fon' => 'Fon',
        'fr' => 'Fransızca',
        'frc' => 'Cajun Fransızcası',
        'frm' => 'Ortaçağ Fransızcası',
        'fro' => 'Eski Fransızca',
        'frp' => 'Arpitanca',
        'frr' => 'Kuzey Frizce',
        'frs' => 'Doğu Frizcesi',
        'fur' => 'Friuli dili',
        'fy' => 'Batı Frizcesi',
        'ga' => 'İrlandaca',
        'gaa' => 'Ga dili',
        'gag' => 'Gagavuzca',
        'gan' => 'Gan Çincesi',
        'gay' => 'Gayo dili',
        'gba' => 'Gbaya',
        'gbz' => 'Zerdüşt Daricesi',
        'gd' => 'İskoç Gaelcesi',
        'gez' => 'Geez',
        'gil' => 'Kiribatice',
        'gl' => 'Galiçyaca',
        'glk' => 'Gilanice',
        'gmh' => 'Ortaçağ Yüksek Almancası',
        'gn' => 'Guarani dili',
        'goh' => 'Eski Yüksek Almanca',
        'gon' => 'Gondi dili',
        'gor' => 'Gorontalo dili',
        'got' => 'Gotça',
        'grb' => 'Grebo dili',
        'grc' => 'Antik Yunanca',
        'gsw' => 'İsviçre Almancası',
        'gu' => 'Güceratça',
        'guc' => 'Wayuu dili',
        'gur' => 'Frafra',
        'guz' => 'Gusii',
        'gv' => 'Man dili',
        'gwi' => 'Guçince',
        'ha' => 'Hausa dili',
        'hai' => 'Haydaca',
        'hak' => 'Hakka Çincesi',
        'haw' => 'Hawaii dili',
        'hax' => 'Güney Haydaca',
        'he' => 'İbranice',
        'hi' => 'Hintçe',
        'hif' => 'Fiji Hintçesi',
        'hil' => 'Hiligaynon dili',
        'hit' => 'Hititçe',
        'hmn' => 'Hmong',
        'ho' => 'Hiri Motu',
        'hr' => 'Hırvatça',
        'hsb' => 'Yukarı Sorbça',
        'hsn' => 'Xiang Çincesi',
        'ht' => 'Haiti Kreyolu',
        'hu' => 'Macarca',
        'hup' => 'Hupaca',
        'hur' => 'Halkomelemce',
        'hy' => 'Ermenice',
        'hz' => 'Herero dili',
        'ia' => 'İnterlingua',
        'iba' => 'Iban',
        'ibb' => 'İbibio dili',
        'id' => 'Endonezce',
        'ie' => 'Interlingue',
        'ig' => 'İbo dili',
        'ii' => 'Sichuan Yi',
        'ik' => 'İnyupikçe',
        'ikt' => 'Batı Kanada İnuktitut dili',
        'ilo' => 'Iloko',
        'inh' => 'İnguşça',
        'io' => 'Ido',
        'is' => 'İzlandaca',
        'it' => 'İtalyanca',
        'iu' => 'İnuktitut dili',
        'izh' => 'İngriya Dili',
        'ja' => 'Japonca',
        'jam' => 'Jamaika Patois Dili',
        'jbo' => 'Lojban',
        'jgo' => 'Ngomba',
        'jmc' => 'Machame',
        'jpr' => 'Yahudi Farsçası',
        'jrb' => 'Yahudi Arapçası',
        'jut' => 'Yutland Dili',
        'jv' => 'Cava dili',
        'ka' => 'Gürcüce',
        'kaa' => 'Karakalpakça',
        'kab' => 'Kabiliyece',
        'kac' => 'Kaçin dili',
        'kaj' => 'Jju',
        'kam' => 'Kamba',
        'kaw' => 'Kawi',
        'kbd' => 'Kabardeyce',
        'kbl' => 'Kanembu',
        'kcg' => 'Tyap',
        'kde' => 'Makonde',
        'kea' => 'Kabuverdianu',
        'ken' => 'Kenyang',
        'kfo' => 'Koro',
        'kg' => 'Kongo dili',
        'kgp' => 'Kaingang',
        'kha' => 'Khasi dili',
        'kho' => 'Hotanca',
        'khq' => 'Koyra Chiini',
        'khw' => 'Çitral Dili',
        'ki' => 'Kikuyu',
        'kiu' => 'Kırmançça',
        'kj' => 'Kuanyama',
        'kk' => 'Kazakça',
        'kkj' => 'Kako',
        'kl' => 'Grönland dili',
        'kln' => 'Kalenjin',
        'km' => 'Khmer dili',
        'kmb' => 'Kimbundu',
        'kn' => 'Kannada dili',
        'ko' => 'Korece',
        'koi' => 'Komi-Permyak',
        'kok' => 'Konkani dili',
        'kos' => 'Kosraean',
        'kpe' => 'Kpelle dili',
        'kr' => 'Kanuri dili',
        'krc' => 'Karaçay-Balkarca',
        'kri' => 'Krio',
        'krj' => 'Kinaray-a',
        'krl' => 'Karelyaca',
        'kru' => 'Kurukh dili',
        'ks' => 'Keşmir dili',
        'ksb' => 'Şambala',
        'ksf' => 'Bafia',
        'ksh' => 'Köln lehçesi',
        'ku' => 'Kürtçe',
        'kum' => 'Kumukça',
        'kut' => 'Kutenai dili',
        'kv' => 'Komi',
        'kw' => 'Kernevekçe',
        'kwk' => 'Kwakʼwala dili',
        'kxv' => 'Kuvi',
        'ky' => 'Kırgızca',
        'la' => 'Latince',
        'lad' => 'Ladino',
        'lag' => 'Langi',
        'lah' => 'Lahnda',
        'lam' => 'Lamba dili',
        'lb' => 'Lüksemburgca',
        'lez' => 'Lezgice',
        'lfn' => 'Lingua Franca Nova',
        'lg' => 'Ganda',
        'li' => 'Limburgca',
        'lij' => 'Ligurca',
        'lil' => 'Lillooet dili',
        'liv' => 'Livonca',
        'lkt' => 'Lakotaca',
        'lmo' => 'Lombardça',
        'ln' => 'Lingala',
        'lo' => 'Lao dili',
        'lol' => 'Mongo',
        'lou' => 'Louisiana Kreolcesi',
        'loz' => 'Lozi',
        'lrc' => 'Kuzey Luri',
        'lsm' => 'Samia dili',
        'lt' => 'Litvanca',
        'ltg' => 'Latgalian',
        'lu' => 'Luba-Katanga',
        'lua' => 'Luba-Lulua',
        'lui' => 'Luiseno',
        'lun' => 'Lunda',
        'luo' => 'Luo',
        'lus' => 'Lushai',
        'luy' => 'Luyia',
        'lv' => 'Letonca',
        'lzh' => 'Edebi Çince',
        'lzz' => 'Lazca',
        'mad' => 'Madura Dili',
        'maf' => 'Mafa',
        'mag' => 'Magahi',
        'mai' => 'Maithili',
        'mak' => 'Makasar',
        'man' => 'Mandingo',
        'mas' => 'Masai',
        'mde' => 'Maba',
        'mdf' => 'Mokşa dili',
        'mdr' => 'Mandar',
        'men' => 'Mende dili',
        'mer' => 'Meru',
        'mfe' => 'Morisyen',
        'mg' => 'Malgaşça',
        'mga' => 'Ortaçağ İrlandacası',
        'mgh' => 'Makhuwa-Meetto',
        'mgo' => 'Meta’',
        'mh' => 'Marshall Adaları dili',
        'mi' => 'Maori dili',
        'mic' => 'Micmac',
        'min' => 'Minangkabau',
        'mk' => 'Makedonca',
        'ml' => 'Malayalam dili',
        'mn' => 'Moğolca',
        'mnc' => 'Mançurya dili',
        'mni' => 'Manipuri dili',
        'moe' => 'Doğu İnnucası',
        'moh' => 'Mohavk dili',
        'mos' => 'Mossi',
        'mr' => 'Marathi dili',
        'mrj' => 'Ova Çirmişçesi',
        'ms' => 'Malayca',
        'mt' => 'Maltaca',
        'mua' => 'Mundang',
        'mus' => 'Krikçe',
        'mwl' => 'Miranda dili',
        'mwr' => 'Marvari',
        'mwv' => 'Mentawai',
        'my' => 'Birman dili',
        'mye' => 'Myene',
        'myv' => 'Erzya',
        'mzn' => 'Mazenderanca',
        'na' => 'Nauru dili',
        'nan' => 'Min Nan Çincesi',
        'nap' => 'Napolice',
        'naq' => 'Nama',
        'nb' => 'Norveççe Bokmål',
        'nd' => 'Kuzey Ndebele',
        'nds' => 'Aşağı Almanca',
        'ne' => 'Nepalce',
        'new' => 'Nevari',
        'ng' => 'Ndonga',
        'nia' => 'Nias',
        'niu' => 'Niue dili',
        'njo' => 'Ao Naga',
        'nl' => 'Felemenkçe',
        'nmg' => 'Kwasio',
        'nn' => 'Norveççe Nynorsk',
        'nnh' => 'Ngiemboon',
        'no' => 'Norveççe',
        'nog' => 'Nogayca',
        'non' => 'Eski Nors dili',
        'nov' => 'Novial',
        'nqo' => 'N’Ko',
        'nr' => 'Güney Ndebele',
        'nso' => 'Kuzey Sotho dili',
        'nus' => 'Nuer',
        'nv' => 'Navaho dili',
        'nwc' => 'Klasik Nevari',
        'ny' => 'Nyanja',
        'nym' => 'Nyamvezi',
        'nyn' => 'Nyankole',
        'nyo' => 'Nyoro',
        'nzi' => 'Nzima dili',
        'oc' => 'Oksitan dili',
        'oj' => 'Ojibva dili',
        'ojb' => 'Kuzeybatı Ojibwe dili',
        'ojc' => 'Orta Ojibwe dili',
        'ojs' => 'Anişininice',
        'ojw' => 'Batı Ojibwe dili',
        'oka' => 'Okanagan dili',
        'om' => 'Oromo dili',
        'or' => 'Oriya dili',
        'os' => 'Osetçe',
        'osa' => 'Osage',
        'ota' => 'Osmanlı Türkçesi',
        'pa' => 'Pencapça',
        'pag' => 'Pangasinan dili',
        'pal' => 'Pehlevi Dili',
        'pam' => 'Pampanga',
        'pap' => 'Papiamento',
        'pau' => 'Palau dili',
        'pcd' => 'Picard Dili',
        'pcm' => 'Nijerya Pidgin dili',
        'pdc' => 'Pensilvanya Almancası',
        'pdt' => 'Plautdietsch',
        'peo' => 'Eski Farsça',
        'pfl' => 'Palatin Almancası',
        'phn' => 'Fenike dili',
        'pi' => 'Pali',
        'pis' => 'Pijin dili',
        'pl' => 'Lehçe',
        'pms' => 'Piyemontece',
        'pnt' => 'Kuzeybatı Kafkasya',
        'pon' => 'Pohnpeian',
        'pqm' => 'Malisetçe-Passamaquoddy',
        'prg' => 'Prusyaca',
        'pro' => 'Eski Provensal',
        'ps' => 'Peştuca',
        'pt' => 'Portekizce',
        'qu' => 'Keçuva dili',
        'quc' => 'Kiçece',
        'qug' => 'Chimborazo Highland Quichua',
        'raj' => 'Rajasthani',
        'rap' => 'Rapanui dili',
        'rar' => 'Rarotongan',
        'rgn' => 'Romanyolca',
        'rhg' => 'Rohingya dili',
        'rif' => 'Rif Berbericesi',
        'rm' => 'Romanşça',
        'rn' => 'Kirundi',
        'ro' => 'Rumence',
        'rof' => 'Rombo',
        'rom' => 'Romanca',
        'rtm' => 'Rotuman',
        'ru' => 'Rusça',
        'rue' => 'Rusince',
        'rug' => 'Roviana',
        'rup' => 'Ulahça',
        'rw' => 'Kinyarwanda',
        'rwk' => 'Rwa',
        'sa' => 'Sanskrit',
        'sad' => 'Sandave',
        'sah' => 'Yakutça',
        'sam' => 'Samarit Aramcası',
        'saq' => 'Samburu',
        'sas' => 'Sasak',
        'sat' => 'Santali',
        'saz' => 'Saurashtra',
        'sba' => 'Ngambay',
        'sbp' => 'Sangu',
        'sc' => 'Sardunya dili',
        'scn' => 'Sicilyaca',
        'sco' => 'İskoçça',
        'sd' => 'Sindhi dili',
        'sdc' => 'Sassari Sarduca',
        'sdh' => 'Güney Kürtçesi',
        'se' => 'Kuzey Laponcası',
        'see' => 'Seneca dili',
        'seh' => 'Sena',
        'sei' => 'Seri',
        'sel' => 'Selkup dili',
        'ses' => 'Koyraboro Senni',
        'sg' => 'Sango',
        'sga' => 'Eski İrlandaca',
        'sgs' => 'Samogitçe',
        'sh' => 'Sırp-Hırvat Dili',
        'shi' => 'Taşelit',
        'shn' => 'Shan dili',
        'shu' => 'Çad Arapçası',
        'si' => 'Sinhali dili',
        'sid' => 'Sidamo dili',
        'sk' => 'Slovakça',
        'sl' => 'Slovence',
        'slh' => 'Güney Lushootseed',
        'sli' => 'Aşağı Silezyaca',
        'sly' => 'Selayar',
        'sm' => 'Samoa dili',
        'sma' => 'Güney Laponcası',
        'smj' => 'Lule Laponcası',
        'smn' => 'İnari Laponcası',
        'sms' => 'Skolt Laponcası',
        'sn' => 'Şona dili',
        'snk' => 'Soninke',
        'so' => 'Somalice',
        'sog' => 'Sogdiana Dili',
        'sq' => 'Arnavutça',
        'sr' => 'Sırpça',
        'srn' => 'Sranan Tongo',
        'srr' => 'Serer dili',
        'ss' => 'Sisvati',
        'ssy' => 'Saho',
        'st' => 'Güney Sotho dili',
        'stq' => 'Saterland Frizcesi',
        'str' => 'Boğazlar Saliş dili',
        'su' => 'Sunda dili',
        'suk' => 'Sukuma dili',
        'sus' => 'Susu',
        'sux' => 'Sümerce',
        'sv' => 'İsveççe',
        'sw' => 'Svahili dili',
        'swb' => 'Komorca',
        'syc' => 'Klasik Süryanice',
        'syr' => 'Süryanice',
        'szl' => 'Silezyaca',
        'ta' => 'Tamilce',
        'tce' => 'Güney Tuçoncası',
        'tcy' => 'Tuluca',
        'te' => 'Telugu dili',
        'tem' => 'Timne',
        'teo' => 'Teso',
        'ter' => 'Tereno',
        'tet' => 'Tetum',
        'tg' => 'Tacikçe',
        'tgx' => 'Tagişçe',
        'th' => 'Tayca',
        'tht' => 'Tahltanca',
        'ti' => 'Tigrinya dili',
        'tig' => 'Tigre',
        'tiv' => 'Tiv',
        'tk' => 'Türkmence',
        'tkl' => 'Tokelau dili',
        'tkr' => 'Sahurca',
        'tl' => 'Tagalogca',
        'tlh' => 'Klingonca',
        'tli' => 'Tlingitçe',
        'tly' => 'Talışça',
        'tmh' => 'Tamaşek',
        'tn' => 'Setsvana',
        'to' => 'Tonga dili',
        'tog' => 'Nyasa Tonga',
        'tok' => 'Toki Pona',
        'tpi' => 'Tok Pisin',
        'tr' => 'Türkçe',
        'tru' => 'Turoyo',
        'trv' => 'Taroko',
        'ts' => 'Tsonga',
        'tsd' => 'Tsakonca',
        'tsi' => 'Tsimshian',
        'tt' => 'Tatarca',
        'ttm' => 'Kuzey Tuçoncası',
        'ttt' => 'Tatça',
        'tum' => 'Tumbuka',
        'tvl' => 'Tuvalyanca',
        'tw' => 'Tvi',
        'twq' => 'Tasawaq',
        'ty' => 'Tahiti dili',
        'tyv' => 'Tuvaca',
        'tzm' => 'Orta Atlas Tamazigti',
        'udm' => 'Udmurtça',
        'ug' => 'Uygurca',
        'uga' => 'Ugarit dili',
        'uk' => 'Ukraynaca',
        'umb' => 'Umbundu',
        'ur' => 'Urduca',
        'uz' => 'Özbekçe',
        'vai' => 'Vai',
        've' => 'Venda dili',
        'vec' => 'Venedikçe',
        'vep' => 'Veps dili',
        'vi' => 'Vietnamca',
        'vls' => 'Batı Flamanca',
        'vmf' => 'Main Frankonya Dili',
        'vmw' => 'Makuaca',
        'vo' => 'Volapük',
        'vot' => 'Votça',
        'vro' => 'Võro',
        'vun' => 'Vunjo',
        'wa' => 'Valonca',
        'wae' => 'Walser',
        'wal' => 'Valamo',
        'war' => 'Varay',
        'was' => 'Vaşo',
        'wbp' => 'Warlpiri',
        'wo' => 'Volofça',
        'wuu' => 'Wu Çincesi',
        'xal' => 'Kalmıkça',
        'xh' => 'Zosa dili',
        'xmf' => 'Megrelce',
        'xnr' => 'Kangrice',
        'xog' => 'Soga',
        'yao' => 'Yao',
        'yap' => 'Yapça',
        'yav' => 'Yangben',
        'ybb' => 'Yemba',
        'yi' => 'Yidiş',
        'yo' => 'Yorubaca',
        'yrl' => 'Nheengatu',
        'yue' => 'Kantonca',
        'za' => 'Zhuangca',
        'zap' => 'Zapotek dili',
        'zbl' => 'Blis Sembolleri',
        'zea' => 'Zelandaca',
        'zen' => 'Zenaga dili',
        'zgh' => 'Standart Fas Tamazigti',
        'zh' => 'Çince',
        'zu' => 'Zuluca',
        'zun' => 'Zunice',
        'zza' => 'Zazaca',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Modern Standart Arapça',
        'az_Arab' => 'Güney Azerice',
        'de_AT' => 'Avusturya Almancası',
        'de_CH' => 'İsviçre Yüksek Almancası',
        'en_AU' => 'Avustralya İngilizcesi',
        'en_CA' => 'Kanada İngilizcesi',
        'en_GB' => 'İngiliz İngilizcesi',
        'en_US' => 'Amerikan İngilizcesi',
        'es_419' => 'Latin Amerika İspanyolcası',
        'es_ES' => 'Avrupa İspanyolcası',
        'es_MX' => 'Meksika İspanyolcası',
        'fa_AF' => 'Darice',
        'fr_CA' => 'Kanada Fransızcası',
        'fr_CH' => 'İsviçre Fransızcası',
        'nds_NL' => 'Aşağı Saksonca',
        'nl_BE' => 'Flamanca',
        'pt_BR' => 'Brezilya Portekizcesi',
        'pt_PT' => 'Avrupa Portekizcesi',
        'ro_MD' => 'Moldovaca',
        'sw_CD' => 'Kongo Svahili',
        'zh_Hans' => 'Basitleştirilmiş Çince',
        'zh_Hant' => 'Geleneksel Çince',
    ],
];
