<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwichin normaaliaika (Abidjan)',
        'Africa/Accra' => 'Greenwichin normaaliaika (Accra)',
        'Africa/Addis_Ababa' => 'Itä-Afrikan aika (Addis Abeba)',
        'Africa/Algiers' => 'Keski-Euroopan aika (Alger)',
        'Africa/Asmera' => 'Itä-Afrikan aika (Asmara)',
        'Africa/Asmara' => 'Itä-Afrikan aika (Asmara)',
        'Africa/Bamako' => 'Greenwichin normaaliaika (Bamako)',
        'Africa/Bangui' => 'Länsi-Afrikan aika (Bangui)',
        'Africa/Banjul' => 'Greenwichin normaaliaika (Banjul)',
        'Africa/Bissau' => 'Greenwichin normaaliaika (Bissau)',
        'Africa/Blantyre' => 'Keski-Afrikan aika (Blantyre)',
        'Africa/Brazzaville' => 'Länsi-Afrikan aika (Brazzaville)',
        'Africa/Bujumbura' => 'Keski-Afrikan aika (Bujumbura)',
        'Africa/Cairo' => 'Itä-Euroopan aika (Kairo)',
        'Africa/Casablanca' => 'Länsi-Euroopan aika (Casablanca)',
        'Africa/Ceuta' => 'Keski-Euroopan aika (Ceuta)',
        'Africa/Conakry' => 'Greenwichin normaaliaika (Conakry)',
        'Africa/Dakar' => 'Greenwichin normaaliaika (Dakar)',
        'Africa/Dar_es_Salaam' => 'Itä-Afrikan aika (Dar es Salaam)',
        'Africa/Djibouti' => 'Itä-Afrikan aika (Djibouti)',
        'Africa/Douala' => 'Länsi-Afrikan aika (Douala)',
        'Africa/El_Aaiun' => 'Länsi-Euroopan aika (El Aaiún)',
        'Africa/Freetown' => 'Greenwichin normaaliaika (Freetown)',
        'Africa/Gaborone' => 'Keski-Afrikan aika (Gaborone)',
        'Africa/Harare' => 'Keski-Afrikan aika (Harare)',
        'Africa/Johannesburg' => 'Etelä-Afrikan aika (Johannesburg)',
        'Africa/Juba' => 'Keski-Afrikan aika (Juba)',
        'Africa/Kampala' => 'Itä-Afrikan aika (Kampala)',
        'Africa/Khartoum' => 'Keski-Afrikan aika (Khartum)',
        'Africa/Kigali' => 'Keski-Afrikan aika (Kigali)',
        'Africa/Kinshasa' => 'Länsi-Afrikan aika (Kinshasa)',
        'Africa/Lagos' => 'Länsi-Afrikan aika (Lagos)',
        'Africa/Libreville' => 'Länsi-Afrikan aika (Libreville)',
        'Africa/Lome' => 'Greenwichin normaaliaika (Lomé)',
        'Africa/Luanda' => 'Länsi-Afrikan aika (Luanda)',
        'Africa/Lubumbashi' => 'Keski-Afrikan aika (Lubumbashi)',
        'Africa/Lusaka' => 'Keski-Afrikan aika (Lusaka)',
        'Africa/Malabo' => 'Länsi-Afrikan aika (Malabo)',
        'Africa/Maputo' => 'Keski-Afrikan aika (Maputo)',
        'Africa/Maseru' => 'Etelä-Afrikan aika (Maseru)',
        'Africa/Mbabane' => 'Etelä-Afrikan aika (Mbabane)',
        'Africa/Mogadishu' => 'Itä-Afrikan aika (Mogadishu)',
        'Africa/Monrovia' => 'Greenwichin normaaliaika (Monrovia)',
        'Africa/Nairobi' => 'Itä-Afrikan aika (Nairobi)',
        'Africa/Ndjamena' => 'Länsi-Afrikan aika (N’Djamena)',
        'Africa/Niamey' => 'Länsi-Afrikan aika (Niamey)',
        'Africa/Nouakchott' => 'Greenwichin normaaliaika (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwichin normaaliaika (Ouagadougou)',
        'Africa/Porto-Novo' => 'Länsi-Afrikan aika (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwichin normaaliaika (São Tomé)',
        'Africa/Tripoli' => 'Itä-Euroopan aika (Tripoli)',
        'Africa/Tunis' => 'Keski-Euroopan aika (Tunis)',
        'Africa/Windhoek' => 'Keski-Afrikan aika (Windhoek)',
        'America/Adak' => 'Havaijin-Aleuttien aika (Adak)',
        'America/Anchorage' => 'Alaskan aika (Anchorage)',
        'America/Anguilla' => 'Kanadan Atlantin aika (Anguilla)',
        'America/Antigua' => 'Kanadan Atlantin aika (Antigua)',
        'America/Araguaina' => 'Brasilian aika (Araguaína)',
        'America/Argentina/La_Rioja' => 'Argentiinan aika (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentiinan aika (Río Gallegos)',
        'America/Argentina/Salta' => 'Argentiinan aika (Salta)',
        'America/Argentina/San_Juan' => 'Argentiinan aika (San Juan)',
        'America/Argentina/San_Luis' => 'Argentiinan aika (San Luis)',
        'America/Argentina/Tucuman' => 'Argentiinan aika (Tucumán)',
        'America/Argentina/Ushuaia' => 'Argentiinan aika (Ushuaia)',
        'America/Aruba' => 'Kanadan Atlantin aika (Aruba)',
        'America/Asuncion' => 'Paraguayn aika (Asunción)',
        'America/Bahia' => 'Brasilian aika (Bahia)',
        'America/Bahia_Banderas' => 'Yhdysvaltain keskinen aika (Bahía de Banderas)',
        'America/Barbados' => 'Kanadan Atlantin aika (Barbados)',
        'America/Belem' => 'Brasilian aika (Belém)',
        'America/Belize' => 'Yhdysvaltain keskinen aika (Belize)',
        'America/Blanc-Sablon' => 'Kanadan Atlantin aika (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazonin aika (Boa Vista)',
        'America/Bogota' => 'Kolumbian aika (Bogotá)',
        'America/Boise' => 'Kalliovuorten aika (Boise)',
        'America/Buenos_Aires' => 'Argentiinan aika (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Argentiinan aika (Buenos Aires)',
        'America/Cambridge_Bay' => 'Kalliovuorten aika (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazonin aika (Campo Grande)',
        'America/Cancun' => 'Yhdysvaltain itäinen aika (Cancún)',
        'America/Caracas' => 'Venezuelan aika (Caracas)',
        'America/Catamarca' => 'Argentiinan aika (Catamarca)',
        'America/Argentina/Catamarca' => 'Argentiinan aika (Catamarca)',
        'America/Cayenne' => 'Ranskan Guayanan aika (Cayenne)',
        'America/Cayman' => 'Yhdysvaltain itäinen aika (Cayman)',
        'America/Chicago' => 'Yhdysvaltain keskinen aika (Chicago)',
        'America/Chihuahua' => 'Yhdysvaltain keskinen aika (Chihuahua)',
        'America/Ciudad_Juarez' => 'Kalliovuorten aika (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Yhdysvaltain itäinen aika (Atikokan)',
        'America/Atikokan' => 'Yhdysvaltain itäinen aika (Atikokan)',
        'America/Cordoba' => 'Argentiinan aika (Córdoba)',
        'America/Argentina/Cordoba' => 'Argentiinan aika (Córdoba)',
        'America/Costa_Rica' => 'Yhdysvaltain keskinen aika (Costa Rica)',
        'America/Coyhaique' => 'Chilen aika (Coyhaique)',
        'America/Creston' => 'Kalliovuorten aika (Creston)',
        'America/Cuiaba' => 'Amazonin aika (Cuiabá)',
        'America/Curacao' => 'Kanadan Atlantin aika (Curaçao)',
        'America/Danmarkshavn' => 'Greenwichin normaaliaika (Danmarkshavn)',
        'America/Dawson' => 'Yukonin aika (Dawson)',
        'America/Dawson_Creek' => 'Kalliovuorten aika (Dawson Creek)',
        'America/Denver' => 'Kalliovuorten aika (Denver)',
        'America/Detroit' => 'Yhdysvaltain itäinen aika (Detroit)',
        'America/Dominica' => 'Kanadan Atlantin aika (Dominica)',
        'America/Edmonton' => 'Kalliovuorten aika (Edmonton)',
        'America/Eirunepe' => 'Acren aika (Eirunepé)',
        'America/El_Salvador' => 'Yhdysvaltain keskinen aika (El Salvador)',
        'America/Fort_Nelson' => 'Kalliovuorten aika (Fort Nelson)',
        'America/Fortaleza' => 'Brasilian aika (Fortaleza)',
        'America/Glace_Bay' => 'Kanadan Atlantin aika (Glace Bay)',
        'America/Godthab' => 'aikavyöhyke: Grönlanti (Nuuk)',
        'America/Nuuk' => 'aikavyöhyke: Grönlanti (Nuuk)',
        'America/Goose_Bay' => 'Kanadan Atlantin aika (Goose Bay)',
        'America/Grand_Turk' => 'Yhdysvaltain itäinen aika (Grand Turk)',
        'America/Grenada' => 'Kanadan Atlantin aika (Grenada)',
        'America/Guadeloupe' => 'Kanadan Atlantin aika (Guadeloupe)',
        'America/Guatemala' => 'Yhdysvaltain keskinen aika (Guatemala)',
        'America/Guayaquil' => 'Ecuadorin aika (Guayaquil)',
        'America/Guyana' => 'Guyanan aika',
        'America/Halifax' => 'Kanadan Atlantin aika (Halifax)',
        'America/Havana' => 'Kuuban aika (Havanna)',
        'America/Hermosillo' => 'Meksikon Tyynenmeren aika (Hermosillo)',
        'America/Indiana/Knox' => 'Yhdysvaltain keskinen aika (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Yhdysvaltain itäinen aika (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Yhdysvaltain itäinen aika (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Yhdysvaltain keskinen aika (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Yhdysvaltain itäinen aika (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Yhdysvaltain itäinen aika (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Yhdysvaltain itäinen aika (Winamac, Indiana)',
        'America/Indianapolis' => 'Yhdysvaltain itäinen aika (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Yhdysvaltain itäinen aika (Indianapolis)',
        'America/Inuvik' => 'Kalliovuorten aika (Inuvik)',
        'America/Iqaluit' => 'Yhdysvaltain itäinen aika (Iqaluit)',
        'America/Jamaica' => 'Yhdysvaltain itäinen aika (Jamaika)',
        'America/Jujuy' => 'Argentiinan aika (Jujuy)',
        'America/Argentina/Jujuy' => 'Argentiinan aika (Jujuy)',
        'America/Juneau' => 'Alaskan aika (Juneau)',
        'America/Kentucky/Monticello' => 'Yhdysvaltain itäinen aika (Monticello, Kentucky)',
        'America/Kralendijk' => 'Kanadan Atlantin aika (Kralendijk)',
        'America/La_Paz' => 'Bolivian aika (La Paz)',
        'America/Lima' => 'Perun aika (Lima)',
        'America/Los_Angeles' => 'Yhdysvaltain Tyynenmeren aika (Los Angeles)',
        'America/Louisville' => 'Yhdysvaltain itäinen aika (Louisville)',
        'America/Kentucky/Louisville' => 'Yhdysvaltain itäinen aika (Louisville)',
        'America/Lower_Princes' => 'Kanadan Atlantin aika (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasilian aika (Maceió)',
        'America/Managua' => 'Yhdysvaltain keskinen aika (Managua)',
        'America/Manaus' => 'Amazonin aika (Manaus)',
        'America/Marigot' => 'Kanadan Atlantin aika (Marigot)',
        'America/Martinique' => 'Kanadan Atlantin aika (Martinique)',
        'America/Matamoros' => 'Yhdysvaltain keskinen aika (Matamoros)',
        'America/Mazatlan' => 'Meksikon Tyynenmeren aika (Mazatlán)',
        'America/Mendoza' => 'Argentiinan aika (Mendoza)',
        'America/Argentina/Mendoza' => 'Argentiinan aika (Mendoza)',
        'America/Menominee' => 'Yhdysvaltain keskinen aika (Menominee)',
        'America/Merida' => 'Yhdysvaltain keskinen aika (Mérida)',
        'America/Metlakatla' => 'Alaskan aika (Metlakatla)',
        'America/Mexico_City' => 'Yhdysvaltain keskinen aika (Ciudad de México)',
        'America/Miquelon' => 'Saint-Pierren ja Miquelonin aika',
        'America/Moncton' => 'Kanadan Atlantin aika (Moncton)',
        'America/Monterrey' => 'Yhdysvaltain keskinen aika (Monterrey)',
        'America/Montevideo' => 'Uruguayn aika (Montevideo)',
        'America/Montserrat' => 'Kanadan Atlantin aika (Montserrat)',
        'America/Nassau' => 'Yhdysvaltain itäinen aika (Nassau)',
        'America/New_York' => 'Yhdysvaltain itäinen aika (New York)',
        'America/Nome' => 'Alaskan aika (Nome)',
        'America/Noronha' => 'Fernando de Noronhan aika',
        'America/North_Dakota/Beulah' => 'Yhdysvaltain keskinen aika (Beulah, Pohjois-Dakota)',
        'America/North_Dakota/Center' => 'Yhdysvaltain keskinen aika (Center, Pohjois-Dakota)',
        'America/North_Dakota/New_Salem' => 'Yhdysvaltain keskinen aika (New Salem, Pohjois-Dakota)',
        'America/Ojinaga' => 'Yhdysvaltain keskinen aika (Ojinaga)',
        'America/Panama' => 'Yhdysvaltain itäinen aika (Panama)',
        'America/Paramaribo' => 'Surinamen aika (Paramaribo)',
        'America/Phoenix' => 'Kalliovuorten aika (Phoenix)',
        'America/Port-au-Prince' => 'Yhdysvaltain itäinen aika (Port-au-Prince)',
        'America/Port_of_Spain' => 'Kanadan Atlantin aika (Port of Spain)',
        'America/Porto_Velho' => 'Amazonin aika (Porto Velho)',
        'America/Puerto_Rico' => 'Kanadan Atlantin aika (Puerto Rico)',
        'America/Punta_Arenas' => 'Chilen aika (Punta Arenas)',
        'America/Rankin_Inlet' => 'Yhdysvaltain keskinen aika (Rankin Inlet)',
        'America/Recife' => 'Brasilian aika (Recife)',
        'America/Regina' => 'Yhdysvaltain keskinen aika (Regina)',
        'America/Resolute' => 'Yhdysvaltain keskinen aika (Resolute)',
        'America/Rio_Branco' => 'Acren aika (Rio Branco)',
        'America/Santarem' => 'Brasilian aika (Santarém)',
        'America/Santiago' => 'Chilen aika (Santiago de Chile)',
        'America/Santo_Domingo' => 'Kanadan Atlantin aika (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasilian aika (São Paulo)',
        'America/Scoresbysund' => 'aikavyöhyke: Grönlanti (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaskan aika (Sitka)',
        'America/St_Barthelemy' => 'Kanadan Atlantin aika (Saint-Barthélemy)',
        'America/St_Johns' => 'Newfoundlandin aika (St. John’s)',
        'America/St_Kitts' => 'Kanadan Atlantin aika (Saint Kitts)',
        'America/St_Lucia' => 'Kanadan Atlantin aika (Saint Lucia)',
        'America/St_Thomas' => 'Kanadan Atlantin aika (Saint Thomas)',
        'America/St_Vincent' => 'Kanadan Atlantin aika (Saint Vincent)',
        'America/Swift_Current' => 'Yhdysvaltain keskinen aika (Swift Current)',
        'America/Tegucigalpa' => 'Yhdysvaltain keskinen aika (Tegucigalpa)',
        'America/Thule' => 'Kanadan Atlantin aika (Thule)',
        'America/Tijuana' => 'Yhdysvaltain Tyynenmeren aika (Tijuana)',
        'America/Toronto' => 'Yhdysvaltain itäinen aika (Toronto)',
        'America/Tortola' => 'Kanadan Atlantin aika (Tortola)',
        'America/Vancouver' => 'Yhdysvaltain Tyynenmeren aika (Vancouver)',
        'America/Whitehorse' => 'Yukonin aika (Whitehorse)',
        'America/Winnipeg' => 'Yhdysvaltain keskinen aika (Winnipeg)',
        'America/Yakutat' => 'Alaskan aika (Yakutat)',
        'Antarctica/Casey' => 'Länsi-Australian aika (Casey)',
        'Antarctica/Davis' => 'Davisin aika',
        'Antarctica/DumontDUrville' => 'Dumont d’Urvillen aika',
        'Antarctica/Macquarie' => 'Itä-Australian aika (Macquariensaari)',
        'Antarctica/Mawson' => 'Mawsonin aika',
        'Antarctica/McMurdo' => 'Uuden-Seelannin aika (McMurdo)',
        'Antarctica/Palmer' => 'Chilen aika (Palmer)',
        'Antarctica/Rothera' => 'Rotheran aika',
        'Antarctica/Syowa' => 'Syowan aika (Showa)',
        'Antarctica/Troll' => 'Greenwichin normaaliaika (Troll)',
        'Antarctica/Vostok' => 'Vostokin aika',
        'Arctic/Longyearbyen' => 'Keski-Euroopan aika (Longyearbyen)',
        'Asia/Aden' => 'Saudi-Arabian aika (Aden)',
        'Asia/Almaty' => 'Kazakstanin aika (Almaty)',
        'Asia/Amman' => 'Itä-Euroopan aika (Amman)',
        'Asia/Anadyr' => 'Kamtšatkan aika (Anadyr)',
        'Asia/Aqtau' => 'Kazakstanin aika (Aqtaw)',
        'Asia/Aqtobe' => 'Kazakstanin aika (Aqtöbe)',
        'Asia/Ashgabat' => 'Turkmenistanin aika (Ašgabat)',
        'Asia/Atyrau' => 'Kazakstanin aika (Atıraw)',
        'Asia/Baghdad' => 'Saudi-Arabian aika (Bagdad)',
        'Asia/Bahrain' => 'Saudi-Arabian aika (Bahrain)',
        'Asia/Baku' => 'Azerbaidžanin aika (Baku)',
        'Asia/Bangkok' => 'Indokiinan aika (Bangkok)',
        'Asia/Barnaul' => 'Krasnojarskin aika (Barnaul)',
        'Asia/Beirut' => 'Itä-Euroopan aika (Beirut)',
        'Asia/Bishkek' => 'Kirgisian aika (Biškek)',
        'Asia/Brunei' => 'Brunein aika',
        'Asia/Calcutta' => 'Intian aika (Kalkutta)',
        'Asia/Kolkata' => 'Intian aika (Kalkutta)',
        'Asia/Chita' => 'Jakutskin aika (Tšita)',
        'Asia/Colombo' => 'Intian aika (Colombo)',
        'Asia/Damascus' => 'Itä-Euroopan aika (Damaskos)',
        'Asia/Dhaka' => 'Bangladeshin aika (Dhaka)',
        'Asia/Dili' => 'Itä-Timorin aika (Dili)',
        'Asia/Dubai' => 'Arabiemiirikuntien normaaliaika (Dubai)',
        'Asia/Dushanbe' => 'Tadžikistanin aika (Dušanbe)',
        'Asia/Famagusta' => 'Itä-Euroopan aika (Famagusta)',
        'Asia/Gaza' => 'Itä-Euroopan aika (Gaza)',
        'Asia/Hebron' => 'Itä-Euroopan aika (Hebron)',
        'Asia/Hong_Kong' => 'Hongkongin aika',
        'Asia/Hovd' => 'Hovdin aika (Khovd)',
        'Asia/Irkutsk' => 'Irkutskin aika',
        'Asia/Jakarta' => 'Länsi-Indonesian aika (Jakarta)',
        'Asia/Jayapura' => 'Itä-Indonesian aika (Jayapura)',
        'Asia/Jerusalem' => 'Israelin aika (Jerusalem)',
        'Asia/Kabul' => 'Afganistanin aika (Kabul)',
        'Asia/Kamchatka' => 'Kamtšatkan aika',
        'Asia/Karachi' => 'Pakistanin aika (Karachi)',
        'Asia/Katmandu' => 'Nepalin aika (Kathmandu)',
        'Asia/Kathmandu' => 'Nepalin aika (Kathmandu)',
        'Asia/Khandyga' => 'Jakutskin aika (Handyga)',
        'Asia/Krasnoyarsk' => 'Krasnojarskin aika',
        'Asia/Kuala_Lumpur' => 'Malesian aika (Kuala Lumpur)',
        'Asia/Kuching' => 'Malesian aika (Kuching)',
        'Asia/Kuwait' => 'Saudi-Arabian aika (Kuwait)',
        'Asia/Macau' => 'Kiinan aika (Macao)',
        'Asia/Magadan' => 'Magadanin aika',
        'Asia/Makassar' => 'Keski-Indonesian aika (Makassar)',
        'Asia/Manila' => 'Filippiinien aika (Manila)',
        'Asia/Muscat' => 'Arabiemiirikuntien normaaliaika (Masqat)',
        'Asia/Nicosia' => 'Itä-Euroopan aika (Nikosia)',
        'Asia/Novokuznetsk' => 'Krasnojarskin aika (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Krasnojarskin aika (Novosibirsk)',
        'Asia/Omsk' => 'Omskin aika',
        'Asia/Oral' => 'Kazakstanin aika (Uralsk)',
        'Asia/Phnom_Penh' => 'Indokiinan aika (Phnom Penh)',
        'Asia/Pontianak' => 'Länsi-Indonesian aika (Pontianak)',
        'Asia/Pyongyang' => 'Korean aika (Pjongjang)',
        'Asia/Qatar' => 'Saudi-Arabian aika (Qatar)',
        'Asia/Qostanay' => 'Kazakstanin aika (Kostanai)',
        'Asia/Qyzylorda' => 'Kazakstanin aika (Qızılorda)',
        'Asia/Rangoon' => 'Myanmarin aika (Yangon)',
        'Asia/Yangon' => 'Myanmarin aika (Yangon)',
        'Asia/Riyadh' => 'Saudi-Arabian aika (Riad)',
        'Asia/Saigon' => 'Indokiinan aika (Hồ Chí Minhin kaupunki)',
        'Asia/Ho_Chi_Minh' => 'Indokiinan aika (Hồ Chí Minhin kaupunki)',
        'Asia/Sakhalin' => 'Magadanin aika (Sahalin)',
        'Asia/Samarkand' => 'Uzbekistanin aika (Samarkand)',
        'Asia/Seoul' => 'Korean aika (Soul)',
        'Asia/Shanghai' => 'Kiinan aika (Shanghai)',
        'Asia/Singapore' => 'Singaporen aika',
        'Asia/Srednekolymsk' => 'Magadanin aika (Srednekolymsk)',
        'Asia/Taipei' => 'Taipein aika',
        'Asia/Tashkent' => 'Uzbekistanin aika (Taškent)',
        'Asia/Tbilisi' => 'Georgian aika (Tbilisi)',
        'Asia/Tehran' => 'Iranin aika (Teheran)',
        'Asia/Thimphu' => 'Bhutanin aika (Thimphu)',
        'Asia/Tokyo' => 'Japanin aika (Tokio)',
        'Asia/Tomsk' => 'Krasnojarskin aika (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulan Batorin aika',
        'Asia/Urumqi' => 'aikavyöhyke: Kiina (Ürümqi)',
        'Asia/Ust-Nera' => 'Vladivostokin aika (Ust-Nera)',
        'Asia/Vientiane' => 'Indokiinan aika (Vientiane)',
        'Asia/Vladivostok' => 'Vladivostokin aika',
        'Asia/Yakutsk' => 'Jakutskin aika',
        'Asia/Yekaterinburg' => 'Jekaterinburgin aika',
        'Asia/Yerevan' => 'Armenian aika (Jerevan)',
        'Atlantic/Azores' => 'Azorien aika (Azorit)',
        'Atlantic/Bermuda' => 'Kanadan Atlantin aika (Bermuda)',
        'Atlantic/Canary' => 'Länsi-Euroopan aika (Kanariansaaret)',
        'Atlantic/Cape_Verde' => 'Kap Verden aika',
        'Atlantic/Faeroe' => 'Länsi-Euroopan aika (Färsaaret)',
        'Atlantic/Faroe' => 'Länsi-Euroopan aika (Färsaaret)',
        'Atlantic/Madeira' => 'Länsi-Euroopan aika (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwichin normaaliaika (Reykjavík)',
        'Atlantic/South_Georgia' => 'Etelä-Georgian aika',
        'Atlantic/St_Helena' => 'Greenwichin normaaliaika (Saint Helena)',
        'Atlantic/Stanley' => 'Falklandinsaarten aika (Stanley)',
        'Australia/Adelaide' => 'Keski-Australian aika (Adelaide)',
        'Australia/Brisbane' => 'Itä-Australian aika (Brisbane)',
        'Australia/Broken_Hill' => 'Keski-Australian aika (Broken Hill)',
        'Australia/Darwin' => 'Keski-Australian aika (Darwin)',
        'Australia/Eucla' => 'Läntisen Keski-Australian aika (Eucla)',
        'Australia/Hobart' => 'Itä-Australian aika (Hobart)',
        'Australia/Lindeman' => 'Itä-Australian aika (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howen aika',
        'Australia/Melbourne' => 'Itä-Australian aika (Melbourne)',
        'Australia/Perth' => 'Länsi-Australian aika (Perth)',
        'Australia/Sydney' => 'Itä-Australian aika (Sydney)',
        'Etc/GMT' => 'Greenwichin normaaliaika',
        'Etc/UTC' => 'UTC-yleisaika',
        'Europe/Amsterdam' => 'Keski-Euroopan aika (Amsterdam)',
        'Europe/Andorra' => 'Keski-Euroopan aika (Andorra)',
        'Europe/Astrakhan' => 'Samaran aika (Astrahan)',
        'Europe/Athens' => 'Itä-Euroopan aika (Ateena)',
        'Europe/Belgrade' => 'Keski-Euroopan aika (Belgrad)',
        'Europe/Berlin' => 'Keski-Euroopan aika (Berliini)',
        'Europe/Bratislava' => 'Keski-Euroopan aika (Bratislava)',
        'Europe/Brussels' => 'Keski-Euroopan aika (Bryssel)',
        'Europe/Bucharest' => 'Itä-Euroopan aika (Bukarest)',
        'Europe/Budapest' => 'Keski-Euroopan aika (Budapest)',
        'Europe/Busingen' => 'Keski-Euroopan aika (Büsingen)',
        'Europe/Chisinau' => 'Itä-Euroopan aika (Chişinău)',
        'Europe/Copenhagen' => 'Keski-Euroopan aika (Kööpenhamina)',
        'Europe/Dublin' => 'Greenwichin normaaliaika (Dublin)',
        'Europe/Gibraltar' => 'Keski-Euroopan aika (Gibraltar)',
        'Europe/Guernsey' => 'Greenwichin normaaliaika (Guernsey)',
        'Europe/Helsinki' => 'Itä-Euroopan aika (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwichin normaaliaika (Mansaari)',
        'Europe/Istanbul' => 'Turkin aika (Istanbul)',
        'Europe/Jersey' => 'Greenwichin normaaliaika (Jersey)',
        'Europe/Kaliningrad' => 'Itä-Euroopan aika (Kaliningrad)',
        'Europe/Kiev' => 'Itä-Euroopan aika (Kiova)',
        'Europe/Kyiv' => 'Itä-Euroopan aika (Kiova)',
        'Europe/Kirov' => 'Moskovan aika (Kirov)',
        'Europe/Lisbon' => 'Länsi-Euroopan aika (Lissabon)',
        'Europe/Ljubljana' => 'Keski-Euroopan aika (Ljubljana)',
        'Europe/London' => 'Greenwichin normaaliaika (Lontoo)',
        'Europe/Luxembourg' => 'Keski-Euroopan aika (Luxemburg)',
        'Europe/Madrid' => 'Keski-Euroopan aika (Madrid)',
        'Europe/Malta' => 'Keski-Euroopan aika (Malta)',
        'Europe/Mariehamn' => 'Itä-Euroopan aika (Maarianhamina)',
        'Europe/Minsk' => 'Moskovan aika (Minsk)',
        'Europe/Monaco' => 'Keski-Euroopan aika (Monaco)',
        'Europe/Moscow' => 'Moskovan aika',
        'Europe/Oslo' => 'Keski-Euroopan aika (Oslo)',
        'Europe/Paris' => 'Keski-Euroopan aika (Pariisi)',
        'Europe/Podgorica' => 'Keski-Euroopan aika (Podgorica)',
        'Europe/Prague' => 'Keski-Euroopan aika (Praha)',
        'Europe/Riga' => 'Itä-Euroopan aika (Riika)',
        'Europe/Rome' => 'Keski-Euroopan aika (Rooma)',
        'Europe/Samara' => 'Samaran aika',
        'Europe/San_Marino' => 'Keski-Euroopan aika (San Marino)',
        'Europe/Sarajevo' => 'Keski-Euroopan aika (Sarajevo)',
        'Europe/Saratov' => 'Samaran aika (Saratov)',
        'Europe/Simferopol' => 'Moskovan aika (Simferopol)',
        'Europe/Skopje' => 'Keski-Euroopan aika (Skopje)',
        'Europe/Sofia' => 'Itä-Euroopan aika (Sofia)',
        'Europe/Stockholm' => 'Keski-Euroopan aika (Tukholma)',
        'Europe/Tallinn' => 'Itä-Euroopan aika (Tallinna)',
        'Europe/Tirane' => 'Keski-Euroopan aika (Tirana)',
        'Europe/Ulyanovsk' => 'Samaran aika (Uljanovsk)',
        'Europe/Vaduz' => 'Keski-Euroopan aika (Vaduz)',
        'Europe/Vatican' => 'Keski-Euroopan aika (Vatikaani)',
        'Europe/Vienna' => 'Keski-Euroopan aika (Wien)',
        'Europe/Vilnius' => 'Itä-Euroopan aika (Vilna)',
        'Europe/Volgograd' => 'Moskovan aika (Volgograd)',
        'Europe/Warsaw' => 'Keski-Euroopan aika (Varsova)',
        'Europe/Zagreb' => 'Keski-Euroopan aika (Zagreb)',
        'Europe/Zurich' => 'Keski-Euroopan aika (Zürich)',
        'Indian/Antananarivo' => 'Itä-Afrikan aika (Antananarivo)',
        'Indian/Chagos' => 'Intian valtameren aika (Chagos)',
        'Indian/Christmas' => 'Joulusaaren aika (Joulusaari)',
        'Indian/Cocos' => 'Kookossaarten aika (Kookossaaret)',
        'Indian/Comoro' => 'Itä-Afrikan aika (Komorit)',
        'Indian/Kerguelen' => 'Ranskan eteläisten ja antarktisten alueiden aika (Kerguelensaaret)',
        'Indian/Mahe' => 'Seychellien aika (Mahé)',
        'Indian/Maldives' => 'Malediivien aika (Malediivit)',
        'Indian/Mauritius' => 'Mauritiuksen aika (Mauritius)',
        'Indian/Mayotte' => 'Itä-Afrikan aika (Mayotte)',
        'Indian/Reunion' => 'Réunionin aika',
        'Pacific/Apia' => 'Apian aika',
        'Pacific/Auckland' => 'Uuden-Seelannin aika (Auckland)',
        'Pacific/Bougainville' => 'Papua-Uuden-Guinean aika (Bougainville)',
        'Pacific/Chatham' => 'Chathamin aika (Chathamsaaret)',
        'Pacific/Easter' => 'Pääsiäissaaren aika (Pääsiäissaari)',
        'Pacific/Efate' => 'Vanuatun aika (Efate)',
        'Pacific/Enderbury' => 'Phoenixsaarten aika (Abariringa)',
        'Pacific/Kanton' => 'Phoenixsaarten aika (Abariringa)',
        'Pacific/Fakaofo' => 'Tokelaun aika (Fakaofo)',
        'Pacific/Fiji' => 'Fidžin aika',
        'Pacific/Funafuti' => 'Tuvalun aika (Funafuti)',
        'Pacific/Galapagos' => 'Galápagossaarten aika',
        'Pacific/Gambier' => 'Gambiersaarten aika (Gambiersaaret)',
        'Pacific/Guadalcanal' => 'Salomonsaarten aika (Guadalcanal)',
        'Pacific/Guam' => 'Tšamorron aika (Guam)',
        'Pacific/Honolulu' => 'Havaijin-Aleuttien normaaliaika (Honolulu)',
        'Pacific/Kiritimati' => 'Linesaarten aika (Kiritimati)',
        'Pacific/Kosrae' => 'Kosraen aika',
        'Pacific/Kwajalein' => 'Marshallinsaarten aika (Kwajalein)',
        'Pacific/Majuro' => 'Marshallinsaarten aika (Majuro)',
        'Pacific/Marquesas' => 'Marquesassaarten aika (Marquesassaaret)',
        'Pacific/Midway' => 'Samoan aika (Midwaysaaret)',
        'Pacific/Nauru' => 'Naurun aika',
        'Pacific/Niue' => 'Niuen aika',
        'Pacific/Norfolk' => 'Norfolkinsaaren aika',
        'Pacific/Noumea' => 'Uuden-Kaledonian aika (Nouméa)',
        'Pacific/Pago_Pago' => 'Samoan aika (Pago Pago)',
        'Pacific/Palau' => 'Palaun aika',
        'Pacific/Pitcairn' => 'Pitcairnin aika',
        'Pacific/Ponape' => 'Pohnpein aika',
        'Pacific/Pohnpei' => 'Pohnpein aika',
        'Pacific/Port_Moresby' => 'Papua-Uuden-Guinean aika (Port Moresby)',
        'Pacific/Rarotonga' => 'Cookinsaarten aika (Rarotonga)',
        'Pacific/Saipan' => 'Tšamorron aika (Saipan)',
        'Pacific/Tahiti' => 'Tahitin aika',
        'Pacific/Tarawa' => 'Gilbertsaarten aika (Tarawa)',
        'Pacific/Tongatapu' => 'Tongan aika (Tongatapu)',
        'Pacific/Truk' => 'Chuukin aika',
        'Pacific/Chuuk' => 'Chuukin aika',
        'Pacific/Wake' => 'Waken aika',
        'Pacific/Wallis' => 'Wallisin ja Futunan aika (Wallis & Futuna)',
    ],
    'Meta' => [
        'GmtFormat' => 'UTC%s',
        'HourFormatPos' => '+%d.%02d',
        'HourFormatNeg' => '-%d.%02d',
    ],
];
