<?php

return [
    'Names' => [
        'af' => 'Afrikaans',
        'af_NA' => 'Afrikaans (Namibia)',
        'af_ZA' => 'Afrikaans (South Africa)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Ghana)',
        'am' => 'Asụsụ Amariikị',
        'am_ET' => 'Asụsụ Amariikị (Ethiopia)',
        'ar' => 'Asụsụ Arabiikị',
        'ar_001' => 'Asụsụ Arabiikị (Uwa)',
        'ar_AE' => 'Asụsụ Arabiikị (United Arab Emirates)',
        'ar_BH' => 'Asụsụ Arabiikị (Bahrain)',
        'ar_DJ' => 'Asụsụ Arabiikị (Djibouti)',
        'ar_DZ' => 'Asụsụ Arabiikị (Algeria)',
        'ar_EG' => 'Asụsụ Arabiikị (Egypt)',
        'ar_EH' => 'Asụsụ Arabiikị (Ọdịda Anyanwụ Sahara)',
        'ar_ER' => 'Asụsụ Arabiikị (Eritrea)',
        'ar_IL' => 'Asụsụ Arabiikị (Israel)',
        'ar_IQ' => 'Asụsụ Arabiikị (Iraq)',
        'ar_JO' => 'Asụsụ Arabiikị (Jordan)',
        'ar_KM' => 'Asụsụ Arabiikị (Comoros)',
        'ar_KW' => 'Asụsụ Arabiikị (Kuwait)',
        'ar_LB' => 'Asụsụ Arabiikị (Lebanon)',
        'ar_LY' => 'Asụsụ Arabiikị (Libia)',
        'ar_MA' => 'Asụsụ Arabiikị (Morocco)',
        'ar_MR' => 'Asụsụ Arabiikị (Mauritania)',
        'ar_OM' => 'Asụsụ Arabiikị (Oman)',
        'ar_PS' => 'Asụsụ Arabiikị (Mpaghara ndị Palestine)',
        'ar_QA' => 'Asụsụ Arabiikị (Qatar)',
        'ar_SA' => 'Asụsụ Arabiikị (Saudi Arabia)',
        'ar_SD' => 'Asụsụ Arabiikị (Sudan)',
        'ar_SO' => 'Asụsụ Arabiikị (Somalia)',
        'ar_SS' => 'Asụsụ Arabiikị (South Sudan)',
        'ar_SY' => 'Asụsụ Arabiikị (Syria)',
        'ar_TD' => 'Asụsụ Arabiikị (Chad)',
        'ar_TN' => 'Asụsụ Arabiikị (Tunisia)',
        'ar_YE' => 'Asụsụ Arabiikị (Yemen)',
        'as' => 'Asụsụ Asamisị',
        'as_IN' => 'Asụsụ Asamisị (India)',
        'az' => 'Azerbaijani',
        'az_AZ' => 'Azerbaijani (Azerbaijan)',
        'az_Cyrl' => 'Azerbaijani (Cyrillic)',
        'az_Cyrl_AZ' => 'Azerbaijani (Cyrillic, Azerbaijan)',
        'az_Latn' => 'Azerbaijani (Latin)',
        'az_Latn_AZ' => 'Azerbaijani (Latin, Azerbaijan)',
        'ba' => 'Bashkir',
        'ba_RU' => 'Bashkir (Russia)',
        'be' => 'Belarusian',
        'be_BY' => 'Belarusian (Belarus)',
        'bg' => 'Bulgarian',
        'bg_BG' => 'Bulgarian (Bulgaria)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Bangla',
        'bn_BD' => 'Bangla (Bangladesh)',
        'bn_IN' => 'Bangla (India)',
        'bo' => 'Tibetan',
        'bo_CN' => 'Tibetan (China)',
        'bo_IN' => 'Tibetan (India)',
        'br' => 'Breton',
        'br_FR' => 'Breton (France)',
        'bs' => 'Bosnian',
        'bs_BA' => 'Bosnian (Bosnia & Herzegovina)',
        'bs_Cyrl' => 'Bosnian (Cyrillic)',
        'bs_Cyrl_BA' => 'Bosnian (Cyrillic, Bosnia & Herzegovina)',
        'bs_Latn' => 'Bosnian (Latin)',
        'bs_Latn_BA' => 'Bosnian (Latin, Bosnia & Herzegovina)',
        'ca' => 'Catalan',
        'ca_AD' => 'Catalan (Andorra)',
        'ca_ES' => 'Catalan (Spain)',
        'ca_FR' => 'Catalan (France)',
        'ca_IT' => 'Catalan (Italy)',
        'ce' => 'Chechen',
        'ce_RU' => 'Chechen (Russia)',
        'cs' => 'Czech',
        'cs_CZ' => 'Czech (Czechia)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (Russia)',
        'cy' => 'Welsh',
        'cy_GB' => 'Welsh (United Kingdom)',
        'da' => 'Danish',
        'da_DK' => 'Danish (Denmark)',
        'da_GL' => 'Danish (Greenland)',
        'de' => 'German',
        'de_AT' => 'German (Austria)',
        'de_BE' => 'German (Belgium)',
        'de_CH' => 'German (Switzerland)',
        'de_DE' => 'German (Germany)',
        'de_IT' => 'German (Italy)',
        'de_LI' => 'German (Liechtenstein)',
        'de_LU' => 'German (Luxembourg)',
        'dz' => 'Dọzngọka',
        'dz_BT' => 'Dọzngọka (Bhutan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Ghana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Grik',
        'el_CY' => 'Grik (Cyprus)',
        'el_GR' => 'Grik (Greece)',
        'en' => 'Bekee',
        'en_001' => 'Bekee (Uwa)',
        'en_150' => 'Bekee (Europe)',
        'en_AE' => 'Bekee (United Arab Emirates)',
        'en_AG' => 'Bekee (Antigua na Barbuda)',
        'en_AI' => 'Bekee (Anguilla)',
        'en_AS' => 'Bekee (American Samoa)',
        'en_AT' => 'Bekee (Austria)',
        'en_AU' => 'Bekee (Australia)',
        'en_BB' => 'Bekee (Barbados)',
        'en_BE' => 'Bekee (Belgium)',
        'en_BI' => 'Bekee (Burundi)',
        'en_BM' => 'Bekee (Bemuda)',
        'en_BS' => 'Bekee (Bahamas)',
        'en_BW' => 'Bekee (Botswana)',
        'en_BZ' => 'Bekee (Belize)',
        'en_CA' => 'Bekee (Canada)',
        'en_CC' => 'Bekee (Agwaetiti Cocos [Keeling])',
        'en_CH' => 'Bekee (Switzerland)',
        'en_CK' => 'Bekee (Agwaetiti Cook)',
        'en_CM' => 'Bekee (Cameroon)',
        'en_CX' => 'Bekee (Agwaetiti Christmas)',
        'en_CY' => 'Bekee (Cyprus)',
        'en_CZ' => 'Bekee (Czechia)',
        'en_DE' => 'Bekee (Germany)',
        'en_DK' => 'Bekee (Denmark)',
        'en_DM' => 'Bekee (Dominica)',
        'en_EE' => 'Bekee (Estonia)',
        'en_ER' => 'Bekee (Eritrea)',
        'en_ES' => 'Bekee (Spain)',
        'en_FI' => 'Bekee (Finland)',
        'en_FJ' => 'Bekee (Fiji)',
        'en_FK' => 'Bekee (Falkland Islands)',
        'en_FM' => 'Bekee (Micronesia)',
        'en_FR' => 'Bekee (France)',
        'en_GB' => 'Bekee (United Kingdom)',
        'en_GD' => 'Bekee (Grenada)',
        'en_GE' => 'Bekee (Georgia)',
        'en_GG' => 'Bekee (Guernsey)',
        'en_GH' => 'Bekee (Ghana)',
        'en_GI' => 'Bekee (Gibraltar)',
        'en_GM' => 'Bekee (Gambia)',
        'en_GS' => 'Bekee (South Georgia & South Sandwich Islands)',
        'en_GU' => 'Bekee (Guam)',
        'en_GY' => 'Bekee (Guyana)',
        'en_HK' => 'Bekee (Hong Kong SAR China)',
        'en_HU' => 'Bekee (Hungary)',
        'en_ID' => 'Bekee (Indonesia)',
        'en_IE' => 'Bekee (Ireland)',
        'en_IL' => 'Bekee (Israel)',
        'en_IM' => 'Bekee (Isle of Man)',
        'en_IN' => 'Bekee (India)',
        'en_IO' => 'Bekee (British Indian Ocean Territory)',
        'en_IT' => 'Bekee (Italy)',
        'en_JE' => 'Bekee (Jersey)',
        'en_JM' => 'Bekee (Jamaika)',
        'en_JP' => 'Bekee (Japan)',
        'en_KE' => 'Bekee (Kenya)',
        'en_KI' => 'Bekee (Kiribati)',
        'en_KN' => 'Bekee (St. Kitts & Nevis)',
        'en_KY' => 'Bekee (Cayman Islands)',
        'en_LC' => 'Bekee (St. Lucia)',
        'en_LR' => 'Bekee (Liberia)',
        'en_LS' => 'Bekee (Lesotho)',
        'en_LT' => 'Bekee (Lithuania)',
        'en_LV' => 'Bekee (Latvia)',
        'en_MG' => 'Bekee (Madagascar)',
        'en_MH' => 'Bekee (Agwaetiti Marshall)',
        'en_MO' => 'Bekee (Macao SAR China)',
        'en_MP' => 'Bekee (Agwaetiti Northern Mariana)',
        'en_MS' => 'Bekee (Montserrat)',
        'en_MT' => 'Bekee (Malta)',
        'en_MU' => 'Bekee (Mauritius)',
        'en_MV' => 'Bekee (Maldivesa)',
        'en_MW' => 'Bekee (Malawi)',
        'en_MY' => 'Bekee (Malaysia)',
        'en_NA' => 'Bekee (Namibia)',
        'en_NF' => 'Bekee (Agwaetiti Norfolk)',
        'en_NG' => 'Bekee (Naịjịrịa)',
        'en_NL' => 'Bekee (Netherlands)',
        'en_NO' => 'Bekee (Norway)',
        'en_NR' => 'Bekee (Nauru)',
        'en_NU' => 'Bekee (Niue)',
        'en_NZ' => 'Bekee (New Zealand)',
        'en_PG' => 'Bekee (Papua New Guinea)',
        'en_PH' => 'Bekee (Philippines)',
        'en_PK' => 'Bekee (Pakistan)',
        'en_PL' => 'Bekee (Poland)',
        'en_PN' => 'Bekee (Agwaetiti Pitcairn)',
        'en_PR' => 'Bekee (Puerto Rico)',
        'en_PT' => 'Bekee (Portugal)',
        'en_PW' => 'Bekee (Palau)',
        'en_RO' => 'Bekee (Romania)',
        'en_RW' => 'Bekee (Rwanda)',
        'en_SB' => 'Bekee (Agwaetiti Solomon)',
        'en_SC' => 'Bekee (Seychelles)',
        'en_SD' => 'Bekee (Sudan)',
        'en_SE' => 'Bekee (Sweden)',
        'en_SG' => 'Bekee (Singapore)',
        'en_SH' => 'Bekee (St. Helena)',
        'en_SI' => 'Bekee (Slovenia)',
        'en_SK' => 'Bekee (Slovakia)',
        'en_SL' => 'Bekee (Sierra Leone)',
        'en_SS' => 'Bekee (South Sudan)',
        'en_SX' => 'Bekee (Sint Maarten)',
        'en_SZ' => 'Bekee (Eswatini)',
        'en_TC' => 'Bekee (Turks & Caicos Islands)',
        'en_TK' => 'Bekee (Tokelau)',
        'en_TO' => 'Bekee (Tonga)',
        'en_TT' => 'Bekee (Trinidad na Tobago)',
        'en_TV' => 'Bekee (Tuvalu)',
        'en_TZ' => 'Bekee (Tanzania)',
        'en_UA' => 'Bekee (Ukraine)',
        'en_UG' => 'Bekee (Uganda)',
        'en_UM' => 'Bekee (Obere Agwaetiti Dị Na Mpụga U.S)',
        'en_US' => 'Bekee (United States)',
        'en_VC' => 'Bekee (St. Vincent & Grenadines)',
        'en_VG' => 'Bekee (British Virgin Islands)',
        'en_VI' => 'Bekee (U.S. Virgin Islands)',
        'en_VU' => 'Bekee (Vanuatu)',
        'en_WS' => 'Bekee (Samoa)',
        'en_ZA' => 'Bekee (South Africa)',
        'en_ZM' => 'Bekee (Zambia)',
        'en_ZW' => 'Bekee (Zimbabwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (Uwa)',
        'es' => 'Spanish',
        'es_419' => 'Spanish (Latin America)',
        'es_AR' => 'Spanish (Argentina)',
        'es_BO' => 'Spanish (Bolivia)',
        'es_BR' => 'Spanish (Brazil)',
        'es_BZ' => 'Spanish (Belize)',
        'es_CL' => 'Spanish (Chile)',
        'es_CO' => 'Spanish (Colombia)',
        'es_CR' => 'Spanish (Kosta Rika)',
        'es_CU' => 'Spanish (Cuba)',
        'es_DO' => 'Spanish (Dominican Republik)',
        'es_EC' => 'Spanish (Ecuador)',
        'es_ES' => 'Spanish (Spain)',
        'es_GQ' => 'Spanish (Equatorial Guinea)',
        'es_GT' => 'Spanish (Guatemala)',
        'es_HN' => 'Spanish (Honduras)',
        'es_MX' => 'Spanish (Mexico)',
        'es_NI' => 'Spanish (Nicaragua)',
        'es_PA' => 'Spanish (Panama)',
        'es_PE' => 'Spanish (Peru)',
        'es_PH' => 'Spanish (Philippines)',
        'es_PR' => 'Spanish (Puerto Rico)',
        'es_PY' => 'Spanish (Paraguay)',
        'es_SV' => 'Spanish (El Salvador)',
        'es_US' => 'Spanish (United States)',
        'es_UY' => 'Spanish (Uruguay)',
        'es_VE' => 'Spanish (Venezuela)',
        'et' => 'Estonian',
        'et_EE' => 'Estonian (Estonia)',
        'eu' => 'Basque',
        'eu_ES' => 'Basque (Spain)',
        'fa' => 'Asụsụ Persia',
        'fa_AF' => 'Asụsụ Persia (Afghanistan)',
        'fa_IR' => 'Asụsụ Persia (Iran)',
        'ff' => 'Fula',
        'ff_Adlm' => 'Fula (Adlam)',
        'ff_Adlm_BF' => 'Fula (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Fula (Adlam, Cameroon)',
        'ff_Adlm_GH' => 'Fula (Adlam, Ghana)',
        'ff_Adlm_GM' => 'Fula (Adlam, Gambia)',
        'ff_Adlm_GN' => 'Fula (Adlam, Guinea)',
        'ff_Adlm_GW' => 'Fula (Adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'Fula (Adlam, Liberia)',
        'ff_Adlm_MR' => 'Fula (Adlam, Mauritania)',
        'ff_Adlm_NE' => 'Fula (Adlam, Niger)',
        'ff_Adlm_NG' => 'Fula (Adlam, Naịjịrịa)',
        'ff_Adlm_SL' => 'Fula (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Fula (Adlam, Senegal)',
        'ff_CM' => 'Fula (Cameroon)',
        'ff_GN' => 'Fula (Guinea)',
        'ff_Latn' => 'Fula (Latin)',
        'ff_Latn_BF' => 'Fula (Latin, Burkina Faso)',
        'ff_Latn_CM' => 'Fula (Latin, Cameroon)',
        'ff_Latn_GH' => 'Fula (Latin, Ghana)',
        'ff_Latn_GM' => 'Fula (Latin, Gambia)',
        'ff_Latn_GN' => 'Fula (Latin, Guinea)',
        'ff_Latn_GW' => 'Fula (Latin, Guinea-Bissau)',
        'ff_Latn_LR' => 'Fula (Latin, Liberia)',
        'ff_Latn_MR' => 'Fula (Latin, Mauritania)',
        'ff_Latn_NE' => 'Fula (Latin, Niger)',
        'ff_Latn_NG' => 'Fula (Latin, Naịjịrịa)',
        'ff_Latn_SL' => 'Fula (Latin, Sierra Leone)',
        'ff_Latn_SN' => 'Fula (Latin, Senegal)',
        'ff_MR' => 'Fula (Mauritania)',
        'ff_SN' => 'Fula (Senegal)',
        'fi' => 'Finnish',
        'fi_FI' => 'Finnish (Finland)',
        'fo' => 'Faroese',
        'fo_DK' => 'Faroese (Denmark)',
        'fo_FO' => 'Faroese (Faroe Islands)',
        'fr' => 'French',
        'fr_BE' => 'French (Belgium)',
        'fr_BF' => 'French (Burkina Faso)',
        'fr_BI' => 'French (Burundi)',
        'fr_BJ' => 'French (Benin)',
        'fr_BL' => 'French (St. Barthélemy)',
        'fr_CA' => 'French (Canada)',
        'fr_CD' => 'French (Congo - Kinshasa)',
        'fr_CF' => 'French (Central African Republik)',
        'fr_CG' => 'French (Congo)',
        'fr_CH' => 'French (Switzerland)',
        'fr_CI' => 'French (Côte d’Ivoire)',
        'fr_CM' => 'French (Cameroon)',
        'fr_DJ' => 'French (Djibouti)',
        'fr_DZ' => 'French (Algeria)',
        'fr_FR' => 'French (France)',
        'fr_GA' => 'French (Gabon)',
        'fr_GF' => 'French (French Guiana)',
        'fr_GN' => 'French (Guinea)',
        'fr_GP' => 'French (Guadeloupe)',
        'fr_GQ' => 'French (Equatorial Guinea)',
        'fr_HT' => 'French (Haiti)',
        'fr_KM' => 'French (Comoros)',
        'fr_LU' => 'French (Luxembourg)',
        'fr_MA' => 'French (Morocco)',
        'fr_MC' => 'French (Monaco)',
        'fr_MF' => 'French (St. Martin)',
        'fr_MG' => 'French (Madagascar)',
        'fr_ML' => 'French (Mali)',
        'fr_MQ' => 'French (Martinique)',
        'fr_MR' => 'French (Mauritania)',
        'fr_MU' => 'French (Mauritius)',
        'fr_NC' => 'French (New Caledonia)',
        'fr_NE' => 'French (Niger)',
        'fr_PF' => 'French (French Polynesia)',
        'fr_PM' => 'French (St. Pierre & Miquelon)',
        'fr_RE' => 'French (Réunion)',
        'fr_RW' => 'French (Rwanda)',
        'fr_SC' => 'French (Seychelles)',
        'fr_SN' => 'French (Senegal)',
        'fr_SY' => 'French (Syria)',
        'fr_TD' => 'French (Chad)',
        'fr_TG' => 'French (Togo)',
        'fr_TN' => 'French (Tunisia)',
        'fr_VU' => 'French (Vanuatu)',
        'fr_WF' => 'French (Wallis & Futuna)',
        'fr_YT' => 'French (Mayotte)',
        'fy' => 'Ọdịda anyanwụ Frisian',
        'fy_NL' => 'Ọdịda anyanwụ Frisian (Netherlands)',
        'ga' => 'Irish',
        'ga_GB' => 'Irish (United Kingdom)',
        'ga_IE' => 'Irish (Ireland)',
        'gd' => 'Asụsụ Scottish Gaelic',
        'gd_GB' => 'Asụsụ Scottish Gaelic (United Kingdom)',
        'gl' => 'Galician',
        'gl_ES' => 'Galician (Spain)',
        'gu' => 'Gujarati',
        'gu_IN' => 'Gujarati (India)',
        'gv' => 'Mansị',
        'gv_IM' => 'Mansị (Isle of Man)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Ghana)',
        'ha_NE' => 'Hausa (Niger)',
        'ha_NG' => 'Hausa (Naịjịrịa)',
        'he' => 'Hebrew',
        'he_IL' => 'Hebrew (Israel)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (India)',
        'hi_Latn' => 'Hindi (Latin)',
        'hi_Latn_IN' => 'Hindi (Latin, India)',
        'hr' => 'Croatian',
        'hr_BA' => 'Croatian (Bosnia & Herzegovina)',
        'hr_HR' => 'Croatian (Croatia)',
        'hu' => 'Hungarian',
        'hu_HU' => 'Hungarian (Hungary)',
        'hy' => 'Asụsụ Armenianị',
        'hy_AM' => 'Asụsụ Armenianị (Armenia)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (Uwa)',
        'id' => 'Indonesian',
        'id_ID' => 'Indonesian (Indonesia)',
        'ie' => 'Interlingue',
        'ie_EE' => 'Interlingue (Estonia)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Naịjịrịa)',
        'ii' => 'Sichuan Yi',
        'ii_CN' => 'Sichuan Yi (China)',
        'is' => 'Icelandic',
        'is_IS' => 'Icelandic (Iceland)',
        'it' => 'Italian',
        'it_CH' => 'Italian (Switzerland)',
        'it_IT' => 'Italian (Italy)',
        'it_SM' => 'Italian (San Marino)',
        'it_VA' => 'Italian (Vatican City)',
        'ja' => 'Japanese',
        'ja_JP' => 'Japanese (Japan)',
        'jv' => 'Javanese',
        'jv_ID' => 'Javanese (Indonesia)',
        'ka' => 'Georgian',
        'ka_GE' => 'Georgian (Georgia)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Kenya)',
        'kk' => 'Kazakh',
        'kk_Arab' => 'Kazakh (Mkpụrụ Okwu Arabic)',
        'kk_Arab_CN' => 'Kazakh (Mkpụrụ Okwu Arabic, China)',
        'kk_Cyrl' => 'Kazakh (Cyrillic)',
        'kk_Cyrl_KZ' => 'Kazakh (Cyrillic, Kazakhstan)',
        'kk_KZ' => 'Kazakh (Kazakhstan)',
        'kl' => 'Kalaallisut',
        'kl_GL' => 'Kalaallisut (Greenland)',
        'km' => 'Khmer',
        'km_KH' => 'Khmer (Cambodia)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (India)',
        'ko' => 'Korean',
        'ko_CN' => 'Korean (China)',
        'ko_KP' => 'Korean (North Korea)',
        'ko_KR' => 'Korean (South Korea)',
        'ks' => 'Kashmiri',
        'ks_Arab' => 'Kashmiri (Mkpụrụ Okwu Arabic)',
        'ks_Arab_IN' => 'Kashmiri (Mkpụrụ Okwu Arabic, India)',
        'ks_Deva' => 'Kashmiri (Mkpụrụ ọkwụ Devangarị)',
        'ks_Deva_IN' => 'Kashmiri (Mkpụrụ ọkwụ Devangarị, India)',
        'ks_IN' => 'Kashmiri (India)',
        'ku' => 'Kurdish',
        'ku_Latn' => 'Kurdish (Latin)',
        'ku_Latn_IQ' => 'Kurdish (Latin, Iraq)',
        'ku_Latn_SY' => 'Kurdish (Latin, Syria)',
        'ku_Latn_TR' => 'Kurdish (Latin, Türkiye)',
        'ku_SY' => 'Kurdish (Syria)',
        'ku_TR' => 'Kurdish (Türkiye)',
        'kw' => 'Cornish',
        'kw_GB' => 'Cornish (United Kingdom)',
        'ky' => 'Kyrgyz',
        'ky_KG' => 'Kyrgyz (Kyrgyzstan)',
        'lb' => 'Luxembourgish',
        'lb_LU' => 'Luxembourgish (Luxembourg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angola)',
        'ln_CD' => 'Lingala (Congo - Kinshasa)',
        'ln_CF' => 'Lingala (Central African Republik)',
        'ln_CG' => 'Lingala (Congo)',
        'lo' => 'Lao',
        'lo_LA' => 'Lao (Laos)',
        'lt' => 'Lithuanian',
        'lt_LT' => 'Lithuanian (Lithuania)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Congo - Kinshasa)',
        'lv' => 'Latvian',
        'lv_LV' => 'Latvian (Latvia)',
        'mg' => 'Malagasy',
        'mg_MG' => 'Malagasy (Madagascar)',
        'mi' => 'Māori',
        'mi_NZ' => 'Māori (New Zealand)',
        'mk' => 'Macedonian',
        'mk_MK' => 'Macedonian (North Macedonia)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (India)',
        'mn' => 'Mọngolịan',
        'mn_MN' => 'Mọngolịan (Mongolia)',
        'mr' => 'Asụsụ Marathi',
        'mr_IN' => 'Asụsụ Marathi (India)',
        'ms' => 'Malay',
        'ms_BN' => 'Malay (Brunei)',
        'ms_ID' => 'Malay (Indonesia)',
        'ms_MY' => 'Malay (Malaysia)',
        'ms_SG' => 'Malay (Singapore)',
        'mt' => 'Asụsụ Malta',
        'mt_MT' => 'Asụsụ Malta (Malta)',
        'my' => 'Burmese',
        'my_MM' => 'Burmese (Myanmar [Burma])',
        'nb' => 'Norwegian Bokmål',
        'nb_NO' => 'Norwegian Bokmål (Norway)',
        'nb_SJ' => 'Norwegian Bokmål (Svalbard & Jan Mayen)',
        'nd' => 'North Ndebele',
        'nd_ZW' => 'North Ndebele (Zimbabwe)',
        'ne' => 'Nepali',
        'ne_IN' => 'Nepali (India)',
        'ne_NP' => 'Nepali (Nepal)',
        'nl' => 'Dutch',
        'nl_AW' => 'Dutch (Aruba)',
        'nl_BE' => 'Dutch (Belgium)',
        'nl_BQ' => 'Dutch (Caribbean Netherlands)',
        'nl_CW' => 'Dutch (Kurakao)',
        'nl_NL' => 'Dutch (Netherlands)',
        'nl_SR' => 'Dutch (Suriname)',
        'nl_SX' => 'Dutch (Sint Maarten)',
        'nn' => 'Norwegian Nynorsk',
        'nn_NO' => 'Norwegian Nynorsk (Norway)',
        'no' => 'Norwegian',
        'no_NO' => 'Norwegian (Norway)',
        'oc' => 'Asụsụ Osịtan',
        'oc_ES' => 'Asụsụ Osịtan (Spain)',
        'oc_FR' => 'Asụsụ Osịtan (France)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Ethiopia)',
        'om_KE' => 'Oromo (Kenya)',
        'or' => 'Ọdịa',
        'or_IN' => 'Ọdịa (India)',
        'os' => 'Ossetic',
        'os_GE' => 'Ossetic (Georgia)',
        'os_RU' => 'Ossetic (Russia)',
        'pa' => 'Punjabi',
        'pa_Arab' => 'Punjabi (Mkpụrụ Okwu Arabic)',
        'pa_Arab_PK' => 'Punjabi (Mkpụrụ Okwu Arabic, Pakistan)',
        'pa_Guru' => 'Punjabi (Mkpụrụ ọkwụ Gụrmụkị)',
        'pa_Guru_IN' => 'Punjabi (Mkpụrụ ọkwụ Gụrmụkị, India)',
        'pa_IN' => 'Punjabi (India)',
        'pa_PK' => 'Punjabi (Pakistan)',
        'pl' => 'Asụsụ Polish',
        'pl_PL' => 'Asụsụ Polish (Poland)',
        'ps' => 'Pashọ',
        'ps_AF' => 'Pashọ (Afghanistan)',
        'ps_PK' => 'Pashọ (Pakistan)',
        'pt' => 'Pọrtụgụese',
        'pt_AO' => 'Pọrtụgụese (Angola)',
        'pt_BR' => 'Pọrtụgụese (Brazil)',
        'pt_CH' => 'Pọrtụgụese (Switzerland)',
        'pt_CV' => 'Pọrtụgụese (Cape Verde)',
        'pt_GQ' => 'Pọrtụgụese (Equatorial Guinea)',
        'pt_GW' => 'Pọrtụgụese (Guinea-Bissau)',
        'pt_LU' => 'Pọrtụgụese (Luxembourg)',
        'pt_MO' => 'Pọrtụgụese (Macao SAR China)',
        'pt_MZ' => 'Pọrtụgụese (Mozambique)',
        'pt_PT' => 'Pọrtụgụese (Portugal)',
        'pt_ST' => 'Pọrtụgụese (São Tomé & Príncipe)',
        'pt_TL' => 'Pọrtụgụese (Timor-Leste)',
        'qu' => 'Asụsụ Quechua',
        'qu_BO' => 'Asụsụ Quechua (Bolivia)',
        'qu_EC' => 'Asụsụ Quechua (Ecuador)',
        'qu_PE' => 'Asụsụ Quechua (Peru)',
        'rm' => 'Asụsụ Romansh',
        'rm_CH' => 'Asụsụ Romansh (Switzerland)',
        'rn' => 'Rundi',
        'rn_BI' => 'Rundi (Burundi)',
        'ro' => 'Asụsụ Romanian',
        'ro_MD' => 'Asụsụ Romanian (Moldova)',
        'ro_RO' => 'Asụsụ Romanian (Romania)',
        'ru' => 'Asụsụ Russia',
        'ru_BY' => 'Asụsụ Russia (Belarus)',
        'ru_KG' => 'Asụsụ Russia (Kyrgyzstan)',
        'ru_KZ' => 'Asụsụ Russia (Kazakhstan)',
        'ru_MD' => 'Asụsụ Russia (Moldova)',
        'ru_RU' => 'Asụsụ Russia (Russia)',
        'ru_UA' => 'Asụsụ Russia (Ukraine)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Rwanda)',
        'sa' => 'Asụsụ Sanskrit',
        'sa_IN' => 'Asụsụ Sanskrit (India)',
        'sc' => 'Asụsụ Sardini',
        'sc_IT' => 'Asụsụ Sardini (Italy)',
        'sd' => 'Asụsụ Sindhi',
        'sd_Arab' => 'Asụsụ Sindhi (Mkpụrụ Okwu Arabic)',
        'sd_Arab_PK' => 'Asụsụ Sindhi (Mkpụrụ Okwu Arabic, Pakistan)',
        'sd_Deva' => 'Asụsụ Sindhi (Mkpụrụ ọkwụ Devangarị)',
        'sd_Deva_IN' => 'Asụsụ Sindhi (Mkpụrụ ọkwụ Devangarị, India)',
        'sd_IN' => 'Asụsụ Sindhi (India)',
        'sd_PK' => 'Asụsụ Sindhi (Pakistan)',
        'se' => 'Northern Sami',
        'se_FI' => 'Northern Sami (Finland)',
        'se_NO' => 'Northern Sami (Norway)',
        'se_SE' => 'Northern Sami (Sweden)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Central African Republik)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (Sri Lanka)',
        'sk' => 'Asụsụ Slovak',
        'sk_SK' => 'Asụsụ Slovak (Slovakia)',
        'sl' => 'Asụsụ Slovenia',
        'sl_SI' => 'Asụsụ Slovenia (Slovenia)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (Zimbabwe)',
        'so' => 'Somali',
        'so_DJ' => 'Somali (Djibouti)',
        'so_ET' => 'Somali (Ethiopia)',
        'so_KE' => 'Somali (Kenya)',
        'so_SO' => 'Somali (Somalia)',
        'sq' => 'Asụsụ Albania',
        'sq_AL' => 'Asụsụ Albania (Albania)',
        'sq_MK' => 'Asụsụ Albania (North Macedonia)',
        'sr' => 'Asụsụ Serbia',
        'sr_BA' => 'Asụsụ Serbia (Bosnia & Herzegovina)',
        'sr_Cyrl' => 'Asụsụ Serbia (Cyrillic)',
        'sr_Cyrl_BA' => 'Asụsụ Serbia (Cyrillic, Bosnia & Herzegovina)',
        'sr_Cyrl_ME' => 'Asụsụ Serbia (Cyrillic, Montenegro)',
        'sr_Cyrl_RS' => 'Asụsụ Serbia (Cyrillic, Serbia)',
        'sr_Latn' => 'Asụsụ Serbia (Latin)',
        'sr_Latn_BA' => 'Asụsụ Serbia (Latin, Bosnia & Herzegovina)',
        'sr_Latn_ME' => 'Asụsụ Serbia (Latin, Montenegro)',
        'sr_Latn_RS' => 'Asụsụ Serbia (Latin, Serbia)',
        'sr_ME' => 'Asụsụ Serbia (Montenegro)',
        'sr_RS' => 'Asụsụ Serbia (Serbia)',
        'st' => 'Southern Sotho',
        'st_LS' => 'Southern Sotho (Lesotho)',
        'st_ZA' => 'Southern Sotho (South Africa)',
        'su' => 'Asụsụ Sundan',
        'su_ID' => 'Asụsụ Sundan (Indonesia)',
        'su_Latn' => 'Asụsụ Sundan (Latin)',
        'su_Latn_ID' => 'Asụsụ Sundan (Latin, Indonesia)',
        'sv' => 'Sụwidiishi',
        'sv_AX' => 'Sụwidiishi (Åland Islands)',
        'sv_FI' => 'Sụwidiishi (Finland)',
        'sv_SE' => 'Sụwidiishi (Sweden)',
        'sw' => 'Asụsụ Swahili',
        'sw_CD' => 'Asụsụ Swahili (Congo - Kinshasa)',
        'sw_KE' => 'Asụsụ Swahili (Kenya)',
        'sw_TZ' => 'Asụsụ Swahili (Tanzania)',
        'sw_UG' => 'Asụsụ Swahili (Uganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (India)',
        'ta_LK' => 'Tamil (Sri Lanka)',
        'ta_MY' => 'Tamil (Malaysia)',
        'ta_SG' => 'Tamil (Singapore)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (India)',
        'tg' => 'Tajik',
        'tg_TJ' => 'Tajik (Tajikistan)',
        'th' => 'Thai',
        'th_TH' => 'Thai (Thailand)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (Eritrea)',
        'ti_ET' => 'Tigrinya (Ethiopia)',
        'tk' => 'Turkmen',
        'tk_TM' => 'Turkmen (Turkmenistan)',
        'tn' => 'Tswana',
        'tn_BW' => 'Tswana (Botswana)',
        'tn_ZA' => 'Tswana (South Africa)',
        'to' => 'Tongan',
        'to_TO' => 'Tongan (Tonga)',
        'tr' => 'Turkish',
        'tr_CY' => 'Turkish (Cyprus)',
        'tr_TR' => 'Turkish (Türkiye)',
        'tt' => 'Asụsụ Tatar',
        'tt_RU' => 'Asụsụ Tatar (Russia)',
        'ug' => 'Uyghur',
        'ug_CN' => 'Uyghur (China)',
        'uk' => 'Asụsụ Ukrain',
        'uk_UA' => 'Asụsụ Ukrain (Ukraine)',
        'ur' => 'Urdu',
        'ur_IN' => 'Urdu (India)',
        'ur_PK' => 'Urdu (Pakistan)',
        'uz' => 'Uzbek',
        'uz_AF' => 'Uzbek (Afghanistan)',
        'uz_Arab' => 'Uzbek (Mkpụrụ Okwu Arabic)',
        'uz_Arab_AF' => 'Uzbek (Mkpụrụ Okwu Arabic, Afghanistan)',
        'uz_Cyrl' => 'Uzbek (Cyrillic)',
        'uz_Cyrl_UZ' => 'Uzbek (Cyrillic, Uzbekistan)',
        'uz_Latn' => 'Uzbek (Latin)',
        'uz_Latn_UZ' => 'Uzbek (Latin, Uzbekistan)',
        'uz_UZ' => 'Uzbek (Uzbekistan)',
        'vi' => 'Vietnamese',
        'vi_VN' => 'Vietnamese (Vietnam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (Senegal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (South Africa)',
        'yi' => 'Yiddish',
        'yi_UA' => 'Yiddish (Ukraine)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Benin)',
        'yo_NG' => 'Yoruba (Naịjịrịa)',
        'za' => 'Zhuang',
        'za_CN' => 'Zhuang (China)',
        'zh' => 'Chaịniiz',
        'zh_CN' => 'Chaịniiz (China)',
        'zh_HK' => 'Chaịniiz (Hong Kong SAR China)',
        'zh_Hans' => 'Chaịniiz (Nke dị mfe)',
        'zh_Hans_CN' => 'Chaịniiz (Nke dị mfe, China)',
        'zh_Hans_HK' => 'Chaịniiz (Nke dị mfe, Hong Kong SAR China)',
        'zh_Hans_MO' => 'Chaịniiz (Nke dị mfe, Macao SAR China)',
        'zh_Hans_MY' => 'Chaịniiz (Nke dị mfe, Malaysia)',
        'zh_Hans_SG' => 'Chaịniiz (Nke dị mfe, Singapore)',
        'zh_Hant' => 'Chaịniiz (Omenala)',
        'zh_Hant_HK' => 'Chaịniiz (Omenala, Hong Kong SAR China)',
        'zh_Hant_MO' => 'Chaịniiz (Omenala, Macao SAR China)',
        'zh_Hant_MY' => 'Chaịniiz (Omenala, Malaysia)',
        'zh_Hant_TW' => 'Chaịniiz (Omenala, Taiwan)',
        'zh_MO' => 'Chaịniiz (Macao SAR China)',
        'zh_SG' => 'Chaịniiz (Singapore)',
        'zh_TW' => 'Chaịniiz (Taiwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (South Africa)',
    ],
];
