<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich Mean Time (Abidjan)',
        'Africa/Accra' => 'Greenwich Mean Time (Accra)',
        'Africa/Addis_Ababa' => 'Ħin ta’ l-Etjopja (Addis Ababa)',
        'Africa/Algiers' => 'Ħin Ċentrali Ewropew (l-Alġier)',
        'Africa/Asmera' => 'Ħin ta’ l-Eritrea (Asmara)',
        'Africa/Asmara' => 'Ħin ta’ l-Eritrea (Asmara)',
        'Africa/Bamako' => 'Greenwich Mean Time (Bamako)',
        'Africa/Bangui' => 'Ħin ta’ ir-Repubblika Ċentru-Afrikana (Bangui)',
        'Africa/Banjul' => 'Greenwich Mean Time (Banjul)',
        'Africa/Bissau' => 'Greenwich Mean Time (Bissau)',
        'Africa/Blantyre' => 'Ħin ta’ il-Malawi (Blantyre)',
        'Africa/Brazzaville' => 'Ħin ta’ il-Kongo - Brazzaville (Brazzaville)',
        'Africa/Bujumbura' => 'Ħin ta’ il-Burundi (Bujumbura)',
        'Africa/Cairo' => 'Ħin ta’ l-Eġittu (Cairo)',
        'Africa/Casablanca' => 'Ħin ta’ il-Marokk (Casablanca)',
        'Africa/Ceuta' => 'Ħin Ċentrali Ewropew (Ceuta)',
        'Africa/Conakry' => 'Greenwich Mean Time (Conakry)',
        'Africa/Dakar' => 'Greenwich Mean Time (Dakar)',
        'Africa/Dar_es_Salaam' => 'Ħin ta’ it-Tanzanija (Dar es Salaam)',
        'Africa/Djibouti' => 'Ħin ta’ il-Djibouti (Djibouti)',
        'Africa/Douala' => 'Ħin ta’ il-Kamerun (Douala)',
        'Africa/El_Aaiun' => 'Ħin ta’ is-Saħara tal-Punent (El Aaiún)',
        'Africa/Freetown' => 'Greenwich Mean Time (Freetown)',
        'Africa/Gaborone' => 'Ħin ta’ il-Botswana (Gaborone)',
        'Africa/Harare' => 'Ħin ta’ iż-Żimbabwe (Harare)',
        'Africa/Johannesburg' => 'Ħin ta’ l-Afrika t’Isfel (Johannesburg)',
        'Africa/Juba' => 'Ħin ta’ is-Sudan t’Isfel (Juba)',
        'Africa/Kampala' => 'Ħin ta’ l-Uganda (Kampala)',
        'Africa/Khartoum' => 'Ħin ta’ is-Sudan (Khartoum)',
        'Africa/Kigali' => 'Ħin ta’ ir-Rwanda (Kigali)',
        'Africa/Kinshasa' => 'Ħin ta’ ir-Repubblika Demokratika tal-Kongo (Kinshasa)',
        'Africa/Lagos' => 'Ħin ta’ in-Niġerja (Lagos)',
        'Africa/Libreville' => 'Ħin ta’ il-Gabon (Libreville)',
        'Africa/Lome' => 'Greenwich Mean Time (Lomé)',
        'Africa/Luanda' => 'Ħin ta’ l-Angola (Luanda)',
        'Africa/Lubumbashi' => 'Ħin ta’ ir-Repubblika Demokratika tal-Kongo (Lubumbashi)',
        'Africa/Lusaka' => 'Ħin ta’ iż-Żambja (Lusaka)',
        'Africa/Malabo' => 'Ħin ta’ il-Guinea Ekwatorjali (Malabo)',
        'Africa/Maputo' => 'Ħin ta’ il-Mozambique (Maputo)',
        'Africa/Maseru' => 'Ħin ta’ il-Lesoto (Maseru)',
        'Africa/Mbabane' => 'Ħin ta’ l-Eswatini (Mbabane)',
        'Africa/Mogadishu' => 'Ħin ta’ is-Somalja (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich Mean Time (Monrovia)',
        'Africa/Nairobi' => 'Ħin ta’ il-Kenja (Nairobi)',
        'Africa/Ndjamena' => 'Ħin ta’ iċ-Chad (N’Djamena)',
        'Africa/Niamey' => 'Ħin ta’ in-Niġer (Niamey)',
        'Africa/Nouakchott' => 'Greenwich Mean Time (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich Mean Time (Ouagadougou)',
        'Africa/Porto-Novo' => 'Ħin ta’ il-Benin (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich Mean Time (São Tomé)',
        'Africa/Tripoli' => 'Ħin ta’ il-Libja (Tripoli)',
        'Africa/Tunis' => 'Ħin Ċentrali Ewropew (Tunis)',
        'Africa/Windhoek' => 'Ħin ta’ in-Namibja (Windhoek)',
        'America/Adak' => 'Ħin ta’ l-Istati Uniti (Adak)',
        'America/Anchorage' => 'Ħin ta’ l-Istati Uniti (Anchorage)',
        'America/Anguilla' => 'Ħin ta’ Anguilla (Anguilla)',
        'America/Antigua' => 'Ħin ta’ Antigua u Barbuda (Antigua)',
        'America/Araguaina' => 'Ħin ta’ Il-Brażil (Araguaína)',
        'America/Argentina/La_Rioja' => 'Ħin ta’ l-Arġentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Ħin ta’ l-Arġentina (Río Gallegos)',
        'America/Argentina/Salta' => 'Ħin ta’ l-Arġentina (Salta)',
        'America/Argentina/San_Juan' => 'Ħin ta’ l-Arġentina (San Juan)',
        'America/Argentina/San_Luis' => 'Ħin ta’ l-Arġentina (San Luis)',
        'America/Argentina/Tucuman' => 'Ħin ta’ l-Arġentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'Ħin ta’ l-Arġentina (Ushuaia)',
        'America/Aruba' => 'Ħin ta’ Aruba (Aruba)',
        'America/Asuncion' => 'Ħin ta’ il-Paragwaj (Asunción)',
        'America/Bahia' => 'Ħin ta’ Il-Brażil (Bahia)',
        'America/Bahia_Banderas' => 'Ħin ta’ il-Messiku (Bahía de Banderas)',
        'America/Barbados' => 'Ħin ta’ Barbados (Barbados)',
        'America/Belem' => 'Ħin ta’ Il-Brażil (Belém)',
        'America/Belize' => 'Ħin ta’ il-Belize (Belize)',
        'America/Blanc-Sablon' => 'Ħin ta’ il-Kanada (Blanc-Sablon)',
        'America/Boa_Vista' => 'Ħin ta’ Il-Brażil (Boa Vista)',
        'America/Bogota' => 'Ħin ta’ il-Kolombja (Bogotá)',
        'America/Boise' => 'Ħin ta’ l-Istati Uniti (Boise)',
        'America/Buenos_Aires' => 'Ħin ta’ l-Arġentina (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Ħin ta’ l-Arġentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Ħin ta’ il-Kanada (Cambridge Bay)',
        'America/Campo_Grande' => 'Ħin ta’ Il-Brażil (Campo Grande)',
        'America/Cancun' => 'Ħin ta’ il-Messiku (Cancún)',
        'America/Caracas' => 'Ħin ta’ il-Venezwela (Caracas)',
        'America/Catamarca' => 'Ħin ta’ l-Arġentina (Catamarca)',
        'America/Argentina/Catamarca' => 'Ħin ta’ l-Arġentina (Catamarca)',
        'America/Cayenne' => 'Ħin ta’ il-Guyana Franċiża (Cayenne)',
        'America/Cayman' => 'Ħin ta’ il-Gżejjer Cayman (Cayman)',
        'America/Chicago' => 'Ħin ta’ l-Istati Uniti (Chicago)',
        'America/Chihuahua' => 'Ħin ta’ il-Messiku (Chihuahua)',
        'America/Ciudad_Juarez' => 'Ħin ta’ il-Messiku (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Ħin ta’ il-Kanada (Atikokan)',
        'America/Atikokan' => 'Ħin ta’ il-Kanada (Atikokan)',
        'America/Cordoba' => 'Ħin ta’ l-Arġentina (Córdoba)',
        'America/Argentina/Cordoba' => 'Ħin ta’ l-Arġentina (Córdoba)',
        'America/Costa_Rica' => 'Ħin ta’ il-Costa Rica (Costa Rica)',
        'America/Coyhaique' => 'Ħin ta’ iċ-Ċili (Coyhaique)',
        'America/Creston' => 'Ħin ta’ il-Kanada (Creston)',
        'America/Cuiaba' => 'Ħin ta’ Il-Brażil (Cuiabá)',
        'America/Curacao' => 'Ħin ta’ Curaçao (Curaçao)',
        'America/Danmarkshavn' => 'Greenwich Mean Time (Danmarkshavn)',
        'America/Dawson' => 'Ħin ta’ il-Kanada (Dawson)',
        'America/Dawson_Creek' => 'Ħin ta’ il-Kanada (Dawson Creek)',
        'America/Denver' => 'Ħin ta’ l-Istati Uniti (Denver)',
        'America/Detroit' => 'Ħin ta’ l-Istati Uniti (Detroit)',
        'America/Dominica' => 'Ħin ta’ Dominica (Dominica)',
        'America/Edmonton' => 'Ħin ta’ il-Kanada (Edmonton)',
        'America/Eirunepe' => 'Ħin ta’ Il-Brażil (Eirunepé)',
        'America/El_Salvador' => 'Ħin ta’ El Salvador (El Salvador)',
        'America/Fort_Nelson' => 'Ħin ta’ il-Kanada (Fort Nelson)',
        'America/Fortaleza' => 'Ħin ta’ Il-Brażil (Fortaleza)',
        'America/Glace_Bay' => 'Ħin ta’ il-Kanada (Glace Bay)',
        'America/Godthab' => 'Ħin ta’ Greenland (Nuuk)',
        'America/Nuuk' => 'Ħin ta’ Greenland (Nuuk)',
        'America/Goose_Bay' => 'Ħin ta’ il-Kanada (Goose Bay)',
        'America/Grand_Turk' => 'Ħin ta’ il-Gżejjer Turks u Caicos (Grand Turk)',
        'America/Grenada' => 'Ħin ta’ Grenada (Grenada)',
        'America/Guadeloupe' => 'Ħin ta’ Guadeloupe (Guadeloupe)',
        'America/Guatemala' => 'Ħin ta’ il-Gwatemala (il-Gwatemala)',
        'America/Guayaquil' => 'Ħin ta’ l-Ekwador (Guayaquil)',
        'America/Guyana' => 'Ħin ta’ il-Guyana (Guyana)',
        'America/Halifax' => 'Ħin ta’ il-Kanada (Halifax)',
        'America/Havana' => 'Ħin ta’ Kuba (Havana)',
        'America/Hermosillo' => 'Ħin ta’ il-Messiku (Hermosillo)',
        'America/Indiana/Knox' => 'Ħin ta’ l-Istati Uniti (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Ħin ta’ l-Istati Uniti (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Ħin ta’ l-Istati Uniti (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Ħin ta’ l-Istati Uniti (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Ħin ta’ l-Istati Uniti (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Ħin ta’ l-Istati Uniti (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Ħin ta’ l-Istati Uniti (Winamac, Indiana)',
        'America/Indianapolis' => 'Ħin ta’ l-Istati Uniti (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Ħin ta’ l-Istati Uniti (Indianapolis)',
        'America/Inuvik' => 'Ħin ta’ il-Kanada (Inuvik)',
        'America/Iqaluit' => 'Ħin ta’ il-Kanada (Iqaluit)',
        'America/Jamaica' => 'Ħin ta’ il-Ġamajka (il-Ġamajka)',
        'America/Jujuy' => 'Ħin ta’ l-Arġentina (Jujuy)',
        'America/Argentina/Jujuy' => 'Ħin ta’ l-Arġentina (Jujuy)',
        'America/Juneau' => 'Ħin ta’ l-Istati Uniti (Juneau)',
        'America/Kentucky/Monticello' => 'Ħin ta’ l-Istati Uniti (Monticello, Kentucky)',
        'America/Kralendijk' => 'Ħin ta’ in-Netherlands tal-Karibew (Kralendijk)',
        'America/La_Paz' => 'Ħin ta’ il-Bolivja (La Paz)',
        'America/Lima' => 'Ħin ta’ il-Perù (Lima)',
        'America/Los_Angeles' => 'Ħin ta’ l-Istati Uniti (Los Angeles)',
        'America/Louisville' => 'Ħin ta’ l-Istati Uniti (Louisville)',
        'America/Kentucky/Louisville' => 'Ħin ta’ l-Istati Uniti (Louisville)',
        'America/Lower_Princes' => 'Ħin ta’ Sint Maarten (Lower Prince’s Quarter)',
        'America/Maceio' => 'Ħin ta’ Il-Brażil (Maceió)',
        'America/Managua' => 'Ħin ta’ in-Nikaragwa (Managua)',
        'America/Manaus' => 'Ħin ta’ Il-Brażil (Manaus)',
        'America/Marigot' => 'Ħin ta’ Saint Martin (Marigot)',
        'America/Martinique' => 'Ħin ta’ Martinique (Martinique)',
        'America/Matamoros' => 'Ħin ta’ il-Messiku (Matamoros)',
        'America/Mazatlan' => 'Ħin ta’ il-Messiku (Mazatlán)',
        'America/Mendoza' => 'Ħin ta’ l-Arġentina (Mendoza)',
        'America/Argentina/Mendoza' => 'Ħin ta’ l-Arġentina (Mendoza)',
        'America/Menominee' => 'Ħin ta’ l-Istati Uniti (Menominee)',
        'America/Merida' => 'Ħin ta’ il-Messiku (Mérida)',
        'America/Metlakatla' => 'Ħin ta’ l-Istati Uniti (Metlakatla)',
        'America/Mexico_City' => 'Ħin ta’ il-Messiku (Ciudad de México)',
        'America/Miquelon' => 'Ħin ta’ Saint Pierre u Miquelon (Saint-Pierre)',
        'America/Moncton' => 'Ħin ta’ il-Kanada (Moncton)',
        'America/Monterrey' => 'Ħin ta’ il-Messiku (Monterrey)',
        'America/Montevideo' => 'Ħin ta’ l-Urugwaj (Montevideo)',
        'America/Montserrat' => 'Ħin ta’ Montserrat (Montserrat)',
        'America/Nassau' => 'Ħin ta’ il-Bahamas (Nassau)',
        'America/New_York' => 'Ħin ta’ l-Istati Uniti (New York)',
        'America/Nome' => 'Ħin ta’ l-Istati Uniti (Nome)',
        'America/Noronha' => 'Ħin ta’ Il-Brażil (Fernando de Noronha)',
        'America/North_Dakota/Beulah' => 'Ħin ta’ l-Istati Uniti (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'Ħin ta’ l-Istati Uniti (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'Ħin ta’ l-Istati Uniti (New Salem, North Dakota)',
        'America/Ojinaga' => 'Ħin ta’ il-Messiku (Ojinaga)',
        'America/Panama' => 'Ħin ta’ il-Panama (Panama)',
        'America/Paramaribo' => 'Ħin ta’ is-Suriname (Paramaribo)',
        'America/Phoenix' => 'Ħin ta’ l-Istati Uniti (Phoenix)',
        'America/Port-au-Prince' => 'Ħin ta’ il-Haiti (Port-au-Prince)',
        'America/Port_of_Spain' => 'Ħin ta’ Trinidad u Tobago (Port of Spain)',
        'America/Porto_Velho' => 'Ħin ta’ Il-Brażil (Porto Velho)',
        'America/Puerto_Rico' => 'Ħin ta’ Puerto Rico (Puerto Rico)',
        'America/Punta_Arenas' => 'Ħin ta’ iċ-Ċili (Punta Arenas)',
        'America/Rankin_Inlet' => 'Ħin ta’ il-Kanada (Rankin Inlet)',
        'America/Recife' => 'Ħin ta’ Il-Brażil (Recife)',
        'America/Regina' => 'Ħin ta’ il-Kanada (Regina)',
        'America/Resolute' => 'Ħin ta’ il-Kanada (Resolute)',
        'America/Rio_Branco' => 'Ħin ta’ Il-Brażil (Rio Branco)',
        'America/Santarem' => 'Ħin ta’ Il-Brażil (Santarém)',
        'America/Santiago' => 'Ħin ta’ iċ-Ċili (Santiago)',
        'America/Santo_Domingo' => 'Ħin ta’ ir-Repubblika Dominicana (Santo Domingo)',
        'America/Sao_Paulo' => 'Ħin ta’ Il-Brażil (São Paulo)',
        'America/Scoresbysund' => 'Ħin ta’ Greenland (Ittoqqortoormiit)',
        'America/Sitka' => 'Ħin ta’ l-Istati Uniti (Sitka)',
        'America/St_Barthelemy' => 'Ħin ta’ Saint Barthélemy (St. Barthélemy)',
        'America/St_Johns' => 'Ħin ta’ il-Kanada (St. John’s)',
        'America/St_Kitts' => 'Ħin ta’ Saint Kitts u Nevis (St. Kitts)',
        'America/St_Lucia' => 'Ħin ta’ Saint Lucia (St. Lucia)',
        'America/St_Thomas' => 'Ħin ta’ il-Gżejjer Verġni tal-Istati Uniti (St. Thomas)',
        'America/St_Vincent' => 'Ħin ta’ Saint Vincent u l-Grenadini (St. Vincent)',
        'America/Swift_Current' => 'Ħin ta’ il-Kanada (Swift Current)',
        'America/Tegucigalpa' => 'Ħin ta’ il-Honduras (Tegucigalpa)',
        'America/Thule' => 'Ħin ta’ Greenland (Thule)',
        'America/Tijuana' => 'Ħin ta’ il-Messiku (Tijuana)',
        'America/Toronto' => 'Ħin ta’ il-Kanada (Toronto)',
        'America/Tortola' => 'Ħin ta’ il-Gżejjer Verġni Brittaniċi (Tortola)',
        'America/Vancouver' => 'Ħin ta’ il-Kanada (Vancouver)',
        'America/Whitehorse' => 'Ħin ta’ il-Kanada (Whitehorse)',
        'America/Winnipeg' => 'Ħin ta’ il-Kanada (Winnipeg)',
        'America/Yakutat' => 'Ħin ta’ l-Istati Uniti (Yakutat)',
        'Antarctica/Casey' => 'Ħin ta’ l-Antartika (Casey)',
        'Antarctica/Davis' => 'Ħin ta’ l-Antartika (Davis)',
        'Antarctica/DumontDUrville' => 'Ħin ta’ l-Antartika (Dumont-d’Urville)',
        'Antarctica/Macquarie' => 'Ħin ta’ l-Awstralja (Macquarie)',
        'Antarctica/Mawson' => 'Ħin ta’ l-Antartika (Mawson)',
        'Antarctica/McMurdo' => 'Ħin ta’ l-Antartika (McMurdo)',
        'Antarctica/Palmer' => 'Ħin ta’ l-Antartika (Palmer)',
        'Antarctica/Rothera' => 'Ħin ta’ l-Antartika (Rothera)',
        'Antarctica/Syowa' => 'Ħin ta’ l-Antartika (Showa)',
        'Antarctica/Troll' => 'Greenwich Mean Time (Troll)',
        'Antarctica/Vostok' => 'Ħin ta’ l-Antartika (Vostok)',
        'Arctic/Longyearbyen' => 'Ħin Ċentrali Ewropew (Longyearbyen)',
        'Asia/Aden' => 'Ħin ta’ il-Jemen (Aden)',
        'Asia/Almaty' => 'Ħin ta’ il-Każakistan (Almaty)',
        'Asia/Amman' => 'Ħin ta’ il-Ġordan (Amman)',
        'Asia/Anadyr' => 'Ħin ta’ ir-Russja (Anadyr)',
        'Asia/Aqtau' => 'Ħin ta’ il-Każakistan (Aqtau)',
        'Asia/Aqtobe' => 'Ħin ta’ il-Każakistan (Aqtobe)',
        'Asia/Ashgabat' => 'Ħin ta’ it-Turkmenistan (Ashgabat)',
        'Asia/Atyrau' => 'Ħin ta’ il-Każakistan (Atyrau)',
        'Asia/Baghdad' => 'Ħin ta’ l-Iraq (Baghdad)',
        'Asia/Bahrain' => 'Ħin ta’ il-Bahrain (Bahrain)',
        'Asia/Baku' => 'Ħin ta’ l-Ażerbajġan (Baku)',
        'Asia/Bangkok' => 'Ħin ta’ it-Tajlandja (Bangkok)',
        'Asia/Barnaul' => 'Ħin ta’ ir-Russja (Barnaul)',
        'Asia/Beirut' => 'Ħin ta’ il-Libanu (Bejrut)',
        'Asia/Bishkek' => 'Ħin ta’ il-Kirgiżistan (Bishkek)',
        'Asia/Brunei' => 'Ħin ta’ il-Brunei (Brunei)',
        'Asia/Calcutta' => 'Ħin ta’ l-Indja (Kolkata)',
        'Asia/Kolkata' => 'Ħin ta’ l-Indja (Kolkata)',
        'Asia/Chita' => 'Ħin ta’ ir-Russja (Chita)',
        'Asia/Colombo' => 'Ħin ta’ is-Sri Lanka (Colombo)',
        'Asia/Damascus' => 'Ħin ta’ is-Sirja (Damasku)',
        'Asia/Dhaka' => 'Ħin ta’ il-Bangladesh (Dhaka)',
        'Asia/Dili' => 'Ħin ta’ Timor Leste (Dili)',
        'Asia/Dubai' => 'Ħin ta’ l-Emirati Għarab Magħquda (Dubai)',
        'Asia/Dushanbe' => 'Ħin ta’ it-Taġikistan (Dushanbe)',
        'Asia/Famagusta' => 'Ħin ta’ Ċipru (Famagusta)',
        'Asia/Gaza' => 'Ħin ta’ it-Territorji Palestinjani (Gaza)',
        'Asia/Hebron' => 'Ħin ta’ it-Territorji Palestinjani (Hebron)',
        'Asia/Hong_Kong' => 'Ħin ta’ ir-Reġjun Amministrattiv Speċjali ta’ Hong Kong tar-Repubblika tal-Poplu taċ-Ċina (Hong Kong)',
        'Asia/Hovd' => 'Ħin ta’ il-Mongolja (Khovd)',
        'Asia/Irkutsk' => 'Ħin ta’ ir-Russja (Irkutsk)',
        'Asia/Jakarta' => 'Ħin ta’ l-Indoneżja (Jakarta)',
        'Asia/Jayapura' => 'Ħin ta’ l-Indoneżja (Jayapura)',
        'Asia/Jerusalem' => 'Ħin ta’ Iżrael (Ġerusalemm)',
        'Asia/Kabul' => 'Ħin ta’ l-Afganistan (Kabul)',
        'Asia/Kamchatka' => 'Ħin ta’ ir-Russja (Kamchatka)',
        'Asia/Karachi' => 'Ħin ta’ il-Pakistan (Karachi)',
        'Asia/Katmandu' => 'Ħin ta’ in-Nepal (Kathmandu)',
        'Asia/Kathmandu' => 'Ħin ta’ in-Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Ħin ta’ ir-Russja (Khandyga)',
        'Asia/Krasnoyarsk' => 'Ħin ta’ ir-Russja (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'Ħin ta’ il-Malasja (Kuala Lumpur)',
        'Asia/Kuching' => 'Ħin ta’ il-Malasja (Kuching)',
        'Asia/Kuwait' => 'Ħin ta’ il-Kuwajt (il-Belt tal-Kuwajt)',
        'Asia/Macau' => 'Ħin ta’ ir-Reġjun Amministrattiv Speċjali tal-Macao tar-Repubblika tal-Poplu taċ-Ċina (Macau)',
        'Asia/Magadan' => 'Ħin ta’ ir-Russja (Magadan)',
        'Asia/Makassar' => 'Ħin ta’ l-Indoneżja (Makassar)',
        'Asia/Manila' => 'Ħin ta’ il-Filippini (Manila)',
        'Asia/Muscat' => 'Ħin ta’ l-Oman (Muscat)',
        'Asia/Nicosia' => 'Ħin ta’ Ċipru (Nikosija)',
        'Asia/Novokuznetsk' => 'Ħin ta’ ir-Russja (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Ħin ta’ ir-Russja (Novosibirsk)',
        'Asia/Omsk' => 'Ħin ta’ ir-Russja (Omsk)',
        'Asia/Oral' => 'Ħin ta’ il-Każakistan (Oral)',
        'Asia/Phnom_Penh' => 'Ħin ta’ il-Kambodja (Phnom Penh)',
        'Asia/Pontianak' => 'Ħin ta’ l-Indoneżja (Pontianak)',
        'Asia/Pyongyang' => 'Ħin ta’ il-Korea ta’ Fuq (Pyongyang)',
        'Asia/Qatar' => 'Ħin ta’ il-Qatar (Qatar)',
        'Asia/Qostanay' => 'Ħin ta’ il-Każakistan (Qostanay)',
        'Asia/Qyzylorda' => 'Ħin ta’ il-Każakistan (Qyzylorda)',
        'Asia/Rangoon' => 'Ħin ta’ il-Myanmar/Burma (Rangoon)',
        'Asia/Yangon' => 'Ħin ta’ il-Myanmar/Burma (Rangoon)',
        'Asia/Riyadh' => 'Ħin ta’ l-Arabja Sawdija (Riyadh)',
        'Asia/Saigon' => 'Ħin ta’ il-Vjetnam (Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'Ħin ta’ il-Vjetnam (Ho Chi Minh)',
        'Asia/Sakhalin' => 'Ħin ta’ ir-Russja (Sakhalin)',
        'Asia/Samarkand' => 'Ħin ta’ l-Użbekistan (Samarkand)',
        'Asia/Seoul' => 'Ħin ta’ il-Korea t’Isfel (Seoul)',
        'Asia/Shanghai' => 'Ħin ta’ iċ-Ċina (Shanghai)',
        'Asia/Singapore' => 'Ħin ta’ Singapore (Singapore)',
        'Asia/Srednekolymsk' => 'Ħin ta’ ir-Russja (Srednekolymsk)',
        'Asia/Taipei' => 'Ħin ta’ it-Tajwan (Taipei)',
        'Asia/Tashkent' => 'Ħin ta’ l-Użbekistan (Tashkent)',
        'Asia/Tbilisi' => 'Ħin ta’ il-Georgia (Tbilisi)',
        'Asia/Tehran' => 'Ħin ta’ l-Iran (Tehran)',
        'Asia/Thimphu' => 'Ħin ta’ il-Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Ħin ta’ il-Ġappun (Tokyo)',
        'Asia/Tomsk' => 'Ħin ta’ ir-Russja (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ħin ta’ il-Mongolja (Ulaanbaatar)',
        'Asia/Urumqi' => 'Ħin ta’ iċ-Ċina (Ürümqi)',
        'Asia/Ust-Nera' => 'Ħin ta’ ir-Russja (Ust-Nera)',
        'Asia/Vientiane' => 'Ħin ta’ il-Laos (Vientiane)',
        'Asia/Vladivostok' => 'Ħin ta’ ir-Russja (Vladivostok)',
        'Asia/Yakutsk' => 'Ħin ta’ ir-Russja (Yakutsk)',
        'Asia/Yekaterinburg' => 'Ħin ta’ ir-Russja (Yekaterinburg)',
        'Asia/Yerevan' => 'Ħin ta’ l-Armenja (Yerevan)',
        'Atlantic/Azores' => 'Ħin ta’ il-Portugall (Azores)',
        'Atlantic/Bermuda' => 'Ħin ta’ Bermuda (Bermuda)',
        'Atlantic/Canary' => 'Ħin ta’ Spanja (Canarias)',
        'Atlantic/Cape_Verde' => 'Ħin ta’ Cape Verde (Cape Verde)',
        'Atlantic/Faeroe' => 'Ħin ta’ il-Gżejjer Faeroe (Faroe)',
        'Atlantic/Faroe' => 'Ħin ta’ il-Gżejjer Faeroe (Faroe)',
        'Atlantic/Madeira' => 'Ħin ta’ il-Portugall (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich Mean Time (Reykjavik)',
        'Atlantic/South_Georgia' => 'Ħin ta’ il-Georgia tan-Nofsinhar u l-Gżejjer Sandwich tan-Nofsinhar (il-Georgia tan-Nofsinhar)',
        'Atlantic/St_Helena' => 'Greenwich Mean Time (St. Helena)',
        'Atlantic/Stanley' => 'Ħin ta’ il-Gżejjer Falkland (Stanley)',
        'Australia/Adelaide' => 'Ħin ta’ l-Awstralja (Adelaide)',
        'Australia/Brisbane' => 'Ħin ta’ l-Awstralja (Brisbane)',
        'Australia/Broken_Hill' => 'Ħin ta’ l-Awstralja (Broken Hill)',
        'Australia/Darwin' => 'Ħin ta’ l-Awstralja (Darwin)',
        'Australia/Eucla' => 'Ħin ta’ l-Awstralja (Eucla)',
        'Australia/Hobart' => 'Ħin ta’ l-Awstralja (Hobart)',
        'Australia/Lindeman' => 'Ħin ta’ l-Awstralja (Lindeman)',
        'Australia/Lord_Howe' => 'Ħin ta’ l-Awstralja (Lord Howe)',
        'Australia/Melbourne' => 'Ħin ta’ l-Awstralja (Melbourne)',
        'Australia/Perth' => 'Ħin ta’ l-Awstralja (Perth)',
        'Australia/Sydney' => 'Ħin ta’ l-Awstralja (Sydney)',
        'Etc/GMT' => 'Greenwich Mean Time',
        'Europe/Amsterdam' => 'Ħin Ċentrali Ewropew (Amsterdam)',
        'Europe/Andorra' => 'Ħin Ċentrali Ewropew (Andorra)',
        'Europe/Astrakhan' => 'Ħin ta’ ir-Russja (Astrakhan)',
        'Europe/Athens' => 'Ħin ta’ il-Greċja (Ateni)',
        'Europe/Belgrade' => 'Ħin Ċentrali Ewropew (Belgrad)',
        'Europe/Berlin' => 'Ħin Ċentrali Ewropew (Berlin)',
        'Europe/Bratislava' => 'Ħin Ċentrali Ewropew (Bratislava)',
        'Europe/Brussels' => 'Ħin Ċentrali Ewropew (Brussell)',
        'Europe/Bucharest' => 'Ħin ta’ ir-Rumanija (Bucharest)',
        'Europe/Budapest' => 'Ħin Ċentrali Ewropew (Budapest)',
        'Europe/Busingen' => 'Ħin Ċentrali Ewropew (Büsingen)',
        'Europe/Chisinau' => 'Ħin ta’ il-Moldova (Chișinău)',
        'Europe/Copenhagen' => 'Ħin Ċentrali Ewropew (Copenhagen)',
        'Europe/Dublin' => 'Greenwich Mean Time (Dublin)',
        'Europe/Gibraltar' => 'Ħin Ċentrali Ewropew (Ġibiltà)',
        'Europe/Guernsey' => 'Greenwich Mean Time (Guernsey)',
        'Europe/Helsinki' => 'Ħin ta’ il-Finlandja (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwich Mean Time (Isle of Man)',
        'Europe/Istanbul' => 'Ħin ta’ it-Turkija (Istanbul)',
        'Europe/Jersey' => 'Greenwich Mean Time (Jersey)',
        'Europe/Kaliningrad' => 'Ħin ta’ ir-Russja (Kaliningrad)',
        'Europe/Kiev' => 'Ħin ta’ l-Ukrajna (Kyiv)',
        'Europe/Kyiv' => 'Ħin ta’ l-Ukrajna (Kyiv)',
        'Europe/Kirov' => 'Ħin ta’ ir-Russja (Kirov)',
        'Europe/Lisbon' => 'Ħin ta’ il-Portugall (Liżbona)',
        'Europe/Ljubljana' => 'Ħin Ċentrali Ewropew (Ljubljana)',
        'Europe/London' => 'Greenwich Mean Time (Londra)',
        'Europe/Luxembourg' => 'Ħin Ċentrali Ewropew (il-Lussemburgu)',
        'Europe/Madrid' => 'Ħin Ċentrali Ewropew (Madrid)',
        'Europe/Malta' => 'Ħin Ċentrali Ewropew (Valletta)',
        'Europe/Mariehamn' => 'Ħin ta’ il-Gżejjer Aland (Mariehamn)',
        'Europe/Minsk' => 'Ħin ta’ il-Belarussja (Minsk)',
        'Europe/Monaco' => 'Ħin Ċentrali Ewropew (Monaco)',
        'Europe/Moscow' => 'Ħin ta’ ir-Russja (Moska)',
        'Europe/Oslo' => 'Ħin Ċentrali Ewropew (Oslo)',
        'Europe/Paris' => 'Ħin Ċentrali Ewropew (Pariġi)',
        'Europe/Podgorica' => 'Ħin Ċentrali Ewropew (Podgorica)',
        'Europe/Prague' => 'Ħin Ċentrali Ewropew (Praga)',
        'Europe/Riga' => 'Ħin ta’ il-Latvja (Riga)',
        'Europe/Rome' => 'Ħin Ċentrali Ewropew (Ruma)',
        'Europe/Samara' => 'Ħin ta’ ir-Russja (Samara)',
        'Europe/San_Marino' => 'Ħin Ċentrali Ewropew (San Marino)',
        'Europe/Sarajevo' => 'Ħin Ċentrali Ewropew (Sarajevo)',
        'Europe/Saratov' => 'Ħin ta’ ir-Russja (Saratov)',
        'Europe/Simferopol' => 'Ħin ta’ l-Ukrajna (Simferopol)',
        'Europe/Skopje' => 'Ħin Ċentrali Ewropew (Skopje)',
        'Europe/Sofia' => 'Ħin ta’ il-Bulgarija (Sofija)',
        'Europe/Stockholm' => 'Ħin Ċentrali Ewropew (Stokkolma)',
        'Europe/Tallinn' => 'Ħin ta’ l-Estonja (Tallinn)',
        'Europe/Tirane' => 'Ħin Ċentrali Ewropew (Tirana)',
        'Europe/Ulyanovsk' => 'Ħin ta’ ir-Russja (Ulyanovsk)',
        'Europe/Vaduz' => 'Ħin Ċentrali Ewropew (Vaduz)',
        'Europe/Vatican' => 'Ħin Ċentrali Ewropew (il-Belt tal-Vatikan)',
        'Europe/Vienna' => 'Ħin Ċentrali Ewropew (Vjenna)',
        'Europe/Vilnius' => 'Ħin ta’ il-Litwanja (Vilnius)',
        'Europe/Volgograd' => 'Ħin ta’ ir-Russja (Volgograd)',
        'Europe/Warsaw' => 'Ħin Ċentrali Ewropew (Varsavja)',
        'Europe/Zagreb' => 'Ħin Ċentrali Ewropew (Zagreb)',
        'Europe/Zurich' => 'Ħin Ċentrali Ewropew (Zurich)',
        'Indian/Antananarivo' => 'Ħin ta’ Madagascar (Antananarivo)',
        'Indian/Christmas' => 'Ħin ta’ il-Gżira Christmas (Christmas)',
        'Indian/Cocos' => 'Ħin ta’ Gżejjer Cocos (Keeling) (Cocos)',
        'Indian/Comoro' => 'Ħin ta’ Comoros (Comores)',
        'Indian/Kerguelen' => 'Ħin ta’ It-Territorji Franċiżi tan-Nofsinhar (Kerguelen)',
        'Indian/Mahe' => 'Ħin ta’ is-Seychelles (Mahé)',
        'Indian/Maldives' => 'Ħin ta’ il-Maldivi (il-Maldivi)',
        'Indian/Mauritius' => 'Ħin ta’ Mauritius (Mauritius)',
        'Indian/Mayotte' => 'Ħin ta’ Mayotte (Mayotte)',
        'Indian/Reunion' => 'Ħin ta’ Réunion (Réunion)',
        'Pacific/Apia' => 'Ħin ta’ Samoa (Apia)',
        'Pacific/Auckland' => 'Ħin ta’ New Zealand (Auckland)',
        'Pacific/Bougainville' => 'Ħin ta’ Papua New Guinea (Bougainville)',
        'Pacific/Chatham' => 'Ħin ta’ New Zealand (Chatham)',
        'Pacific/Easter' => 'Ħin ta’ iċ-Ċili (Easter)',
        'Pacific/Efate' => 'Ħin ta’ Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Ħin ta’ Kiribati (Canton)',
        'Pacific/Kanton' => 'Ħin ta’ Kiribati (Canton)',
        'Pacific/Fakaofo' => 'Ħin ta’ it-Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Ħin ta’ Fiġi (Fiji)',
        'Pacific/Funafuti' => 'Ħin ta’ Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Ħin ta’ l-Ekwador (Galápagos)',
        'Pacific/Gambier' => 'Ħin ta’ Polineżja Franċiża (Gambier)',
        'Pacific/Guadalcanal' => 'Ħin ta’ il-Gżejjer Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Ħin ta’ Guam (Guam)',
        'Pacific/Honolulu' => 'Ħin ta’ l-Istati Uniti (Honolulu)',
        'Pacific/Kiritimati' => 'Ħin ta’ Kiribati (Kiritimati)',
        'Pacific/Kosrae' => 'Ħin ta’ il-Mikroneżja (Kosrae)',
        'Pacific/Kwajalein' => 'Ħin ta’ Gżejjer Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Ħin ta’ Gżejjer Marshall (Majuro)',
        'Pacific/Marquesas' => 'Ħin ta’ Polineżja Franċiża (Marquesas)',
        'Pacific/Midway' => 'Ħin ta’ Il-Gżejjer Minuri Mbiegħda tal-Istati Uniti (Midway)',
        'Pacific/Nauru' => 'Ħin ta’ Nauru (Nauru)',
        'Pacific/Niue' => 'Ħin ta’ Niue (Niue)',
        'Pacific/Norfolk' => 'Ħin ta’ Gżira Norfolk (Norfolk)',
        'Pacific/Noumea' => 'Ħin ta’ New Caledonia (Nouméa)',
        'Pacific/Pago_Pago' => 'Ħin ta’ is-Samoa Amerikana (Pago Pago)',
        'Pacific/Palau' => 'Ħin ta’ Palau (Palau)',
        'Pacific/Pitcairn' => 'Ħin ta’ Gżejjer Pitcairn (Pitcairn)',
        'Pacific/Ponape' => 'Ħin ta’ il-Mikroneżja (Pohnpei)',
        'Pacific/Pohnpei' => 'Ħin ta’ il-Mikroneżja (Pohnpei)',
        'Pacific/Port_Moresby' => 'Ħin ta’ Papua New Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Ħin ta’ Gżejjer Cook (Rarotonga)',
        'Pacific/Saipan' => 'Ħin ta’ Ġżejjer Mariana tat-Tramuntana (Saipan)',
        'Pacific/Tahiti' => 'Ħin ta’ Polineżja Franċiża (Tahiti)',
        'Pacific/Tarawa' => 'Ħin ta’ Kiribati (Tarawa)',
        'Pacific/Tongatapu' => 'Ħin ta’ Tonga (Tongatapu)',
        'Pacific/Truk' => 'Ħin ta’ il-Mikroneżja (Chuuk)',
        'Pacific/Chuuk' => 'Ħin ta’ il-Mikroneżja (Chuuk)',
        'Pacific/Wake' => 'Ħin ta’ Il-Gżejjer Minuri Mbiegħda tal-Istati Uniti (Wake)',
        'Pacific/Wallis' => 'Ħin ta’ Wallis u Futuna (Wallis & Futuna)',
    ],
    'Meta' => [],
];
