<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ግሪንዊች ማዕከላዊ ሰዓት (አቢጃን)',
        'Africa/Accra' => 'ግሪንዊች ማዕከላዊ ሰዓት (አክራ)',
        'Africa/Addis_Ababa' => 'የምስራቅ አፍሪካ ሰዓት (አዲስ አበባ)',
        'Africa/Algiers' => 'የመካከለኛው አውሮፓ ሰዓት (አልጀርስ)',
        'Africa/Asmera' => 'የምስራቅ አፍሪካ ሰዓት (አስመራ)',
        'Africa/Asmara' => 'የምስራቅ አፍሪካ ሰዓት (አስመራ)',
        'Africa/Bamako' => 'ግሪንዊች ማዕከላዊ ሰዓት (ባማኮ)',
        'Africa/Bangui' => 'የምዕራብ አፍሪካ ሰዓት (ባንጉኢ)',
        'Africa/Banjul' => 'ግሪንዊች ማዕከላዊ ሰዓት (ባንጁል)',
        'Africa/Bissau' => 'ግሪንዊች ማዕከላዊ ሰዓት (ቢሳኦ)',
        'Africa/Blantyre' => 'የመካከለኛው አፍሪካ ሰዓት (ብላንታየር)',
        'Africa/Brazzaville' => 'የምዕራብ አፍሪካ ሰዓት (ብራዛቪል)',
        'Africa/Bujumbura' => 'የመካከለኛው አፍሪካ ሰዓት (ቡጁምብራ)',
        'Africa/Cairo' => 'የምስራቃዊ አውሮፓ ሰዓት (ካይሮ)',
        'Africa/Casablanca' => 'የምዕራባዊ አውሮፓ ሰዓት (ካዛብላንካ)',
        'Africa/Ceuta' => 'የመካከለኛው አውሮፓ ሰዓት (ሲኡታ)',
        'Africa/Conakry' => 'ግሪንዊች ማዕከላዊ ሰዓት (ኮናክሬ)',
        'Africa/Dakar' => 'ግሪንዊች ማዕከላዊ ሰዓት (ዳካር)',
        'Africa/Dar_es_Salaam' => 'የምስራቅ አፍሪካ ሰዓት (ዳሬ ሰላም)',
        'Africa/Djibouti' => 'የምስራቅ አፍሪካ ሰዓት (ጅቡቲ)',
        'Africa/Douala' => 'የምዕራብ አፍሪካ ሰዓት (ዱአላ)',
        'Africa/El_Aaiun' => 'የምዕራባዊ አውሮፓ ሰዓት (ኤል አዩአን)',
        'Africa/Freetown' => 'ግሪንዊች ማዕከላዊ ሰዓት (ፍሪታውን)',
        'Africa/Gaborone' => 'የመካከለኛው አፍሪካ ሰዓት (ጋቦሮን)',
        'Africa/Harare' => 'የመካከለኛው አፍሪካ ሰዓት (ሃራሬ)',
        'Africa/Johannesburg' => 'የደቡብ አፍሪካ መደበኛ ሰዓት (ጆሃንስበርግ)',
        'Africa/Juba' => 'የመካከለኛው አፍሪካ ሰዓት (ጁባ)',
        'Africa/Kampala' => 'የምስራቅ አፍሪካ ሰዓት (ካምፓላ)',
        'Africa/Khartoum' => 'የመካከለኛው አፍሪካ ሰዓት (ካርቱም)',
        'Africa/Kigali' => 'የመካከለኛው አፍሪካ ሰዓት (ኪጋሊ)',
        'Africa/Kinshasa' => 'የምዕራብ አፍሪካ ሰዓት (ኪንሻሳ)',
        'Africa/Lagos' => 'የምዕራብ አፍሪካ ሰዓት (ሌጎስ)',
        'Africa/Libreville' => 'የምዕራብ አፍሪካ ሰዓት (ሊበርቪል)',
        'Africa/Lome' => 'ግሪንዊች ማዕከላዊ ሰዓት (ሎሜ)',
        'Africa/Luanda' => 'የምዕራብ አፍሪካ ሰዓት (ሉአንዳ)',
        'Africa/Lubumbashi' => 'የመካከለኛው አፍሪካ ሰዓት (ሉቡምባሺ)',
        'Africa/Lusaka' => 'የመካከለኛው አፍሪካ ሰዓት (ሉሳካ)',
        'Africa/Malabo' => 'የምዕራብ አፍሪካ ሰዓት (ማላቡ)',
        'Africa/Maputo' => 'የመካከለኛው አፍሪካ ሰዓት (ማፑቱ)',
        'Africa/Maseru' => 'የደቡብ አፍሪካ መደበኛ ሰዓት (ማሴሩ)',
        'Africa/Mbabane' => 'የደቡብ አፍሪካ መደበኛ ሰዓት (ምባባኔ)',
        'Africa/Mogadishu' => 'የምስራቅ አፍሪካ ሰዓት (ሞቃዲሹ)',
        'Africa/Monrovia' => 'ግሪንዊች ማዕከላዊ ሰዓት (ሞንሮቪያ)',
        'Africa/Nairobi' => 'የምስራቅ አፍሪካ ሰዓት (ናይሮቢ)',
        'Africa/Ndjamena' => 'የምዕራብ አፍሪካ ሰዓት (ንጃሜና)',
        'Africa/Niamey' => 'የምዕራብ አፍሪካ ሰዓት (ኒያሜይ)',
        'Africa/Nouakchott' => 'ግሪንዊች ማዕከላዊ ሰዓት (ኑአክቾት)',
        'Africa/Ouagadougou' => 'ግሪንዊች ማዕከላዊ ሰዓት (ኡጋዱጉ)',
        'Africa/Porto-Novo' => 'የምዕራብ አፍሪካ ሰዓት (ፖርቶ - ኖቮ)',
        'Africa/Sao_Tome' => 'ግሪንዊች ማዕከላዊ ሰዓት (ሳኦ ቶሜ)',
        'Africa/Tripoli' => 'የምስራቃዊ አውሮፓ ሰዓት (ትሪፖሊ)',
        'Africa/Tunis' => 'የመካከለኛው አውሮፓ ሰዓት (ቱኒዝ)',
        'Africa/Windhoek' => 'የመካከለኛው አፍሪካ ሰዓት (ዊንድሆክ)',
        'America/Adak' => 'የሃዋይ አሌኡት ሰዓት አቆጣጠር (አዳክ)',
        'America/Anchorage' => 'የአላስካ ሰዓት አቆጣጠር (አንኮራጅ)',
        'America/Anguilla' => 'የአትላንቲክ የሰዓት አቆጣጠር (አንጉይላ)',
        'America/Antigua' => 'የአትላንቲክ የሰዓት አቆጣጠር (አንቲጓ)',
        'America/Araguaina' => 'የብራዚላዊ ሰዓት አቆጣጠር (አራጉየና)',
        'America/Argentina/La_Rioja' => 'የአርጀንቲና የሰዓት አቆጣጠር (ላ ሪኦጃ)',
        'America/Argentina/Rio_Gallegos' => 'የአርጀንቲና የሰዓት አቆጣጠር (ሪዮ ጋሌጎስ)',
        'America/Argentina/Salta' => 'የአርጀንቲና የሰዓት አቆጣጠር (ሳልታ)',
        'America/Argentina/San_Juan' => 'የአርጀንቲና የሰዓት አቆጣጠር (ሳን ጁአን)',
        'America/Argentina/San_Luis' => 'የአርጀንቲና የሰዓት አቆጣጠር (ሳን ሊውስ)',
        'America/Argentina/Tucuman' => 'የአርጀንቲና የሰዓት አቆጣጠር (ቱኩማን)',
        'America/Argentina/Ushuaia' => 'የአርጀንቲና የሰዓት አቆጣጠር (ኡሹአኢ)',
        'America/Aruba' => 'የአትላንቲክ የሰዓት አቆጣጠር (አሩባ)',
        'America/Asuncion' => 'የፓራጓይ ሰዓት (አሱንሲዮን)',
        'America/Bahia' => 'የብራዚላዊ ሰዓት አቆጣጠር (ባሂአ)',
        'America/Bahia_Banderas' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ባሂያ ባንደራስ)',
        'America/Barbados' => 'የአትላንቲክ የሰዓት አቆጣጠር (ባርቤዶስ)',
        'America/Belem' => 'የብራዚላዊ ሰዓት አቆጣጠር (ቤለም)',
        'America/Belize' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ቤሊዝ)',
        'America/Blanc-Sablon' => 'የአትላንቲክ የሰዓት አቆጣጠር (ብላንክ- ሳብሎን)',
        'America/Boa_Vista' => 'የአማዞን ሰዓት አቆጣጠር (ቦአ ቪስታ)',
        'America/Bogota' => 'የኮሎምቢያ ሰዓት (ቦጎታ)',
        'America/Boise' => 'የተራራ የሰዓት አቆጣጠር (ቦይዝ)',
        'America/Buenos_Aires' => 'የአርጀንቲና የሰዓት አቆጣጠር (ቦነስ አይረስ)',
        'America/Argentina/Buenos_Aires' => 'የአርጀንቲና የሰዓት አቆጣጠር (ቦነስ አይረስ)',
        'America/Cambridge_Bay' => 'የተራራ የሰዓት አቆጣጠር (ካምብሪጅ ቤይ)',
        'America/Campo_Grande' => 'የአማዞን ሰዓት አቆጣጠር (ካምፖ ግራንዴ)',
        'America/Cancun' => 'ምስራቃዊ ሰዓት አቆጣጠር (ካንኩን)',
        'America/Caracas' => 'የቬኔዝዌላ ሰዓት (ካራካስ)',
        'America/Catamarca' => 'የአርጀንቲና የሰዓት አቆጣጠር (ካታማርካ)',
        'America/Argentina/Catamarca' => 'የአርጀንቲና የሰዓት አቆጣጠር (ካታማርካ)',
        'America/Cayenne' => 'የፈረንሳይ ጉያና ሰዓት (ካይንኤ)',
        'America/Cayman' => 'ምስራቃዊ ሰዓት አቆጣጠር (ካይማን)',
        'America/Chicago' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ቺካጎ)',
        'America/Chihuahua' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ቺሁዋውአ)',
        'America/Ciudad_Juarez' => 'የተራራ የሰዓት አቆጣጠር (ሳዮዳድ ሁዋሬዝ)',
        'America/Coral_Harbour' => 'ምስራቃዊ ሰዓት አቆጣጠር (አቲኮካን)',
        'America/Atikokan' => 'ምስራቃዊ ሰዓት አቆጣጠር (አቲኮካን)',
        'America/Cordoba' => 'የአርጀንቲና የሰዓት አቆጣጠር (ኮርዶባ)',
        'America/Argentina/Cordoba' => 'የአርጀንቲና የሰዓት አቆጣጠር (ኮርዶባ)',
        'America/Costa_Rica' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ኮስታሪካ)',
        'America/Coyhaique' => 'የቺሊ ሰዓት (Coyhaique)',
        'America/Creston' => 'የተራራ የሰዓት አቆጣጠር (ክረስተን)',
        'America/Cuiaba' => 'የአማዞን ሰዓት አቆጣጠር (ኩየአባ)',
        'America/Curacao' => 'የአትላንቲክ የሰዓት አቆጣጠር (ኩራሳዎ)',
        'America/Danmarkshavn' => 'ግሪንዊች ማዕከላዊ ሰዓት (ዳንማርክሻቭን)',
        'America/Dawson' => 'የዩኮን ጊዜ (ዳውሰን)',
        'America/Dawson_Creek' => 'የተራራ የሰዓት አቆጣጠር (ዳውሰን ክሬክ)',
        'America/Denver' => 'የተራራ የሰዓት አቆጣጠር (ዴንቨር)',
        'America/Detroit' => 'ምስራቃዊ ሰዓት አቆጣጠር (ዲትሮይት)',
        'America/Dominica' => 'የአትላንቲክ የሰዓት አቆጣጠር (ዶሜኒካ)',
        'America/Edmonton' => 'የተራራ የሰዓት አቆጣጠር (ኤድመንተን)',
        'America/Eirunepe' => 'ብራዚል ሰዓት (ኢሩኔፕ)',
        'America/El_Salvador' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ኤልሳልቫዶር)',
        'America/Fort_Nelson' => 'የተራራ የሰዓት አቆጣጠር (ፎርት ኔልሰን)',
        'America/Fortaleza' => 'የብራዚላዊ ሰዓት አቆጣጠር (ፎርታሌዛ)',
        'America/Glace_Bay' => 'የአትላንቲክ የሰዓት አቆጣጠር (ግሌስ ቤይ)',
        'America/Godthab' => 'ግሪንላንድ ሰዓት (ጋድታብ)',
        'America/Nuuk' => 'ግሪንላንድ ሰዓት (ጋድታብ)',
        'America/Goose_Bay' => 'የአትላንቲክ የሰዓት አቆጣጠር (ጉዝ ቤይ)',
        'America/Grand_Turk' => 'ምስራቃዊ ሰዓት አቆጣጠር (ግራንድ ተርክ)',
        'America/Grenada' => 'የአትላንቲክ የሰዓት አቆጣጠር (ግሬናዳ)',
        'America/Guadeloupe' => 'የአትላንቲክ የሰዓት አቆጣጠር (ጕዳሉፕ)',
        'America/Guatemala' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ጓቲማላ)',
        'America/Guayaquil' => 'የኢኳዶር ሰዓት (ጉያኩይል)',
        'America/Guyana' => 'የጉያና ሰዓት',
        'America/Halifax' => 'የአትላንቲክ የሰዓት አቆጣጠር (ሃሊፋክስ)',
        'America/Havana' => 'ኩባ ሰዓት (ሃቫና)',
        'America/Hermosillo' => 'የሜክሲኮ ፓሲፊክ ሰዓት አቆጣጠር (ኸርሞዚሎ)',
        'America/Indiana/Knox' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ኖክስ, ኢንዲያና)',
        'America/Indiana/Marengo' => 'ምስራቃዊ ሰዓት አቆጣጠር (ማሬንጎ, ኢንዲያና)',
        'America/Indiana/Petersburg' => 'ምስራቃዊ ሰዓት አቆጣጠር (ፒተርስበርግ, ኢንዲያና)',
        'America/Indiana/Tell_City' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ቴል ከተማ, ኢንዲያና)',
        'America/Indiana/Vevay' => 'ምስራቃዊ ሰዓት አቆጣጠር (ቪቫይ, ኢንዲያና)',
        'America/Indiana/Vincennes' => 'ምስራቃዊ ሰዓት አቆጣጠር (ቪንቼንስ, ኢንዲያና)',
        'America/Indiana/Winamac' => 'ምስራቃዊ ሰዓት አቆጣጠር (ዊናማክ, ኢንዲያና)',
        'America/Indianapolis' => 'ምስራቃዊ ሰዓት አቆጣጠር (ኢንዲያናፖሊስ)',
        'America/Indiana/Indianapolis' => 'ምስራቃዊ ሰዓት አቆጣጠር (ኢንዲያናፖሊስ)',
        'America/Inuvik' => 'የተራራ የሰዓት አቆጣጠር (ኢኑቪክ)',
        'America/Iqaluit' => 'ምስራቃዊ ሰዓት አቆጣጠር (ኢኳሊውት)',
        'America/Jamaica' => 'ምስራቃዊ ሰዓት አቆጣጠር (ጃማይካ)',
        'America/Jujuy' => 'የአርጀንቲና የሰዓት አቆጣጠር (ጁጁይ)',
        'America/Argentina/Jujuy' => 'የአርጀንቲና የሰዓት አቆጣጠር (ጁጁይ)',
        'America/Juneau' => 'የአላስካ ሰዓት አቆጣጠር (ጁኒዩ)',
        'America/Kentucky/Monticello' => 'ምስራቃዊ ሰዓት አቆጣጠር (ሞንቲሴሎ, ኪንታኪ)',
        'America/Kralendijk' => 'የአትላንቲክ የሰዓት አቆጣጠር (ክራለንዲይክ)',
        'America/La_Paz' => 'የቦሊቪያ ሰዓት (ላ ፓዝ)',
        'America/Lima' => 'የፔሩ ሰዓት (ሊማ)',
        'America/Los_Angeles' => 'የፓስፊክ ሰዓት አቆጣጠር (ሎስ አንጀለስ)',
        'America/Louisville' => 'ምስራቃዊ ሰዓት አቆጣጠር (ሊውስቪል)',
        'America/Kentucky/Louisville' => 'ምስራቃዊ ሰዓት አቆጣጠር (ሊውስቪል)',
        'America/Lower_Princes' => 'የአትላንቲክ የሰዓት አቆጣጠር (የታችኛው ልዑል ሩብ)',
        'America/Maceio' => 'የብራዚላዊ ሰዓት አቆጣጠር (ሜሲኦ)',
        'America/Managua' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ማናጉአ)',
        'America/Manaus' => 'የአማዞን ሰዓት አቆጣጠር (ማናኡስ)',
        'America/Marigot' => 'የአትላንቲክ የሰዓት አቆጣጠር (ማርጎት)',
        'America/Martinique' => 'የአትላንቲክ የሰዓት አቆጣጠር (ማርቲኒክ)',
        'America/Matamoros' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ማታሞሮስ)',
        'America/Mazatlan' => 'የሜክሲኮ ፓሲፊክ ሰዓት አቆጣጠር (ማዛትላን)',
        'America/Mendoza' => 'የአርጀንቲና የሰዓት አቆጣጠር (ሜንዶዛ)',
        'America/Argentina/Mendoza' => 'የአርጀንቲና የሰዓት አቆጣጠር (ሜንዶዛ)',
        'America/Menominee' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ሜኖሚኒ)',
        'America/Merida' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ሜሪዳ)',
        'America/Metlakatla' => 'የአላስካ ሰዓት አቆጣጠር (መትላካትላ)',
        'America/Mexico_City' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ሜክሲኮ ከተማ)',
        'America/Miquelon' => 'ቅዱስ የፒዬር እና ሚኴሎን ሰዓት (ሚኮውሎን)',
        'America/Moncton' => 'የአትላንቲክ የሰዓት አቆጣጠር (ሞንክቶን)',
        'America/Monterrey' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ሞንተርሬይ)',
        'America/Montevideo' => 'የኡራጓይ ሰዓት (ሞንቴቪድዮ)',
        'America/Montserrat' => 'የአትላንቲክ የሰዓት አቆጣጠር (ሞንትሴራት)',
        'America/Nassau' => 'ምስራቃዊ ሰዓት አቆጣጠር (ናሳው)',
        'America/New_York' => 'ምስራቃዊ ሰዓት አቆጣጠር (ኒውዮርክ)',
        'America/Nome' => 'የአላስካ ሰዓት አቆጣጠር (ኖሜ)',
        'America/Noronha' => 'የኖሮንሃ ሰዓት አቆጣጠር (ኖሮኛ)',
        'America/North_Dakota/Beulah' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ቤኡላህ, ሰሜን ዳኮታ)',
        'America/North_Dakota/Center' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (መካከለኛ, ሰሜን ዳኮታ)',
        'America/North_Dakota/New_Salem' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (አዲስ ሳሌም, ሰሜን ዳኮታ)',
        'America/Ojinaga' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ኦዪናጋ)',
        'America/Panama' => 'ምስራቃዊ ሰዓት አቆጣጠር (ፓናማ)',
        'America/Paramaribo' => 'የሱሪናም ሰዓት (ፓራማሪቦ)',
        'America/Phoenix' => 'የተራራ የሰዓት አቆጣጠር (ፊኒክስ)',
        'America/Port-au-Prince' => 'ምስራቃዊ ሰዓት አቆጣጠር (ፖርት ኦ ፕሪንስ)',
        'America/Port_of_Spain' => 'የአትላንቲክ የሰዓት አቆጣጠር (የእስፔን ወደብ)',
        'America/Porto_Velho' => 'የአማዞን ሰዓት አቆጣጠር (ፔትሮ ቬልሆ)',
        'America/Puerto_Rico' => 'የአትላንቲክ የሰዓት አቆጣጠር (ፖርቶሪኮ)',
        'America/Punta_Arenas' => 'የቺሊ ሰዓት (ፑንታ አሬናስ)',
        'America/Rankin_Inlet' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ራንኪን ኢንሌት)',
        'America/Recife' => 'የብራዚላዊ ሰዓት አቆጣጠር (ረሲፍ)',
        'America/Regina' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ረጂና)',
        'America/Resolute' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ሪዞሊዩት)',
        'America/Rio_Branco' => 'ብራዚል ሰዓት (ሪዮ ብራንኮ)',
        'America/Santarem' => 'የብራዚላዊ ሰዓት አቆጣጠር (ሳንታሬም)',
        'America/Santiago' => 'የቺሊ ሰዓት (ሳንቲያጎ)',
        'America/Santo_Domingo' => 'የአትላንቲክ የሰዓት አቆጣጠር (ሳንቶ ዶሚንጎ)',
        'America/Sao_Paulo' => 'የብራዚላዊ ሰዓት አቆጣጠር (ሳኦ ፖሎ)',
        'America/Scoresbysund' => 'ግሪንላንድ ሰዓት (ስኮርስባይሰንድ)',
        'America/Sitka' => 'የአላስካ ሰዓት አቆጣጠር (ሲትካ)',
        'America/St_Barthelemy' => 'የአትላንቲክ የሰዓት አቆጣጠር (ቅድስት ቤርተሎሜ)',
        'America/St_Johns' => 'የኒውፋውንድላንድ የሰዓት አቆጣጠር (ቅዱስ ዮሐንስ)',
        'America/St_Kitts' => 'የአትላንቲክ የሰዓት አቆጣጠር (ቅዱስ ኪትስ)',
        'America/St_Lucia' => 'የአትላንቲክ የሰዓት አቆጣጠር (ቅድስት ሉሲያ)',
        'America/St_Thomas' => 'የአትላንቲክ የሰዓት አቆጣጠር (ቅዱስ ቶማስ)',
        'America/St_Vincent' => 'የአትላንቲክ የሰዓት አቆጣጠር (ቅዱስ ቪንሰንት)',
        'America/Swift_Current' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (የሐዋላ ገንዘብ)',
        'America/Tegucigalpa' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ቴጉሲጋልፓ)',
        'America/Thule' => 'የአትላንቲክ የሰዓት አቆጣጠር (ቱሌ)',
        'America/Tijuana' => 'የፓስፊክ ሰዓት አቆጣጠር (ቲጁአና)',
        'America/Toronto' => 'ምስራቃዊ ሰዓት አቆጣጠር (ቶሮንቶ)',
        'America/Tortola' => 'የአትላንቲክ የሰዓት አቆጣጠር (ቶርቶላ)',
        'America/Vancouver' => 'የፓስፊክ ሰዓት አቆጣጠር (ቫንኮቨር)',
        'America/Whitehorse' => 'የዩኮን ጊዜ (ኋይትሆርስ)',
        'America/Winnipeg' => 'የሰሜን አሜሪካ የመካከለኛ ሰዓት አቆጣጠር (ዊኒፔግ)',
        'America/Yakutat' => 'የአላስካ ሰዓት አቆጣጠር (ያኩታት)',
        'Antarctica/Casey' => 'የምስራቃዊ አውስትራሊያ ሰዓት አቆጣጠር (ካዚይ)',
        'Antarctica/Davis' => 'የዴቪስ ሰዓት (ዳቪስ)',
        'Antarctica/DumontDUrville' => 'የዱሞንት-ዱርቪል ሰዓት (ደሞንት ዲኡርቪል)',
        'Antarctica/Macquarie' => 'የምዕራባዊ አውስትራሊያ የሰዓት አቆጣጠር (ማከሪ)',
        'Antarctica/Mawson' => 'የማውሰን ሰዓት (ናውሰን)',
        'Antarctica/McMurdo' => 'የኒው ዚላንድ ሰዓት (ማክመርዶ)',
        'Antarctica/Palmer' => 'የቺሊ ሰዓት (ፓልመር)',
        'Antarctica/Rothera' => 'የሮቴራ ሰዓት',
        'Antarctica/Syowa' => 'የሲዮዋ ሰዓት (ስዮዋ)',
        'Antarctica/Troll' => 'ግሪንዊች ማዕከላዊ ሰዓት (ትሮል)',
        'Antarctica/Vostok' => 'የቮስቶክ ሰዓት (ቭስቶክ)',
        'Arctic/Longyearbyen' => 'የመካከለኛው አውሮፓ ሰዓት (ሎንግይርባየን)',
        'Asia/Aden' => 'የዓረቢያ ሰዓት (ኤደን)',
        'Asia/Almaty' => 'ካዛኪስታን ሰዓት (አልማትይ)',
        'Asia/Amman' => 'የምስራቃዊ አውሮፓ ሰዓት (አማን)',
        'Asia/Anadyr' => 'የካምቻትካ ሰዓት አቆጣጠር (አናድይር)',
        'Asia/Aqtau' => 'ካዛኪስታን ሰዓት (አኩታኡ)',
        'Asia/Aqtobe' => 'ካዛኪስታን ሰዓት (አኩቶቤ)',
        'Asia/Ashgabat' => 'የቱርክመኒስታን ሰዓት (አሽጋባት)',
        'Asia/Atyrau' => 'ካዛኪስታን ሰዓት (አትይራኡ)',
        'Asia/Baghdad' => 'የዓረቢያ ሰዓት (ባግዳድ)',
        'Asia/Bahrain' => 'የዓረቢያ ሰዓት (ባህሬን)',
        'Asia/Baku' => 'የአዘርባጃን ሰዓት (ባኩ)',
        'Asia/Bangkok' => 'የኢንዶቻይና ሰዓት (ባንኮክ)',
        'Asia/Barnaul' => 'የክራስኖያርስክ ሰዓት አቆጣጠር (ባርናኡል)',
        'Asia/Beirut' => 'የምስራቃዊ አውሮፓ ሰዓት (ቤሩት)',
        'Asia/Bishkek' => 'የኪርጊስታን ሰዓት (ቢሽኬክ)',
        'Asia/Brunei' => 'የብሩኔይ ዳሩሳላም ሰዓት (ብሩናይ)',
        'Asia/Calcutta' => 'የህንድ መደበኛ ሰዓት (ኮልካታ)',
        'Asia/Kolkata' => 'የህንድ መደበኛ ሰዓት (ኮልካታ)',
        'Asia/Chita' => 'ያኩትስክ የሰዓት አቆጣጠር (ቺታ)',
        'Asia/Colombo' => 'የህንድ መደበኛ ሰዓት (ኮሎምቦ)',
        'Asia/Damascus' => 'የምስራቃዊ አውሮፓ ሰዓት (ደማስቆ)',
        'Asia/Dhaka' => 'የባንግላዴሽ ሰዓት (ዳካ)',
        'Asia/Dili' => 'የምስራቅ ቲሞር ሰዓት (ዲሊ)',
        'Asia/Dubai' => 'የባህረሰላጤ መደበኛ ሰዓት (ዱባይ)',
        'Asia/Dushanbe' => 'የታጂኪስታን ሰዓት (ደሻንቤ)',
        'Asia/Famagusta' => 'የምስራቃዊ አውሮፓ ሰዓት (ፋማጉስታ)',
        'Asia/Gaza' => 'የምስራቃዊ አውሮፓ ሰዓት (ጋዛ)',
        'Asia/Hebron' => 'የምስራቃዊ አውሮፓ ሰዓት (ኬብሮን)',
        'Asia/Hong_Kong' => 'የሆንግ ኮንግ ሰዓት',
        'Asia/Hovd' => 'የሆቭድ ሰዓት አቆጣጠር',
        'Asia/Irkutsk' => 'የኢርኩትስክ ሰዓት አቆጣጠር',
        'Asia/Jakarta' => 'የምዕራባዊ ኢንዶኔዢያ ሰዓት (ጃካርታ)',
        'Asia/Jayapura' => 'የምስራቃዊ ኢንዶኔዢያ ሰዓት (ጃያፑራ)',
        'Asia/Jerusalem' => 'የእስራኤል ሰዓት (እየሩሳሌም)',
        'Asia/Kabul' => 'የአፍጋኒስታን ሰዓት (ካቡል)',
        'Asia/Kamchatka' => 'የካምቻትካ ሰዓት አቆጣጠር',
        'Asia/Karachi' => 'የፓኪስታን ሰዓት (ካራቺ)',
        'Asia/Katmandu' => 'የኔፓል ሰዓት (ካትማንዱ)',
        'Asia/Kathmandu' => 'የኔፓል ሰዓት (ካትማንዱ)',
        'Asia/Khandyga' => 'ያኩትስክ የሰዓት አቆጣጠር (ካንዲጋ)',
        'Asia/Krasnoyarsk' => 'የክራስኖያርስክ ሰዓት አቆጣጠር',
        'Asia/Kuala_Lumpur' => 'የማሌይዢያ ሰዓት (ኩዋላ ላምፑር)',
        'Asia/Kuching' => 'የማሌይዢያ ሰዓት (ኩቺንግ)',
        'Asia/Kuwait' => 'የዓረቢያ ሰዓት (ኩዌት)',
        'Asia/Macau' => 'የቻይና ሰዓት (ማካኡ)',
        'Asia/Magadan' => 'የማጋዳን የሰዓት አቆጣጠር',
        'Asia/Makassar' => 'የመካከለኛው ኢንዶኔዢያ ሰዓት (ማካሳር)',
        'Asia/Manila' => 'የፊሊፒን ሰዓት (ማኒላ)',
        'Asia/Muscat' => 'የባህረሰላጤ መደበኛ ሰዓት (ሙስካት)',
        'Asia/Nicosia' => 'የምስራቃዊ አውሮፓ ሰዓት (ኒኮሲአ)',
        'Asia/Novokuznetsk' => 'የክራስኖያርስክ ሰዓት አቆጣጠር (ኖቮኩትዝኔክ)',
        'Asia/Novosibirsk' => 'የክራስኖያርስክ ሰዓት አቆጣጠር (ኖቮሲቢሪስክ)',
        'Asia/Omsk' => 'የኦምስክ የሰዓት አቆጣጠር',
        'Asia/Oral' => 'ካዛኪስታን ሰዓት (ኦራል)',
        'Asia/Phnom_Penh' => 'የኢንዶቻይና ሰዓት (ፍኖም ፔንህ)',
        'Asia/Pontianak' => 'የምዕራባዊ ኢንዶኔዢያ ሰዓት (ፖንቲአናክ)',
        'Asia/Pyongyang' => 'የኮሪያ ሰዓት (ፕዮንግያንግ)',
        'Asia/Qatar' => 'የዓረቢያ ሰዓት (ኳታር)',
        'Asia/Qostanay' => 'ካዛኪስታን ሰዓት (ኮስታናይ)',
        'Asia/Qyzylorda' => 'ካዛኪስታን ሰዓት (ኩይዚሎርዳ)',
        'Asia/Rangoon' => 'የሚያንማር ሰዓት (ያንጎን)',
        'Asia/Yangon' => 'የሚያንማር ሰዓት (ያንጎን)',
        'Asia/Riyadh' => 'የዓረቢያ ሰዓት (ሪያድ)',
        'Asia/Saigon' => 'የኢንዶቻይና ሰዓት (ሆ ቺ ሚንህ ከተማ)',
        'Asia/Ho_Chi_Minh' => 'የኢንዶቻይና ሰዓት (ሆ ቺ ሚንህ ከተማ)',
        'Asia/Sakhalin' => 'የማጋዳን የሰዓት አቆጣጠር (ሳክሃሊን)',
        'Asia/Samarkand' => 'የኡዝቤኪስታን ሰዓት (ሳማርካንድ)',
        'Asia/Seoul' => 'የኮሪያ ሰዓት (ሴኦል)',
        'Asia/Shanghai' => 'የቻይና ሰዓት (ሻንጋይ)',
        'Asia/Singapore' => 'የሲንጋፒር መደበኛ ሰዓት (ሲንጋፖር)',
        'Asia/Srednekolymsk' => 'የማጋዳን የሰዓት አቆጣጠር (ስሬድኔስኮልምስክ)',
        'Asia/Taipei' => 'የታይፔይ ሰዓት (ታይፓይ)',
        'Asia/Tashkent' => 'የኡዝቤኪስታን ሰዓት (ታሽኬንት)',
        'Asia/Tbilisi' => 'የጂዮርጂያ ሰዓት (ትብሊሲ)',
        'Asia/Tehran' => 'የኢራን ሰዓት (ቴህራን)',
        'Asia/Thimphu' => 'የቡታን ሰዓት (ቲምፉ)',
        'Asia/Tokyo' => 'የጃፓን ሰዓት (ቶኪዮ)',
        'Asia/Tomsk' => 'የክራስኖያርስክ ሰዓት አቆጣጠር (ቶምስክ)',
        'Asia/Ulaanbaatar' => 'የኡላን ባቶር ጊዜ (ኡላአንባአታር)',
        'Asia/Urumqi' => 'ቻይና ሰዓት (ኡሩምኪ)',
        'Asia/Ust-Nera' => 'የቭላዲቮስቶክ የሰዓት አቆጣጠር (ኡስት-ኔራ)',
        'Asia/Vientiane' => 'የኢንዶቻይና ሰዓት (ቬንቲአን)',
        'Asia/Vladivostok' => 'የቭላዲቮስቶክ የሰዓት አቆጣጠር',
        'Asia/Yakutsk' => 'ያኩትስክ የሰዓት አቆጣጠር',
        'Asia/Yekaterinburg' => 'የየካተሪንበርግ ሰዓት አቆጣጠር',
        'Asia/Yerevan' => 'የአርመኒያ ሰዓት (ይሬቫን)',
        'Atlantic/Azores' => 'የአዞረስ ሰዓት',
        'Atlantic/Bermuda' => 'የአትላንቲክ የሰዓት አቆጣጠር (ቤርሙዳ)',
        'Atlantic/Canary' => 'የምዕራባዊ አውሮፓ ሰዓት (ካናሪ)',
        'Atlantic/Cape_Verde' => 'የኬፕ ቨርዴ ሰዓት (ኬፕ ቬርደ)',
        'Atlantic/Faeroe' => 'የምዕራባዊ አውሮፓ ሰዓት (ፋሮእ)',
        'Atlantic/Faroe' => 'የምዕራባዊ አውሮፓ ሰዓት (ፋሮእ)',
        'Atlantic/Madeira' => 'የምዕራባዊ አውሮፓ ሰዓት (ማዴራ)',
        'Atlantic/Reykjavik' => 'ግሪንዊች ማዕከላዊ ሰዓት (ሬይክጃቪክ)',
        'Atlantic/South_Georgia' => 'የደቡብ ጂዮርጂያ ሰዓት (ደቡብ ጆርጂያ)',
        'Atlantic/St_Helena' => 'ግሪንዊች ማዕከላዊ ሰዓት (ቅድስት ሄለና)',
        'Atlantic/Stanley' => 'የፋልክላንድ ደሴቶች ሰዓት (ስታንሌይ)',
        'Australia/Adelaide' => 'የመካከለኛው አውስትራሊያ ሰዓት አቆጣጠር (አዴሌእድ)',
        'Australia/Brisbane' => 'የምዕራባዊ አውስትራሊያ የሰዓት አቆጣጠር (ብሪስቤን)',
        'Australia/Broken_Hill' => 'የመካከለኛው አውስትራሊያ ሰዓት አቆጣጠር (ብሮክን ሂል)',
        'Australia/Darwin' => 'የመካከለኛው አውስትራሊያ ሰዓት አቆጣጠር (ዳርዊን)',
        'Australia/Eucla' => 'የአውስትራሊያ መካከለኛ ምስራቃዊ ሰዓት አቆጣጠር (ኡክላ)',
        'Australia/Hobart' => 'የምዕራባዊ አውስትራሊያ የሰዓት አቆጣጠር (ሆባርት)',
        'Australia/Lindeman' => 'የምዕራባዊ አውስትራሊያ የሰዓት አቆጣጠር (ሊንድማን)',
        'Australia/Lord_Howe' => 'የሎርድ ሆዌ የሰዓት አቆጣጠር (ሎርድ ሆዊ)',
        'Australia/Melbourne' => 'የምዕራባዊ አውስትራሊያ የሰዓት አቆጣጠር (ሜልቦርን)',
        'Australia/Perth' => 'የምስራቃዊ አውስትራሊያ ሰዓት አቆጣጠር (ፐርዝ)',
        'Australia/Sydney' => 'የምዕራባዊ አውስትራሊያ የሰዓት አቆጣጠር (ሲድኒ)',
        'Etc/GMT' => 'ግሪንዊች ማዕከላዊ ሰዓት',
        'Etc/UTC' => 'የተቀነባበረ ሁለገብ ሰዓት',
        'Europe/Amsterdam' => 'የመካከለኛው አውሮፓ ሰዓት (አምስተርዳም)',
        'Europe/Andorra' => 'የመካከለኛው አውሮፓ ሰዓት (አንዶራ)',
        'Europe/Astrakhan' => 'የሳማራ ሰዓት አቆጣጠር (አስትራክሃን)',
        'Europe/Athens' => 'የምስራቃዊ አውሮፓ ሰዓት (አቴንስ)',
        'Europe/Belgrade' => 'የመካከለኛው አውሮፓ ሰዓት (ቤልግሬድ)',
        'Europe/Berlin' => 'የመካከለኛው አውሮፓ ሰዓት (በርሊን)',
        'Europe/Bratislava' => 'የመካከለኛው አውሮፓ ሰዓት (ብራቲስላቫ)',
        'Europe/Brussels' => 'የመካከለኛው አውሮፓ ሰዓት (ብራሰልስ)',
        'Europe/Bucharest' => 'የምስራቃዊ አውሮፓ ሰዓት (ቡካሬስት)',
        'Europe/Budapest' => 'የመካከለኛው አውሮፓ ሰዓት (ቡዳፔስት)',
        'Europe/Busingen' => 'የመካከለኛው አውሮፓ ሰዓት (ቡሲንገን)',
        'Europe/Chisinau' => 'የምስራቃዊ አውሮፓ ሰዓት (ቺስናኡ)',
        'Europe/Copenhagen' => 'የመካከለኛው አውሮፓ ሰዓት (ኮፐንሃገን)',
        'Europe/Dublin' => 'ግሪንዊች ማዕከላዊ ሰዓት (ደብሊን)',
        'Europe/Gibraltar' => 'የመካከለኛው አውሮፓ ሰዓት (ጂብራልታር)',
        'Europe/Guernsey' => 'ግሪንዊች ማዕከላዊ ሰዓት (ጉርነሲ)',
        'Europe/Helsinki' => 'የምስራቃዊ አውሮፓ ሰዓት (ሄልሲንኪ)',
        'Europe/Isle_of_Man' => 'ግሪንዊች ማዕከላዊ ሰዓት (አይስል ኦፍ ማን)',
        'Europe/Istanbul' => 'ቱርክ ሰዓት (ኢስታንቡል)',
        'Europe/Jersey' => 'ግሪንዊች ማዕከላዊ ሰዓት (ጀርሲ)',
        'Europe/Kaliningrad' => 'የምስራቃዊ አውሮፓ ሰዓት (ካሊኒንግራድ)',
        'Europe/Kiev' => 'የምስራቃዊ አውሮፓ ሰዓት (ኪየቭ)',
        'Europe/Kyiv' => 'የምስራቃዊ አውሮፓ ሰዓት (ኪየቭ)',
        'Europe/Kirov' => 'የሞስኮ ሰዓት አቆጣጠር (ኪሮቭ)',
        'Europe/Lisbon' => 'የምዕራባዊ አውሮፓ ሰዓት (ሊዝበን)',
        'Europe/Ljubljana' => 'የመካከለኛው አውሮፓ ሰዓት (ልጁብልጃና)',
        'Europe/London' => 'ግሪንዊች ማዕከላዊ ሰዓት (ለንደን)',
        'Europe/Luxembourg' => 'የመካከለኛው አውሮፓ ሰዓት (ሉክሰምበርግ)',
        'Europe/Madrid' => 'የመካከለኛው አውሮፓ ሰዓት (ማድሪድ)',
        'Europe/Malta' => 'የመካከለኛው አውሮፓ ሰዓት (ማልታ)',
        'Europe/Mariehamn' => 'የምስራቃዊ አውሮፓ ሰዓት (ሜሪሃምን)',
        'Europe/Minsk' => 'የሞስኮ ሰዓት አቆጣጠር (ሚንስክ)',
        'Europe/Monaco' => 'የመካከለኛው አውሮፓ ሰዓት (ሞናኮ)',
        'Europe/Moscow' => 'የሞስኮ ሰዓት አቆጣጠር',
        'Europe/Oslo' => 'የመካከለኛው አውሮፓ ሰዓት (ኦስሎ)',
        'Europe/Paris' => 'የመካከለኛው አውሮፓ ሰዓት (ፓሪስ)',
        'Europe/Podgorica' => 'የመካከለኛው አውሮፓ ሰዓት (ፖድጎሪካ)',
        'Europe/Prague' => 'የመካከለኛው አውሮፓ ሰዓት (ፕራግ)',
        'Europe/Riga' => 'የምስራቃዊ አውሮፓ ሰዓት (ሪጋ)',
        'Europe/Rome' => 'የመካከለኛው አውሮፓ ሰዓት (ሮም)',
        'Europe/Samara' => 'የሳማራ ሰዓት አቆጣጠር',
        'Europe/San_Marino' => 'የመካከለኛው አውሮፓ ሰዓት (ሳን ማሪኖ)',
        'Europe/Sarajevo' => 'የመካከለኛው አውሮፓ ሰዓት (ሳሪየቮ)',
        'Europe/Saratov' => 'የሳማራ ሰዓት አቆጣጠር (ሳራቶቭ)',
        'Europe/Simferopol' => 'የሞስኮ ሰዓት አቆጣጠር (ሲምፈሮፖል)',
        'Europe/Skopje' => 'የመካከለኛው አውሮፓ ሰዓት (ስኮፕየ)',
        'Europe/Sofia' => 'የምስራቃዊ አውሮፓ ሰዓት (ሶፊያ)',
        'Europe/Stockholm' => 'የመካከለኛው አውሮፓ ሰዓት (ስቶክሆልም)',
        'Europe/Tallinn' => 'የምስራቃዊ አውሮፓ ሰዓት (ታሊን)',
        'Europe/Tirane' => 'የመካከለኛው አውሮፓ ሰዓት (ቴራን)',
        'Europe/Ulyanovsk' => 'የሳማራ ሰዓት አቆጣጠር (ኡልያኖቭስክ)',
        'Europe/Vaduz' => 'የመካከለኛው አውሮፓ ሰዓት (ቫዱዝ)',
        'Europe/Vatican' => 'የመካከለኛው አውሮፓ ሰዓት (ቫቲካን)',
        'Europe/Vienna' => 'የመካከለኛው አውሮፓ ሰዓት (ቪየና)',
        'Europe/Vilnius' => 'የምስራቃዊ አውሮፓ ሰዓት (ቪሊነስ)',
        'Europe/Volgograd' => 'የሞስኮ ሰዓት አቆጣጠር (ቮልጎራድ)',
        'Europe/Warsaw' => 'የመካከለኛው አውሮፓ ሰዓት (ዋርሶው)',
        'Europe/Zagreb' => 'የመካከለኛው አውሮፓ ሰዓት (ዛግሬብ)',
        'Europe/Zurich' => 'የመካከለኛው አውሮፓ ሰዓት (ዙሪክ)',
        'Indian/Antananarivo' => 'የምስራቅ አፍሪካ ሰዓት (አንታናናሪቮ)',
        'Indian/Chagos' => 'የህንድ ውቅያኖስ ሰዓት (ቻጎስ)',
        'Indian/Christmas' => 'የገና ደሴት ሰዓት',
        'Indian/Cocos' => 'የኮኮስ ደሴቶች ሰዓት',
        'Indian/Comoro' => 'የምስራቅ አፍሪካ ሰዓት (ኮሞሮ)',
        'Indian/Kerguelen' => 'የፈረንሳይ ደቡባዊ እና አንታርክቲክ ሰዓት (ኬርጉለን)',
        'Indian/Mahe' => 'የሴሸልስ ሰዓት (ማሄ)',
        'Indian/Maldives' => 'የማልዲቭስ ሰዓት (ማልዲቨ)',
        'Indian/Mauritius' => 'የማውሪሺየስ ሰዓት (ሞሪሽየስ)',
        'Indian/Mayotte' => 'የምስራቅ አፍሪካ ሰዓት (ማዮቴ)',
        'Indian/Reunion' => 'የሬዩኒየን ሰዓት',
        'Pacific/Apia' => 'የአፒያ ሰዓት (አፒአ)',
        'Pacific/Auckland' => 'የኒው ዚላንድ ሰዓት (ኦክላንድ)',
        'Pacific/Bougainville' => 'የፓፗ ኒው ጊኒ ሰዓት (ቦጌይንቪል)',
        'Pacific/Chatham' => 'የቻታም ሰዓት',
        'Pacific/Easter' => 'የኢስተር ደሴት ሰዓት (ፋሲካ)',
        'Pacific/Efate' => 'የቫኗቱ ሰዓት (ኢፋቴ)',
        'Pacific/Enderbury' => 'የፊኒክስ ደሴቶች ሰዓት (ካንቶን)',
        'Pacific/Kanton' => 'የፊኒክስ ደሴቶች ሰዓት (ካንቶን)',
        'Pacific/Fakaofo' => 'የቶኬላው ሰዓት (ፋካኦፎ)',
        'Pacific/Fiji' => 'የፊጂ ሰዓት',
        'Pacific/Funafuti' => 'የቱቫሉ ሰዓት (ፈናፉቲ)',
        'Pacific/Galapagos' => 'የጋላፓጎስ ሰዓት',
        'Pacific/Gambier' => 'የጋምቢየር ሰዓት',
        'Pacific/Guadalcanal' => 'የሰለሞን ደሴቶች ሰዓት (ጉዋዳልካናል)',
        'Pacific/Guam' => 'የቻሞሮ መደበኛ ሰዓት (ጉአም)',
        'Pacific/Honolulu' => 'የሃዋይ አሌኡት መደበኛ ሰዓት አቆጣጠር (ሆኖሉሉ)',
        'Pacific/Kiritimati' => 'የላይን ደሴቶች ሰዓት (ኪሪቲማቲ)',
        'Pacific/Kosrae' => 'የኮስራኤ ሰዓት (ኮስሬ)',
        'Pacific/Kwajalein' => 'የማርሻል ደሴቶች ሰዓት (ክዋጃሊን)',
        'Pacific/Majuro' => 'የማርሻል ደሴቶች ሰዓት (ማጁሩ)',
        'Pacific/Marquesas' => 'የማርኴሳስ ሰዓት (ማርክዌሳስ)',
        'Pacific/Midway' => 'የሳሞዋ ሰዓት (ሚድወይ)',
        'Pacific/Nauru' => 'የናውሩ ሰዓት',
        'Pacific/Niue' => 'የኒዩዌ ሰዓት (ኒዌ)',
        'Pacific/Norfolk' => 'የኖርፎልክ ደሴቶች ሰዓት',
        'Pacific/Noumea' => 'የኒው ካሌዶኒያ ሰዓት (ናኦሚአ)',
        'Pacific/Pago_Pago' => 'የሳሞዋ ሰዓት (ፓጎ ፓጎ)',
        'Pacific/Palau' => 'የፓላው ሰዓት',
        'Pacific/Pitcairn' => 'የፒትካይርን ሰዓት (ፒትከይርን)',
        'Pacific/Ponape' => 'የፖናፔ ሰዓት (ፖህንፔ)',
        'Pacific/Pohnpei' => 'የፖናፔ ሰዓት (ፖህንፔ)',
        'Pacific/Port_Moresby' => 'የፓፗ ኒው ጊኒ ሰዓት (ፖርት ሞሬስባይ)',
        'Pacific/Rarotonga' => 'የኩክ ደሴቶች ሰዓት (ራሮቶንጋ)',
        'Pacific/Saipan' => 'የቻሞሮ መደበኛ ሰዓት (ሴይፓን)',
        'Pacific/Tahiti' => 'የታሂቲ ሰዓት',
        'Pacific/Tarawa' => 'የጂልበርት ደሴቶች ሰዓት (ታራዋ)',
        'Pacific/Tongatapu' => 'የቶንጋ ሰዓት (ቶንጋታፑ)',
        'Pacific/Truk' => 'የቹክ ሰዓት',
        'Pacific/Chuuk' => 'የቹክ ሰዓት',
        'Pacific/Wake' => 'የዌክ ደሴት ሰዓት (ዋኬ)',
        'Pacific/Wallis' => 'የዋሊስ እና ፉቱና ሰዓት',
    ],
    'Meta' => [
        'GmtFormat' => 'ጂ ኤም ቲ%s',
        'HourFormatPos' => '+%02d%02d',
        'HourFormatNeg' => '-%02d%02d',
    ],
];
