<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Diami ti Awon Orílɛ́ède Arabu',
        ],
        'ALL' => [
            'ALL',
            'Lɛ́ɛ̀kì Àlìbáníà',
        ],
        'AMD' => [
            'AMD',
            'Dírààmù Àmɛ́níà',
        ],
        'ARS' => [
            'ARS',
            'Pɛ́sò Agɛntínà',
        ],
        'AUD' => [
            'A$',
            'Dɔla ti Orílɛ́ède Ástràlìá',
        ],
        'BBD' => [
            'BBD',
            'Dɔ́là Bábádɔ̀ɔ̀sì',
        ],
        'BDT' => [
            'BDT',
            'Tákà Báńgíládɛ̀ɛ̀shì',
        ],
        'BGN' => [
            'BGN',
            'Owó Lɛ́fì Bɔ̀lìgéríà',
        ],
        'BHD' => [
            'BHD',
            'Dina ti Orílɛ́ède Báránì',
        ],
        'BMD' => [
            'BMD',
            'Dɔ́là Bɛ̀múdà',
        ],
        'BND' => [
            'BND',
            'Dɔ́là Bùrùnéì',
        ],
        'BOB' => [
            'BOB',
            'Bɔlifiánò Bɔ̀lífíà',
        ],
        'BRL' => [
            'R$',
            'Owó ti Orílɛ̀-èdè Brazil',
        ],
        'BSD' => [
            'BSD',
            'Dɔ́là Bàhámà',
        ],
        'BTN' => [
            'BTN',
            'Ìngɔ́tírɔ̀mù Bútàànì',
        ],
        'BWP' => [
            'BWP',
            'Pula Bɔ̀tìsúwánà',
        ],
        'BYN' => [
            'BYN',
            'Rɔ́bù Bɛ̀lárùùsì',
        ],
        'BZD' => [
            'BZD',
            'Dɔ́là Bɛ̀lísè',
        ],
        'CAD' => [
            'CA$',
            'Dɔ́là Kánádà',
        ],
        'CLP' => [
            'CLP',
            'Pɛ́sò Shílè',
        ],
        'CNY' => [
            'CN¥',
            'Reminibi ti Orílɛ́ède sháínà',
        ],
        'COP' => [
            'COP',
            'Pɛ́sò Kòlóḿbíà',
        ],
        'CRC' => [
            'CRC',
            'Kólɔ́ɔ̀nì Kosita Ríkà',
        ],
        'CUC' => [
            'CUC',
            'Pɛ́sò Yíyípadà Kúbà',
        ],
        'CUP' => [
            'CUP',
            'Pɛ́sò Kúbà',
        ],
        'CZK' => [
            'CZK',
            'Koruna Shɛ́ɛ̀kì',
        ],
        'DKK' => [
            'DKK',
            'Kírónì Dáníshì',
        ],
        'DOP' => [
            'DOP',
            'Pɛ́sò Dòníníkà',
        ],
        'DZD' => [
            'DZD',
            'Dina ti Orílɛ́ède Àlùgèríánì',
        ],
        'EGP' => [
            'EGP',
            'pɔɔn ti Orílɛ́ède Egipiti',
        ],
        'FJD' => [
            'FJD',
            'Dɔ́là Fíjì',
        ],
        'FKP' => [
            'FKP',
            'Pɔ́n-ùn Erékùsù Falkland',
        ],
        'GBP' => [
            '£',
            'Pɔ́n-ùn ti Orilɛ̀-èdè Gɛ̀ɛ́sì',
        ],
        'GEL' => [
            'GEL',
            'Lárì Jɔ́jíà',
        ],
        'GHC' => [
            'GHC',
            'shidi ti Orílɛ́ède Gana',
        ],
        'GIP' => [
            'GIP',
            'Pɔ́n-ùn Gibúrátà',
        ],
        'GNS' => [
            'GNS',
            'Faransi ti Orílɛ́ède Gini',
        ],
        'GTQ' => [
            'GTQ',
            'Kúɛ́tísààlì Guatimílà',
        ],
        'GYD' => [
            'GYD',
            'Dɔ́là Gùyánà',
        ],
        'HKD' => [
            'HK$',
            'Dɔ́là Hong Kong',
        ],
        'HNL' => [
            'HNL',
            'Lɛmipírà Ɔ́ńdúrà',
        ],
        'HRK' => [
            'HRK',
            'Kúnà Kúróshíà',
        ],
        'HTG' => [
            'HTG',
            'Gɔ́dì Àítì',
        ],
        'HUF' => [
            'HUF',
            'Fɔ́ríǹtì Hɔ̀ngérí',
        ],
        'ILS' => [
            '₪',
            'Shékélì Tuntun Ísírɛ̀ɛ̀lì',
        ],
        'INR' => [
            '₹',
            'Rupi ti Orílɛ́ède Indina',
        ],
        'JMD' => [
            'JMD',
            'Dɔ́là Jàmáíkà',
        ],
        'JOD' => [
            'JOD',
            'Dínárì Jɔ́dàànì',
        ],
        'JPY' => [
            'JP¥',
            'Yeni ti Orílɛ́ède Japani',
        ],
        'KES' => [
            'KES',
            'Shiili Kenya',
        ],
        'KHR' => [
            'KHR',
            'Ráyò Kàm̀bɔ́díà',
        ],
        'KPW' => [
            'KPW',
            'Wɔ́ɔ̀nù Àríwá Kòríà',
        ],
        'KRW' => [
            '₩',
            'Wɔ́ɔ̀nù Gúúsù Kòríà',
        ],
        'KYD' => [
            'KYD',
            'Dɔ́là Erékùsù Cayman',
        ],
        'KZT' => [
            'KZT',
            'Tɛngé Kasakísítàànì',
        ],
        'LBP' => [
            'LBP',
            'Pɔ́n-ùn Lebanese',
        ],
        'LRD' => [
            'LRD',
            'Dɔla Liberia',
        ],
        'LSL' => [
            'LSL',
            'Loti ti Orílɛ́ède Lesoto',
        ],
        'MKD' => [
            'MKD',
            'Dɛ́nà Masidóníà',
        ],
        'MRO' => [
            'MRO',
            'Ouguiya ti Orílɛ́ède Maritania (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Ouguiya ti Orílɛ́ède Maritania',
        ],
        'MVR' => [
            'MVR',
            'Rúfìyá Mɔ̀lìdífà',
        ],
        'MXN' => [
            'MX$',
            'Pɛ́sò Mɛ́síkò',
        ],
        'MYR' => [
            'MYR',
            'Ríngìtì Màléshíà',
        ],
        'MZM' => [
            'MZM',
            'Metika ti Orílɛ́ède Mosamibiki',
        ],
        'MZN' => [
            'MZN',
            'Mɛ́tíkààlì Mòsáḿbíìkì',
        ],
        'NAD' => [
            'NAD',
            'Dɔla Namibíà',
        ],
        'NIO' => [
            'NIO',
            'Kɔ̀dóbà Naikarágúà',
        ],
        'NOK' => [
            'NOK',
            'kórónì Nɔ́wè',
        ],
        'NPR' => [
            'NPR',
            'Rúpìì Nɛ̵́pààlì',
        ],
        'NZD' => [
            'NZ$',
            'Dɔ́là New Zealand',
        ],
        'PLN' => [
            'PLN',
            'Sílɔ̀tì Pɔ́líshì',
        ],
        'RUB' => [
            '₽',
            'Owó ruble ti ilɛ̀ Rɔ́shíà',
        ],
        'SAR' => [
            'SAR',
            'Riya ti Orílɛ́ède Saudi',
        ],
        'SBD' => [
            'SBD',
            'Dɔ́là Erékùsù Sɔ́lómɔ́nì',
        ],
        'SDG' => [
            'SDG',
            'Pɔ́n-ùn Sùdáànì',
        ],
        'SDP' => [
            'SDP',
            'Pɔɔun ti Orílɛ́ède Sudani',
        ],
        'SGD' => [
            'SGD',
            'Dɔ́là Síngápɔ̀',
        ],
        'SHP' => [
            'SHP',
            'Pɔ́n-un Elena',
        ],
        'SOS' => [
            'SOS',
            'Shílè Somali',
        ],
        'SRD' => [
            'SRD',
            'Dɔ́là Súrínámì',
        ],
        'SSP' => [
            'SSP',
            'Pɔ́n-un Gúúsù Sùdáànì',
        ],
        'STD' => [
            'STD',
            'Dobira ti Orílɛ́ède Sao tome Ati Pirisipe (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Dɔbíra Sao tome àti Pirisipi',
        ],
        'SYP' => [
            'SYP',
            'Pɔ́n-ùn Sírìà',
        ],
        'TMT' => [
            'TMT',
            'Mánààtì Tɔkimɛnístàànì',
        ],
        'TND' => [
            'TND',
            'Dínà Tunishíà',
        ],
        'TRY' => [
            'TRY',
            'Lírà Tɔ́kì',
        ],
        'TTD' => [
            'TTD',
            'Dɔ́là Trinidad & Tobago',
        ],
        'TWD' => [
            'NT$',
            'Dɔ́là Tàìwánì Tuntun',
        ],
        'UAH' => [
            'UAH',
            'Ɔrifiníyà Yukiréníà',
        ],
        'UGX' => [
            'UGX',
            'Shile Uganda',
        ],
        'USD' => [
            '$',
            'Dɔ́là',
        ],
        'UYU' => [
            'UYU',
            'Pɛ́sò Úrúgúwè',
        ],
        'UZS' => [
            'UZS',
            'Sómú Usibɛkísítàànì',
        ],
        'VES' => [
            'VES',
            'Bɔ̀lífà Fɛnɛsuɛ́là',
        ],
        'XCD' => [
            'EC$',
            'Dɔ́là Ilà Oòrùn Karíbíà',
        ],
        'XCG' => [
            'Cg.',
            'Owó ìlú Kùrásɔ̀ àti Saint Mátìnì',
        ],
        'XOF' => [
            'F CFA',
            'Faransì ìwɔ̀-oorùn Afíríkà',
        ],
        'YER' => [
            'YER',
            'Ráyò Yɛ́mɛ̀nì',
        ],
        'ZMK' => [
            'ZMK',
            'Kawasha ti Orílɛ́ède Saabia (1968–2012)',
        ],
        'ZWD' => [
            'ZWD',
            'Dɔla ti Orílɛ́ède Siibabuwe',
        ],
    ],
];
