<?php

return [
    'Names' => [
        'aa' => 'afarų',
        'ab' => 'abchazų',
        'ace' => 'ačinezų',
        'ach' => 'akolių',
        'ada' => 'adangmų',
        'ady' => 'adygėjų',
        'ae' => 'avestų',
        'aeb' => 'Tuniso arabų',
        'af' => 'afrikanų',
        'afh' => 'afrihili',
        'agq' => 'aghemų',
        'ain' => 'ainų',
        'ak' => 'akanų',
        'akk' => 'akadianų',
        'akz' => 'alabamiečių',
        'ale' => 'aleutų',
        'aln' => 'albanų kalbos gegų tarmė',
        'alt' => 'pietų Altajaus',
        'am' => 'amharų',
        'an' => 'aragonesų',
        'ang' => 'senoji anglų',
        'ann' => 'obolų',
        'anp' => 'angikų',
        'ar' => 'arabų',
        'arc' => 'aramaikų',
        'arn' => 'mapudungunų',
        'aro' => 'araonų',
        'arp' => 'arapahų',
        'arq' => 'Alžyro arabų',
        'ars' => 'arabų najdi',
        'arw' => 'aravakų',
        'ary' => 'Maroko arabų',
        'arz' => 'Egipto arabų',
        'as' => 'asamų',
        'asa' => 'asu',
        'ase' => 'Amerikos ženklų kalba',
        'ast' => 'asturianų',
        'atj' => 'atikamekų',
        'av' => 'avarikų',
        'avk' => 'kotava',
        'awa' => 'avadhi',
        'ay' => 'aimarų',
        'az' => 'azerbaidžaniečių',
        'ba' => 'baškirų',
        'bal' => 'baluči',
        'ban' => 'baliečių',
        'bar' => 'bavarų',
        'bas' => 'basų',
        'bax' => 'bamunų',
        'bbc' => 'batak toba',
        'bbj' => 'ghomalų',
        'be' => 'baltarusių',
        'bej' => 'bėjų',
        'bem' => 'bembų',
        'bew' => 'betavi',
        'bez' => 'benų',
        'bfd' => 'bafutų',
        'bfq' => 'badaga',
        'bg' => 'bulgarų',
        'bgc' => 'harijanvi',
        'bgn' => 'vakarų beludžių',
        'bho' => 'baučpuri',
        'bi' => 'bislama',
        'bik' => 'bikolų',
        'bin' => 'bini',
        'bjn' => 'bandžarų',
        'bkm' => 'komų',
        'bla' => 'siksikų',
        'blo' => 'guanų',
        'bm' => 'bambarų',
        'bn' => 'bengalų',
        'bo' => 'tibetiečių',
        'bpy' => 'bišnuprijos',
        'bqi' => 'bakhtiari',
        'br' => 'bretonų',
        'bra' => 'brajų',
        'brh' => 'brahujų',
        'brx' => 'bodo',
        'bs' => 'bosnių',
        'bss' => 'akūsų',
        'bua' => 'buriatų',
        'bug' => 'buginezų',
        'bum' => 'bulu',
        'byn' => 'blin',
        'byv' => 'medumbų',
        'ca' => 'katalonų',
        'cad' => 'kado',
        'car' => 'karibų',
        'cay' => 'kaijūgų',
        'cch' => 'atsamų',
        'ccp' => 'Čakma',
        'ce' => 'čečėnų',
        'ceb' => 'sebuanų',
        'cgg' => 'čigų',
        'ch' => 'čamorų',
        'chb' => 'čibčų',
        'chg' => 'čagatų',
        'chk' => 'čukesų',
        'chm' => 'marių',
        'chn' => 'činuk žargonas',
        'cho' => 'čoktau',
        'chp' => 'čipvėjų',
        'chr' => 'čerokių',
        'chy' => 'čajenų',
        'ckb' => 'soranių kurdų',
        'clc' => 'čilkotinų',
        'co' => 'korsikiečių',
        'cop' => 'koptų',
        'cps' => 'capiznon',
        'cr' => 'kry',
        'crg' => 'metisų',
        'crh' => 'Krymo turkų',
        'crj' => 'pietryčių kri',
        'crk' => 'supraprastinta kri',
        'crl' => 'šiaurės rytų kri',
        'crm' => 'muskri',
        'crr' => 'pamlikų',
        'crs' => 'Seišelių kreolų ir prancūzų',
        'cs' => 'čekų',
        'csb' => 'kašubų',
        'csw' => 'pelkynų kri',
        'cu' => 'bažnytinė slavų',
        'cv' => 'čiuvašų',
        'cy' => 'valų',
        'da' => 'danų',
        'dak' => 'dakotų',
        'dar' => 'dargva',
        'dav' => 'taitų',
        'de' => 'vokiečių',
        'del' => 'delavero',
        'den' => 'slave',
        'dgr' => 'dogribų',
        'din' => 'dinkų',
        'dje' => 'zarmų',
        'doi' => 'dogri',
        'dsb' => 'žemutinių sorbų',
        'dtp' => 'centrinio Dusuno',
        'dua' => 'dualų',
        'dum' => 'Vidurio Vokietijos',
        'dv' => 'divehų',
        'dyo' => 'džiola-foni',
        'dyu' => 'dyulų',
        'dz' => 'botijų',
        'dzg' => 'dazagų',
        'ebu' => 'embu',
        'ee' => 'evių',
        'efi' => 'efik',
        'egl' => 'italų kalbos Emilijos tarmė',
        'egy' => 'senovės egiptiečių',
        'eka' => 'ekajuk',
        'el' => 'graikų',
        'elx' => 'elamitų',
        'en' => 'anglų',
        'enm' => 'Vidurio Anglijos',
        'eo' => 'esperanto',
        'es' => 'ispanų',
        'esu' => 'centrinės Aliaskos jupikų',
        'et' => 'estų',
        'eu' => 'baskų',
        'ewo' => 'evondo',
        'ext' => 'ispanų kalbos Ekstremadūros tarmė',
        'fa' => 'persų',
        'fan' => 'fangų',
        'fat' => 'fanti',
        'ff' => 'fulahų',
        'fi' => 'suomių',
        'fil' => 'filipiniečių',
        'fit' => 'suomių kalbos Tornedalio tarmė',
        'fj' => 'fidžių',
        'fo' => 'farerų',
        'fon' => 'fon',
        'fr' => 'prancūzų',
        'frc' => 'kadžunų prancūzų',
        'frm' => 'Vidurio Prancūzijos',
        'fro' => 'senoji prancūzų',
        'frp' => 'arpitano',
        'frr' => 'šiaurinių fryzų',
        'frs' => 'rytų fryzų',
        'fur' => 'friulių',
        'fy' => 'vakarų fryzų',
        'ga' => 'airių',
        'gaa' => 'ga',
        'gag' => 'gagaūzų',
        'gan' => 'kinų kalbos dziangsi tarmė',
        'gay' => 'gajo',
        'gba' => 'gbaja',
        'gbz' => 'zoroastrų dari',
        'gd' => 'škotų (gėlų)',
        'gez' => 'gyz',
        'gil' => 'kiribati',
        'gl' => 'galisų',
        'glk' => 'gilaki',
        'gmh' => 'Vidurio Aukštosios Vokietijos',
        'gn' => 'gvaranių',
        'goh' => 'senoji Aukštosios Vokietijos',
        'gon' => 'gondi',
        'gor' => 'gorontalo',
        'got' => 'gotų',
        'grb' => 'grebo',
        'grc' => 'senovės graikų',
        'gsw' => 'Šveicarijos vokiečių',
        'gu' => 'gudžaratų',
        'guc' => 'vajų',
        'gur' => 'frafra',
        'guz' => 'gusi',
        'gv' => 'meniečių',
        'gwi' => 'gvičino',
        'ha' => 'hausų',
        'hai' => 'haido',
        'hak' => 'kinų kalbos hakų tarmė',
        'haw' => 'havajiečių',
        'hax' => 'Pietų Haidos',
        'he' => 'hebrajų',
        'hi' => 'hindi',
        'hif' => 'Fidžio hindi',
        'hil' => 'hiligainonų',
        'hit' => 'hititų',
        'hmn' => 'hmong',
        'ho' => 'hiri motu',
        'hr' => 'kroatų',
        'hsb' => 'aukštutinių sorbų',
        'hsn' => 'kinų kalbos hunano tarmė',
        'ht' => 'Haičio',
        'hu' => 'vengrų',
        'hup' => 'hupa',
        'hur' => 'halkomelemų',
        'hy' => 'armėnų',
        'hz' => 'hererų',
        'ia' => 'tarpinė',
        'iba' => 'iban',
        'ibb' => 'ibibijų',
        'id' => 'indoneziečių',
        'ie' => 'interkalba',
        'ig' => 'igbų',
        'ii' => 'sičuan ji',
        'ik' => 'inupiakų',
        'ikt' => 'vakarų kanadiečių inuktitutas',
        'ilo' => 'ilokų',
        'inh' => 'ingušų',
        'io' => 'ido',
        'is' => 'islandų',
        'it' => 'italų',
        'iu' => 'inukitut',
        'izh' => 'ingrų',
        'ja' => 'japonų',
        'jam' => 'Jamaikos kreolų anglų',
        'jbo' => 'loiban',
        'jgo' => 'ngombų',
        'jmc' => 'mačamų',
        'jpr' => 'judėjų persų',
        'jrb' => 'judėjų arabų',
        'jut' => 'danų kalbos jutų tarmė',
        'jv' => 'javiečių',
        'ka' => 'gruzinų',
        'kaa' => 'karakalpakų',
        'kab' => 'kebailų',
        'kac' => 'kačinų',
        'kaj' => 'ju',
        'kam' => 'kembų',
        'kaw' => 'kavių',
        'kbd' => 'kabardinų',
        'kbl' => 'kanembų',
        'kcg' => 'tyap',
        'kde' => 'makondų',
        'kea' => 'Žaliojo Kyšulio kreolų',
        'ken' => 'kenyang',
        'kfo' => 'koro',
        'kg' => 'Kongo',
        'kgp' => 'kaingang',
        'kha' => 'kasi',
        'kho' => 'kotanezų',
        'khq' => 'kojra čini',
        'khw' => 'khovarų',
        'ki' => 'kikujų',
        'kiu' => 'kirmanjki',
        'kj' => 'kuaniama',
        'kk' => 'kazachų',
        'kkj' => 'kako',
        'kl' => 'kalalisut',
        'kln' => 'kalenjinų',
        'km' => 'khmerų',
        'kmb' => 'kimbundu',
        'kn' => 'kanadų',
        'ko' => 'korėjiečių',
        'koi' => 'komių-permių',
        'kok' => 'konkanių',
        'kos' => 'kosreanų',
        'kpe' => 'kpelių',
        'kr' => 'kanurių',
        'krc' => 'karačiajų balkarijos',
        'kri' => 'krio',
        'krj' => 'kinaray-a',
        'krl' => 'karelų',
        'kru' => 'kuruk',
        'ks' => 'kašmyrų',
        'ksb' => 'šambalų',
        'ksf' => 'bafų',
        'ksh' => 'kolognų',
        'ku' => 'kurdų',
        'kum' => 'kumikų',
        'kut' => 'kutenai',
        'kv' => 'komi',
        'kw' => 'kornų',
        'kwk' => 'kvakvalų',
        'kxv' => 'kuvi',
        'ky' => 'kirgizų',
        'la' => 'lotynų',
        'lad' => 'ladino',
        'lag' => 'langi',
        'lah' => 'landa',
        'lam' => 'lamba',
        'lb' => 'liuksemburgiečių',
        'lez' => 'lezginų',
        'lfn' => 'naujoji frankų kalba',
        'lg' => 'ganda',
        'li' => 'limburgiečių',
        'lij' => 'ligūrų',
        'lil' => 'liluetų',
        'liv' => 'lyvių',
        'lkt' => 'lakotų',
        'lmo' => 'lombardų',
        'ln' => 'ngalų',
        'lo' => 'laosiečių',
        'lol' => 'mongų',
        'lou' => 'Luizianos kreolų',
        'loz' => 'lozių',
        'lrc' => 'šiaurės luri',
        'lsm' => 'samių',
        'lt' => 'lietuvių',
        'ltg' => 'latgalių',
        'lu' => 'luba katanga',
        'lua' => 'luba lulua',
        'lui' => 'luiseno',
        'lun' => 'Lundos',
        'lus' => 'mizo',
        'luy' => 'luja',
        'lv' => 'latvių',
        'lzh' => 'klasikinė kinų',
        'lzz' => 'laz',
        'mad' => 'madurezų',
        'maf' => 'mafų',
        'mag' => 'magahi',
        'mai' => 'maithili',
        'mak' => 'Makasaro',
        'man' => 'mandingų',
        'mas' => 'masajų',
        'mde' => 'mabų',
        'mdf' => 'mokša',
        'mdr' => 'mandarų',
        'men' => 'mende',
        'mer' => 'merų',
        'mfe' => 'morisijų',
        'mg' => 'malagasų',
        'mga' => 'Vidurio Airijos',
        'mgh' => 'makua-maeto',
        'mgo' => 'meta',
        'mh' => 'Maršalo Salų',
        'mi' => 'maorių',
        'mic' => 'mikmakų',
        'min' => 'minangkabau',
        'mk' => 'makedonų',
        'ml' => 'malajalių',
        'mn' => 'mongolų',
        'mnc' => 'manču',
        'mni' => 'manipurių',
        'moe' => 'montanjų',
        'moh' => 'mohok',
        'mos' => 'mosi',
        'mr' => 'maratų',
        'mrj' => 'vakarų mari',
        'ms' => 'malajiečių',
        'mt' => 'maltiečių',
        'mua' => 'mundangų',
        'mus' => 'krykų',
        'mwl' => 'mirandezų',
        'mwr' => 'marvari',
        'mwv' => 'mentavai',
        'my' => 'birmiečių',
        'mye' => 'mjenų',
        'myv' => 'erzyjų',
        'mzn' => 'mazenderanių',
        'na' => 'naurų',
        'nan' => 'kinų kalbos pietų minų tarmė',
        'nap' => 'neapoliečių',
        'naq' => 'nama',
        'nb' => 'norvegų bukmolas',
        'nd' => 'šiaurės ndebelų',
        'nds' => 'Žemutinės Vokietijos',
        'ne' => 'nepaliečių',
        'new' => 'nevari',
        'ng' => 'ndongų',
        'nia' => 'nias',
        'niu' => 'niujiečių',
        'njo' => 'ao naga',
        'nl' => 'olandų',
        'nmg' => 'kvasių',
        'nn' => 'naujoji norvegų',
        'nnh' => 'ngiembūnų',
        'no' => 'norvegų',
        'nog' => 'nogų',
        'non' => 'senoji norsų',
        'nov' => 'novial',
        'nqo' => 'enko',
        'nr' => 'pietų ndebele',
        'nso' => 'šiaurės Soto',
        'nus' => 'nuerų',
        'nv' => 'navajų',
        'nwc' => 'klasikinė nevari',
        'ny' => 'nianjų',
        'nym' => 'niamvezi',
        'nyn' => 'niankolų',
        'nyo' => 'niorų',
        'nzi' => 'nzima',
        'oc' => 'očitarų',
        'oj' => 'ojibva',
        'ojb' => 'šiaurės vakarų odžibvių',
        'ojc' => 'ojibvų',
        'ojs' => 'odži kri',
        'ojw' => 'vakarų odžibvių',
        'oka' => 'okanaganų',
        'om' => 'oromų',
        'or' => 'odijų',
        'os' => 'osetinų',
        'osa' => 'osage',
        'ota' => 'osmanų turkų',
        'pa' => 'pendžabų',
        'pag' => 'pangasinanų',
        'pal' => 'vidurinė persų kalba',
        'pam' => 'pampangų',
        'pap' => 'papiamento',
        'pau' => 'palauliečių',
        'pcd' => 'pikardų',
        'pcm' => 'Nigerijos pidžinų',
        'pdc' => 'Pensilvanijos vokiečių',
        'pdt' => 'vokiečių kalbos žemaičių tarmė',
        'peo' => 'senoji persų',
        'pfl' => 'vokiečių kalbos Pfalco tarmė',
        'phn' => 'finikiečių',
        'pi' => 'pali',
        'pis' => 'pidžinų',
        'pl' => 'lenkų',
        'pms' => 'italų kalbos Pjemonto tarmė',
        'pnt' => 'Ponto',
        'pon' => 'Ponapės',
        'pqm' => 'Maliset-Pasamakvodžio',
        'prg' => 'prūsų',
        'pro' => 'senovės provansalų',
        'ps' => 'puštūnų',
        'pt' => 'portugalų',
        'qu' => 'kečujų',
        'quc' => 'kičių',
        'qug' => 'Čimboraso aukštumų kečujų',
        'raj' => 'Radžastano',
        'rap' => 'rapanui',
        'rar' => 'rarotonganų',
        'rgn' => 'italų kalbos Romanijos tarmė',
        'rhg' => 'rochindža',
        'rif' => 'rifų',
        'rm' => 'retoromanų',
        'rn' => 'rundi',
        'ro' => 'rumunų',
        'rof' => 'rombo',
        'rom' => 'romų',
        'rtm' => 'rotumanų',
        'ru' => 'rusų',
        'rue' => 'rusinų',
        'rug' => 'Rovianos',
        'rup' => 'aromanių',
        'rw' => 'kinjaruandų',
        'rwk' => 'rua',
        'sa' => 'sanskritas',
        'sad' => 'sandavių',
        'sah' => 'jakutų',
        'sam' => 'samarėjų aramių',
        'saq' => 'sambūrų',
        'sas' => 'sasak',
        'sat' => 'santalių',
        'saz' => 'sauraštrų',
        'sba' => 'ngambajų',
        'sbp' => 'sangų',
        'sc' => 'sardiniečių',
        'scn' => 'siciliečių',
        'sco' => 'škotų',
        'sd' => 'sindų',
        'sdc' => 'sasaresų sardinų',
        'sdh' => 'pietų kurdų',
        'se' => 'šiaurės samių',
        'see' => 'senecų',
        'seh' => 'senų',
        'sei' => 'seri',
        'sel' => 'selkup',
        'ses' => 'kojraboro seni',
        'sg' => 'sango',
        'sga' => 'senoji airių',
        'sgs' => 'žemaičių',
        'sh' => 'serbų-kroatų',
        'shi' => 'tachelhitų',
        'shn' => 'šan',
        'shu' => 'chadian arabų',
        'si' => 'sinhalų',
        'sid' => 'sidamų',
        'sk' => 'slovakų',
        'sl' => 'slovėnų',
        'slh' => 'pietų lushusidų',
        'sli' => 'sileziečių žemaičių',
        'sly' => 'selajarų',
        'sm' => 'Samoa',
        'sma' => 'pietų samių',
        'smj' => 'Liuleo samių',
        'smn' => 'Inario samių',
        'sms' => 'Skolto samių',
        'sn' => 'šonų',
        'snk' => 'soninke',
        'so' => 'somaliečių',
        'sog' => 'sogdien',
        'sq' => 'albanų',
        'sr' => 'serbų',
        'srn' => 'sranan tongo',
        'srr' => 'sererų',
        'ss' => 'svatų',
        'ssy' => 'saho',
        'st' => 'pietų Soto',
        'stq' => 'Saterlendo fryzų',
        'str' => 'Sališo sąsiaurio',
        'su' => 'sundų',
        'suk' => 'sukuma',
        'sus' => 'susu',
        'sux' => 'šumerų',
        'sv' => 'švedų',
        'sw' => 'suahilių',
        'swb' => 'komorų',
        'syc' => 'klasikinė sirų',
        'syr' => 'sirų',
        'szl' => 'sileziečių',
        'ta' => 'tamilų',
        'tce' => 'pietų tučonų',
        'tcy' => 'tulų',
        'te' => 'telugų',
        'tem' => 'timne',
        'teo' => 'teso',
        'ter' => 'Tereno',
        'tet' => 'tetum',
        'tg' => 'tadžikų',
        'tgx' => 'tagišų',
        'th' => 'tajų',
        'tht' => 'taltanų',
        'ti' => 'tigrajų',
        'tig' => 'tigre',
        'tiv' => 'tiv',
        'tk' => 'turkmėnų',
        'tkl' => 'Tokelau',
        'tkr' => 'tsakurų',
        'tl' => 'tagalogų',
        'tlh' => 'klingonų',
        'tli' => 'tlingitų',
        'tly' => 'talyšų',
        'tmh' => 'tamašek',
        'tn' => 'tsvanų',
        'to' => 'tonganų',
        'tog' => 'niasa tongų',
        'tok' => 'Toki Pona',
        'tpi' => 'Papua pidžinų',
        'tr' => 'turkų',
        'tru' => 'turoyo',
        'trv' => 'Taroko',
        'ts' => 'tsongų',
        'tsd' => 'tsakonų',
        'tsi' => 'tsimšian',
        'tt' => 'totorių',
        'ttm' => 'šiaurės tutsonų',
        'ttt' => 'musulmonų tatų',
        'tum' => 'tumbukų',
        'tvl' => 'Tuvalu',
        'tw' => 'tvi',
        'twq' => 'tasavakų',
        'ty' => 'taitiečių',
        'tyv' => 'tuvių',
        'tzm' => 'Centrinio Maroko tamazitų',
        'udm' => 'udmurtų',
        'ug' => 'uigūrų',
        'uga' => 'ugaritų',
        'uk' => 'ukrainiečių',
        'umb' => 'umbundu',
        'ur' => 'urdų',
        'uz' => 'uzbekų',
        've' => 'vendų',
        'vec' => 'venetų',
        'vep' => 'vepsų',
        'vi' => 'vietnamiečių',
        'vls' => 'vakarų flamandų',
        'vmf' => 'pagrindinė frankonų',
        'vmw' => 'makua',
        'vo' => 'volapiuko',
        'vot' => 'Votik',
        'vro' => 'veru',
        'vun' => 'vunjo',
        'wa' => 'valonų',
        'wae' => 'valserų',
        'wal' => 'valamo',
        'war' => 'varai',
        'was' => 'Vašo',
        'wbp' => 'valrpiri',
        'wo' => 'volofų',
        'wuu' => 'kinų kalbos vu tarmė',
        'xal' => 'kalmukų',
        'xh' => 'kosų',
        'xmf' => 'megrelų',
        'xnr' => 'kangri',
        'xog' => 'sogų',
        'yao' => 'jao',
        'yap' => 'japezų',
        'yav' => 'jangbenų',
        'ybb' => 'jembų',
        'yi' => 'jidiš',
        'yo' => 'jorubų',
        'yrl' => 'njengatu',
        'yue' => 'kinų kalbos Kantono tarmė',
        'za' => 'chuang',
        'zap' => 'zapotekų',
        'zbl' => 'BLISS simbolių',
        'zea' => 'zelandų',
        'zen' => 'zenaga',
        'zgh' => 'standartinė Maroko tamazigtų',
        'zh' => 'kinų',
        'zu' => 'zulų',
        'zun' => 'Zuni',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'šiuolaikinė standartinė arabų',
        'de_AT' => 'Austrijos vokiečių',
        'de_CH' => 'Šveicarijos aukštutinė vokiečių',
        'en_AU' => 'Australijos anglų',
        'en_CA' => 'Kanados anglų',
        'en_GB' => 'Didžiosios Britanijos anglų',
        'en_US' => 'Jungtinių Valstijų anglų',
        'fr_CA' => 'Kanados prancūzų',
        'fr_CH' => 'Šveicarijos prancūzų',
        'nds_NL' => 'Žemutinės Saksonijos (Nyderlandai)',
        'nl_BE' => 'flamandų',
        'ro_MD' => 'moldavų',
        'sw_CD' => 'Kongo suahilių',
        'zh_Hans' => 'supaprastintoji kinų',
        'zh_Hant' => 'tradicinė kinų',
    ],
];
