<?php

return [
    'Names' => [
        'cy' => 'Sewelsh',
        'en' => 'Senyesemane',
        'en_LS' => 'Senyesemane (Lesotho)',
        'en_ZA' => 'Senyesemane (Afrika Borwa)',
        'st' => 'Sesotho',
        'st_LS' => 'Sesotho (Lesotho)',
        'st_ZA' => 'Sesotho (Afrika Borwa)',
    ],
];
