<?php return array(
    'root' => array(
        'name' => 'simplesamlphp/simplesamlphp',
        'pretty_version' => 'v2.4.8',
        'version' => '2.4.8.0',
        'reference' => null,
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'gettext/gettext' => array(
            'pretty_version' => 'v5.7.3',
            'version' => '5.7.3.0',
            'reference' => '95820f020e4f2f05e0bbaa5603e4c6ec3edc50f1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gettext/gettext',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'gettext/languages' => array(
            'pretty_version' => '2.12.2',
            'version' => '2.12.2.0',
            'reference' => '079d6f4842cbcbf5673a70d8e93169a684e7aadd',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gettext/languages',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'gettext/translator' => array(
            'pretty_version' => 'v1.2.3',
            'version' => '1.2.3.0',
            'reference' => 'e6d96e03d8c1afb3ef497799921ad0adfc9f4f96',
            'type' => 'library',
            'install_path' => __DIR__ . '/../gettext/translator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.12.3',
            'version' => '2.12.3.0',
            'reference' => '7ec62dc3f44aa218487dbed81a9bf9bc647be55d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nyholm/psr7' => array(
            'pretty_version' => '1.8.2',
            'version' => '1.8.2.0',
            'reference' => 'a71f2b11690f4b24d099d6b16690a90ae14fc6f3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../nyholm/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/message-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'phpmailer/phpmailer' => array(
            'pretty_version' => 'v6.12.0',
            'version' => '6.12.0.0',
            'reference' => 'd1ac35d784bf9f5e61b424901d5a014967f15b12',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpmailer/phpmailer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/cache' => array(
            'pretty_version' => '3.0.0',
            'version' => '3.0.0.0',
            'reference' => 'aa5030cfa5405eccfdcb1083ce040c2cb8d253bf',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/cache-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '2.0|3.0',
            ),
        ),
        'psr/clock' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'e41a24703d4560fd0acb709162f73b8adfc3aa0d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/clock',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/container' => array(
            'pretty_version' => '2.0.2',
            'version' => '2.0.2.0',
            'reference' => 'c71ecc56dfe541dbd90c5360474fbc405f8d5963',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/container',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/container-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.1|2.0',
            ),
        ),
        'psr/event-dispatcher' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'dbefd12671e8a14ec7f180cab83036ed26714bb0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/event-dispatcher',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/event-dispatcher-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '2b4765fddfe3b508ac62f829e852b1501d3f6e8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '2.0',
            'version' => '2.0.0.0',
            'reference' => '402d35bcb92c70c026d1a6a9883f06b2ead23d71',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/log' => array(
            'pretty_version' => '3.0.2',
            'version' => '3.0.2.0',
            'reference' => 'f16e1d5863e37f8d8c2a01719f5b34baa2b714d3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0|2.0|3.0',
            ),
        ),
        'psr/simple-cache-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0|2.0|3.0',
            ),
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'robrichards/xmlseclibs' => array(
            'pretty_version' => '3.1.5',
            'version' => '3.1.5.0',
            'reference' => '03062be78178cbb5e8f605cd255dc32a14981f92',
            'type' => 'library',
            'install_path' => __DIR__ . '/../robrichards/xmlseclibs',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/assert' => array(
            'pretty_version' => 'v1.8.4',
            'version' => '1.8.4.0',
            'reference' => '7250fb858b025032590078fc4cc52a4c1b634dbb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../simplesamlphp/assert',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/composer-module-installer' => array(
            'pretty_version' => 'v1.4.0',
            'version' => '1.4.0.0',
            'reference' => 'edb2155d200e2a208816d06f42cfa78bfd9e7cf4',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../simplesamlphp/composer-module-installer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/composer-xmlprovider-installer' => array(
            'pretty_version' => 'v1.0.2',
            'version' => '1.0.2.0',
            'reference' => '3d882187b5b0b404c381a2e4d17498ca4b2785b3',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../simplesamlphp/composer-xmlprovider-installer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/saml2' => array(
            'pretty_version' => 'v5.0.6',
            'version' => '5.0.6.0',
            'reference' => 'a2c1ac588c70d7b7998546cf32675fb113f22a5f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../simplesamlphp/saml2',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/saml2-legacy' => array(
            'pretty_version' => 'v4.19.3',
            'version' => '4.19.3.0',
            'reference' => '7f1217a6296df3a89565ec7cd121bfe2e76e2bdc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../simplesamlphp/saml2-legacy',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/simplesamlphp' => array(
            'pretty_version' => 'v2.4.8',
            'version' => '2.4.8.0',
            'reference' => null,
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/simplesamlphp-assets-base' => array(
            'pretty_version' => 'v2.4.8',
            'version' => '2.4.8.0',
            'reference' => '4837aa3408f669e48c62e8b146b3ad2a27d8336d',
            'type' => 'simplesamlphp-module',
            'install_path' => __DIR__ . '/../../public/assets/base',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/xml-common' => array(
            'pretty_version' => 'v1.25.1',
            'version' => '1.25.1.0',
            'reference' => '999603aa521d91e17b562bb0b498513af80eb190',
            'type' => 'simplesamlphp-xmlprovider',
            'install_path' => __DIR__ . '/../simplesamlphp/xml-common',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/xml-security' => array(
            'pretty_version' => 'v1.13.9',
            'version' => '1.13.9.0',
            'reference' => '16a5cf4a107e1b607337ff5af5fb4051fcc23ba0',
            'type' => 'simplesamlphp-xmlprovider',
            'install_path' => __DIR__ . '/../simplesamlphp/xml-security',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simplesamlphp/xml-soap' => array(
            'pretty_version' => 'v1.7.1',
            'version' => '1.7.1.0',
            'reference' => 'ca1ee4ea29c62fa66fc30d040b4013b4543f4f76',
            'type' => 'simplesamlphp-xmlprovider',
            'install_path' => __DIR__ . '/../simplesamlphp/xml-soap',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/cache' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '704edf29f1c97ff6e36e248def6ff4a51f765ce1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/cache-contracts' => array(
            'pretty_version' => 'v3.7.1',
            'version' => '3.7.1.0',
            'reference' => '9789738bc19af1106dc54d6afba9a0b467516cf2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/cache-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/cache-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.1|2.0|3.0',
            ),
        ),
        'symfony/config' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '922d980c90a69ffdd63e6ee551efb338b58be677',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/config',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/console' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '9ef84af84a7b66396da483634227650506428639',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/console',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/dependency-injection' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => 'ba3538ae8d14dd9a3a8758229e8ddaeff1a23643',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/dependency-injection',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/deprecation-contracts' => array(
            'pretty_version' => 'v3.7.1',
            'version' => '3.7.1.0',
            'reference' => 'f3202fa1b5097b0af062dc978b32ecf63404e31d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/error-handler' => array(
            'pretty_version' => 'v6.4.36',
            'version' => '6.4.36.0',
            'reference' => '2ea68f0e1835ad6a126f93bbc14cd236c10ab361',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/error-handler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/event-dispatcher' => array(
            'pretty_version' => 'v6.4.37',
            'version' => '6.4.37.0',
            'reference' => '2e3bf817ba9347341ab15926700fb6320367c0e1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/event-dispatcher',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/event-dispatcher-contracts' => array(
            'pretty_version' => 'v3.7.1',
            'version' => '3.7.1.0',
            'reference' => 'c7de7a00ffb67842132da02ea92988a39ccd9f4e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/event-dispatcher-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/event-dispatcher-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '2.0|3.0',
            ),
        ),
        'symfony/expression-language' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '728f0c48560a851e83681dc03efefa65d5fc076e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/expression-language',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/filesystem' => array(
            'pretty_version' => 'v6.4.39',
            'version' => '6.4.39.0',
            'reference' => 'c507b077756b4e3e09adbbe7975fac81cd3722ca',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/filesystem',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/finder' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '0b73dac42493acbadbba644207a715b254e9b029',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/finder',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/framework-bundle' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => 'fde24f8e5f6aeadbc092ed894d569846c8bc1304',
            'type' => 'symfony-bundle',
            'install_path' => __DIR__ . '/../symfony/framework-bundle',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-foundation' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '23dcf8e0f59cbbfa9d2894f58fd8be6833794372',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-foundation',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-kernel' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '51fd5bb7d4f221ceeac927e14ade63962e27a47c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-kernel',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/intl' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '65e85c6665bb4b4b1c2214a8e89eb30acc20468a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/intl',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/password-hasher' => array(
            'pretty_version' => 'v6.4.32',
            'version' => '6.4.32.0',
            'reference' => 'fbdfa5a2ca218ec8bb9029517426df2d780bdba9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/password-hasher',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-ctype' => array(
            'pretty_version' => 'v1.37.0',
            'version' => '1.37.0.0',
            'reference' => '141046a8f9477948ff284fa65be2095baafb94f2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-ctype',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-grapheme' => array(
            'pretty_version' => 'v1.38.1',
            'version' => '1.38.1.0',
            'reference' => 'e9247d281d694a5120554d9afaf54e070e88a603',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-grapheme',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-icu' => array(
            'pretty_version' => 'v1.38.0',
            'version' => '1.38.0.0',
            'reference' => '445c90e341fccda10311019cf82ff73bb7343945',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-icu',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-normalizer' => array(
            'pretty_version' => 'v1.38.0',
            'version' => '1.38.0.0',
            'reference' => '2d446c214bdbe5b71bde5011b060a05fece3ae6b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-normalizer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-mbstring' => array(
            'pretty_version' => 'v1.38.2',
            'version' => '1.38.2.0',
            'reference' => 'd3d318bad5e7a1bfbd026009c8bfb8d8f99ae6b6',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-mbstring',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'pretty_version' => 'v1.37.0',
            'version' => '1.37.0.0',
            'reference' => 'dfb55726c3a76ea3b6459fcfda1ec2d80a682411',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php80',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php83' => array(
            'pretty_version' => 'v1.38.2',
            'version' => '1.38.2.0',
            'reference' => '796a26abb75ce49f3a84433cd81bf1009d73d5f8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php83',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/routing' => array(
            'pretty_version' => 'v6.4.41',
            'version' => '6.4.41.0',
            'reference' => 'af04c79671fd8df0805a44c83fa2b0ba56c8329e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/routing',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/service-contracts' => array(
            'pretty_version' => 'v3.7.1',
            'version' => '3.7.1.0',
            'reference' => 'c0a284bab1ed8aa0417e3d69250ab437739563a0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/service-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/service-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.1|2.0|3.0',
            ),
        ),
        'symfony/string' => array(
            'pretty_version' => 'v6.4.39',
            'version' => '6.4.39.0',
            'reference' => '62e3c927de664edadb5bef260987eb047a17a113',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/string',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation-contracts' => array(
            'pretty_version' => 'v3.7.1',
            'version' => '3.7.1.0',
            'reference' => 'ccb206b98faccc511ebae8e5fad50f2dc0b30621',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/translation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/twig-bridge' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => 'bc8a4cad8d95722666ce4a572cdbc96f7a50bdbb',
            'type' => 'symfony-bridge',
            'install_path' => __DIR__ . '/../symfony/twig-bridge',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/var-dumper' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '29adc5e34255f42ca9b8ae61c22b4d9e3f611317',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/var-dumper',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/var-exporter' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '15e670e0218bfe4efbc0556b8a12ad1304f4c7f4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/var-exporter',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/yaml' => array(
            'pretty_version' => 'v6.4.42',
            'version' => '6.4.42.0',
            'reference' => '989dfb75049b77884f3f8cf9e99f103c8f91ca1c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/yaml',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'twig/intl-extra' => array(
            'pretty_version' => 'v3.26.0',
            'version' => '3.26.0.0',
            'reference' => '98f5ad5bff13230fcd2d834d9e79b50adf3ccda9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../twig/intl-extra',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'twig/twig' => array(
            'pretty_version' => 'v3.28.0',
            'version' => '3.28.0.0',
            'reference' => '597c12ed286fb9d1701a36684ce6e0cbe28ebc8b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../twig/twig',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'webmozart/assert' => array(
            'pretty_version' => '1.11.0',
            'version' => '1.11.0.0',
            'reference' => '11cb2199493b2f8a3b53e7f19068fc6aac760991',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/assert',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
