<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'peseta andorrana',
        ],
        'AED' => [
            'AED',
            'dirham dals Emirats Arabs Unids',
        ],
        'AFA' => [
            'AFA',
            'afgani afgan (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'afgani afgan',
        ],
        'ALK' => [
            'ALK',
            'lek albanais (1947–1961)',
        ],
        'ALL' => [
            'ALL',
            'lek albanais',
        ],
        'AMD' => [
            'AMD',
            'dram da l’Armenia',
        ],
        'ANG' => [
            'ANG',
            'flurin da las Antillas Ollandaisas',
        ],
        'AOA' => [
            'AOA',
            'kwanza angolan',
        ],
        'AOK' => [
            'AOK',
            'kwanza angolan (1977–1991)',
        ],
        'AON' => [
            'AON',
            'nov kwanza angolan (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'kwanza angolan reagiustà (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'austral argentin',
        ],
        'ARL' => [
            'ARL',
            'peso argentin ley',
        ],
        'ARM' => [
            'ARM',
            'peso argentin moneda nacional',
        ],
        'ARP' => [
            'ARP',
            'peso argentin (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'peso argentin',
        ],
        'ATS' => [
            'ATS',
            'schilling austriac',
        ],
        'AUD' => [
            'A$',
            'dollar australian',
        ],
        'AWG' => [
            'AWG',
            'flurin da l’Aruba',
        ],
        'AZM' => [
            'AZM',
            'manat aserbaidschan (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'manat aserbaidschan',
        ],
        'BAD' => [
            'BAD',
            'dinar da la Bosnia-Erzegovina (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'marc convertibel da la Bosnia-Erzegovina',
        ],
        'BAN' => [
            'BAN',
            'nov dinar da la Bosnia-Erzegovina (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'dollar da Barbados',
        ],
        'BDT' => [
            'BDT',
            'taka dal Bangladesch',
        ],
        'BEC' => [
            'BEC',
            'franc beltg (convertibel)',
        ],
        'BEF' => [
            'BEF',
            'franc beltg',
        ],
        'BEL' => [
            'BEL',
            'franc beltg (finanzial)',
        ],
        'BGL' => [
            'BGL',
            'lev bulgar dir',
        ],
        'BGM' => [
            'BGM',
            'lev bulgar socialistic',
        ],
        'BGN' => [
            'BGN',
            'lev bulgar',
        ],
        'BGO' => [
            'BGO',
            'lev bulgar (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'dinar dal Bahrain',
        ],
        'BIF' => [
            'BIF',
            'franc dal Burundi',
        ],
        'BMD' => [
            'BMD',
            'dollar da las Bermudas',
        ],
        'BND' => [
            'BND',
            'dollar dal Brunei',
        ],
        'BOB' => [
            'BOB',
            'boliviano bolivian',
        ],
        'BOL' => [
            'BOL',
            'vegl boliviano',
        ],
        'BOP' => [
            'BOP',
            'peso bolivian',
        ],
        'BOV' => [
            'BOV',
            'mvdol bolivian',
        ],
        'BRB' => [
            'BRB',
            'cruzeiro novo brasilian (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'cruzado brasilian',
        ],
        'BRE' => [
            'BRE',
            'cruzeiro brasilian (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'real brasilian',
        ],
        'BRN' => [
            'BRN',
            'cruzado novo brasilian',
        ],
        'BRR' => [
            'BRR',
            'cruzeiro brasilian',
        ],
        'BRZ' => [
            'BRZ',
            'vegl cruzeiro brasilian',
        ],
        'BSD' => [
            'BSD',
            'dollar da las Bahamas',
        ],
        'BTN' => [
            'BTN',
            'ngultrum dal Butan',
        ],
        'BUK' => [
            'BUK',
            'kyat burmais',
        ],
        'BWP' => [
            'BWP',
            'pula da la Botsuana',
        ],
        'BYB' => [
            'BYB',
            'rubel bieloruss (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'rubel bieloruss',
        ],
        'BYR' => [
            'BYR',
            'rubel bieloruss (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'dollar dal Belize',
        ],
        'CAD' => [
            'CA$',
            'dollar canadais',
        ],
        'CDF' => [
            'CDF',
            'franc congolais',
        ],
        'CHE' => [
            'CHE',
            'euro WIR',
        ],
        'CHF' => [
            'CHF',
            'franc svizzer',
        ],
        'CHW' => [
            'CHW',
            'franc WIR',
        ],
        'CLE' => [
            'CLE',
            'escudo chilen',
        ],
        'CLF' => [
            'CLF',
            'unidades de fomento chilenas',
        ],
        'CLP' => [
            'CLP',
            'peso chilen',
        ],
        'CNH' => [
            'CNH',
            'yuan chinais (offshore)',
        ],
        'CNY' => [
            'CN¥',
            'yuan chinais',
        ],
        'COP' => [
            'COP',
            'peso columbian',
        ],
        'COU' => [
            'COU',
            'unidad de valor real',
        ],
        'CRC' => [
            'CRC',
            'colón da la Costa Rica',
        ],
        'CSD' => [
            'CSD',
            'dinar serb (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'cruna tschecoslovaca',
        ],
        'CUC' => [
            'CUC',
            'peso cuban convertibel',
        ],
        'CUP' => [
            'CUP',
            'peso cuban',
        ],
        'CVE' => [
            'CVE',
            'escudo dal Cap Verd',
        ],
        'CYP' => [
            'CYP',
            'glivra cipriota',
        ],
        'CZK' => [
            'CZK',
            'curuna tscheca',
        ],
        'DDM' => [
            'DDM',
            'marc da la Germania da l’Ost',
        ],
        'DEM' => [
            'DEM',
            'marc tudestg',
        ],
        'DJF' => [
            'DJF',
            'franc dal Dschibuti',
        ],
        'DKK' => [
            'DKK',
            'curuna danaisa',
        ],
        'DOP' => [
            'DOP',
            'peso dominican',
        ],
        'DZD' => [
            'DZD',
            'dinar algerian',
        ],
        'ECS' => [
            'ECS',
            'sucre equadorian',
        ],
        'ECV' => [
            'ECV',
            'unitad da scuntrada da l’Ecuador',
        ],
        'EEK' => [
            'EEK',
            'cruna estona',
        ],
        'EGP' => [
            'EGP',
            'glivra egipziana',
        ],
        'ERN' => [
            'ERN',
            'nakfa da l’Eritrea',
        ],
        'ESA' => [
            'ESA',
            'peseta spagnola (conto A)',
        ],
        'ESB' => [
            'ESB',
            'peseta spagnola (conto convertibel)',
        ],
        'ESP' => [
            'ESP',
            'peseta spagnola',
        ],
        'ETB' => [
            'ETB',
            'birr etiopic',
        ],
        'EUR' => [
            '€',
            'euro',
        ],
        'FIM' => [
            'FIM',
            'marc finlandais',
        ],
        'FJD' => [
            'FJD',
            'dollar dal Fidschi',
        ],
        'FKP' => [
            'FKP',
            'glivra dal Falkland',
        ],
        'FRF' => [
            'FRF',
            'franc franzos',
        ],
        'GBP' => [
            '£',
            'glivra sterlina',
        ],
        'GEK' => [
            'GEK',
            'kupon larit georgian',
        ],
        'GEL' => [
            'GEL',
            'lari georgian',
        ],
        'GHC' => [
            'GHC',
            'cedi ghanais (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'cedi ghanais',
        ],
        'GIP' => [
            'GIP',
            'glivra da Gibraltar',
        ],
        'GMD' => [
            'GMD',
            'dalasi da la Gambia',
        ],
        'GNF' => [
            'GNF',
            'franc da la Guinea',
        ],
        'GNS' => [
            'GNS',
            'syli da la Guinea',
        ],
        'GQE' => [
            'GQE',
            'ekwele da la Guinea Equatoriala',
        ],
        'GRD' => [
            'GRD',
            'drachma greca',
        ],
        'GTQ' => [
            'GTQ',
            'quetzal da la Guatemala',
        ],
        'GWE' => [
            'GWE',
            'escudo da la Guinea Portugaisa',
        ],
        'GWP' => [
            'GWP',
            'peso da la Guinea-Bissau',
        ],
        'GYD' => [
            'GYD',
            'dollar da la Guyana',
        ],
        'HKD' => [
            'HK$',
            'dollar da Hongkong',
        ],
        'HNL' => [
            'HNL',
            'lempira honduriana',
        ],
        'HRD' => [
            'HRD',
            'dinar croat',
        ],
        'HRK' => [
            'HRK',
            'kuna croata',
        ],
        'HTG' => [
            'HTG',
            'gourde haitian',
        ],
        'HUF' => [
            'HUF',
            'forint ungarais',
        ],
        'IDR' => [
            'IDR',
            'rupia indonaisa',
        ],
        'IEP' => [
            'IEP',
            'glivra indonaisa',
        ],
        'ILP' => [
            'ILP',
            'glivra israeliana',
        ],
        'ILR' => [
            'ILR',
            'schekel israelian (1980–1985)',
        ],
        'ILS' => [
            '₪',
            'nov shekel israelian',
        ],
        'INR' => [
            '₹',
            'rupia indica',
        ],
        'IQD' => [
            'IQD',
            'dinar iracais',
        ],
        'IRR' => [
            'IRR',
            'rial iranais',
        ],
        'ISJ' => [
            'ISJ',
            'veglia cruna islandaisa',
        ],
        'ISK' => [
            'ISK',
            'curuna islandaisa',
        ],
        'ITL' => [
            'ITL',
            'lira taliana',
        ],
        'JMD' => [
            'JMD',
            'dollar giamaican',
        ],
        'JOD' => [
            'JOD',
            'dinar jordanic',
        ],
        'JPY' => [
            'JP¥',
            'yen giapunais',
        ],
        'KES' => [
            'KES',
            'schilling kenian',
        ],
        'KGS' => [
            'KGS',
            'som kirghis',
        ],
        'KHR' => [
            'KHR',
            'riel cambodschan',
        ],
        'KMF' => [
            'KMF',
            'franc da las Comoras',
        ],
        'KPW' => [
            'KPW',
            'won da la Corea dal Nord',
        ],
        'KRH' => [
            'KRH',
            'hwan da la Corea dal Sid (1953–1962)',
        ],
        'KRO' => [
            'KRO',
            'won da la Corea dal Sid (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'won da la Corea dal Sid',
        ],
        'KWD' => [
            'KWD',
            'dinar dal Kuwait',
        ],
        'KYD' => [
            'KYD',
            'dollar da las Inslas Cayman',
        ],
        'KZT' => [
            'KZT',
            'tenge kasac',
        ],
        'LAK' => [
            'LAK',
            'kip laot',
        ],
        'LBP' => [
            'LBP',
            'glivra libanaisa',
        ],
        'LKR' => [
            'LKR',
            'rupia da la Sri Lanka',
        ],
        'LRD' => [
            'LRD',
            'dollar liberian',
        ],
        'LSL' => [
            'LSL',
            'loti dal Lesotho',
        ],
        'LTL' => [
            'LTL',
            'litas lituan',
        ],
        'LTT' => [
            'LTT',
            'talonas lituan',
        ],
        'LUC' => [
            'LUC',
            'franc convertibel luxemburgais',
        ],
        'LUF' => [
            'LUF',
            'franc luxemburgais',
        ],
        'LUL' => [
            'LUL',
            'franc finanzial luxemburgais',
        ],
        'LVL' => [
            'LVL',
            'lats letton',
        ],
        'LVR' => [
            'LVR',
            'rubel letton',
        ],
        'LYD' => [
            'LYD',
            'dinar libic',
        ],
        'MAD' => [
            'MAD',
            'dirham marocan',
        ],
        'MAF' => [
            'MAF',
            'franc marocan',
        ],
        'MCF' => [
            'MCF',
            'franc monegass',
        ],
        'MDC' => [
            'MDC',
            'cupon moldav',
        ],
        'MDL' => [
            'MDL',
            'leu moldav',
        ],
        'MGA' => [
            'MGA',
            'ariary madagasc',
        ],
        'MGF' => [
            'MGF',
            'franc madagasc',
        ],
        'MKD' => [
            'MKD',
            'dinar macedon',
        ],
        'MKN' => [
            'MKN',
            'dinar macedon (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'franc dal Mali',
        ],
        'MMK' => [
            'MMK',
            'kyat dal Myanmar',
        ],
        'MNT' => [
            'MNT',
            'tugrik mongolic',
        ],
        'MOP' => [
            'MOP',
            'pataca da Macao',
        ],
        'MRO' => [
            'MRO',
            'ouguiya da la Mauretania (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'ouguiya da la Mauretania',
        ],
        'MTL' => [
            'MTL',
            'lira maltaisa',
        ],
        'MTP' => [
            'MTP',
            'glivra maltaisa',
        ],
        'MUR' => [
            'MUR',
            'rupia dal Mauritius',
        ],
        'MVP' => [
            'MVP',
            'rupia da las Maledivas (1947–1981)',
        ],
        'MVR' => [
            'MVR',
            'rufiyaa da las Maledivas',
        ],
        'MWK' => [
            'MWK',
            'kwacha dal Malawi',
        ],
        'MXN' => [
            'MX$',
            'peso mexican',
        ],
        'MXP' => [
            'MXP',
            'peso d’argient mexican (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'unidad de inversion mexicana (UDI)',
        ],
        'MYR' => [
            'MYR',
            'ringgit malaisic',
        ],
        'MZE' => [
            'MZE',
            'escudo dal Mosambic',
        ],
        'MZM' => [
            'MZM',
            'metical dal Mosambic (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'metical dal Mosambic',
        ],
        'NAD' => [
            'NAD',
            'dollar da la Namibia',
        ],
        'NGN' => [
            'NGN',
            'naira nigeriana',
        ],
        'NIC' => [
            'NIC',
            'cordoba nicaraguan',
        ],
        'NIO' => [
            'NIO',
            'córdoba nicaraguan',
        ],
        'NLG' => [
            'NLG',
            'flurin ollandais',
        ],
        'NOK' => [
            'NOK',
            'curuna norvegiaisa',
        ],
        'NPR' => [
            'NPR',
            'rupia nepalaisa',
        ],
        'NZD' => [
            'NZ$',
            'dollar da la Nova Zelanda',
        ],
        'OMR' => [
            'OMR',
            'rial da l’Oman',
        ],
        'PAB' => [
            'PAB',
            'balboa dal Panama',
        ],
        'PEI' => [
            'PEI',
            'inti peruan',
        ],
        'PEN' => [
            'PEN',
            'sol peruan',
        ],
        'PES' => [
            'PES',
            'sol peruan (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'kina da la Papua Nova Guinea',
        ],
        'PHP' => [
            '₱',
            'peso filippin',
        ],
        'PKR' => [
            'PKR',
            'rupia pakistana',
        ],
        'PLN' => [
            'PLN',
            'zloti polac',
        ],
        'PLZ' => [
            'PLZ',
            'zloty polac (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'escudo portugais',
        ],
        'PYG' => [
            'PYG',
            'guarani paraguaian',
        ],
        'QAR' => [
            'QAR',
            'riyal dal Qatar',
        ],
        'RHD' => [
            'RHD',
            'dollar rodesian',
        ],
        'ROL' => [
            'ROL',
            'leu rumen (1952–2006)',
        ],
        'RON' => [
            'RON',
            'leu rumen',
        ],
        'RSD' => [
            'RSD',
            'dinar serb',
        ],
        'RUB' => [
            'RUB',
            'rubel russ',
        ],
        'RUR' => [
            'RUR',
            'rubel russ (vegl)',
        ],
        'RWF' => [
            'RWF',
            'franc ruandais',
        ],
        'SAR' => [
            'SAR',
            'riyal saudit',
        ],
        'SBD' => [
            'SBD',
            'dollar da las Inslas da Salomon',
        ],
        'SCR' => [
            'SCR',
            'rupia da las Seychellas',
        ],
        'SDD' => [
            'SDD',
            'dinar sudanais (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'glivra sudanaisa',
        ],
        'SDP' => [
            'SDP',
            'glivra sudanaisa (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'curuna svedaisa',
        ],
        'SGD' => [
            'SGD',
            'dollar da Singapur',
        ],
        'SHP' => [
            'SHP',
            'glivra da Sontg’Elena',
        ],
        'SIT' => [
            'SIT',
            'tolar sloven',
        ],
        'SKK' => [
            'SKK',
            'cruna slovaca',
        ],
        'SLE' => [
            'SLE',
            'leone da la Sierra Leone',
        ],
        'SLL' => [
            'SLL',
            'leone da la Sierra Leone (1964–2022)',
        ],
        'SOS' => [
            'SOS',
            'schilling somalian',
        ],
        'SRD' => [
            'SRD',
            'dollar dal Surinam',
        ],
        'SRG' => [
            'SRG',
            'flurin surinam',
        ],
        'SSP' => [
            'SSP',
            'glivra sidsudanaisa',
        ],
        'STD' => [
            'STD',
            'dobra da São Tomé e Principe (1977–2017)',
        ],
        'STN' => [
            'STN',
            'dobra da São Tomé e Príncipe',
        ],
        'SUR' => [
            'SUR',
            'rubel sovietic',
        ],
        'SVC' => [
            'SVC',
            'colon da l’El Salvador',
        ],
        'SYP' => [
            'SYP',
            'glivra siriana',
        ],
        'SZL' => [
            'SZL',
            'lilangeni dal Swasiland',
        ],
        'THB' => [
            'THB',
            'baht tailandais',
        ],
        'TJR' => [
            'TJR',
            'rubel tadschic',
        ],
        'TJS' => [
            'TJS',
            'somoni tadschic',
        ],
        'TMM' => [
            'TMM',
            'manat turkmen (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'manat turkmen',
        ],
        'TND' => [
            'TND',
            'dinar tunesian',
        ],
        'TOP' => [
            'TOP',
            'paʻanga dal Tonga',
        ],
        'TPE' => [
            'TPE',
            'escudo dal Timor',
        ],
        'TRL' => [
            'TRL',
            'lira tirca (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'lira tirca',
        ],
        'TTD' => [
            'TTD',
            'dollar da Trinidad e Tobago',
        ],
        'TWD' => [
            'NT$',
            'nov dollar taiwanais',
        ],
        'TZS' => [
            'TZS',
            'schilling da la Tansania',
        ],
        'UAH' => [
            'UAH',
            'hryvnia ucranaisa',
        ],
        'UAK' => [
            'UAK',
            'karbovanets ucranais',
        ],
        'UGS' => [
            'UGS',
            'schilling ugandais (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'schilling ugandais',
        ],
        'USD' => [
            '$',
            'dollar da l’USA',
        ],
        'USN' => [
            'USN',
            'dollar dals Stadis Unids da l’America (proxim di)',
        ],
        'USS' => [
            'USS',
            'dollar dals Stadis Unids da l’America (medem di)',
        ],
        'UYI' => [
            'UYI',
            'peso da l’Uruguay (unidades indexadas)',
        ],
        'UYP' => [
            'UYP',
            'nov peso da l’Uruguay (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'peso uruguaian',
        ],
        'UZS' => [
            'UZS',
            'som usbec',
        ],
        'VEB' => [
            'VEB',
            'bolivar venezuelan (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'bolivar venezuelan (2008–2018)',
        ],
        'VES' => [
            'VES',
            'bolívar venezolan',
        ],
        'VND' => [
            '₫',
            'dong vietnamais',
        ],
        'VNN' => [
            'VNN',
            'dong vietnamais (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'vatu dal Vanuatu',
        ],
        'WST' => [
            'WST',
            'tala da la Samoa',
        ],
        'XAF' => [
            'FCFA',
            'franc CFA da l’Africa Centrala',
        ],
        'XCD' => [
            'EC$',
            'dollar da la Caribica Orientala',
        ],
        'XCG' => [
            'Cg.',
            'flurin caribic',
        ],
        'XFO' => [
            'XFO',
            'franc d’aur franzos',
        ],
        'XFU' => [
            'XFU',
            'franc UIC franzos',
        ],
        'XOF' => [
            'F CFA',
            'franc CFA da l’Africa dal Vest',
        ],
        'XPF' => [
            'CFPF',
            'franc CFP',
        ],
        'XRE' => [
            'XRE',
            'fonds RINET',
        ],
        'YDD' => [
            'YDD',
            'dinar jemenit',
        ],
        'YER' => [
            'YER',
            'rial jemenit',
        ],
        'YUD' => [
            'YUD',
            'dinar jugoslav dir (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'nov dinar jugoslav (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'dinar jugoslav convertibel (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'dinar jugoslav refurmà (1992–1993)',
        ],
        'ZAL' => [
            'ZAL',
            'rand sidafrican (finanzial)',
        ],
        'ZAR' => [
            'ZAR',
            'rand sidafrican',
        ],
        'ZMK' => [
            'ZMK',
            'kwacha da la Sambia (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'kwacha da la Sambia',
        ],
        'ZRN' => [
            'ZRN',
            'nov zaire dal Zaire (1993–1998)',
        ],
        'ZRZ' => [
            'ZRZ',
            'zaire dal Zaire',
        ],
        'ZWD' => [
            'ZWD',
            'dollar dal Simbabwe (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'aur dal Simbabwe',
        ],
        'ZWL' => [
            'ZWL',
            'dollar dal Simbabwe (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'dollar dal Simbabwe (2008)',
        ],
    ],
];
