<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Dirham ya Falme za Kiarabu',
        ],
        'AOA' => [
            'AOA',
            'Kwanza ya Angola',
        ],
        'AUD' => [
            'A$',
            'Dola ya Australia',
        ],
        'BHD' => [
            'BHD',
            'Dinari ya Bahareni',
        ],
        'BIF' => [
            'BIF',
            'Faranga ya Burundi',
        ],
        'BWP' => [
            'BWP',
            'Pula ya Botswana',
        ],
        'CAD' => [
            'CA$',
            'Ndora ya Kananda',
        ],
        'CDF' => [
            'CDF',
            'Faranga ya Kongo',
        ],
        'CHF' => [
            'CHF',
            'Faranga ya Uswisi',
        ],
        'CNY' => [
            'CN¥',
            'Yuan Renminbi ya China',
        ],
        'CVE' => [
            'CVE',
            'Eskudo ya Kepuvede',
        ],
        'DJF' => [
            'DJF',
            'Faranga ya Jibuti',
        ],
        'DZD' => [
            'DZD',
            'Dinari ya Aljeria',
        ],
        'EGP' => [
            'EGP',
            'Pauni ya Misri',
        ],
        'ERN' => [
            'ERN',
            'Nakfa ya Eritrea',
        ],
        'ETB' => [
            'ETB',
            'Bir ya Uhabeshi',
        ],
        'EUR' => [
            '€',
            'Yuro',
        ],
        'GBP' => [
            '£',
            'Mbauini cia Ngeretha',
        ],
        'GHC' => [
            'GHC',
            'Sedi ya Ghana',
        ],
        'GMD' => [
            'GMD',
            'Dalasi ya Gambia',
        ],
        'GNS' => [
            'GNS',
            'Faranga ya Gine',
        ],
        'INR' => [
            '₹',
            'Rubia rwa India',
        ],
        'JPY' => [
            'JP¥',
            'Sarafu ya Kijapani',
        ],
        'KES' => [
            'Ksh',
            'Ciringi ya Kenya',
        ],
        'KMF' => [
            'KMF',
            'Faranga ya Komoro',
        ],
        'LRD' => [
            'LRD',
            'Dola ya Liberia',
        ],
        'LSL' => [
            'LSL',
            'Loti ya Lesoto',
        ],
        'LYD' => [
            'LYD',
            'Dinari ya Libya',
        ],
        'MAD' => [
            'MAD',
            'Dirham ya Moroko',
        ],
        'MGA' => [
            'MGA',
            'Ariary ya Bukini',
        ],
        'MRO' => [
            'MRO',
            'Ugwiya ya Moritania (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Ugwiya ya Moritania',
        ],
        'MUR' => [
            'MUR',
            'Rupia ya Morisi',
        ],
        'MWK' => [
            'MWK',
            'Kwacha ya Malawi',
        ],
        'MZM' => [
            'MZM',
            'Metikali ya Msumbiji',
        ],
        'NAD' => [
            'NAD',
            'Dola ya Namibia',
        ],
        'NGN' => [
            'NGN',
            'Naira ya Nijeria',
        ],
        'RWF' => [
            'RWF',
            'Faranga ya Rwanda',
        ],
        'SAR' => [
            'SAR',
            'Riyal ya Saudia',
        ],
        'SCR' => [
            'SCR',
            'Rupia ya Shelisheli',
        ],
        'SDG' => [
            'SDG',
            'Pauni ya Sudani',
        ],
        'SHP' => [
            'SHP',
            'Pauni ya Santahelena',
        ],
        'SLE' => [
            'SLE',
            'Leoni',
        ],
        'SLL' => [
            'SLL',
            'Leoni (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'ciringi cia cumarĩ',
        ],
        'STD' => [
            'STD',
            'Dobra ya Sao Tome na Principe (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Dobra ya Sao Tome na Principe',
        ],
        'SZL' => [
            'SZL',
            'Lilangeni',
        ],
        'TND' => [
            'TND',
            'Dinari ya Tunisia',
        ],
        'TZS' => [
            'TZS',
            'ciringi cia Tanizania',
        ],
        'UGX' => [
            'UGX',
            'ciringi cia Ũganda',
        ],
        'USD' => [
            'US$',
            'Ndora cia Amerika',
        ],
        'XAF' => [
            'FCFA',
            'Faranga CFA BEAC',
        ],
        'XOF' => [
            'F CFA',
            'Faranga CFA BCEAO',
        ],
        'ZAR' => [
            'ZAR',
            'Randi ya Afrika Kusini',
        ],
        'ZMK' => [
            'ZMK',
            'Kwacha ya Zambia (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Kwacha ya Zambia',
        ],
        'ZWD' => [
            'ZWD',
            'Dola ya Zimbabwe',
        ],
    ],
];
