<?php

return [
    'UserAssignedNames' => [],
    'Names' => [
        'AX' => 'جزائر آلینڈ',
        'BV' => 'جزیرہ بوویت',
        'CC' => 'جزائر (کیلنگ) کوکوس',
        'CK' => 'جزائر کک',
        'FK' => 'جزائر فاکلینڈ',
        'FO' => 'جزائر فیرو',
        'GF' => 'فرانسیسی گیانا',
        'HM' => 'جزائر ہرڈ و مکڈونلڈ',
        'MH' => 'جزائر مارشل',
        'MP' => 'جزائر شمالی ماریانا',
        'NF' => 'جزیرہ نارفوک',
        'PN' => 'جزائر پٹکیرن',
        'SB' => 'جزائر سلیمان',
        'TC' => 'جزائر کیکس و ترکیہ',
        'UM' => 'امریکی بیرونی جزائر',
        'VG' => 'برطانوی جزائر ورجن',
        'VI' => 'امریکی جزائر ورجن',
    ],
];
