<?php

return [
    'Names' => [
        'Adlm' => 'адлам',
        'Afak' => 'афака',
        'Aghb' => 'кавказька албанська',
        'Ahom' => 'ахом',
        'Arab' => 'арабиця',
        'Aran' => 'насталік',
        'Armi' => 'армі',
        'Armn' => 'вірменська',
        'Avst' => 'авестійський',
        'Bali' => 'балійський',
        'Bamu' => 'бамум',
        'Bass' => 'басса',
        'Batk' => 'батак',
        'Beng' => 'бенгальська',
        'Blis' => 'символи Блісса',
        'Bopo' => 'бопомофо',
        'Brah' => 'брахмі',
        'Brai' => 'шрифт Брайля',
        'Bugi' => 'бугійський',
        'Buhd' => 'бухід',
        'Cakm' => 'чакма',
        'Cans' => 'уніфіковані символи канадських тубільців',
        'Cari' => 'каріанський',
        'Cham' => 'хамітський',
        'Cher' => 'черокі',
        'Cirt' => 'кирт',
        'Copt' => 'коптський',
        'Cprt' => 'кіпрський',
        'Cyrl' => 'кирилиця',
        'Cyrs' => 'давньоцерковнословʼянський',
        'Deva' => 'деванагарі',
        'Dsrt' => 'дезерет',
        'Egyd' => 'єгипетський демотичний',
        'Egyh' => 'єгипетський ієратичний',
        'Egyp' => 'єгипетський ієрогліфічний',
        'Ethi' => 'ефіопська',
        'Geok' => 'кхутсурі',
        'Geor' => 'грузинська',
        'Glag' => 'глаголичний',
        'Goth' => 'готичний',
        'Grek' => 'грецька',
        'Gujr' => 'гуджараті',
        'Guru' => 'гурмухі',
        'Hanb' => 'хань',
        'Hang' => 'хангиль',
        'Hani' => 'китайська',
        'Hano' => 'хануну',
        'Hans' => 'спрощена',
        'Hant' => 'традиційна',
        'Hebr' => 'іврит',
        'Hira' => 'хірагана',
        'Hmng' => 'пахау хмонг',
        'Hrkt' => 'японські силабарії',
        'Hung' => 'давньоугорський',
        'Inds' => 'харапський',
        'Ital' => 'давньоіталійський',
        'Jamo' => 'чамо',
        'Java' => 'яванський',
        'Jpan' => 'японська',
        'Kali' => 'кая лі',
        'Kana' => 'катакана',
        'Khar' => 'кхароштхі',
        'Khmr' => 'кхмерська',
        'Knda' => 'каннада',
        'Kore' => 'корейська',
        'Kthi' => 'каїті',
        'Lana' => 'ланна',
        'Laoo' => 'лаоська',
        'Latf' => 'латинський фрактурний',
        'Latg' => 'латинський гельський',
        'Latn' => 'латиниця',
        'Lepc' => 'лепча',
        'Limb' => 'лімбу',
        'Lina' => 'лінійний А',
        'Linb' => 'лінійний В',
        'Lisu' => 'абетка Фрейзера',
        'Loma' => 'лома',
        'Lyci' => 'лікійський',
        'Lydi' => 'лідійський',
        'Mand' => 'мандейський',
        'Mani' => 'маніхейський',
        'Maya' => 'майя ієрогліфічний',
        'Mero' => 'мероїтський',
        'Mlym' => 'малаяламська',
        'Mong' => 'монгольська',
        'Moon' => 'мун',
        'Mtei' => 'мейтей майєк',
        'Mymr' => 'мʼянмська',
        'Newa' => 'нева',
        'Nkoo' => 'нко',
        'Ogam' => 'огамічний',
        'Olck' => 'ол-чикі',
        'Orkh' => 'орхонський',
        'Orya' => 'орія',
        'Osge' => 'осейджиська',
        'Osma' => 'османський',
        'Perm' => 'давньопермський',
        'Phag' => 'пхагс-па',
        'Phli' => 'пехлеві написів',
        'Phlp' => 'пехлеві релігійний',
        'Phlv' => 'пехлеві літературний',
        'Phnx' => 'фінікійський',
        'Plrd' => 'писемність Полларда',
        'Prti' => 'парфянський',
        'Qaag' => 'зоджі',
        'Rjng' => 'реджанг',
        'Rohg' => 'ханіфі',
        'Roro' => 'ронго-ронго',
        'Runr' => 'рунічний',
        'Samr' => 'самаритянський',
        'Sara' => 'сараті',
        'Saur' => 'саураштра',
        'Sgnw' => 'знаковий',
        'Shaw' => 'шоу',
        'Sinh' => 'сингальська',
        'Sund' => 'сунданська',
        'Sylo' => 'сілоті нагрі',
        'Syrc' => 'сирійська',
        'Syre' => 'давньосирійський естрангело',
        'Syrj' => 'давньосирійський західний',
        'Syrn' => 'давньосирійський східний',
        'Tagb' => 'тагбанва',
        'Tale' => 'тай-лі',
        'Talu' => 'новий тайський луе',
        'Taml' => 'тамільська',
        'Tang' => 'тангут',
        'Tavt' => 'тай-вʼєт',
        'Telu' => 'телугу',
        'Teng' => 'тенгвар',
        'Tfng' => 'тифінаг',
        'Tglg' => 'тагальський',
        'Thaa' => 'таана',
        'Thai' => 'тайська',
        'Tibt' => 'тибетська',
        'Ugar' => 'угаритський',
        'Vaii' => 'ваї',
        'Visp' => 'видиме мовлення',
        'Xpeo' => 'давньоперський',
        'Xsux' => 'шумеро-аккадський клінопис',
        'Yiii' => 'йї',
        'Zinh' => 'успадкована',
        'Zmth' => 'математична',
        'Zsye' => 'емодзі',
        'Zsym' => 'символьна',
        'Zxxx' => 'безписемна',
        'Zyyy' => 'звичайна',
    ],
];
