<?php

return [
    'Names' => [
        'aa' => 'афар чӗлхи',
        'ab' => 'абхаз чӗлхи',
        'af' => 'африкаанс чӗлхи',
        'agq' => 'агем чӗлхи',
        'ak' => 'акан чӗлхи',
        'am' => 'амхар чӗлхи',
        'an' => 'арагон чӗлхи',
        'ann' => 'оболо чӗлхи',
        'apc' => 'левант арап чӗлхи',
        'ar' => 'араб чӗлхи',
        'arn' => 'мапуче чӗлхи',
        'as' => 'ассам чӗлхи',
        'asa' => 'асу чӗлхи',
        'ast' => 'астури чӗлхи',
        'az' => 'азербайджан чӗлхи',
        'ba' => 'пушкӑрт чӗлхи',
        'bal' => 'белудж чӗлхи',
        'bas' => 'баса чӗлхи',
        'be' => 'беларус чӗлхи',
        'bem' => 'бемба чӗлхи',
        'bew' => 'батав чӗлхи',
        'bez' => 'бена чӗлхи',
        'bg' => 'болгар чӗлхи',
        'bgc' => 'харианви чӗлхи',
        'bgn' => 'анӑҫ белудж чӗлхи',
        'bho' => 'бходжпури чӗлхи',
        'blo' => 'ании чӗлхи',
        'blt' => 'тай-дам чӗлхи',
        'bm' => 'бамбара чӗлхи',
        'bn' => 'бенгал чӗлхи',
        'bo' => 'тибет чӗлхи',
        'bqi' => 'бахтияр чӗлхи',
        'br' => 'бретон чӗлхи',
        'brx' => 'бодо чӗлхи',
        'bs' => 'босни чӗлхи',
        'bss' => 'акоосе чӗлхи',
        'bua' => 'бурят чӗлхи',
        'byn' => 'билин чӗлхи',
        'ca' => 'каталан чӗлхи',
        'cad' => 'каддо чӗлхи',
        'cch' => 'атсам чӗлхи',
        'ccp' => 'чакма чӗлхи',
        'ce' => 'чечен чӗлхи',
        'ceb' => 'себуано чӗлхи',
        'cgg' => 'кига чӗлхи',
        'cho' => 'чоктав чӗлхи',
        'chr' => 'чероки чӗлхи',
        'cic' => 'чикасав чӗлхи',
        'ckb' => 'вӑта курд чӗлхи',
        'co' => 'корсикан чӗлхи',
        'cop' => 'копт чӗлхи',
        'cs' => 'чех чӗлхи',
        'csw' => 'шурти кри чӗлхи',
        'cu' => 'чиркӳ славян чӗлхи',
        'cv' => 'чӑваш чӗлхи',
        'cy' => 'валли чӗлхи',
        'da' => 'датчан чӗлхи',
        'dav' => 'таита чӗлхи',
        'de' => 'нимӗҫ чӗлхи',
        'dje' => 'джерма чӗлхи',
        'doi' => 'догри чӗлхи',
        'dsb' => 'анатри лужица чӗлхи',
        'dua' => 'дуала чӗлхи',
        'dv' => 'мальдив чӗлхи',
        'dyo' => 'диола-фоньи чӗлхи',
        'dz' => 'дзонг-кэ чӗлхи',
        'ebu' => 'эмбу чӗлхи',
        'ee' => 'эве чӗлхи',
        'el' => 'грек чӗлхи',
        'en' => 'акӑлчан чӗлхи',
        'eo' => 'эсперанто чӗлхи',
        'es' => 'испан чӗлхи',
        'et' => 'эстон чӗлхи',
        'eu' => 'баск чӗлхи',
        'ewo' => 'эвондо чӗлхи',
        'fa' => 'перс чӗлхи',
        'ff' => 'фула чӗлхи',
        'fi' => 'финн чӗлхи',
        'fil' => 'филиппин чӗлхи',
        'fo' => 'фарер чӗлхи',
        'fr' => 'француз чӗлхи',
        'frc' => 'каджун француз чӗлхи',
        'frr' => 'ҫур ҫӗр фриз чӗлхи',
        'fur' => 'фриу чӗлхи',
        'fy' => 'анӑҫ фриз чӗлхи',
        'ga' => 'ирланд чӗлхи',
        'gaa' => 'га чӗлхи',
        'gd' => 'гэл чӗлхи',
        'gez' => 'геэз чӗлхи',
        'gl' => 'галиси чӗлхи',
        'gn' => 'гуарани чӗлхи',
        'gsw' => 'швейцари нимӗҫ чӗлхи',
        'gu' => 'гуджарати чӗлхи',
        'guz' => 'гуси чӗлхи',
        'gv' => 'мэн чӗлхи',
        'ha' => 'хауса чӗлхи',
        'haw' => 'гавай чӗлхи',
        'he' => 'иврит чӗлхи',
        'hi' => 'хинди чӗлхи',
        'hnj' => 'хмонг-ну чӗлхи',
        'hr' => 'хорват чӗлхи',
        'hsb' => 'тури лужица чӗлхи',
        'ht' => 'гаитян чӗлхи',
        'hu' => 'венгер чӗлхи',
        'hy' => 'эрмен чӗлхи',
        'ia' => 'интерлингва чӗлхи',
        'id' => 'индонези чӗлхи',
        'ie' => 'интерлингве чӗлхи',
        'ig' => 'игбо чӗлхи',
        'ii' => 'носу чӗлхи',
        'io' => 'идо чӗлхи',
        'is' => 'исланд чӗлхи',
        'it' => 'итальян чӗлхи',
        'iu' => 'инуктитут чӗлхи',
        'ja' => 'япон чӗлхи',
        'jbo' => 'ложбан чӗлхи',
        'jgo' => 'нгомба чӗлхи',
        'jmc' => 'мачаме чӗлхи',
        'jv' => 'яван чӗлхи',
        'ka' => 'грузин чӗлхи',
        'kaa' => 'каракалпак чӗлхи',
        'kab' => 'кабил чӗлхи',
        'kaj' => 'каджи чӗлхи',
        'kam' => 'камба чӗлхи',
        'kcg' => 'тьяп чӗлхи',
        'kde' => 'маконде чӗлхи',
        'kea' => 'кабувердьяну чӗлхи',
        'kek' => 'кекчи чӗлхи',
        'ken' => 'ньянг чӗлхи',
        'kgp' => 'каинганг чӗлхи',
        'khq' => 'койра-чиини чӗлхи',
        'ki' => 'кикуйю чӗлхи',
        'kk' => 'казах чӗлхи',
        'kkj' => 'како чӗлхи',
        'kl' => 'гренланд чӗлхи',
        'kln' => 'календжин чӗлхи',
        'km' => 'кхмер чӗлхи',
        'kn' => 'каннада чӗлхи',
        'ko' => 'корей чӗлхи',
        'kok' => 'конкани чӗлхи',
        'kpe' => 'кпелле чӗлхи',
        'ks' => 'кашмири чӗлхи',
        'ksb' => 'шамбала чӗлхи',
        'ksf' => 'бафи чӗлхи',
        'ksh' => 'кёльн чӗлхи',
        'ku' => 'курд чӗлхи',
        'kw' => 'корн чӗлхи',
        'kxv' => 'куви чӗлхи',
        'ky' => 'кӑркӑс чӗлхи',
        'la' => 'латин чӗлхи',
        'lag' => 'ланго чӗлхи',
        'lb' => 'люксембург чӗлхи',
        'lg' => 'ганда чӗлхи',
        'lij' => 'лигур чӗлхи',
        'lkt' => 'лакота чӗлхи',
        'lld' => 'ладин чӗлхи',
        'lmo' => 'ломбард чӗлхи',
        'ln' => 'лингала чӗлхи',
        'lo' => 'лаос чӗлхи',
        'lou' => 'луизиан креол чӗлхи',
        'lrc' => 'ҫур ҫӗр лур чӗлхи',
        'lt' => 'литва чӗлхи',
        'ltg' => 'латгал чӗлхи',
        'lu' => 'луба-катанга чӗлхи',
        'luo' => 'луо чӗлхи',
        'luy' => 'лухья чӗлхи',
        'lv' => 'латыш чӗлхи',
        'lzz' => 'лаз чӗлхи',
        'mai' => 'майтхили чӗлхи',
        'mas' => 'масаи чӗлхи',
        'mdf' => 'мӑкшӑ чӗлхи',
        'mer' => 'меру чӗлхи',
        'mfe' => 'маврики креол чӗлхи',
        'mg' => 'малагас чӗлхи',
        'mgh' => 'макуа-меетто чӗлхи',
        'mgo' => 'мета чӗлхи',
        'mhn' => 'мокен чӗлхи',
        'mi' => 'маори чӗлхи',
        'mic' => 'микмак чӗлхи',
        'mk' => 'македон чӗлхи',
        'ml' => 'малаялам чӗлхи',
        'mn' => 'монгол чӗлхи',
        'mni' => 'манипур чӗлхи',
        'moh' => 'мохаук чӗлхи',
        'mr' => 'маратхи чӗлхи',
        'ms' => 'малай чӗлхи',
        'mt' => 'мальта чӗлхи',
        'mua' => 'мунданг чӗлхи',
        'mus' => 'крик чӗлхи',
        'mww' => 'хмонг-доу чӗлхи',
        'my' => 'бирман чӗлхи',
        'myv' => 'ирҫе чӗлхи',
        'mzn' => 'мазандеран чӗлхи',
        'nan' => 'миньнань чӗлхи',
        'naq' => 'нама чӗлхи',
        'nb' => 'букмол норвег чӗлхи',
        'nd' => 'ҫур ҫӗр ндебеле чӗлхи',
        'nds' => 'анатри нимӗҫ чӗлхи',
        'ne' => 'непал чӗлхи',
        'nl' => 'нидерланд чӗлхи',
        'nmg' => 'квасио чӗлхи',
        'nn' => 'нюнорск норвег чӗлхи',
        'nnh' => 'нгиембунд чӗлхи',
        'no' => 'норвег чӗлхи',
        'nqo' => 'нко чӗлхи',
        'nr' => 'кӑнтӑр ндебеле чӗлхи',
        'nso' => 'ҫур ҫӗр сото чӗлхи',
        'nus' => 'нуэр чӗлхи',
        'nv' => 'навахо чӗлхи',
        'ny' => 'ньянджа чӗлхи',
        'nyn' => 'ньянколе чӗлхи',
        'oc' => 'окситан чӗлхи',
        'oka' => 'оканаган чӗлхи',
        'om' => 'оромо чӗлхи',
        'or' => 'ори чӗлхи',
        'os' => 'осетин чӗлхи',
        'osa' => 'оседжи чӗлхи',
        'pa' => 'панджаби чӗлхи',
        'pap' => 'папьяменто чӗлхи',
        'pcm' => 'нигери креол чӗлхи',
        'pi' => 'пали чӗлхи',
        'pis' => 'соломон пиджин чӗлхи',
        'pl' => 'поляк чӗлхи',
        'pms' => 'пьемонт чӗлхи',
        'prg' => 'прусс чӗлхи',
        'ps' => 'пушту чӗлхи',
        'pt' => 'португал чӗлхи',
        'qu' => 'кечуа чӗлхи',
        'quc' => 'киче чӗлхи',
        'raj' => 'раджастхани чӗлхи',
        'rhg' => 'рохинджа чӗлхи',
        'rif' => 'риф чӗлхи',
        'rm' => 'романш чӗлхи',
        'rn' => 'рунди чӗлхи',
        'ro' => 'румын чӗлхи',
        'rof' => 'ромбо чӗлхи',
        'ru' => 'вырӑс чӗлхи',
        'rw' => 'киньяруанда чӗлхи',
        'rwk' => 'руанда чӗлхи',
        'sa' => 'санскрит чӗлхи',
        'sah' => 'саха чӗлхи',
        'saq' => 'самбуру чӗлхи',
        'sat' => 'сантали чӗлхи',
        'sbp' => 'сангу чӗлхи',
        'sc' => 'сардин чӗлхи',
        'scn' => 'сицил чӗлхи',
        'sd' => 'синдхи чӗлхи',
        'sdh' => 'кӑнтӑр алтай чӗлхи',
        'se' => 'ҫур ҫӗр саам чӗлхи',
        'seh' => 'сена чӗлхи',
        'ses' => 'койраборо-сенни чӗлхи',
        'sg' => 'санго чӗлхи',
        'sgs' => 'жемайт чӗлхи',
        'shi' => 'ташельхит чӗлхи',
        'shn' => 'шан чӗлхи',
        'si' => 'сингал чӗлхи',
        'sid' => 'сидама чӗлхи',
        'sk' => 'словак чӗлхи',
        'skr' => 'сирайки чӗлхи',
        'sl' => 'словен чӗлхи',
        'sma' => 'кӑнтӑр саам чӗлхи',
        'smj' => 'луле-саам чӗлхи',
        'smn' => 'инари саам чӗлхи',
        'sms' => 'колтта-саам чӗлхи',
        'sn' => 'шона чӗлхи',
        'so' => 'сомали чӗлхи',
        'sq' => 'албан чӗлхи',
        'sr' => 'серб чӗлхи',
        'ss' => 'свази чӗлхи',
        'ssy' => 'сахо чӗлхи',
        'st' => 'кӑнтӑр сото чӗлхи',
        'su' => 'сундан чӗлхи',
        'suz' => 'сунвар чӗлхи',
        'sv' => 'швед чӗлхи',
        'sw' => 'суахили чӗлхи',
        'syr' => 'сири чӗлхи',
        'szl' => 'силез чӗлхи',
        'ta' => 'тамил чӗлхи',
        'te' => 'телугу чӗлхи',
        'teo' => 'тесо чӗлхи',
        'tg' => 'таджик чӗлхи',
        'th' => 'тай чӗлхи',
        'ti' => 'тигринья чӗлхи',
        'tig' => 'тигре чӗлхи',
        'tk' => 'туркмен чӗлхи',
        'tn' => 'тсвана чӗлхи',
        'to' => 'тонган чӗлхи',
        'tok' => 'токипона чӗлхи',
        'tpi' => 'ток-писин чӗлхи',
        'tr' => 'турккӑ чӗлхи',
        'trv' => 'седек чӗлхи',
        'trw' => 'торвали чӗлхи',
        'ts' => 'тсонга чӗлхи',
        'tt' => 'тутар чӗлхи',
        'twq' => 'тасавак чӗлхи',
        'tyv' => 'тува чӗлхи',
        'tzm' => 'вӑта атлас тамазигхт чӗлхи',
        'ug' => 'уйгур чӗлхи',
        'uk' => 'украин чӗлхи',
        'ur' => 'урду чӗлхи',
        'uz' => 'узбек чӗлхи',
        'vai' => 'ваи чӗлхи',
        've' => 'венда чӗлхи',
        'vec' => 'венет чӗлхи',
        'vi' => 'вьетнам чӗлхи',
        'vmw' => 'макуа чӗлхи',
        'vo' => 'волапюк чӗлхи',
        'vun' => 'вунджо чӗлхи',
        'wa' => 'валлон чӗлхи',
        'wae' => 'валлис чӗлхи',
        'wal' => 'воламо чӗлхи',
        'wbp' => 'вальбири чӗлхи',
        'wo' => 'волоф чӗлхи',
        'xh' => 'коса чӗлхи',
        'xnr' => 'кангри чӗлхи',
        'xog' => 'сога чӗлхи',
        'yav' => 'янгбен чӗлхи',
        'yi' => 'идиш чӗлхи',
        'yo' => 'йоруба чӗлхи',
        'yrl' => 'ньенгату чӗлхи',
        'yue' => 'кантон чӗлхи',
        'za' => 'чжуань чӗлхи',
        'zgh' => 'тамазигхт чӗлхи',
        'zh' => 'китай чӗлхи',
        'zu' => 'зулу чӗлхи',
    ],
    'LocalizedNames' => [
        'ar_001' => 'хальхи стандартлӑ араб чӗлхи',
        'de_AT' => 'австри нимӗҫ чӗлхи',
        'de_CH' => 'швейцари тури нимӗҫ чӗлхи',
        'en_AU' => 'австрали акӑлчан чӗлхи',
        'en_CA' => 'канада акӑлчан чӗлхи',
        'en_GB' => 'британи акӑлчан чӗлхи',
        'en_US' => 'америка акӑлчан чӗлхи',
        'es_419' => 'латинла америка испан чӗлхи',
        'es_ES' => 'европа испан чӗлхи',
        'es_MX' => 'мексика испан чӗлхи',
        'fa_AF' => 'дари чӗлхи',
        'fr_CA' => 'канада француз чӗлхи',
        'fr_CH' => 'швейцари француз чӗлхи',
        'hi_Latn' => 'хинди чӗлхи (латин ҫырулӑхӗ)',
        'nds_NL' => 'анатри саксон чӗлхи',
        'nl_BE' => 'фламанд чӗлхи',
        'pt_BR' => 'бразили португал чӗлхи',
        'pt_PT' => 'португали португал чӗлхи',
        'ro_MD' => 'молдаван чӗлхи',
        'sw_CD' => 'конго суахили чӗлхи',
        'zh_Hans' => 'ҫӑмӑллатнӑ китай чӗлхи',
        'zh_Hant' => 'йӑлана кӗнӗ китай чӗлхи',
    ],
];
