<?php

/**
 * Danish PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author John Sebastian <jms@iwb.dk>
 * Rewrite and extension of the work by Mikael Stokkebro <info@stokkebro.dk>
 *
 */

$PHPMAILER_LANG['authenticate']         = 'SMTP fejl: Login mislykkedes.';
$PHPMAILER_LANG['buggy_php']            = 'Din version af PHP er berørt af en fejl, som gør at dine beskeder muligvis vises forkert. For at rette dette kan du skifte til SMTP, slå mail.add_x_header headeren i din php.ini fil fra, skifte til MacOS eller Linux eller opgradere din version af PHP til 7.0.17+ eller 7.1.3+.';
$PHPMAILER_LANG['connect_host']         = 'SMTP fejl: Forbindelse til SMTP serveren kunne ikke oprettes.';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTP fejl: Data blev ikke accepteret.';
$PHPMAILER_LANG['empty_message']        = 'Meddelelsen er uden indhold';
$PHPMAILER_LANG['encoding']             = 'Ukendt encode-format: ';
$PHPMAILER_LANG['execute']              = 'Kunne ikke afvikle: ';
$PHPMAILER_LANG['extension_missing']    = 'Udvidelse mangler: ';
$PHPMAILER_LANG['file_access']          = 'Kunne ikke tilgå filen: ';
$PHPMAILER_LANG['file_open']            = 'Fil fejl: Kunne ikke åbne filen: ';
$PHPMAILER_LANG['from_failed']          = 'Følgende afsenderadresse er forkert: ';
$PHPMAILER_LANG['instantiate']          = 'Email funktionen kunne ikke initialiseres.';
$PHPMAILER_LANG['invalid_address']      = 'Udgyldig adresse: ';
$PHPMAILER_LANG['invalid_header']       = 'Ugyldig header navn eller værdi';
$PHPMAILER_LANG['invalid_hostentry']    = 'Ugyldig hostentry: ';
$PHPMAILER_LANG['invalid_host']         = 'Ugyldig vært: ';
$PHPMAILER_LANG['mailer_not_supported'] = ' mailer understøttes ikke.';
$PHPMAILER_LANG['provide_address']      = 'Indtast mindst en modtagers email adresse.';
$PHPMAILER_LANG['recipients_failed']    = 'SMTP fejl: Følgende modtagere fejlede: ';
$PHPMAILER_LANG['signing']              = 'Signeringsfejl: ';
$PHPMAILER_LANG['smtp_code']            = 'SMTP kode: ';
$PHPMAILER_LANG['smtp_code_ex']         = 'Yderligere SMTP info: ';
$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP Connect() fejlede.';
$PHPMAILER_LANG['smtp_detail']          = 'Detalje: ';
$PHPMAILER_LANG['smtp_error']           = 'SMTP server fejl: ';
$PHPMAILER_LANG['variable_set']         = 'Kunne ikke definere eller nulstille variablen: ';
