<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'بىرىككەن اراب امىرلىكتەرىنىڭ ديرحامى',
        ],
        'AFN' => [
            'AFN',
            'اۋعانستان افگانيى',
        ],
        'ALL' => [
            'ALL',
            'البانيا لەگى',
        ],
        'AMD' => [
            'AMD',
            'ارمەنيا درامى',
        ],
        'ANG' => [
            'ANG',
            'نيدەرلاند انتيل گۋلدەنى',
        ],
        'AOA' => [
            'AOA',
            'انگولا كۆانزاسى',
        ],
        'ARS' => [
            'ARS',
            'ارگەنتينا پەسوسى',
        ],
        'AUD' => [
            'A$',
            'اۋستراليا دوللارى',
        ],
        'AWG' => [
            'AWG',
            'ارۋبا فلورينى',
        ],
        'AZN' => [
            'AZN',
            'ءازىربايجان ماناتى',
        ],
        'BAM' => [
            'BAM',
            'بوسنيا جانە گەرتسەگوۆينا ايىرباستالمالى ماركاسى',
        ],
        'BBD' => [
            'BBD',
            'باربادوس دوللارى',
        ],
        'BDT' => [
            'BDT',
            'بانگلادەش تاكاسى',
        ],
        'BGN' => [
            'BGN',
            'ڭولگاريا لەۆى',
        ],
        'BHD' => [
            'BHD',
            'باحرەين دينارى',
        ],
        'BIF' => [
            'BIF',
            'بۋرۋندي فرانكى',
        ],
        'BMD' => [
            'BMD',
            'بەرمۋد دوللارى',
        ],
        'BND' => [
            'BND',
            'برۋنەي دوللارى',
        ],
        'BOB' => [
            'BOB',
            'بوليۆيا بوليۆيانوسى',
        ],
        'BRL' => [
            'R$',
            'برازيليا رەالى',
        ],
        'BSD' => [
            'BSD',
            'باگام دوللارى',
        ],
        'BTN' => [
            'BTN',
            'بۋتان نگۋلترۋمى',
        ],
        'BWP' => [
            'BWP',
            'بوتسۆانا پۋلاسى',
        ],
        'BYN' => [
            'BYN',
            'بەلارۋس رۋبىلى',
        ],
        'BZD' => [
            'BZD',
            'بەليز دوللارى',
        ],
        'CAD' => [
            'CA$',
            'كانادا دوللارى',
        ],
        'CDF' => [
            'CDF',
            'كونگو فرانكى',
        ],
        'CHF' => [
            'CHF',
            'شۆەيساريا فرانكى',
        ],
        'CLP' => [
            'CLP',
            'چيلي پەسوسى',
        ],
        'CNH' => [
            'CNH',
            'قىتاي يۋانى (وفشور)',
        ],
        'CNY' => [
            'CN¥',
            'قىتاي يۋانى',
        ],
        'COP' => [
            'COP',
            'كولۋمبيا پەسوسى',
        ],
        'CRC' => [
            'CRC',
            'كوستا-ريكا كولونى',
        ],
        'CUC' => [
            'CUC',
            'كۋبا ايىرباستالمالى پەسوسى',
        ],
        'CUP' => [
            'CUP',
            'كۋبا پەسوسى',
        ],
        'CVE' => [
            'CVE',
            'كابو-ۆەردە ەسكۋدوسى',
        ],
        'CZK' => [
            'CZK',
            'چەح كرونى',
        ],
        'DJF' => [
            'DJF',
            'جيبۋتي فرانكى',
        ],
        'DKK' => [
            'DKK',
            'دار كرونى',
        ],
        'DOP' => [
            'DOP',
            'دومينيكان پەسوسى',
        ],
        'DZD' => [
            'DZD',
            'الجير دينارى',
        ],
        'EGP' => [
            'EGP',
            'مىسىر فۋنتى',
        ],
        'ERN' => [
            'ERN',
            'ەريترەيا ناكفاس',
        ],
        'ETB' => [
            'ETB',
            'ەفيوپيا بىرى',
        ],
        'EUR' => [
            '€',
            'ەۋرو',
        ],
        'FJD' => [
            'FJD',
            'فيجي دوللارى',
        ],
        'FKP' => [
            'FKP',
            'فولكلەند ارالدارىنىڭ فۋنتى',
        ],
        'GBP' => [
            '£',
            'بريتاندىق فۋنت',
        ],
        'GEL' => [
            'GEL',
            'گرۋزيا لاريى',
        ],
        'GHS' => [
            'GHS',
            'گانا سەديى',
        ],
        'GIP' => [
            'GIP',
            'گيبراتال فۋنتى',
        ],
        'GMD' => [
            'GMD',
            'گامبيا دالاسيى',
        ],
        'GNF' => [
            'GNF',
            'گۆينەيا فرانكى',
        ],
        'GTQ' => [
            'GTQ',
            'گۆاتەمالا كەتسالى',
        ],
        'GYD' => [
            'GYD',
            'گايانا دوللارى',
        ],
        'HKD' => [
            'HK$',
            'حوڭكوڭ دوللارى',
        ],
        'HNL' => [
            'HNL',
            'گوندۋراس ليمپيراسى',
        ],
        'HRK' => [
            'HRK',
            'حورۆاتيا كۋناسى',
        ],
        'HTG' => [
            'HTG',
            'گايتي گۋردى',
        ],
        'HUF' => [
            'HUF',
            'ماجار فورينتى',
        ],
        'IDR' => [
            'IDR',
            'يندونەزيا رۋپياسى',
        ],
        'ILS' => [
            '₪',
            'يزرايل جاڭا شەكەلى',
        ],
        'INR' => [
            '₹',
            'ءۇندىستان رۋپياسى',
        ],
        'IQD' => [
            'IQD',
            'يراك دينارى',
        ],
        'IRR' => [
            'IRR',
            'يران ريالى',
        ],
        'ISK' => [
            'ISK',
            'يسلانديا كروناسى',
        ],
        'JMD' => [
            'JMD',
            'يامايكا دوللارى',
        ],
        'JOD' => [
            'JOD',
            'يوردانيا دينارى',
        ],
        'JPY' => [
            'JP¥',
            'جاپون يەناسى',
        ],
        'KES' => [
            'KES',
            'كەنيا شيللينگى',
        ],
        'KGS' => [
            'KGS',
            'قىرعىس سومى',
        ],
        'KHR' => [
            'KHR',
            'كامبودجا ريەلى',
        ],
        'KMF' => [
            'KMF',
            'كومور ارالدارى فرانكى',
        ],
        'KPW' => [
            'KPW',
            'سولتۇستىك كورەيا ۆونى',
        ],
        'KRW' => [
            '₩',
            'وڭتۇستىك كورەيا ۆونى',
        ],
        'KWD' => [
            'KWD',
            'كۋۆەيت دينارى',
        ],
        'KYD' => [
            'KYD',
            'كايمان ارالدارى دوللارى',
        ],
        'KZT' => [
            '₸',
            'قازاق تەڭگەسى',
        ],
        'LAK' => [
            'LAK',
            'لاوس كيپى',
        ],
        'LBP' => [
            'LBP',
            'ليۆان فۋنتى',
        ],
        'LKR' => [
            'LKR',
            'شري-لانكا رۋپياسى',
        ],
        'LRD' => [
            'LRD',
            'ليبەريا دوللارى',
        ],
        'LSL' => [
            'LSL',
            'لەسوتو ءلوتيى',
        ],
        'LYD' => [
            'LYD',
            'ليۆيا دينارى',
        ],
        'MAD' => [
            'MAD',
            'ماروككو دينارى',
        ],
        'MDL' => [
            'MDL',
            'مولدوۆا لەيى',
        ],
        'MGA' => [
            'MGA',
            'مالاگاسي ءارياريى',
        ],
        'MKD' => [
            'MKD',
            'ماكەدونيا دينارى',
        ],
        'MMK' => [
            'MMK',
            'ميانما كياتى',
        ],
        'MNT' => [
            'MNT',
            'موڭعوليا تۋگريكى',
        ],
        'MOP' => [
            'MOP',
            'ماكاو پاتاكاسى',
        ],
        'MRU' => [
            'MRU',
            'ماۆريتانيا ۋگياسى',
        ],
        'MUR' => [
            'MUR',
            'ماۆريكيي رۋپياسى',
        ],
        'MVR' => [
            'MVR',
            'مالديۆ رۋفياسى',
        ],
        'MWK' => [
            'MWK',
            'مالاۆي كۆاچاسى',
        ],
        'MXN' => [
            'MX$',
            'مەكسيكا پەسوسى',
        ],
        'MYR' => [
            'MYR',
            'مالايزيا رينگگيتى',
        ],
        'MZN' => [
            'MZN',
            'موزامبيك مەتيكالى',
        ],
        'NAD' => [
            'NAD',
            'ناميبيا دوللارى',
        ],
        'NGN' => [
            'NGN',
            'نيگەريا نايراسى',
        ],
        'NIO' => [
            'NIO',
            'نيكاراگۋا كوردوباسى',
        ],
        'NOK' => [
            'NOK',
            'نورۆەگيا كرونى',
        ],
        'NPR' => [
            'NPR',
            'نەپال رۋپياسى',
        ],
        'NZD' => [
            'NZ$',
            'جاڭا زەلانديا دوللارى',
        ],
        'OMR' => [
            'OMR',
            'ومان ريالى',
        ],
        'PAB' => [
            'PAB',
            'پاناما بالبواسى',
        ],
        'PEN' => [
            'PEN',
            'پەرۋ سولى',
        ],
        'PGK' => [
            'PGK',
            'پاپۋا - جاڭا گۆينەيا كيناسى',
        ],
        'PHP' => [
            '₱',
            'فيليپپين پەسوسى',
        ],
        'PKR' => [
            'PKR',
            'پاكىستان رۋپياسى',
        ],
        'PLN' => [
            'PLN',
            'پولشا زلوتىسى',
        ],
        'PYG' => [
            'PYG',
            'پاراگۆاي گۋارانيى',
        ],
        'QAR' => [
            'QAR',
            'كاتار ريالى',
        ],
        'RON' => [
            'RON',
            'رۋمىنيا لەيى',
        ],
        'RSD' => [
            'RSD',
            'سەربيا دينارى',
        ],
        'RUB' => [
            'RUB',
            'رەسەي رۋبىلى',
        ],
        'RWF' => [
            'RWF',
            'رۋاندا فرانكى',
        ],
        'SAR' => [
            'SAR',
            'ساۋد ارابياسىنىڭ ريالى',
        ],
        'SBD' => [
            'SBD',
            'سولومون ارالدارى دوللارى',
        ],
        'SCR' => [
            'SCR',
            'سەيشەل رۋپياسى',
        ],
        'SDG' => [
            'SDG',
            'سۋدان فۋنتى',
        ],
        'SEK' => [
            'SEK',
            'شۆەسيا كرونى',
        ],
        'SGD' => [
            'SGD',
            'سينگاپۋر دوللارى',
        ],
        'SHP' => [
            'SHP',
            'اۋليە ەلەنا ارالى فۋنتى',
        ],
        'SLE' => [
            'SLE',
            'سەررا-لەونە لەونەسى',
        ],
        'SLL' => [
            'SLL',
            'سەررا-لەونە لەونەسى (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'سومالي شيللينگى',
        ],
        'SRD' => [
            'SRD',
            'سۋرينام دوللارى',
        ],
        'SSP' => [
            'SSP',
            'وڭتۇستىك سۋدان فۋنتى',
        ],
        'STN' => [
            'STN',
            'سانت-تومە مەن پرينسيپي دوبراسى',
        ],
        'SYP' => [
            'SYP',
            'سيريا فۋنتى',
        ],
        'SZL' => [
            'SZL',
            'سۆازيلەند ليلانگەنيى',
        ],
        'THB' => [
            'THB',
            'تاي باتى',
        ],
        'TJS' => [
            'TJS',
            'تاجىك سومونيى',
        ],
        'TMT' => [
            'TMT',
            'تۇىكمەن ماناتى',
        ],
        'TND' => [
            'TND',
            'تۋنيس دينارى',
        ],
        'TOP' => [
            'TOP',
            'تونگا پاانگاسى',
        ],
        'TRY' => [
            'TRY',
            'تۇرىك ليراسى',
        ],
        'TTD' => [
            'TTD',
            'ترينيداد جانە توباگو دوللارى',
        ],
        'TWD' => [
            'NT$',
            'جاڭا تايبەي دوللارى',
        ],
        'TZS' => [
            'TZS',
            'تانزانيا شيللينگى',
        ],
        'UAH' => [
            'UAH',
            'ۋكراينا گريۆناسى',
        ],
        'UGX' => [
            'UGX',
            'ۋگاندا شيللينگى',
        ],
        'USD' => [
            'US$',
            'ا ق ش دوللارى',
        ],
        'UYU' => [
            'UYU',
            'ۋرۋگۆاي پەسوسى',
        ],
        'UZS' => [
            'UZS',
            'وزبەك سومى',
        ],
        'VES' => [
            'VES',
            'ۆەنەسۋەلا بوليۆارى',
        ],
        'VND' => [
            '₫',
            'ۆەتنام دونگى',
        ],
        'VUV' => [
            'VUV',
            'ۆانۋاتۋ ۆاتۋى',
        ],
        'WST' => [
            'WST',
            'ساموا تالاسى',
        ],
        'XAF' => [
            'FCFA',
            'ورتالىق افريكانىڭ فرانكى',
        ],
        'XCD' => [
            'EC$',
            'شىعىس كاريب دوللارى',
        ],
        'XCG' => [
            'Cg.',
            'كاريب گۋلدەرى',
        ],
        'XOF' => [
            'F CFA',
            'باتىس افريكانىڭ فرانكى',
        ],
        'XPF' => [
            'CFPF',
            'فرانسۋز پولينەزيا فرانكى',
        ],
        'YER' => [
            'YER',
            'يەمەن ريالى',
        ],
        'ZAR' => [
            'ZAR',
            'وڭتۇستىك افريكا ءرەندى',
        ],
        'ZMW' => [
            'ZMW',
            'زامبيا كۆاچاسى',
        ],
        'ZWG' => [
            'ZWG',
            'زيمباب التىنى',
        ],
    ],
];
