<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'basu: persone, persone, pedde crara e pedde bastante crara',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'basu: persone, persone, pedde crara e pedde de colore mèdiu',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'basu: persone, persone, pedde crara e pedde bastante iscura',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'basu: persone, persone, pedde crara e pedde iscura',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'basu: persone, persone, pedde bastante crara e pedde crara',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'basu: persone, persone, pedde bastante crara e pedde de colore mèdiu',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'basu: persone, persone, pedde bastante crara e pedde bastante iscura',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'basu: persone, persone, pedde bastante crara e pedde iscura',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'basu: persone, persone, pedde de colore mèdiu e pedde crara',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'basu: persone, persone, pedde de colore mèdiu e pedde bastante crara',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'basu: persone, persone, pedde de colore mèdiu e pedde bastante iscura',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'basu: persone, persone, pedde de colore mèdiu e pedde iscura',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'basu: persone, persone, pedde bastante iscura e pedde crara',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'basu: persone, persone, pedde bastante iscura e pedde bastante crara',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'basu: persone, persone, pedde bastante iscura e pedde de colore mèdiu',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'basu: persone, persone, pedde bastante iscura e pedde iscura',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'basu: persone, persone, pedde iscura e pedde crara',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'basu: persone, persone, pedde iscura e pedde bastante crara',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'basu: persone, persone, pedde iscura e pedde de colore mèdiu',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'basu: persone, persone, pedde iscura e pedde bastante iscura',
    '👨🏻‍❤‍💋‍👨🏻' => 'basu: òmine, òmine e pedde crara',
    '👨🏻‍❤‍💋‍👨🏼' => 'basu: òmine, òmine, pedde crara e pedde bastante crara',
    '👨🏻‍❤‍💋‍👨🏽' => 'basu: òmine, òmine, pedde crara e pedde de colore mèdiu',
    '👨🏻‍❤‍💋‍👨🏾' => 'basu: òmine, òmine, pedde crara e pedde bastante iscura',
    '👨🏻‍❤‍💋‍👨🏿' => 'basu: òmine, òmine, pedde crara e pedde iscura',
    '👨🏼‍❤‍💋‍👨🏻' => 'basu: òmine, òmine, pedde bastante crara e pedde crara',
    '👨🏼‍❤‍💋‍👨🏼' => 'basu: òmine, òmine e pedde bastante crara',
    '👨🏼‍❤‍💋‍👨🏽' => 'basu: òmine, òmine, pedde bastante crara e pedde de colore mèdiu',
    '👨🏼‍❤‍💋‍👨🏾' => 'basu: òmine, òmine, pedde bastante crara e pedde bastante iscura',
    '👨🏼‍❤‍💋‍👨🏿' => 'basu: òmine, òmine, pedde bastante crara e pedde iscura',
    '👨🏽‍❤‍💋‍👨🏻' => 'basu: òmine, òmine, pedde de colore mèdiu e pedde crara',
    '👨🏽‍❤‍💋‍👨🏼' => 'basu: òmine, òmine, pedde de colore mèdiu e pedde bastante crara',
    '👨🏽‍❤‍💋‍👨🏽' => 'basu: òmine, òmine e pedde de colore mèdiu',
    '👨🏽‍❤‍💋‍👨🏾' => 'basu: òmine, òmine, pedde de colore mèdiu e pedde bastante iscura',
    '👨🏽‍❤‍💋‍👨🏿' => 'basu: òmine, òmine, pedde de colore mèdiu e pedde iscura',
    '👨🏾‍❤‍💋‍👨🏻' => 'basu: òmine, òmine, pedde bastante iscura e pedde crara',
    '👨🏾‍❤‍💋‍👨🏼' => 'basu: òmine, òmine, pedde bastante iscura e pedde bastante crara',
    '👨🏾‍❤‍💋‍👨🏽' => 'basu: òmine, òmine, pedde bastante iscura e pedde de colore mèdiu',
    '👨🏾‍❤‍💋‍👨🏾' => 'basu: òmine, òmine e pedde bastante iscura',
    '👨🏾‍❤‍💋‍👨🏿' => 'basu: òmine, òmine, pedde bastante iscura e pedde iscura',
    '👨🏿‍❤‍💋‍👨🏻' => 'basu: òmine, òmine, pedde iscura e pedde crara',
    '👨🏿‍❤‍💋‍👨🏼' => 'basu: òmine, òmine, pedde iscura e pedde bastante crara',
    '👨🏿‍❤‍💋‍👨🏽' => 'basu: òmine, òmine, pedde iscura e pedde de colore mèdiu',
    '👨🏿‍❤‍💋‍👨🏾' => 'basu: òmine, òmine, pedde iscura e pedde bastante iscura',
    '👨🏿‍❤‍💋‍👨🏿' => 'basu: òmine, òmine e pedde iscura',
    '👩🏻‍❤‍💋‍👨🏻' => 'basu: fèmina, òmine e pedde crara',
    '👩🏻‍❤‍💋‍👨🏼' => 'basu: fèmina, òmine, pedde crara e pedde bastante crara',
    '👩🏻‍❤‍💋‍👨🏽' => 'basu: fèmina, òmine, pedde crara e pedde de colore mèdiu',
    '👩🏻‍❤‍💋‍👨🏾' => 'basu: fèmina, òmine, pedde crara e pedde bastante iscura',
    '👩🏻‍❤‍💋‍👨🏿' => 'basu: fèmina, òmine, pedde crara e pedde iscura',
    '👩🏼‍❤‍💋‍👨🏻' => 'basu: fèmina, òmine, pedde bastante crara e pedde crara',
    '👩🏼‍❤‍💋‍👨🏼' => 'basu: fèmina, òmine e pedde bastante crara',
    '👩🏼‍❤‍💋‍👨🏽' => 'basu: fèmina, òmine, pedde bastante crara e pedde de colore mèdiu',
    '👩🏼‍❤‍💋‍👨🏾' => 'basu: fèmina, òmine, pedde bastante crara e pedde bastante iscura',
    '👩🏼‍❤‍💋‍👨🏿' => 'basu: fèmina, òmine, pedde bastante crara e pedde iscura',
    '👩🏽‍❤‍💋‍👨🏻' => 'basu: fèmina, òmine, pedde de colore mèdiu e pedde crara',
    '👩🏽‍❤‍💋‍👨🏼' => 'basu: fèmina, òmine, pedde de colore mèdiu e pedde bastante crara',
    '👩🏽‍❤‍💋‍👨🏽' => 'basu: fèmina, òmine e pedde de colore mèdiu',
    '👩🏽‍❤‍💋‍👨🏾' => 'basu: fèmina, òmine, pedde de colore mèdiu e pedde bastante iscura',
    '👩🏽‍❤‍💋‍👨🏿' => 'basu: fèmina, òmine, pedde de colore mèdiu e pedde iscura',
    '👩🏾‍❤‍💋‍👨🏻' => 'basu: fèmina, òmine, pedde bastante iscura e pedde crara',
    '👩🏾‍❤‍💋‍👨🏼' => 'basu: fèmina, òmine, pedde bastante iscura e pedde bastante crara',
    '👩🏾‍❤‍💋‍👨🏽' => 'basu: fèmina, òmine, pedde bastante iscura e pedde de colore mèdiu',
    '👩🏾‍❤‍💋‍👨🏾' => 'basu: fèmina, òmine e pedde bastante iscura',
    '👩🏾‍❤‍💋‍👨🏿' => 'basu: fèmina, òmine, pedde bastante iscura e pedde iscura',
    '👩🏿‍❤‍💋‍👨🏻' => 'basu: fèmina, òmine, pedde iscura e pedde crara',
    '👩🏿‍❤‍💋‍👨🏼' => 'basu: fèmina, òmine, pedde iscura e pedde bastante crara',
    '👩🏿‍❤‍💋‍👨🏽' => 'basu: fèmina, òmine, pedde iscura e pedde de colore mèdiu',
    '👩🏿‍❤‍💋‍👨🏾' => 'basu: fèmina, òmine, pedde iscura e pedde bastante iscura',
    '👩🏿‍❤‍💋‍👨🏿' => 'basu: fèmina, òmine e pedde iscura',
    '👩🏻‍❤‍💋‍👩🏻' => 'basu: fèmina, fèmina e pedde crara',
    '👩🏻‍❤‍💋‍👩🏼' => 'basu: fèmina, fèmina, pedde crara e pedde bastante crara',
    '👩🏻‍❤‍💋‍👩🏽' => 'basu: fèmina, fèmina, pedde crara e pedde de colore mèdiu',
    '👩🏻‍❤‍💋‍👩🏾' => 'basu: fèmina, fèmina, pedde crara e pedde bastante iscura',
    '👩🏻‍❤‍💋‍👩🏿' => 'basu: fèmina, fèmina, pedde crara e pedde iscura',
    '👩🏼‍❤‍💋‍👩🏻' => 'basu: fèmina, fèmina, pedde bastante crara e pedde crara',
    '👩🏼‍❤‍💋‍👩🏼' => 'basu: fèmina, fèmina e pedde bastante crara',
    '👩🏼‍❤‍💋‍👩🏽' => 'basu: fèmina, fèmina, pedde bastante crara e pedde de colore mèdiu',
    '👩🏼‍❤‍💋‍👩🏾' => 'basu: fèmina, fèmina, pedde bastante crara e pedde bastante iscura',
    '👩🏼‍❤‍💋‍👩🏿' => 'basu: fèmina, fèmina, pedde bastante crara e pedde iscura',
    '👩🏽‍❤‍💋‍👩🏻' => 'basu: fèmina, fèmina, pedde de colore mèdiu e pedde crara',
    '👩🏽‍❤‍💋‍👩🏼' => 'basu: fèmina, fèmina, pedde de colore mèdiu e pedde bastante crara',
    '👩🏽‍❤‍💋‍👩🏽' => 'basu: fèmina, fèmina e pedde de colore mèdiu',
    '👩🏽‍❤‍💋‍👩🏾' => 'basu: fèmina, fèmina, pedde de colore mèdiu e pedde bastante iscura',
    '👩🏽‍❤‍💋‍👩🏿' => 'basu: fèmina, fèmina, pedde de colore mèdiu e pedde iscura',
    '👩🏾‍❤‍💋‍👩🏻' => 'basu: fèmina, fèmina, pedde bastante iscura e pedde crara',
    '👩🏾‍❤‍💋‍👩🏼' => 'basu: fèmina, fèmina, pedde bastante iscura e pedde bastante crara',
    '👩🏾‍❤‍💋‍👩🏽' => 'basu: fèmina, fèmina, pedde bastante iscura e pedde de colore mèdiu',
    '👩🏾‍❤‍💋‍👩🏾' => 'basu: fèmina, fèmina e pedde bastante iscura',
    '👩🏾‍❤‍💋‍👩🏿' => 'basu: fèmina, fèmina, pedde bastante iscura e pedde iscura',
    '👩🏿‍❤‍💋‍👩🏻' => 'basu: fèmina, fèmina, pedde iscura e pedde crara',
    '👩🏿‍❤‍💋‍👩🏼' => 'basu: fèmina, fèmina, pedde iscura e pedde bastante crara',
    '👩🏿‍❤‍💋‍👩🏽' => 'basu: fèmina, fèmina, pedde iscura e pedde de colore mèdiu',
    '👩🏿‍❤‍💋‍👩🏾' => 'basu: fèmina, fèmina, pedde iscura e pedde bastante iscura',
    '👩🏿‍❤‍💋‍👩🏿' => 'basu: fèmina, fèmina e pedde iscura',
    '👩‍❤‍💋‍👨' => 'basu: fèmina e òmine',
    '👨‍❤‍💋‍👨' => 'basu: òmine e òmine',
    '👩‍❤‍💋‍👩' => 'basu: fèmina e fèmina',
    '👨‍👩‍👧‍👦' => 'famìlia: òmine, fèmina, pitzinna e pitzinnu',
    '👨‍👩‍👦‍👦' => 'famìlia: òmine, fèmina, pitzinnu e pitzinnu',
    '👨‍👩‍👧‍👧' => 'famìlia: òmine, fèmina, pitzinna e pitzinna',
    '👨‍👨‍👧‍👦' => 'famìlia: òmine, òmine, pitzinna e pitzinnu',
    '👨‍👨‍👦‍👦' => 'famìlia: òmine, òmine, pitzinnu e pitzinnu',
    '👨‍👨‍👧‍👧' => 'famìlia: òmine, òmine, pitzinna e pitzinna',
    '👩‍👩‍👧‍👦' => 'famìlia: fèmina, fèmina, pitzinna e pitzinnu',
    '👩‍👩‍👦‍👦' => 'famìlia: fèmina, fèmina, pitzinnu e pitzinnu',
    '👩‍👩‍👧‍👧' => 'famìlia: fèmina, fèmina, pitzinna e pitzinna',
    '👨‍👩‍👦' => 'famìlia: òmine, fèmina e pitzinnu',
    '👨‍👩‍👧' => 'famìlia: òmine, fèmina e pitzinna',
    '👨‍👨‍👦' => 'famìlia: òmine, òmine e pitzinnu',
    '👨‍👨‍👧' => 'famìlia: òmine, òmine e pitzinna',
    '👩‍👩‍👦' => 'famìlia: fèmina, fèmina e pitzinnu',
    '👩‍👩‍👧' => 'famìlia: fèmina, fèmina e pitzinna',
    '👨‍👦‍👦' => 'famìlia: òmine, pitzinnu e pitzinnu',
    '👨‍👧‍👦' => 'famìlia: òmine, pitzinna e pitzinnu',
    '👨‍👧‍👧' => 'famìlia: òmine, pitzinna e pitzinna',
    '👩‍👦‍👦' => 'famìlia: fèmina, pitzinnu e pitzinnu',
    '👩‍👧‍👦' => 'famìlia: fèmina, pitzinna e pitzinnu',
    '👩‍👧‍👧' => 'famìlia: fèmina, pitzinna e pitzinna',
    '🧑🏻‍🦰' => 'persone: pedde crara e pilos rujos',
    '🧑🏼‍🦰' => 'persone: pedde bastante crara e pilos rujos',
    '🧑🏽‍🦰' => 'persone: pedde de colore mèdiu e pilos rujos',
    '🧑🏾‍🦰' => 'persone: pedde bastante iscura e pilos rujos',
    '🧑🏿‍🦰' => 'persone: pedde iscura e pilos rujos',
    '🧑🏻‍🦱' => 'persone: pedde crara e pilos aneddados',
    '🧑🏼‍🦱' => 'persone: pedde bastante crara e pilos aneddados',
    '🧑🏽‍🦱' => 'persone: pedde de colore mèdiu e pilos aneddados',
    '🧑🏾‍🦱' => 'persone: pedde bastante iscura e pilos aneddados',
    '🧑🏿‍🦱' => 'persone: pedde iscura e pilos aneddados',
    '🧑🏻‍🦳' => 'persone: pedde crara e pilos biancos',
    '🧑🏼‍🦳' => 'persone: pedde bastante crara e pilos biancos',
    '🧑🏽‍🦳' => 'persone: pedde de colore mèdiu e pilos biancos',
    '🧑🏾‍🦳' => 'persone: pedde bastante iscura e pilos biancos',
    '🧑🏿‍🦳' => 'persone: pedde iscura e pilos biancos',
    '🧑🏻‍🦲' => 'persone: pedde crara e ispilidu',
    '🧑🏼‍🦲' => 'persone: pedde bastante crara e ispilidu',
    '🧑🏽‍🦲' => 'persone: pedde de colore mèdiu e ispilidu',
    '🧑🏾‍🦲' => 'persone: pedde bastante iscura e ispilidu',
    '🧑🏿‍🦲' => 'persone: pedde iscura e ispilidu',
    '🧔🏻‍♂' => 'òmine barbudu: pedde crara',
    '🧔🏼‍♂' => 'òmine barbudu: pedde bastante crara',
    '🧔🏽‍♂' => 'òmine barbudu: pedde de colore mèdiu',
    '🧔🏾‍♂' => 'òmine barbudu: pedde bastante iscura',
    '🧔🏿‍♂' => 'òmine barbudu: pedde iscura',
    '👱🏻‍♂' => 'òmine brundu: pedde crara',
    '👱🏼‍♂' => 'òmine brundu: pedde bastante crara',
    '👱🏽‍♂' => 'òmine brundu: pedde de colore mèdiu',
    '👱🏾‍♂' => 'òmine brundu: pedde bastante iscura',
    '👱🏿‍♂' => 'òmine brundu: pedde iscura',
    '👨🏻‍🦰' => 'òmine: pedde crara e pilos rujos',
    '👨🏼‍🦰' => 'òmine: pedde bastante crara e pilos rujos',
    '👨🏽‍🦰' => 'òmine: pedde de colore mèdiu e pilos rujos',
    '👨🏾‍🦰' => 'òmine: pedde bastante iscura e pilos rujos',
    '👨🏿‍🦰' => 'òmine: pedde iscura e pilos rujos',
    '👨🏻‍🦱' => 'òmine: pedde crara e pilos aneddados',
    '👨🏼‍🦱' => 'òmine: pedde bastante crara e pilos aneddados',
    '👨🏽‍🦱' => 'òmine: pedde de colore mèdiu e pilos aneddados',
    '👨🏾‍🦱' => 'òmine: pedde bastante iscura e pilos aneddados',
    '👨🏿‍🦱' => 'òmine: pedde iscura e pilos aneddados',
    '👨🏻‍🦳' => 'òmine: pedde crara e pilos biancos',
    '👨🏼‍🦳' => 'òmine: pedde bastante crara e pilos biancos',
    '👨🏽‍🦳' => 'òmine: pedde de colore mèdiu e pilos biancos',
    '👨🏾‍🦳' => 'òmine: pedde bastante iscura e pilos biancos',
    '👨🏿‍🦳' => 'òmine: pedde iscura e pilos biancos',
    '👨🏻‍🦲' => 'òmine: pedde crara e ispilidu',
    '👨🏼‍🦲' => 'òmine: pedde bastante crara e ispilidu',
    '👨🏽‍🦲' => 'òmine: pedde de colore mèdiu e ispilidu',
    '👨🏾‍🦲' => 'òmine: pedde bastante iscura e ispilidu',
    '👨🏿‍🦲' => 'òmine: pedde iscura e ispilidu',
    '🧔🏻‍♀' => 'fèmina barbuda: pedde crara',
    '🧔🏼‍♀' => 'fèmina barbuda: pedde bastante crara',
    '🧔🏽‍♀' => 'fèmina barbuda: pedde de colore mèdiu',
    '🧔🏾‍♀' => 'fèmina barbuda: pedde bastante iscura',
    '🧔🏿‍♀' => 'fèmina barbuda: pedde iscura',
    '👱🏻‍♀' => 'fèmina brunda: pedde crara',
    '👱🏼‍♀' => 'fèmina brunda: pedde bastante crara',
    '👱🏽‍♀' => 'fèmina brunda: pedde de colore mèdiu',
    '👱🏾‍♀' => 'fèmina brunda: pedde bastante iscura',
    '👱🏿‍♀' => 'fèmina brunda: pedde iscura',
    '👩🏻‍🦰' => 'fèmina: pedde crara e pilos rujos',
    '👩🏼‍🦰' => 'fèmina: pedde bastante crara e pilos rujos',
    '👩🏽‍🦰' => 'fèmina: pedde de colore mèdiu e pilos rujos',
    '👩🏾‍🦰' => 'fèmina: pedde bastante iscura e pilos rujos',
    '👩🏿‍🦰' => 'fèmina: pedde iscura e pilos rujos',
    '👩🏻‍🦱' => 'fèmina: pedde crara e pilos aneddados',
    '👩🏼‍🦱' => 'fèmina: pedde bastante crara e pilos aneddados',
    '👩🏽‍🦱' => 'fèmina: pedde de colore mèdiu e pilos aneddados',
    '👩🏾‍🦱' => 'fèmina: pedde bastante iscura e pilos aneddados',
    '👩🏿‍🦱' => 'fèmina: pedde iscura e pilos aneddados',
    '👩🏻‍🦳' => 'fèmina: pedde crara e pilos biancos',
    '👩🏼‍🦳' => 'fèmina: pedde bastante crara e pilos biancos',
    '👩🏽‍🦳' => 'fèmina: pedde de colore mèdiu e pilos biancos',
    '👩🏾‍🦳' => 'fèmina: pedde bastante iscura e pilos biancos',
    '👩🏿‍🦳' => 'fèmina: pedde iscura e pilos biancos',
    '👩🏻‍🦲' => 'fèmina: pedde crara e ispilidu',
    '👩🏼‍🦲' => 'fèmina: pedde bastante crara e ispilidu',
    '👩🏽‍🦲' => 'fèmina: pedde de colore mèdiu e ispilidu',
    '👩🏾‍🦲' => 'fèmina: pedde bastante iscura e ispilidu',
    '👩🏿‍🦲' => 'fèmina: pedde iscura e ispilidu',
    '🦹🏻‍♂' => 'supercriminale òmine: pedde crara',
    '🦹🏼‍♂' => 'supercriminale òmine: pedde bastante crara',
    '🦹🏽‍♂' => 'supercriminale òmine: pedde de colore mèdiu',
    '🦹🏾‍♂' => 'supercriminale òmine: pedde bastante iscura',
    '🦹🏿‍♂' => 'supercriminale òmine: pedde iscura',
    '🦹🏻‍♀' => 'supercriminale fèmina: pedde crara',
    '🦹🏼‍♀' => 'supercriminale fèmina: pedde bastante crara',
    '🦹🏽‍♀' => 'supercriminale fèmina: pedde de colore mèdiu',
    '🦹🏾‍♀' => 'supercriminale fèmina: pedde bastante iscura',
    '🦹🏿‍♀' => 'supercriminale fèmina: pedde iscura',
    '🧙🏻‍♂' => 'majàrgiu òmine: pedde crara',
    '🧙🏼‍♂' => 'majàrgiu òmine: pedde bastante crara',
    '🧙🏽‍♂' => 'majàrgiu òmine: pedde de colore mèdiu',
    '🧙🏾‍♂' => 'majàrgiu òmine: pedde bastante iscura',
    '🧙🏿‍♂' => 'majàrgiu òmine: pedde iscura',
    '🧙🏻‍♀' => 'majàrgia: pedde crara',
    '🧙🏼‍♀' => 'majàrgia: pedde bastante crara',
    '🧙🏽‍♀' => 'majàrgia: pedde de colore mèdiu',
    '🧙🏾‍♀' => 'majàrgia: pedde bastante iscura',
    '🧙🏿‍♀' => 'majàrgia: pedde iscura',
    '🧚🏻‍♂' => 'fada òmine: pedde crara',
    '🧚🏼‍♂' => 'fada òmine: pedde bastante crara',
    '🧚🏽‍♂' => 'fada òmine: pedde de colore mèdiu',
    '🧚🏾‍♂' => 'fada òmine: pedde bastante iscura',
    '🧚🏿‍♂' => 'fada òmine: pedde iscura',
    '🧚🏻‍♀' => 'fada fèmina: pedde crara',
    '🧚🏼‍♀' => 'fada fèmina: pedde bastante crara',
    '🧚🏽‍♀' => 'fada fèmina: pedde de colore mèdiu',
    '🧚🏾‍♀' => 'fada fèmina: pedde bastante iscura',
    '🧚🏿‍♀' => 'fada fèmina: pedde iscura',
    '🧛🏻‍♂' => 'vampiru òmine: pedde crara',
    '🧛🏼‍♂' => 'vampiru òmine: pedde bastante crara',
    '🧛🏽‍♂' => 'vampiru òmine: pedde de colore mèdiu',
    '🧛🏾‍♂' => 'vampiru òmine: pedde bastante iscura',
    '🧛🏿‍♂' => 'vampiru òmine: pedde iscura',
    '🧛🏻‍♀' => 'vampira: pedde crara',
    '🧛🏼‍♀' => 'vampira: pedde bastante crara',
    '🧛🏽‍♀' => 'vampira: pedde de colore mèdiu',
    '🧛🏾‍♀' => 'vampira: pedde bastante iscura',
    '🧛🏿‍♀' => 'vampira: pedde iscura',
    '🧝🏻‍♂' => 'alvu òmine: pedde crara',
    '🧝🏼‍♂' => 'alvu òmine: pedde bastante crara',
    '🧝🏽‍♂' => 'alvu òmine: pedde de colore mèdiu',
    '🧝🏾‍♂' => 'alvu òmine: pedde bastante iscura',
    '🧝🏿‍♂' => 'alvu òmine: pedde iscura',
    '🧝🏻‍♀' => 'alva: pedde crara',
    '🧝🏼‍♀' => 'alva: pedde bastante crara',
    '🧝🏽‍♀' => 'alva: pedde de colore mèdiu',
    '🧝🏾‍♀' => 'alva: pedde bastante iscura',
    '🧝🏿‍♀' => 'alva: pedde iscura',
    '🧑‍🦰' => 'persone: pilos rujos',
    '🧑‍🦱' => 'persone: pilos aneddados',
    '🧑‍🦳' => 'persone: pilos biancos',
    '🧑‍🦲' => 'persone: ispilidu',
    '👨‍🦰' => 'òmine: pilos rujos',
    '👨‍🦱' => 'òmine: pilos aneddados',
    '👨‍🦳' => 'òmine: pilos biancos',
    '👨‍🦲' => 'òmine: ispilidu',
    '👩‍🦰' => 'fèmina: pilos rujos',
    '👩‍🦱' => 'fèmina: pilos aneddados',
    '👩‍🦳' => 'fèmina: pilos biancos',
    '👩‍🦲' => 'fèmina: ispilidu',
    '👨‍👦' => 'famìlia: òmine e pitzinnu',
    '👨‍👧' => 'famìlia: òmine e pitzinna',
    '👩‍👦' => 'famìlia: fèmina e pitzinnu',
    '👩‍👧' => 'famìlia: fèmina e pitzinna',
    '😶‍🌫' => 'cara in sas nues',
    '❤‍🔥' => 'coro brusiende',
    '❤‍🩹' => 'coro sanende',
    '👁‍🗨' => 'ogru in una nuedda',
    '🧔‍♂' => 'òmine barbudu',
    '👱‍♂' => 'òmine brundu',
    '🧔‍♀' => 'fèmina barbuda',
    '👱‍♀' => 'fèmina brunda',
    '🦹‍♂' => 'supercriminale òmine',
    '🦹‍♀' => 'supercriminale fèmina',
    '🧙‍♂' => 'majàrgiu òmine',
    '🧙‍♀' => 'majàrgia',
    '🧚‍♂' => 'fada òmine',
    '🧚‍♀' => 'fada fèmina',
    '🧛‍♂' => 'vampiru òmine',
    '🧛‍♀' => 'vampira',
    '🧝‍♂' => 'alvu òmine',
    '🧝‍♀' => 'alva',
    '🐕‍🦺' => 'cane de agiudu',
    '🐈‍⬛' => 'gatu nieddu',
    '🐻‍❄' => 'ursu polare',
    '🐦‍⬛' => 'pugione nieddu',
    '🐦‍🔥' => 'fenitze',
    '⛓‍💥' => 'cadena truncada',
    '🏳‍🌈' => 'bandera de s’arcu de chelu',
    '🏳‍⚧' => 'bandera de sos transgèneres',
    '🏴‍☠' => 'bandera de sos piratas',
    '🦵🏻' => 'anca: pedde crara',
    '🦵🏼' => 'anca: pedde bastante crara',
    '🦵🏽' => 'anca: pedde de colore mèdiu',
    '🦵🏾' => 'anca: pedde bastante iscura',
    '🦵🏿' => 'anca: pedde iscura',
    '🦶🏻' => 'pee: pedde crara',
    '🦶🏼' => 'pee: pedde bastante crara',
    '🦶🏽' => 'pee: pedde de colore mèdiu',
    '🦶🏾' => 'pee: pedde bastante iscura',
    '🦶🏿' => 'pee: pedde iscura',
    '👂🏻' => 'origra: pedde crara',
    '👂🏼' => 'origra: pedde bastante crara',
    '👂🏽' => 'origra: pedde de colore mèdiu',
    '👂🏾' => 'origra: pedde bastante iscura',
    '👂🏿' => 'origra: pedde iscura',
    '👃🏻' => 'nasu: pedde crara',
    '👃🏼' => 'nasu: pedde bastante crara',
    '👃🏽' => 'nasu: pedde de colore mèdiu',
    '👃🏾' => 'nasu: pedde bastante iscura',
    '👃🏿' => 'nasu: pedde iscura',
    '👶🏻' => 'creadura: pedde crara',
    '👶🏼' => 'creadura: pedde bastante crara',
    '👶🏽' => 'creadura: pedde de colore mèdiu',
    '👶🏾' => 'creadura: pedde bastante iscura',
    '👶🏿' => 'creadura: pedde iscura',
    '🧒🏻' => 'pitzinneddu: pedde crara',
    '🧒🏼' => 'pitzinneddu: pedde bastante crara',
    '🧒🏽' => 'pitzinneddu: pedde de colore mèdiu',
    '🧒🏾' => 'pitzinneddu: pedde bastante iscura',
    '🧒🏿' => 'pitzinneddu: pedde iscura',
    '👦🏻' => 'pitzinnu: pedde crara',
    '👦🏼' => 'pitzinnu: pedde bastante crara',
    '👦🏽' => 'pitzinnu: pedde de colore mèdiu',
    '👦🏾' => 'pitzinnu: pedde bastante iscura',
    '👦🏿' => 'pitzinnu: pedde iscura',
    '👧🏻' => 'pitzinna: pedde crara',
    '👧🏼' => 'pitzinna: pedde bastante crara',
    '👧🏽' => 'pitzinna: pedde de colore mèdiu',
    '👧🏾' => 'pitzinna: pedde bastante iscura',
    '👧🏿' => 'pitzinna: pedde iscura',
    '🧑🏻' => 'persone: pedde crara',
    '🧑🏼' => 'persone: pedde bastante crara',
    '🧑🏽' => 'persone: pedde de colore mèdiu',
    '🧑🏾' => 'persone: pedde bastante iscura',
    '🧑🏿' => 'persone: pedde iscura',
    '👱🏻' => 'persone brunda: pedde crara',
    '👱🏼' => 'persone brunda: pedde bastante crara',
    '👱🏽' => 'persone brunda: pedde de colore mèdiu',
    '👱🏾' => 'persone brunda: pedde bastante iscura',
    '👱🏿' => 'persone brunda: pedde iscura',
    '👨🏻' => 'òmine: pedde crara',
    '👨🏼' => 'òmine: pedde bastante crara',
    '👨🏽' => 'òmine: pedde de colore mèdiu',
    '👨🏾' => 'òmine: pedde bastante iscura',
    '👨🏿' => 'òmine: pedde iscura',
    '🧔🏻' => 'persone barbuda: pedde crara',
    '🧔🏼' => 'persone barbuda: pedde bastante crara',
    '🧔🏽' => 'persone barbuda: pedde de colore mèdiu',
    '🧔🏾' => 'persone barbuda: pedde bastante iscura',
    '🧔🏿' => 'persone barbuda: pedde iscura',
    '👩🏻' => 'fèmina: pedde crara',
    '👩🏼' => 'fèmina: pedde bastante crara',
    '👩🏽' => 'fèmina: pedde de colore mèdiu',
    '👩🏾' => 'fèmina: pedde bastante iscura',
    '👩🏿' => 'fèmina: pedde iscura',
    '🧓🏻' => 'persone antziana: pedde crara',
    '🧓🏼' => 'persone antziana: pedde bastante crara',
    '🧓🏽' => 'persone antziana: pedde de colore mèdiu',
    '🧓🏾' => 'persone antziana: pedde bastante iscura',
    '🧓🏿' => 'persone antziana: pedde iscura',
    '👴🏻' => 'òmine antzianu: pedde crara',
    '👴🏼' => 'òmine antzianu: pedde bastante crara',
    '👴🏽' => 'òmine antzianu: pedde de colore mèdiu',
    '👴🏾' => 'òmine antzianu: pedde bastante iscura',
    '👴🏿' => 'òmine antzianu: pedde iscura',
    '👵🏻' => 'fèmina antziana: pedde crara',
    '👵🏼' => 'fèmina antziana: pedde bastante crara',
    '👵🏽' => 'fèmina antziana: pedde de colore mèdiu',
    '👵🏾' => 'fèmina antziana: pedde bastante iscura',
    '👵🏿' => 'fèmina antziana: pedde iscura',
    '🤴🏻' => 'prìntzipe: pedde crara',
    '🤴🏼' => 'prìntzipe: pedde bastante crara',
    '🤴🏽' => 'prìntzipe: pedde de colore mèdiu',
    '🤴🏾' => 'prìntzipe: pedde bastante iscura',
    '🤴🏿' => 'prìntzipe: pedde iscura',
    '👸🏻' => 'printzesa: pedde crara',
    '👸🏼' => 'printzesa: pedde bastante crara',
    '👸🏽' => 'printzesa: pedde de colore mèdiu',
    '👸🏾' => 'printzesa: pedde bastante iscura',
    '👸🏿' => 'printzesa: pedde iscura',
    '🤰🏻' => 'fèmina prìngia: pedde crara',
    '🤰🏼' => 'fèmina prìngia: pedde bastante crara',
    '🤰🏽' => 'fèmina prìngia: pedde de colore mèdiu',
    '🤰🏾' => 'fèmina prìngia: pedde bastante iscura',
    '🤰🏿' => 'fèmina prìngia: pedde iscura',
    '👼🏻' => 'angheleddu: pedde crara',
    '👼🏼' => 'angheleddu: pedde bastante crara',
    '👼🏽' => 'angheleddu: pedde de colore mèdiu',
    '👼🏾' => 'angheleddu: pedde bastante iscura',
    '👼🏿' => 'angheleddu: pedde iscura',
    '🦸🏻' => 'supereroe: pedde crara',
    '🦸🏼' => 'supereroe: pedde bastante crara',
    '🦸🏽' => 'supereroe: pedde de colore mèdiu',
    '🦸🏾' => 'supereroe: pedde bastante iscura',
    '🦸🏿' => 'supereroe: pedde iscura',
    '🦹🏻' => 'supercriminale: pedde crara',
    '🦹🏼' => 'supercriminale: pedde bastante crara',
    '🦹🏽' => 'supercriminale: pedde de colore mèdiu',
    '🦹🏾' => 'supercriminale: pedde bastante iscura',
    '🦹🏿' => 'supercriminale: pedde iscura',
    '🧙🏻' => 'majàrgiu: pedde crara',
    '🧙🏼' => 'majàrgiu: pedde bastante crara',
    '🧙🏽' => 'majàrgiu: pedde de colore mèdiu',
    '🧙🏾' => 'majàrgiu: pedde bastante iscura',
    '🧙🏿' => 'majàrgiu: pedde iscura',
    '🧚🏻' => 'fada: pedde crara',
    '🧚🏼' => 'fada: pedde bastante crara',
    '🧚🏽' => 'fada: pedde de colore mèdiu',
    '🧚🏾' => 'fada: pedde bastante iscura',
    '🧚🏿' => 'fada: pedde iscura',
    '🧛🏻' => 'vampiru: pedde crara',
    '🧛🏼' => 'vampiru: pedde bastante crara',
    '🧛🏽' => 'vampiru: pedde de colore mèdiu',
    '🧛🏾' => 'vampiru: pedde bastante iscura',
    '🧛🏿' => 'vampiru: pedde iscura',
    '🧝🏻' => 'alvu: pedde crara',
    '🧝🏼' => 'alvu: pedde bastante crara',
    '🧝🏽' => 'alvu: pedde de colore mèdiu',
    '🧝🏾' => 'alvu: pedde bastante iscura',
    '🧝🏿' => 'alvu: pedde iscura',
    '💏🏻' => 'basu: pedde crara',
    '💏🏼' => 'basu: pedde bastante crara',
    '💏🏽' => 'basu: pedde de colore mèdiu',
    '💏🏾' => 'basu: pedde bastante iscura',
    '💏🏿' => 'basu: pedde iscura',
    '🇦🇨' => 'bandera: Ìsula de s’Ascensione',
    '🇦🇩' => 'bandera: Andorra',
    '🇦🇪' => 'bandera: Emirados Àrabos Unidos',
    '🇦🇫' => 'bandera: Afghànistan',
    '🇦🇬' => 'bandera: Antigua e Barbuda',
    '🇦🇮' => 'bandera: Anguilla',
    '🇦🇱' => 'bandera: Albania',
    '🇦🇲' => 'bandera: Armènia',
    '🇦🇴' => 'bandera: Angola',
    '🇦🇶' => 'bandera: Antàrticu',
    '🇦🇷' => 'bandera: Argentina',
    '🇦🇸' => 'bandera: Samoa americanas',
    '🇦🇹' => 'bandera: Àustria',
    '🇦🇺' => 'bandera: Austràlia',
    '🇦🇼' => 'bandera: Aruba',
    '🇦🇽' => 'bandera: Ìsulas Åland',
    '🇦🇿' => 'bandera: Azerbaigiàn',
    '🇧🇦' => 'bandera: Bòsnia e Erzegòvina',
    '🇧🇧' => 'bandera: Barbados',
    '🇧🇩' => 'bandera: Bangladèsh',
    '🇧🇪' => 'bandera: Bèlgiu',
    '🇧🇫' => 'bandera: Burkina Faso',
    '🇧🇬' => 'bandera: Bulgaria',
    '🇧🇭' => 'bandera: Bahrein',
    '🇧🇮' => 'bandera: Burundi',
    '🇧🇯' => 'bandera: Benin',
    '🇧🇱' => 'bandera: Santu Bartolomeu',
    '🇧🇲' => 'bandera: Bermudas',
    '🇧🇳' => 'bandera: Brunei',
    '🇧🇴' => 'bandera: Bolìvia',
    '🇧🇶' => 'bandera: Caràibes olandesas',
    '🇧🇷' => 'bandera: Brasile',
    '🇧🇸' => 'bandera: Bahamas',
    '🇧🇹' => 'bandera: Bhutàn',
    '🇧🇻' => 'bandera: Ìsula Bouvet',
    '🇧🇼' => 'bandera: Botswana',
    '🇧🇾' => 'bandera: Bielorùssia',
    '🇧🇿' => 'bandera: Belize',
    '🇨🇦' => 'bandera: Cànada',
    '🇨🇨' => 'bandera: Ìsulas Cocos (Keeling)',
    '🇨🇩' => 'bandera: Congo - Kinshasa',
    '🇨🇫' => 'bandera: Repùblica Tzentrafricana',
    '🇨🇬' => 'bandera: Congo - Bratzaville',
    '🇨🇭' => 'bandera: Isvìtzera',
    '🇨🇮' => 'bandera: Costa de Avòriu',
    '🇨🇰' => 'bandera: Ìsulas Cook',
    '🇨🇱' => 'bandera: Tzile',
    '🇨🇲' => 'bandera: Camerùn',
    '🇨🇳' => 'bandera: Tzina',
    '🇨🇴' => 'bandera: Colòmbia',
    '🇨🇵' => 'bandera: Ìsula de Clipperton',
    '🇨🇶' => 'bandera: Sark',
    '🇨🇷' => 'bandera: Costa Rica',
    '🇨🇺' => 'bandera: Cuba',
    '🇨🇻' => 'bandera: Cabu birde',
    '🇨🇼' => 'bandera: Curaçao',
    '🇨🇽' => 'bandera: Ìsula de sa Natividade',
    '🇨🇾' => 'bandera: Tzipru',
    '🇨🇿' => 'bandera: Tzèchia',
    '🇩🇪' => 'bandera: Germània',
    '🇩🇬' => 'bandera: Diego Garcia',
    '🇩🇯' => 'bandera: Gibuti',
    '🇩🇰' => 'bandera: Danimarca',
    '🇩🇲' => 'bandera: Dominica',
    '🇩🇴' => 'bandera: Repùblica Dominicana',
    '🇩🇿' => 'bandera: Algeria',
    '🇪🇦' => 'bandera: Ceuta e Melilla',
    '🇪🇨' => 'bandera: Ècuador',
    '🇪🇪' => 'bandera: Estònia',
    '🇪🇬' => 'bandera: Egitu',
    '🇪🇭' => 'bandera: Sahara otzidentale',
    '🇪🇷' => 'bandera: Eritrea',
    '🇪🇸' => 'bandera: Ispagna',
    '🇪🇹' => 'bandera: Etiòpia',
    '🇪🇺' => 'bandera: Unione Europea',
    '🇫🇮' => 'bandera: Finlàndia',
    '🇫🇯' => 'bandera: Fiji',
    '🇫🇰' => 'bandera: Ìsulas Falkland',
    '🇫🇲' => 'bandera: Micronèsia',
    '🇫🇴' => 'bandera: Ìsulas Føroyar',
    '🇫🇷' => 'bandera: Frantza',
    '🇬🇦' => 'bandera: Gabòn',
    '🇬🇧' => 'bandera: Regnu Unidu',
    '🇬🇩' => 'bandera: Grenada',
    '🇬🇪' => 'bandera: Geòrgia',
    '🇬🇫' => 'bandera: Guiana frantzesa',
    '🇬🇬' => 'bandera: Guernsey',
    '🇬🇭' => 'bandera: Ghana',
    '🇬🇮' => 'bandera: Gibilterra',
    '🇬🇱' => 'bandera: Groenlàndia',
    '🇬🇲' => 'bandera: Gàmbia',
    '🇬🇳' => 'bandera: Guinea',
    '🇬🇵' => 'bandera: Guadalupa',
    '🇬🇶' => 'bandera: Guinea Ecuadoriale',
    '🇬🇷' => 'bandera: Grètzia',
    '🇬🇸' => 'bandera: Geòrgia de su Sud e Ìsulas Sandwich Australes',
    '🇬🇹' => 'bandera: Guatemala',
    '🇬🇺' => 'bandera: Guàm',
    '🇬🇼' => 'bandera: Guinea-Bissau',
    '🇬🇾' => 'bandera: Guyana',
    '🇭🇰' => 'bandera: RAS tzinesa de Hong Kong',
    '🇭🇲' => 'bandera: Ìsulas Heard e McDonald',
    '🇭🇳' => 'bandera: Honduras',
    '🇭🇷' => 'bandera: Croàtzia',
    '🇭🇹' => 'bandera: Haiti',
    '🇭🇺' => 'bandera: Ungheria',
    '🇮🇨' => 'bandera: Ìsulas Canàrias',
    '🇮🇩' => 'bandera: Indonèsia',
    '🇮🇪' => 'bandera: Irlanda',
    '🇮🇱' => 'bandera: Israele',
    '🇮🇲' => 'bandera: Ìsula de Man',
    '🇮🇳' => 'bandera: Ìndia',
    '🇮🇴' => 'bandera: Territòriu Britànnicu de s’Otzèanu Indianu',
    '🇮🇶' => 'bandera: Iraq',
    '🇮🇷' => 'bandera: Iràn',
    '🇮🇸' => 'bandera: Islanda',
    '🇮🇹' => 'bandera: Itàlia',
    '🇯🇪' => 'bandera: Jersey',
    '🇯🇲' => 'bandera: Giamàica',
    '🇯🇴' => 'bandera: Giordània',
    '🇯🇵' => 'bandera: Giapone',
    '🇰🇪' => 'bandera: Kènya',
    '🇰🇬' => 'bandera: Kirghìzistan',
    '🇰🇭' => 'bandera: Cambòdia',
    '🇰🇮' => 'bandera: Kiribati',
    '🇰🇲' => 'bandera: Comoras',
    '🇰🇳' => 'bandera: Santu Cristolu e Nevis',
    '🇰🇵' => 'bandera: Corea de su Nord',
    '🇰🇷' => 'bandera: Corea de su Sud',
    '🇰🇼' => 'bandera: Kuwait',
    '🇰🇾' => 'bandera: Ìsulas Cayman',
    '🇰🇿' => 'bandera: Kazàkistan',
    '🇱🇦' => 'bandera: Laos',
    '🇱🇧' => 'bandera: Lèbanu',
    '🇱🇨' => 'bandera: Santa Lughia',
    '🇱🇮' => 'bandera: Liechtenstein',
    '🇱🇰' => 'bandera: Sri Lanka',
    '🇱🇷' => 'bandera: Libèria',
    '🇱🇸' => 'bandera: Lesotho',
    '🇱🇹' => 'bandera: Lituània',
    '🇱🇺' => 'bandera: Lussemburgu',
    '🇱🇻' => 'bandera: Letònia',
    '🇱🇾' => 'bandera: Lìbia',
    '🇲🇦' => 'bandera: Marocu',
    '🇲🇨' => 'bandera: Mònacu',
    '🇲🇩' => 'bandera: Moldàvia',
    '🇲🇪' => 'bandera: Montenegro',
    '🇲🇫' => 'bandera: Santu Martine',
    '🇲🇬' => 'bandera: Madagascàr',
    '🇲🇭' => 'bandera: Ìsulas Marshall',
    '🇲🇰' => 'bandera: Matzedònia de su Nord',
    '🇲🇱' => 'bandera: Mali',
    '🇲🇲' => 'bandera: Myanmàr (Birmània)',
    '🇲🇳' => 'bandera: Mongòlia',
    '🇲🇴' => 'bandera: RAS tzinesa de Macao',
    '🇲🇵' => 'bandera: Ìsulas Mariannas setentrionales',
    '🇲🇶' => 'bandera: Martinica',
    '🇲🇷' => 'bandera: Mauritània',
    '🇲🇸' => 'bandera: Montserrat',
    '🇲🇹' => 'bandera: Malta',
    '🇲🇺' => 'bandera: Maurìtzius',
    '🇲🇻' => 'bandera: Maldivas',
    '🇲🇼' => 'bandera: Malawi',
    '🇲🇽' => 'bandera: Mèssicu',
    '🇲🇾' => 'bandera: Malèsia',
    '🇲🇿' => 'bandera: Mozambicu',
    '🇳🇦' => 'bandera: Namìbia',
    '🇳🇨' => 'bandera: Caledònia Noa',
    '🇳🇪' => 'bandera: Niger',
    '🇳🇫' => 'bandera: Ìsula Norfolk',
    '🇳🇬' => 'bandera: Nigèria',
    '🇳🇮' => 'bandera: Nicaràgua',
    '🇳🇱' => 'bandera: Paisos Bassos',
    '🇳🇴' => 'bandera: Norvègia',
    '🇳🇵' => 'bandera: Nèpal',
    '🇳🇷' => 'bandera: Nauru',
    '🇳🇺' => 'bandera: Niue',
    '🇳🇿' => 'bandera: Zelanda Noa',
    '🇴🇲' => 'bandera: Omàn',
    '🇵🇦' => 'bandera: Pànama',
    '🇵🇪' => 'bandera: Perù',
    '🇵🇫' => 'bandera: Polinèsia frantzesa',
    '🇵🇬' => 'bandera: Pàpua Guinea Noa',
    '🇵🇭' => 'bandera: Filipinas',
    '🇵🇰' => 'bandera: Pàkistan',
    '🇵🇱' => 'bandera: Polònia',
    '🇵🇲' => 'bandera: Santu Predu e Miquelon',
    '🇵🇳' => 'bandera: Ìsulas Pìtcairn',
    '🇵🇷' => 'bandera: Puerto Rico',
    '🇵🇸' => 'bandera: Territòrios palestinesos',
    '🇵🇹' => 'bandera: Portogallu',
    '🇵🇼' => 'bandera: Palau',
    '🇵🇾' => 'bandera: Paraguày',
    '🇶🇦' => 'bandera: Catàr',
    '🇷🇪' => 'bandera: Riunione',
    '🇷🇴' => 'bandera: Romania',
    '🇷🇸' => 'bandera: Sèrbia',
    '🇷🇺' => 'bandera: Rùssia',
    '🇷🇼' => 'bandera: Ruanda',
    '🇸🇦' => 'bandera: Aràbia Saudita',
    '🇸🇧' => 'bandera: Ìsulas Salomone',
    '🇸🇨' => 'bandera: Seychelles',
    '🇸🇩' => 'bandera: Sudàn',
    '🇸🇪' => 'bandera: Isvètzia',
    '🇸🇬' => 'bandera: Singapore',
    '🇸🇭' => 'bandera: Santa Elene',
    '🇸🇮' => 'bandera: Islovènia',
    '🇸🇯' => 'bandera: Svalbard e Jan Mayen',
    '🇸🇰' => 'bandera: Islovàchia',
    '🇸🇱' => 'bandera: Sierra Leone',
    '🇸🇲' => 'bandera: Santu Marinu',
    '🇸🇳' => 'bandera: Senegal',
    '🇸🇴' => 'bandera: Somàlia',
    '🇸🇷' => 'bandera: Suriname',
    '🇸🇸' => 'bandera: Sudan de su Sud',
    '🇸🇹' => 'bandera: São Tomé e Príncipe',
    '🇸🇻' => 'bandera: El Salvador',
    '🇸🇽' => 'bandera: Sint Maarten',
    '🇸🇾' => 'bandera: Sìria',
    '🇸🇿' => 'bandera: Eswatini',
    '🇹🇦' => 'bandera: Tristan da Cunha',
    '🇹🇨' => 'bandera: Ìsulas Turks e Caicos',
    '🇹🇩' => 'bandera: Chad',
    '🇹🇫' => 'bandera: Terras australes frantzesas',
    '🇹🇬' => 'bandera: Togo',
    '🇹🇭' => 'bandera: Tailàndia',
    '🇹🇯' => 'bandera: Tagìkistan',
    '🇹🇰' => 'bandera: Tokelau',
    '🇹🇱' => 'bandera: Timor-Est',
    '🇹🇲' => 'bandera: Turkmènistan',
    '🇹🇳' => 'bandera: Tunisia',
    '🇹🇴' => 'bandera: Tonga',
    '🇹🇷' => 'bandera: Turchia',
    '🇹🇹' => 'bandera: Trinidad e Tobago',
    '🇹🇻' => 'bandera: Tuvalu',
    '🇹🇼' => 'bandera: Taiwàn',
    '🇹🇿' => 'bandera: Tanzània',
    '🇺🇦' => 'bandera: Ucraina',
    '🇺🇬' => 'bandera: Uganda',
    '🇺🇲' => 'bandera: Ìsulas perifèricas de sos Istados Unidos',
    '🇺🇳' => 'bandera: Natziones Unidas',
    '🇺🇸' => 'bandera: Istados Unidos',
    '🇺🇾' => 'bandera: Uruguày',
    '🇺🇿' => 'bandera: Uzbèkistan',
    '🇻🇦' => 'bandera: Tzitade de su Vaticanu',
    '🇻🇨' => 'bandera: Santu Vissente e sas Grenadinas',
    '🇻🇪' => 'bandera: Venetzuela',
    '🇻🇬' => 'bandera: Ìsulas Vèrgines Britànnicas',
    '🇻🇮' => 'bandera: Ìsulas Vèrgines de sos Istados Unidos',
    '🇻🇳' => 'bandera: Vietnam',
    '🇻🇺' => 'bandera: Vanuatu',
    '🇼🇫' => 'bandera: Wallis e Futuna',
    '🇼🇸' => 'bandera: Samoa',
    '🇽🇰' => 'bandera: Kòssovo',
    '🇾🇪' => 'bandera: Yemen',
    '🇾🇹' => 'bandera: Mayotte',
    '🇿🇦' => 'bandera: Sudàfrica',
    '🇿🇲' => 'bandera: Zàmbia',
    '🇿🇼' => 'bandera: Zimbabwe',
    '🔟' => 'tecla: 10',
    '🏻' => 'pedde crara',
    '🏼' => 'pedde bastante crara',
    '🏽' => 'pedde de colore mèdiu',
    '🏾' => 'pedde bastante iscura',
    '🏿' => 'pedde iscura',
    '😀' => 'cara risulana',
    '😃' => 'cara risulana cun ogros ispamparriados',
    '😄' => 'cara risulana cun sos ogros chi rident',
    '😁' => 'cara alligra cun ogros risulanos',
    '😆' => 'cara risulana cun ogros serrados',
    '😅' => 'cara risulana cun gùtiu de suore',
    '🤣' => 'riende a iscracàllios',
    '😂' => 'cara cun làgrimas de cuntentesa',
    '🙂' => 'cara cun sorrisu atzinnadu',
    '🙃' => 'cara a conca a giosso',
    '🫠' => 'cara isorvende·si',
    '😉' => 'cara chi faghet s’atzinnu',
    '😊' => 'cara risulana cun ogros risulanos',
    '😇' => 'cara risulana cun chìrchinu',
    '🙄' => 'cara cun ogros a chelu',
    '🤥' => 'cara de faulàrgiu',
    '😡' => 'cara inchieta',
    '😠' => 'cara arrennegada',
    '🤬' => 'cara cun sìmbulos subra de sa buca',
    '😈' => 'cara risulana cun corros',
    '👿' => 'cara inchieta cun corros',
    '💀' => 'calavera',
    '☠' => 'calavera cun ossos rugrados',
    '💩' => 'muntoneddu de merda',
    '🤡' => 'cara de palliatzu',
    '👹' => 'orcu',
    '👺' => 'tengu giaponesu',
    '👻' => 'pantasma',
    '👽' => 'alienu',
    '👾' => 'mostru alienu',
    '🤖' => 'robot',
    '😺' => 'gatu risulanu',
    '😸' => 'gatu risulanu cun sos ogros chi rident',
    '😹' => 'gatu cun làgrimas de cuntentesa',
    '😻' => 'gatu risulanu cun ogros a forma de coro',
    '😼' => 'gatu befulanu',
    '😽' => 'gatu chi mandat basos',
    '🙀' => 'gatu istasidu',
    '😿' => 'gatu chi pranghet',
    '😾' => 'gatu a murru longu',
    '🙈' => 'muninca chi non bidet su male',
    '🙉' => 'muninca chi no intendet su male',
    '🙊' => 'muninca chi non narat cosa mala',
    '💌' => 'lìtera de amore',
    '💘' => 'coro cun fritza',
    '💝' => 'coro cun listrone',
    '💖' => 'coro brillende',
    '💗' => 'coro creschende',
    '💓' => 'coro tocheddende',
    '💞' => 'coros girende',
    '💕' => 'duos coros',
    '💟' => 'decoratzione a forma de coro',
    '❣' => 'coro esclamativu',
    '💔' => 'coro segadu',
    '❤' => 'coro ruju',
    '🩷' => 'coro rosa',
    '🧡' => 'coro arantzu',
    '💛' => 'coro grogu',
    '💚' => 'coro birde',
    '💙' => 'coro biaitu',
    '🩵' => 'coro asulu',
    '💜' => 'coro tanadu',
    '🤎' => 'coro castàngiu',
    '🖤' => 'coro nieddu',
    '🩶' => 'coro murru',
    '🤍' => 'coro biancu',
    '💋' => 'sinnu de basu',
    '💯' => '100 puntos',
    '💢' => 'sìmbulu de s’arrennegu',
    '💥' => 'istumbada',
    '💫' => 'isteddu cun coa',
    '💦' => 'gùtios de sudore',
    '💨' => 'fuida lestra',
    '🕳' => 'istampu',
    '💬' => 'nuedda',
    '🗨' => 'nuedda de diàlogu a manca',
    '🗯' => 'nuedda de diàlogu inchietu a destra',
    '💭' => 'nuedda de pensamentu',
    '💤' => 'Zzz',
    '🦵' => 'anca',
    '🦶' => 'pee',
    '👂' => 'origra',
    '👃' => 'nasu',
    '🧠' => 'cherbeddu',
    '🫀' => 'coro anatòmicu',
    '🫁' => 'purmones',
    '🦷' => 'dente',
    '🦴' => 'ossu',
    '👀' => 'ogros',
    '👁' => 'ogru',
    '👅' => 'limba',
    '👄' => 'buca',
    '🫦' => 'buca chi mòssigat sas lavras',
    '👶' => 'creadura',
    '🧒' => 'pitzinneddu',
    '👦' => 'pitzinnu',
    '👧' => 'pitzinna',
    '🧑' => 'persone',
    '👱' => 'persone brunda',
    '👨' => 'òmine',
    '🧔' => 'persone barbuda',
    '👩' => 'fèmina',
    '🧓' => 'persone antziana',
    '👴' => 'òmine antzianu',
    '👵' => 'fèmina antziana',
    '🤴' => 'prìntzipe',
    '👸' => 'printzesa',
    '🤰' => 'fèmina prìngia',
    '👼' => 'angheleddu',
    '🦸' => 'supereroe',
    '🦹' => 'supercriminale',
    '🧙' => 'majàrgiu',
    '🧚' => 'fada',
    '🧛' => 'vampiru',
    '🧝' => 'alvu',
    '🧞' => 'gèniu',
    '🧌' => 'troll',
    '💏' => 'basu',
    '👪' => 'famìlia',
    '🦰' => 'pilos rujos',
    '🦱' => 'pilos aneddados',
    '🦳' => 'pilos biancos',
    '🦲' => 'ispilidu',
    '🐵' => 'cara de martinica',
    '🐒' => 'martinica',
    '🦍' => 'gorilla',
    '🦧' => 'orangutangu',
    '🐶' => 'murru de cane',
    '🐕' => 'cane',
    '🦮' => 'cane de ghia',
    '🐩' => 'barbontzinu',
    '🐺' => 'lupu',
    '🦊' => 'mariane',
    '🦝' => 'procione',
    '🐱' => 'murru de gatu',
    '🐈' => 'gatu',
    '🦁' => 'leone',
    '🐯' => 'murru de tigre',
    '🐅' => 'tigre',
    '🐆' => 'leopardu',
    '🐴' => 'murru de caddu',
    '🫎' => 'chervu nòrdicu',
    '🫏' => 'poleddu',
    '🐎' => 'caddu',
    '🦄' => 'unicornu',
    '🦓' => 'zebra',
    '🦌' => 'chervu',
    '🦬' => 'bisonte',
    '🐮' => 'murru de baca',
    '🐂' => 'boe',
    '🐃' => 'bùfalu de abba',
    '🐄' => 'baca',
    '🐷' => 'murru de porcu',
    '🐖' => 'porcu',
    '🐗' => 'sirbone',
    '🐽' => 'nasu de porcu',
    '🐏' => 'mascru',
    '🐑' => 'berbeghe',
    '🐐' => 'craba',
    '🐪' => 'dromedàriu',
    '🐫' => 'cammellu',
    '🦙' => 'lama',
    '🦒' => 'girafa',
    '🐘' => 'elefante',
    '🦣' => 'mammùt',
    '🦏' => 'rinotzeronte',
    '🦛' => 'ipopòtamu',
    '🐭' => 'murru de sòrighe',
    '🐁' => 'sòrighe',
    '🐀' => 'ratu',
    '🐹' => 'critzetu',
    '🐰' => 'murru de cunillu',
    '🐇' => 'cunillu',
    '🐿' => 'iscojàtulu',
    '🦫' => 'castoru',
    '🦔' => 'eritzu',
    '🦇' => 'tzintzimurreddu',
    '🐻' => 'ursu',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'bràdipu',
    '🦦' => 'lontra',
    '🦨' => 'pùtzola',
    '🦘' => 'canguru',
    '🦡' => 'tassu',
    '🐾' => 'rastas de animales',
    '🦃' => 'dindu',
    '🐔' => 'pudda',
    '🐓' => 'puddu',
    '🐣' => 'puddighinu naschende',
    '🐤' => 'puddighinu',
    '🐥' => 'puddighinu pompiadu in cara',
    '🐦' => 'pugione',
    '🐧' => 'pinguinu',
    '🕊' => 'culumba',
    '🦅' => 'àbbila',
    '🦆' => 'anade',
    '🦢' => 'chìghinu',
    '🦉' => 'cucumiau',
    '🦤' => 'dodo',
    '🪶' => 'piuma',
    '🦩' => 'mangone',
    '🦚' => 'paone',
    '🦜' => 'papagallu',
    '🪽' => 'ala',
    '🪿' => 'oca',
    '🐸' => 'rana',
    '🐊' => 'cocodrillu',
    '🐢' => 'tostòine',
    '🦎' => 'tziligherta',
    '🐍' => 'colovra',
    '🐲' => 'conca de dragu',
    '🐉' => 'dragu',
    '🦕' => 'sauròpodu',
    '🦖' => 'tirannosàuru',
    '🐳' => 'balena tzaviende abba',
    '🐋' => 'balena',
    '🐬' => 'delfinu',
    '🦭' => 'boe marinu',
    '🐟' => 'pische',
    '🐠' => 'pische tropicale',
    '🐡' => 'pische botza',
    '🦈' => 'canisca',
    '🐙' => 'purpu',
    '🐚' => 'croca',
    '🪸' => 'coraddu',
    '🪼' => 'medusa',
    '🐌' => 'corrobaca',
    '🦋' => 'mariposa',
    '🐛' => 'babbarotu',
    '🐜' => 'formiga',
    '🐝' => 'abe',
    '🪲' => 'carrabusu',
    '🐞' => 'mariola',
    '🦗' => 'grillu',
    '🪳' => 'iscarrafone',
    '🕷' => 'arangiolu',
    '🕸' => 'taddaranu',
    '🦂' => 'furchiddàdile',
    '🦟' => 'tzìntzula',
    '🪰' => 'musca',
    '🪱' => 'berme',
    '🦠' => 'mìcrobu',
    '💐' => 'matzu de frores',
    '🌸' => 'frore de cariasa',
    '💮' => 'frore biancu',
    '🪷' => 'lotu',
    '🏵' => 'rosighedda',
    '🌹' => 'rosa',
    '🥀' => 'frore alligiadu',
    '🌺' => 'ibiscu',
    '🌻' => 'girasole',
    '🌼' => 'frore',
    '🌷' => 'tulipanu',
    '🪻' => 'giatzintu',
    '🌱' => 'tziriotu',
    '🪴' => 'pranta in vasu',
    '🌲' => 'àrbore semper birde',
    '🌳' => 'àrbore cun fògia caduca',
    '🌴' => 'prama',
    '🌵' => 'càctus',
    '🌾' => 'pranta de rosu',
    '🌿' => 'pranta',
    '☘' => 'trifògiu',
    '🍀' => 'cuadrifògiu',
    '🍁' => 'fògia de olàdighe',
    '🍂' => 'fògia ruta',
    '🍃' => 'fògia in su bentu',
    '🪹' => 'nidu bòidu',
    '🪺' => 'nidu cun oos',
    '🍄' => 'cardulinu',
    '🍇' => 'àghina',
    '🍈' => 'melone',
    '🍉' => 'sìndria',
    '🍊' => 'mandarinu',
    '🍋' => 'limone',
    '🍌' => 'banana',
    '🍍' => 'ànanas',
    '🥭' => 'mangu',
    '🍎' => 'mela ruja',
    '🍏' => 'mela birde',
    '🍐' => 'pira',
    '🍑' => 'pèssighe',
    '🍒' => 'cariasas',
    '🍓' => 'fràgula',
    '🫐' => 'murtitzos',
    '🥝' => 'kiwi',
    '🍅' => 'tomata',
    '🫒' => 'olia',
    '🥥' => 'cocu',
    '🥑' => 'avocadu',
    '🍆' => 'perdingianu',
    '🥔' => 'patata',
    '🥕' => 'pastinaga',
    '🌽' => 'pannuga',
    '🌶' => 'pibereddu',
    '🫑' => 'piberone',
    '🥒' => 'cugùmene',
    '🥬' => 'birdura a fògia birde',
    '🥦' => 'càule de conca',
    '🧄' => 'àgiu',
    '🧅' => 'chibudda',
    '🥜' => 'nutzolas americanas',
    '🫘' => 'fasolos',
    '🌰' => 'castàngia',
    '🍞' => 'pane',
    '🥐' => 'croissant',
    '🥖' => 'baguette',
    '🫓' => 'covatza',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'pancakes',
    '🧇' => 'waffle',
    '🍔' => 'hamburger',
    '🍟' => 'patatas frintas',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥚' => 'ou',
    '🧈' => 'butiru',
    '🧂' => 'sale',
    '🥫' => 'màndigu in boto',
    '🍣' => 'sushi',
    '🍼' => 'puparola',
    '🥛' => 'tassa de late',
    '☕' => 'bèvida caente',
    '🫖' => 'tejera',
    '🍵' => 'tzìchera de tè chene mànigu',
    '🍶' => 'sakè',
    '🥢' => 'bachitas',
    '🍽' => 'furcheta e leputzu cun pratu',
    '🍴' => 'furcheta e leputzu',
    '🥄' => 'cullera',
    '🔪' => 'leputzu de coghina',
    '🫙' => 'boto',
    '🏺' => 'ànfora',
    '🌍' => 'mapamundu chi ammustrat s’Europa e s’Àfrica',
    '🌎' => 'mapamundu chi ammustrat sas Amèricas',
    '🌏' => 'mapamundu chi ammustrat s’Àsia e s’Austràlia',
    '🌐' => 'mapamundu cun meridianos',
    '🗺' => 'mapa de su mundu',
    '🗾' => 'mapa de su Giapone',
    '🧭' => 'bùssola',
    '🏔' => 'monte cun nie',
    '⛰' => 'monte',
    '🌋' => 'vulcanu',
    '🗻' => 'monte fuji',
    '🏕' => 'campègiu',
    '🏖' => 'praja cun para-sole',
    '🏜' => 'desertu',
    '🏝' => 'ìsula deserta',
    '🏞' => 'parcu natzionale',
    '🏟' => 'istàdiu',
    '🏛' => 'edifìtziu clàssicu',
    '🏗' => 'fàbricu de un’edifìtziu',
    '🧱' => 'matone',
    '🪨' => 'roca',
    '🪵' => 'linna',
    '🛖' => 'pinnetu',
    '🏘' => 'domos',
    '🏚' => 'domo chi si nch’est irrughende',
    '🏠' => 'domo',
    '🏡' => 'domo cun giardinu',
    '🏢' => 'fàbricu de ufìtzios',
    '🏣' => 'ufìtziu postale giaponesu',
    '🏤' => 'ufìtziu postale',
    '🏥' => 'ispidale',
    '🏦' => 'banca',
    '🏨' => 'albergu',
    '🏩' => 'love hotel',
    '🏪' => 'buteghedda',
    '🏫' => 'iscola',
    '🏬' => 'supermercadu',
    '🏭' => 'fàbrica',
    '🏯' => 'casteddu giaponesu',
    '🏰' => 'casteddu',
    '💒' => 'cojuiu',
    '🗼' => 'Turre de Tòkyo',
    '🗽' => 'Istàtua de sa Libertade',
    '⛪' => 'crèsia',
    '🕌' => 'moschea',
    '🛕' => 'tèmpiu induista',
    '🕍' => 'sinagoga',
    '⛩' => 'santuàriu shintoista',
    '🕋' => 'kaaba',
    '⛲' => 'càntaru',
    '⛺' => 'tenda',
    '🌁' => 'anneuladu',
    '🌃' => 'note cun isteddos',
    '🏙' => 'paesàgiu urbanu',
    '🌄' => 'arbèschida in sos montes',
    '🌅' => 'arbèschida',
    '🌆' => 'tzitade a s’intrinada',
    '🌇' => 'intrinada',
    '🌉' => 'ponte a de note',
    '♨' => 'fontes termales',
    '🎠' => 'caddu de giòstra',
    '🛝' => 'lassinadòrgiu',
    '🎡' => 'roda panoràmica',
    '🎢' => 'montagnas russas',
    '💈' => 'palu de barbieri',
    '🎪' => 'tendone de su tzircu',
    '🚂' => 'locomotiva',
    '🚃' => 'vagone',
    '🚄' => 'trenu a lestresa arta',
    '🚅' => 'trenu balla',
    '🚆' => 'trenu',
    '🚇' => 'metropolitana',
    '🚈' => 'metrotranvia',
    '🚉' => 'istatzione',
    '🚊' => 'tram',
    '🚝' => 'monorotàia',
    '🚞' => 'ferrovia de monte',
    '🚋' => 'vagone de su tram',
    '🚌' => 'postale',
    '🚍' => 'postale arribende',
    '🚎' => 'postalinu cun filu',
    '🚐' => 'postalinu',
    '🚑' => 'ambulàntzia',
    '🚒' => 'càmion de sos pompieris',
    '🚓' => 'màchina de sa politzia',
    '🚔' => 'màchina de sa politzia arribende',
    '🚕' => 'taxi',
    '🚖' => 'taxi arribende',
    '🚗' => 'automòbile',
    '🚘' => 'automòbile arribende',
    '🚙' => 'SUV',
    '🛻' => 'camieddu',
    '🚚' => 'càmion',
    '🚛' => 'autoarticuladu',
    '🚜' => 'tratore',
    '🏎' => 'automòbile de cursa',
    '🏍' => 'mototzicleta',
    '🛵' => 'motorinu',
    '🦽' => 'carrotzedda manuale',
    '🦼' => 'carrotzedda a motore',
    '🛺' => 'risciò a motore',
    '🚲' => 'bitzicleta',
    '🛴' => 'monopàtinu',
    '🛹' => 'skateboard',
    '🛼' => 'pàtinos a rodeddas',
    '🚏' => 'firmada de su postale',
    '🛣' => 'autostrada',
    '🛤' => 'ferrovia',
    '🛢' => 'barile de petròliu',
    '⛽' => 'istatzione de servìtziu',
    '🛞' => 'roda',
    '🚨' => 'sirena de sa politzia',
    '🚥' => 'semàforu orizontale',
    '🚦' => 'semàforu verticale',
    '🛑' => 'sinnale de stop',
    '🚧' => 'cantieri',
    '⚓' => 'àncora',
    '🛟' => 'sarvagente',
    '⛵' => 'barca a vela',
    '🛶' => 'canoa',
    '🚤' => 'motoscafu',
    '🛳' => 'nave de crotziera',
    '⛴' => 'navile',
    '🛥' => 'barca a motore',
    '🚢' => 'nave',
    '✈' => 'aeroplanu',
    '🛩' => 'aeroplanu minore',
    '🛫' => 'decollu',
    '🛬' => 'aterràgiu',
    '🪂' => 'pararutas',
    '💺' => 'sedile',
    '🚁' => 'elicòteru',
    '🚟' => 'ferrovia suspesa',
    '🚠' => 'funivia',
    '🚡' => 'funivia aèrea',
    '🛰' => 'satèllite',
    '🚀' => 'razu',
    '🛸' => 'discu chi bolat',
    '🛎' => 'campanedda de albergu',
    '🧳' => 'bagàlliu',
    '⌛' => 'rellògiu a arena chene tempus',
    '⏳' => 'rellògiu a arena iscurrende',
    '⌚' => 'rellògiu',
    '⏰' => 'isvèllia',
    '⏱' => 'cronòmetru',
    '⏲' => 'temporizadore',
    '🕰' => 'rellògiu de mesa',
    '🕛' => 'dòighi in puntu',
    '🕧' => 'dòighi e mesa',
    '🕐' => 'una in puntu',
    '🕜' => 'una e mesa',
    '🕑' => 'duas in puntu',
    '🕝' => 'duas e mesa',
    '🕒' => 'tres in puntu',
    '🕞' => 'tres e mesa',
    '🕓' => 'bator in puntu',
    '🕟' => 'bator e mesa',
    '🕔' => 'chimbe in puntu',
    '🕠' => 'chimbe e mesa',
    '🕕' => 'ses in puntu',
    '🕡' => 'ses e mesa',
    '🕖' => 'sete in puntu',
    '🕢' => 'sete e mesa',
    '🕗' => 'oto in puntu',
    '🕣' => 'oto e mesa',
    '🕘' => 'noe in puntu',
    '🕤' => 'noe e mesa',
    '🕙' => 'deghe in puntu',
    '🕥' => 'deghe e mesa',
    '🕚' => 'ùndighi in puntu',
    '🕦' => 'ùndighi e mesa',
    '🌑' => 'luna noa',
    '🌒' => 'luna creschente',
    '🌓' => 'primu cuartu de luna',
    '🌔' => 'luna creschente cumbessa',
    '🌕' => 'luna prena',
    '🌖' => 'luna calante cumbessa',
    '🌗' => 'ùrtimu cuartu de luna',
    '🌘' => 'luna calante',
    '🌙' => 'farche de luna',
    '🌚' => 'luna noa cun cara',
    '🌛' => 'primu cuartu de luna cun cara',
    '🌜' => 'ùrtimu cuartu de luna cun cara',
    '🌡' => 'termòmetru',
    '☀' => 'sole',
    '🌝' => 'luna prena cun cara',
    '🌞' => 'sole cun cara',
    '🪐' => 'praneta cun aneddos',
    '⭐' => 'isteddu',
    '🌟' => 'isteddu lughente',
    '🌠' => 'isteddu coudu',
    '🌌' => 'caminu de pàgia',
    '☁' => 'nue',
    '⛅' => 'sole in palas de una nue',
    '⛈' => 'nue cun lampos e abba',
    '🌤' => 'sole in palas de una nue minoredda',
    '🌥' => 'sole in palas de una nue manna',
    '🌦' => 'sole in palas de una nue cun abba',
    '🌧' => 'nue cun abba',
    '🌨' => 'nue cun nie',
    '🌩' => 'nue cun lampu',
    '🌪' => 'trumujone',
    '🌫' => 'nèula',
    '🌬' => 'cara de bentu',
    '🌀' => 'tziclone',
    '🌈' => 'arcu de chelu',
    '🌂' => 'paracu serradu',
    '☂' => 'paracu',
    '☔' => 'paracu cun gùtios de abba',
    '⛱' => 'umbrellone',
    '⚡' => 'tensione arta',
    '❄' => 'froca',
    '☃' => 'òmine de nie',
    '⛄' => 'òmine de nie chene nie',
    '☄' => 'cometa',
    '🔥' => 'fogu',
    '💧' => 'gùtiu',
    '🌊' => 'unda',
    '🎃' => 'conca de mortu',
    '🎄' => 'àrbore de Nadale',
    '🎆' => 'fogos de artifìtziu',
    '🎇' => 'bengala',
    '🧨' => 'petardu',
    '✨' => 'ischintiddas',
    '🎈' => 'palloneddu',
    '🎉' => 'ispara coriàndolos',
    '🎊' => 'botza de coriàndolos',
    '🎋' => 'àrbore de Tanabata',
    '🎍' => 'bambù decoradu',
    '🎎' => 'pupias giaponesas',
    '🎏' => 'bandereddas de carpas',
    '🎐' => 'campana a su bentu',
    '🎑' => 'tzerimònia de osservatzione de sa luna',
    '🧧' => 'busta ruja',
    '🎀' => 'frocu',
    '🎁' => 'donu incartadu',
    '🎗' => 'nastru ammentadore',
    '🎟' => 'billete de intrada',
    '🎫' => 'billete',
    '🎖' => 'medàllia militare',
    '🏆' => 'trofeu',
    '🏅' => 'medàllia de isport',
    '🥇' => 'medàllia de oro',
    '🥈' => 'medàllia de prata',
    '🥉' => 'medàllia de brunzu',
    '⚽' => 'botza de fùbalu',
    '⚾' => 'botza de baseball',
    '🥎' => 'botza de softball',
    '🏀' => 'botza de basket',
    '🏐' => 'volley',
    '🏈' => 'fùbalu americanu',
    '🏉' => 'rugby',
    '🎾' => 'tennis',
    '🥏' => 'frisbee',
    '🎳' => 'bowling',
    '🏏' => 'cricket',
    '🏑' => 'hockey de pradu',
    '🏒' => 'hockey in s’astra',
    '🥍' => 'lacrosse',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'guante de pugiladu',
    '🥋' => 'uniforme pro artes martziales',
    '🥅' => 'porta',
    '⛳' => 'banderedda in sa buca',
    '⛸' => 'patinàgiu in s’astra',
    '🎣' => 'canna de pisca',
    '🤿' => 'màscara pro sas imbèrghidas',
    '🎽' => 'màllia de cursa',
    '🎿' => 'iscì',
    '🛷' => 'islita',
    '🥌' => 'perda de curling',
    '🎯' => 'bersàlliu',
    '🪀' => 'yo-yo',
    '🪁' => 'abbilone',
    '🔫' => 'pistola a abba',
    '🎱' => 'botza de billiardu de 8',
    '🔮' => 'isfera de cristallu',
    '🪄' => 'bachita màgica',
    '🎮' => 'videogiogu',
    '🕹' => 'leva de giogu',
    '🎰' => 'machineta màndiga-dinari',
    '🎲' => 'dadu de giogu',
    '🧩' => 'tèssera de giogu a incastros',
    '🧸' => 'ursigheddu',
    '🪅' => 'padeddatza',
    '🪩' => 'botza de discoteca',
    '🪆' => 'pupias russas',
    '♠' => 'bastos',
    '♥' => 'coros',
    '♦' => 'oros',
    '♣' => 'frores',
    '♟' => 'pedone de sos iscacos',
    '🃏' => 'jolly',
    '🀄' => 'dragu ruju de su mahjong',
    '🎴' => 'carta de giogu de frores',
    '🎭' => 'artes performativas',
    '🖼' => 'cuadru incornitzadu',
    '🎨' => 'tauledda de pintore',
    '🧵' => 'filu',
    '🪡' => 'agu pro cosire',
    '🧶' => 'gròmuru',
    '🪢' => 'nodu',
    '👓' => 'ulleras',
    '🕶' => 'ulleras de sole',
    '🥽' => 'màscara',
    '🥼' => 'càmitze',
    '🦺' => 'corpete de seguresa',
    '👔' => 'corbata',
    '👕' => 'malliedda',
    '👖' => 'jeans',
    '🧣' => 'isserpa',
    '🧤' => 'guantes',
    '🧥' => 'capotu',
    '🧦' => 'mìgias',
    '👗' => 'bestire',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'costuminu intreu',
    '🩲' => 'mudandas',
    '🩳' => 'pantaloneddos',
    '👙' => 'bikini',
    '👚' => 'bestire de fèmina',
    '🪭' => 'ventàlliu',
    '👛' => 'taschinu',
    '👜' => 'bussedda',
    '👝' => 'butzachedda',
    '🛍' => 'bussas de ispesa',
    '🎒' => 'zàinu',
    '🩴' => 'cartzola',
    '👞' => 'iscarpa de òmine',
    '👟' => 'iscarpa de cursa',
    '🥾' => 'bota de escursionismu',
    '🥿' => 'ballerina',
    '👠' => 'iscarpa cun su tacu',
    '👡' => 'sàndalu de fèmina',
    '🩰' => 'iscarpitas pro ballerinas',
    '👢' => 'bota de fèmina',
    '🪮' => 'pètene',
    '👑' => 'corona',
    '👒' => 'bonete de fèmina',
    '🎩' => 'bonete a tzilindru',
    '🎓' => 'bonete de laureadu',
    '🧢' => 'bonete cun visiera',
    '🪖' => 'elmetu militare',
    '⛑' => 'cascu cun rughe bianca',
    '📿' => 'rosàriu',
    '💄' => 'russetu',
    '💍' => 'aneddu',
    '💎' => 'gemma',
    '🔇' => 'altoparlante istudadu',
    '🔈' => 'altoparlante a volume bassu',
    '🔉' => 'altoparlante a volume mèdiu',
    '🔊' => 'altoparlante a volume artu',
    '📢' => 'altoparlante',
    '📣' => 'megàfonu',
    '📯' => 'cornu postale',
    '🔔' => 'campana',
    '🔕' => 'campana istangada',
    '🎼' => 'pentagramma',
    '🎵' => 'nota musicale',
    '🎶' => 'notas musicales',
    '🎙' => 'micròfonu de istùdiu',
    '🎚' => 'cursore de su volume',
    '🎛' => 'manòpulas de controllu',
    '🎤' => 'micròfonu',
    '🎧' => 'cùfias',
    '📻' => 'ràdiu',
    '🎷' => 'sassòfonu',
    '🎺' => 'trumba',
    '🪗' => 'organitu',
    '🎸' => 'chiterra',
    '🎹' => 'tecladu musicale',
    '🎻' => 'violinu',
    '🪕' => 'banjo',
    '🥁' => 'tamburu',
    '🪘' => 'tamburu longu',
    '🪇' => 'maracas',
    '🪈' => 'flàutu',
    '🪉' => 'arpa',
    '📱' => 'telefoneddu',
    '📲' => 'telefoneddu cun fritza',
    '☎' => 'telèfonu',
    '📞' => 'corneta de su telèfonu',
    '📟' => 'chircapersones',
    '📠' => 'fax',
    '🔋' => 'bateria',
    '🪫' => 'bateria bassa',
    '🔌' => 'ispina elètrica',
    '💻' => 'elaboradore portàtile',
    '🖥' => 'elaboradore fissu',
    '🖨' => 'imprentadora',
    '⌨' => 'tecladu',
    '🖱' => 'ratu de s’ordinadore',
    '🖲' => 'botza de controllu',
    '💽' => 'minidiscu',
    '💾' => 'discheddu',
    '💿' => 'discu òticu',
    '📀' => 'dvd',
    '🧮' => 'àbacu',
    '🎥' => 'tzinepresa',
    '🎞' => 'pellìcula tzinematogràfica',
    '📽' => 'projetore tzinematogràficu',
    '🎬' => 'ciàc',
    '📺' => 'televisione',
    '📷' => 'fotocàmera',
    '📸' => 'fotocàmera cun su flash',
    '📹' => 'videocàmera',
    '📼' => 'videocasseta',
    '🔍' => 'lente de ismanniamentu orientada cara a manca',
    '🔎' => 'lente de ismanniamentu orientada cara a destra',
    '🕯' => 'candela',
    '💡' => 'lampadina',
    '🔦' => 'tortza',
    '🏮' => 'lanterna de paperi ruju',
    '🪔' => 'làmpada diya',
    '📔' => 'cuadernu cun cobertedda decorada',
    '📕' => 'libru serradu',
    '📖' => 'libru abertu',
    '📗' => 'libru birde',
    '📘' => 'libru biaitu',
    '📙' => 'libru in colore de arantzu',
    '📚' => 'libros',
    '📓' => 'cuadernu',
    '📒' => 'cuadernu a aneddos',
    '📃' => 'pàgina pinnigada',
    '📜' => 'pergamena',
    '📄' => 'pàgina',
    '📰' => 'giornale',
    '🗞' => 'giornale alloturadu',
    '📑' => 'etichetas sinnalibru',
    '🔖' => 'sinnalibru',
    '🏷' => 'eticheta',
    '🪙' => 'moneda',
    '💰' => 'sacu de dinare',
    '💴' => 'banconota in yen',
    '💵' => 'banconota in dòllaros',
    '💶' => 'banconota in èuros',
    '💷' => 'banconota in isterlinas',
    '💸' => 'dinare cun sas alas',
    '💳' => 'carta de crèditu',
    '🧾' => 'iscontrinu',
    '💹' => 'gràficu chi àrtziat cun su sìmbulu de su yen',
    '✉' => 'busta',
    '📧' => 'lìtera eletrònica',
    '📨' => 'posta in intrada',
    '📩' => 'busta cun fritza',
    '📤' => 'cartella de essida',
    '📥' => 'cartella de intrada',
    '📦' => 'pacu',
    '📫' => 'cassita postale serrada cun sa banderedda artziada',
    '📪' => 'cassita postale serrada cun sa banderedda abbassada',
    '📬' => 'cassita postale aberta cun sa banderedda artziada',
    '📭' => 'cassita postale aberta cun sa banderedda abbassada',
    '📮' => 'cassita de sas lìteras',
    '🗳' => 'urna eletorale cun ischeda',
    '✏' => 'lapis',
    '✒' => 'pinninu nieddu',
    '🖋' => 'pinna istilogràfica',
    '🖊' => 'pinna',
    '🖌' => 'pintzellu',
    '🖍' => 'pastellu a cera',
    '📝' => 'nota',
    '💼' => 'valigedda',
    '📁' => 'cartella de documentos',
    '📂' => 'cartella de documentos aberta',
    '🗂' => 'partzidores pro ischedàriu',
    '📅' => 'calendàriu',
    '📆' => 'calendàriu de istratzare',
    '🗒' => 'blocu pro notas a ispirale',
    '🗓' => 'calendàriu a ispirale',
    '📇' => 'ischedàriu',
    '📈' => 'gràficu in artziada',
    '📉' => 'gràficu in achirrada',
    '📊' => 'gràficu a barras',
    '📋' => 'portablocu',
    '📌' => 'puntina',
    '📍' => 'puntina tunda',
    '📎' => 'grafeta',
    '🖇' => 'grafetas collegadas',
    '📏' => 'righighedda',
    '📐' => 'iscuadra',
    '✂' => 'fòrtzighes',
    '🗃' => 'ischedàriu de mesa',
    '🗄' => 'ischedàriu de ufìtziu',
    '🗑' => 'botu de s’arga',
    '🔒' => 'luchete serradu',
    '🔓' => 'luchete abertu',
    '🔏' => 'luchete serradu cun pinninu',
    '🔐' => 'luchete serradu cun crae',
    '🔑' => 'crae',
    '🗝' => 'crae antiga',
    '🔨' => 'marteddu',
    '🪓' => 'istrale',
    '⛏' => 'picu',
    '⚒' => 'marteddu e picu',
    '🛠' => 'marteddu e crae inglesa',
    '🗡' => 'istocu',
    '⚔' => 'ispadas rugradas',
    '💣' => 'bomba',
    '🪃' => 'boomerang',
    '🏹' => 'arcu e fritza',
    '🛡' => 'iscudu',
    '🪚' => 'serracu',
    '🔧' => 'crae inglesa',
    '🪛' => 'catzavite',
    '🔩' => 'vite e bullone',
    '⚙' => 'ingranàgiu',
    '🗜' => 'istringone',
    '⚖' => 'bilàntzia',
    '🦯' => 'bàculu pro tzegos',
    '🔗' => 'ligàmene',
    '⛓' => 'cadenas',
    '🪝' => 'càncaru',
    '🧰' => 'cassita de sos trastes',
    '🧲' => 'calamita',
    '🪜' => 'iscala',
    '⚗' => 'lambicu',
    '🧪' => 'proveta',
    '🧫' => 'piastra de Petri',
    '🧬' => 'dna',
    '🔬' => 'microscòpiu',
    '🔭' => 'telescòpiu',
    '📡' => 'antenna satellitare',
    '💉' => 'siringa',
    '🩸' => 'gùtiu de sàmbene',
    '💊' => 'pìllola',
    '🩹' => 'tzerotu',
    '🩼' => 'istampella',
    '🩺' => 'isteteoscòpiu',
    '🩻' => 'radiografia',
    '🚪' => 'ghenna',
    '🛗' => 'ascensore',
    '🪞' => 'ispricu',
    '🪟' => 'ventana',
    '🛏' => 'letu',
    '🛋' => 'otomana cun làmpada',
    '🪑' => 'cadira',
    '🚽' => 'gabinete',
    '🪠' => 'istupa-lavandinos',
    '🚿' => 'dòtzia',
    '🛁' => 'bagnera',
    '🪤' => 'sorigàrgiu',
    '🪒' => 'lesorja de barba',
    '🧴' => 'flacone',
    '🧷' => 'ispilla de bàlia',
    '🧹' => 'iscoba',
    '🧺' => 'canistedda',
    '🧻' => 'ròtulu de paperi',
    '🪣' => 'puale',
    '🧼' => 'sabone',
    '🫧' => 'bolloncas',
    '🪥' => 'ispatzulinu',
    '🧽' => 'ispugna',
    '🧯' => 'istudadore',
    '🛒' => 'carrellu de sas còmporas',
    '🚬' => 'sigareta',
    '⚰' => 'baule',
    '🪦' => 'losa',
    '⚱' => 'urna funerària',
    '🧿' => 'nazar',
    '🪬' => 'manu de Fàtima',
    '🗿' => 'moai',
    '🪧' => 'cartellu',
    '🪪' => 'carta de identidade',
    '🏧' => 'sìmbulu de s’isportellu bàncomat',
    '🚮' => 'sìmbulu de sa collida de s’arga',
    '🚰' => 'abba potàbile',
    '♿' => 'sìmbulu de cadira a rodas',
    '🚹' => 'bagnu de sos òmines',
    '🚺' => 'bagnu de sas fèminas',
    '🚻' => 'bagnu',
    '🚼' => 'sìmbulu de pipiu',
    '🚾' => 'sìmbulu WC',
    '🛂' => 'controllu de sos passaportos',
    '🛃' => 'dogana',
    '🛄' => 'ritiru de bagàllios',
    '🛅' => 'depòsitu de bagàllios',
    '⚠' => 'avisu',
    '🚸' => 'atraessamentu de pitzinnos',
    '⛔' => 'proibitzione de intrada',
    '🚫' => 'proibidu',
    '🚳' => 'bitzicletas proibidas',
    '🚭' => 'pipòngiu proibidu',
    '🚯' => 'arga in terra proibida',
    '🚱' => 'abba non potàbile',
    '🚷' => 'pedones proibidos',
    '📵' => 'telefoneddos proibidos',
    '🔞' => 'proibitzione a sos minorennes',
    '☢' => 'radiativu',
    '☣' => 'perìgulu biològicu',
    '⬆' => 'fritza cara a artu',
    '↗' => 'fritza cara a artu a destra',
    '➡' => 'fritza cara a destra',
    '↘' => 'fritza cara a bassu a destra',
    '⬇' => 'fritza cara a bassu',
    '↙' => 'fritza cara a bassu a manca',
    '⬅' => 'fritza cara a manca',
    '↖' => 'fritza cara a artu a manca',
    '↕' => 'fritza cara a susu e a giosso',
    '↔' => 'fritza cara a manca e a destra',
    '↩' => 'fritza cara a dereta chi girat cara a manca',
    '↪' => 'fritza cara a manca chi girat cara a destra',
    '⤴' => 'fritza cara a destra chi girat cara a artu',
    '⤵' => 'fritza cara a destra chi girat cara a bassu',
    '🔃' => 'fritzas verticales in sensu oràriu',
    '🔄' => 'butone de fritzas in sensu antioràriu',
    '🔙' => 'fritza "BACK"',
    '🔚' => 'fritza "END"',
    '🔛' => 'fritza "ON!"',
    '🔜' => 'fritza "SOON"',
    '🔝' => 'fritza "TOP"',
    '🛐' => 'logu de cultu',
    '⚛' => 'sìmbulu de s’àtomu',
    '🕉' => 'om',
    '✡' => 'isteddu de David',
    '☸' => 'roda de su dharma',
    '☯' => 'yin e yang',
    '✝' => 'rughe latina',
    '☦' => 'rughe ortodossa',
    '☪' => 'farche de luna e isteddu',
    '☮' => 'sìmbulu de sa paghe',
    '🕎' => 'menorah',
    '🔯' => 'isteddu a ses puntas',
    '🪯' => 'khanda',
    '♈' => 'sinnu de su mascru',
    '♉' => 'sinnu de su trau',
    '♊' => 'sinnu de sos gemellos',
    '♋' => 'sinnu de su càncaru',
    '♌' => 'sinnu de su leone',
    '♍' => 'sinnu de sa vìrgine',
    '♎' => 'sinnu de sa balantza',
    '♏' => 'sinnu de s’iscorpione',
    '♐' => 'sinnu de su sagitàriu',
    '♑' => 'sinnu de su capricornu',
    '♒' => 'sinnu de s’abbàrgiu',
    '♓' => 'sinnu de sos pisches',
    '⛎' => 'sinnu de s’ofiucu',
    '🔀' => 'butone de riprodutzione casuale',
    '🔁' => 'butone de ripetitzione',
    '🔂' => 'butone de ripetitzione sìngula',
    '▶' => 'butone de riprodutzione',
    '⏩' => 'butone de avantzamentu lestru',
    '⏭' => 'butone de rasta imbeniente',
    '⏯' => 'butone de riprodutzione o pàusa',
    '◀' => 'butone de incuida',
    '⏪' => 'butone de incuida lestra',
    '⏮' => 'butone de rasta anteposta',
    '🔼' => 'butone a triàngulu conca a susu',
    '⏫' => 'butone a triàngulu dòpiu conca a susu',
    '🔽' => 'butone a triàngulu conca a giosso',
    '⏬' => 'butone a triàngulu dòpiu conca a giosso',
    '⏸' => 'butone de pàusa',
    '⏹' => 'butone de firmada',
    '⏺' => 'butone de registratzione',
    '⏏' => 'butone de espulsione',
    '🎦' => 'tzìnema',
    '🔅' => 'butone de luminosidade bassa',
    '🔆' => 'butone de luminosidade arta',
    '📶' => 'istangas de sinnale',
    '🛜' => 'retze chene filos',
    '📳' => 'modalidade de vibratzione',
    '📴' => 'telefoneddu istudadu',
    '♀' => 'sìmbulu femininu',
    '♂' => 'sìmbulu masculinu',
    '⚧' => 'sìmbulu transgènere',
    '✖' => 'multiplicatzione',
    '➕' => 'additzione',
    '➖' => 'sutratzione',
    '➗' => 'divisione',
    '🟰' => 'sinnu de ugualidade',
    '♾' => 'infinidu',
    '💱' => 'càmbiu de valuta',
    '💲' => 'sìmbulu de su dòllaru',
    '🔴' => 'chircu ruju',
    '🟠' => 'chircu arantzu',
    '🟡' => 'chircu grogu',
    '🟢' => 'chircu birde',
    '🔵' => 'chircu biaitu',
    '🟣' => 'chircu tanadu',
    '🟤' => 'chircu castàngiu',
    '⚫' => 'chircu nieddu',
    '⚪' => 'chircu biancu',
    '🟥' => 'cuadradu ruju',
    '🟧' => 'cuadradu arantzu',
    '🟨' => 'cuadradu grogu',
    '🟩' => 'cuadradu birde',
    '🟦' => 'cuadradu biaitu',
    '🟪' => 'cuadradu tanadu',
    '🟫' => 'cuadradu castàngiu',
    '⬛' => 'cuadradu nieddu mannu',
    '⬜' => 'cuadradu biancu mannu',
    '◼' => 'cuadradu nieddu mesanu',
    '◻' => 'cuadradu biancu mesanu',
    '◾' => 'cuadradu nieddu mesanu-minore',
    '◽' => 'cuadradu biancu mesanu-minore',
    '▪' => 'cuadradu nieddu minore',
    '▫' => 'cuadradu biancu minore',
    '🔶' => 'rombu arantzu mannu',
    '🔷' => 'rombu biaitu mannu',
    '🔸' => 'rombu arantzu minore',
    '🔹' => 'rombu biaitu minure',
    '🔺' => 'triàngulu ruju punta a susu',
    '🔻' => 'triàngulu ruju punta a giosso',
    '💠' => 'rombu cun puntu',
    '🔘' => 'butone tundu',
    '🔳' => 'butone cuadradu cun oru arbu',
    '🔲' => 'butone cuadradu cun oru nieddu',
    '🏁' => 'bandera a iscacos',
    '🚩' => 'bandera triangulare',
    '🎌' => 'banderas rugradas',
    '🏴' => 'bandera niedda',
    '🏳' => 'bandera bianca',
];
