<?php

return [
    'Names' => [
        'ar_AE' => 'арабский (Объединенные Арабские Эмираты)',
        'en_AE' => 'английский (Объединенные Арабские Эмираты)',
        'en_CK' => 'английский (О-ва Кука)',
        'en_CX' => 'английский (О-в Рождества)',
        'en_NF' => 'английский (О-в Норфолк)',
        'en_UM' => 'английский (Малые Тихоокеанские Отдаленные Острова США)',
        'pt_TL' => 'португальский (Тимор-Лесте)',
    ],
];
