<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Ora de su meridianu de Greenwich (Abidjan)',
        'Africa/Accra' => 'Ora de su meridianu de Greenwich (Accra)',
        'Africa/Addis_Ababa' => 'Ora de s’Àfrica orientale (Addis Abeba)',
        'Africa/Algiers' => 'Ora de s’Europa tzentrale (Algeri)',
        'Africa/Asmera' => 'Ora de s’Àfrica orientale (Asmara)',
        'Africa/Asmara' => 'Ora de s’Àfrica orientale (Asmara)',
        'Africa/Bamako' => 'Ora de su meridianu de Greenwich (Bamako)',
        'Africa/Bangui' => 'Ora de s’Àfrica otzidentale (Bangui)',
        'Africa/Banjul' => 'Ora de su meridianu de Greenwich (Banjul)',
        'Africa/Bissau' => 'Ora de su meridianu de Greenwich (Bissau)',
        'Africa/Blantyre' => 'Ora de s’Àfrica tzentrale (Blantyre)',
        'Africa/Brazzaville' => 'Ora de s’Àfrica otzidentale (Brazzaville)',
        'Africa/Bujumbura' => 'Ora de s’Àfrica tzentrale (Bujumbura)',
        'Africa/Cairo' => 'Ora de s’Europa orientale (Su Càiru)',
        'Africa/Casablanca' => 'Ora de s’Europa otzidentale (Casablanca)',
        'Africa/Ceuta' => 'Ora de s’Europa tzentrale (Ceuta)',
        'Africa/Conakry' => 'Ora de su meridianu de Greenwich (Conakry)',
        'Africa/Dakar' => 'Ora de su meridianu de Greenwich (Dakar)',
        'Africa/Dar_es_Salaam' => 'Ora de s’Àfrica orientale (Dar es Salaam)',
        'Africa/Djibouti' => 'Ora de s’Àfrica orientale (Djibouti)',
        'Africa/Douala' => 'Ora de s’Àfrica otzidentale (Douala)',
        'Africa/El_Aaiun' => 'Ora de s’Europa otzidentale (El Aaiún)',
        'Africa/Freetown' => 'Ora de su meridianu de Greenwich (Freetown)',
        'Africa/Gaborone' => 'Ora de s’Àfrica tzentrale (Gaborone)',
        'Africa/Harare' => 'Ora de s’Àfrica tzentrale (Harare)',
        'Africa/Johannesburg' => 'Ora istandard de s’Àfrica meridionale (Johannesburg)',
        'Africa/Juba' => 'Ora de s’Àfrica tzentrale (Juba)',
        'Africa/Kampala' => 'Ora de s’Àfrica orientale (Kampala)',
        'Africa/Khartoum' => 'Ora de s’Àfrica tzentrale (Khartoum)',
        'Africa/Kigali' => 'Ora de s’Àfrica tzentrale (Kigali)',
        'Africa/Kinshasa' => 'Ora de s’Àfrica otzidentale (Kinshasa)',
        'Africa/Lagos' => 'Ora de s’Àfrica otzidentale (Lagos)',
        'Africa/Libreville' => 'Ora de s’Àfrica otzidentale (Libreville)',
        'Africa/Lome' => 'Ora de su meridianu de Greenwich (Lomé)',
        'Africa/Luanda' => 'Ora de s’Àfrica otzidentale (Luanda)',
        'Africa/Lubumbashi' => 'Ora de s’Àfrica tzentrale (Lubumbashi)',
        'Africa/Lusaka' => 'Ora de s’Àfrica tzentrale (Lusaka)',
        'Africa/Malabo' => 'Ora de s’Àfrica otzidentale (Malabo)',
        'Africa/Maputo' => 'Ora de s’Àfrica tzentrale (Maputo)',
        'Africa/Maseru' => 'Ora istandard de s’Àfrica meridionale (Maseru)',
        'Africa/Mbabane' => 'Ora istandard de s’Àfrica meridionale (Mbabane)',
        'Africa/Mogadishu' => 'Ora de s’Àfrica orientale (Mogadìsciu)',
        'Africa/Monrovia' => 'Ora de su meridianu de Greenwich (Monròvia)',
        'Africa/Nairobi' => 'Ora de s’Àfrica orientale (Nairobi)',
        'Africa/Ndjamena' => 'Ora de s’Àfrica otzidentale (N’Djamena)',
        'Africa/Niamey' => 'Ora de s’Àfrica otzidentale (Niamey)',
        'Africa/Nouakchott' => 'Ora de su meridianu de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'Ora de su meridianu de Greenwich (Ouagadougou)',
        'Africa/Porto-Novo' => 'Ora de s’Àfrica otzidentale (Portu-Nou)',
        'Africa/Sao_Tome' => 'Ora de su meridianu de Greenwich (São Tomé)',
        'Africa/Tripoli' => 'Ora de s’Europa orientale (Trìpoli)',
        'Africa/Tunis' => 'Ora de s’Europa tzentrale (Tùnisi)',
        'Africa/Windhoek' => 'Ora de s’Àfrica tzentrale (Windhoek)',
        'America/Adak' => 'Ora de sas ìsulas Hawaii-Aleutinas (Adak)',
        'America/Anchorage' => 'Ora de s’Alaska (Anchorage)',
        'America/Anguilla' => 'Ora de s’Atlànticu (Anguilla)',
        'America/Antigua' => 'Ora de s’Atlànticu (Antigua)',
        'America/Araguaina' => 'Ora de Brasìlia (Araguaína)',
        'America/Argentina/La_Rioja' => 'Ora de s’Argentina (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Ora de s’Argentina (Río Gallegos)',
        'America/Argentina/Salta' => 'Ora de s’Argentina (Salta)',
        'America/Argentina/San_Juan' => 'Ora de s’Argentina (San Juan)',
        'America/Argentina/San_Luis' => 'Ora de s’Argentina (San Luis)',
        'America/Argentina/Tucuman' => 'Ora de s’Argentina (Tucumán)',
        'America/Argentina/Ushuaia' => 'Ora de s’Argentina (Ushuaia)',
        'America/Aruba' => 'Ora de s’Atlànticu (Aruba)',
        'America/Asuncion' => 'Ora de su Paraguay (Asunción)',
        'America/Bahia' => 'Ora de Brasìlia (Bahia)',
        'America/Bahia_Banderas' => 'Ora tzentrale USA (Bahía de Banderas)',
        'America/Barbados' => 'Ora de s’Atlànticu (Barbados)',
        'America/Belem' => 'Ora de Brasìlia (Belém)',
        'America/Belize' => 'Ora tzentrale USA (Belize)',
        'America/Blanc-Sablon' => 'Ora de s’Atlànticu (Blanc-Sablon)',
        'America/Boa_Vista' => 'Ora de s’Amatzònia (Boa Vista)',
        'America/Bogota' => 'Ora de sa Colòmbia (Bogotá)',
        'America/Boise' => 'Ora Montes Pedrosos USA (Boise)',
        'America/Buenos_Aires' => 'Ora de s’Argentina (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Ora de s’Argentina (Buenos Aires)',
        'America/Cambridge_Bay' => 'Ora Montes Pedrosos USA (Cambridge Bay)',
        'America/Campo_Grande' => 'Ora de s’Amatzònia (Campo Grande)',
        'America/Cancun' => 'Ora orientale USA (Cancún)',
        'America/Caracas' => 'Ora de su Venetzuela (Caracas)',
        'America/Catamarca' => 'Ora de s’Argentina (Catamarca)',
        'America/Argentina/Catamarca' => 'Ora de s’Argentina (Catamarca)',
        'America/Cayenne' => 'Ora de sa Guiana Frantzesa (Cayenne)',
        'America/Cayman' => 'Ora orientale USA (Cayman)',
        'America/Chicago' => 'Ora tzentrale USA (Chicago)',
        'America/Chihuahua' => 'Ora tzentrale USA (Chihuahua)',
        'America/Ciudad_Juarez' => 'Ora Montes Pedrosos USA (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Ora orientale USA (Atikokan)',
        'America/Atikokan' => 'Ora orientale USA (Atikokan)',
        'America/Cordoba' => 'Ora de s’Argentina (Córdoba)',
        'America/Argentina/Cordoba' => 'Ora de s’Argentina (Córdoba)',
        'America/Costa_Rica' => 'Ora tzentrale USA (Costa Rica)',
        'America/Coyhaique' => 'Ora de su Tzile (Coyhaique)',
        'America/Creston' => 'Ora Montes Pedrosos USA (Creston)',
        'America/Cuiaba' => 'Ora de s’Amatzònia (Cuiabá)',
        'America/Curacao' => 'Ora de s’Atlànticu (Curaçao)',
        'America/Danmarkshavn' => 'Ora de su meridianu de Greenwich (Danmarkshavn)',
        'America/Dawson' => 'Ora de su Yukon (Dawson)',
        'America/Dawson_Creek' => 'Ora Montes Pedrosos USA (Dawson Creek)',
        'America/Denver' => 'Ora Montes Pedrosos USA (Denver)',
        'America/Detroit' => 'Ora orientale USA (Detroit)',
        'America/Dominica' => 'Ora de s’Atlànticu (Dominica)',
        'America/Edmonton' => 'Ora Montes Pedrosos USA (Edmonton)',
        'America/Eirunepe' => 'Ora de Acre (Eirunepé)',
        'America/El_Salvador' => 'Ora tzentrale USA (El Salvador)',
        'America/Fort_Nelson' => 'Ora Montes Pedrosos USA (Fort Nelson)',
        'America/Fortaleza' => 'Ora de Brasìlia (Fortaleza)',
        'America/Glace_Bay' => 'Ora de s’Atlànticu (Glace Bay)',
        'America/Godthab' => 'Ora de sa Groenlàndia (Nuuk)',
        'America/Nuuk' => 'Ora de sa Groenlàndia (Nuuk)',
        'America/Goose_Bay' => 'Ora de s’Atlànticu (Goose Bay)',
        'America/Grand_Turk' => 'Ora orientale USA (Grand Turk)',
        'America/Grenada' => 'Ora de s’Atlànticu (Grenada)',
        'America/Guadeloupe' => 'Ora de s’Atlànticu (Guadeloupe)',
        'America/Guatemala' => 'Ora tzentrale USA (Guatemala)',
        'America/Guayaquil' => 'Ora de s’Ecuador (Guayaquil)',
        'America/Guyana' => 'Ora de sa Guyana',
        'America/Halifax' => 'Ora de s’Atlànticu (Halifax)',
        'America/Havana' => 'Ora de Cuba (S’Avana)',
        'America/Hermosillo' => 'Ora de su Patzìficu (Mèssicu) (Hermosillo)',
        'America/Indiana/Knox' => 'Ora tzentrale USA (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Ora orientale USA (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Ora orientale USA (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Ora tzentrale USA (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Ora orientale USA (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Ora orientale USA (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Ora orientale USA (Winamac, Indiana)',
        'America/Indianapolis' => 'Ora orientale USA (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Ora orientale USA (Indianapolis)',
        'America/Inuvik' => 'Ora Montes Pedrosos USA (Inuvik)',
        'America/Iqaluit' => 'Ora orientale USA (Iqaluit)',
        'America/Jamaica' => 'Ora orientale USA (Jamaica)',
        'America/Jujuy' => 'Ora de s’Argentina (Jujuy)',
        'America/Argentina/Jujuy' => 'Ora de s’Argentina (Jujuy)',
        'America/Juneau' => 'Ora de s’Alaska (Juneau)',
        'America/Kentucky/Monticello' => 'Ora orientale USA (Monticello, Kentucky)',
        'America/Kralendijk' => 'Ora de s’Atlànticu (Kralendijk)',
        'America/La_Paz' => 'Ora de sa Bolìvia (La Paz)',
        'America/Lima' => 'Ora de su Perù (Lima)',
        'America/Los_Angeles' => 'Ora de su Patzìficu USA (Los Angeles)',
        'America/Louisville' => 'Ora orientale USA (Louisville)',
        'America/Kentucky/Louisville' => 'Ora orientale USA (Louisville)',
        'America/Lower_Princes' => 'Ora de s’Atlànticu (Lower Prince’s Quarter)',
        'America/Maceio' => 'Ora de Brasìlia (Maceió)',
        'America/Managua' => 'Ora tzentrale USA (Managua)',
        'America/Manaus' => 'Ora de s’Amatzònia (Manaus)',
        'America/Marigot' => 'Ora de s’Atlànticu (Marigot)',
        'America/Martinique' => 'Ora de s’Atlànticu (Martinica)',
        'America/Matamoros' => 'Ora tzentrale USA (Matamoros)',
        'America/Mazatlan' => 'Ora de su Patzìficu (Mèssicu) (Mazatlán)',
        'America/Mendoza' => 'Ora de s’Argentina (Mendoza)',
        'America/Argentina/Mendoza' => 'Ora de s’Argentina (Mendoza)',
        'America/Menominee' => 'Ora tzentrale USA (Menominee)',
        'America/Merida' => 'Ora tzentrale USA (Mérida)',
        'America/Metlakatla' => 'Ora de s’Alaska (Metlakatla)',
        'America/Mexico_City' => 'Ora tzentrale USA (Tzitade de su Mèssicu)',
        'America/Miquelon' => 'Ora de Saint-Pierre e Miquelon',
        'America/Moncton' => 'Ora de s’Atlànticu (Moncton)',
        'America/Monterrey' => 'Ora tzentrale USA (Monterrey)',
        'America/Montevideo' => 'Ora de s’Uruguay (Montevideo)',
        'America/Montserrat' => 'Ora de s’Atlànticu (Montserrat)',
        'America/Nassau' => 'Ora orientale USA (Nassau)',
        'America/New_York' => 'Ora orientale USA (Noa York)',
        'America/Nome' => 'Ora de s’Alaska (Nome)',
        'America/Noronha' => 'Ora de su Fernando de Noronha',
        'America/North_Dakota/Beulah' => 'Ora tzentrale USA (Beulah, Dakota de su Nord)',
        'America/North_Dakota/Center' => 'Ora tzentrale USA (Center, Dakota de su Nord)',
        'America/North_Dakota/New_Salem' => 'Ora tzentrale USA (New Salem, Dakota de su Nord)',
        'America/Ojinaga' => 'Ora tzentrale USA (Ojinaga)',
        'America/Panama' => 'Ora orientale USA (Pànama)',
        'America/Paramaribo' => 'Ora de su Suriname (Paramaribo)',
        'America/Phoenix' => 'Ora Montes Pedrosos USA (Phoenix)',
        'America/Port-au-Prince' => 'Ora orientale USA (Port-au-Prince)',
        'America/Port_of_Spain' => 'Ora de s’Atlànticu (Portu de Ispagna)',
        'America/Porto_Velho' => 'Ora de s’Amatzònia (Porto Velho)',
        'America/Puerto_Rico' => 'Ora de s’Atlànticu (Puerto Rico)',
        'America/Punta_Arenas' => 'Ora de su Tzile (Punta Arenas)',
        'America/Rankin_Inlet' => 'Ora tzentrale USA (Rankin Inlet)',
        'America/Recife' => 'Ora de Brasìlia (Recife)',
        'America/Regina' => 'Ora tzentrale USA (Regina)',
        'America/Resolute' => 'Ora tzentrale USA (Resolute)',
        'America/Rio_Branco' => 'Ora de Acre (Rio Branco)',
        'America/Santarem' => 'Ora de Brasìlia (Santarém)',
        'America/Santiago' => 'Ora de su Tzile (Santiago)',
        'America/Santo_Domingo' => 'Ora de s’Atlànticu (Santo Domingo)',
        'America/Sao_Paulo' => 'Ora de Brasìlia (São Paulo)',
        'America/Scoresbysund' => 'Ora de sa Groenlàndia (Ittoqqortoormiit)',
        'America/Sitka' => 'Ora de s’Alaska (Sitka)',
        'America/St_Barthelemy' => 'Ora de s’Atlànticu (Santu Bartolomeu)',
        'America/St_Johns' => 'Ora de Terranova (Santu Giuanne)',
        'America/St_Kitts' => 'Ora de s’Atlànticu (Santu Cristolu)',
        'America/St_Lucia' => 'Ora de s’Atlànticu (Santa Lughia)',
        'America/St_Thomas' => 'Ora de s’Atlànticu (Santu Tommasu)',
        'America/St_Vincent' => 'Ora de s’Atlànticu (Santu Vissente)',
        'America/Swift_Current' => 'Ora tzentrale USA (Swift Current)',
        'America/Tegucigalpa' => 'Ora tzentrale USA (Tegucigalpa)',
        'America/Thule' => 'Ora de s’Atlànticu (Thule)',
        'America/Tijuana' => 'Ora de su Patzìficu USA (Tijuana)',
        'America/Toronto' => 'Ora orientale USA (Toronto)',
        'America/Tortola' => 'Ora de s’Atlànticu (Tortola)',
        'America/Vancouver' => 'Ora de su Patzìficu USA (Vancouver)',
        'America/Whitehorse' => 'Ora de su Yukon (Whitehorse)',
        'America/Winnipeg' => 'Ora tzentrale USA (Winnipeg)',
        'America/Yakutat' => 'Ora de s’Alaska (Yakutat)',
        'Antarctica/Casey' => 'Ora de s’Austràlia otzidentale (Casey)',
        'Antarctica/Davis' => 'Ora de Davis',
        'Antarctica/DumontDUrville' => 'Ora de Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Ora de s’Austràlia orientale (Macquarie)',
        'Antarctica/Mawson' => 'Ora de Mawson',
        'Antarctica/McMurdo' => 'Ora de sa Zelanda Noa (McMurdo)',
        'Antarctica/Palmer' => 'Ora de su Tzile (Palmer)',
        'Antarctica/Rothera' => 'Ora de Rothera',
        'Antarctica/Syowa' => 'Ora de Syowa (Showa)',
        'Antarctica/Troll' => 'Ora de su meridianu de Greenwich (Troll)',
        'Antarctica/Vostok' => 'Ora de Vostok',
        'Arctic/Longyearbyen' => 'Ora de s’Europa tzentrale (Longyearbyen)',
        'Asia/Aden' => 'Ora àraba (Aden)',
        'Asia/Almaty' => 'Ora de su Kazàkistan (Almaty)',
        'Asia/Amman' => 'Ora de s’Europa orientale (Amman)',
        'Asia/Anadyr' => 'Ora de Petropavlovsk-Kamchatski (Anadyr)',
        'Asia/Aqtau' => 'Ora de su Kazàkistan (Aktau)',
        'Asia/Aqtobe' => 'Ora de su Kazàkistan (Aktobe)',
        'Asia/Ashgabat' => 'Ora de su Turkmènistan (Ashgabat)',
        'Asia/Atyrau' => 'Ora de su Kazàkistan (Atyrau)',
        'Asia/Baghdad' => 'Ora àraba (Baghdad)',
        'Asia/Bahrain' => 'Ora àraba (Bahrein)',
        'Asia/Baku' => 'Ora de s’Azerbaigiàn (Baku)',
        'Asia/Bangkok' => 'Ora de s’Indotzina (Bangkok)',
        'Asia/Barnaul' => 'Ora de Krasnoyarsk (Barnaul)',
        'Asia/Beirut' => 'Ora de s’Europa orientale (Beirut)',
        'Asia/Bishkek' => 'Ora de su Kirghìzistan (Bishkek)',
        'Asia/Brunei' => 'Ora de su Brunei',
        'Asia/Calcutta' => 'Ora istandard de s’Ìndia (Calcuta)',
        'Asia/Kolkata' => 'Ora istandard de s’Ìndia (Calcuta)',
        'Asia/Chita' => 'Ora de Yakutsk (Čita)',
        'Asia/Colombo' => 'Ora istandard de s’Ìndia (Colombo)',
        'Asia/Damascus' => 'Ora de s’Europa orientale (Damascu)',
        'Asia/Dhaka' => 'Ora de su Bangladesh (Daca)',
        'Asia/Dili' => 'Ora de su Timor Est (Dili)',
        'Asia/Dubai' => 'Ora istandard de su Gulfu (Dubai)',
        'Asia/Dushanbe' => 'Ora de su Tagìkistan (Dushanbe)',
        'Asia/Famagusta' => 'Ora de s’Europa orientale (Famagusta)',
        'Asia/Gaza' => 'Ora de s’Europa orientale (Gaza)',
        'Asia/Hebron' => 'Ora de s’Europa orientale (Hebron)',
        'Asia/Hong_Kong' => 'Ora de Hong Kong',
        'Asia/Hovd' => 'Ora de Hovd (Khovd)',
        'Asia/Irkutsk' => 'Ora de Irkutsk',
        'Asia/Jakarta' => 'Ora de s’Indonèsia otzidentale (Giacarta)',
        'Asia/Jayapura' => 'Ora de s’Indonèsia orientale (Jayapura)',
        'Asia/Jerusalem' => 'Ora de Israele (Gerusalemme)',
        'Asia/Kabul' => 'Ora de s’Afghànistan (Kabul)',
        'Asia/Kamchatka' => 'Ora de Petropavlovsk-Kamchatski (Kamchatka)',
        'Asia/Karachi' => 'Ora de su Pàkistan (Karachi)',
        'Asia/Katmandu' => 'Ora de su Nepal (Kathmandu)',
        'Asia/Kathmandu' => 'Ora de su Nepal (Kathmandu)',
        'Asia/Khandyga' => 'Ora de Yakutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Ora de Krasnoyarsk (Krasnojarsk)',
        'Asia/Kuala_Lumpur' => 'Ora de sa Malèsia (Kuala Lumpur)',
        'Asia/Kuching' => 'Ora de sa Malèsia (Kuching)',
        'Asia/Kuwait' => 'Ora àraba (Kuwait)',
        'Asia/Macau' => 'Ora de sa Tzina (Macao)',
        'Asia/Magadan' => 'Ora de Magadan',
        'Asia/Makassar' => 'Ora de s’Indonèsia tzentrale (Makassar)',
        'Asia/Manila' => 'Ora de sas Filipinas (Manila)',
        'Asia/Muscat' => 'Ora istandard de su Gulfu (Mascate)',
        'Asia/Nicosia' => 'Ora de s’Europa orientale (Nicosia)',
        'Asia/Novokuznetsk' => 'Ora de Krasnoyarsk (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Ora de Krasnoyarsk (Novosibirsk)',
        'Asia/Omsk' => 'Ora de Omsk',
        'Asia/Oral' => 'Ora de su Kazàkistan (Oral)',
        'Asia/Phnom_Penh' => 'Ora de s’Indotzina (Phnom Penh)',
        'Asia/Pontianak' => 'Ora de s’Indonèsia otzidentale (Pontianak)',
        'Asia/Pyongyang' => 'Ora coreana (Pyongyang)',
        'Asia/Qatar' => 'Ora àraba (Catàr)',
        'Asia/Qostanay' => 'Ora de su Kazàkistan (Qostanay)',
        'Asia/Qyzylorda' => 'Ora de su Kazàkistan (Kyzylorda)',
        'Asia/Rangoon' => 'Ora de su Myanmàr (Yangon)',
        'Asia/Yangon' => 'Ora de su Myanmàr (Yangon)',
        'Asia/Riyadh' => 'Ora àraba (Riyàd)',
        'Asia/Saigon' => 'Ora de s’Indotzina (Tzitade de Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'Ora de s’Indotzina (Tzitade de Ho Chi Minh)',
        'Asia/Sakhalin' => 'Ora de Magadan (Sakhalin)',
        'Asia/Samarkand' => 'Ora de s’Uzbèkistan (Samarcanda)',
        'Asia/Seoul' => 'Ora coreana (Seùl)',
        'Asia/Shanghai' => 'Ora de sa Tzina (Shanghai)',
        'Asia/Singapore' => 'Ora de Singapore',
        'Asia/Srednekolymsk' => 'Ora de Magadan (Srednekolymsk)',
        'Asia/Taipei' => 'Ora de Taipei',
        'Asia/Tashkent' => 'Ora de s’Uzbèkistan (Tashkent)',
        'Asia/Tbilisi' => 'Ora de sa Geòrgia (Tbilisi)',
        'Asia/Tehran' => 'Ora de s’Iràn (Teheràn)',
        'Asia/Thimphu' => 'Ora de su Bhutàn (Thimphu)',
        'Asia/Tokyo' => 'Ora de su Giapone (Tòkyo)',
        'Asia/Tomsk' => 'Ora de Krasnoyarsk (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ora de Ulàn Bator',
        'Asia/Urumqi' => 'Ora Tzina (Ürümqi)',
        'Asia/Ust-Nera' => 'Ora de Vladivostok (Ust-Nera)',
        'Asia/Vientiane' => 'Ora de s’Indotzina (Vientiane)',
        'Asia/Vladivostok' => 'Ora de Vladivostok',
        'Asia/Yakutsk' => 'Ora de Yakutsk',
        'Asia/Yekaterinburg' => 'Ora de Yekaterinburg',
        'Asia/Yerevan' => 'Ora de s’Armènia (Yerevan)',
        'Atlantic/Azores' => 'Ora de sas Azorras',
        'Atlantic/Bermuda' => 'Ora de s’Atlànticu (Bermuda)',
        'Atlantic/Canary' => 'Ora de s’Europa otzidentale (Ìsulas Canàrias)',
        'Atlantic/Cape_Verde' => 'Ora de su Cabu Birde',
        'Atlantic/Faeroe' => 'Ora de s’Europa otzidentale (Ìsulas Føroyar)',
        'Atlantic/Faroe' => 'Ora de s’Europa otzidentale (Ìsulas Føroyar)',
        'Atlantic/Madeira' => 'Ora de s’Europa otzidentale (Madèira)',
        'Atlantic/Reykjavik' => 'Ora de su meridianu de Greenwich (Reykjavik)',
        'Atlantic/South_Georgia' => 'Ora de sa Geòrgia de su Sud',
        'Atlantic/St_Helena' => 'Ora de su meridianu de Greenwich (Sant’Elene)',
        'Atlantic/Stanley' => 'Ora de sas Ìsulas Falkland (Stanley)',
        'Australia/Adelaide' => 'Ora de s’Austràlia tzentrale (Adelaide)',
        'Australia/Brisbane' => 'Ora de s’Austràlia orientale (Brisbane)',
        'Australia/Broken_Hill' => 'Ora de s’Austràlia tzentrale (Broken Hill)',
        'Australia/Darwin' => 'Ora de s’Austràlia tzentrale (Darwin)',
        'Australia/Eucla' => 'Ora de s’Austràlia tzentru-otzidentale (Eucla)',
        'Australia/Hobart' => 'Ora de s’Austràlia orientale (Hobart)',
        'Australia/Lindeman' => 'Ora de s’Austràlia orientale (Lindeman)',
        'Australia/Lord_Howe' => 'Ora de Lord Howe',
        'Australia/Melbourne' => 'Ora de s’Austràlia orientale (Melbourne)',
        'Australia/Perth' => 'Ora de s’Austràlia otzidentale (Perth)',
        'Australia/Sydney' => 'Ora de s’Austràlia orientale (Sydney)',
        'Etc/GMT' => 'Ora de su meridianu de Greenwich',
        'Etc/UTC' => 'Tempus coordinadu universale',
        'Europe/Amsterdam' => 'Ora de s’Europa tzentrale (Amsterdam)',
        'Europe/Andorra' => 'Ora de s’Europa tzentrale (Andorra)',
        'Europe/Astrakhan' => 'Ora de Samara (Astrakhan)',
        'Europe/Athens' => 'Ora de s’Europa orientale (Atene)',
        'Europe/Belgrade' => 'Ora de s’Europa tzentrale (Belgradu)',
        'Europe/Berlin' => 'Ora de s’Europa tzentrale (Berlinu)',
        'Europe/Bratislava' => 'Ora de s’Europa tzentrale (Bratislava)',
        'Europe/Brussels' => 'Ora de s’Europa tzentrale (Bruxelles)',
        'Europe/Bucharest' => 'Ora de s’Europa orientale (Bùcarest)',
        'Europe/Budapest' => 'Ora de s’Europa tzentrale (Bùdapest)',
        'Europe/Busingen' => 'Ora de s’Europa tzentrale (Büsingen)',
        'Europe/Chisinau' => 'Ora de s’Europa orientale (Chișinău)',
        'Europe/Copenhagen' => 'Ora de s’Europa tzentrale (Copenhagen)',
        'Europe/Dublin' => 'Ora de su meridianu de Greenwich (Dublinu)',
        'Europe/Gibraltar' => 'Ora de s’Europa tzentrale (Gibilterra)',
        'Europe/Guernsey' => 'Ora de su meridianu de Greenwich (Guernsey)',
        'Europe/Helsinki' => 'Ora de s’Europa orientale (Helsinki)',
        'Europe/Isle_of_Man' => 'Ora de su meridianu de Greenwich (Ìsula de Man)',
        'Europe/Istanbul' => 'Ora Turchia (Ìstanbul)',
        'Europe/Jersey' => 'Ora de su meridianu de Greenwich (Jersey)',
        'Europe/Kaliningrad' => 'Ora de s’Europa orientale (Kaliningrad)',
        'Europe/Kiev' => 'Ora de s’Europa orientale (Kiev)',
        'Europe/Kyiv' => 'Ora de s’Europa orientale (Kiev)',
        'Europe/Kirov' => 'Ora de Mosca (Kirov)',
        'Europe/Lisbon' => 'Ora de s’Europa otzidentale (Lisbona)',
        'Europe/Ljubljana' => 'Ora de s’Europa tzentrale (Lubiana)',
        'Europe/London' => 'Ora de su meridianu de Greenwich (Londra)',
        'Europe/Luxembourg' => 'Ora de s’Europa tzentrale (Lussemburgu)',
        'Europe/Madrid' => 'Ora de s’Europa tzentrale (Madrìd)',
        'Europe/Malta' => 'Ora de s’Europa tzentrale (Malta)',
        'Europe/Mariehamn' => 'Ora de s’Europa orientale (Mariehamn)',
        'Europe/Minsk' => 'Ora de Mosca (Minsk)',
        'Europe/Monaco' => 'Ora de s’Europa tzentrale (Mònacu)',
        'Europe/Moscow' => 'Ora de Mosca',
        'Europe/Oslo' => 'Ora de s’Europa tzentrale (Oslo)',
        'Europe/Paris' => 'Ora de s’Europa tzentrale (Parigi)',
        'Europe/Podgorica' => 'Ora de s’Europa tzentrale (Podgorica)',
        'Europe/Prague' => 'Ora de s’Europa tzentrale (Praga)',
        'Europe/Riga' => 'Ora de s’Europa orientale (Riga)',
        'Europe/Rome' => 'Ora de s’Europa tzentrale (Roma)',
        'Europe/Samara' => 'Ora de Samara',
        'Europe/San_Marino' => 'Ora de s’Europa tzentrale (Santu Marinu)',
        'Europe/Sarajevo' => 'Ora de s’Europa tzentrale (Sarajevo)',
        'Europe/Saratov' => 'Ora de Samara (Saratov)',
        'Europe/Simferopol' => 'Ora de Mosca (Simferopol)',
        'Europe/Skopje' => 'Ora de s’Europa tzentrale (Skopje)',
        'Europe/Sofia' => 'Ora de s’Europa orientale (Sofia)',
        'Europe/Stockholm' => 'Ora de s’Europa tzentrale (Istocolma)',
        'Europe/Tallinn' => 'Ora de s’Europa orientale (Tallinn)',
        'Europe/Tirane' => 'Ora de s’Europa tzentrale (Tirana)',
        'Europe/Ulyanovsk' => 'Ora de Samara (Ulyanovsk)',
        'Europe/Vaduz' => 'Ora de s’Europa tzentrale (Vaduz)',
        'Europe/Vatican' => 'Ora de s’Europa tzentrale (Tzitade de su Vaticanu)',
        'Europe/Vienna' => 'Ora de s’Europa tzentrale (Vienna)',
        'Europe/Vilnius' => 'Ora de s’Europa orientale (Vìlnius)',
        'Europe/Volgograd' => 'Ora de Mosca (Volgograd)',
        'Europe/Warsaw' => 'Ora de s’Europa tzentrale (Varsàvia)',
        'Europe/Zagreb' => 'Ora de s’Europa tzentrale (Zagàbria)',
        'Europe/Zurich' => 'Ora de s’Europa tzentrale (Zurigu)',
        'Indian/Antananarivo' => 'Ora de s’Àfrica orientale (Antananarivo)',
        'Indian/Chagos' => 'Ora de s’Otzèanu Indianu (Chagos)',
        'Indian/Christmas' => 'Ora de s’Ìsula de sa Natividade',
        'Indian/Cocos' => 'Ora de sas Ìsulas Cocos',
        'Indian/Comoro' => 'Ora de s’Àfrica orientale (Comores)',
        'Indian/Kerguelen' => 'Ora de sa Terras australes e antàrticas frantzesas (Kerguelen)',
        'Indian/Mahe' => 'Ora de sas Seychelles (Mahé)',
        'Indian/Maldives' => 'Ora de sas Maldivas',
        'Indian/Mauritius' => 'Ora de sas Maurìtzius',
        'Indian/Mayotte' => 'Ora de s’Àfrica orientale (Maiota)',
        'Indian/Reunion' => 'Ora de sa Reunione',
        'Pacific/Apia' => 'Ora de Apia',
        'Pacific/Auckland' => 'Ora de sa Zelanda Noa (Auckland)',
        'Pacific/Bougainville' => 'Ora de sa Pàpua Guinea Noa (Bougainville)',
        'Pacific/Chatham' => 'Ora de sas Chatham',
        'Pacific/Easter' => 'Ora de s’Ìsula de Pasca',
        'Pacific/Efate' => 'Ora de su Vanuatu (Efate)',
        'Pacific/Enderbury' => 'Ora de sas Ìsulas de sa Fenìtzie (Canton)',
        'Pacific/Kanton' => 'Ora de sas Ìsulas de sa Fenìtzie (Canton)',
        'Pacific/Fakaofo' => 'Ora de su Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Ora de sas Fiji',
        'Pacific/Funafuti' => 'Ora de su Tuvalu (Funafuti)',
        'Pacific/Galapagos' => 'Ora de sas Galàpagos (Ìsulas Galàpagos)',
        'Pacific/Gambier' => 'Ora de Gambier',
        'Pacific/Guadalcanal' => 'Ora de sas Ìsulas Salomone (Guadalcanal)',
        'Pacific/Guam' => 'Ora istandard de Chamorro (Guàm)',
        'Pacific/Honolulu' => 'Ora istandard de sas ìsulas Hawaii-Aleutinas (Honolulu)',
        'Pacific/Kiritimati' => 'Ora de sas Ìsulas de sa Lìnia (Kiritimati)',
        'Pacific/Kosrae' => 'Ora de Kosrae',
        'Pacific/Kwajalein' => 'Ora de sas Ìsulas Marshall (Kwajalein)',
        'Pacific/Majuro' => 'Ora de sas Ìsulas Marshall (Majuro)',
        'Pacific/Marquesas' => 'Ora de sas Marchesas',
        'Pacific/Midway' => 'Ora de sas Samoa (Midway)',
        'Pacific/Nauru' => 'Ora de Nauru',
        'Pacific/Niue' => 'Ora de Niue',
        'Pacific/Norfolk' => 'Ora de s’Ìsula Norfolk',
        'Pacific/Noumea' => 'Ora de sa Caledònia Noa (Nouméa)',
        'Pacific/Pago_Pago' => 'Ora de sas Samoa (Pago Pago)',
        'Pacific/Palau' => 'Ora de Palau',
        'Pacific/Pitcairn' => 'Ora de sas Pitcairn',
        'Pacific/Ponape' => 'Ora de Pohnpei',
        'Pacific/Pohnpei' => 'Ora de Pohnpei',
        'Pacific/Port_Moresby' => 'Ora de sa Pàpua Guinea Noa (Port Moresby)',
        'Pacific/Rarotonga' => 'Ora de sas Ìsulas Cook (Rarotonga)',
        'Pacific/Saipan' => 'Ora istandard de Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Ora de Tahiti',
        'Pacific/Tarawa' => 'Ora de sas Ìsulas Gilbert (Tarawa)',
        'Pacific/Tongatapu' => 'Ora de su Tonga (Tongatapu)',
        'Pacific/Truk' => 'Ora de su Chuuk',
        'Pacific/Chuuk' => 'Ora de su Chuuk',
        'Pacific/Wake' => 'Ora de sas Ìsulas Wake',
        'Pacific/Wallis' => 'Ora de Wallis e Futuna',
    ],
    'Meta' => [],
];
