<?php

return [
    'Names' => [
        'be' => 'bjeloruski',
        'bm' => 'bamanankan',
        'bn' => 'bangla',
        'crl' => 'sjeveroistočni kri',
        'de' => 'njemački',
        'frr' => 'sjevernofrizijski',
        'gsw' => 'njemački (Švajcarska)',
        'ht' => 'haićanski kreolski',
        'lrc' => 'sjeverni luri',
        'nd' => 'sjeverni ndebele',
        'nds' => 'niskonjemački',
        'nso' => 'sjeverni soto',
        'ojb' => 'sjeverozapadni odžibva',
        'se' => 'sjeverni sami',
        'ttm' => 'sjeverni tučon',
    ],
    'LocalizedNames' => [
        'de_CH' => 'švajcarski visoki njemački',
    ],
];
