<?php

return [
    'Names' => [
        'Africa/Abidjan' => '格林尼治标准时间（阿比让）',
        'Africa/Accra' => '格林尼治标准时间（阿克拉）',
        'Africa/Addis_Ababa' => '东部非洲时间（亚的斯亚贝巴）',
        'Africa/Algiers' => '中欧时间（阿尔及尔）',
        'Africa/Asmera' => '东部非洲时间（阿斯马拉）',
        'Africa/Asmara' => '东部非洲时间（阿斯马拉）',
        'Africa/Bamako' => '格林尼治标准时间（巴马科）',
        'Africa/Bangui' => '西部非洲时间（班吉）',
        'Africa/Banjul' => '格林尼治标准时间（班珠尔）',
        'Africa/Bissau' => '格林尼治标准时间（比绍）',
        'Africa/Blantyre' => '中部非洲时间（布兰太尔）',
        'Africa/Brazzaville' => '西部非洲时间（布拉柴维尔）',
        'Africa/Bujumbura' => '中部非洲时间（布琼布拉）',
        'Africa/Cairo' => '东欧时间（开罗）',
        'Africa/Casablanca' => '西欧时间（卡萨布兰卡）',
        'Africa/Ceuta' => '中欧时间（休达）',
        'Africa/Conakry' => '格林尼治标准时间（科纳克里）',
        'Africa/Dakar' => '格林尼治标准时间（达喀尔）',
        'Africa/Dar_es_Salaam' => '东部非洲时间（达累斯萨拉姆）',
        'Africa/Djibouti' => '东部非洲时间（吉布提）',
        'Africa/Douala' => '西部非洲时间（杜阿拉）',
        'Africa/El_Aaiun' => '西欧时间（阿尤恩）',
        'Africa/Freetown' => '格林尼治标准时间（弗里敦）',
        'Africa/Gaborone' => '中部非洲时间（哈博罗内）',
        'Africa/Harare' => '中部非洲时间（哈拉雷）',
        'Africa/Johannesburg' => '南非标准时间（约翰内斯堡）',
        'Africa/Juba' => '中部非洲时间（朱巴）',
        'Africa/Kampala' => '东部非洲时间（坎帕拉）',
        'Africa/Khartoum' => '中部非洲时间（喀土穆）',
        'Africa/Kigali' => '中部非洲时间（基加利）',
        'Africa/Kinshasa' => '西部非洲时间（金沙萨）',
        'Africa/Lagos' => '西部非洲时间（拉各斯）',
        'Africa/Libreville' => '西部非洲时间（利伯维尔）',
        'Africa/Lome' => '格林尼治标准时间（洛美）',
        'Africa/Luanda' => '西部非洲时间（罗安达）',
        'Africa/Lubumbashi' => '中部非洲时间（卢本巴希）',
        'Africa/Lusaka' => '中部非洲时间（卢萨卡）',
        'Africa/Malabo' => '西部非洲时间（马拉博）',
        'Africa/Maputo' => '中部非洲时间（马普托）',
        'Africa/Maseru' => '南非标准时间（马塞卢）',
        'Africa/Mbabane' => '南非标准时间（姆巴巴纳）',
        'Africa/Mogadishu' => '东部非洲时间（摩加迪沙）',
        'Africa/Monrovia' => '格林尼治标准时间（蒙罗维亚）',
        'Africa/Nairobi' => '东部非洲时间（内罗毕）',
        'Africa/Ndjamena' => '西部非洲时间（恩贾梅纳）',
        'Africa/Niamey' => '西部非洲时间（尼亚美）',
        'Africa/Nouakchott' => '格林尼治标准时间（努瓦克肖特）',
        'Africa/Ouagadougou' => '格林尼治标准时间（瓦加杜古）',
        'Africa/Porto-Novo' => '西部非洲时间（波多诺伏）',
        'Africa/Sao_Tome' => '格林尼治标准时间（圣多美）',
        'Africa/Tripoli' => '东欧时间（的黎波里）',
        'Africa/Tunis' => '中欧时间（突尼斯）',
        'Africa/Windhoek' => '中部非洲时间（温得和克）',
        'America/Adak' => '夏威夷-阿留申时间（埃达克）',
        'America/Anchorage' => '阿拉斯加时间（安克雷奇）',
        'America/Anguilla' => '大西洋时间（安圭拉）',
        'America/Antigua' => '大西洋时间（安提瓜）',
        'America/Araguaina' => '巴西利亚时间（阿拉瓜伊纳）',
        'America/Argentina/La_Rioja' => '阿根廷时间（拉里奥哈）',
        'America/Argentina/Rio_Gallegos' => '阿根廷时间（里奥加耶戈斯）',
        'America/Argentina/Salta' => '阿根廷时间（萨尔塔）',
        'America/Argentina/San_Juan' => '阿根廷时间（圣胡安）',
        'America/Argentina/San_Luis' => '阿根廷时间（圣路易斯）',
        'America/Argentina/Tucuman' => '阿根廷时间（图库曼）',
        'America/Argentina/Ushuaia' => '阿根廷时间（乌斯怀亚）',
        'America/Aruba' => '大西洋时间（阿鲁巴）',
        'America/Asuncion' => '巴拉圭时间（亚松森）',
        'America/Bahia' => '巴西利亚时间（巴伊亚）',
        'America/Bahia_Banderas' => '北美中部时间（巴伊亚班德拉斯）',
        'America/Barbados' => '大西洋时间（巴巴多斯）',
        'America/Belem' => '巴西利亚时间（贝伦）',
        'America/Belize' => '北美中部时间（伯利兹）',
        'America/Blanc-Sablon' => '大西洋时间（布兰克萨布隆）',
        'America/Boa_Vista' => '亚马逊时间（博阿维斯塔）',
        'America/Bogota' => '哥伦比亚时间（波哥大）',
        'America/Boise' => '北美山区时间（博伊西）',
        'America/Buenos_Aires' => '阿根廷时间（布宜诺斯艾利斯）',
        'America/Argentina/Buenos_Aires' => '阿根廷时间（布宜诺斯艾利斯）',
        'America/Cambridge_Bay' => '北美山区时间（剑桥湾）',
        'America/Campo_Grande' => '亚马逊时间（大坎普）',
        'America/Cancun' => '北美东部时间（坎昆）',
        'America/Caracas' => '委内瑞拉时间（加拉加斯）',
        'America/Catamarca' => '阿根廷时间（卡塔马卡）',
        'America/Argentina/Catamarca' => '阿根廷时间（卡塔马卡）',
        'America/Cayenne' => '法属圭亚那标准时间（卡宴）',
        'America/Cayman' => '北美东部时间（开曼）',
        'America/Chicago' => '北美中部时间（芝加哥）',
        'America/Chihuahua' => '北美中部时间（奇瓦瓦）',
        'America/Ciudad_Juarez' => '北美山区时间（华雷斯城）',
        'America/Coral_Harbour' => '北美东部时间（阿蒂科肯）',
        'America/Atikokan' => '北美东部时间（阿蒂科肯）',
        'America/Cordoba' => '阿根廷时间（科尔多瓦）',
        'America/Argentina/Cordoba' => '阿根廷时间（科尔多瓦）',
        'America/Costa_Rica' => '北美中部时间（哥斯达黎加）',
        'America/Coyhaique' => '智利时间（科伊艾克）',
        'America/Creston' => '北美山区时间（克雷斯顿）',
        'America/Cuiaba' => '亚马逊时间（库亚巴）',
        'America/Curacao' => '大西洋时间（库拉索）',
        'America/Danmarkshavn' => '格林尼治标准时间（丹马沙文）',
        'America/Dawson' => '育空时间（道森）',
        'America/Dawson_Creek' => '北美山区时间（道森克里克）',
        'America/Denver' => '北美山区时间（丹佛）',
        'America/Detroit' => '北美东部时间（底特律）',
        'America/Dominica' => '大西洋时间（多米尼加）',
        'America/Edmonton' => '北美山区时间（埃德蒙顿）',
        'America/Eirunepe' => '阿克里时间（依伦尼贝）',
        'America/El_Salvador' => '北美中部时间（萨尔瓦多）',
        'America/Fort_Nelson' => '北美山区时间（纳尔逊堡）',
        'America/Fortaleza' => '巴西利亚时间（福塔雷萨）',
        'America/Glace_Bay' => '大西洋时间（格莱斯贝）',
        'America/Godthab' => '格陵兰时间（努克）',
        'America/Nuuk' => '格陵兰时间（努克）',
        'America/Goose_Bay' => '大西洋时间（古斯湾）',
        'America/Grand_Turk' => '北美东部时间（大特克）',
        'America/Grenada' => '大西洋时间（格林纳达）',
        'America/Guadeloupe' => '大西洋时间（瓜德罗普）',
        'America/Guatemala' => '北美中部时间（危地马拉）',
        'America/Guayaquil' => '厄瓜多尔标准时间（瓜亚基尔）',
        'America/Guyana' => '圭亚那时间',
        'America/Halifax' => '大西洋时间（哈利法克斯）',
        'America/Havana' => '古巴时间（哈瓦那）',
        'America/Hermosillo' => '墨西哥太平洋时间（埃莫西约）',
        'America/Indiana/Knox' => '北美中部时间（印第安纳州诺克斯）',
        'America/Indiana/Marengo' => '北美东部时间（印第安纳州马伦戈）',
        'America/Indiana/Petersburg' => '北美东部时间（印第安纳州彼得斯堡）',
        'America/Indiana/Tell_City' => '北美中部时间（印第安纳州特尔城）',
        'America/Indiana/Vevay' => '北美东部时间（印第安纳州维维市）',
        'America/Indiana/Vincennes' => '北美东部时间（印第安纳州温森斯）',
        'America/Indiana/Winamac' => '北美东部时间（印第安纳州威纳马克）',
        'America/Indianapolis' => '北美东部时间（印第安纳波利斯）',
        'America/Indiana/Indianapolis' => '北美东部时间（印第安纳波利斯）',
        'America/Inuvik' => '北美山区时间（伊努维克）',
        'America/Iqaluit' => '北美东部时间（伊魁特）',
        'America/Jamaica' => '北美东部时间（牙买加）',
        'America/Jujuy' => '阿根廷时间（胡胡伊）',
        'America/Argentina/Jujuy' => '阿根廷时间（胡胡伊）',
        'America/Juneau' => '阿拉斯加时间（朱诺）',
        'America/Kentucky/Monticello' => '北美东部时间（肯塔基州蒙蒂塞洛）',
        'America/Kralendijk' => '大西洋时间（克拉伦代克）',
        'America/La_Paz' => '玻利维亚标准时间（拉巴斯）',
        'America/Lima' => '秘鲁时间（利马）',
        'America/Los_Angeles' => '北美太平洋时间（洛杉矶）',
        'America/Louisville' => '北美东部时间（路易斯维尔）',
        'America/Kentucky/Louisville' => '北美东部时间（路易斯维尔）',
        'America/Lower_Princes' => '大西洋时间（下太子区）',
        'America/Maceio' => '巴西利亚时间（马塞约）',
        'America/Managua' => '北美中部时间（马那瓜）',
        'America/Manaus' => '亚马逊时间（马瑙斯）',
        'America/Marigot' => '大西洋时间（马里戈特）',
        'America/Martinique' => '大西洋时间（马提尼克）',
        'America/Matamoros' => '北美中部时间（马塔莫罗斯）',
        'America/Mazatlan' => '墨西哥太平洋时间（马萨特兰）',
        'America/Mendoza' => '阿根廷时间（门多萨）',
        'America/Argentina/Mendoza' => '阿根廷时间（门多萨）',
        'America/Menominee' => '北美中部时间（梅诺米尼）',
        'America/Merida' => '北美中部时间（梅里达）',
        'America/Metlakatla' => '阿拉斯加时间（梅特拉卡特拉）',
        'America/Mexico_City' => '北美中部时间（墨西哥城）',
        'America/Miquelon' => '圣皮埃尔和密克隆群岛时间',
        'America/Moncton' => '大西洋时间（蒙克顿）',
        'America/Monterrey' => '北美中部时间（蒙特雷）',
        'America/Montevideo' => '乌拉圭时间（蒙得维的亚）',
        'America/Montserrat' => '大西洋时间（蒙特塞拉特）',
        'America/Nassau' => '北美东部时间（拿骚）',
        'America/New_York' => '北美东部时间（纽约）',
        'America/Nome' => '阿拉斯加时间（诺姆）',
        'America/Noronha' => '费尔南多-迪诺罗尼亚岛时间（洛罗尼亚）',
        'America/North_Dakota/Beulah' => '北美中部时间（北达科他州比尤拉）',
        'America/North_Dakota/Center' => '北美中部时间（北达科他州申特）',
        'America/North_Dakota/New_Salem' => '北美中部时间（北达科他州新塞勒姆）',
        'America/Ojinaga' => '北美中部时间（奥希纳加）',
        'America/Panama' => '北美东部时间（巴拿马）',
        'America/Paramaribo' => '苏里南时间（帕拉马里博）',
        'America/Phoenix' => '北美山区时间（凤凰城）',
        'America/Port-au-Prince' => '北美东部时间（太子港）',
        'America/Port_of_Spain' => '大西洋时间（西班牙港）',
        'America/Porto_Velho' => '亚马逊时间（波多韦柳）',
        'America/Puerto_Rico' => '大西洋时间（波多黎各）',
        'America/Punta_Arenas' => '智利时间（蓬塔阿雷纳斯）',
        'America/Rankin_Inlet' => '北美中部时间（兰今湾）',
        'America/Recife' => '巴西利亚时间（累西腓）',
        'America/Regina' => '北美中部时间（里贾纳）',
        'America/Resolute' => '北美中部时间（雷索卢特）',
        'America/Rio_Branco' => '阿克里时间（里奥布郎库）',
        'America/Santarem' => '巴西利亚时间（圣塔伦）',
        'America/Santiago' => '智利时间（圣地亚哥）',
        'America/Santo_Domingo' => '大西洋时间（圣多明各）',
        'America/Sao_Paulo' => '巴西利亚时间（圣保罗）',
        'America/Scoresbysund' => '格陵兰时间（斯科列斯比桑德）',
        'America/Sitka' => '阿拉斯加时间（锡特卡）',
        'America/St_Barthelemy' => '大西洋时间（圣巴泰勒米岛）',
        'America/St_Johns' => '纽芬兰时间（圣约翰斯）',
        'America/St_Kitts' => '大西洋时间（圣基茨）',
        'America/St_Lucia' => '大西洋时间（圣卢西亚）',
        'America/St_Thomas' => '大西洋时间（圣托马斯）',
        'America/St_Vincent' => '大西洋时间（圣文森特）',
        'America/Swift_Current' => '北美中部时间（斯威夫特卡伦特）',
        'America/Tegucigalpa' => '北美中部时间（特古西加尔巴）',
        'America/Thule' => '大西洋时间（图勒）',
        'America/Tijuana' => '北美太平洋时间（蒂华纳）',
        'America/Toronto' => '北美东部时间（多伦多）',
        'America/Tortola' => '大西洋时间（托尔托拉）',
        'America/Vancouver' => '北美太平洋时间（温哥华）',
        'America/Whitehorse' => '育空时间（怀特霍斯）',
        'America/Winnipeg' => '北美中部时间（温尼伯）',
        'America/Yakutat' => '阿拉斯加时间（亚库塔特）',
        'Antarctica/Casey' => '澳大利亚西部时间（卡塞）',
        'Antarctica/Davis' => '戴维斯时间',
        'Antarctica/DumontDUrville' => '迪蒙·迪维尔时间',
        'Antarctica/Macquarie' => '澳大利亚东部时间（麦夸里岛）',
        'Antarctica/Mawson' => '莫森时间',
        'Antarctica/McMurdo' => '新西兰时间（麦克默多）',
        'Antarctica/Palmer' => '智利时间（帕尔默）',
        'Antarctica/Rothera' => '罗瑟拉时间',
        'Antarctica/Syowa' => '昭和时间',
        'Antarctica/Troll' => '格林尼治标准时间（特罗尔）',
        'Antarctica/Vostok' => '沃斯托克时间',
        'Arctic/Longyearbyen' => '中欧时间（朗伊尔城）',
        'Asia/Aden' => '阿拉伯时间（亚丁）',
        'Asia/Almaty' => '哈萨克斯坦时间（阿拉木图）',
        'Asia/Amman' => '东欧时间（安曼）',
        'Asia/Anadyr' => '彼得罗巴甫洛夫斯克-堪察加时间（阿纳德尔）',
        'Asia/Aqtau' => '哈萨克斯坦时间（阿克套）',
        'Asia/Aqtobe' => '哈萨克斯坦时间（阿克托别）',
        'Asia/Ashgabat' => '土库曼斯坦时间（阿什哈巴德）',
        'Asia/Atyrau' => '哈萨克斯坦时间（阿特劳）',
        'Asia/Baghdad' => '阿拉伯时间（巴格达）',
        'Asia/Bahrain' => '阿拉伯时间（巴林）',
        'Asia/Baku' => '阿塞拜疆时间（巴库）',
        'Asia/Bangkok' => '中南半岛时间（曼谷）',
        'Asia/Barnaul' => '克拉斯诺亚尔斯克时间（巴尔瑙尔）',
        'Asia/Beirut' => '东欧时间（贝鲁特）',
        'Asia/Bishkek' => '吉尔吉斯斯坦时间（比什凯克）',
        'Asia/Brunei' => '文莱达鲁萨兰时间',
        'Asia/Calcutta' => '印度时间（加尔各答）',
        'Asia/Kolkata' => '印度时间（加尔各答）',
        'Asia/Chita' => '雅库茨克时间（赤塔）',
        'Asia/Colombo' => '印度时间（科伦坡）',
        'Asia/Damascus' => '东欧时间（大马士革）',
        'Asia/Dhaka' => '孟加拉时间（达卡）',
        'Asia/Dili' => '东帝汶时间（帝力）',
        'Asia/Dubai' => '海湾标准时间（迪拜）',
        'Asia/Dushanbe' => '塔吉克斯坦时间（杜尚别）',
        'Asia/Famagusta' => '东欧时间（法马古斯塔）',
        'Asia/Gaza' => '东欧时间（加沙）',
        'Asia/Hebron' => '东欧时间（希伯伦）',
        'Asia/Hong_Kong' => '香港时间',
        'Asia/Hovd' => '科布多时间',
        'Asia/Irkutsk' => '伊尔库茨克时间',
        'Asia/Jakarta' => '印度尼西亚西部时间（雅加达）',
        'Asia/Jayapura' => '印度尼西亚东部时间（查亚普拉）',
        'Asia/Jerusalem' => '以色列时间（耶路撒冷）',
        'Asia/Kabul' => '阿富汗时间（喀布尔）',
        'Asia/Kamchatka' => '彼得罗巴甫洛夫斯克-堪察加时间',
        'Asia/Karachi' => '巴基斯坦时间（卡拉奇）',
        'Asia/Katmandu' => '尼泊尔时间（加德满都）',
        'Asia/Kathmandu' => '尼泊尔时间（加德满都）',
        'Asia/Khandyga' => '雅库茨克时间（汉德加）',
        'Asia/Krasnoyarsk' => '克拉斯诺亚尔斯克时间',
        'Asia/Kuala_Lumpur' => '马来西亚时间（吉隆坡）',
        'Asia/Kuching' => '马来西亚时间（古晋）',
        'Asia/Kuwait' => '阿拉伯时间（科威特）',
        'Asia/Macau' => '中国时间（澳门）',
        'Asia/Magadan' => '马加丹时间',
        'Asia/Makassar' => '印度尼西亚中部时间（望加锡）',
        'Asia/Manila' => '菲律宾时间（马尼拉）',
        'Asia/Muscat' => '海湾标准时间（马斯喀特）',
        'Asia/Nicosia' => '东欧时间（尼科西亚）',
        'Asia/Novokuznetsk' => '克拉斯诺亚尔斯克时间（新库兹涅茨克）',
        'Asia/Novosibirsk' => '克拉斯诺亚尔斯克时间（新西伯利亚）',
        'Asia/Omsk' => '鄂木斯克时间',
        'Asia/Oral' => '哈萨克斯坦时间（乌拉尔）',
        'Asia/Phnom_Penh' => '中南半岛时间（金边）',
        'Asia/Pontianak' => '印度尼西亚西部时间（坤甸）',
        'Asia/Pyongyang' => '韩国时间（平壤）',
        'Asia/Qatar' => '阿拉伯时间（卡塔尔）',
        'Asia/Qostanay' => '哈萨克斯坦时间（库斯塔奈）',
        'Asia/Qyzylorda' => '哈萨克斯坦时间（克孜洛尔达）',
        'Asia/Rangoon' => '缅甸时间（仰光）',
        'Asia/Yangon' => '缅甸时间（仰光）',
        'Asia/Riyadh' => '阿拉伯时间（利雅得）',
        'Asia/Saigon' => '中南半岛时间（胡志明市）',
        'Asia/Ho_Chi_Minh' => '中南半岛时间（胡志明市）',
        'Asia/Sakhalin' => '马加丹时间（萨哈林）',
        'Asia/Samarkand' => '乌兹别克斯坦时间（撒马尔罕）',
        'Asia/Seoul' => '韩国时间（首尔）',
        'Asia/Shanghai' => '中国时间（上海）',
        'Asia/Singapore' => '新加坡标准时间',
        'Asia/Srednekolymsk' => '马加丹时间（中科雷姆斯克）',
        'Asia/Taipei' => '台北时间',
        'Asia/Tashkent' => '乌兹别克斯坦时间（塔什干）',
        'Asia/Tbilisi' => '格鲁吉亚时间（第比利斯）',
        'Asia/Tehran' => '伊朗时间（德黑兰）',
        'Asia/Thimphu' => '不丹时间（廷布）',
        'Asia/Tokyo' => '日本时间（东京）',
        'Asia/Tomsk' => '克拉斯诺亚尔斯克时间（托木斯克）',
        'Asia/Ulaanbaatar' => '乌兰巴托时间',
        'Asia/Urumqi' => '中国时间（乌鲁木齐）',
        'Asia/Ust-Nera' => '海参崴时间（乌斯内拉）',
        'Asia/Vientiane' => '中南半岛时间（万象）',
        'Asia/Vladivostok' => '海参崴时间',
        'Asia/Yakutsk' => '雅库茨克时间',
        'Asia/Yekaterinburg' => '叶卡捷琳堡时间',
        'Asia/Yerevan' => '亚美尼亚时间（埃里温）',
        'Atlantic/Azores' => '亚速尔群岛时间',
        'Atlantic/Bermuda' => '大西洋时间（百慕大）',
        'Atlantic/Canary' => '西欧时间（加那利）',
        'Atlantic/Cape_Verde' => '佛得角时间',
        'Atlantic/Faeroe' => '西欧时间（法罗）',
        'Atlantic/Faroe' => '西欧时间（法罗）',
        'Atlantic/Madeira' => '西欧时间（马德拉）',
        'Atlantic/Reykjavik' => '格林尼治标准时间（雷克雅未克）',
        'Atlantic/South_Georgia' => '南乔治亚岛时间',
        'Atlantic/St_Helena' => '格林尼治标准时间（圣赫勒拿）',
        'Atlantic/Stanley' => '福克兰群岛时间（斯坦利）',
        'Australia/Adelaide' => '澳大利亚中部时间（阿德莱德）',
        'Australia/Brisbane' => '澳大利亚东部时间（布里斯班）',
        'Australia/Broken_Hill' => '澳大利亚中部时间（布罗肯希尔）',
        'Australia/Darwin' => '澳大利亚中部时间（达尔文）',
        'Australia/Eucla' => '澳大利亚中西部时间（尤克拉）',
        'Australia/Hobart' => '澳大利亚东部时间（霍巴特）',
        'Australia/Lindeman' => '澳大利亚东部时间（林德曼）',
        'Australia/Lord_Howe' => '豪勋爵岛时间',
        'Australia/Melbourne' => '澳大利亚东部时间（墨尔本）',
        'Australia/Perth' => '澳大利亚西部时间（珀斯）',
        'Australia/Sydney' => '澳大利亚东部时间（悉尼）',
        'Etc/GMT' => '格林尼治标准时间',
        'Etc/UTC' => '协调世界时',
        'Europe/Amsterdam' => '中欧时间（阿姆斯特丹）',
        'Europe/Andorra' => '中欧时间（安道尔）',
        'Europe/Astrakhan' => '萨马拉时间（阿斯特拉罕）',
        'Europe/Athens' => '东欧时间（雅典）',
        'Europe/Belgrade' => '中欧时间（贝尔格莱德）',
        'Europe/Berlin' => '中欧时间（柏林）',
        'Europe/Bratislava' => '中欧时间（布拉迪斯拉发）',
        'Europe/Brussels' => '中欧时间（布鲁塞尔）',
        'Europe/Bucharest' => '东欧时间（布加勒斯特）',
        'Europe/Budapest' => '中欧时间（布达佩斯）',
        'Europe/Busingen' => '中欧时间（布辛根）',
        'Europe/Chisinau' => '东欧时间（基希讷乌）',
        'Europe/Copenhagen' => '中欧时间（哥本哈根）',
        'Europe/Dublin' => '格林尼治标准时间（都柏林）',
        'Europe/Gibraltar' => '中欧时间（直布罗陀）',
        'Europe/Guernsey' => '格林尼治标准时间（根西岛）',
        'Europe/Helsinki' => '东欧时间（赫尔辛基）',
        'Europe/Isle_of_Man' => '格林尼治标准时间（马恩岛）',
        'Europe/Istanbul' => '土耳其时间（伊斯坦布尔）',
        'Europe/Jersey' => '格林尼治标准时间（泽西岛）',
        'Europe/Kaliningrad' => '东欧时间（加里宁格勒）',
        'Europe/Kiev' => '东欧时间（基辅）',
        'Europe/Kyiv' => '东欧时间（基辅）',
        'Europe/Kirov' => '莫斯科时间（基洛夫）',
        'Europe/Lisbon' => '西欧时间（里斯本）',
        'Europe/Ljubljana' => '中欧时间（卢布尔雅那）',
        'Europe/London' => '格林尼治标准时间（伦敦）',
        'Europe/Luxembourg' => '中欧时间（卢森堡）',
        'Europe/Madrid' => '中欧时间（马德里）',
        'Europe/Malta' => '中欧时间（马耳他）',
        'Europe/Mariehamn' => '东欧时间（玛丽港）',
        'Europe/Minsk' => '莫斯科时间（明斯克）',
        'Europe/Monaco' => '中欧时间（摩纳哥）',
        'Europe/Moscow' => '莫斯科时间',
        'Europe/Oslo' => '中欧时间（奥斯陆）',
        'Europe/Paris' => '中欧时间（巴黎）',
        'Europe/Podgorica' => '中欧时间（波德戈里察）',
        'Europe/Prague' => '中欧时间（布拉格）',
        'Europe/Riga' => '东欧时间（里加）',
        'Europe/Rome' => '中欧时间（罗马）',
        'Europe/Samara' => '萨马拉时间',
        'Europe/San_Marino' => '中欧时间（圣马力诺）',
        'Europe/Sarajevo' => '中欧时间（萨拉热窝）',
        'Europe/Saratov' => '萨马拉时间（萨拉托夫）',
        'Europe/Simferopol' => '莫斯科时间（辛菲罗波尔）',
        'Europe/Skopje' => '中欧时间（斯科普里）',
        'Europe/Sofia' => '东欧时间（索非亚）',
        'Europe/Stockholm' => '中欧时间（斯德哥尔摩）',
        'Europe/Tallinn' => '东欧时间（塔林）',
        'Europe/Tirane' => '中欧时间（地拉那）',
        'Europe/Ulyanovsk' => '萨马拉时间（乌里扬诺夫斯克）',
        'Europe/Vaduz' => '中欧时间（瓦杜兹）',
        'Europe/Vatican' => '中欧时间（梵蒂冈）',
        'Europe/Vienna' => '中欧时间（维也纳）',
        'Europe/Vilnius' => '东欧时间（维尔纽斯）',
        'Europe/Volgograd' => '莫斯科时间（伏尔加格勒）',
        'Europe/Warsaw' => '中欧时间（华沙）',
        'Europe/Zagreb' => '中欧时间（萨格勒布）',
        'Europe/Zurich' => '中欧时间（苏黎世）',
        'Indian/Antananarivo' => '东部非洲时间（安塔那那利佛）',
        'Indian/Chagos' => '印度洋时间（查戈斯）',
        'Indian/Christmas' => '圣诞岛时间',
        'Indian/Cocos' => '科科斯群岛时间（可可斯）',
        'Indian/Comoro' => '东部非洲时间（科摩罗）',
        'Indian/Kerguelen' => '法属南方和南极领地时间（凯尔盖朗）',
        'Indian/Mahe' => '塞舌尔时间（马埃岛）',
        'Indian/Maldives' => '马尔代夫时间',
        'Indian/Mauritius' => '毛里求斯时间',
        'Indian/Mayotte' => '东部非洲时间（马约特）',
        'Indian/Reunion' => '留尼汪时间',
        'Pacific/Apia' => '阿皮亚时间',
        'Pacific/Auckland' => '新西兰时间（奥克兰）',
        'Pacific/Bougainville' => '巴布亚新几内亚时间（布干维尔）',
        'Pacific/Chatham' => '查塔姆时间',
        'Pacific/Easter' => '复活节岛时间',
        'Pacific/Efate' => '瓦努阿图时间（埃法特）',
        'Pacific/Enderbury' => '菲尼克斯群岛时间（坎顿岛）',
        'Pacific/Kanton' => '菲尼克斯群岛时间（坎顿岛）',
        'Pacific/Fakaofo' => '托克劳时间（法考福）',
        'Pacific/Fiji' => '斐济时间',
        'Pacific/Funafuti' => '图瓦卢时间（富纳富提）',
        'Pacific/Galapagos' => '科隆群岛时间',
        'Pacific/Gambier' => '甘比尔时间',
        'Pacific/Guadalcanal' => '所罗门群岛时间（瓜达尔卡纳尔）',
        'Pacific/Guam' => '查莫罗时间（关岛）',
        'Pacific/Honolulu' => '夏威夷-阿留申标准时间（檀香山）',
        'Pacific/Kiritimati' => '莱恩群岛时间（基里地马地岛）',
        'Pacific/Kosrae' => '科斯雷时间（库赛埃）',
        'Pacific/Kwajalein' => '马绍尔群岛时间（夸贾林）',
        'Pacific/Majuro' => '马绍尔群岛时间（马朱罗）',
        'Pacific/Marquesas' => '马克萨斯群岛时间',
        'Pacific/Midway' => '萨摩亚时间（中途岛）',
        'Pacific/Nauru' => '瑙鲁时间',
        'Pacific/Niue' => '纽埃时间',
        'Pacific/Norfolk' => '诺福克岛时间',
        'Pacific/Noumea' => '新喀里多尼亚时间（努美阿）',
        'Pacific/Pago_Pago' => '萨摩亚时间（帕果帕果）',
        'Pacific/Palau' => '帕劳时间',
        'Pacific/Pitcairn' => '皮特凯恩时间',
        'Pacific/Ponape' => '波纳佩时间（波纳佩岛）',
        'Pacific/Pohnpei' => '波纳佩时间（波纳佩岛）',
        'Pacific/Port_Moresby' => '巴布亚新几内亚时间（莫尔兹比港）',
        'Pacific/Rarotonga' => '库克群岛时间（拉罗汤加）',
        'Pacific/Saipan' => '查莫罗时间（塞班）',
        'Pacific/Tahiti' => '塔希提岛时间',
        'Pacific/Tarawa' => '吉尔伯特群岛时间（塔拉瓦）',
        'Pacific/Tongatapu' => '汤加时间（东加塔布）',
        'Pacific/Truk' => '楚克时间（特鲁克群岛）',
        'Pacific/Chuuk' => '楚克时间（特鲁克群岛）',
        'Pacific/Wake' => '威克岛时间',
        'Pacific/Wallis' => '瓦利斯和富图纳时间',
    ],
    'Meta' => [],
];
