<?php

return [
    'Names' => [
        'af' => 'африкаанс',
        'af_NA' => 'африкаанс (Намибия)',
        'af_ZA' => 'африкаанс (Южно-Африканская Республика)',
        'ak' => 'акан',
        'ak_GH' => 'акан (Гана)',
        'am' => 'амхарский',
        'am_ET' => 'амхарский (Эфиопия)',
        'ar' => 'арабский',
        'ar_001' => 'арабский (весь мир)',
        'ar_AE' => 'арабский (ОАЭ)',
        'ar_BH' => 'арабский (Бахрейн)',
        'ar_DJ' => 'арабский (Джибути)',
        'ar_DZ' => 'арабский (Алжир)',
        'ar_EG' => 'арабский (Египет)',
        'ar_EH' => 'арабский (Западная Сахара)',
        'ar_ER' => 'арабский (Эритрея)',
        'ar_IL' => 'арабский (Израиль)',
        'ar_IQ' => 'арабский (Ирак)',
        'ar_JO' => 'арабский (Иордания)',
        'ar_KM' => 'арабский (Коморы)',
        'ar_KW' => 'арабский (Кувейт)',
        'ar_LB' => 'арабский (Ливан)',
        'ar_LY' => 'арабский (Ливия)',
        'ar_MA' => 'арабский (Марокко)',
        'ar_MR' => 'арабский (Мавритания)',
        'ar_OM' => 'арабский (Оман)',
        'ar_PS' => 'арабский (Палестинские территории)',
        'ar_QA' => 'арабский (Катар)',
        'ar_SA' => 'арабский (Саудовская Аравия)',
        'ar_SD' => 'арабский (Судан)',
        'ar_SO' => 'арабский (Сомали)',
        'ar_SS' => 'арабский (Южный Судан)',
        'ar_SY' => 'арабский (Сирия)',
        'ar_TD' => 'арабский (Чад)',
        'ar_TN' => 'арабский (Тунис)',
        'ar_YE' => 'арабский (Йемен)',
        'as' => 'ассамский',
        'as_IN' => 'ассамский (Индия)',
        'az' => 'азербайджанский',
        'az_AZ' => 'азербайджанский (Азербайджан)',
        'az_Cyrl' => 'азербайджанский (кириллица)',
        'az_Cyrl_AZ' => 'азербайджанский (кириллица, Азербайджан)',
        'az_Latn' => 'азербайджанский (латиница)',
        'az_Latn_AZ' => 'азербайджанский (латиница, Азербайджан)',
        'ba' => 'башкирский',
        'ba_RU' => 'башкирский (Россия)',
        'be' => 'белорусский',
        'be_BY' => 'белорусский (Беларусь)',
        'bg' => 'болгарский',
        'bg_BG' => 'болгарский (Болгария)',
        'bm' => 'бамбара',
        'bm_ML' => 'бамбара (Мали)',
        'bn' => 'бенгальский',
        'bn_BD' => 'бенгальский (Бангладеш)',
        'bn_IN' => 'бенгальский (Индия)',
        'bo' => 'тибетский',
        'bo_CN' => 'тибетский (Китай)',
        'bo_IN' => 'тибетский (Индия)',
        'br' => 'бретонский',
        'br_FR' => 'бретонский (Франция)',
        'bs' => 'боснийский',
        'bs_BA' => 'боснийский (Босния и Герцеговина)',
        'bs_Cyrl' => 'боснийский (кириллица)',
        'bs_Cyrl_BA' => 'боснийский (кириллица, Босния и Герцеговина)',
        'bs_Latn' => 'боснийский (латиница)',
        'bs_Latn_BA' => 'боснийский (латиница, Босния и Герцеговина)',
        'ca' => 'каталанский',
        'ca_AD' => 'каталанский (Андорра)',
        'ca_ES' => 'каталанский (Испания)',
        'ca_FR' => 'каталанский (Франция)',
        'ca_IT' => 'каталанский (Италия)',
        'ce' => 'чеченский',
        'ce_RU' => 'чеченский (Россия)',
        'cs' => 'чешский',
        'cs_CZ' => 'чешский (Чехия)',
        'cv' => 'чувашский',
        'cv_RU' => 'чувашский (Россия)',
        'cy' => 'валлийский',
        'cy_GB' => 'валлийский (Великобритания)',
        'da' => 'датский',
        'da_DK' => 'датский (Дания)',
        'da_GL' => 'датский (Гренландия)',
        'de' => 'немецкий',
        'de_AT' => 'немецкий (Австрия)',
        'de_BE' => 'немецкий (Бельгия)',
        'de_CH' => 'немецкий (Швейцария)',
        'de_DE' => 'немецкий (Германия)',
        'de_IT' => 'немецкий (Италия)',
        'de_LI' => 'немецкий (Лихтенштейн)',
        'de_LU' => 'немецкий (Люксембург)',
        'dz' => 'дзонг-кэ',
        'dz_BT' => 'дзонг-кэ (Бутан)',
        'ee' => 'эве',
        'ee_GH' => 'эве (Гана)',
        'ee_TG' => 'эве (Того)',
        'el' => 'греческий',
        'el_CY' => 'греческий (Кипр)',
        'el_GR' => 'греческий (Греция)',
        'en' => 'английский',
        'en_001' => 'английский (весь мир)',
        'en_150' => 'английский (Европа)',
        'en_AE' => 'английский (ОАЭ)',
        'en_AG' => 'английский (Антигуа и Барбуда)',
        'en_AI' => 'английский (Ангилья)',
        'en_AS' => 'английский (Американское Самоа)',
        'en_AT' => 'английский (Австрия)',
        'en_AU' => 'английский (Австралия)',
        'en_BB' => 'английский (Барбадос)',
        'en_BE' => 'английский (Бельгия)',
        'en_BI' => 'английский (Бурунди)',
        'en_BM' => 'английский (Бермудские о-ва)',
        'en_BS' => 'английский (Багамы)',
        'en_BW' => 'английский (Ботсвана)',
        'en_BZ' => 'английский (Белиз)',
        'en_CA' => 'английский (Канада)',
        'en_CC' => 'английский (Кокосовые о-ва)',
        'en_CH' => 'английский (Швейцария)',
        'en_CK' => 'английский (о-ва Кука)',
        'en_CM' => 'английский (Камерун)',
        'en_CX' => 'английский (о-в Рождества)',
        'en_CY' => 'английский (Кипр)',
        'en_CZ' => 'английский (Чехия)',
        'en_DE' => 'английский (Германия)',
        'en_DK' => 'английский (Дания)',
        'en_DM' => 'английский (Доминика)',
        'en_EE' => 'английский (Эстония)',
        'en_ER' => 'английский (Эритрея)',
        'en_ES' => 'английский (Испания)',
        'en_FI' => 'английский (Финляндия)',
        'en_FJ' => 'английский (Фиджи)',
        'en_FK' => 'английский (Фолклендские о-ва)',
        'en_FM' => 'английский (Федеративные Штаты Микронезии)',
        'en_FR' => 'английский (Франция)',
        'en_GB' => 'английский (Великобритания)',
        'en_GD' => 'английский (Гренада)',
        'en_GE' => 'английский (Грузия)',
        'en_GG' => 'английский (Гернси)',
        'en_GH' => 'английский (Гана)',
        'en_GI' => 'английский (Гибралтар)',
        'en_GM' => 'английский (Гамбия)',
        'en_GS' => 'английский (Южная Георгия и Южные Сандвичевы о-ва)',
        'en_GU' => 'английский (Гуам)',
        'en_GY' => 'английский (Гайана)',
        'en_HK' => 'английский (Гонконг [САР])',
        'en_HU' => 'английский (Венгрия)',
        'en_ID' => 'английский (Индонезия)',
        'en_IE' => 'английский (Ирландия)',
        'en_IL' => 'английский (Израиль)',
        'en_IM' => 'английский (о-в Мэн)',
        'en_IN' => 'английский (Индия)',
        'en_IO' => 'английский (Британская территория в Индийском океане)',
        'en_IT' => 'английский (Италия)',
        'en_JE' => 'английский (Джерси)',
        'en_JM' => 'английский (Ямайка)',
        'en_JP' => 'английский (Япония)',
        'en_KE' => 'английский (Кения)',
        'en_KI' => 'английский (Кирибати)',
        'en_KN' => 'английский (Сент-Китс и Невис)',
        'en_KY' => 'английский (о-ва Кайман)',
        'en_LC' => 'английский (Сент-Люсия)',
        'en_LR' => 'английский (Либерия)',
        'en_LS' => 'английский (Лесото)',
        'en_LT' => 'английский (Литва)',
        'en_LV' => 'английский (Латвия)',
        'en_MG' => 'английский (Мадагаскар)',
        'en_MH' => 'английский (Маршалловы о-ва)',
        'en_MO' => 'английский (Макао [САР])',
        'en_MP' => 'английский (Северные Марианские о-ва)',
        'en_MS' => 'английский (Монтсеррат)',
        'en_MT' => 'английский (Мальта)',
        'en_MU' => 'английский (Маврикий)',
        'en_MV' => 'английский (Мальдивы)',
        'en_MW' => 'английский (Малави)',
        'en_MY' => 'английский (Малайзия)',
        'en_NA' => 'английский (Намибия)',
        'en_NF' => 'английский (о-в Норфолк)',
        'en_NG' => 'английский (Нигерия)',
        'en_NL' => 'английский (Нидерланды)',
        'en_NO' => 'английский (Норвегия)',
        'en_NR' => 'английский (Науру)',
        'en_NU' => 'английский (Ниуэ)',
        'en_NZ' => 'английский (Новая Зеландия)',
        'en_PG' => 'английский (Папуа — Новая Гвинея)',
        'en_PH' => 'английский (Филиппины)',
        'en_PK' => 'английский (Пакистан)',
        'en_PL' => 'английский (Польша)',
        'en_PN' => 'английский (о-ва Питкэрн)',
        'en_PR' => 'английский (Пуэрто-Рико)',
        'en_PT' => 'английский (Португалия)',
        'en_PW' => 'английский (Палау)',
        'en_RO' => 'английский (Румыния)',
        'en_RW' => 'английский (Руанда)',
        'en_SB' => 'английский (Соломоновы о-ва)',
        'en_SC' => 'английский (Сейшельские о-ва)',
        'en_SD' => 'английский (Судан)',
        'en_SE' => 'английский (Швеция)',
        'en_SG' => 'английский (Сингапур)',
        'en_SH' => 'английский (о-в Св. Елены)',
        'en_SI' => 'английский (Словения)',
        'en_SK' => 'английский (Словакия)',
        'en_SL' => 'английский (Сьерра-Леоне)',
        'en_SS' => 'английский (Южный Судан)',
        'en_SX' => 'английский (Синт-Мартен)',
        'en_SZ' => 'английский (Эсватини)',
        'en_TC' => 'английский (Тёркс и Кайкос)',
        'en_TK' => 'английский (Токелау)',
        'en_TO' => 'английский (Тонга)',
        'en_TT' => 'английский (Тринидад и Тобаго)',
        'en_TV' => 'английский (Тувалу)',
        'en_TZ' => 'английский (Танзания)',
        'en_UA' => 'английский (Украина)',
        'en_UG' => 'английский (Уганда)',
        'en_UM' => 'английский (Внешние малые о-ва [США])',
        'en_US' => 'английский (Соединенные Штаты)',
        'en_VC' => 'английский (Сент-Винсент и Гренадины)',
        'en_VG' => 'английский (Виргинские о-ва [Великобритания])',
        'en_VI' => 'английский (Виргинские о-ва [США])',
        'en_VU' => 'английский (Вануату)',
        'en_WS' => 'английский (Самоа)',
        'en_ZA' => 'английский (Южно-Африканская Республика)',
        'en_ZM' => 'английский (Замбия)',
        'en_ZW' => 'английский (Зимбабве)',
        'eo' => 'эсперанто',
        'eo_001' => 'эсперанто (весь мир)',
        'es' => 'испанский',
        'es_419' => 'испанский (Латинская Америка)',
        'es_AR' => 'испанский (Аргентина)',
        'es_BO' => 'испанский (Боливия)',
        'es_BR' => 'испанский (Бразилия)',
        'es_BZ' => 'испанский (Белиз)',
        'es_CL' => 'испанский (Чили)',
        'es_CO' => 'испанский (Колумбия)',
        'es_CR' => 'испанский (Коста-Рика)',
        'es_CU' => 'испанский (Куба)',
        'es_DO' => 'испанский (Доминиканская Республика)',
        'es_EC' => 'испанский (Эквадор)',
        'es_ES' => 'испанский (Испания)',
        'es_GQ' => 'испанский (Экваториальная Гвинея)',
        'es_GT' => 'испанский (Гватемала)',
        'es_HN' => 'испанский (Гондурас)',
        'es_MX' => 'испанский (Мексика)',
        'es_NI' => 'испанский (Никарагуа)',
        'es_PA' => 'испанский (Панама)',
        'es_PE' => 'испанский (Перу)',
        'es_PH' => 'испанский (Филиппины)',
        'es_PR' => 'испанский (Пуэрто-Рико)',
        'es_PY' => 'испанский (Парагвай)',
        'es_SV' => 'испанский (Сальвадор)',
        'es_US' => 'испанский (Соединенные Штаты)',
        'es_UY' => 'испанский (Уругвай)',
        'es_VE' => 'испанский (Венесуэла)',
        'et' => 'эстонский',
        'et_EE' => 'эстонский (Эстония)',
        'eu' => 'баскский',
        'eu_ES' => 'баскский (Испания)',
        'fa' => 'персидский',
        'fa_AF' => 'персидский (Афганистан)',
        'fa_IR' => 'персидский (Иран)',
        'ff' => 'фулах',
        'ff_Adlm' => 'фулах (адлам)',
        'ff_Adlm_BF' => 'фулах (адлам, Буркина-Фасо)',
        'ff_Adlm_CM' => 'фулах (адлам, Камерун)',
        'ff_Adlm_GH' => 'фулах (адлам, Гана)',
        'ff_Adlm_GM' => 'фулах (адлам, Гамбия)',
        'ff_Adlm_GN' => 'фулах (адлам, Гвинея)',
        'ff_Adlm_GW' => 'фулах (адлам, Гвинея-Бисау)',
        'ff_Adlm_LR' => 'фулах (адлам, Либерия)',
        'ff_Adlm_MR' => 'фулах (адлам, Мавритания)',
        'ff_Adlm_NE' => 'фулах (адлам, Нигер)',
        'ff_Adlm_NG' => 'фулах (адлам, Нигерия)',
        'ff_Adlm_SL' => 'фулах (адлам, Сьерра-Леоне)',
        'ff_Adlm_SN' => 'фулах (адлам, Сенегал)',
        'ff_CM' => 'фулах (Камерун)',
        'ff_GN' => 'фулах (Гвинея)',
        'ff_Latn' => 'фулах (латиница)',
        'ff_Latn_BF' => 'фулах (латиница, Буркина-Фасо)',
        'ff_Latn_CM' => 'фулах (латиница, Камерун)',
        'ff_Latn_GH' => 'фулах (латиница, Гана)',
        'ff_Latn_GM' => 'фулах (латиница, Гамбия)',
        'ff_Latn_GN' => 'фулах (латиница, Гвинея)',
        'ff_Latn_GW' => 'фулах (латиница, Гвинея-Бисау)',
        'ff_Latn_LR' => 'фулах (латиница, Либерия)',
        'ff_Latn_MR' => 'фулах (латиница, Мавритания)',
        'ff_Latn_NE' => 'фулах (латиница, Нигер)',
        'ff_Latn_NG' => 'фулах (латиница, Нигерия)',
        'ff_Latn_SL' => 'фулах (латиница, Сьерра-Леоне)',
        'ff_Latn_SN' => 'фулах (латиница, Сенегал)',
        'ff_MR' => 'фулах (Мавритания)',
        'ff_SN' => 'фулах (Сенегал)',
        'fi' => 'финский',
        'fi_FI' => 'финский (Финляндия)',
        'fo' => 'фарерский',
        'fo_DK' => 'фарерский (Дания)',
        'fo_FO' => 'фарерский (Фарерские о-ва)',
        'fr' => 'французский',
        'fr_BE' => 'французский (Бельгия)',
        'fr_BF' => 'французский (Буркина-Фасо)',
        'fr_BI' => 'французский (Бурунди)',
        'fr_BJ' => 'французский (Бенин)',
        'fr_BL' => 'французский (Сен-Бартелеми)',
        'fr_CA' => 'французский (Канада)',
        'fr_CD' => 'французский (Конго - Киншаса)',
        'fr_CF' => 'французский (Центрально-Африканская Республика)',
        'fr_CG' => 'французский (Конго - Браззавиль)',
        'fr_CH' => 'французский (Швейцария)',
        'fr_CI' => 'французский (Кот-д’Ивуар)',
        'fr_CM' => 'французский (Камерун)',
        'fr_DJ' => 'французский (Джибути)',
        'fr_DZ' => 'французский (Алжир)',
        'fr_FR' => 'французский (Франция)',
        'fr_GA' => 'французский (Габон)',
        'fr_GF' => 'французский (Французская Гвиана)',
        'fr_GN' => 'французский (Гвинея)',
        'fr_GP' => 'французский (Гваделупа)',
        'fr_GQ' => 'французский (Экваториальная Гвинея)',
        'fr_HT' => 'французский (Гаити)',
        'fr_KM' => 'французский (Коморы)',
        'fr_LU' => 'французский (Люксембург)',
        'fr_MA' => 'французский (Марокко)',
        'fr_MC' => 'французский (Монако)',
        'fr_MF' => 'французский (Сен-Мартен)',
        'fr_MG' => 'французский (Мадагаскар)',
        'fr_ML' => 'французский (Мали)',
        'fr_MQ' => 'французский (Мартиника)',
        'fr_MR' => 'французский (Мавритания)',
        'fr_MU' => 'французский (Маврикий)',
        'fr_NC' => 'французский (Новая Каледония)',
        'fr_NE' => 'французский (Нигер)',
        'fr_PF' => 'французский (Французская Полинезия)',
        'fr_PM' => 'французский (Сен-Пьер и Микелон)',
        'fr_RE' => 'французский (Реюньон)',
        'fr_RW' => 'французский (Руанда)',
        'fr_SC' => 'французский (Сейшельские о-ва)',
        'fr_SN' => 'французский (Сенегал)',
        'fr_SY' => 'французский (Сирия)',
        'fr_TD' => 'французский (Чад)',
        'fr_TG' => 'французский (Того)',
        'fr_TN' => 'французский (Тунис)',
        'fr_VU' => 'французский (Вануату)',
        'fr_WF' => 'французский (Уоллис и Футуна)',
        'fr_YT' => 'французский (Майотта)',
        'fy' => 'западнофризский',
        'fy_NL' => 'западнофризский (Нидерланды)',
        'ga' => 'ирландский',
        'ga_GB' => 'ирландский (Великобритания)',
        'ga_IE' => 'ирландский (Ирландия)',
        'gd' => 'гэльский',
        'gd_GB' => 'гэльский (Великобритания)',
        'gl' => 'галисийский',
        'gl_ES' => 'галисийский (Испания)',
        'gu' => 'гуджарати',
        'gu_IN' => 'гуджарати (Индия)',
        'gv' => 'мэнский',
        'gv_IM' => 'мэнский (о-в Мэн)',
        'ha' => 'хауса',
        'ha_GH' => 'хауса (Гана)',
        'ha_NE' => 'хауса (Нигер)',
        'ha_NG' => 'хауса (Нигерия)',
        'he' => 'иврит',
        'he_IL' => 'иврит (Израиль)',
        'hi' => 'хинди',
        'hi_IN' => 'хинди (Индия)',
        'hi_Latn' => 'хинди (латиница)',
        'hi_Latn_IN' => 'хинди (латиница, Индия)',
        'hr' => 'хорватский',
        'hr_BA' => 'хорватский (Босния и Герцеговина)',
        'hr_HR' => 'хорватский (Хорватия)',
        'hu' => 'венгерский',
        'hu_HU' => 'венгерский (Венгрия)',
        'hy' => 'армянский',
        'hy_AM' => 'армянский (Армения)',
        'ia' => 'интерлингва',
        'ia_001' => 'интерлингва (весь мир)',
        'id' => 'индонезийский',
        'id_ID' => 'индонезийский (Индонезия)',
        'ie' => 'интерлингве',
        'ie_EE' => 'интерлингве (Эстония)',
        'ig' => 'игбо',
        'ig_NG' => 'игбо (Нигерия)',
        'ii' => 'носу',
        'ii_CN' => 'носу (Китай)',
        'is' => 'исландский',
        'is_IS' => 'исландский (Исландия)',
        'it' => 'итальянский',
        'it_CH' => 'итальянский (Швейцария)',
        'it_IT' => 'итальянский (Италия)',
        'it_SM' => 'итальянский (Сан-Марино)',
        'it_VA' => 'итальянский (Ватикан)',
        'ja' => 'японский',
        'ja_JP' => 'японский (Япония)',
        'jv' => 'яванский',
        'jv_ID' => 'яванский (Индонезия)',
        'ka' => 'грузинский',
        'ka_GE' => 'грузинский (Грузия)',
        'ki' => 'кикуйю',
        'ki_KE' => 'кикуйю (Кения)',
        'kk' => 'казахский',
        'kk_Arab' => 'казахский (арабица)',
        'kk_Arab_CN' => 'казахский (арабица, Китай)',
        'kk_Cyrl' => 'казахский (кириллица)',
        'kk_Cyrl_KZ' => 'казахский (кириллица, Казахстан)',
        'kk_KZ' => 'казахский (Казахстан)',
        'kl' => 'гренландский',
        'kl_GL' => 'гренландский (Гренландия)',
        'km' => 'кхмерский',
        'km_KH' => 'кхмерский (Камбоджа)',
        'kn' => 'каннада',
        'kn_IN' => 'каннада (Индия)',
        'ko' => 'корейский',
        'ko_CN' => 'корейский (Китай)',
        'ko_KP' => 'корейский (КНДР)',
        'ko_KR' => 'корейский (Республика Корея)',
        'ks' => 'кашмири',
        'ks_Arab' => 'кашмири (арабица)',
        'ks_Arab_IN' => 'кашмири (арабица, Индия)',
        'ks_Deva' => 'кашмири (деванагари)',
        'ks_Deva_IN' => 'кашмири (деванагари, Индия)',
        'ks_IN' => 'кашмири (Индия)',
        'ku' => 'курдский',
        'ku_Latn' => 'курдский (латиница)',
        'ku_Latn_IQ' => 'курдский (латиница, Ирак)',
        'ku_Latn_SY' => 'курдский (латиница, Сирия)',
        'ku_Latn_TR' => 'курдский (латиница, Турция)',
        'ku_SY' => 'курдский (Сирия)',
        'ku_TR' => 'курдский (Турция)',
        'kw' => 'корнский',
        'kw_GB' => 'корнский (Великобритания)',
        'ky' => 'киргизский',
        'ky_KG' => 'киргизский (Киргизия)',
        'lb' => 'люксембургский',
        'lb_LU' => 'люксембургский (Люксембург)',
        'lg' => 'ганда',
        'lg_UG' => 'ганда (Уганда)',
        'ln' => 'лингала',
        'ln_AO' => 'лингала (Ангола)',
        'ln_CD' => 'лингала (Конго - Киншаса)',
        'ln_CF' => 'лингала (Центрально-Африканская Республика)',
        'ln_CG' => 'лингала (Конго - Браззавиль)',
        'lo' => 'лаосский',
        'lo_LA' => 'лаосский (Лаос)',
        'lt' => 'литовский',
        'lt_LT' => 'литовский (Литва)',
        'lu' => 'луба-катанга',
        'lu_CD' => 'луба-катанга (Конго - Киншаса)',
        'lv' => 'латышский',
        'lv_LV' => 'латышский (Латвия)',
        'mg' => 'малагасийский',
        'mg_MG' => 'малагасийский (Мадагаскар)',
        'mi' => 'маори',
        'mi_NZ' => 'маори (Новая Зеландия)',
        'mk' => 'македонский',
        'mk_MK' => 'македонский (Северная Македония)',
        'ml' => 'малаялам',
        'ml_IN' => 'малаялам (Индия)',
        'mn' => 'монгольский',
        'mn_MN' => 'монгольский (Монголия)',
        'mr' => 'маратхи',
        'mr_IN' => 'маратхи (Индия)',
        'ms' => 'малайский',
        'ms_BN' => 'малайский (Бруней)',
        'ms_ID' => 'малайский (Индонезия)',
        'ms_MY' => 'малайский (Малайзия)',
        'ms_SG' => 'малайский (Сингапур)',
        'mt' => 'мальтийский',
        'mt_MT' => 'мальтийский (Мальта)',
        'my' => 'бирманский',
        'my_MM' => 'бирманский (Мьянма [Бирма])',
        'nb' => 'норвежский букмол',
        'nb_NO' => 'норвежский букмол (Норвегия)',
        'nb_SJ' => 'норвежский букмол (Шпицберген и Ян-Майен)',
        'nd' => 'северный ндебеле',
        'nd_ZW' => 'северный ндебеле (Зимбабве)',
        'ne' => 'непальский',
        'ne_IN' => 'непальский (Индия)',
        'ne_NP' => 'непальский (Непал)',
        'nl' => 'нидерландский',
        'nl_AW' => 'нидерландский (Аруба)',
        'nl_BE' => 'нидерландский (Бельгия)',
        'nl_BQ' => 'нидерландский (Бонэйр, Синт-Эстатиус и Саба)',
        'nl_CW' => 'нидерландский (Кюрасао)',
        'nl_NL' => 'нидерландский (Нидерланды)',
        'nl_SR' => 'нидерландский (Суринам)',
        'nl_SX' => 'нидерландский (Синт-Мартен)',
        'nn' => 'нюнорск',
        'nn_NO' => 'нюнорск (Норвегия)',
        'no' => 'норвежский',
        'no_NO' => 'норвежский (Норвегия)',
        'oc' => 'окситанский',
        'oc_ES' => 'окситанский (Испания)',
        'oc_FR' => 'окситанский (Франция)',
        'om' => 'оромо',
        'om_ET' => 'оромо (Эфиопия)',
        'om_KE' => 'оромо (Кения)',
        'or' => 'ория',
        'or_IN' => 'ория (Индия)',
        'os' => 'осетинский',
        'os_GE' => 'осетинский (Грузия)',
        'os_RU' => 'осетинский (Россия)',
        'pa' => 'панджаби',
        'pa_Arab' => 'панджаби (арабица)',
        'pa_Arab_PK' => 'панджаби (арабица, Пакистан)',
        'pa_Guru' => 'панджаби (гурмукхи)',
        'pa_Guru_IN' => 'панджаби (гурмукхи, Индия)',
        'pa_IN' => 'панджаби (Индия)',
        'pa_PK' => 'панджаби (Пакистан)',
        'pl' => 'польский',
        'pl_PL' => 'польский (Польша)',
        'ps' => 'пушту',
        'ps_AF' => 'пушту (Афганистан)',
        'ps_PK' => 'пушту (Пакистан)',
        'pt' => 'португальский',
        'pt_AO' => 'португальский (Ангола)',
        'pt_BR' => 'португальский (Бразилия)',
        'pt_CH' => 'португальский (Швейцария)',
        'pt_CV' => 'португальский (Кабо-Верде)',
        'pt_GQ' => 'португальский (Экваториальная Гвинея)',
        'pt_GW' => 'португальский (Гвинея-Бисау)',
        'pt_LU' => 'португальский (Люксембург)',
        'pt_MO' => 'португальский (Макао [САР])',
        'pt_MZ' => 'португальский (Мозамбик)',
        'pt_PT' => 'португальский (Португалия)',
        'pt_ST' => 'португальский (Сан-Томе и Принсипи)',
        'pt_TL' => 'португальский (Восточный Тимор)',
        'qu' => 'кечуа',
        'qu_BO' => 'кечуа (Боливия)',
        'qu_EC' => 'кечуа (Эквадор)',
        'qu_PE' => 'кечуа (Перу)',
        'rm' => 'романшский',
        'rm_CH' => 'романшский (Швейцария)',
        'rn' => 'рунди',
        'rn_BI' => 'рунди (Бурунди)',
        'ro' => 'румынский',
        'ro_MD' => 'румынский (Молдова)',
        'ro_RO' => 'румынский (Румыния)',
        'ru' => 'русский',
        'ru_BY' => 'русский (Беларусь)',
        'ru_KG' => 'русский (Киргизия)',
        'ru_KZ' => 'русский (Казахстан)',
        'ru_MD' => 'русский (Молдова)',
        'ru_RU' => 'русский (Россия)',
        'ru_UA' => 'русский (Украина)',
        'rw' => 'киньяруанда',
        'rw_RW' => 'киньяруанда (Руанда)',
        'sa' => 'санскрит',
        'sa_IN' => 'санскрит (Индия)',
        'sc' => 'сардинский',
        'sc_IT' => 'сардинский (Италия)',
        'sd' => 'синдхи',
        'sd_Arab' => 'синдхи (арабица)',
        'sd_Arab_PK' => 'синдхи (арабица, Пакистан)',
        'sd_Deva' => 'синдхи (деванагари)',
        'sd_Deva_IN' => 'синдхи (деванагари, Индия)',
        'sd_IN' => 'синдхи (Индия)',
        'sd_PK' => 'синдхи (Пакистан)',
        'se' => 'северносаамский',
        'se_FI' => 'северносаамский (Финляндия)',
        'se_NO' => 'северносаамский (Норвегия)',
        'se_SE' => 'северносаамский (Швеция)',
        'sg' => 'санго',
        'sg_CF' => 'санго (Центрально-Африканская Республика)',
        'sh' => 'сербскохорватский',
        'sh_BA' => 'сербскохорватский (Босния и Герцеговина)',
        'si' => 'сингальский',
        'si_LK' => 'сингальский (Шри-Ланка)',
        'sk' => 'словацкий',
        'sk_SK' => 'словацкий (Словакия)',
        'sl' => 'словенский',
        'sl_SI' => 'словенский (Словения)',
        'sn' => 'шона',
        'sn_ZW' => 'шона (Зимбабве)',
        'so' => 'сомали',
        'so_DJ' => 'сомали (Джибути)',
        'so_ET' => 'сомали (Эфиопия)',
        'so_KE' => 'сомали (Кения)',
        'so_SO' => 'сомали (Сомали)',
        'sq' => 'албанский',
        'sq_AL' => 'албанский (Албания)',
        'sq_MK' => 'албанский (Северная Македония)',
        'sr' => 'сербский',
        'sr_BA' => 'сербский (Босния и Герцеговина)',
        'sr_Cyrl' => 'сербский (кириллица)',
        'sr_Cyrl_BA' => 'сербский (кириллица, Босния и Герцеговина)',
        'sr_Cyrl_ME' => 'сербский (кириллица, Черногория)',
        'sr_Cyrl_RS' => 'сербский (кириллица, Сербия)',
        'sr_Latn' => 'сербский (латиница)',
        'sr_Latn_BA' => 'сербский (латиница, Босния и Герцеговина)',
        'sr_Latn_ME' => 'сербский (латиница, Черногория)',
        'sr_Latn_RS' => 'сербский (латиница, Сербия)',
        'sr_ME' => 'сербский (Черногория)',
        'sr_RS' => 'сербский (Сербия)',
        'st' => 'южный сото',
        'st_LS' => 'южный сото (Лесото)',
        'st_ZA' => 'южный сото (Южно-Африканская Республика)',
        'su' => 'сунданский',
        'su_ID' => 'сунданский (Индонезия)',
        'su_Latn' => 'сунданский (латиница)',
        'su_Latn_ID' => 'сунданский (латиница, Индонезия)',
        'sv' => 'шведский',
        'sv_AX' => 'шведский (Аландские о-ва)',
        'sv_FI' => 'шведский (Финляндия)',
        'sv_SE' => 'шведский (Швеция)',
        'sw' => 'суахили',
        'sw_CD' => 'суахили (Конго - Киншаса)',
        'sw_KE' => 'суахили (Кения)',
        'sw_TZ' => 'суахили (Танзания)',
        'sw_UG' => 'суахили (Уганда)',
        'ta' => 'тамильский',
        'ta_IN' => 'тамильский (Индия)',
        'ta_LK' => 'тамильский (Шри-Ланка)',
        'ta_MY' => 'тамильский (Малайзия)',
        'ta_SG' => 'тамильский (Сингапур)',
        'te' => 'телугу',
        'te_IN' => 'телугу (Индия)',
        'tg' => 'таджикский',
        'tg_TJ' => 'таджикский (Таджикистан)',
        'th' => 'тайский',
        'th_TH' => 'тайский (Таиланд)',
        'ti' => 'тигринья',
        'ti_ER' => 'тигринья (Эритрея)',
        'ti_ET' => 'тигринья (Эфиопия)',
        'tk' => 'туркменский',
        'tk_TM' => 'туркменский (Туркменистан)',
        'tl' => 'тагалог',
        'tl_PH' => 'тагалог (Филиппины)',
        'tn' => 'тсвана',
        'tn_BW' => 'тсвана (Ботсвана)',
        'tn_ZA' => 'тсвана (Южно-Африканская Республика)',
        'to' => 'тонганский',
        'to_TO' => 'тонганский (Тонга)',
        'tr' => 'турецкий',
        'tr_CY' => 'турецкий (Кипр)',
        'tr_TR' => 'турецкий (Турция)',
        'tt' => 'татарский',
        'tt_RU' => 'татарский (Россия)',
        'ug' => 'уйгурский',
        'ug_CN' => 'уйгурский (Китай)',
        'uk' => 'украинский',
        'uk_UA' => 'украинский (Украина)',
        'ur' => 'урду',
        'ur_IN' => 'урду (Индия)',
        'ur_PK' => 'урду (Пакистан)',
        'uz' => 'узбекский',
        'uz_AF' => 'узбекский (Афганистан)',
        'uz_Arab' => 'узбекский (арабица)',
        'uz_Arab_AF' => 'узбекский (арабица, Афганистан)',
        'uz_Cyrl' => 'узбекский (кириллица)',
        'uz_Cyrl_UZ' => 'узбекский (кириллица, Узбекистан)',
        'uz_Latn' => 'узбекский (латиница)',
        'uz_Latn_UZ' => 'узбекский (латиница, Узбекистан)',
        'uz_UZ' => 'узбекский (Узбекистан)',
        'vi' => 'вьетнамский',
        'vi_VN' => 'вьетнамский (Вьетнам)',
        'wo' => 'волоф',
        'wo_SN' => 'волоф (Сенегал)',
        'xh' => 'коса',
        'xh_ZA' => 'коса (Южно-Африканская Республика)',
        'yi' => 'идиш',
        'yi_UA' => 'идиш (Украина)',
        'yo' => 'йоруба',
        'yo_BJ' => 'йоруба (Бенин)',
        'yo_NG' => 'йоруба (Нигерия)',
        'za' => 'чжуань',
        'za_CN' => 'чжуань (Китай)',
        'zh' => 'китайский',
        'zh_CN' => 'китайский (Китай)',
        'zh_HK' => 'китайский (Гонконг [САР])',
        'zh_Hans' => 'китайский (упрощенная)',
        'zh_Hans_CN' => 'китайский (упрощенная, Китай)',
        'zh_Hans_HK' => 'китайский (упрощенная, Гонконг [САР])',
        'zh_Hans_MO' => 'китайский (упрощенная, Макао [САР])',
        'zh_Hans_MY' => 'китайский (упрощенная, Малайзия)',
        'zh_Hans_SG' => 'китайский (упрощенная, Сингапур)',
        'zh_Hant' => 'китайский (традиционная)',
        'zh_Hant_HK' => 'китайский (традиционная, Гонконг [САР])',
        'zh_Hant_MO' => 'китайский (традиционная, Макао [САР])',
        'zh_Hant_MY' => 'китайский (традиционная, Малайзия)',
        'zh_Hant_TW' => 'китайский (традиционная, Тайвань)',
        'zh_MO' => 'китайский (Макао [САР])',
        'zh_SG' => 'китайский (Сингапур)',
        'zh_TW' => 'китайский (Тайвань)',
        'zu' => 'зулу',
        'zu_ZA' => 'зулу (Южно-Африканская Республика)',
    ],
];
