<?php

return [
    'Names' => [
        'de' => 'Jérman',
        'de_DE' => 'Jérman (Jérman)',
        'de_IT' => 'Jérman (Italia)',
        'en' => 'Inggris',
        'en_DE' => 'Inggris (Jérman)',
        'en_FR' => 'Inggris (Prancis)',
        'en_GB' => 'Inggris (Britania Raya)',
        'en_ID' => 'Inggris (Indonesia)',
        'en_IN' => 'Inggris (India)',
        'en_IT' => 'Inggris (Italia)',
        'en_JP' => 'Inggris (Jepang)',
        'en_US' => 'Inggris (Amérika Sarikat)',
        'es' => 'Spanyol',
        'es_BR' => 'Spanyol (Brasil)',
        'es_US' => 'Spanyol (Amérika Sarikat)',
        'fr' => 'Prancis',
        'fr_FR' => 'Prancis (Prancis)',
        'it' => 'Italia',
        'it_IT' => 'Italia (Italia)',
        'ja' => 'Jepang',
        'ja_JP' => 'Jepang (Jepang)',
        'pt' => 'Portugis',
        'pt_BR' => 'Portugis (Brasil)',
        'ru' => 'Rusia',
        'ru_RU' => 'Rusia (Rusia)',
        'su' => 'Basa Sunda',
        'su_ID' => 'Basa Sunda (Indonesia)',
        'su_Latn' => 'Basa Sunda (Latin)',
        'su_Latn_ID' => 'Basa Sunda (Latin, Indonesia)',
        'zh' => 'Tiongkok',
        'zh_CN' => 'Tiongkok (Tiongkok)',
        'zh_Hans' => 'Tiongkok (Sederhana)',
        'zh_Hans_CN' => 'Tiongkok (Sederhana, Tiongkok)',
        'zh_Hant' => 'Tiongkok (Tradisional)',
    ],
];
