<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'arab',
        'Aran' => 'nastaʼliq',
        'Armn' => 'arman',
        'Beng' => 'bengal',
        'Bopo' => 'bopomofo',
        'Brai' => 'brayl',
        'Cakm' => 'chakma',
        'Cans' => 'kanada boʻgʻin yozuvi',
        'Cher' => 'cheroki',
        'Cyrl' => 'kirill',
        'Deva' => 'devanagari',
        'Ethi' => 'habash',
        'Geor' => 'gruzin',
        'Grek' => 'grek',
        'Gujr' => 'gujarot',
        'Guru' => 'gurmukxi',
        'Hanb' => 'hanb',
        'Hang' => 'hangul',
        'Hani' => 'xitoy',
        'Hans' => 'soddalashgan',
        'Hant' => 'anʼanaviy',
        'Hebr' => 'ivrit',
        'Hira' => 'hiragana',
        'Hrkt' => 'katakana yoki hiragana',
        'Jamo' => 'jamo',
        'Jpan' => 'yapon',
        'Kana' => 'katakana',
        'Khmr' => 'kxmer',
        'Knda' => 'kannada',
        'Kore' => 'koreys',
        'Laoo' => 'laos',
        'Latn' => 'lotin',
        'Mlym' => 'malayalam',
        'Mong' => 'mongol',
        'Mtei' => 'manipuri',
        'Mymr' => 'myanma',
        'Nkoo' => 'nko',
        'Olck' => 'ol chiki',
        'Orya' => 'oriya',
        'Rohg' => 'hanifi',
        'Sinh' => 'singal',
        'Sund' => 'sundan',
        'Syrc' => 'suryoniy',
        'Taml' => 'tamil',
        'Telu' => 'telugu',
        'Tfng' => 'tifinag',
        'Thaa' => 'taana',
        'Thai' => 'tay',
        'Tibt' => 'tibet',
        'Vaii' => 'vay',
        'Yiii' => 'i',
        'Zmth' => 'matematik ifodalar',
        'Zsye' => 'emoji',
        'Zsym' => 'belgilar',
        'Zxxx' => 'yozuvsiz',
        'Zyyy' => 'umumiy',
    ],
];
