<?php

/**
 * Japanese PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Mitsuhiro Yoshida <https://mitstek.com>
 * @author Yoshi Sakai <http://bluemooninc.jp/>
 * @author Arisophy <https://github.com/arisophy/>
 * @author ARAKI Musashi <https://github.com/arakim/>
 */

$PHPMAILER_LANG['authenticate']         = 'SMTPエラー: 認証できませんでした。';
$PHPMAILER_LANG['buggy_php']            = 'ご利用のバージョンのPHPには不具合があり、メッセージが破損するおそれがあります。問題の解決は以下のいずれかを行ってください。SMTPでの送信に切り替える。php.iniのmail.add_x_headerをoffにする。MacOSまたはLinuxに切り替える。PHPバージョン7.0.17以降または7.1.3以降にアップグレードする。';
$PHPMAILER_LANG['connect_host']         = 'SMTPエラー: SMTPホストに接続できませんでした。';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTPエラー: データが受け付けられませんでした。';
$PHPMAILER_LANG['empty_message']        = 'メール本文が空です。';
$PHPMAILER_LANG['encoding']             = '不明なエンコーディング: ';
$PHPMAILER_LANG['execute']              = '実行できませんでした: ';
$PHPMAILER_LANG['extension_missing']    = '拡張機能が見つかりません: ';
$PHPMAILER_LANG['file_access']          = 'ファイルにアクセスできません: ';
$PHPMAILER_LANG['file_open']            = 'ファイルエラー: ファイルを開けません: ';
$PHPMAILER_LANG['from_failed']          = 'Fromアドレスを登録する際にエラーが発生しました: ';
$PHPMAILER_LANG['instantiate']          = 'メール関数が正常に動作しませんでした。';
$PHPMAILER_LANG['invalid_address']      = '不正なメールアドレス: ';
$PHPMAILER_LANG['invalid_header']       = '不正なヘッダー名またはその内容';
$PHPMAILER_LANG['invalid_hostentry']    = '不正なホストエントリー: ';
$PHPMAILER_LANG['invalid_host']         = '不正なホスト: ';
$PHPMAILER_LANG['mailer_not_supported'] = ' メーラーがサポートされていません。';
$PHPMAILER_LANG['provide_address']      = '少なくとも1つメールアドレスを 指定する必要があります。';
$PHPMAILER_LANG['recipients_failed']    = 'SMTPエラー: 次の受信者アドレスに 間違いがあります: ';
$PHPMAILER_LANG['signing']              = '署名エラー: ';
$PHPMAILER_LANG['smtp_code']            = 'SMTPコード: ';
$PHPMAILER_LANG['smtp_code_ex']         = 'SMTP追加情報: ';
$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP接続に失敗しました。';
$PHPMAILER_LANG['smtp_detail']          = '詳細: ';
$PHPMAILER_LANG['smtp_error']           = 'SMTPサーバーエラー: ';
$PHPMAILER_LANG['variable_set']         = '変数が存在しません: ';
