<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'שעון גריניץ׳‏ (אביג׳אן)',
        'Africa/Accra' => 'שעון גריניץ׳‏ (אקרה)',
        'Africa/Addis_Ababa' => 'שעון מזרח אפריקה (אדיס אבבה)',
        'Africa/Algiers' => 'שעון מרכז אירופה (אלג׳יר)',
        'Africa/Asmera' => 'שעון מזרח אפריקה (אסמרה)',
        'Africa/Asmara' => 'שעון מזרח אפריקה (אסמרה)',
        'Africa/Bamako' => 'שעון גריניץ׳‏ (במאקו)',
        'Africa/Bangui' => 'שעון מערב אפריקה (בנגואי)',
        'Africa/Banjul' => 'שעון גריניץ׳‏ (בנג׳ול)',
        'Africa/Bissau' => 'שעון גריניץ׳‏ (ביסאו)',
        'Africa/Blantyre' => 'שעון מרכז אפריקה (בלנטיר)',
        'Africa/Brazzaville' => 'שעון מערב אפריקה (ברזוויל)',
        'Africa/Bujumbura' => 'שעון מרכז אפריקה (בוג׳ומבורה)',
        'Africa/Cairo' => 'שעון מזרח אירופה (קהיר)',
        'Africa/Casablanca' => 'שעון מערב אירופה (קזבלנקה)',
        'Africa/Ceuta' => 'שעון מרכז אירופה (סאוטה)',
        'Africa/Conakry' => 'שעון גריניץ׳‏ (קונאקרי)',
        'Africa/Dakar' => 'שעון גריניץ׳‏ (דקאר)',
        'Africa/Dar_es_Salaam' => 'שעון מזרח אפריקה (דאר א-סלאם)',
        'Africa/Djibouti' => 'שעון מזרח אפריקה (ג׳יבוטי)',
        'Africa/Douala' => 'שעון מערב אפריקה (דואלה)',
        'Africa/El_Aaiun' => 'שעון מערב אירופה (אל עיון)',
        'Africa/Freetown' => 'שעון גריניץ׳‏ (פריטאון)',
        'Africa/Gaborone' => 'שעון מרכז אפריקה (גבורונה)',
        'Africa/Harare' => 'שעון מרכז אפריקה (הרארה)',
        'Africa/Johannesburg' => 'שעון דרום אפריקה (יוהנסבורג)',
        'Africa/Juba' => 'שעון מרכז אפריקה (ג׳ובה)',
        'Africa/Kampala' => 'שעון מזרח אפריקה (קמפאלה)',
        'Africa/Khartoum' => 'שעון מרכז אפריקה (חרטום)',
        'Africa/Kigali' => 'שעון מרכז אפריקה (קיגלי)',
        'Africa/Kinshasa' => 'שעון מערב אפריקה (קינשסה)',
        'Africa/Lagos' => 'שעון מערב אפריקה (לאגוס)',
        'Africa/Libreville' => 'שעון מערב אפריקה (ליברוויל)',
        'Africa/Lome' => 'שעון גריניץ׳‏ (לומה)',
        'Africa/Luanda' => 'שעון מערב אפריקה (לואנדה)',
        'Africa/Lubumbashi' => 'שעון מרכז אפריקה (לובומבאשי)',
        'Africa/Lusaka' => 'שעון מרכז אפריקה (לוסקה)',
        'Africa/Malabo' => 'שעון מערב אפריקה (מלבו)',
        'Africa/Maputo' => 'שעון מרכז אפריקה (מאפוטו)',
        'Africa/Maseru' => 'שעון דרום אפריקה (מסרו)',
        'Africa/Mbabane' => 'שעון דרום אפריקה (מבבנה)',
        'Africa/Mogadishu' => 'שעון מזרח אפריקה (מוגדישו)',
        'Africa/Monrovia' => 'שעון גריניץ׳‏ (מונרוביה)',
        'Africa/Nairobi' => 'שעון מזרח אפריקה (ניירובי)',
        'Africa/Ndjamena' => 'שעון מערב אפריקה (נג׳מנה)',
        'Africa/Niamey' => 'שעון מערב אפריקה (ניאמיי)',
        'Africa/Nouakchott' => 'שעון גריניץ׳‏ (נואקצ׳וט)',
        'Africa/Ouagadougou' => 'שעון גריניץ׳‏ (וואגאדוגו)',
        'Africa/Porto-Novo' => 'שעון מערב אפריקה (פורטו נובו)',
        'Africa/Sao_Tome' => 'שעון גריניץ׳‏ (סאו טומה)',
        'Africa/Tripoli' => 'שעון מזרח אירופה (טריפולי)',
        'Africa/Tunis' => 'שעון מרכז אירופה (תוניס)',
        'Africa/Windhoek' => 'שעון מרכז אפריקה (וינדהוק)',
        'America/Adak' => 'שעון האיים האלאוטיים הוואי (אדאק)',
        'America/Anchorage' => 'שעון אלסקה (אנקורג׳)',
        'America/Anguilla' => 'שעון האוקיינוס האטלנטי (אנגווילה)',
        'America/Antigua' => 'שעון האוקיינוס האטלנטי (אנטיגואה)',
        'America/Araguaina' => 'שעון ברזיליה (אראגואינה)',
        'America/Argentina/La_Rioja' => 'שעון ארגנטינה (לה ריוחה)',
        'America/Argentina/Rio_Gallegos' => 'שעון ארגנטינה (ריו גאייגוס)',
        'America/Argentina/Salta' => 'שעון ארגנטינה (סלטה)',
        'America/Argentina/San_Juan' => 'שעון ארגנטינה (סן חואן)',
        'America/Argentina/San_Luis' => 'שעון ארגנטינה (סן לואיס)',
        'America/Argentina/Tucuman' => 'שעון ארגנטינה (טוקומן)',
        'America/Argentina/Ushuaia' => 'שעון ארגנטינה (אושוואיה)',
        'America/Aruba' => 'שעון האוקיינוס האטלנטי (ארובה)',
        'America/Asuncion' => 'שעון פרגוואי (אסונסיון)',
        'America/Bahia' => 'שעון ברזיליה (באהיה)',
        'America/Bahia_Banderas' => 'שעון מרכז ארה״ב (באהיה בנדרס)',
        'America/Barbados' => 'שעון האוקיינוס האטלנטי (ברבדוס)',
        'America/Belem' => 'שעון ברזיליה (בלם)',
        'America/Belize' => 'שעון מרכז ארה״ב (בליז)',
        'America/Blanc-Sablon' => 'שעון האוקיינוס האטלנטי (בלאן-סבלון)',
        'America/Boa_Vista' => 'שעון אמזונס (בואה ויסטה)',
        'America/Bogota' => 'שעון קולומביה (בוגוטה)',
        'America/Boise' => 'שעון אזור ההרים בארה״ב (בויסי)',
        'America/Buenos_Aires' => 'שעון ארגנטינה (בואנוס איירס)',
        'America/Argentina/Buenos_Aires' => 'שעון ארגנטינה (בואנוס איירס)',
        'America/Cambridge_Bay' => 'שעון אזור ההרים בארה״ב (קיימברידג׳ ביי)',
        'America/Campo_Grande' => 'שעון אמזונס (קמפו גרנדה)',
        'America/Cancun' => 'שעון החוף המזרחי (קנקון)',
        'America/Caracas' => 'שעון ונצואלה (קראקס)',
        'America/Catamarca' => 'שעון ארגנטינה (קטמרקה)',
        'America/Argentina/Catamarca' => 'שעון ארגנטינה (קטמרקה)',
        'America/Cayenne' => 'שעון גיאנה הצרפתית (קאיין)',
        'America/Cayman' => 'שעון החוף המזרחי (קיימן)',
        'America/Chicago' => 'שעון מרכז ארה״ב (שיקגו)',
        'America/Chihuahua' => 'שעון מרכז ארה״ב (צ׳יוואווה)',
        'America/Ciudad_Juarez' => 'שעון אזור ההרים בארה״ב (סיודד חוארס)',
        'America/Coral_Harbour' => 'שעון החוף המזרחי (אטיקוקן)',
        'America/Atikokan' => 'שעון החוף המזרחי (אטיקוקן)',
        'America/Cordoba' => 'שעון ארגנטינה (קורדובה)',
        'America/Argentina/Cordoba' => 'שעון ארגנטינה (קורדובה)',
        'America/Costa_Rica' => 'שעון מרכז ארה״ב (קוסטה ריקה)',
        'America/Coyhaique' => 'שעון צ׳ילה (קויאיקה)',
        'America/Creston' => 'שעון אזור ההרים בארה״ב (קרסטון)',
        'America/Cuiaba' => 'שעון אמזונס (קויאבה)',
        'America/Curacao' => 'שעון האוקיינוס האטלנטי (קוראסאו)',
        'America/Danmarkshavn' => 'שעון גריניץ׳‏ (דנמרקסהוון)',
        'America/Dawson' => 'שעון יוקון (דוסון)',
        'America/Dawson_Creek' => 'שעון אזור ההרים בארה״ב (דוסון קריק)',
        'America/Denver' => 'שעון אזור ההרים בארה״ב (דנוור)',
        'America/Detroit' => 'שעון החוף המזרחי (דטרויט)',
        'America/Dominica' => 'שעון האוקיינוס האטלנטי (דומיניקה)',
        'America/Edmonton' => 'שעון אזור ההרים בארה״ב (אדמונטון)',
        'America/Eirunepe' => 'שעון ברזיל (אירונפי)',
        'America/El_Salvador' => 'שעון מרכז ארה״ב (אל סלבדור)',
        'America/Fort_Nelson' => 'שעון אזור ההרים בארה״ב (פורט נלסון)',
        'America/Fortaleza' => 'שעון ברזיליה (פורטאלזה)',
        'America/Glace_Bay' => 'שעון האוקיינוס האטלנטי (גלייס ביי)',
        'America/Godthab' => 'שעון גרינלנד (נואוק)',
        'America/Nuuk' => 'שעון גרינלנד (נואוק)',
        'America/Goose_Bay' => 'שעון האוקיינוס האטלנטי (גוס ביי)',
        'America/Grand_Turk' => 'שעון החוף המזרחי (גרנד טורק)',
        'America/Grenada' => 'שעון האוקיינוס האטלנטי (גרנדה)',
        'America/Guadeloupe' => 'שעון האוקיינוס האטלנטי (גואדלופ)',
        'America/Guatemala' => 'שעון מרכז ארה״ב (גואטמלה)',
        'America/Guayaquil' => 'שעון אקוודור (גואיאקיל)',
        'America/Guyana' => 'שעון גיאנה',
        'America/Halifax' => 'שעון האוקיינוס האטלנטי (הליפקס)',
        'America/Havana' => 'שעון קובה (הוואנה)',
        'America/Hermosillo' => 'שעון מערב מקסיקו (הרמוסיו)',
        'America/Indiana/Knox' => 'שעון מרכז ארה״ב (נוקס, אינדיאנה)',
        'America/Indiana/Marengo' => 'שעון החוף המזרחי (מרנגו, אינדיאנה)',
        'America/Indiana/Petersburg' => 'שעון החוף המזרחי (פיטרסבורג, אינדיאנה)',
        'America/Indiana/Tell_City' => 'שעון מרכז ארה״ב (טל סיטי, אינדיאנה)',
        'America/Indiana/Vevay' => 'שעון החוף המזרחי (ויוואיי, אינדיאנה)',
        'America/Indiana/Vincennes' => 'שעון החוף המזרחי (וינסנס, אינדיאנה)',
        'America/Indiana/Winamac' => 'שעון החוף המזרחי (וינמאק, אינדיאנה)',
        'America/Indianapolis' => 'שעון החוף המזרחי (אינדיאנפוליס)',
        'America/Indiana/Indianapolis' => 'שעון החוף המזרחי (אינדיאנפוליס)',
        'America/Inuvik' => 'שעון אזור ההרים בארה״ב (אינוויק)',
        'America/Iqaluit' => 'שעון החוף המזרחי (איקלואיט)',
        'America/Jamaica' => 'שעון החוף המזרחי (ג׳מייקה)',
        'America/Jujuy' => 'שעון ארגנטינה (חוחוי)',
        'America/Argentina/Jujuy' => 'שעון ארגנטינה (חוחוי)',
        'America/Juneau' => 'שעון אלסקה (ג׳ונו)',
        'America/Kentucky/Monticello' => 'שעון החוף המזרחי (מונטיצ׳לו, קנטאקי)',
        'America/Kralendijk' => 'שעון האוקיינוס האטלנטי (קרלנדייק)',
        'America/La_Paz' => 'שעון בוליביה (לה פאס)',
        'America/Lima' => 'שעון פרו (לימה)',
        'America/Los_Angeles' => 'שעון מערב ארה״ב (לוס אנג׳לס)',
        'America/Louisville' => 'שעון החוף המזרחי (לואיוויל)',
        'America/Kentucky/Louisville' => 'שעון החוף המזרחי (לואיוויל)',
        'America/Lower_Princes' => 'שעון האוקיינוס האטלנטי (לואוור פרינסס קוורטר)',
        'America/Maceio' => 'שעון ברזיליה (מסייאו)',
        'America/Managua' => 'שעון מרכז ארה״ב (מנגואה)',
        'America/Manaus' => 'שעון אמזונס (מנאוס)',
        'America/Marigot' => 'שעון האוקיינוס האטלנטי (מריגו)',
        'America/Martinique' => 'שעון האוקיינוס האטלנטי (מרטיניק)',
        'America/Matamoros' => 'שעון מרכז ארה״ב (מטמורוס)',
        'America/Mazatlan' => 'שעון מערב מקסיקו (מזטלן)',
        'America/Mendoza' => 'שעון ארגנטינה (מנדוזה)',
        'America/Argentina/Mendoza' => 'שעון ארגנטינה (מנדוזה)',
        'America/Menominee' => 'שעון מרכז ארה״ב (מנומיני)',
        'America/Merida' => 'שעון מרכז ארה״ב (מרידה)',
        'America/Metlakatla' => 'שעון אלסקה (מטלקטלה)',
        'America/Mexico_City' => 'שעון מרכז ארה״ב (מקסיקו סיטי)',
        'America/Miquelon' => 'שעון סנט פייר ומיקלון',
        'America/Moncton' => 'שעון האוקיינוס האטלנטי (מונקטון)',
        'America/Monterrey' => 'שעון מרכז ארה״ב (מונטריי)',
        'America/Montevideo' => 'שעון אורוגוואי (מונטווידאו)',
        'America/Montserrat' => 'שעון האוקיינוס האטלנטי (מונסראט)',
        'America/Nassau' => 'שעון החוף המזרחי (נסאו)',
        'America/New_York' => 'שעון החוף המזרחי (ניו יורק)',
        'America/Nome' => 'שעון אלסקה (נום)',
        'America/Noronha' => 'שעון פרננדו די נורוניה',
        'America/North_Dakota/Beulah' => 'שעון מרכז ארה״ב (ביולה, דקוטה הצפונית)',
        'America/North_Dakota/Center' => 'שעון מרכז ארה״ב (סנטר, דקוטה הצפונית)',
        'America/North_Dakota/New_Salem' => 'שעון מרכז ארה״ב (ניו סיילם, דקוטה הצפונית)',
        'America/Ojinaga' => 'שעון מרכז ארה״ב (אוג׳ינאגה)',
        'America/Panama' => 'שעון החוף המזרחי (פנמה)',
        'America/Paramaribo' => 'שעון סורינאם (פרמריבו)',
        'America/Phoenix' => 'שעון אזור ההרים בארה״ב (פיניקס)',
        'America/Port-au-Prince' => 'שעון החוף המזרחי (פורט או פראנס)',
        'America/Port_of_Spain' => 'שעון האוקיינוס האטלנטי (פורט אוף ספיין)',
        'America/Porto_Velho' => 'שעון אמזונס (פורטו וליו)',
        'America/Puerto_Rico' => 'שעון האוקיינוס האטלנטי (פוארטו ריקו)',
        'America/Punta_Arenas' => 'שעון צ׳ילה (פונטה ארנס)',
        'America/Rankin_Inlet' => 'שעון מרכז ארה״ב (רנקין אינלט)',
        'America/Recife' => 'שעון ברזיליה (רסיפה)',
        'America/Regina' => 'שעון מרכז ארה״ב (רג׳ינה)',
        'America/Resolute' => 'שעון מרכז ארה״ב (רזולוט)',
        'America/Rio_Branco' => 'שעון ברזיל (ריו ברנקו)',
        'America/Santarem' => 'שעון ברזיליה (סנטרם)',
        'America/Santiago' => 'שעון צ׳ילה (סנטיאגו)',
        'America/Santo_Domingo' => 'שעון האוקיינוס האטלנטי (סנטו דומינגו)',
        'America/Sao_Paulo' => 'שעון ברזיליה (סאו פאולו)',
        'America/Scoresbysund' => 'שעון גרינלנד (סקורסביסונד)',
        'America/Sitka' => 'שעון אלסקה (סיטקה)',
        'America/St_Barthelemy' => 'שעון האוקיינוס האטלנטי (סנט ברתלמי)',
        'America/St_Johns' => 'שעון ניופאונדלנד (סנט ג׳ונס)',
        'America/St_Kitts' => 'שעון האוקיינוס האטלנטי (סנט קיטס)',
        'America/St_Lucia' => 'שעון האוקיינוס האטלנטי (סנט לוסיה)',
        'America/St_Thomas' => 'שעון האוקיינוס האטלנטי (סנט תומאס)',
        'America/St_Vincent' => 'שעון האוקיינוס האטלנטי (סנט וינסנט)',
        'America/Swift_Current' => 'שעון מרכז ארה״ב (סוויפט קרנט)',
        'America/Tegucigalpa' => 'שעון מרכז ארה״ב (טגוסיגלפה)',
        'America/Thule' => 'שעון האוקיינוס האטלנטי (תולה)',
        'America/Tijuana' => 'שעון מערב ארה״ב (טיחואנה)',
        'America/Toronto' => 'שעון החוף המזרחי (טורונטו)',
        'America/Tortola' => 'שעון האוקיינוס האטלנטי (טורטולה)',
        'America/Vancouver' => 'שעון מערב ארה״ב (ונקובר)',
        'America/Whitehorse' => 'שעון יוקון (ווייטהורס)',
        'America/Winnipeg' => 'שעון מרכז ארה״ב (וויניפג)',
        'America/Yakutat' => 'שעון אלסקה (יקוטאט)',
        'Antarctica/Casey' => 'שעון מערב אוסטרליה (קייסי)',
        'Antarctica/Davis' => 'שעון דיוויס',
        'Antarctica/DumontDUrville' => 'שעון דומון ד׳אורוויל',
        'Antarctica/Macquarie' => 'שעון מזרח אוסטרליה (מקווארי)',
        'Antarctica/Mawson' => 'שעון מאוסון (מוסון)',
        'Antarctica/McMurdo' => 'שעון ניו זילנד (מק-מרדו)',
        'Antarctica/Palmer' => 'שעון צ׳ילה (פאלמר)',
        'Antarctica/Rothera' => 'שעון רות׳רה',
        'Antarctica/Syowa' => 'שעון סייווה',
        'Antarctica/Troll' => 'שעון גריניץ׳‏ (טרול)',
        'Antarctica/Vostok' => 'שעון ווסטוק',
        'Arctic/Longyearbyen' => 'שעון מרכז אירופה (לונגיירבין)',
        'Asia/Aden' => 'שעון חצי האי ערב (עדן)',
        'Asia/Almaty' => 'שעון קזחסטן (אלמאטי)',
        'Asia/Amman' => 'שעון מזרח אירופה (עמאן)',
        'Asia/Anadyr' => 'שעון פטרופבלובסק-קמצ׳טסקי (אנדיר)',
        'Asia/Aqtau' => 'שעון קזחסטן (אקטאו)',
        'Asia/Aqtobe' => 'שעון קזחסטן (אקטובה)',
        'Asia/Ashgabat' => 'שעון טורקמניסטן (אשגבט)',
        'Asia/Atyrau' => 'שעון קזחסטן (אטיראו)',
        'Asia/Baghdad' => 'שעון חצי האי ערב (בגדד)',
        'Asia/Bahrain' => 'שעון חצי האי ערב (בחריין)',
        'Asia/Baku' => 'שעון אזרבייג׳ן (באקו)',
        'Asia/Bangkok' => 'שעון הודו-סין (בנגקוק)',
        'Asia/Barnaul' => 'שעון קרסנויארסק (ברנאול)',
        'Asia/Beirut' => 'שעון מזרח אירופה (ביירות)',
        'Asia/Bishkek' => 'שעון קירגיזסטן (בישקק)',
        'Asia/Brunei' => 'שעון ברוניי דארוסלאם',
        'Asia/Calcutta' => 'שעון הודו (קולקטה)',
        'Asia/Kolkata' => 'שעון הודו (קולקטה)',
        'Asia/Chita' => 'שעון יקוטסק (צ׳יטה)',
        'Asia/Colombo' => 'שעון הודו (קולומבו)',
        'Asia/Damascus' => 'שעון מזרח אירופה (דמשק)',
        'Asia/Dhaka' => 'שעון בנגלדש (דאקה)',
        'Asia/Dili' => 'שעון מזרח טימור (דילי)',
        'Asia/Dubai' => 'שעון מדינות המפרץ (דובאי)',
        'Asia/Dushanbe' => 'שעון טג׳יקיסטן (דושנבה)',
        'Asia/Famagusta' => 'שעון מזרח אירופה (פמגוסטה)',
        'Asia/Gaza' => 'שעון מזרח אירופה (עזה)',
        'Asia/Hebron' => 'שעון מזרח אירופה (חברון)',
        'Asia/Hong_Kong' => 'שעון הונג קונג',
        'Asia/Hovd' => 'שעון חובד',
        'Asia/Irkutsk' => 'שעון אירקוטסק',
        'Asia/Jakarta' => 'שעון מערב אינדונזיה (ג׳קרטה)',
        'Asia/Jayapura' => 'שעון מזרח אינדונזיה (ג׳איאפורה)',
        'Asia/Jerusalem' => 'שעון ישראל (ירושלים)',
        'Asia/Kabul' => 'שעון אפגניסטן (קאבול)',
        'Asia/Kamchatka' => 'שעון פטרופבלובסק-קמצ׳טסקי (קמצ׳טקה)',
        'Asia/Karachi' => 'שעון פקיסטן (קראצ׳י)',
        'Asia/Katmandu' => 'שעון נפאל (קטמנדו)',
        'Asia/Kathmandu' => 'שעון נפאל (קטמנדו)',
        'Asia/Khandyga' => 'שעון יקוטסק (חנדיגה)',
        'Asia/Krasnoyarsk' => 'שעון קרסנויארסק',
        'Asia/Kuala_Lumpur' => 'שעון מלזיה (קואלה לומפור)',
        'Asia/Kuching' => 'שעון מלזיה (קוצ׳ינג)',
        'Asia/Kuwait' => 'שעון חצי האי ערב (כווית)',
        'Asia/Macau' => 'שעון סין (מקאו)',
        'Asia/Magadan' => 'שעון מגדן',
        'Asia/Makassar' => 'שעון מרכז אינדונזיה (מאקאסאר)',
        'Asia/Manila' => 'שעון הפיליפינים (מנילה)',
        'Asia/Muscat' => 'שעון מדינות המפרץ (מוסקט)',
        'Asia/Nicosia' => 'שעון מזרח אירופה (ניקוסיה)',
        'Asia/Novokuznetsk' => 'שעון קרסנויארסק (נובוקוזנטסק)',
        'Asia/Novosibirsk' => 'שעון קרסנויארסק (נובוסיבירסק)',
        'Asia/Omsk' => 'שעון אומסק',
        'Asia/Oral' => 'שעון קזחסטן (אורל)',
        'Asia/Phnom_Penh' => 'שעון הודו-סין (פנום פן)',
        'Asia/Pontianak' => 'שעון מערב אינדונזיה (פונטיאנק)',
        'Asia/Pyongyang' => 'שעון קוריאה (פיונגיאנג)',
        'Asia/Qatar' => 'שעון חצי האי ערב (קטאר)',
        'Asia/Qostanay' => 'שעון קזחסטן (קוסטנאי)',
        'Asia/Qyzylorda' => 'שעון קזחסטן (קיזילורדה)',
        'Asia/Rangoon' => 'שעון מיאנמר (רנגון)',
        'Asia/Yangon' => 'שעון מיאנמר (רנגון)',
        'Asia/Riyadh' => 'שעון חצי האי ערב (ריאד)',
        'Asia/Saigon' => 'שעון הודו-סין (הו צ׳י מין סיטי)',
        'Asia/Ho_Chi_Minh' => 'שעון הודו-סין (הו צ׳י מין סיטי)',
        'Asia/Sakhalin' => 'שעון מגדן (סחלין)',
        'Asia/Samarkand' => 'שעון אוזבקיסטן (סמרקנד)',
        'Asia/Seoul' => 'שעון קוריאה (סיאול)',
        'Asia/Shanghai' => 'שעון סין (שנחאי)',
        'Asia/Singapore' => 'שעון סינגפור',
        'Asia/Srednekolymsk' => 'שעון מגדן (סרדנייקולימסק)',
        'Asia/Taipei' => 'שעון טאיפיי',
        'Asia/Tashkent' => 'שעון אוזבקיסטן (טשקנט)',
        'Asia/Tbilisi' => 'שעון גאורגיה (טביליסי)',
        'Asia/Tehran' => 'שעון איראן (טהרן)',
        'Asia/Thimphu' => 'שעון בהוטן (טהימפהו)',
        'Asia/Tokyo' => 'שעון יפן (טוקיו)',
        'Asia/Tomsk' => 'שעון קרסנויארסק (טומסק)',
        'Asia/Ulaanbaatar' => 'שעון אולאן באטור',
        'Asia/Urumqi' => 'שעון סין (אורומקי)',
        'Asia/Ust-Nera' => 'שעון ולדיווסטוק (אוסט-נרה)',
        'Asia/Vientiane' => 'שעון הודו-סין (ויינטיאן)',
        'Asia/Vladivostok' => 'שעון ולדיווסטוק',
        'Asia/Yakutsk' => 'שעון יקוטסק',
        'Asia/Yekaterinburg' => 'שעון יקטרינבורג',
        'Asia/Yerevan' => 'שעון ארמניה (ירוואן)',
        'Atlantic/Azores' => 'שעון האיים האזוריים',
        'Atlantic/Bermuda' => 'שעון האוקיינוס האטלנטי (ברמודה)',
        'Atlantic/Canary' => 'שעון מערב אירופה (האיים הקנריים)',
        'Atlantic/Cape_Verde' => 'שעון כף ורדה',
        'Atlantic/Faeroe' => 'שעון מערב אירופה (פארו)',
        'Atlantic/Faroe' => 'שעון מערב אירופה (פארו)',
        'Atlantic/Madeira' => 'שעון מערב אירופה (מדיירה)',
        'Atlantic/Reykjavik' => 'שעון גריניץ׳‏ (רייקיאוויק)',
        'Atlantic/South_Georgia' => 'שעון דרום ג׳ורג׳יה',
        'Atlantic/St_Helena' => 'שעון גריניץ׳‏ (סנט הלנה)',
        'Atlantic/Stanley' => 'שעון איי פוקלנד (סטנלי)',
        'Australia/Adelaide' => 'שעון מרכז אוסטרליה (אדלייד)',
        'Australia/Brisbane' => 'שעון מזרח אוסטרליה (בריסביין)',
        'Australia/Broken_Hill' => 'שעון מרכז אוסטרליה (ברוקן היל)',
        'Australia/Darwin' => 'שעון מרכז אוסטרליה (דרווין)',
        'Australia/Eucla' => 'שעון מרכז-מערב אוסטרליה (יוקלה)',
        'Australia/Hobart' => 'שעון מזרח אוסטרליה (הוברט)',
        'Australia/Lindeman' => 'שעון מזרח אוסטרליה (לינדמן)',
        'Australia/Lord_Howe' => 'שעון אי הלורד האו',
        'Australia/Melbourne' => 'שעון מזרח אוסטרליה (מלבורן)',
        'Australia/Perth' => 'שעון מערב אוסטרליה (פרת׳)',
        'Australia/Sydney' => 'שעון מזרח אוסטרליה (סידני)',
        'Etc/GMT' => 'שעון גריניץ׳‏',
        'Etc/UTC' => 'זמן אוניברסלי מתואם',
        'Europe/Amsterdam' => 'שעון מרכז אירופה (אמסטרדם)',
        'Europe/Andorra' => 'שעון מרכז אירופה (אנדורה)',
        'Europe/Astrakhan' => 'שעון סמרה (אסטרחן)',
        'Europe/Athens' => 'שעון מזרח אירופה (אתונה)',
        'Europe/Belgrade' => 'שעון מרכז אירופה (בלגרד)',
        'Europe/Berlin' => 'שעון מרכז אירופה (ברלין)',
        'Europe/Bratislava' => 'שעון מרכז אירופה (ברטיסלבה)',
        'Europe/Brussels' => 'שעון מרכז אירופה (בריסל)',
        'Europe/Bucharest' => 'שעון מזרח אירופה (בוקרשט)',
        'Europe/Budapest' => 'שעון מרכז אירופה (בודפשט)',
        'Europe/Busingen' => 'שעון מרכז אירופה (ביזינגן)',
        'Europe/Chisinau' => 'שעון מזרח אירופה (קישינב)',
        'Europe/Copenhagen' => 'שעון מרכז אירופה (קופנהגן)',
        'Europe/Dublin' => 'שעון גריניץ׳‏ (דבלין)',
        'Europe/Gibraltar' => 'שעון מרכז אירופה (גיברלטר)',
        'Europe/Guernsey' => 'שעון גריניץ׳‏ (גרנזי)',
        'Europe/Helsinki' => 'שעון מזרח אירופה (הלסינקי)',
        'Europe/Isle_of_Man' => 'שעון גריניץ׳‏ (האי מאן)',
        'Europe/Istanbul' => 'שעון טורקיה (איסטנבול)',
        'Europe/Jersey' => 'שעון גריניץ׳‏ (ג׳רזי)',
        'Europe/Kaliningrad' => 'שעון מזרח אירופה (קלינינגרד)',
        'Europe/Kiev' => 'שעון מזרח אירופה (קייב)',
        'Europe/Kyiv' => 'שעון מזרח אירופה (קייב)',
        'Europe/Kirov' => 'שעון מוסקבה (קירוב)',
        'Europe/Lisbon' => 'שעון מערב אירופה (ליסבון)',
        'Europe/Ljubljana' => 'שעון מרכז אירופה (לובליאנה)',
        'Europe/London' => 'שעון גריניץ׳‏ (לונדון)',
        'Europe/Luxembourg' => 'שעון מרכז אירופה (לוקסמבורג)',
        'Europe/Madrid' => 'שעון מרכז אירופה (מדריד)',
        'Europe/Malta' => 'שעון מרכז אירופה (מלטה)',
        'Europe/Mariehamn' => 'שעון מזרח אירופה (מרייהאמן)',
        'Europe/Minsk' => 'שעון מוסקבה (מינסק)',
        'Europe/Monaco' => 'שעון מרכז אירופה (מונקו)',
        'Europe/Moscow' => 'שעון מוסקבה',
        'Europe/Oslo' => 'שעון מרכז אירופה (אוסלו)',
        'Europe/Paris' => 'שעון מרכז אירופה (פריז)',
        'Europe/Podgorica' => 'שעון מרכז אירופה (פודגוריצה)',
        'Europe/Prague' => 'שעון מרכז אירופה (פראג)',
        'Europe/Riga' => 'שעון מזרח אירופה (ריגה)',
        'Europe/Rome' => 'שעון מרכז אירופה (רומא)',
        'Europe/Samara' => 'שעון סמרה',
        'Europe/San_Marino' => 'שעון מרכז אירופה (סן מרינו)',
        'Europe/Sarajevo' => 'שעון מרכז אירופה (סרייבו)',
        'Europe/Saratov' => 'שעון סמרה (סראטוב)',
        'Europe/Simferopol' => 'שעון מוסקבה (סימפרופול)',
        'Europe/Skopje' => 'שעון מרכז אירופה (סקופיה)',
        'Europe/Sofia' => 'שעון מזרח אירופה (סופיה)',
        'Europe/Stockholm' => 'שעון מרכז אירופה (שטוקהולם)',
        'Europe/Tallinn' => 'שעון מזרח אירופה (טאלין)',
        'Europe/Tirane' => 'שעון מרכז אירופה (טירנה)',
        'Europe/Ulyanovsk' => 'שעון סמרה (אוליאנובסק)',
        'Europe/Vaduz' => 'שעון מרכז אירופה (ואדוץ)',
        'Europe/Vatican' => 'שעון מרכז אירופה (הוותיקן)',
        'Europe/Vienna' => 'שעון מרכז אירופה (וינה)',
        'Europe/Vilnius' => 'שעון מזרח אירופה (וילנה)',
        'Europe/Volgograd' => 'שעון מוסקבה (וולגוגרד)',
        'Europe/Warsaw' => 'שעון מרכז אירופה (ורשה)',
        'Europe/Zagreb' => 'שעון מרכז אירופה (זאגרב)',
        'Europe/Zurich' => 'שעון מרכז אירופה (ציריך)',
        'Indian/Antananarivo' => 'שעון מזרח אפריקה (אנטננריבו)',
        'Indian/Chagos' => 'שעון האוקיינוס ההודי (צ׳אגוס)',
        'Indian/Christmas' => 'שעון האי כריסטמס',
        'Indian/Cocos' => 'שעון איי קוקוס',
        'Indian/Comoro' => 'שעון מזרח אפריקה (קומורו)',
        'Indian/Kerguelen' => 'שעון הארצות הדרומיות והאנטארקטיות של צרפת (קרגוולן)',
        'Indian/Mahe' => 'שעון איי סיישל (מהא)',
        'Indian/Maldives' => 'שעון האיים המלדיביים',
        'Indian/Mauritius' => 'שעון מאוריציוס',
        'Indian/Mayotte' => 'שעון מזרח אפריקה (מאיוט)',
        'Indian/Reunion' => 'שעון ראוניון',
        'Pacific/Apia' => 'שעון אפיה',
        'Pacific/Auckland' => 'שעון ניו זילנד (אוקלנד)',
        'Pacific/Bougainville' => 'שעון פפואה גיניאה החדשה (בוגנוויל)',
        'Pacific/Chatham' => 'שעון צ׳טהאם (צ׳אטהאם)',
        'Pacific/Easter' => 'שעון אי הפסחא',
        'Pacific/Efate' => 'שעון ונואטו (אפטה)',
        'Pacific/Enderbury' => 'שעון איי פיניקס (קנטון)',
        'Pacific/Kanton' => 'שעון איי פיניקס (קנטון)',
        'Pacific/Fakaofo' => 'שעון טוקלאו (פקאופו)',
        'Pacific/Fiji' => 'שעון פיג׳י',
        'Pacific/Funafuti' => 'שעון טובאלו (פונפוטי)',
        'Pacific/Galapagos' => 'שעון איי גלאפגוס (גלפאגוס)',
        'Pacific/Gambier' => 'שעון איי גמבייה',
        'Pacific/Guadalcanal' => 'שעון איי שלמה (גוודלקנאל)',
        'Pacific/Guam' => 'שעון צ׳אמורו (גואם)',
        'Pacific/Honolulu' => 'שעון האיים האלאוטיים הוואי (חורף) (הונולולו)',
        'Pacific/Kiritimati' => 'שעון איי ליין (קיריטימאטי)',
        'Pacific/Kosrae' => 'שעון קוסראה (קוסרה)',
        'Pacific/Kwajalein' => 'שעון איי מרשל (קוואג׳ליין)',
        'Pacific/Majuro' => 'שעון איי מרשל (מאג׳ורו)',
        'Pacific/Marquesas' => 'שעון איי מרקיז',
        'Pacific/Midway' => 'שעון סמואה (מידוויי)',
        'Pacific/Nauru' => 'שעון נאורו',
        'Pacific/Niue' => 'שעון ניואה',
        'Pacific/Norfolk' => 'שעון האי נורפוק',
        'Pacific/Noumea' => 'שעון קלדוניה החדשה (נומאה)',
        'Pacific/Pago_Pago' => 'שעון סמואה (פאגו פאגו)',
        'Pacific/Palau' => 'שעון פלאו',
        'Pacific/Pitcairn' => 'שעון פיטקרן',
        'Pacific/Ponape' => 'שעון פונאפי (פונפיי)',
        'Pacific/Pohnpei' => 'שעון פונאפי (פונפיי)',
        'Pacific/Port_Moresby' => 'שעון פפואה גיניאה החדשה (פורט מורסבי)',
        'Pacific/Rarotonga' => 'שעון איי קוק (רארוטונגה)',
        'Pacific/Saipan' => 'שעון צ׳אמורו (סאיפאן)',
        'Pacific/Tahiti' => 'שעון טהיטי',
        'Pacific/Tarawa' => 'שעון איי גילברט (טאראווה)',
        'Pacific/Tongatapu' => 'שעון טונגה (טונגטאפו)',
        'Pacific/Truk' => 'שעון צ׳וק',
        'Pacific/Chuuk' => 'שעון צ׳וק',
        'Pacific/Wake' => 'שעון האי וייק',
        'Pacific/Wallis' => 'שעון וואליס ופוטונה (ווליס)',
    ],
    'Meta' => [
        'GmtFormat' => 'GMT%s‎',
        'HourFormatPos' => '‎+%02d:%02d',
        'HourFormatNeg' => '-%02d:%02d‎',
    ],
];
