<?php

return [
    'Names' => [
        'Adlm' => 'Άντλαμ',
        'Arab' => 'Αραβικό',
        'Aran' => 'Νασταλίκ',
        'Armi' => 'Αυτοκρατορικό Αραμαϊκό',
        'Armn' => 'Αρμενικό',
        'Avst' => 'Αβεστάν',
        'Bali' => 'Μπαλινίζ',
        'Batk' => 'Μπατάκ',
        'Beng' => 'Μπενγκάλι',
        'Blis' => 'Σύμβολα Bliss',
        'Bopo' => 'Μποπομόφο',
        'Brah' => 'Μπραχμί',
        'Brai' => 'Μπράιγ',
        'Bugi' => 'Μπούγκις',
        'Buhd' => 'Μπουχίντ',
        'Cakm' => 'Τσάκμα',
        'Cans' => 'Ενοποιημένοι Καναδεζικοί Συλλαβισμοί Ιθαγενών',
        'Cari' => 'Καριάν',
        'Cham' => 'Τσαμ',
        'Cher' => 'Τσερόκι',
        'Cirt' => 'Σερθ',
        'Copt' => 'Κοπτικό',
        'Cprt' => 'Κυπριακό',
        'Cyrl' => 'Κυριλλικό',
        'Cyrs' => 'Παλαιό Εκκλησιαστικό Σλαβικό Κυριλλικό',
        'Deva' => 'Ντεβαναγκάρι',
        'Dsrt' => 'Ντεσερέ',
        'Egyd' => 'Λαϊκό Αιγυπτιακό',
        'Egyh' => 'Ιερατικό Αιγυπτιακό',
        'Egyp' => 'Αιγυπτιακά Ιερογλυφικά',
        'Ethi' => 'Αιθιοπικό',
        'Geok' => 'Γεωργιανό Κχουτσούρι',
        'Geor' => 'Γεωργιανό',
        'Glag' => 'Γκλαγκολιτικό',
        'Goth' => 'Γοτθικό',
        'Grek' => 'Ελληνικό',
        'Gujr' => 'Γκουγιαράτι',
        'Guru' => 'Γκουρμουκχί',
        'Hanb' => 'Χανμπ',
        'Hang' => 'Χανγκούλ',
        'Hani' => 'Χαν',
        'Hano' => 'Χανούνου',
        'Hans' => 'Απλοποιημένο',
        'Hant' => 'Παραδοσιακό',
        'Hebr' => 'Εβραϊκό',
        'Hira' => 'Χιραγκάνα',
        'Hmng' => 'Παχάχ Χμονγκ',
        'Hrkt' => 'Κατακάνα ή Χιραγκάνα',
        'Hung' => 'Παλαιό Ουγγρικό',
        'Inds' => 'Ίνδους',
        'Ital' => 'Παλαιό Ιταλικό',
        'Jamo' => 'Τζάμο',
        'Java' => 'Ιαβανεζικό',
        'Jpan' => 'Ιαπωνικό',
        'Kali' => 'Καγιάχ Λι',
        'Kana' => 'Κατακάνα',
        'Khar' => 'Καρόσθι',
        'Khmr' => 'Χμερ',
        'Knda' => 'Κανάντα',
        'Kore' => 'Κορεατικό',
        'Kthi' => 'Καϊθί',
        'Lana' => 'Λάννα',
        'Laoo' => 'Λαοτινό',
        'Latf' => 'Φράκτουρ Λατινικό',
        'Latg' => 'Γαελικό Λατινικό',
        'Latn' => 'Λατινικό',
        'Lepc' => 'Λέπτσα',
        'Limb' => 'Λιμπού',
        'Lina' => 'Γραμμικό Α',
        'Linb' => 'Γραμμικό Β',
        'Lyci' => 'Λυκιανικό',
        'Lydi' => 'Λυδιανικό',
        'Mand' => 'Μανδαϊκό',
        'Mani' => 'Μανιχαϊκό',
        'Maya' => 'Ιερογλυφικά Μάγια',
        'Mero' => 'Μεροϊτικό',
        'Mlym' => 'Μαλαγιάλαμ',
        'Mong' => 'Μογγολικό',
        'Moon' => 'Μουν',
        'Mtei' => 'Μεϊτέι Μάγεκ',
        'Mymr' => 'Μιανμάρ',
        'Nkoo' => 'Ν’Κο',
        'Ogam' => 'Όγκχαμ',
        'Olck' => 'Ολ Τσίκι',
        'Orkh' => 'Όρκχον',
        'Orya' => 'Όντια',
        'Osma' => 'Οσμάνγια',
        'Perm' => 'Παλαιό Περμικό',
        'Phag' => 'Παγκς-πα',
        'Phli' => 'Επιγραφικό Παχλάβι',
        'Phlp' => 'Ψάλτερ Παχλάβι',
        'Phlv' => 'Μπουκ Παχλαβί',
        'Phnx' => 'Φοινικικό',
        'Plrd' => 'Φωνητικό Πόλαρντ',
        'Prti' => 'Επιγραφικό Παρθιάν',
        'Rjng' => 'Ρετζάνγκ',
        'Rohg' => 'Χανίφι',
        'Roro' => 'Ρονγκορόνγκο',
        'Runr' => 'Ρουνίκ',
        'Samr' => 'Σαμαριτικό',
        'Sara' => 'Σαράθι',
        'Saur' => 'Σαουράστρα',
        'Sgnw' => 'Νοηματική γραφή',
        'Shaw' => 'Σαβιανό',
        'Sinh' => 'Σινχάλα',
        'Sund' => 'Σουνδανικό',
        'Sylo' => 'Συλότι Νάγκρι',
        'Syrc' => 'Συριακό',
        'Syre' => 'Εστραντζέλο Συριακό',
        'Syrj' => 'Δυτικό Συριακό',
        'Syrn' => 'Ανατολικό Συριακό',
        'Tagb' => 'Ταγκμάνγουα',
        'Tale' => 'Τάι Λε',
        'Talu' => 'Νέο Τάι Λούε',
        'Taml' => 'Ταμίλ',
        'Tavt' => 'Τάι Βιέτ',
        'Telu' => 'Τελούγκου',
        'Teng' => 'Τεγνγουάρ',
        'Tfng' => 'Τιφινάγκ',
        'Tglg' => 'Ταγκαλόγκ',
        'Thaa' => 'Θαανά',
        'Thai' => 'Ταϊλανδικό',
        'Tibt' => 'Θιβετιανό',
        'Ugar' => 'Ουγκαριτικό',
        'Vaii' => 'Βάι',
        'Visp' => 'Ορατή ομιλία',
        'Xpeo' => 'Παλαιό Περσικό',
        'Xsux' => 'Σούμερο-Ακάντιαν Κουνεϊφόρμ',
        'Yiii' => 'Γι',
        'Zinh' => 'Κληρονομημένο',
        'Zmth' => 'Μαθηματική σημειογραφία',
        'Zsye' => 'Emoji',
        'Zsym' => 'Σύμβολα',
        'Zxxx' => 'Άγραφο',
        'Zyyy' => 'Κοινό',
    ],
];
