<?php

return [
    'Names' => [
        'aa' => 'อะฟาร์',
        'ab' => 'อับฮาเซีย',
        'ace' => 'อาเจะห์',
        'ach' => 'อาโคลิ',
        'ada' => 'อาแดงมี',
        'ady' => 'อะดืยเก',
        'ae' => 'อเวสตะ',
        'aeb' => 'อาหรับตูนิเซีย',
        'af' => 'แอฟริกานส์',
        'afh' => 'แอฟริฮีลี',
        'agq' => 'อักเฮม',
        'ain' => 'ไอนุ',
        'ak' => 'อาคาน',
        'akk' => 'อักกาด',
        'akz' => 'แอละแบมา',
        'ale' => 'อาลิวต์',
        'aln' => 'เกกแอลเบเนีย',
        'alt' => 'อัลไตใต้',
        'am' => 'อัมฮารา',
        'an' => 'อารากอน',
        'ang' => 'อังกฤษโบราณ',
        'ann' => 'โอโบโล',
        'anp' => 'อังคิกา',
        'ar' => 'อาหรับ',
        'arc' => 'อราเมอิก',
        'arn' => 'มาปูเช',
        'aro' => 'อาเรานา',
        'arp' => 'อาราปาโฮ',
        'arq' => 'อาหรับแอลจีเรีย',
        'ars' => 'อาหรับนัจญ์ดี',
        'arw' => 'อาราวัก',
        'ary' => 'อาหรับโมร็อกโก',
        'arz' => 'อาหรับพื้นเมืองอียิปต์',
        'as' => 'อัสสัม',
        'asa' => 'อาซู',
        'ase' => 'ภาษามืออเมริกัน',
        'ast' => 'อัสตูเรียส',
        'atj' => 'อะทิคาเมก',
        'av' => 'อาวาร์',
        'avk' => 'โคตาวา',
        'awa' => 'อวธี',
        'ay' => 'ไอย์มารา',
        'az' => 'อาเซอร์ไบจาน',
        'ba' => 'บัชคีร์',
        'bal' => 'บาลูชิ',
        'ban' => 'บาหลี',
        'bar' => 'บาวาเรีย',
        'bas' => 'บาสา',
        'bax' => 'บามัน',
        'bbc' => 'บาตักโทบา',
        'bbj' => 'โคมาลา',
        'be' => 'เบลารุส',
        'bej' => 'เบจา',
        'bem' => 'เบมบา',
        'bew' => 'เบตาวี',
        'bez' => 'เบนา',
        'bfd' => 'บาฟัต',
        'bfq' => 'พทคะ',
        'bg' => 'บัลแกเรีย',
        'bgc' => 'หริยนวี',
        'bgn' => 'บาลูจิตะวันตก',
        'bho' => 'โภชปุรี',
        'bi' => 'บิสลามา',
        'bik' => 'บิกอล',
        'bin' => 'บินี',
        'bjn' => 'บันจาร์',
        'bkm' => 'กม',
        'bla' => 'สิกสิกา',
        'blo' => 'อานี',
        'bm' => 'บัมบารา',
        'bn' => 'บังกลา',
        'bo' => 'ทิเบต',
        'bpy' => 'พิศนุปริยะ',
        'bqi' => 'บักติยารี',
        'br' => 'เบรตัน',
        'bra' => 'พัรช',
        'brh' => 'บราฮุย',
        'brx' => 'โพโฑ',
        'bs' => 'บอสเนีย',
        'bss' => 'อาโคซี',
        'bua' => 'บูเรียต',
        'bug' => 'บูกิส',
        'bum' => 'บูลู',
        'byn' => 'บลิน',
        'byv' => 'เมดุมบา',
        'ca' => 'คาตาลัน',
        'cad' => 'คัดโด',
        'car' => 'คาริบ',
        'cay' => 'คายูกา',
        'cch' => 'แอตแซม',
        'ccp' => 'จักม่า',
        'ce' => 'เชเชน',
        'ceb' => 'เซบู',
        'cgg' => 'คีกา',
        'ch' => 'ชามอร์โร',
        'chb' => 'ชิบชา',
        'chg' => 'ชะกะไต',
        'chk' => 'ชูก',
        'chm' => 'มารี',
        'chn' => 'ชินุกจาร์กอน',
        'cho' => 'ช็อกทอว์',
        'chp' => 'ชิพิวยัน',
        'chr' => 'เชอโรกี',
        'chy' => 'เชเยนเน',
        'ckb' => 'เคิร์ดตอนกลาง',
        'clc' => 'ชิลโคติน',
        'co' => 'คอร์ซิกา',
        'cop' => 'คอปติก',
        'cps' => 'กาปิซนอน',
        'cr' => 'ครี',
        'crg' => 'มิชิฟ',
        'crh' => 'ตุรกีไครเมีย',
        'crj' => 'ครีตะวันออกเฉียงใต้',
        'crk' => 'เพลนส์ครี',
        'crl' => 'ครีตะวันออกเฉียงเหนือ',
        'crm' => 'มูสครี',
        'crr' => 'อัลกอนควินแคโรไลนา',
        'crs' => 'ครีโอลเซเซลส์ฝรั่งเศส',
        'cs' => 'เช็ก',
        'csb' => 'คาซูเบียน',
        'csw' => 'สวอมปีครี',
        'cu' => 'เชอร์ชสลาวิก',
        'cv' => 'ชูวัช',
        'cy' => 'เวลส์',
        'da' => 'เดนมาร์ก',
        'dak' => 'ดาโกทา',
        'dar' => 'ดาร์กิน',
        'dav' => 'ไททา',
        'de' => 'เยอรมัน',
        'del' => 'เดลาแวร์',
        'den' => 'สเลวี',
        'dgr' => 'โดกริบ',
        'din' => 'ดิงกา',
        'dje' => 'ซาร์มา',
        'doi' => 'โฑครี',
        'dsb' => 'ซอร์เบียตอนล่าง',
        'dtp' => 'ดูซุนกลาง',
        'dua' => 'ดัวลา',
        'dum' => 'ดัตช์กลาง',
        'dv' => 'ธิเวหิ',
        'dyo' => 'โจลา-ฟอนยี',
        'dyu' => 'ดิวลา',
        'dz' => 'ซองคา',
        'dzg' => 'ดาซากา',
        'ebu' => 'เอ็มบู',
        'ee' => 'เอเว',
        'efi' => 'อีฟิก',
        'egl' => 'เอมีเลีย',
        'egy' => 'อียิปต์โบราณ',
        'eka' => 'อีกาจุก',
        'el' => 'กรีก',
        'elx' => 'อีลาไมต์',
        'en' => 'อังกฤษ',
        'enm' => 'อังกฤษกลาง',
        'eo' => 'เอสเปรันโต',
        'es' => 'สเปน',
        'esu' => 'ยูพิกกลาง',
        'et' => 'เอสโตเนีย',
        'eu' => 'บาสก์',
        'ewo' => 'อีวันโด',
        'ext' => 'เอกซ์เตรมาดูรา',
        'fa' => 'เปอร์เซีย',
        'fan' => 'ฟอง',
        'fat' => 'ฟันติ',
        'ff' => 'ฟูลาห์',
        'fi' => 'ฟินแลนด์',
        'fil' => 'ฟิลิปปินส์',
        'fit' => 'ฟินแลนด์ทอร์เนดาเล็น',
        'fj' => 'ฟิจิ',
        'fo' => 'แฟโร',
        'fon' => 'ฟอน',
        'fr' => 'ฝรั่งเศส',
        'frc' => 'ฝรั่งเศสเคจัน',
        'frm' => 'ฝรั่งเศสกลาง',
        'fro' => 'ฝรั่งเศสโบราณ',
        'frp' => 'อาร์พิตา',
        'frr' => 'ฟริเซียนเหนือ',
        'frs' => 'ฟริเซียนตะวันออก',
        'fur' => 'ฟรูลี',
        'fy' => 'ฟริเซียนตะวันตก',
        'ga' => 'ไอริช',
        'gaa' => 'กา',
        'gag' => 'กากาอุซ',
        'gan' => 'จีนกั้น',
        'gay' => 'กาโย',
        'gba' => 'กบายา',
        'gbz' => 'ดารีโซโรอัสเตอร์',
        'gd' => 'เกลิกสกอต',
        'gez' => 'กีซ',
        'gil' => 'กิลเบอร์ต',
        'gl' => 'กาลิเซีย',
        'glk' => 'กิลากี',
        'gmh' => 'เยอรมันสูงกลาง',
        'gn' => 'กัวรานี',
        'goh' => 'เยอรมันสูงโบราณ',
        'gon' => 'กอนดิ',
        'gor' => 'กอรอนทาโล',
        'got' => 'โกธิก',
        'grb' => 'เกรโบ',
        'grc' => 'กรีกโบราณ',
        'gsw' => 'เยอรมันสวิส',
        'gu' => 'คุชราต',
        'guc' => 'วายู',
        'gur' => 'ฟราฟรา',
        'guz' => 'กุซซี',
        'gv' => 'มานซ์',
        'gwi' => 'กวิชอิน',
        'ha' => 'เฮาซา',
        'hai' => 'ไฮดา',
        'hak' => 'จีนแคะ',
        'haw' => 'ฮาวาย',
        'hax' => 'เฮดาใต้',
        'he' => 'ฮิบรู',
        'hi' => 'ฮินดี',
        'hif' => 'ฮินดีฟิจิ',
        'hil' => 'ฮีลีกัยนน',
        'hit' => 'ฮิตไตต์',
        'hmn' => 'ม้ง',
        'ho' => 'ฮีรีโมตู',
        'hr' => 'โครเอเชีย',
        'hsb' => 'ซอร์เบียตอนบน',
        'hsn' => 'จีนเซียง',
        'ht' => 'เฮติครีโอล',
        'hu' => 'ฮังการี',
        'hup' => 'ฮูปา',
        'hur' => 'ฮัลโกเมเลม',
        'hy' => 'อาร์เมเนีย',
        'hz' => 'เฮเรโร',
        'ia' => 'อินเตอร์ลิงกัว',
        'iba' => 'อิบาน',
        'ibb' => 'อิบิบิโอ',
        'id' => 'อินโดนีเซีย',
        'ie' => 'อินเตอร์ลิงกิว',
        'ig' => 'อิกโบ',
        'ii' => 'เสฉวนยี่',
        'ik' => 'อีนูเปียก',
        'ikt' => 'อินุกติตุตแคนาดาตะวันตก',
        'ilo' => 'อีโลโก',
        'inh' => 'อินกุช',
        'io' => 'อีโด',
        'is' => 'ไอซ์แลนด์',
        'it' => 'อิตาลี',
        'iu' => 'อินุกติตุต',
        'izh' => 'อินเกรียน',
        'ja' => 'ญี่ปุ่น',
        'jam' => 'อังกฤษคลีโอลจาเมกา',
        'jbo' => 'โลชบัน',
        'jgo' => 'อึนกอมบา',
        'jmc' => 'มาชาเม',
        'jpr' => 'ยิว-เปอร์เซีย',
        'jrb' => 'ยิว-อาหรับ',
        'jut' => 'จัท',
        'jv' => 'ชวา',
        'ka' => 'จอร์เจีย',
        'kaa' => 'การา-กาลพาก',
        'kab' => 'กาไบล',
        'kac' => 'กะฉิ่น',
        'kaj' => 'คจู',
        'kam' => 'คัมบา',
        'kaw' => 'กวี',
        'kbd' => 'คาบาร์เดีย',
        'kbl' => 'คาเนมบู',
        'kcg' => 'ทีแยป',
        'kde' => 'มาคอนเด',
        'kea' => 'คาบูเวอร์เดียนู',
        'ken' => 'เกินยาง',
        'kfo' => 'โคโร',
        'kg' => 'คองโก',
        'kgp' => 'เคนก่าง',
        'kha' => 'กาสี',
        'kho' => 'โคตัน',
        'khq' => 'โคย์ราชีนี',
        'khw' => 'โควาร์',
        'ki' => 'กีกูยู',
        'kiu' => 'เคอร์มานิกิ',
        'kj' => 'กวนยามา',
        'kk' => 'คาซัค',
        'kkj' => 'คาโก',
        'kl' => 'กรีนแลนด์',
        'kln' => 'คาเลนจิน',
        'km' => 'เขมร',
        'kmb' => 'คิมบุนดู',
        'kn' => 'กันนาดา',
        'ko' => 'เกาหลี',
        'koi' => 'โคมิ-เปียร์เมียค',
        'kok' => 'กอนกานี',
        'kos' => 'คูสไร',
        'kpe' => 'กาแปล',
        'kr' => 'คานูรี',
        'krc' => 'คาราไช-บัลคาร์',
        'kri' => 'คริโอ',
        'krj' => 'กินารายอา',
        'krl' => 'คารีเลียน',
        'kru' => 'กุรุข',
        'ks' => 'แคชเมียร์',
        'ksb' => 'ชัมบาลา',
        'ksf' => 'บาเฟีย',
        'ksh' => 'โคโลญ',
        'ku' => 'เคิร์ด',
        'kum' => 'คูมืยค์',
        'kut' => 'คูเทไน',
        'kv' => 'โกมิ',
        'kw' => 'คอร์นิช',
        'kwk' => 'ควักวาลา',
        'kxv' => 'กูวี',
        'ky' => 'คีร์กีซ',
        'la' => 'ละติน',
        'lad' => 'ลาดิโน',
        'lag' => 'แลนจี',
        'lah' => 'ลาฮ์นดา',
        'lam' => 'แลมบา',
        'lb' => 'ลักเซมเบิร์ก',
        'lez' => 'เลซเกีย',
        'lfn' => 'ลิงกัวฟรังกาโนวา',
        'lg' => 'ยูกันดา',
        'li' => 'ลิมเบิร์ก',
        'lij' => 'ลิกูเรีย',
        'lil' => 'ลิลลูเอต',
        'liv' => 'ลิโวเนีย',
        'lkt' => 'ลาโกตา',
        'lmo' => 'ลอมบาร์ด',
        'ln' => 'ลิงกาลา',
        'lo' => 'ลาว',
        'lol' => 'มองโก',
        'lou' => 'ครีโอลุยเซียนา',
        'loz' => 'โลซิ',
        'lrc' => 'ลูรีเหนือ',
        'lsm' => 'ซาเมีย',
        'lt' => 'ลิทัวเนีย',
        'ltg' => 'ลัตเกล',
        'lu' => 'ลูบา-กาตองกา',
        'lua' => 'ลูบา-ลูลัว',
        'lui' => 'ลุยเซโน',
        'lun' => 'ลันดา',
        'luo' => 'ลัว',
        'lus' => 'มิโซ',
        'luy' => 'ลูเยีย',
        'lv' => 'ลัตเวีย',
        'lzh' => 'จีนคลาสสิก',
        'lzz' => 'แลซ',
        'mad' => 'มาดูรา',
        'maf' => 'มาฟา',
        'mag' => 'มคหี',
        'mai' => 'ไมถิลี',
        'mak' => 'มากาซาร์',
        'man' => 'มันดิงกา',
        'mas' => 'มาไซ',
        'mde' => 'มาบา',
        'mdf' => 'มอคชา',
        'mdr' => 'มานดาร์',
        'men' => 'เมนเด',
        'mer' => 'เมรู',
        'mfe' => 'มอริสเยน',
        'mg' => 'มาลากาซี',
        'mga' => 'ไอริชกลาง',
        'mgh' => 'มากัววา-มีทโท',
        'mgo' => 'เมตา',
        'mh' => 'มาร์แชลล์',
        'mi' => 'เมารี',
        'mic' => 'มิกแมก',
        'min' => 'มีนังกาเบา',
        'mk' => 'มาซิโดเนีย',
        'ml' => 'มาลายาลัม',
        'mn' => 'มองโกเลีย',
        'mnc' => 'แมนจู',
        'mni' => 'มณีปุระ',
        'moe' => 'อินนุ-ไอมุน',
        'moh' => 'โมฮอว์ก',
        'mos' => 'โมซี',
        'mr' => 'มราฐี',
        'mrj' => 'มารีตะวันตก',
        'ms' => 'มาเลย์',
        'mt' => 'มอลตา',
        'mua' => 'มันดัง',
        'mus' => 'มัสคีกี',
        'mwl' => 'มีรันดา',
        'mwr' => 'มารวาฑี',
        'mwv' => 'เม็นตาไว',
        'my' => 'พม่า',
        'mye' => 'มยีน',
        'myv' => 'เอียร์ซยา',
        'mzn' => 'มาซันดารานี',
        'na' => 'นาอูรู',
        'nan' => 'จีนมินหนาน',
        'nap' => 'นาโปลี',
        'naq' => 'นามา',
        'nb' => 'นอร์เวย์บุคมอล',
        'nd' => 'เอ็นเดเบเลเหนือ',
        'nds' => 'เยอรมันต่ำ',
        'ne' => 'เนปาล',
        'new' => 'เนวาร์',
        'ng' => 'ดองกา',
        'nia' => 'นีอัส',
        'niu' => 'นีวเว',
        'njo' => 'อ๋าวนากา',
        'nl' => 'ดัตช์',
        'nmg' => 'กวาซิโอ',
        'nn' => 'นอร์เวย์นีนอสก์',
        'nnh' => 'จีมบูน',
        'no' => 'นอร์เวย์',
        'nog' => 'โนไก',
        'non' => 'นอร์สโบราณ',
        'nov' => 'โนเวียล',
        'nqo' => 'เอ็นโก',
        'nr' => 'เอ็นเดเบเลใต้',
        'nso' => 'โซโทเหนือ',
        'nus' => 'เนือร์',
        'nv' => 'นาวาโฮ',
        'nwc' => 'เนวาร์ดั้งเดิม',
        'ny' => 'เนียนจา',
        'nym' => 'เนียมเวซี',
        'nyn' => 'เนียนโกเล',
        'nyo' => 'นิโอโร',
        'nzi' => 'นซิมา',
        'oc' => 'อ็อกซิตัน',
        'oj' => 'โอจิบวา',
        'ojb' => 'โอจิบเวตะวันตกเฉียงเหนือ',
        'ojc' => 'โอจิบเวตอนกลาง',
        'ojs' => 'ออจิ-ครี',
        'ojw' => 'โอจิบเวตะวันตก',
        'oka' => 'โอคานากัน',
        'om' => 'โอโรโม',
        'or' => 'โอดิยา',
        'os' => 'ออสเซเตีย',
        'osa' => 'โอซากี',
        'ota' => 'ตุรกีออตโตมัน',
        'pa' => 'ปัญจาบ',
        'pag' => 'ปังกาซีนัน',
        'pal' => 'ปะห์ลาวี',
        'pam' => 'ปัมปังกา',
        'pap' => 'ปาเปียเมนโต',
        'pau' => 'ปาเลา',
        'pcd' => 'ปิการ์',
        'pcm' => 'ไนจีเรียนพิดจิน',
        'pdc' => 'เยอรมันเพนซิลเวเนีย',
        'pdt' => 'เพลาท์ดิช',
        'peo' => 'เปอร์เซียโบราณ',
        'pfl' => 'เยอรมันพาลาทิเนต',
        'phn' => 'ฟินิเชีย',
        'pi' => 'บาลี',
        'pis' => 'พิดจิน',
        'pl' => 'โปแลนด์',
        'pms' => 'พีดมอนต์',
        'pnt' => 'พอนติก',
        'pon' => 'พอห์นเพ',
        'pqm' => 'มาเลไซท์-ปัสมาโควดี',
        'prg' => 'ปรัสเซีย',
        'pro' => 'โปรวองซาลโบราณ',
        'ps' => 'พัชโต',
        'pt' => 'โปรตุเกส',
        'qu' => 'เคชวา',
        'quc' => 'กีเช',
        'qug' => 'ควิชัวไฮแลนด์ชิมโบราโซ',
        'raj' => 'ราชสถาน',
        'rap' => 'ราปานูอี',
        'rar' => 'ราโรทองกา',
        'rgn' => 'โรมัณโญ',
        'rhg' => 'โรฮิงญา',
        'rif' => 'ริฟฟิอัน',
        'rm' => 'โรแมนซ์',
        'rn' => 'บุรุนดี',
        'ro' => 'โรมาเนีย',
        'rof' => 'รอมโบ',
        'rom' => 'โรมานี',
        'rtm' => 'โรทูมัน',
        'ru' => 'รัสเซีย',
        'rue' => 'รูซิน',
        'rug' => 'โรเวียนา',
        'rup' => 'อาโรมาเนีย',
        'rw' => 'รวันดา',
        'rwk' => 'รวา',
        'sa' => 'สันสกฤต',
        'sad' => 'ซันดาเว',
        'sah' => 'ซาคา',
        'sam' => 'อราเมอิกซามาเรีย',
        'saq' => 'แซมบูรู',
        'sas' => 'ซาซัก',
        'sat' => 'สันตาลี',
        'saz' => 'เสาราษฏร์',
        'sba' => 'กัมเบ',
        'sbp' => 'แซงกู',
        'sc' => 'ซาร์เดญา',
        'scn' => 'ซิซิลี',
        'sco' => 'สกอตส์',
        'sd' => 'สินธิ',
        'sdc' => 'ซาร์ดิเนียซาสซารี',
        'sdh' => 'เคอร์ดิชใต้',
        'se' => 'ซามิเหนือ',
        'see' => 'เซนิกา',
        'seh' => 'เซนา',
        'sei' => 'เซรี',
        'sel' => 'เซลคุป',
        'ses' => 'โคย์ราโบโรเซนนี',
        'sg' => 'ซันโก',
        'sga' => 'ไอริชโบราณ',
        'sgs' => 'ซาโมจิเตียน',
        'sh' => 'เซอร์โบ-โครเอเชีย',
        'shi' => 'ทาเชลีห์ท',
        'shn' => 'ไทใหญ่',
        'shu' => 'อาหรับ-ชาด',
        'si' => 'สิงหล',
        'sid' => 'ซิดาโม',
        'sk' => 'สโลวัก',
        'sl' => 'สโลวีเนีย',
        'slh' => 'ลูชูตซีดใต้',
        'sli' => 'ไซลีเซียตอนล่าง',
        'sly' => 'เซลายาร์',
        'sm' => 'ซามัว',
        'sma' => 'ซามิใต้',
        'smj' => 'ซามิลูเล',
        'smn' => 'ซามิอีนารี',
        'sms' => 'ซามิสคอลต์',
        'sn' => 'โชนา',
        'snk' => 'โซนีนเก',
        'so' => 'โซมาลี',
        'sog' => 'ซอกดีน',
        'sq' => 'แอลเบเนีย',
        'sr' => 'เซอร์เบีย',
        'srn' => 'สรานานตองโก',
        'srr' => 'เซแรร์',
        'ss' => 'สวาติ',
        'ssy' => 'ซาโฮ',
        'st' => 'โซโทใต้',
        'stq' => 'ฟรีเซียนซัทเธอร์แลนด์',
        'str' => 'สเตรตส์ซาลิช',
        'su' => 'ซุนดา',
        'suk' => 'ซูคูมา',
        'sus' => 'ซูซู',
        'sux' => 'ซูเมอ',
        'sv' => 'สวีเดน',
        'sw' => 'สวาฮีลี',
        'swb' => 'โคเมอเรีย',
        'syc' => 'ซีเรียแบบดั้งเดิม',
        'syr' => 'ซีเรีย',
        'szl' => 'ไซลีเซีย',
        'ta' => 'ทมิฬ',
        'tce' => 'ทัชโชนใต้',
        'tcy' => 'ตูลู',
        'te' => 'เตลูกู',
        'tem' => 'ทิมเน',
        'teo' => 'เตโซ',
        'ter' => 'เทเรโน',
        'tet' => 'เตตุม',
        'tg' => 'ทาจิก',
        'tgx' => 'ทากิช',
        'th' => 'ไทย',
        'tht' => 'ทาลทาน',
        'ti' => 'ติกริญญา',
        'tig' => 'ตีเกร',
        'tiv' => 'ทิฟ',
        'tk' => 'เติร์กเมน',
        'tkl' => 'โตเกเลา',
        'tkr' => 'แซคเซอร์',
        'tl' => 'ตากาล็อก',
        'tlh' => 'คลิงงอน',
        'tli' => 'ทลิงกิต',
        'tly' => 'ทาลิช',
        'tmh' => 'ทามาเชก',
        'tn' => 'สวานา',
        'to' => 'ตองกา',
        'tog' => 'ไนอะซาตองกา',
        'tok' => 'โทคิโพนา',
        'tpi' => 'ท็อกพิซิน',
        'tr' => 'ตุรกี',
        'tru' => 'ตูโรโย',
        'trv' => 'ทาโรโก',
        'ts' => 'ซองกา',
        'tsd' => 'ซาโคเนีย',
        'tsi' => 'ซิมชีแอน',
        'tt' => 'ตาตาร์',
        'ttm' => 'ทัชโชนเหนือ',
        'ttt' => 'ตัตมุสลิม',
        'tum' => 'ทุมบูกา',
        'tvl' => 'ตูวาลู',
        'tw' => 'ทวิ',
        'twq' => 'ตัสซาวัค',
        'ty' => 'ตาฮิตี',
        'tyv' => 'ตูวา',
        'tzm' => 'ทามาไซต์แอตลาสกลาง',
        'udm' => 'อุดมูร์ต',
        'ug' => 'อุยกูร์',
        'uga' => 'ยูการิต',
        'uk' => 'ยูเครน',
        'umb' => 'อุมบุนดู',
        'ur' => 'อูรดู',
        'uz' => 'อุซเบก',
        'vai' => 'ไว',
        've' => 'เวนดา',
        'vec' => 'เวเนโต้',
        'vep' => 'เวปส์',
        'vi' => 'เวียดนาม',
        'vls' => 'เฟลมิชตะวันตก',
        'vmf' => 'เมน-ฟรานโกเนีย',
        'vmw' => 'มากัววา',
        'vo' => 'โวลาพึค',
        'vot' => 'โวทิก',
        'vro' => 'โวโร',
        'vun' => 'วุนจู',
        'wa' => 'วอลลูน',
        'wae' => 'วัลเซอร์',
        'wal' => 'โวแลตตา',
        'war' => 'วาเรย์',
        'was' => 'วาโช',
        'wbp' => 'วอล์เพอร์รี',
        'wo' => 'โวลอฟ',
        'wuu' => 'จีนอู๋',
        'xal' => 'คัลมืยค์',
        'xh' => 'คะห์โอซา',
        'xmf' => 'เมเกรเลีย',
        'xnr' => 'กังกรี',
        'xog' => 'โซกา',
        'yao' => 'เย้า',
        'yap' => 'ยัป',
        'yav' => 'แยงเบน',
        'ybb' => 'เยมบา',
        'yi' => 'ยิดดิช',
        'yo' => 'โยรูบา',
        'yrl' => 'เหงงกาตุ',
        'yue' => 'กวางตุ้ง',
        'za' => 'จ้วง',
        'zap' => 'ซาโปเตก',
        'zbl' => 'บลิสซิมโบลส์',
        'zea' => 'เซแลนด์',
        'zen' => 'เซนากา',
        'zgh' => 'ทามาไซต์โมร็อกโกมาตรฐาน',
        'zh' => 'จีน',
        'zu' => 'ซูลู',
        'zun' => 'ซูนิ',
        'zza' => 'ซาซา',
    ],
    'LocalizedNames' => [
        'ar_001' => 'อาหรับมาตรฐานสมัยใหม่',
        'de_AT' => 'เยอรมัน - ออสเตรีย',
        'de_CH' => 'เยอรมันสูง (สวิส)',
        'en_AU' => 'อังกฤษ - ออสเตรเลีย',
        'en_CA' => 'อังกฤษ - แคนาดา',
        'en_GB' => 'อังกฤษ - สหราชอาณาจักร',
        'en_US' => 'อังกฤษ - สหรัฐอเมริกา',
        'es_419' => 'สเปน - ละตินอเมริกา',
        'es_ES' => 'สเปน - ยุโรป',
        'es_MX' => 'สเปน - เม็กซิโก',
        'fa_AF' => 'ดารี',
        'fr_CA' => 'ฝรั่งเศส - แคนาดา',
        'fr_CH' => 'ฝรั่งเศส - สวิส',
        'nds_NL' => 'แซกซอนใต้',
        'nl_BE' => 'เฟลมิช',
        'pt_BR' => 'โปรตุเกส - บราซิล',
        'pt_PT' => 'โปรตุเกส - ยุโรป',
        'ro_MD' => 'มอลโดวา',
        'sw_CD' => 'สวาฮีลี - คองโก',
        'zh_Hans' => 'จีนตัวย่อ',
        'zh_Hant' => 'จีนตัวเต็ม',
    ],
];
