<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'andorska pezeta',
        ],
        'AED' => [
            'AED',
            'UAE dirham',
        ],
        'AFA' => [
            'AFA',
            'afganistanski afgani (1927.–2002.)',
        ],
        'AFN' => [
            'AFN',
            'afganistanski afgani',
        ],
        'ALK' => [
            'ALK',
            'stari albanski lek',
        ],
        'ALL' => [
            'ALL',
            'albanski lek',
        ],
        'AMD' => [
            'AMD',
            'armenski dram',
        ],
        'ANG' => [
            'ANG',
            'nizozemskoantilski gulden',
        ],
        'AOA' => [
            'AOA',
            'angolska kvanza',
        ],
        'AOK' => [
            'AOK',
            'angolska kvanza (1977.–1990.)',
        ],
        'AON' => [
            'AON',
            'angolska nova kvanza (1990.–2000.)',
        ],
        'AOR' => [
            'AOR',
            'angolska kvanza (1995.–1999.)',
        ],
        'ARA' => [
            'ARA',
            'argentinski austral',
        ],
        'ARL' => [
            'ARL',
            'argentinski pezo lej (1970.–1983.)',
        ],
        'ARM' => [
            'ARM',
            'argentinski pezo (1881.–1970.)',
        ],
        'ARP' => [
            'ARP',
            'argentinski pezo (1983.–1985.)',
        ],
        'ARS' => [
            'ARS',
            'argentinski pezo',
        ],
        'ATS' => [
            'ATS',
            'austrijski šiling',
        ],
        'AUD' => [
            'AUD',
            'australski dolar',
        ],
        'AWG' => [
            'AWG',
            'arupski florin',
        ],
        'AZM' => [
            'AZM',
            'azerbajdžanski manat (1993.–2006.)',
        ],
        'AZN' => [
            'AZN',
            'azerbajdžanski manat',
        ],
        'BAD' => [
            'BAD',
            'bosansko-hercegovački dinar',
        ],
        'BAM' => [
            'BAM',
            'konvertibilna marka',
        ],
        'BAN' => [
            'BAN',
            'bosansko-hercegovački novi dinar',
        ],
        'BBD' => [
            'BBD',
            'barbadoski dolar',
        ],
        'BDT' => [
            'BDT',
            'bangladeška taka',
        ],
        'BEC' => [
            'BEC',
            'belgijski franak (konvertibilan)',
        ],
        'BEF' => [
            'BEF',
            'belgijski franak',
        ],
        'BEL' => [
            'BEL',
            'belgijski franak (financijski)',
        ],
        'BGL' => [
            'BGL',
            'bugarski čvrsti lev',
        ],
        'BGM' => [
            'BGM',
            'bugarski socijalistički lev',
        ],
        'BGN' => [
            'BGN',
            'bugarski lev',
        ],
        'BGO' => [
            'BGO',
            'stari bugarski lev',
        ],
        'BHD' => [
            'BHD',
            'bahreinski dinar',
        ],
        'BIF' => [
            'BIF',
            'burundski franak',
        ],
        'BMD' => [
            'BMD',
            'bermudski dolar',
        ],
        'BND' => [
            'BND',
            'brunejski dolar',
        ],
        'BOB' => [
            'BOB',
            'bolivijski bolivijano',
        ],
        'BOL' => [
            'BOL',
            'stari bolivijski bolivijano',
        ],
        'BOP' => [
            'BOP',
            'bolivijski pezo',
        ],
        'BOV' => [
            'BOV',
            'bolivijski mvdol',
        ],
        'BRB' => [
            'BRB',
            'brazilski novi cruzeiro (1967.–1986.)',
        ],
        'BRC' => [
            'BRC',
            'brazilski cruzado',
        ],
        'BRE' => [
            'BRE',
            'brazilski cruzeiro (1990.–1993.)',
        ],
        'BRL' => [
            'BRL',
            'brazilski real',
        ],
        'BRN' => [
            'BRN',
            'brazilski novi cruzado',
        ],
        'BRR' => [
            'BRR',
            'brazilski cruzeiro',
        ],
        'BSD' => [
            'BSD',
            'bahamski dolar',
        ],
        'BTN' => [
            'BTN',
            'butanski ngultrum',
        ],
        'BUK' => [
            'BUK',
            'burmanski kyat',
        ],
        'BWP' => [
            'BWP',
            'bocvanska pula',
        ],
        'BYB' => [
            'BYB',
            'bjeloruska nova rublja (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'bjeloruski rubalj',
        ],
        'BYR' => [
            'BYR',
            'bjeloruska rublja (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'belizeanski dolar',
        ],
        'CAD' => [
            'CAD',
            'kanadski dolar',
        ],
        'CDF' => [
            'CDF',
            'kongoanski franak',
        ],
        'CHE' => [
            'CHE',
            'WIR euro',
        ],
        'CHF' => [
            'CHF',
            'švicarski franak',
        ],
        'CHW' => [
            'CHW',
            'WIR franak',
        ],
        'CLE' => [
            'CLE',
            'čileanski eskudo',
        ],
        'CLF' => [
            'CLF',
            'čileanski unidades de fomentos',
        ],
        'CLP' => [
            'CLP',
            'čileanski pezo',
        ],
        'CNH' => [
            'CNH',
            'kineski juan (offshore)',
        ],
        'CNX' => [
            'CNX',
            'kineski narodni dolar',
        ],
        'CNY' => [
            'CNY',
            'kineski yuan',
        ],
        'COP' => [
            'COP',
            'kolumbijski pezo',
        ],
        'COU' => [
            'COU',
            'unidad de valor real',
        ],
        'CRC' => [
            'CRC',
            'kostarikanski kolon',
        ],
        'CSD' => [
            'CSD',
            'stari srpski dinar',
        ],
        'CSK' => [
            'CSK',
            'čehoslovačka kruna',
        ],
        'CUC' => [
            'CUC',
            'kubanski konvertibilni pezo',
        ],
        'CUP' => [
            'CUP',
            'kubanski pezo',
        ],
        'CVE' => [
            'CVE',
            'zelenortski eskudo',
        ],
        'CYP' => [
            'CYP',
            'ciparska funta',
        ],
        'CZK' => [
            'CZK',
            'češka kruna',
        ],
        'DDM' => [
            'DDM',
            'istočnonjemačka marka',
        ],
        'DEM' => [
            'DEM',
            'njemačka marka',
        ],
        'DJF' => [
            'DJF',
            'džibutski franak',
        ],
        'DKK' => [
            'DKK',
            'danska kruna',
        ],
        'DOP' => [
            'DOP',
            'dominikanski pezo',
        ],
        'DZD' => [
            'DZD',
            'alžirski dinar',
        ],
        'ECS' => [
            'ECS',
            'ekvatorska sukra',
        ],
        'ECV' => [
            'ECV',
            'ekvatorski unidad de valor constante (UVC)',
        ],
        'EEK' => [
            'EEK',
            'estonska kruna',
        ],
        'EGP' => [
            'EGP',
            'egipatska funta',
        ],
        'ERN' => [
            'ERN',
            'eritrejska nakfa',
        ],
        'ESA' => [
            'ESA',
            'španjolska pezeta (A račun)',
        ],
        'ESB' => [
            'ESB',
            'španjolska pezeta (konvertibilni račun)',
        ],
        'ESP' => [
            'ESP',
            'španjolska pezeta',
        ],
        'ETB' => [
            'ETB',
            'etiopski bir',
        ],
        'EUR' => [
            '€',
            'euro',
        ],
        'FIM' => [
            'FIM',
            'finska marka',
        ],
        'FJD' => [
            'FJD',
            'fidžijski dolar',
        ],
        'FKP' => [
            'FKP',
            'falklandska funta',
        ],
        'FRF' => [
            'FRF',
            'francuski franak',
        ],
        'GBP' => [
            'GBP',
            'britanska funta',
        ],
        'GEK' => [
            'GEK',
            'gruzijski kupon larit',
        ],
        'GEL' => [
            'GEL',
            'gruzijski lari',
        ],
        'GHC' => [
            'GHC',
            'ganski cedi (1979.–2007.)',
        ],
        'GHS' => [
            'GHS',
            'ganski cedi',
        ],
        'GIP' => [
            'GIP',
            'gibraltarska funta',
        ],
        'GMD' => [
            'GMD',
            'gambijski dalas',
        ],
        'GNF' => [
            'GNF',
            'gvinejski franak',
        ],
        'GNS' => [
            'GNS',
            'gvinejski syli',
        ],
        'GQE' => [
            'GQE',
            'ekvatorski gvinejski ekwele',
        ],
        'GRD' => [
            'GRD',
            'grčka drahma',
        ],
        'GTQ' => [
            'GTQ',
            'gvatemalski kvecal',
        ],
        'GWE' => [
            'GWE',
            'portugalski gvinejski eskudo',
        ],
        'GWP' => [
            'GWP',
            'gvinejskobisauski pezo',
        ],
        'GYD' => [
            'GYD',
            'gvajanski dolar',
        ],
        'HKD' => [
            'HKD',
            'hongkonški dolar',
        ],
        'HNL' => [
            'HNL',
            'honduraška lempira',
        ],
        'HRD' => [
            'HRD',
            'hrvatski dinar',
        ],
        'HRK' => [
            'kn',
            'hrvatska kuna',
        ],
        'HTG' => [
            'HTG',
            'haićanski gourd',
        ],
        'HUF' => [
            'HUF',
            'mađarska forinta',
        ],
        'IDR' => [
            'IDR',
            'indonezijska rupija',
        ],
        'IEP' => [
            'IEP',
            'irska funta',
        ],
        'ILP' => [
            'ILP',
            'izraelska funta',
        ],
        'ILR' => [
            'ILR',
            'stari izraelski šekel',
        ],
        'ILS' => [
            'ILS',
            'novi izraelski šekel',
        ],
        'INR' => [
            'INR',
            'indijska rupija',
        ],
        'IQD' => [
            'IQD',
            'irački dinar',
        ],
        'IRR' => [
            'IRR',
            'iranski rijal',
        ],
        'ISJ' => [
            'ISJ',
            'stara islandska kruna',
        ],
        'ISK' => [
            'ISK',
            'islandska kruna',
        ],
        'ITL' => [
            'ITL',
            'talijanska lira',
        ],
        'JMD' => [
            'JMD',
            'jamajčanski dolar',
        ],
        'JOD' => [
            'JOD',
            'jordanski dinar',
        ],
        'JPY' => [
            'JPY',
            'japanski jen',
        ],
        'KES' => [
            'KES',
            'kenijski šiling',
        ],
        'KGS' => [
            'KGS',
            'kirgiski som',
        ],
        'KHR' => [
            'KHR',
            'kambodžanski rijal',
        ],
        'KMF' => [
            'KMF',
            'komorski franak',
        ],
        'KPW' => [
            'KPW',
            'sjevernokorejski won',
        ],
        'KRH' => [
            'KRH',
            'južnokorejski hvan',
        ],
        'KRO' => [
            'KRO',
            'stari južnokorejski von',
        ],
        'KRW' => [
            'KRW',
            'južnokorejski won',
        ],
        'KWD' => [
            'KWD',
            'kuvajtski dinar',
        ],
        'KYD' => [
            'KYD',
            'kajmanski dolar',
        ],
        'KZT' => [
            'KZT',
            'kazahstanski tenge',
        ],
        'LAK' => [
            'LAK',
            'laoski kip',
        ],
        'LBP' => [
            'LBP',
            'libanonska funta',
        ],
        'LKR' => [
            'LKR',
            'šrilankanska rupija',
        ],
        'LRD' => [
            'LRD',
            'liberijski dolar',
        ],
        'LSL' => [
            'LSL',
            'lesotski loti',
        ],
        'LTL' => [
            'LTL',
            'litavski litas',
        ],
        'LTT' => [
            'LTT',
            'litavski talonas',
        ],
        'LUC' => [
            'LUC',
            'luksemburški konvertibilni franak',
        ],
        'LUF' => [
            'LUF',
            'luksemburški franak',
        ],
        'LUL' => [
            'LUL',
            'luksemburški financijski franak',
        ],
        'LVL' => [
            'LVL',
            'letonski lats',
        ],
        'LVR' => [
            'LVR',
            'letonska rublja',
        ],
        'LYD' => [
            'LYD',
            'libijski dinar',
        ],
        'MAD' => [
            'MAD',
            'marokanski dirham',
        ],
        'MAF' => [
            'MAF',
            'marokanski franak',
        ],
        'MDC' => [
            'MDC',
            'moldavski kupon',
        ],
        'MDL' => [
            'MDL',
            'moldavski lej',
        ],
        'MGA' => [
            'MGA',
            'malgaški arijari',
        ],
        'MGF' => [
            'MGF',
            'madagaskarski franak',
        ],
        'MKD' => [
            'MKD',
            'makedonski denar',
        ],
        'MKN' => [
            'MKN',
            'stari makedonski denar',
        ],
        'MLF' => [
            'MLF',
            'malijski franak',
        ],
        'MMK' => [
            'MMK',
            'mjanmarski kjat',
        ],
        'MNT' => [
            'MNT',
            'mongolski tugrik',
        ],
        'MOP' => [
            'MOP',
            'makaoška pataka',
        ],
        'MRO' => [
            'MRO',
            'mauritanijska ouguja (1973. – 2017.)',
        ],
        'MRU' => [
            'MRU',
            'mauretanska ouguja',
        ],
        'MTL' => [
            'MTL',
            'malteška lira',
        ],
        'MTP' => [
            'MTP',
            'malteška funta',
        ],
        'MUR' => [
            'MUR',
            'mauricijska rupija',
        ],
        'MVP' => [
            'MVP',
            'maldivijska rupija',
        ],
        'MVR' => [
            'MVR',
            'maldivijska rufija',
        ],
        'MWK' => [
            'MWK',
            'malavijska kvača',
        ],
        'MXN' => [
            'MXN',
            'meksički pezo',
        ],
        'MXP' => [
            'MXP',
            'meksički srebrni pezo (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'meksički unidad de inversion (UDI)',
        ],
        'MYR' => [
            'MYR',
            'malezijski ringit',
        ],
        'MZE' => [
            'MZE',
            'mozambijski eskudo',
        ],
        'MZM' => [
            'MZM',
            'stari mozambijski metikal',
        ],
        'MZN' => [
            'MZN',
            'mozambički metikal',
        ],
        'NAD' => [
            'NAD',
            'namibijski dolar',
        ],
        'NGN' => [
            'NGN',
            'nigerijska naira',
        ],
        'NIC' => [
            'NIC',
            'nikaragvanska kordoba',
        ],
        'NIO' => [
            'NIO',
            'nikaragvanska zlatna kordoba',
        ],
        'NLG' => [
            'NLG',
            'nizozemski gulden',
        ],
        'NOK' => [
            'NOK',
            'norveška kruna',
        ],
        'NPR' => [
            'NPR',
            'nepalska rupija',
        ],
        'NZD' => [
            'NZD',
            'novozelandski dolar',
        ],
        'OMR' => [
            'OMR',
            'omanski rijal',
        ],
        'PAB' => [
            'PAB',
            'panamska balboa',
        ],
        'PEI' => [
            'PEI',
            'peruanski inti',
        ],
        'PEN' => [
            'PEN',
            'peruanski sol',
        ],
        'PES' => [
            'PES',
            'peruanski sol (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'kina Papue Nove Gvineje',
        ],
        'PHP' => [
            'PHP',
            'filipinski pezo',
        ],
        'PKR' => [
            'PKR',
            'pakistanska rupija',
        ],
        'PLN' => [
            'PLN',
            'poljska zlota',
        ],
        'PLZ' => [
            'PLZ',
            'poljska zlota (1950.–1995.)',
        ],
        'PTE' => [
            'PTE',
            'portugalski eskudo',
        ],
        'PYG' => [
            'PYG',
            'paragvajski gvarani',
        ],
        'QAR' => [
            'QAR',
            'katarski rial',
        ],
        'RHD' => [
            'RHD',
            'rodezijski dolar',
        ],
        'ROL' => [
            'ROL',
            'starorumunjski lek',
        ],
        'RON' => [
            'RON',
            'rumunjski lej',
        ],
        'RSD' => [
            'RSD',
            'srpski dinar',
        ],
        'RUB' => [
            'RUB',
            'ruski rubalj',
        ],
        'RUR' => [
            'RUR',
            'ruska rublja (1991.–1998.)',
        ],
        'RWF' => [
            'RWF',
            'ruandski franak',
        ],
        'SAR' => [
            'SAR',
            'saudijski rijal',
        ],
        'SBD' => [
            'SBD',
            'solmonskootočni dolar',
        ],
        'SCR' => [
            'SCR',
            'sejšelska rupija',
        ],
        'SDD' => [
            'SDD',
            'sudanski dinar',
        ],
        'SDG' => [
            'SDG',
            'sudanska funta',
        ],
        'SDP' => [
            'SDP',
            'stara sudanska funta',
        ],
        'SEK' => [
            'SEK',
            'švedska kruna',
        ],
        'SGD' => [
            'SGD',
            'singapurski dolar',
        ],
        'SHP' => [
            'SHP',
            'svetohelenska funta',
        ],
        'SIT' => [
            'SIT',
            'slovenski tolar',
        ],
        'SKK' => [
            'SKK',
            'slovačka kruna',
        ],
        'SLE' => [
            'SLE',
            'sijeraleonski leone',
        ],
        'SLL' => [
            'SLL',
            'sijeraleonski leone (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'somalijski šiling',
        ],
        'SRD' => [
            'SRD',
            'surinamski dolar',
        ],
        'SRG' => [
            'SRG',
            'surinamski gulden',
        ],
        'SSP' => [
            'SSP',
            'južnosudanska funta',
        ],
        'STD' => [
            'STD',
            'dobra Svetog Tome i Principa (1977–2017)',
        ],
        'STN' => [
            'STN',
            'dobra Svetog Tome i Principa',
        ],
        'SUR' => [
            'SUR',
            'sovjetska rublja',
        ],
        'SVC' => [
            'SVC',
            'salvadorski kolon',
        ],
        'SYP' => [
            'SYP',
            'sirijska funta',
        ],
        'SZL' => [
            'SZL',
            'svazi lilangeni',
        ],
        'THB' => [
            'THB',
            'tajlandski baht',
        ],
        'TJR' => [
            'TJR',
            'tajikistanska rublja',
        ],
        'TJS' => [
            'TJS',
            'tadžikistanski somoni',
        ],
        'TMM' => [
            'TMM',
            'turkmenistanski manat (1993.–2009.)',
        ],
        'TMT' => [
            'TMT',
            'turkmenistanski manat',
        ],
        'TND' => [
            'TND',
            'tuniski dinar',
        ],
        'TOP' => [
            'TOP',
            'tongaška pa’anga',
        ],
        'TPE' => [
            'TPE',
            'timorski eskudo',
        ],
        'TRL' => [
            'TRL',
            'turska lira (1922.–2005.)',
        ],
        'TRY' => [
            'TRY',
            'turska lira',
        ],
        'TTD' => [
            'TTD',
            'trininadtobaški dolar',
        ],
        'TWD' => [
            'TWD',
            'novotajvanski dolar',
        ],
        'TZS' => [
            'TZS',
            'tanzanijski šiling',
        ],
        'UAH' => [
            'UAH',
            'ukrajinska hrivnja',
        ],
        'UAK' => [
            'UAK',
            'ukrajinski karbovanet',
        ],
        'UGS' => [
            'UGS',
            'ugandski šiling (1966.–1987.)',
        ],
        'UGX' => [
            'UGX',
            'ugandski šiling',
        ],
        'USD' => [
            'USD',
            'američki dolar',
        ],
        'USN' => [
            'USN',
            'američki dolar (sljedeći dan)',
        ],
        'USS' => [
            'USS',
            'američki dolar (isti dan)',
        ],
        'UYI' => [
            'UYI',
            'urugvajski pezo en unidades indexadas',
        ],
        'UYP' => [
            'UYP',
            'urugvajski pezo (1975.–1993.)',
        ],
        'UYU' => [
            'UYU',
            'urugvajski pezo',
        ],
        'UZS' => [
            'UZS',
            'uzbekistanski som',
        ],
        'VEB' => [
            'VEB',
            'venezuelanski bolivar (1871.–2008.)',
        ],
        'VEF' => [
            'VEF',
            'venezuelanski bolivar (2008. – 2018.)',
        ],
        'VES' => [
            'VES',
            'venezuelanski bolivar',
        ],
        'VND' => [
            'VND',
            'vijetnamski dong',
        ],
        'VNN' => [
            'VNN',
            'vijetnamski dong (1978.–1985.)',
        ],
        'VUV' => [
            'VUV',
            'vanuatski vatu',
        ],
        'WST' => [
            'WST',
            'samoanska tala',
        ],
        'XAF' => [
            'FCFA',
            'CFA franak BEAC',
        ],
        'XCD' => [
            'XCD',
            'istočnokaripski dolar',
        ],
        'XCG' => [
            'Cg.',
            'karipski gulden',
        ],
        'XEU' => [
            'XEU',
            'europska monetarna jedinica (ECU)',
        ],
        'XFO' => [
            'XFO',
            'francuski zlatni franak',
        ],
        'XFU' => [
            'XFU',
            'francuski UIC-franak',
        ],
        'XOF' => [
            'F CFA',
            'CFA franak BCEAO',
        ],
        'XPF' => [
            'XPF',
            'CFP franak',
        ],
        'XRE' => [
            'XRE',
            'RINET fondovi',
        ],
        'YDD' => [
            'YDD',
            'jemenski dinar',
        ],
        'YER' => [
            'YER',
            'jemenski rijal',
        ],
        'YUD' => [
            'YUD',
            'jugoslavenski čvrsti dinar',
        ],
        'YUM' => [
            'YUM',
            'jugoslavenski novi dinar',
        ],
        'YUN' => [
            'YUN',
            'jugoslavenski konvertibilni dinar',
        ],
        'YUR' => [
            'YUR',
            'jugoslavenski reformirani dinar',
        ],
        'ZAL' => [
            'ZAL',
            'južnoafrički rand (financijski)',
        ],
        'ZAR' => [
            'ZAR',
            'južnoafrički rand',
        ],
        'ZMK' => [
            'ZMK',
            'zambijska kvača (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'zambijska kvača',
        ],
        'ZRN' => [
            'ZRN',
            'zairski novi zair',
        ],
        'ZRZ' => [
            'ZRZ',
            'zairski zair',
        ],
        'ZWD' => [
            'ZWD',
            'zimbabveanski dolar (1980.–2008.)',
        ],
        'ZWG' => [
            'ZWG',
            'zimbabveansko zlato',
        ],
        'ZWL' => [
            'ZWL',
            'zimbabveanski dolar (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'zimbabveanski dolar (2008)',
        ],
    ],
];
