<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'андоррська песета',
        ],
        'AED' => [
            'AED',
            'дирхам ОАЕ',
        ],
        'AFA' => [
            'AFA',
            'афгані (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'афганський афгані',
        ],
        'ALL' => [
            'ALL',
            'албанський лек',
        ],
        'AMD' => [
            'AMD',
            'вірменський драм',
        ],
        'ANG' => [
            'ANG',
            'нідерландський антильський гульден',
        ],
        'AOA' => [
            'AOA',
            'ангольська кванза',
        ],
        'AOK' => [
            'AOK',
            'ангольська кванза (1977–1990)',
        ],
        'AON' => [
            'AON',
            'ангольська нова кванза (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'ангольська кванза реаджастадо (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'аргентинський австрал',
        ],
        'ARP' => [
            'ARP',
            'аргентинський песо (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'аргентинський песо',
        ],
        'ATS' => [
            'ATS',
            'австрійський шилінг',
        ],
        'AUD' => [
            'AUD',
            'австралійський долар',
        ],
        'AWG' => [
            'AWG',
            'арубський флорин',
        ],
        'AZM' => [
            'AZM',
            'азербайджанський манат (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'азербайджанський манат',
        ],
        'BAD' => [
            'BAD',
            'динар (Боснія і Герцеговина)',
        ],
        'BAM' => [
            'BAM',
            'конвертована марка Боснії і Герцеговини',
        ],
        'BBD' => [
            'BBD',
            'барбадоський долар',
        ],
        'BDT' => [
            'BDT',
            'бангладеська така',
        ],
        'BEC' => [
            'BEC',
            'бельгійський франк (конвертований)',
        ],
        'BEF' => [
            'BEF',
            'бельгійський франк',
        ],
        'BEL' => [
            'BEL',
            'бельгійський франк (фінансовий)',
        ],
        'BGL' => [
            'BGL',
            'болгарський твердий лев',
        ],
        'BGN' => [
            'BGN',
            'болгарський лев',
        ],
        'BHD' => [
            'BHD',
            'бахрейнський динар',
        ],
        'BIF' => [
            'BIF',
            'бурундійський франк',
        ],
        'BMD' => [
            'BMD',
            'бермудський долар',
        ],
        'BND' => [
            'BND',
            'брунейський долар',
        ],
        'BOB' => [
            'BOB',
            'болівійський болівіано',
        ],
        'BOP' => [
            'BOP',
            'болівійське песо',
        ],
        'BOV' => [
            'BOV',
            'болівійський мвдол',
        ],
        'BRB' => [
            'BRB',
            'бразильське нове крузейро (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'бразильське крузадо',
        ],
        'BRE' => [
            'BRE',
            'бразильське крузейро (1990–1993)',
        ],
        'BRL' => [
            'BRL',
            'бразильський реал',
        ],
        'BRN' => [
            'BRN',
            'бразильське нове крузадо',
        ],
        'BRR' => [
            'BRR',
            'бразильське крузейро',
        ],
        'BSD' => [
            'BSD',
            'багамський долар',
        ],
        'BTN' => [
            'BTN',
            'бутанський нгултрум',
        ],
        'BUK' => [
            'BUK',
            'бірманський кіат',
        ],
        'BWP' => [
            'BWP',
            'ботсванська пула',
        ],
        'BYB' => [
            'BYB',
            'білоруський новий рубль (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'білоруський рубль',
        ],
        'BYR' => [
            'BYR',
            'білоруський рубль (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'белізький долар',
        ],
        'CAD' => [
            'CAD',
            'канадський долар',
        ],
        'CDF' => [
            'CDF',
            'конголезький франк',
        ],
        'CHE' => [
            'CHE',
            'євро WIR',
        ],
        'CHF' => [
            'CHF',
            'швейцарський франк',
        ],
        'CHW' => [
            'CHW',
            'франк WIR',
        ],
        'CLF' => [
            'CLF',
            'чилійський юнідадес де фоменто',
        ],
        'CLP' => [
            'CLP',
            'чилійський песо',
        ],
        'CNH' => [
            'CNH',
            'китайський офшорний юань',
        ],
        'CNY' => [
            'CNY',
            'китайський юань',
        ],
        'COP' => [
            'COP',
            'колумбійський песо',
        ],
        'COU' => [
            'COU',
            'одиниця реальної вартості',
        ],
        'CRC' => [
            'CRC',
            'костариканський колон',
        ],
        'CSD' => [
            'CSD',
            'старий сербський динар',
        ],
        'CSK' => [
            'CSK',
            'чехословацька тверда крона',
        ],
        'CUC' => [
            'CUC',
            'кубинський конвертований песо',
        ],
        'CUP' => [
            'CUP',
            'кубинський песо',
        ],
        'CVE' => [
            'CVE',
            'ескудо Кабо-Верде',
        ],
        'CYP' => [
            'CYP',
            'кіпрський фунт',
        ],
        'CZK' => [
            'CZK',
            'чеська крона',
        ],
        'DDM' => [
            'DDM',
            'марка НДР',
        ],
        'DEM' => [
            'DEM',
            'німецька марка',
        ],
        'DJF' => [
            'DJF',
            'джибутійський франк',
        ],
        'DKK' => [
            'DKK',
            'данська крона',
        ],
        'DOP' => [
            'DOP',
            'домініканський песо',
        ],
        'DZD' => [
            'DZD',
            'алжирський динар',
        ],
        'ECS' => [
            'ECS',
            'еквадорський сукре',
        ],
        'ECV' => [
            'ECV',
            'еквадорський юнідад де валор константе',
        ],
        'EEK' => [
            'EEK',
            'естонська крона',
        ],
        'EGP' => [
            'EGP',
            'єгипетський фунт',
        ],
        'ERN' => [
            'ERN',
            'еритрейська накфа',
        ],
        'ESA' => [
            'ESA',
            'іспанська песета ("А" рахунок)',
        ],
        'ESB' => [
            'ESB',
            'іспанська песета (конвертовані рахунки)',
        ],
        'ESP' => [
            'ESP',
            'іспанська песета',
        ],
        'ETB' => [
            'ETB',
            'ефіопський бир',
        ],
        'EUR' => [
            'EUR',
            'євро',
        ],
        'FIM' => [
            'FIM',
            'фінляндська марка',
        ],
        'FJD' => [
            'FJD',
            'фіджійський долар',
        ],
        'FKP' => [
            'FKP',
            'фунт Фолклендських островів',
        ],
        'FRF' => [
            'FRF',
            'французький франк',
        ],
        'GBP' => [
            'GBP',
            'англійський фунт',
        ],
        'GEK' => [
            'GEK',
            'грузинський купон',
        ],
        'GEL' => [
            'GEL',
            'грузинський ларі',
        ],
        'GHC' => [
            'GHC',
            'ганський седі (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'ганський седі',
        ],
        'GIP' => [
            'GIP',
            'гібралтарський фунт',
        ],
        'GMD' => [
            'GMD',
            'гамбійський даласі',
        ],
        'GNF' => [
            'GNF',
            'гвінейський франк',
        ],
        'GNS' => [
            'GNS',
            'гвінейське сілі',
        ],
        'GQE' => [
            'GQE',
            'еквеле (Екваторіальна Ґвінея)',
        ],
        'GRD' => [
            'GRD',
            'грецька драхма',
        ],
        'GTQ' => [
            'GTQ',
            'гватемальський кетсаль',
        ],
        'GWE' => [
            'GWE',
            'ескудо португальської гвінеї',
        ],
        'GWP' => [
            'GWP',
            'песо Гвінеї-Бісау',
        ],
        'GYD' => [
            'GYD',
            'гаянський долар',
        ],
        'HKD' => [
            'HKD',
            'гонконгський долар',
        ],
        'HNL' => [
            'HNL',
            'гондураська лемпіра',
        ],
        'HRD' => [
            'HRD',
            'хорватський динар',
        ],
        'HRK' => [
            'HRK',
            'хорватська куна',
        ],
        'HTG' => [
            'HTG',
            'гаїтянський гурд',
        ],
        'HUF' => [
            'HUF',
            'угорський форинт',
        ],
        'IDR' => [
            'IDR',
            'індонезійська рупія',
        ],
        'IEP' => [
            'IEP',
            'ірландський фунт',
        ],
        'ILP' => [
            'ILP',
            'ізраїльський фунт',
        ],
        'ILS' => [
            'ILS',
            'ізраїльський новий шекель',
        ],
        'INR' => [
            'INR',
            'індійська рупія',
        ],
        'IQD' => [
            'IQD',
            'іракський динар',
        ],
        'IRR' => [
            'IRR',
            'іранський ріал',
        ],
        'ISK' => [
            'ISK',
            'ісландська крона',
        ],
        'ITL' => [
            'ITL',
            'італійська ліра',
        ],
        'JMD' => [
            'JMD',
            'ямайський долар',
        ],
        'JOD' => [
            'JOD',
            'йорданський динар',
        ],
        'JPY' => [
            '¥',
            'японська єна',
        ],
        'KES' => [
            'KES',
            'кенійський шилінг',
        ],
        'KGS' => [
            'KGS',
            'киргизький сом',
        ],
        'KHR' => [
            'KHR',
            'камбоджійський рієль',
        ],
        'KMF' => [
            'KMF',
            'коморський франк',
        ],
        'KPW' => [
            'KPW',
            'північнокорейський вон',
        ],
        'KRW' => [
            'KRW',
            'південнокорейський вон',
        ],
        'KWD' => [
            'KWD',
            'кувейтський динар',
        ],
        'KYD' => [
            'KYD',
            'долар Кайманових островів',
        ],
        'KZT' => [
            'KZT',
            'казахстанський тенге',
        ],
        'LAK' => [
            'LAK',
            'лаоський кіп',
        ],
        'LBP' => [
            'LBP',
            'ліванський фунт',
        ],
        'LKR' => [
            'LKR',
            'шрі-ланкійська рупія',
        ],
        'LRD' => [
            'LRD',
            'ліберійський долар',
        ],
        'LSL' => [
            'LSL',
            'лесотський лоті',
        ],
        'LTL' => [
            'LTL',
            'литовський літ',
        ],
        'LTT' => [
            'LTT',
            'литовський талон',
        ],
        'LUC' => [
            'LUC',
            'люксембурґський франк (конвертований)',
        ],
        'LUF' => [
            'LUF',
            'люксембурзький франк',
        ],
        'LUL' => [
            'LUL',
            'люксембурґський франк (фінансовий)',
        ],
        'LVL' => [
            'LVL',
            'латвійський лат',
        ],
        'LVR' => [
            'LVR',
            'латвійський рубль',
        ],
        'LYD' => [
            'LYD',
            'лівійський динар',
        ],
        'MAD' => [
            'MAD',
            'марокканський дирхам',
        ],
        'MAF' => [
            'MAF',
            'марокканський франк',
        ],
        'MDL' => [
            'MDL',
            'молдовський лей',
        ],
        'MGA' => [
            'MGA',
            'малагасійський аріарі',
        ],
        'MGF' => [
            'MGF',
            'мадагаскарський франк',
        ],
        'MKD' => [
            'MKD',
            'македонський денар',
        ],
        'MLF' => [
            'MLF',
            'малійський франк',
        ],
        'MMK' => [
            'MMK',
            'кʼят Мʼянми',
        ],
        'MNT' => [
            'MNT',
            'монгольський тугрик',
        ],
        'MOP' => [
            'MOP',
            'патака Макао',
        ],
        'MRO' => [
            'MRO',
            'мавританська угія (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'мавританська угія',
        ],
        'MTL' => [
            'MTL',
            'мальтійська ліра',
        ],
        'MTP' => [
            'MTP',
            'мальтійський фунт',
        ],
        'MUR' => [
            'MUR',
            'маврикійська рупія',
        ],
        'MVR' => [
            'MVR',
            'мальдівська руфія',
        ],
        'MWK' => [
            'MWK',
            'малавійська квача',
        ],
        'MXN' => [
            'MXN',
            'мексиканський песо',
        ],
        'MXP' => [
            'MXP',
            'мексиканське срібне песо (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'мексиканський юнідад де інверсіон',
        ],
        'MYR' => [
            'MYR',
            'малайзійський рингіт',
        ],
        'MZE' => [
            'MZE',
            'мозамбіцький ескудо',
        ],
        'MZM' => [
            'MZM',
            'старий мозамбіцький метикал',
        ],
        'MZN' => [
            'MZN',
            'мозамбіцький метикал',
        ],
        'NAD' => [
            'NAD',
            'намібійський долар',
        ],
        'NGN' => [
            'NGN',
            'нігерійська найра',
        ],
        'NIC' => [
            'NIC',
            'нікарагуанська кордоба (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'нікарагуанська кордоба',
        ],
        'NLG' => [
            'NLG',
            'нідерландський гульден',
        ],
        'NOK' => [
            'NOK',
            'норвезька крона',
        ],
        'NPR' => [
            'NPR',
            'непальська рупія',
        ],
        'NZD' => [
            'NZD',
            'новозеландський долар',
        ],
        'OMR' => [
            'OMR',
            'оманський ріал',
        ],
        'PAB' => [
            'PAB',
            'панамське бальбоа',
        ],
        'PEI' => [
            'PEI',
            'перуанський інті',
        ],
        'PEN' => [
            'PEN',
            'перуанський новий сол',
        ],
        'PES' => [
            'PES',
            'перуанський сол (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'кіна Папуа-Нової Ґвінеї',
        ],
        'PHP' => [
            'PHP',
            'філіппінський песо',
        ],
        'PKR' => [
            'PKR',
            'пакистанська рупія',
        ],
        'PLN' => [
            'PLN',
            'польський злотий',
        ],
        'PLZ' => [
            'PLZ',
            'польський злотий (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'португальський ескудо',
        ],
        'PYG' => [
            'PYG',
            'парагвайський гуарані',
        ],
        'QAR' => [
            'QAR',
            'катарський ріал',
        ],
        'RHD' => [
            'RHD',
            'родезійський долар',
        ],
        'ROL' => [
            'ROL',
            'старий румунський лей',
        ],
        'RON' => [
            'RON',
            'румунський лей',
        ],
        'RSD' => [
            'RSD',
            'сербський динар',
        ],
        'RUB' => [
            'RUB',
            'російський рубль',
        ],
        'RUR' => [
            'RUR',
            'російський рубль (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'руандійський франк',
        ],
        'SAR' => [
            'SAR',
            'саудівський ріал',
        ],
        'SBD' => [
            'SBD',
            'долар Соломонових Островів',
        ],
        'SCR' => [
            'SCR',
            'сейшельська рупія',
        ],
        'SDD' => [
            'SDD',
            'суданський динар',
        ],
        'SDG' => [
            'SDG',
            'суданський фунт',
        ],
        'SDP' => [
            'SDP',
            'старий суданський фунт',
        ],
        'SEK' => [
            'SEK',
            'шведська крона',
        ],
        'SGD' => [
            'SGD',
            'сінгапурський долар',
        ],
        'SHP' => [
            'SHP',
            'фунт острова Святої Єлени',
        ],
        'SIT' => [
            'SIT',
            'словенський толар',
        ],
        'SKK' => [
            'SKK',
            'словацька крона',
        ],
        'SLE' => [
            'SLE',
            'леоне Сьєрра-Леоне',
        ],
        'SLL' => [
            'SLL',
            'леоне Сьєрра-Леоне (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'сомалійський шилінг',
        ],
        'SRD' => [
            'SRD',
            'суринамський долар',
        ],
        'SRG' => [
            'SRG',
            'суринамський гульден',
        ],
        'SSP' => [
            'SSP',
            'південносуданський фунт',
        ],
        'STD' => [
            'STD',
            'добра Сан-Томе і Прінсіпі (1977–2017)',
        ],
        'STN' => [
            'STN',
            'добра Сан-Томе і Прінсіпі',
        ],
        'SUR' => [
            'SUR',
            'радянський рубль',
        ],
        'SVC' => [
            'SVC',
            'сальвадорський колон',
        ],
        'SYP' => [
            'SYP',
            'сирійський фунт',
        ],
        'SZL' => [
            'SZL',
            'свазілендський лілангені',
        ],
        'THB' => [
            'THB',
            'таїландський бат',
        ],
        'TJR' => [
            'TJR',
            'таджицький рубль',
        ],
        'TJS' => [
            'TJS',
            'таджицький сомоні',
        ],
        'TMM' => [
            'TMM',
            'туркменський манат (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'туркменський манат',
        ],
        'TND' => [
            'TND',
            'туніський динар',
        ],
        'TOP' => [
            'TOP',
            'тонганська паанга',
        ],
        'TPE' => [
            'TPE',
            'тіморський ескудо',
        ],
        'TRL' => [
            'TRL',
            'турецька ліра (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'турецька ліра',
        ],
        'TTD' => [
            'TTD',
            'долар Тринідаду і Тобаго',
        ],
        'TWD' => [
            'TWD',
            'новий тайванський долар',
        ],
        'TZS' => [
            'TZS',
            'танзанійський шилінг',
        ],
        'UAH' => [
            '₴',
            'українська гривня',
        ],
        'UAK' => [
            'крб.',
            'український карбованець',
        ],
        'UGS' => [
            'UGS',
            'угандійський шилінг (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'угандійський шилінг',
        ],
        'USD' => [
            'USD',
            'долар США',
        ],
        'USN' => [
            'USN',
            'долар США (наступного дня)',
        ],
        'USS' => [
            'USS',
            'долар США (цього дня)',
        ],
        'UYI' => [
            'UYI',
            'уругвайський песо в індексованих одиницях',
        ],
        'UYP' => [
            'UYP',
            'уругвайське песо (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'уругвайський песо',
        ],
        'UZS' => [
            'UZS',
            'узбецький сум',
        ],
        'VEB' => [
            'VEB',
            'венесуельський болівар (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'венесуельський болівар (2008–2018)',
        ],
        'VES' => [
            'VES',
            'венесуельський болівар',
        ],
        'VND' => [
            'VND',
            'вʼєтнамський донг',
        ],
        'VUV' => [
            'VUV',
            'вануатський вату',
        ],
        'WST' => [
            'WST',
            'самоанська тала',
        ],
        'XAF' => [
            'FCFA',
            'центральноафриканський франк',
        ],
        'XCD' => [
            'XCD',
            'східнокарибський долар',
        ],
        'XCG' => [
            'Cg.',
            'карибський гульден',
        ],
        'XEU' => [
            'XEU',
            'європейська валютна одиниця',
        ],
        'XFO' => [
            'XFO',
            'французький золотий франк',
        ],
        'XFU' => [
            'XFU',
            'французький франк UIC',
        ],
        'XOF' => [
            'F CFA',
            'західноафриканський франк',
        ],
        'XPF' => [
            'CFPF',
            'французький тихоокеанський франк',
        ],
        'XRE' => [
            'XRE',
            'фонди RINET',
        ],
        'YDD' => [
            'YDD',
            'єменський динар',
        ],
        'YER' => [
            'YER',
            'єменський ріал',
        ],
        'YUD' => [
            'YUD',
            'югославський твердий динар',
        ],
        'YUM' => [
            'YUM',
            'югославський новий динар',
        ],
        'YUN' => [
            'YUN',
            'югославський конвертований динар',
        ],
        'ZAL' => [
            'ZAL',
            'південноафриканський фінансовий ранд',
        ],
        'ZAR' => [
            'ZAR',
            'південноафриканський ранд',
        ],
        'ZMK' => [
            'ZMK',
            'замбійська квача (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'замбійська квача',
        ],
        'ZRN' => [
            'ZRN',
            'заїрський новий заїр',
        ],
        'ZRZ' => [
            'ZRZ',
            'заїрський заїр',
        ],
        'ZWD' => [
            'ZWD',
            'зімбабвійський долар',
        ],
        'ZWG' => [
            'ZWG',
            'зімбабвійський золотий',
        ],
        'ZWL' => [
            'ZWL',
            'зімбабвійський долар (2009)',
        ],
    ],
];
