<?php

return [
    'Names' => [
        'af' => 'Afraganais',
        'af_NA' => 'Afraganais (An Namaib)',
        'af_ZA' => 'Afraganais (Afraga a Deas)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Gàna)',
        'am' => 'Amtharais',
        'am_ET' => 'Amtharais (An Itiop)',
        'ar' => 'Arabais',
        'ar_001' => 'Arabais (An Saoghal)',
        'ar_AE' => 'Arabais (Na h-Iomaratan Arabach Aonaichte)',
        'ar_BH' => 'Arabais (Bachrain)',
        'ar_DJ' => 'Arabais (Diobùtaidh)',
        'ar_DZ' => 'Arabais (Aildiria)',
        'ar_EG' => 'Arabais (An Èipheit)',
        'ar_EH' => 'Arabais (Sathara an Iar)',
        'ar_ER' => 'Arabais (Eartra)',
        'ar_IL' => 'Arabais (Iosrael)',
        'ar_IQ' => 'Arabais (Ioràc)',
        'ar_JO' => 'Arabais (Iòrdan)',
        'ar_KM' => 'Arabais (Comoros)',
        'ar_KW' => 'Arabais (Cuibhèit)',
        'ar_LB' => 'Arabais (Leabanon)',
        'ar_LY' => 'Arabais (Libia)',
        'ar_MA' => 'Arabais (Moroco)',
        'ar_MR' => 'Arabais (Moratàinea)',
        'ar_OM' => 'Arabais (Omàn)',
        'ar_PS' => 'Arabais (Ùghdarras nam Palastaineach)',
        'ar_QA' => 'Arabais (Catar)',
        'ar_SA' => 'Arabais (Aràibia nan Sabhd)',
        'ar_SD' => 'Arabais (Sudàn)',
        'ar_SO' => 'Arabais (Somàilia)',
        'ar_SS' => 'Arabais (Sudàn a Deas)',
        'ar_SY' => 'Arabais (Siridhea)',
        'ar_TD' => 'Arabais (An t-Seàd)',
        'ar_TN' => 'Arabais (Tuinisea)',
        'ar_YE' => 'Arabais (An Eaman)',
        'as' => 'Asamais',
        'as_IN' => 'Asamais (Na h-Innseachan)',
        'az' => 'Asarbaideànais',
        'az_AZ' => 'Asarbaideànais (Asarbaideàn)',
        'az_Cyrl' => 'Asarbaideànais (Cirilis)',
        'az_Cyrl_AZ' => 'Asarbaideànais (Cirilis, Asarbaideàn)',
        'az_Latn' => 'Asarbaideànais (Laideann)',
        'az_Latn_AZ' => 'Asarbaideànais (Laideann, Asarbaideàn)',
        'ba' => 'Bashkir',
        'ba_RU' => 'Bashkir (An Ruis)',
        'be' => 'Bealaruisis',
        'be_BY' => 'Bealaruisis (A’ Bhealaruis)',
        'bg' => 'Bulgarais',
        'bg_BG' => 'Bulgarais (A’ Bhulgair)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Màili)',
        'bn' => 'Bangla',
        'bn_BD' => 'Bangla (Bangladais)',
        'bn_IN' => 'Bangla (Na h-Innseachan)',
        'bo' => 'Tibeitis',
        'bo_CN' => 'Tibeitis (An t-Sìn)',
        'bo_IN' => 'Tibeitis (Na h-Innseachan)',
        'br' => 'Breatnais',
        'br_FR' => 'Breatnais (An Fhraing)',
        'bs' => 'Bosnais',
        'bs_BA' => 'Bosnais (Bosna is Hearsagobhana)',
        'bs_Cyrl' => 'Bosnais (Cirilis)',
        'bs_Cyrl_BA' => 'Bosnais (Cirilis, Bosna is Hearsagobhana)',
        'bs_Latn' => 'Bosnais (Laideann)',
        'bs_Latn_BA' => 'Bosnais (Laideann, Bosna is Hearsagobhana)',
        'ca' => 'Catalanais',
        'ca_AD' => 'Catalanais (Andorra)',
        'ca_ES' => 'Catalanais (An Spàinnt)',
        'ca_FR' => 'Catalanais (An Fhraing)',
        'ca_IT' => 'Catalanais (An Eadailt)',
        'ce' => 'Deideanais',
        'ce_RU' => 'Deideanais (An Ruis)',
        'cs' => 'Seicis',
        'cs_CZ' => 'Seicis (An t-Seic)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (An Ruis)',
        'cy' => 'Cuimris',
        'cy_GB' => 'Cuimris (An Rìoghachd Aonaichte)',
        'da' => 'Danmhairgis',
        'da_DK' => 'Danmhairgis (An Danmhairg)',
        'da_GL' => 'Danmhairgis (A’ Ghraonlann)',
        'de' => 'Gearmailtis',
        'de_AT' => 'Gearmailtis (An Ostair)',
        'de_BE' => 'Gearmailtis (A’ Bheilg)',
        'de_CH' => 'Gearmailtis (An Eilbheis)',
        'de_DE' => 'Gearmailtis (A’ Ghearmailt)',
        'de_IT' => 'Gearmailtis (An Eadailt)',
        'de_LI' => 'Gearmailtis (Lichtenstein)',
        'de_LU' => 'Gearmailtis (Lugsamburg)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Butàn)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Gàna)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Greugais',
        'el_CY' => 'Greugais (Cìopras)',
        'el_GR' => 'Greugais (A’ Ghreug)',
        'en' => 'Beurla',
        'en_001' => 'Beurla (An Saoghal)',
        'en_150' => 'Beurla (An Roinn-Eòrpa)',
        'en_AE' => 'Beurla (Na h-Iomaratan Arabach Aonaichte)',
        'en_AG' => 'Beurla (Aintìoga is Barbuda)',
        'en_AI' => 'Beurla (Anguillia)',
        'en_AS' => 'Beurla (Samotha na h-Aimeireaga)',
        'en_AT' => 'Beurla (An Ostair)',
        'en_AU' => 'Beurla (Astràilia)',
        'en_BB' => 'Beurla (Barbados)',
        'en_BE' => 'Beurla (A’ Bheilg)',
        'en_BI' => 'Beurla (Burundaidh)',
        'en_BM' => 'Beurla (Bearmùda)',
        'en_BS' => 'Beurla (Na h-Eileanan Bhathama)',
        'en_BW' => 'Beurla (Botsuana)',
        'en_BZ' => 'Beurla (A’ Bheilìs)',
        'en_CA' => 'Beurla (Canada)',
        'en_CC' => 'Beurla (Na h-Eileanan Chocos [Keeling])',
        'en_CH' => 'Beurla (An Eilbheis)',
        'en_CK' => 'Beurla (Eileanan Cook)',
        'en_CM' => 'Beurla (Camarun)',
        'en_CX' => 'Beurla (Eilean na Nollaig)',
        'en_CY' => 'Beurla (Cìopras)',
        'en_CZ' => 'Beurla (An t-Seic)',
        'en_DE' => 'Beurla (A’ Ghearmailt)',
        'en_DK' => 'Beurla (An Danmhairg)',
        'en_DM' => 'Beurla (Doiminicea)',
        'en_EE' => 'Beurla (An Eastoin)',
        'en_ER' => 'Beurla (Eartra)',
        'en_ES' => 'Beurla (An Spàinnt)',
        'en_FI' => 'Beurla (An Fhionnlann)',
        'en_FJ' => 'Beurla (Fìdi)',
        'en_FK' => 'Beurla (Na h-Eileanan Fàclannach)',
        'en_FM' => 'Beurla (Na Meanbh-eileanan)',
        'en_FR' => 'Beurla (An Fhraing)',
        'en_GB' => 'Beurla (An Rìoghachd Aonaichte)',
        'en_GD' => 'Beurla (Greanàda)',
        'en_GE' => 'Beurla (A’ Chairtbheil)',
        'en_GG' => 'Beurla (Geàrnsaidh)',
        'en_GH' => 'Beurla (Gàna)',
        'en_GI' => 'Beurla (Diobraltar)',
        'en_GM' => 'Beurla (A’ Ghaimbia)',
        'en_GS' => 'Beurla (Seòirsea a Deas is na h-Eileanan Sandwich a Deas)',
        'en_GU' => 'Beurla (Guam)',
        'en_GY' => 'Beurla (Guidheàna)',
        'en_HK' => 'Beurla (Hong Kong SAR na Sìne)',
        'en_HU' => 'Beurla (An Ungair)',
        'en_ID' => 'Beurla (Na h-Innd-innse)',
        'en_IE' => 'Beurla (Èirinn)',
        'en_IL' => 'Beurla (Iosrael)',
        'en_IM' => 'Beurla (Eilean Mhanainn)',
        'en_IN' => 'Beurla (Na h-Innseachan)',
        'en_IO' => 'Beurla (Ranntair Breatannach Cuan nan Innseachan)',
        'en_IT' => 'Beurla (An Eadailt)',
        'en_JE' => 'Beurla (Deàrsaidh)',
        'en_JM' => 'Beurla (Diameuga)',
        'en_JP' => 'Beurla (An t-Seapan)',
        'en_KE' => 'Beurla (Ceinia)',
        'en_KI' => 'Beurla (Ciribeas)',
        'en_KN' => 'Beurla (Naomh Crìstean is Nibheis)',
        'en_KY' => 'Beurla (Na h-Eileanan Caimean)',
        'en_LC' => 'Beurla (Naomh Lùisea)',
        'en_LR' => 'Beurla (Libèir)',
        'en_LS' => 'Beurla (Leasoto)',
        'en_LT' => 'Beurla (An Liotuain)',
        'en_LV' => 'Beurla (An Laitbhe)',
        'en_MG' => 'Beurla (Madagasgar)',
        'en_MH' => 'Beurla (Eileanan Mharshall)',
        'en_MO' => 'Beurla (Macàthu SAR na Sìne)',
        'en_MP' => 'Beurla (Na h-Eileanan Mairianach a Tuath)',
        'en_MS' => 'Beurla (Montsarat)',
        'en_MT' => 'Beurla (Malta)',
        'en_MU' => 'Beurla (Na h-Eileanan Mhoiriseas)',
        'en_MV' => 'Beurla (Na h-Eileanan Mhaladaibh)',
        'en_MW' => 'Beurla (Malabhaidh)',
        'en_MY' => 'Beurla (Malaidhsea)',
        'en_NA' => 'Beurla (An Namaib)',
        'en_NF' => 'Beurla (Eilean Norfolk)',
        'en_NG' => 'Beurla (Nigèiria)',
        'en_NL' => 'Beurla (Na Tìrean Ìsle)',
        'en_NO' => 'Beurla (Nirribhidh)',
        'en_NR' => 'Beurla (Nabhru)',
        'en_NU' => 'Beurla (Niue)',
        'en_NZ' => 'Beurla (Sealainn Nuadh)',
        'en_PG' => 'Beurla (Gini Nuadh Phaputhach)',
        'en_PH' => 'Beurla (Na h-Eileanan Filipineach)',
        'en_PK' => 'Beurla (Pagastàn)',
        'en_PL' => 'Beurla (A’ Phòlainn)',
        'en_PN' => 'Beurla (Eileanan Pheit a’ Chàirn)',
        'en_PR' => 'Beurla (Porto Rìceo)',
        'en_PT' => 'Beurla (A’ Phortagail)',
        'en_PW' => 'Beurla (Palabh)',
        'en_RO' => 'Beurla (Romàinia)',
        'en_RW' => 'Beurla (Rubhanda)',
        'en_SB' => 'Beurla (Eileanan Sholaimh)',
        'en_SC' => 'Beurla (Na h-Eileanan Sheiseall)',
        'en_SD' => 'Beurla (Sudàn)',
        'en_SE' => 'Beurla (An t-Suain)',
        'en_SG' => 'Beurla (Singeapòr)',
        'en_SH' => 'Beurla (Eilean Naomh Eilidh)',
        'en_SI' => 'Beurla (An t-Slòbhain)',
        'en_SK' => 'Beurla (An t-Slòbhac)',
        'en_SL' => 'Beurla (Siarra Leòmhann)',
        'en_SS' => 'Beurla (Sudàn a Deas)',
        'en_SX' => 'Beurla (Sint Maarten)',
        'en_SZ' => 'Beurla (eSwatini)',
        'en_TC' => 'Beurla (Na h-Eileanan Turcach is Caiceo)',
        'en_TK' => 'Beurla (Tokelau)',
        'en_TO' => 'Beurla (Tonga)',
        'en_TT' => 'Beurla (Trianaid agus Tobago)',
        'en_TV' => 'Beurla (Tubhalu)',
        'en_TZ' => 'Beurla (An Tansan)',
        'en_UA' => 'Beurla (An Ucràin)',
        'en_UG' => 'Beurla (Uganda)',
        'en_UM' => 'Beurla (Meanbh-Eileanan Iomallach nan SA)',
        'en_US' => 'Beurla (Na Stàitean Aonaichte)',
        'en_VC' => 'Beurla (Naomh Bhionsant agus Eileanan Greanadach)',
        'en_VG' => 'Beurla (Eileanan Breatannach na Maighdinn)',
        'en_VI' => 'Beurla (Eileanan na Maighdinn aig na SA)',
        'en_VU' => 'Beurla (Vanuatu)',
        'en_WS' => 'Beurla (Samotha)',
        'en_ZA' => 'Beurla (Afraga a Deas)',
        'en_ZM' => 'Beurla (Sàimbia)',
        'en_ZW' => 'Beurla (An t-Sìombab)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (An Saoghal)',
        'es' => 'Spàinntis',
        'es_419' => 'Spàinntis (Aimeireaga Laidinneach)',
        'es_AR' => 'Spàinntis (An Argantain)',
        'es_BO' => 'Spàinntis (Boilibhia)',
        'es_BR' => 'Spàinntis (Braisil)',
        'es_BZ' => 'Spàinntis (A’ Bheilìs)',
        'es_CL' => 'Spàinntis (An t-Sile)',
        'es_CO' => 'Spàinntis (Coloimbia)',
        'es_CR' => 'Spàinntis (Costa Rìcea)',
        'es_CU' => 'Spàinntis (Cùba)',
        'es_DO' => 'Spàinntis (A’ Phoblachd Dhoiminiceach)',
        'es_EC' => 'Spàinntis (Eacuador)',
        'es_ES' => 'Spàinntis (An Spàinnt)',
        'es_GQ' => 'Spàinntis (Gini Mheadhan-Chriosach)',
        'es_GT' => 'Spàinntis (Guatamala)',
        'es_HN' => 'Spàinntis (Hondùras)',
        'es_MX' => 'Spàinntis (Meagsago)',
        'es_NI' => 'Spàinntis (Niocaragua)',
        'es_PA' => 'Spàinntis (Panama)',
        'es_PE' => 'Spàinntis (Pearù)',
        'es_PH' => 'Spàinntis (Na h-Eileanan Filipineach)',
        'es_PR' => 'Spàinntis (Porto Rìceo)',
        'es_PY' => 'Spàinntis (Paraguaidh)',
        'es_SV' => 'Spàinntis (An Salbhador)',
        'es_US' => 'Spàinntis (Na Stàitean Aonaichte)',
        'es_UY' => 'Spàinntis (Uruguaidh)',
        'es_VE' => 'Spàinntis (A’ Bheiniseala)',
        'et' => 'Eastoinis',
        'et_EE' => 'Eastoinis (An Eastoin)',
        'eu' => 'Basgais',
        'eu_ES' => 'Basgais (An Spàinnt)',
        'fa' => 'Peirsis',
        'fa_AF' => 'Peirsis (Afghanastàn)',
        'fa_IR' => 'Peirsis (Ioràn)',
        'ff' => 'Fulah',
        'ff_Adlm' => 'Fulah (Adlam)',
        'ff_Adlm_BF' => 'Fulah (Adlam, Buirciona Faso)',
        'ff_Adlm_CM' => 'Fulah (Adlam, Camarun)',
        'ff_Adlm_GH' => 'Fulah (Adlam, Gàna)',
        'ff_Adlm_GM' => 'Fulah (Adlam, A’ Ghaimbia)',
        'ff_Adlm_GN' => 'Fulah (Adlam, Gini)',
        'ff_Adlm_GW' => 'Fulah (Adlam, Gini-Bioso)',
        'ff_Adlm_LR' => 'Fulah (Adlam, Libèir)',
        'ff_Adlm_MR' => 'Fulah (Adlam, Moratàinea)',
        'ff_Adlm_NE' => 'Fulah (Adlam, Nìgeir)',
        'ff_Adlm_NG' => 'Fulah (Adlam, Nigèiria)',
        'ff_Adlm_SL' => 'Fulah (Adlam, Siarra Leòmhann)',
        'ff_Adlm_SN' => 'Fulah (Adlam, Seanagal)',
        'ff_CM' => 'Fulah (Camarun)',
        'ff_GN' => 'Fulah (Gini)',
        'ff_Latn' => 'Fulah (Laideann)',
        'ff_Latn_BF' => 'Fulah (Laideann, Buirciona Faso)',
        'ff_Latn_CM' => 'Fulah (Laideann, Camarun)',
        'ff_Latn_GH' => 'Fulah (Laideann, Gàna)',
        'ff_Latn_GM' => 'Fulah (Laideann, A’ Ghaimbia)',
        'ff_Latn_GN' => 'Fulah (Laideann, Gini)',
        'ff_Latn_GW' => 'Fulah (Laideann, Gini-Bioso)',
        'ff_Latn_LR' => 'Fulah (Laideann, Libèir)',
        'ff_Latn_MR' => 'Fulah (Laideann, Moratàinea)',
        'ff_Latn_NE' => 'Fulah (Laideann, Nìgeir)',
        'ff_Latn_NG' => 'Fulah (Laideann, Nigèiria)',
        'ff_Latn_SL' => 'Fulah (Laideann, Siarra Leòmhann)',
        'ff_Latn_SN' => 'Fulah (Laideann, Seanagal)',
        'ff_MR' => 'Fulah (Moratàinea)',
        'ff_SN' => 'Fulah (Seanagal)',
        'fi' => 'Fionnlannais',
        'fi_FI' => 'Fionnlannais (An Fhionnlann)',
        'fo' => 'Fàrothais',
        'fo_DK' => 'Fàrothais (An Danmhairg)',
        'fo_FO' => 'Fàrothais (Na h-Eileanan Fàro)',
        'fr' => 'Fraingis',
        'fr_BE' => 'Fraingis (A’ Bheilg)',
        'fr_BF' => 'Fraingis (Buirciona Faso)',
        'fr_BI' => 'Fraingis (Burundaidh)',
        'fr_BJ' => 'Fraingis (Beinin)',
        'fr_BL' => 'Fraingis (Saint Barthélemy)',
        'fr_CA' => 'Fraingis (Canada)',
        'fr_CD' => 'Fraingis (Congo - Kinshasa)',
        'fr_CF' => 'Fraingis (Poblachd Meadhan Afraga)',
        'fr_CG' => 'Fraingis (A’ Chongo - Brazzaville)',
        'fr_CH' => 'Fraingis (An Eilbheis)',
        'fr_CI' => 'Fraingis (Côte d’Ivoire)',
        'fr_CM' => 'Fraingis (Camarun)',
        'fr_DJ' => 'Fraingis (Diobùtaidh)',
        'fr_DZ' => 'Fraingis (Aildiria)',
        'fr_FR' => 'Fraingis (An Fhraing)',
        'fr_GA' => 'Fraingis (Gabon)',
        'fr_GF' => 'Fraingis (Guidheàna na Frainge)',
        'fr_GN' => 'Fraingis (Gini)',
        'fr_GP' => 'Fraingis (Guadalup)',
        'fr_GQ' => 'Fraingis (Gini Mheadhan-Chriosach)',
        'fr_HT' => 'Fraingis (Haidhti)',
        'fr_KM' => 'Fraingis (Comoros)',
        'fr_LU' => 'Fraingis (Lugsamburg)',
        'fr_MA' => 'Fraingis (Moroco)',
        'fr_MC' => 'Fraingis (Monaco)',
        'fr_MF' => 'Fraingis (Naomh Màrtainn)',
        'fr_MG' => 'Fraingis (Madagasgar)',
        'fr_ML' => 'Fraingis (Màili)',
        'fr_MQ' => 'Fraingis (Mairtinic)',
        'fr_MR' => 'Fraingis (Moratàinea)',
        'fr_MU' => 'Fraingis (Na h-Eileanan Mhoiriseas)',
        'fr_NC' => 'Fraingis (Cailleann Nuadh)',
        'fr_NE' => 'Fraingis (Nìgeir)',
        'fr_PF' => 'Fraingis (Poilinèis na Frainge)',
        'fr_PM' => 'Fraingis (Saint Pierre agus Miquelon)',
        'fr_RE' => 'Fraingis (Réunion)',
        'fr_RW' => 'Fraingis (Rubhanda)',
        'fr_SC' => 'Fraingis (Na h-Eileanan Sheiseall)',
        'fr_SN' => 'Fraingis (Seanagal)',
        'fr_SY' => 'Fraingis (Siridhea)',
        'fr_TD' => 'Fraingis (An t-Seàd)',
        'fr_TG' => 'Fraingis (Togo)',
        'fr_TN' => 'Fraingis (Tuinisea)',
        'fr_VU' => 'Fraingis (Vanuatu)',
        'fr_WF' => 'Fraingis (Uallas agus Futuna)',
        'fr_YT' => 'Fraingis (Mayotte)',
        'fy' => 'Frìoslannais Shiarach',
        'fy_NL' => 'Frìoslannais Shiarach (Na Tìrean Ìsle)',
        'ga' => 'Gaeilge',
        'ga_GB' => 'Gaeilge (An Rìoghachd Aonaichte)',
        'ga_IE' => 'Gaeilge (Èirinn)',
        'gd' => 'Gàidhlig',
        'gd_GB' => 'Gàidhlig (An Rìoghachd Aonaichte)',
        'gl' => 'Gailìsis',
        'gl_ES' => 'Gailìsis (An Spàinnt)',
        'gu' => 'Gujarati',
        'gu_IN' => 'Gujarati (Na h-Innseachan)',
        'gv' => 'Gaelg',
        'gv_IM' => 'Gaelg (Eilean Mhanainn)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Gàna)',
        'ha_NE' => 'Hausa (Nìgeir)',
        'ha_NG' => 'Hausa (Nigèiria)',
        'he' => 'Eabhra',
        'he_IL' => 'Eabhra (Iosrael)',
        'hi' => 'Hindis',
        'hi_IN' => 'Hindis (Na h-Innseachan)',
        'hi_Latn' => 'Hindis (Laideann)',
        'hi_Latn_IN' => 'Hindis (Laideann, Na h-Innseachan)',
        'hr' => 'Cròthaisis',
        'hr_BA' => 'Cròthaisis (Bosna is Hearsagobhana)',
        'hr_HR' => 'Cròthaisis (A’ Chròthais)',
        'hu' => 'Ungairis',
        'hu_HU' => 'Ungairis (An Ungair)',
        'hy' => 'Airmeinis',
        'hy_AM' => 'Airmeinis (Airmeinea)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (An Saoghal)',
        'id' => 'Innd-Innsis',
        'id_ID' => 'Innd-Innsis (Na h-Innd-innse)',
        'ie' => 'Interlingue',
        'ie_EE' => 'Interlingue (An Eastoin)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nigèiria)',
        'ii' => 'Yi Sichuan',
        'ii_CN' => 'Yi Sichuan (An t-Sìn)',
        'is' => 'Innis Tìlis',
        'is_IS' => 'Innis Tìlis (Innis Tìle)',
        'it' => 'Eadailtis',
        'it_CH' => 'Eadailtis (An Eilbheis)',
        'it_IT' => 'Eadailtis (An Eadailt)',
        'it_SM' => 'Eadailtis (San Marino)',
        'it_VA' => 'Eadailtis (Cathair na Bhatacain)',
        'ja' => 'Seapanais',
        'ja_JP' => 'Seapanais (An t-Seapan)',
        'jv' => 'Deàbhanais',
        'jv_ID' => 'Deàbhanais (Na h-Innd-innse)',
        'ka' => 'Cairtbheilis',
        'ka_GE' => 'Cairtbheilis (A’ Chairtbheil)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Ceinia)',
        'kk' => 'Casachais',
        'kk_Arab' => 'Casachais (Arabais)',
        'kk_Arab_CN' => 'Casachais (Arabais, An t-Sìn)',
        'kk_Cyrl' => 'Casachais (Cirilis)',
        'kk_Cyrl_KZ' => 'Casachais (Cirilis, Casachstàn)',
        'kk_KZ' => 'Casachais (Casachstàn)',
        'kl' => 'Kalaallisut',
        'kl_GL' => 'Kalaallisut (A’ Ghraonlann)',
        'km' => 'Cmèar',
        'km_KH' => 'Cmèar (Cambuidea)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (Na h-Innseachan)',
        'ko' => 'Coirèanais',
        'ko_CN' => 'Coirèanais (An t-Sìn)',
        'ko_KP' => 'Coirèanais (Coirèa a Tuath)',
        'ko_KR' => 'Coirèanais (Coirèa)',
        'ks' => 'Caismiris',
        'ks_Arab' => 'Caismiris (Arabais)',
        'ks_Arab_IN' => 'Caismiris (Arabais, Na h-Innseachan)',
        'ks_Deva' => 'Caismiris (Devanagari)',
        'ks_Deva_IN' => 'Caismiris (Devanagari, Na h-Innseachan)',
        'ks_IN' => 'Caismiris (Na h-Innseachan)',
        'ku' => 'Cùrdais',
        'ku_Latn' => 'Cùrdais (Laideann)',
        'ku_Latn_IQ' => 'Cùrdais (Laideann, Ioràc)',
        'ku_Latn_SY' => 'Cùrdais (Laideann, Siridhea)',
        'ku_Latn_TR' => 'Cùrdais (Laideann, An Tuirc)',
        'ku_SY' => 'Cùrdais (Siridhea)',
        'ku_TR' => 'Cùrdais (An Tuirc)',
        'kw' => 'Còrnais',
        'kw_GB' => 'Còrnais (An Rìoghachd Aonaichte)',
        'ky' => 'Cìorgasais',
        'ky_KG' => 'Cìorgasais (Cìorgastan)',
        'lb' => 'Lugsamburgais',
        'lb_LU' => 'Lugsamburgais (Lugsamburg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angòla)',
        'ln_CD' => 'Lingala (Congo - Kinshasa)',
        'ln_CF' => 'Lingala (Poblachd Meadhan Afraga)',
        'ln_CG' => 'Lingala (A’ Chongo - Brazzaville)',
        'lo' => 'Làtho',
        'lo_LA' => 'Làtho (Làthos)',
        'lt' => 'Liotuainis',
        'lt_LT' => 'Liotuainis (An Liotuain)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Congo - Kinshasa)',
        'lv' => 'Laitbheis',
        'lv_LV' => 'Laitbheis (An Laitbhe)',
        'mg' => 'Malagasais',
        'mg_MG' => 'Malagasais (Madagasgar)',
        'mi' => 'Māori',
        'mi_NZ' => 'Māori (Sealainn Nuadh)',
        'mk' => 'Masadonais',
        'mk_MK' => 'Masadonais (A’ Mhasadon a Tuath)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (Na h-Innseachan)',
        'mn' => 'Mongolais',
        'mn_MN' => 'Mongolais (Dùthaich nam Mongol)',
        'mr' => 'Marathi',
        'mr_IN' => 'Marathi (Na h-Innseachan)',
        'ms' => 'Malaidhis',
        'ms_BN' => 'Malaidhis (Brùnaigh)',
        'ms_ID' => 'Malaidhis (Na h-Innd-innse)',
        'ms_MY' => 'Malaidhis (Malaidhsea)',
        'ms_SG' => 'Malaidhis (Singeapòr)',
        'mt' => 'Maltais',
        'mt_MT' => 'Maltais (Malta)',
        'my' => 'Burmais',
        'my_MM' => 'Burmais (Miànmar)',
        'nb' => 'Bokmål na Nirribhidh',
        'nb_NO' => 'Bokmål na Nirribhidh (Nirribhidh)',
        'nb_SJ' => 'Bokmål na Nirribhidh (Svalbard is Jan Mayen)',
        'nd' => 'Ndebele Thuathach',
        'nd_ZW' => 'Ndebele Thuathach (An t-Sìombab)',
        'ne' => 'Neapàlais',
        'ne_IN' => 'Neapàlais (Na h-Innseachan)',
        'ne_NP' => 'Neapàlais (Neapàl)',
        'nl' => 'Duitsis',
        'nl_AW' => 'Duitsis (Arùba)',
        'nl_BE' => 'Duitsis (A’ Bheilg)',
        'nl_BQ' => 'Duitsis (Na Tìrean Ìsle Caraibeach)',
        'nl_CW' => 'Duitsis (Curaçao)',
        'nl_NL' => 'Duitsis (Na Tìrean Ìsle)',
        'nl_SR' => 'Duitsis (Suranam)',
        'nl_SX' => 'Duitsis (Sint Maarten)',
        'nn' => 'Nynorsk na Nirribhidh',
        'nn_NO' => 'Nynorsk na Nirribhidh (Nirribhidh)',
        'no' => 'Nirribhis',
        'no_NO' => 'Nirribhis (Nirribhidh)',
        'oc' => 'Ogsatanais',
        'oc_ES' => 'Ogsatanais (An Spàinnt)',
        'oc_FR' => 'Ogsatanais (An Fhraing)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (An Itiop)',
        'om_KE' => 'Oromo (Ceinia)',
        'or' => 'Odia',
        'or_IN' => 'Odia (Na h-Innseachan)',
        'os' => 'Ossetic',
        'os_GE' => 'Ossetic (A’ Chairtbheil)',
        'os_RU' => 'Ossetic (An Ruis)',
        'pa' => 'Panjabi',
        'pa_Arab' => 'Panjabi (Arabais)',
        'pa_Arab_PK' => 'Panjabi (Arabais, Pagastàn)',
        'pa_Guru' => 'Panjabi (Gurmukhi)',
        'pa_Guru_IN' => 'Panjabi (Gurmukhi, Na h-Innseachan)',
        'pa_IN' => 'Panjabi (Na h-Innseachan)',
        'pa_PK' => 'Panjabi (Pagastàn)',
        'pl' => 'Pòlainnis',
        'pl_PL' => 'Pòlainnis (A’ Phòlainn)',
        'ps' => 'Pashto',
        'ps_AF' => 'Pashto (Afghanastàn)',
        'ps_PK' => 'Pashto (Pagastàn)',
        'pt' => 'Portagailis',
        'pt_AO' => 'Portagailis (Angòla)',
        'pt_BR' => 'Portagailis (Braisil)',
        'pt_CH' => 'Portagailis (An Eilbheis)',
        'pt_CV' => 'Portagailis (An Ceap Uaine)',
        'pt_GQ' => 'Portagailis (Gini Mheadhan-Chriosach)',
        'pt_GW' => 'Portagailis (Gini-Bioso)',
        'pt_LU' => 'Portagailis (Lugsamburg)',
        'pt_MO' => 'Portagailis (Macàthu SAR na Sìne)',
        'pt_MZ' => 'Portagailis (Mòsaimbic)',
        'pt_PT' => 'Portagailis (A’ Phortagail)',
        'pt_ST' => 'Portagailis (São Tomé agus Príncipe)',
        'pt_TL' => 'Portagailis (Timor-Leste)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Boilibhia)',
        'qu_EC' => 'Quechua (Eacuador)',
        'qu_PE' => 'Quechua (Pearù)',
        'rm' => 'Rumains',
        'rm_CH' => 'Rumains (An Eilbheis)',
        'rn' => 'Kirundi',
        'rn_BI' => 'Kirundi (Burundaidh)',
        'ro' => 'Romàinis',
        'ro_MD' => 'Romàinis (A’ Mholdobha)',
        'ro_RO' => 'Romàinis (Romàinia)',
        'ru' => 'Ruisis',
        'ru_BY' => 'Ruisis (A’ Bhealaruis)',
        'ru_KG' => 'Ruisis (Cìorgastan)',
        'ru_KZ' => 'Ruisis (Casachstàn)',
        'ru_MD' => 'Ruisis (A’ Mholdobha)',
        'ru_RU' => 'Ruisis (An Ruis)',
        'ru_UA' => 'Ruisis (An Ucràin)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Rubhanda)',
        'sa' => 'Sanskrit',
        'sa_IN' => 'Sanskrit (Na h-Innseachan)',
        'sc' => 'Sàrdais',
        'sc_IT' => 'Sàrdais (An Eadailt)',
        'sd' => 'Sindhi',
        'sd_Arab' => 'Sindhi (Arabais)',
        'sd_Arab_PK' => 'Sindhi (Arabais, Pagastàn)',
        'sd_Deva' => 'Sindhi (Devanagari)',
        'sd_Deva_IN' => 'Sindhi (Devanagari, Na h-Innseachan)',
        'sd_IN' => 'Sindhi (Na h-Innseachan)',
        'sd_PK' => 'Sindhi (Pagastàn)',
        'se' => 'Sàmais Thuathach',
        'se_FI' => 'Sàmais Thuathach (An Fhionnlann)',
        'se_NO' => 'Sàmais Thuathach (Nirribhidh)',
        'se_SE' => 'Sàmais Thuathach (An t-Suain)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Poblachd Meadhan Afraga)',
        'sh' => 'Sèirb-Chròthaisis',
        'sh_BA' => 'Sèirb-Chròthaisis (Bosna is Hearsagobhana)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (Sri Lanca)',
        'sk' => 'Slòbhacais',
        'sk_SK' => 'Slòbhacais (An t-Slòbhac)',
        'sl' => 'Slòbhainis',
        'sl_SI' => 'Slòbhainis (An t-Slòbhain)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (An t-Sìombab)',
        'so' => 'Somàilis',
        'so_DJ' => 'Somàilis (Diobùtaidh)',
        'so_ET' => 'Somàilis (An Itiop)',
        'so_KE' => 'Somàilis (Ceinia)',
        'so_SO' => 'Somàilis (Somàilia)',
        'sq' => 'Albàinis',
        'sq_AL' => 'Albàinis (Albàinia)',
        'sq_MK' => 'Albàinis (A’ Mhasadon a Tuath)',
        'sr' => 'Sèirbis',
        'sr_BA' => 'Sèirbis (Bosna is Hearsagobhana)',
        'sr_Cyrl' => 'Sèirbis (Cirilis)',
        'sr_Cyrl_BA' => 'Sèirbis (Cirilis, Bosna is Hearsagobhana)',
        'sr_Cyrl_ME' => 'Sèirbis (Cirilis, Am Monadh Neagrach)',
        'sr_Cyrl_RS' => 'Sèirbis (Cirilis, An t-Sèirb)',
        'sr_Latn' => 'Sèirbis (Laideann)',
        'sr_Latn_BA' => 'Sèirbis (Laideann, Bosna is Hearsagobhana)',
        'sr_Latn_ME' => 'Sèirbis (Laideann, Am Monadh Neagrach)',
        'sr_Latn_RS' => 'Sèirbis (Laideann, An t-Sèirb)',
        'sr_ME' => 'Sèirbis (Am Monadh Neagrach)',
        'sr_RS' => 'Sèirbis (An t-Sèirb)',
        'st' => 'Sesotho',
        'st_LS' => 'Sesotho (Leasoto)',
        'st_ZA' => 'Sesotho (Afraga a Deas)',
        'su' => 'Cànan Sunda',
        'su_ID' => 'Cànan Sunda (Na h-Innd-innse)',
        'su_Latn' => 'Cànan Sunda (Laideann)',
        'su_Latn_ID' => 'Cànan Sunda (Laideann, Na h-Innd-innse)',
        'sv' => 'Suainis',
        'sv_AX' => 'Suainis (Na h-Eileanan Åland)',
        'sv_FI' => 'Suainis (An Fhionnlann)',
        'sv_SE' => 'Suainis (An t-Suain)',
        'sw' => 'Kiswahili',
        'sw_CD' => 'Kiswahili (Congo - Kinshasa)',
        'sw_KE' => 'Kiswahili (Ceinia)',
        'sw_TZ' => 'Kiswahili (An Tansan)',
        'sw_UG' => 'Kiswahili (Uganda)',
        'ta' => 'Taimilis',
        'ta_IN' => 'Taimilis (Na h-Innseachan)',
        'ta_LK' => 'Taimilis (Sri Lanca)',
        'ta_MY' => 'Taimilis (Malaidhsea)',
        'ta_SG' => 'Taimilis (Singeapòr)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (Na h-Innseachan)',
        'tg' => 'Taidigis',
        'tg_TJ' => 'Taidigis (Taidigeastàn)',
        'th' => 'Cànan nan Tàidh',
        'th_TH' => 'Cànan nan Tàidh (Dùthaich nan Tàidh)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (Eartra)',
        'ti_ET' => 'Tigrinya (An Itiop)',
        'tk' => 'Turcmanais',
        'tk_TM' => 'Turcmanais (Turcmanastàn)',
        'tl' => 'Tagalog',
        'tl_PH' => 'Tagalog (Na h-Eileanan Filipineach)',
        'tn' => 'Tswana',
        'tn_BW' => 'Tswana (Botsuana)',
        'tn_ZA' => 'Tswana (Afraga a Deas)',
        'to' => 'Tonga',
        'to_TO' => 'Tonga (Tonga)',
        'tr' => 'Turcais',
        'tr_CY' => 'Turcais (Cìopras)',
        'tr_TR' => 'Turcais (An Tuirc)',
        'tt' => 'Tatarais',
        'tt_RU' => 'Tatarais (An Ruis)',
        'ug' => 'Ùigiurais',
        'ug_CN' => 'Ùigiurais (An t-Sìn)',
        'uk' => 'Ucràinis',
        'uk_UA' => 'Ucràinis (An Ucràin)',
        'ur' => 'Ùrdu',
        'ur_IN' => 'Ùrdu (Na h-Innseachan)',
        'ur_PK' => 'Ùrdu (Pagastàn)',
        'uz' => 'Usbagais',
        'uz_AF' => 'Usbagais (Afghanastàn)',
        'uz_Arab' => 'Usbagais (Arabais)',
        'uz_Arab_AF' => 'Usbagais (Arabais, Afghanastàn)',
        'uz_Cyrl' => 'Usbagais (Cirilis)',
        'uz_Cyrl_UZ' => 'Usbagais (Cirilis, Usbagastàn)',
        'uz_Latn' => 'Usbagais (Laideann)',
        'uz_Latn_UZ' => 'Usbagais (Laideann, Usbagastàn)',
        'uz_UZ' => 'Usbagais (Usbagastàn)',
        'vi' => 'Bhiet-Namais',
        'vi_VN' => 'Bhiet-Namais (Bhiet-Nam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (Seanagal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (Afraga a Deas)',
        'yi' => 'Iùdhais',
        'yi_UA' => 'Iùdhais (An Ucràin)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Beinin)',
        'yo_NG' => 'Yoruba (Nigèiria)',
        'za' => 'Zhuang',
        'za_CN' => 'Zhuang (An t-Sìn)',
        'zh' => 'Sìnis',
        'zh_CN' => 'Sìnis (An t-Sìn)',
        'zh_HK' => 'Sìnis (Hong Kong SAR na Sìne)',
        'zh_Hans' => 'Sìnis (Simplichte)',
        'zh_Hans_CN' => 'Sìnis (Simplichte, An t-Sìn)',
        'zh_Hans_HK' => 'Sìnis (Simplichte, Hong Kong SAR na Sìne)',
        'zh_Hans_MO' => 'Sìnis (Simplichte, Macàthu SAR na Sìne)',
        'zh_Hans_MY' => 'Sìnis (Simplichte, Malaidhsea)',
        'zh_Hans_SG' => 'Sìnis (Simplichte, Singeapòr)',
        'zh_Hant' => 'Sìnis (Tradaiseanta)',
        'zh_Hant_HK' => 'Sìnis (Tradaiseanta, Hong Kong SAR na Sìne)',
        'zh_Hant_MO' => 'Sìnis (Tradaiseanta, Macàthu SAR na Sìne)',
        'zh_Hant_MY' => 'Sìnis (Tradaiseanta, Malaidhsea)',
        'zh_Hant_TW' => 'Sìnis (Tradaiseanta, Taidh-Bhàn)',
        'zh_MO' => 'Sìnis (Macàthu SAR na Sìne)',
        'zh_SG' => 'Sìnis (Singeapòr)',
        'zh_TW' => 'Sìnis (Taidh-Bhàn)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (Afraga a Deas)',
    ],
];
