<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (അബിദ്‌ജാൻ‌)',
        'Africa/Accra' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ആക്ര)',
        'Africa/Addis_Ababa' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (അഡിസ് അബാബ)',
        'Africa/Algiers' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (അൾജിയേഴ്‌സ്)',
        'Africa/Asmera' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (അസ്‍മാര)',
        'Africa/Asmara' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (അസ്‍മാര)',
        'Africa/Bamako' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ബമാകോ)',
        'Africa/Bangui' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (ബംഗുയി)',
        'Africa/Banjul' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ബഞ്ചുൽ)',
        'Africa/Bissau' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ബിസ്സാവു)',
        'Africa/Blantyre' => 'മധ്യ ആഫ്രിക്ക സമയം (ബ്ലാണ്ടെയർ‌)',
        'Africa/Brazzaville' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (ബ്രാസവിൽ)',
        'Africa/Bujumbura' => 'മധ്യ ആഫ്രിക്ക സമയം (ബുജും‌ബുര)',
        'Africa/Cairo' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (കെയ്‌റോ)',
        'Africa/Casablanca' => 'പടിഞ്ഞാറൻ യൂറോപ്യൻ സമയം (കാസബ്ലാങ്ക)',
        'Africa/Ceuta' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ക്യൂട്ട)',
        'Africa/Conakry' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (കൊണാക്രി)',
        'Africa/Dakar' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ഡാക്കർ‌)',
        'Africa/Dar_es_Salaam' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (ദാർ എസ് സലാം)',
        'Africa/Djibouti' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (ദിജിബൗട്ടി)',
        'Africa/Douala' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (ഡൗല)',
        'Africa/El_Aaiun' => 'പടിഞ്ഞാറൻ യൂറോപ്യൻ സമയം (എൽ‌ ഐയുൻ‌)',
        'Africa/Freetown' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ഫ്രീടൗൺ)',
        'Africa/Gaborone' => 'മധ്യ ആഫ്രിക്ക സമയം (ഗാബറോൺ)',
        'Africa/Harare' => 'മധ്യ ആഫ്രിക്ക സമയം (ഹരാരെ)',
        'Africa/Johannesburg' => 'ദക്ഷിണാഫ്രിക്ക സ്റ്റാൻഡേർഡ് സമയം (ജോഹന്നാസ്ബർ‌ഗ്)',
        'Africa/Juba' => 'മധ്യ ആഫ്രിക്ക സമയം (ജുബ)',
        'Africa/Kampala' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (കമ്പാല)',
        'Africa/Khartoum' => 'മധ്യ ആഫ്രിക്ക സമയം (ഖാർ‌തൌം)',
        'Africa/Kigali' => 'മധ്യ ആഫ്രിക്ക സമയം (കിഗാലി)',
        'Africa/Kinshasa' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (കിൻഷാസ)',
        'Africa/Lagos' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (ലാഗോസ്)',
        'Africa/Libreville' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (ലിബ്രെവില്ല)',
        'Africa/Lome' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ലോം)',
        'Africa/Luanda' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (ലുവാൻഡ)',
        'Africa/Lubumbashi' => 'മധ്യ ആഫ്രിക്ക സമയം (ലൂബുംബാഷി)',
        'Africa/Lusaka' => 'മധ്യ ആഫ്രിക്ക സമയം (ലുസാക)',
        'Africa/Malabo' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (മലാബോ)',
        'Africa/Maputo' => 'മധ്യ ആഫ്രിക്ക സമയം (മാപ്യുട്ടോ)',
        'Africa/Maseru' => 'ദക്ഷിണാഫ്രിക്ക സ്റ്റാൻഡേർഡ് സമയം (മസേറു)',
        'Africa/Mbabane' => 'ദക്ഷിണാഫ്രിക്ക സ്റ്റാൻഡേർഡ് സമയം (മബാബെയ്‌ൻ‌)',
        'Africa/Mogadishu' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (മൊഗാദിഷു)',
        'Africa/Monrovia' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (മൺ‌റോവിയ)',
        'Africa/Nairobi' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (നയ്‌റോബി)',
        'Africa/Ndjamena' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (ജമെന)',
        'Africa/Niamey' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (നിയാമി)',
        'Africa/Nouakchott' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (നൗവാക്‌ഷോട്ട്)',
        'Africa/Ouagadougou' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ഔഗാദൗഗൗ)',
        'Africa/Porto-Novo' => 'പടിഞ്ഞാറൻ ആഫ്രിക്ക സമയം (പോർ‌ട്ടോ-നോവോ)',
        'Africa/Sao_Tome' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (സാവോ ടോം‌)',
        'Africa/Tripoli' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ട്രിപൊളി)',
        'Africa/Tunis' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ട്യൂണിസ്)',
        'Africa/Windhoek' => 'മധ്യ ആഫ്രിക്ക സമയം (വിൻഡ്‌ഹോക്)',
        'America/Adak' => 'ഹവായ്-അലൂഷ്യൻ സമയം (അഡാക്)',
        'America/Anchorage' => 'അലാസ്‌ക സമയം (ആങ്കറേജ്)',
        'America/Anguilla' => 'അറ്റ്‌ലാന്റിക് സമയം (ആൻഗ്വില്ല)',
        'America/Antigua' => 'അറ്റ്‌ലാന്റിക് സമയം (ആൻറിഗ്വ)',
        'America/Araguaina' => 'ബ്രസീലിയ സമയം (അറഗ്വൈന)',
        'America/Argentina/La_Rioja' => 'അർജന്റീന സമയം (ലാ റിയോജ)',
        'America/Argentina/Rio_Gallegos' => 'അർജന്റീന സമയം (റിയോ ഗ്യാലഗോസ്)',
        'America/Argentina/Salta' => 'അർജന്റീന സമയം (സാൽട്ട)',
        'America/Argentina/San_Juan' => 'അർജന്റീന സമയം (സാൻ ജുവാൻ)',
        'America/Argentina/San_Luis' => 'അർജന്റീന സമയം (സാൻ ലൂയിസ്)',
        'America/Argentina/Tucuman' => 'അർജന്റീന സമയം (റ്റുകുമാൻ)',
        'America/Argentina/Ushuaia' => 'അർജന്റീന സമയം (ഉഷിയ)',
        'America/Aruba' => 'അറ്റ്‌ലാന്റിക് സമയം (അറൂബ)',
        'America/Asuncion' => 'പരാഗ്വേ സമയം (അസൻ‌ഷ്യൻ‌)',
        'America/Bahia' => 'ബ്രസീലിയ സമയം (ബഹിയ)',
        'America/Bahia_Banderas' => 'സെൻട്രൽ സമയം (ബഹിയ ബൻഡാരസ്)',
        'America/Barbados' => 'അറ്റ്‌ലാന്റിക് സമയം (ബാർബഡോസ്)',
        'America/Belem' => 'ബ്രസീലിയ സമയം (ബെലം)',
        'America/Belize' => 'സെൻട്രൽ സമയം (ബെലീസ്)',
        'America/Blanc-Sablon' => 'അറ്റ്‌ലാന്റിക് സമയം (ബ്ലാങ്ക് സാബ്ലോൺ)',
        'America/Boa_Vista' => 'ആമസോൺ സമയം (ബോവ വിസ്റ്റ)',
        'America/Bogota' => 'കൊളംബിയ സമയം (ബൊഗോട്ട)',
        'America/Boise' => 'മൗണ്ടൻ സമയം (ബൊയ്സി)',
        'America/Buenos_Aires' => 'അർജന്റീന സമയം (ബ്യൂണസ് ഐറിസ്)',
        'America/Argentina/Buenos_Aires' => 'അർജന്റീന സമയം (ബ്യൂണസ് ഐറിസ്)',
        'America/Cambridge_Bay' => 'മൗണ്ടൻ സമയം (കേംബ്രിഡ്‌ജ് ബേ)',
        'America/Campo_Grande' => 'ആമസോൺ സമയം (ക്യാമ്പോ ഗ്രാൻഡെ)',
        'America/Cancun' => 'ഈസ്റ്റേൺ സമയം (കാൻകൂൺ)',
        'America/Caracas' => 'വെനിസ്വേല സമയം (കരാക്കസ്)',
        'America/Catamarca' => 'അർജന്റീന സമയം (‍ക്യാറ്റമാർക്ക)',
        'America/Argentina/Catamarca' => 'അർജന്റീന സമയം (‍ക്യാറ്റമാർക്ക)',
        'America/Cayenne' => 'ഫ്രഞ്ച് ഗയാന സമയം (കയീൻ‌)',
        'America/Cayman' => 'ഈസ്റ്റേൺ സമയം (കേമാൻ)',
        'America/Chicago' => 'സെൻട്രൽ സമയം (ചിക്കാഗോ)',
        'America/Chihuahua' => 'സെൻട്രൽ സമയം (ചിഹ്വാഹ)',
        'America/Ciudad_Juarez' => 'മൗണ്ടൻ സമയം (സിയുഡാഡ് ഹുവാരസ്)',
        'America/Coral_Harbour' => 'ഈസ്റ്റേൺ സമയം (ഏറ്റികോക്കൺ)',
        'America/Atikokan' => 'ഈസ്റ്റേൺ സമയം (ഏറ്റികോക്കൺ)',
        'America/Cordoba' => 'അർജന്റീന സമയം (കോർഡോബ)',
        'America/Argentina/Cordoba' => 'അർജന്റീന സമയം (കോർഡോബ)',
        'America/Costa_Rica' => 'സെൻട്രൽ സമയം (കോസ്റ്റ റിക്ക)',
        'America/Coyhaique' => 'ചിലി സമയം (കൊയൈകേ)',
        'America/Creston' => 'മൗണ്ടൻ സമയം (ക്രെസ്റ്റൺ)',
        'America/Cuiaba' => 'ആമസോൺ സമയം (കുയ്‌ബ)',
        'America/Curacao' => 'അറ്റ്‌ലാന്റിക് സമയം (കുറാക്കാവോ)',
        'America/Danmarkshavn' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ഡാൻമാർക്ക്ഷാവ്ൻ)',
        'America/Dawson' => 'യൂക്കോൺ സമയം (ഡോവ്സൺ)',
        'America/Dawson_Creek' => 'മൗണ്ടൻ സമയം (ഡോവ്സൺ ക്രീക്ക്)',
        'America/Denver' => 'മൗണ്ടൻ സമയം (ഡെൻ‌വർ)',
        'America/Detroit' => 'ഈസ്റ്റേൺ സമയം (ഡെട്രോയിറ്റ്)',
        'America/Dominica' => 'അറ്റ്‌ലാന്റിക് സമയം (ഡൊമിനിക്ക)',
        'America/Edmonton' => 'മൗണ്ടൻ സമയം (എഡ്മോൺടൺ)',
        'America/Eirunepe' => 'എയ്ക്കർ സമയം (യെറുനീപ്പെ)',
        'America/El_Salvador' => 'സെൻട്രൽ സമയം (എൽ സാൽ‌വദോർ)',
        'America/Fort_Nelson' => 'മൗണ്ടൻ സമയം (ഫോർട്ട് നെൽസൺ)',
        'America/Fortaleza' => 'ബ്രസീലിയ സമയം (ഫോർട്ടലീസ)',
        'America/Glace_Bay' => 'അറ്റ്‌ലാന്റിക് സമയം (ഗ്ലെയ്സ് ബേ)',
        'America/Godthab' => 'ഗ്രീൻലൻഡ് സമയം (നൂക്ക്)',
        'America/Nuuk' => 'ഗ്രീൻലൻഡ് സമയം (നൂക്ക്)',
        'America/Goose_Bay' => 'അറ്റ്‌ലാന്റിക് സമയം (ഗൂസ് ബേ)',
        'America/Grand_Turk' => 'ഈസ്റ്റേൺ സമയം (ഗ്രാൻഡ് ടർക്ക്)',
        'America/Grenada' => 'അറ്റ്‌ലാന്റിക് സമയം (ഗ്രനേഡ)',
        'America/Guadeloupe' => 'അറ്റ്‌ലാന്റിക് സമയം (ഗ്വാഡലൂപ്പ്)',
        'America/Guatemala' => 'സെൻട്രൽ സമയം (ഗ്വാട്ടിമാല)',
        'America/Guayaquil' => 'ഇക്വഡോർ സമയം (ഗുവായക്വിൽ)',
        'America/Guyana' => 'ഗയാന സമയം',
        'America/Halifax' => 'അറ്റ്‌ലാന്റിക് സമയം (ഹാലിഫാക്സ്)',
        'America/Havana' => 'ക്യൂബ സമയം (ഹവാന)',
        'America/Hermosillo' => 'മെക്സിക്കൻ പസഫിക് സമയം (ഹെർമോസില്ലോ)',
        'America/Indiana/Knox' => 'സെൻട്രൽ സമയം (നോക്സ്, ഇൻഡ്യാന)',
        'America/Indiana/Marengo' => 'ഈസ്റ്റേൺ സമയം (മരെങ്കോ, ഇൻഡ്യാന)',
        'America/Indiana/Petersburg' => 'ഈസ്റ്റേൺ സമയം (പീറ്റേഴ്സ്ബർഗ്, ഇൻഡ്യാന)',
        'America/Indiana/Tell_City' => 'സെൻട്രൽ സമയം (റ്റെൽ സിറ്റി, ഇൻഡ്യാന)',
        'America/Indiana/Vevay' => 'ഈസ്റ്റേൺ സമയം (വിവെയ്, ഇൻഡ്യാന)',
        'America/Indiana/Vincennes' => 'ഈസ്റ്റേൺ സമയം (വിൻസെൻസ്, ഇൻഡ്യാന)',
        'America/Indiana/Winamac' => 'ഈസ്റ്റേൺ സമയം (വിനാമാക്, ഇൻഡ്യാന)',
        'America/Indianapolis' => 'ഈസ്റ്റേൺ സമയം (ഇൻഡ്യാനാപോളിസ്)',
        'America/Indiana/Indianapolis' => 'ഈസ്റ്റേൺ സമയം (ഇൻഡ്യാനാപോളിസ്)',
        'America/Inuvik' => 'മൗണ്ടൻ സമയം (ഇനുവിക്)',
        'America/Iqaluit' => 'ഈസ്റ്റേൺ സമയം (ഇഖാലിത്)',
        'America/Jamaica' => 'ഈസ്റ്റേൺ സമയം (ജമൈക്ക)',
        'America/Jujuy' => 'അർജന്റീന സമയം (ജുജുയ്)',
        'America/Argentina/Jujuy' => 'അർജന്റീന സമയം (ജുജുയ്)',
        'America/Juneau' => 'അലാസ്‌ക സമയം (ജൂനോ)',
        'America/Kentucky/Monticello' => 'ഈസ്റ്റേൺ സമയം (മോണ്ടിസെല്ലോ, കെന്റക്കി)',
        'America/Kralendijk' => 'അറ്റ്‌ലാന്റിക് സമയം (കാർലൻഡിജെക്ക്)',
        'America/La_Paz' => 'ബൊളീവിയ സമയം (ലാ പാസ്)',
        'America/Lima' => 'പെറു സമയം (ലിമ)',
        'America/Los_Angeles' => 'വടക്കെ അമേരിക്കൻ പസഫിക് സമയം (ലോസ് എയ്ഞ്ചലസ്)',
        'America/Louisville' => 'ഈസ്റ്റേൺ സമയം (ലൂയിസ്‌വില്ലെ)',
        'America/Kentucky/Louisville' => 'ഈസ്റ്റേൺ സമയം (ലൂയിസ്‌വില്ലെ)',
        'America/Lower_Princes' => 'അറ്റ്‌ലാന്റിക് സമയം (ലോവർ പ്രിൻസസ് ക്വാർട്ടർ)',
        'America/Maceio' => 'ബ്രസീലിയ സമയം (മാസിയോ)',
        'America/Managua' => 'സെൻട്രൽ സമയം (മനാഗ്വ)',
        'America/Manaus' => 'ആമസോൺ സമയം (മനൗസ്)',
        'America/Marigot' => 'അറ്റ്‌ലാന്റിക് സമയം (മാരിഗോ)',
        'America/Martinique' => 'അറ്റ്‌ലാന്റിക് സമയം (മാർട്ടിനിക്)',
        'America/Matamoros' => 'സെൻട്രൽ സമയം (മറ്റാമൊറോസ്)',
        'America/Mazatlan' => 'മെക്സിക്കൻ പസഫിക് സമയം (മസറ്റ്‌ലാൻ)',
        'America/Mendoza' => 'അർജന്റീന സമയം (മെൻഡോസ)',
        'America/Argentina/Mendoza' => 'അർജന്റീന സമയം (മെൻഡോസ)',
        'America/Menominee' => 'സെൻട്രൽ സമയം (മെനോമിനീ)',
        'America/Merida' => 'സെൻട്രൽ സമയം (മെരിഡ)',
        'America/Metlakatla' => 'അലാസ്‌ക സമയം (മെഡ്‌ലകട്‌ലെ)',
        'America/Mexico_City' => 'സെൻട്രൽ സമയം (മെക്സിക്കോ സിറ്റി)',
        'America/Miquelon' => 'സെന്റ് പിയറി ആൻഡ് മിക്വലൻ സമയം',
        'America/Moncton' => 'അറ്റ്‌ലാന്റിക് സമയം (മോംഗ്‌ടൻ)',
        'America/Monterrey' => 'സെൻട്രൽ സമയം (മോണ്ടെറി)',
        'America/Montevideo' => 'ഉറുഗ്വേ സമയം (മൊണ്ടെ‌വീഡിയോ)',
        'America/Montserrat' => 'അറ്റ്‌ലാന്റിക് സമയം (മൊണ്ടെസരത്ത്)',
        'America/Nassau' => 'ഈസ്റ്റേൺ സമയം (നാസൗ)',
        'America/New_York' => 'ഈസ്റ്റേൺ സമയം (ന്യൂയോർക്ക്)',
        'America/Nome' => 'അലാസ്‌ക സമയം (നോം)',
        'America/Noronha' => 'ഫെർണാഡോ ഡി നൊറോൻഹ സമയം (നൊറോന)',
        'America/North_Dakota/Beulah' => 'സെൻട്രൽ സമയം (ബ്യൂല, വടക്കൻ ഡെക്കോട്ട)',
        'America/North_Dakota/Center' => 'സെൻട്രൽ സമയം (സെന്റർ, വടക്കൻ ഡെക്കോട്ട)',
        'America/North_Dakota/New_Salem' => 'സെൻട്രൽ സമയം (ന്യൂ സെയ്‌ലം, വടക്കൻ ഡെക്കോട്ട)',
        'America/Ojinaga' => 'സെൻട്രൽ സമയം (ഒജിൻഗ)',
        'America/Panama' => 'ഈസ്റ്റേൺ സമയം (പനാമ)',
        'America/Paramaribo' => 'സുരിനെയിം സമയം (പരാമാരിബോ)',
        'America/Phoenix' => 'മൗണ്ടൻ സമയം (ഫീനിക്സ്)',
        'America/Port-au-Prince' => 'ഈസ്റ്റേൺ സമയം (പോർട്ടോപ്രിൻസ്)',
        'America/Port_of_Spain' => 'അറ്റ്‌ലാന്റിക് സമയം (പോർ‌ട്ട് ഓഫ് സ്‌പെയിൻ‌)',
        'America/Porto_Velho' => 'ആമസോൺ സമയം (പോർട്ടോ വെല്ലോ)',
        'America/Puerto_Rico' => 'അറ്റ്‌ലാന്റിക് സമയം (പ്യൂർട്ടോ റിക്കോ)',
        'America/Punta_Arenas' => 'ചിലി സമയം (പുന്റ അരീനസ്)',
        'America/Rankin_Inlet' => 'സെൻട്രൽ സമയം (റാങ്കിൻ ഇൻലെറ്റ്)',
        'America/Recife' => 'ബ്രസീലിയ സമയം (റെസീഫെ)',
        'America/Regina' => 'സെൻട്രൽ സമയം (റിജീന)',
        'America/Resolute' => 'സെൻട്രൽ സമയം (റെസല്യൂട്ട്)',
        'America/Rio_Branco' => 'എയ്ക്കർ സമയം (റിയോ ബ്രാങ്കോ)',
        'America/Santarem' => 'ബ്രസീലിയ സമയം (സാന്ററെം)',
        'America/Santiago' => 'ചിലി സമയം (സാന്റിയാഗോ)',
        'America/Santo_Domingo' => 'അറ്റ്‌ലാന്റിക് സമയം (സാന്തോ ഡോമിംഗോ)',
        'America/Sao_Paulo' => 'ബ്രസീലിയ സമയം (സാവോപോളോ)',
        'America/Scoresbysund' => 'ഗ്രീൻലൻഡ് സമയം (ഇറ്റ്വാഖ്വാർടൂർമിറ്റ്)',
        'America/Sitka' => 'അലാസ്‌ക സമയം (സിറ്റ്‌കാ)',
        'America/St_Barthelemy' => 'അറ്റ്‌ലാന്റിക് സമയം (സെന്റ് ബർത്തലെമി)',
        'America/St_Johns' => 'ന്യൂഫൗണ്ട്‌ലാന്റ് സമയം (സെന്റ് ജോൺസ്)',
        'America/St_Kitts' => 'അറ്റ്‌ലാന്റിക് സമയം (സെന്റ് കിറ്റ്സ്)',
        'America/St_Lucia' => 'അറ്റ്‌ലാന്റിക് സമയം (സെന്റ് ലൂസിയ)',
        'America/St_Thomas' => 'അറ്റ്‌ലാന്റിക് സമയം (സെന്റ് തോമസ്)',
        'America/St_Vincent' => 'അറ്റ്‌ലാന്റിക് സമയം (സെന്റ് വിൻസെന്റ്)',
        'America/Swift_Current' => 'സെൻട്രൽ സമയം (സ്വിഫ്‌റ്റ് കറന്റ്)',
        'America/Tegucigalpa' => 'സെൻട്രൽ സമയം (ടെഗൂസിഗാൽപ)',
        'America/Thule' => 'അറ്റ്‌ലാന്റിക് സമയം (തൂളി)',
        'America/Tijuana' => 'വടക്കെ അമേരിക്കൻ പസഫിക് സമയം (തിയുവാന)',
        'America/Toronto' => 'ഈസ്റ്റേൺ സമയം (ടൊറന്റോ)',
        'America/Tortola' => 'അറ്റ്‌ലാന്റിക് സമയം (ടോർ‌ട്ടോള)',
        'America/Vancouver' => 'വടക്കെ അമേരിക്കൻ പസഫിക് സമയം (വാൻ‌കൂവർ)',
        'America/Whitehorse' => 'യൂക്കോൺ സമയം (വൈറ്റ്ഹോഴ്സ്)',
        'America/Winnipeg' => 'സെൻട്രൽ സമയം (വിന്നിപെഗ്)',
        'America/Yakutat' => 'അലാസ്‌ക സമയം (യാകുറ്റാറ്റ്)',
        'Antarctica/Casey' => 'പടിഞ്ഞാറൻ ഓസ്‌ട്രേലിയ സമയം (കാസെ)',
        'Antarctica/Davis' => 'ഡേവിസ് സമയം (ഡെയ്‌വിസ്)',
        'Antarctica/DumontDUrville' => 'ഡുമോണ്ട് ഡി ഉർവില്ലെ സമയം (ഡ്യൂമണ്ട് ഡി യുർവിൽ)',
        'Antarctica/Macquarie' => 'കിഴക്കൻ ഓസ്‌ട്രേലിയ സമയം (മക്വയറി)',
        'Antarctica/Mawson' => 'മാസൺ സമയം (മാവ്സൺ)',
        'Antarctica/McMurdo' => 'ന്യൂസിലാൻഡ് സമയം (മാക്മർഡോ)',
        'Antarctica/Palmer' => 'ചിലി സമയം (പാമർ)',
        'Antarctica/Rothera' => 'റോഥെറ സമയം (റൊതീറ)',
        'Antarctica/Syowa' => 'സയോവ സമയം (സ്യോവ)',
        'Antarctica/Troll' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ട്രോൾ)',
        'Antarctica/Vostok' => 'വോസ്റ്റോക് സമയം',
        'Arctic/Longyearbyen' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ലംഗ്‍യെർബിൻ)',
        'Asia/Aden' => 'അറേബ്യൻ സമയം (ഏദെൻ)',
        'Asia/Almaty' => 'കസാഖിസ്ഥാൻ സമയം (അൽമാട്ടി)',
        'Asia/Amman' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (അമ്മാൻ‌)',
        'Asia/Anadyr' => 'പെട്രോപാവ്‌ലോസ്ക് കംചാസ്കി സമയം (അനാഡിർ)',
        'Asia/Aqtau' => 'കസാഖിസ്ഥാൻ സമയം (അക്തൗ)',
        'Asia/Aqtobe' => 'കസാഖിസ്ഥാൻ സമയം (അഖ്‌തോബ്)',
        'Asia/Ashgabat' => 'തുർക്ക്‌മെനിസ്ഥാൻ സമയം (ആഷ്‌ഗാബട്ട്)',
        'Asia/Atyrau' => 'കസാഖിസ്ഥാൻ സമയം (അറ്റിറോ)',
        'Asia/Baghdad' => 'അറേബ്യൻ സമയം (ബാഗ്‌ദാദ്)',
        'Asia/Bahrain' => 'അറേബ്യൻ സമയം (ബഹ്റിൻ)',
        'Asia/Baku' => 'അസർബൈജാൻ സമയം (ബാക്കു)',
        'Asia/Bangkok' => 'ഇൻഡോചൈന സമയം (ബാങ്കോക്ക്)',
        'Asia/Barnaul' => 'ക്രാസ്‌നോയാർസ്‌ക് സമയം (ബർണോൽ)',
        'Asia/Beirut' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ബെയ്‌റൂട്ട്)',
        'Asia/Bishkek' => 'കിർഗിസ്ഥാൻ സമയം (ബിഷ്‌കേക്)',
        'Asia/Brunei' => 'ബ്രൂണൈ ദാറുസ്സലാം സമയം',
        'Asia/Calcutta' => 'ഇന്ത്യൻ സ്റ്റാൻഡേർഡ് സമയം (കൊൽ‌ക്കത്ത)',
        'Asia/Kolkata' => 'ഇന്ത്യൻ സ്റ്റാൻഡേർഡ് സമയം (കൊൽ‌ക്കത്ത)',
        'Asia/Chita' => 'യാകസ്‌ക്ക് സമയം (ചീറ്റ)',
        'Asia/Colombo' => 'ഇന്ത്യൻ സ്റ്റാൻഡേർഡ് സമയം (കൊളം‌ബോ)',
        'Asia/Damascus' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ദമാസ്കസ്)',
        'Asia/Dhaka' => 'ബംഗ്ലാദേശ് സമയം (ധാക്ക)',
        'Asia/Dili' => 'കിഴക്കൻ തിമോർ സമയം (ദിലി)',
        'Asia/Dubai' => 'ഗൾഫ് സ്റ്റാൻഡേർഡ് സമയം (ദുബായ്)',
        'Asia/Dushanbe' => 'താജിക്കിസ്ഥാൻ സമയം (ദുഷൻ‌ബെ)',
        'Asia/Famagusta' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ഫാമഗുസ്‌റ്റ)',
        'Asia/Gaza' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ഗാസ)',
        'Asia/Hebron' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ഹെബ്‌റോൺ)',
        'Asia/Hong_Kong' => 'ഹോങ്കോങ്ങ് സമയം (ഹോങ്കോംഗ്)',
        'Asia/Hovd' => 'ഹോഡ് സമയം',
        'Asia/Irkutsk' => 'ഇർകസ്ക് സമയം',
        'Asia/Jakarta' => 'പടിഞ്ഞാറൻ ഇന്തോനേഷ്യ സമയം (ജക്കാർത്ത)',
        'Asia/Jayapura' => 'കിഴക്കൻ ഇന്തോനേഷ്യ സമയം (ജയപുര)',
        'Asia/Jerusalem' => 'ഇസ്രായേൽ സമയം (ജെറുസലേം)',
        'Asia/Kabul' => 'അഫ്‌ഗാനിസ്ഥാൻ സമയം (കാബൂൾ)',
        'Asia/Kamchatka' => 'പെട്രോപാവ്‌ലോസ്ക് കംചാസ്കി സമയം (കാംചട്ക)',
        'Asia/Karachi' => 'പാക്കിസ്ഥാൻ സമയം (കറാച്ചി)',
        'Asia/Katmandu' => 'നേപ്പാൾ സമയം (കാഠ്‌മണ്ഡു)',
        'Asia/Kathmandu' => 'നേപ്പാൾ സമയം (കാഠ്‌മണ്ഡു)',
        'Asia/Khandyga' => 'യാകസ്‌ക്ക് സമയം (കാൻഡിഗ)',
        'Asia/Krasnoyarsk' => 'ക്രാസ്‌നോയാർസ്‌ക് സമയം (ക്രാസ്നോയാസ്ക്)',
        'Asia/Kuala_Lumpur' => 'മലേഷ്യ സമയം (ക്വാലലം‌പൂർ‌‌)',
        'Asia/Kuching' => 'മലേഷ്യ സമയം (കുചിങ്)',
        'Asia/Kuwait' => 'അറേബ്യൻ സമയം (കുവൈത്ത്)',
        'Asia/Macau' => 'ചൈന സമയം (മക്കാവു)',
        'Asia/Magadan' => 'മഗാദൻ സമയം (മഗഡാൻ)',
        'Asia/Makassar' => 'മധ്യ ഇന്തോനേഷ്യ സമയം (മകസ്സർ)',
        'Asia/Manila' => 'ഫിലിപ്പൈൻ സമയം (മനില)',
        'Asia/Muscat' => 'ഗൾഫ് സ്റ്റാൻഡേർഡ് സമയം (മസ്കറ്റ്)',
        'Asia/Nicosia' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (നിക്കോഷ്യ)',
        'Asia/Novokuznetsk' => 'ക്രാസ്‌നോയാർസ്‌ക് സമയം (നോവോകുസെൻസ്‌ക്)',
        'Asia/Novosibirsk' => 'ക്രാസ്‌നോയാർസ്‌ക് സമയം (നൊവോസിബിർസ്ക്)',
        'Asia/Omsk' => 'ഓംസ്‌ക്ക് സമയം (ഒംസ്ക്)',
        'Asia/Oral' => 'കസാഖിസ്ഥാൻ സമയം (ഓറൽ)',
        'Asia/Phnom_Penh' => 'ഇൻഡോചൈന സമയം (ഫെനോം പെൻ)',
        'Asia/Pontianak' => 'പടിഞ്ഞാറൻ ഇന്തോനേഷ്യ സമയം (പൊന്റിയാനക്)',
        'Asia/Pyongyang' => 'കൊറിയൻ സമയം (പ്യോംഗ്‌യാംഗ്)',
        'Asia/Qatar' => 'അറേബ്യൻ സമയം (ഖത്തർ)',
        'Asia/Qostanay' => 'കസാഖിസ്ഥാൻ സമയം (കോസ്റ്റനേ)',
        'Asia/Qyzylorda' => 'കസാഖിസ്ഥാൻ സമയം (ഖിസിലോർഡ)',
        'Asia/Rangoon' => 'മ്യാൻമാർ സമയം (റങ്കൂൺ‌)',
        'Asia/Yangon' => 'മ്യാൻമാർ സമയം (റങ്കൂൺ‌)',
        'Asia/Riyadh' => 'അറേബ്യൻ സമയം (റിയാദ്)',
        'Asia/Saigon' => 'ഇൻഡോചൈന സമയം (ഹോ ചി മിൻ സിറ്റി)',
        'Asia/Ho_Chi_Minh' => 'ഇൻഡോചൈന സമയം (ഹോ ചി മിൻ സിറ്റി)',
        'Asia/Sakhalin' => 'മഗാദൻ സമയം (സഖാലിൻ)',
        'Asia/Samarkand' => 'ഉസ്‌ബെക്കിസ്ഥാൻ സമയം (സമർക്കന്ദ്)',
        'Asia/Seoul' => 'കൊറിയൻ സമയം (സോൾ)',
        'Asia/Shanghai' => 'ചൈന സമയം (ഷാങ്‌ഹായി)',
        'Asia/Singapore' => 'സിംഗപ്പൂർ സ്റ്റാൻഡേർഡ് സമയം',
        'Asia/Srednekolymsk' => 'മഗാദൻ സമയം (സ്രിഡ്‌നികോളിംസ്ക്)',
        'Asia/Taipei' => 'തായ്‌പെയ് സമയം',
        'Asia/Tashkent' => 'ഉസ്‌ബെക്കിസ്ഥാൻ സമയം (താഷ്‌ക്കന്റ്)',
        'Asia/Tbilisi' => 'ജോർജ്ജിയ സമയം (തിബിലിസി)',
        'Asia/Tehran' => 'ഇറാൻ സമയം (ടെഹ്‌റാൻ‌)',
        'Asia/Thimphu' => 'ഭൂട്ടാൻ സമയം (തിംഫു)',
        'Asia/Tokyo' => 'ജപ്പാൻ സമയം (ടോക്കിയോ)',
        'Asia/Tomsk' => 'ക്രാസ്‌നോയാർസ്‌ക് സമയം (ടോംസ്ക്)',
        'Asia/Ulaanbaatar' => 'ഉലാൻബാത്തർ സമയം',
        'Asia/Urumqi' => 'ചൈന സമയം (ഉറുംഖി)',
        'Asia/Ust-Nera' => 'വ്ലാഡിവോസ്റ്റോക് സമയം (യുസ്-നേര)',
        'Asia/Vientiane' => 'ഇൻഡോചൈന സമയം (വെന്റിയാൻ)',
        'Asia/Vladivostok' => 'വ്ലാഡിവോസ്റ്റോക് സമയം (വ്ളാഡിവോസ്റ്റോക്)',
        'Asia/Yakutsk' => 'യാകസ്‌ക്ക് സമയം (യാക്കറ്റ്സ്‌ക്)',
        'Asia/Yekaterinburg' => 'യെക്കാറ്റരിൻബർഗ് സമയം (യാകാറ്റെറിൻബർഗ്)',
        'Asia/Yerevan' => 'അർമേനിയ സമയം (യേരവൻ‌)',
        'Atlantic/Azores' => 'അസോർസ് സമയം (അസോറസ്)',
        'Atlantic/Bermuda' => 'അറ്റ്‌ലാന്റിക് സമയം (ബർമുഡ)',
        'Atlantic/Canary' => 'പടിഞ്ഞാറൻ യൂറോപ്യൻ സമയം (ക്യാനറി)',
        'Atlantic/Cape_Verde' => 'കേപ് വെർദെ സമയം',
        'Atlantic/Faeroe' => 'പടിഞ്ഞാറൻ യൂറോപ്യൻ സമയം (ഫെറോ)',
        'Atlantic/Faroe' => 'പടിഞ്ഞാറൻ യൂറോപ്യൻ സമയം (ഫെറോ)',
        'Atlantic/Madeira' => 'പടിഞ്ഞാറൻ യൂറോപ്യൻ സമയം (മഡെയ്റ)',
        'Atlantic/Reykjavik' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (റേയ്‌ജാവിക്)',
        'Atlantic/South_Georgia' => 'ദക്ഷിണ ജോർജ്ജിയൻ സമയം (ദക്ഷിണ ജോർജിയ)',
        'Atlantic/St_Helena' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (സെന്റ് ഹെലെന)',
        'Atlantic/Stanley' => 'ഫാക്ക്‌ലാൻഡ് ദ്വീപുകൾ സമയം (സ്റ്റാൻ‌ലി)',
        'Australia/Adelaide' => 'സെൻട്രൽ ഓസ്ട്രേലിയ സമയം (അഡിലെയ്‌ഡ്)',
        'Australia/Brisbane' => 'കിഴക്കൻ ഓസ്‌ട്രേലിയ സമയം (ബ്രിസ്‌ബെയിൻ)',
        'Australia/Broken_Hill' => 'സെൻട്രൽ ഓസ്ട്രേലിയ സമയം (ബ്രോക്കൺ ഹിൽ)',
        'Australia/Darwin' => 'സെൻട്രൽ ഓസ്ട്രേലിയ സമയം (ഡാർവിൻ)',
        'Australia/Eucla' => 'ഓസ്ട്രേലിയൻ സെൻട്രൽ പടിഞ്ഞാറൻ സമയം (യൂക്ല)',
        'Australia/Hobart' => 'കിഴക്കൻ ഓസ്‌ട്രേലിയ സമയം (ഹൊബാർട്ട്)',
        'Australia/Lindeman' => 'കിഴക്കൻ ഓസ്‌ട്രേലിയ സമയം (ലിൻഡെമാൻ)',
        'Australia/Lord_Howe' => 'ലോർഡ് ഹോവ് സമയം (ലോഡ് ഹോവ്)',
        'Australia/Melbourne' => 'കിഴക്കൻ ഓസ്‌ട്രേലിയ സമയം (മെൽബൺ)',
        'Australia/Perth' => 'പടിഞ്ഞാറൻ ഓസ്‌ട്രേലിയ സമയം (പെർത്ത്)',
        'Australia/Sydney' => 'കിഴക്കൻ ഓസ്‌ട്രേലിയ സമയം (സിഡ്നി)',
        'Etc/GMT' => 'ഗ്രീൻവിച്ച് മീൻ സമയം',
        'Etc/UTC' => 'കോർഡിനേറ്റഡ് യൂണിവേഴ്‌സൽ സമയം',
        'Europe/Amsterdam' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ആം‌സ്റ്റർ‌ഡാം)',
        'Europe/Andorra' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (അണ്ടോറ)',
        'Europe/Astrakhan' => 'സമാര സമയം (അസ്‌ട്രഖാൻ)',
        'Europe/Athens' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ഏതൻ‌സ്)',
        'Europe/Belgrade' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ബെൽഗ്രേഡ്)',
        'Europe/Berlin' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ബെർ‌ലിൻ‌)',
        'Europe/Bratislava' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ബ്രാട്ടിസ്‍ലാവ)',
        'Europe/Brussels' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ബ്രസ്സൽ‌സ്)',
        'Europe/Bucharest' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ബുച്ചാറെസ്റ്റ്)',
        'Europe/Budapest' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ബുഡാപെസ്റ്റ്)',
        'Europe/Busingen' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ബുസിൻജൻ)',
        'Europe/Chisinau' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ചിസിനാവു)',
        'Europe/Copenhagen' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (കോപ്പൻ‌ഹേഗൻ‌)',
        'Europe/Dublin' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ഡബ്ലിൻ)',
        'Europe/Gibraltar' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ജിബ്രാൾട്ടർ)',
        'Europe/Guernsey' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ഗേൺസേ)',
        'Europe/Helsinki' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ഹെൽ‌സിങ്കി)',
        'Europe/Isle_of_Man' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ഐൽ‌ ഓഫ് മാൻ‌)',
        'Europe/Istanbul' => 'തുർക്കി സമയം (ഇസ്താം‌ബുൾ‌)',
        'Europe/Jersey' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ജേഴ്‌സി)',
        'Europe/Kaliningrad' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (കലിനിൻഗ്രാഡ്)',
        'Europe/Kiev' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (കീവ്)',
        'Europe/Kyiv' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (കീവ്)',
        'Europe/Kirov' => 'മോസ്കോ സമയം (കിറോ)',
        'Europe/Lisbon' => 'പടിഞ്ഞാറൻ യൂറോപ്യൻ സമയം (ലിസ്‌ബൺ‌)',
        'Europe/Ljubljana' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ലുബ്‍ലിയാന)',
        'Europe/London' => 'ഗ്രീൻവിച്ച് മീൻ സമയം (ലണ്ടൻ‌)',
        'Europe/Luxembourg' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ലക്‌സംബർഗ്)',
        'Europe/Madrid' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (മാഡ്രിഡ്)',
        'Europe/Malta' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (മാൾട്ട)',
        'Europe/Mariehamn' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (മരിയാഹാമൻ)',
        'Europe/Minsk' => 'മോസ്കോ സമയം (മിൻ‌സ്ക്)',
        'Europe/Monaco' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (മൊണാക്കോ)',
        'Europe/Moscow' => 'മോസ്കോ സമയം',
        'Europe/Oslo' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ഓസ്ലോ)',
        'Europe/Paris' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (പാരീസ്)',
        'Europe/Podgorica' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (പൊഡ്‍ഗൊറിസ)',
        'Europe/Prague' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (പ്രാഗ്)',
        'Europe/Riga' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (റിഗ)',
        'Europe/Rome' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (റോം)',
        'Europe/Samara' => 'സമാര സമയം (സമാറ)',
        'Europe/San_Marino' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (സാൻ മാരിനോ)',
        'Europe/Sarajevo' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (സരയേവോ)',
        'Europe/Saratov' => 'സമാര സമയം (സരാറ്റോവ്)',
        'Europe/Simferopol' => 'മോസ്കോ സമയം (സിംഫെറോപോൾ)',
        'Europe/Skopje' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (സ്കോപ്പിയെ)',
        'Europe/Sofia' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (സോഫിയ)',
        'Europe/Stockholm' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (സ്റ്റോക്ക്ഹോം)',
        'Europe/Tallinn' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (ടാലിൻ‌)',
        'Europe/Tirane' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (ടിരാനെ)',
        'Europe/Ulyanovsk' => 'സമാര സമയം (ഉല്ല്യാനോവ്‌സ്‌ക്)',
        'Europe/Vaduz' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (വാദുസ്)',
        'Europe/Vatican' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (വത്തിക്കാൻ)',
        'Europe/Vienna' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (വിയന്ന)',
        'Europe/Vilnius' => 'കിഴക്കൻ യൂറോപ്യൻ സമയം (വിൽ‌നിയസ്)',
        'Europe/Volgograd' => 'മോസ്കോ സമയം (വോൾഗോഗ്രാഡ്)',
        'Europe/Warsaw' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (വാർസോ)',
        'Europe/Zagreb' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (സാക്രെബ്)',
        'Europe/Zurich' => 'സെൻട്രൽ യൂറോപ്യൻ സമയം (സൂറിച്ച്)',
        'Indian/Antananarivo' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (അൻറാനനറിവോ)',
        'Indian/Chagos' => 'ഇന്ത്യൻ മഹാസമുദ്ര സമയം (ചാഗോസ്)',
        'Indian/Christmas' => 'ക്രിസ്‌മസ് ദ്വീപ് സമയം (ക്രിസ്തുമസ്)',
        'Indian/Cocos' => 'കൊക്കോസ് ദ്വീപുകൾ സമയം (കോക്കോസ്)',
        'Indian/Comoro' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (കൊമോറോ)',
        'Indian/Kerguelen' => 'ഫ്രഞ്ച് സതേൺ, അന്റാർട്ടിക് സമയം (കെർഗുലെൻ)',
        'Indian/Mahe' => 'സീഷെൽസ് സമയം (മാഹി)',
        'Indian/Maldives' => 'മാലിദ്വീപ് സമയം',
        'Indian/Mauritius' => 'മൗറീഷ്യസ് സമയം',
        'Indian/Mayotte' => 'കിഴക്കൻ ആഫ്രിക്ക സമയം (മയോട്ടി)',
        'Indian/Reunion' => 'റീയൂണിയൻ സമയം',
        'Pacific/Apia' => 'അപിയ സമയം (ആപിയ)',
        'Pacific/Auckland' => 'ന്യൂസിലാൻഡ് സമയം (ഓക്ക്‌ലാന്റ്)',
        'Pacific/Bougainville' => 'പാപ്പുവ ന്യൂ ഗിനിയ സമയം (ബോഗൺവില്ലെ)',
        'Pacific/Chatham' => 'ചാത്തം സമയം',
        'Pacific/Easter' => 'ഈസ്റ്റർ ദ്വീപ് സമയം',
        'Pacific/Efate' => 'വന്വാതു സമയം (ഇഫാതെ)',
        'Pacific/Enderbury' => 'ഫിനിക്‌സ് ദ്വീപ് സമയം (കാന്റൺ ദ്വീപ്)',
        'Pacific/Kanton' => 'ഫിനിക്‌സ് ദ്വീപ് സമയം (കാന്റൺ ദ്വീപ്)',
        'Pacific/Fakaofo' => 'ടോക്കെലൂ സമയം (ഫക്കാവോഫോ)',
        'Pacific/Fiji' => 'ഫിജി സമയം',
        'Pacific/Funafuti' => 'ടുവാലു സമയം (ഫുണാഫുട്ടി)',
        'Pacific/Galapagos' => 'ഗാലപ്പഗോസ് സമയം (ഗാലപ്പാഗോസ്)',
        'Pacific/Gambier' => 'ഗാമ്പിയർ സമയം',
        'Pacific/Guadalcanal' => 'സോളമൻ ദ്വീപുകൾ സമയം (ഗ്വാഡൽകനാൽ)',
        'Pacific/Guam' => 'ചമോറോ സ്റ്റാൻഡേർഡ് സമയം (ഗ്വാം)',
        'Pacific/Honolulu' => 'ഹവായ്-അലൂഷ്യൻ സ്റ്റാൻഡേർഡ് സമയം (ഹോണലൂലു)',
        'Pacific/Kiritimati' => 'ലൈൻ ദ്വീപുകൾ സമയം (കിരിറ്റിമാറ്റി)',
        'Pacific/Kosrae' => 'കൊസ്ര സമയം (കൊസ്രേ)',
        'Pacific/Kwajalein' => 'മാർഷൽ ദ്വീപുകൾ സമയം (ക്വാജലെയ്ൻ)',
        'Pacific/Majuro' => 'മാർഷൽ ദ്വീപുകൾ സമയം (മജൂറോ)',
        'Pacific/Marquesas' => 'മർക്കസസ് സമയം (മാർക്യുസാസ്)',
        'Pacific/Midway' => 'സമോവ സമയം (മിഡ്‌വേ)',
        'Pacific/Nauru' => 'നൗറു സമയം',
        'Pacific/Niue' => 'ന്യൂയി സമയം (നിയു)',
        'Pacific/Norfolk' => 'നോർ‌ഫോക്ക് ദ്വീപ് സമയം',
        'Pacific/Noumea' => 'ന്യൂ കാലിഡോണിയ സമയം (നോമിയ)',
        'Pacific/Pago_Pago' => 'സമോവ സമയം (പാഗോ പാഗോ)',
        'Pacific/Palau' => 'പലാവു സമയം',
        'Pacific/Pitcairn' => 'പിറ്റ്കേൻ സമയം (പിറ്റ്കയിൻ‌)',
        'Pacific/Ponape' => 'പൊനാപ്പ് സമയം (പോൺപെ)',
        'Pacific/Pohnpei' => 'പൊനാപ്പ് സമയം (പോൺപെ)',
        'Pacific/Port_Moresby' => 'പാപ്പുവ ന്യൂ ഗിനിയ സമയം (പോർട്ട് മോഴ്‌സ്ബൈ)',
        'Pacific/Rarotonga' => 'കുക്ക് ദ്വീപുകൾ സമയം (റാരോടോംഗ)',
        'Pacific/Saipan' => 'ചമോറോ സ്റ്റാൻഡേർഡ് സമയം (സെയ്‌പ്പാൻ‌)',
        'Pacific/Tahiti' => 'താഹിതി സമയം',
        'Pacific/Tarawa' => 'ഗിൽബേർട്ട് ദ്വീപുകൾ സമയം (തരാവ)',
        'Pacific/Tongatapu' => 'ടോംഗ സമയം (ടോംഗാടാപു)',
        'Pacific/Truk' => 'ചൂക്ക് സമയം (ചക്)',
        'Pacific/Chuuk' => 'ചൂക്ക് സമയം (ചക്)',
        'Pacific/Wake' => 'വേക്ക് ദ്വീപ് സമയം (വെയ്ക്)',
        'Pacific/Wallis' => 'വാലിസ് ആന്റ് ഫ്യൂച്യുന സമയം (വാല്ലിസ്)',
    ],
    'Meta' => [
        'GmtFormat' => 'ജിഎംടി%s',
    ],
];
