<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'グリニッジ標準時（アビジャン）',
        'Africa/Accra' => 'グリニッジ標準時（アクラ）',
        'Africa/Addis_Ababa' => '東アフリカ時間（アジスアベバ）',
        'Africa/Algiers' => '中央ヨーロッパ時間（アルジェ）',
        'Africa/Asmera' => '東アフリカ時間（アスマラ）',
        'Africa/Asmara' => '東アフリカ時間（アスマラ）',
        'Africa/Bamako' => 'グリニッジ標準時（バマコ）',
        'Africa/Bangui' => '西アフリカ時間（バンギ）',
        'Africa/Banjul' => 'グリニッジ標準時（バンジュール）',
        'Africa/Bissau' => 'グリニッジ標準時（ビサウ）',
        'Africa/Blantyre' => '中央アフリカ時間（ブランタイヤ）',
        'Africa/Brazzaville' => '西アフリカ時間（ブラザビル）',
        'Africa/Bujumbura' => '中央アフリカ時間（ブジュンブラ）',
        'Africa/Cairo' => '東ヨーロッパ時間（カイロ）',
        'Africa/Casablanca' => '西ヨーロッパ時間（カサブランカ）',
        'Africa/Ceuta' => '中央ヨーロッパ時間（セウタ）',
        'Africa/Conakry' => 'グリニッジ標準時（コナクリ）',
        'Africa/Dakar' => 'グリニッジ標準時（ダカール）',
        'Africa/Dar_es_Salaam' => '東アフリカ時間（ダルエスサラーム）',
        'Africa/Djibouti' => '東アフリカ時間（ジブチ）',
        'Africa/Douala' => '西アフリカ時間（ドゥアラ）',
        'Africa/El_Aaiun' => '西ヨーロッパ時間（アイウン）',
        'Africa/Freetown' => 'グリニッジ標準時（フリータウン）',
        'Africa/Gaborone' => '中央アフリカ時間（ハボローネ）',
        'Africa/Harare' => '中央アフリカ時間（ハラレ）',
        'Africa/Johannesburg' => '南アフリカ標準時（ヨハネスブルグ）',
        'Africa/Juba' => '中央アフリカ時間（ジュバ）',
        'Africa/Kampala' => '東アフリカ時間（カンパラ）',
        'Africa/Khartoum' => '中央アフリカ時間（ハルツーム）',
        'Africa/Kigali' => '中央アフリカ時間（キガリ）',
        'Africa/Kinshasa' => '西アフリカ時間（キンシャサ）',
        'Africa/Lagos' => '西アフリカ時間（ラゴス）',
        'Africa/Libreville' => '西アフリカ時間（リーブルヴィル）',
        'Africa/Lome' => 'グリニッジ標準時（ロメ）',
        'Africa/Luanda' => '西アフリカ時間（ルアンダ）',
        'Africa/Lubumbashi' => '中央アフリカ時間（ルブンバシ）',
        'Africa/Lusaka' => '中央アフリカ時間（ルサカ）',
        'Africa/Malabo' => '西アフリカ時間（マラボ）',
        'Africa/Maputo' => '中央アフリカ時間（マプト）',
        'Africa/Maseru' => '南アフリカ標準時（マセル）',
        'Africa/Mbabane' => '南アフリカ標準時（ムババーネ）',
        'Africa/Mogadishu' => '東アフリカ時間（モガディシオ）',
        'Africa/Monrovia' => 'グリニッジ標準時（モンロビア）',
        'Africa/Nairobi' => '東アフリカ時間（ナイロビ）',
        'Africa/Ndjamena' => '西アフリカ時間（ンジャメナ）',
        'Africa/Niamey' => '西アフリカ時間（ニアメ）',
        'Africa/Nouakchott' => 'グリニッジ標準時（ヌアクショット）',
        'Africa/Ouagadougou' => 'グリニッジ標準時（ワガドゥグー）',
        'Africa/Porto-Novo' => '西アフリカ時間（ポルトノボ）',
        'Africa/Sao_Tome' => 'グリニッジ標準時（サントメ）',
        'Africa/Tripoli' => '東ヨーロッパ時間（トリポリ）',
        'Africa/Tunis' => '中央ヨーロッパ時間（チュニス）',
        'Africa/Windhoek' => '中央アフリカ時間（ウィントフック）',
        'America/Adak' => 'ハワイ・アリューシャン時間（アダック）',
        'America/Anchorage' => 'アラスカ時間（アンカレッジ）',
        'America/Anguilla' => '大西洋時間（アンギラ）',
        'America/Antigua' => '大西洋時間（アンティグア）',
        'America/Araguaina' => 'ブラジリア時間（アラグァイナ）',
        'America/Argentina/La_Rioja' => 'アルゼンチン時間（ラリオハ）',
        'America/Argentina/Rio_Gallegos' => 'アルゼンチン時間（リオガジェゴス）',
        'America/Argentina/Salta' => 'アルゼンチン時間（サルタ）',
        'America/Argentina/San_Juan' => 'アルゼンチン時間（サンファン）',
        'America/Argentina/San_Luis' => 'アルゼンチン時間（サンルイス）',
        'America/Argentina/Tucuman' => 'アルゼンチン時間（トゥクマン）',
        'America/Argentina/Ushuaia' => 'アルゼンチン時間（ウシュアイア）',
        'America/Aruba' => '大西洋時間（アルバ）',
        'America/Asuncion' => 'パラグアイ時間（アスンシオン）',
        'America/Bahia' => 'ブラジリア時間（バイーア）',
        'America/Bahia_Banderas' => '米国中部時間（バイアバンデラ）',
        'America/Barbados' => '大西洋時間（バルバドス）',
        'America/Belem' => 'ブラジリア時間（ベレン）',
        'America/Belize' => '米国中部時間（ベリーズ）',
        'America/Blanc-Sablon' => '大西洋時間（ブラン・サブロン）',
        'America/Boa_Vista' => 'アマゾン時間（ボアビスタ）',
        'America/Bogota' => 'コロンビア時間（ボゴタ）',
        'America/Boise' => '米国山岳部時間（ボイシ）',
        'America/Buenos_Aires' => 'アルゼンチン時間（ブエノスアイレス）',
        'America/Argentina/Buenos_Aires' => 'アルゼンチン時間（ブエノスアイレス）',
        'America/Cambridge_Bay' => '米国山岳部時間（ケンブリッジベイ）',
        'America/Campo_Grande' => 'アマゾン時間（カンポグランデ）',
        'America/Cancun' => '米国東部時間（カンクン）',
        'America/Caracas' => 'ベネズエラ時間（カラカス）',
        'America/Catamarca' => 'アルゼンチン時間（カタマルカ）',
        'America/Argentina/Catamarca' => 'アルゼンチン時間（カタマルカ）',
        'America/Cayenne' => '仏領ギアナ時間（カイエンヌ）',
        'America/Cayman' => '米国東部時間（ケイマン）',
        'America/Chicago' => '米国中部時間（シカゴ）',
        'America/Chihuahua' => '米国中部時間（チワワ）',
        'America/Ciudad_Juarez' => '米国山岳部時間（シウダー・フアレス）',
        'America/Coral_Harbour' => '米国東部時間（アティコカン）',
        'America/Atikokan' => '米国東部時間（アティコカン）',
        'America/Cordoba' => 'アルゼンチン時間（コルドバ）',
        'America/Argentina/Cordoba' => 'アルゼンチン時間（コルドバ）',
        'America/Costa_Rica' => '米国中部時間（コスタリカ）',
        'America/Coyhaique' => 'チリ時間（コジャイケ）',
        'America/Creston' => '米国山岳部時間（クレストン）',
        'America/Cuiaba' => 'アマゾン時間（クイアバ）',
        'America/Curacao' => '大西洋時間（キュラソー）',
        'America/Danmarkshavn' => 'グリニッジ標準時（デンマークシャウン）',
        'America/Dawson' => 'ユーコン時間（ドーソン）',
        'America/Dawson_Creek' => '米国山岳部時間（ドーソンクリーク）',
        'America/Denver' => '米国山岳部時間（デンバー）',
        'America/Detroit' => '米国東部時間（デトロイト）',
        'America/Dominica' => '大西洋時間（ドミニカ）',
        'America/Edmonton' => '米国山岳部時間（エドモントン）',
        'America/Eirunepe' => 'アクレ時間（エイルネペ）',
        'America/El_Salvador' => '米国中部時間（エルサルバドル）',
        'America/Fort_Nelson' => '米国山岳部時間（フォートネルソン）',
        'America/Fortaleza' => 'ブラジリア時間（フォルタレザ）',
        'America/Glace_Bay' => '大西洋時間（グレースベイ）',
        'America/Godthab' => 'グリーンランド時間（ヌーク）',
        'America/Nuuk' => 'グリーンランド時間（ヌーク）',
        'America/Goose_Bay' => '大西洋時間（グースベイ）',
        'America/Grand_Turk' => '米国東部時間（グランドターク）',
        'America/Grenada' => '大西洋時間（グレナダ）',
        'America/Guadeloupe' => '大西洋時間（グアドループ）',
        'America/Guatemala' => '米国中部時間（グアテマラ）',
        'America/Guayaquil' => 'エクアドル時間（グアヤキル）',
        'America/Guyana' => 'ガイアナ時間',
        'America/Halifax' => '大西洋時間（ハリファクス）',
        'America/Havana' => 'キューバ時間（ハバナ）',
        'America/Hermosillo' => 'メキシコ太平洋時間（エルモシヨ）',
        'America/Indiana/Knox' => '米国中部時間（インディアナ州ノックス）',
        'America/Indiana/Marengo' => '米国東部時間（インディアナ州マレンゴ）',
        'America/Indiana/Petersburg' => '米国東部時間（インディアナ州ピーターズバーグ）',
        'America/Indiana/Tell_City' => '米国中部時間（インディアナ州テルシティ）',
        'America/Indiana/Vevay' => '米国東部時間（インディアナ州ビベー）',
        'America/Indiana/Vincennes' => '米国東部時間（インディアナ州ビンセンス）',
        'America/Indiana/Winamac' => '米国東部時間（インディアナ州ウィナマック）',
        'America/Indianapolis' => '米国東部時間（インディアナポリス）',
        'America/Indiana/Indianapolis' => '米国東部時間（インディアナポリス）',
        'America/Inuvik' => '米国山岳部時間（イヌヴィク）',
        'America/Iqaluit' => '米国東部時間（イカルイット）',
        'America/Jamaica' => '米国東部時間（ジャマイカ）',
        'America/Jujuy' => 'アルゼンチン時間（フフイ）',
        'America/Argentina/Jujuy' => 'アルゼンチン時間（フフイ）',
        'America/Juneau' => 'アラスカ時間（ジュノー）',
        'America/Kentucky/Monticello' => '米国東部時間（ケンタッキー州モンティチェロ）',
        'America/Kralendijk' => '大西洋時間（クラレンダイク）',
        'America/La_Paz' => 'ボリビア時間（ラパス）',
        'America/Lima' => 'ペルー時間（リマ）',
        'America/Los_Angeles' => '米国太平洋時間（ロサンゼルス）',
        'America/Louisville' => '米国東部時間（ルイビル）',
        'America/Kentucky/Louisville' => '米国東部時間（ルイビル）',
        'America/Lower_Princes' => '大西洋時間（ローワー・プリンセズ・クウォーター）',
        'America/Maceio' => 'ブラジリア時間（マセイオ）',
        'America/Managua' => '米国中部時間（マナグア）',
        'America/Manaus' => 'アマゾン時間（マナウス）',
        'America/Marigot' => '大西洋時間（マリゴ）',
        'America/Martinique' => '大西洋時間（マルティニーク）',
        'America/Matamoros' => '米国中部時間（マタモロス）',
        'America/Mazatlan' => 'メキシコ太平洋時間（マサトラン）',
        'America/Mendoza' => 'アルゼンチン時間（メンドーサ）',
        'America/Argentina/Mendoza' => 'アルゼンチン時間（メンドーサ）',
        'America/Menominee' => '米国中部時間（メノミニー）',
        'America/Merida' => '米国中部時間（メリダ）',
        'America/Metlakatla' => 'アラスカ時間（メトラカトラ）',
        'America/Mexico_City' => '米国中部時間（メキシコシティー）',
        'America/Miquelon' => 'サンピエール島・ミクロン島時間',
        'America/Moncton' => '大西洋時間（モンクトン）',
        'America/Monterrey' => '米国中部時間（モンテレイ）',
        'America/Montevideo' => 'ウルグアイ時間（モンテビデオ）',
        'America/Montserrat' => '大西洋時間（モントセラト）',
        'America/Nassau' => '米国東部時間（ナッソー）',
        'America/New_York' => '米国東部時間（ニューヨーク）',
        'America/Nome' => 'アラスカ時間（ノーム）',
        'America/Noronha' => 'フェルナンド・デ・ノローニャ時間',
        'America/North_Dakota/Beulah' => '米国中部時間（ノースダコタ州ビューラー）',
        'America/North_Dakota/Center' => '米国中部時間（ノースダコタ州センター）',
        'America/North_Dakota/New_Salem' => '米国中部時間（ノースダコタ州ニューセーラム）',
        'America/Ojinaga' => '米国中部時間（オヒナガ）',
        'America/Panama' => '米国東部時間（パナマ）',
        'America/Paramaribo' => 'スリナム時間（パラマリボ）',
        'America/Phoenix' => '米国山岳部時間（フェニックス）',
        'America/Port-au-Prince' => '米国東部時間（ポルトープランス）',
        'America/Port_of_Spain' => '大西洋時間（ポートオブスペイン）',
        'America/Porto_Velho' => 'アマゾン時間（ポルトベーリョ）',
        'America/Puerto_Rico' => '大西洋時間（プエルトリコ）',
        'America/Punta_Arenas' => 'チリ時間（プンタアレナス）',
        'America/Rankin_Inlet' => '米国中部時間（ランキンインレット）',
        'America/Recife' => 'ブラジリア時間（レシフェ）',
        'America/Regina' => '米国中部時間（レジャイナ）',
        'America/Resolute' => '米国中部時間（レゾリュート）',
        'America/Rio_Branco' => 'アクレ時間（リオブランコ）',
        'America/Santarem' => 'ブラジリア時間（サンタレム）',
        'America/Santiago' => 'チリ時間（サンチアゴ）',
        'America/Santo_Domingo' => '大西洋時間（サントドミンゴ）',
        'America/Sao_Paulo' => 'ブラジリア時間（サンパウロ）',
        'America/Scoresbysund' => 'グリーンランド時間（イトコルトルミット）',
        'America/Sitka' => 'アラスカ時間（シトカ）',
        'America/St_Barthelemy' => '大西洋時間（サン・バルテルミー）',
        'America/St_Johns' => 'ニューファンドランド時間（セントジョンズ）',
        'America/St_Kitts' => '大西洋時間（セントクリストファー）',
        'America/St_Lucia' => '大西洋時間（セントルシア）',
        'America/St_Thomas' => '大西洋時間（セントトーマス）',
        'America/St_Vincent' => '大西洋時間（セントビンセント）',
        'America/Swift_Current' => '米国中部時間（スウィフトカレント）',
        'America/Tegucigalpa' => '米国中部時間（テグシガルパ）',
        'America/Thule' => '大西洋時間（チューレ）',
        'America/Tijuana' => '米国太平洋時間（ティフアナ）',
        'America/Toronto' => '米国東部時間（トロント）',
        'America/Tortola' => '大西洋時間（トルトーラ）',
        'America/Vancouver' => '米国太平洋時間（バンクーバー）',
        'America/Whitehorse' => 'ユーコン時間（ホワイトホース）',
        'America/Winnipeg' => '米国中部時間（ウィニペグ）',
        'America/Yakutat' => 'アラスカ時間（ヤクタット）',
        'Antarctica/Casey' => 'オーストラリア西部時間（ケーシー基地）',
        'Antarctica/Davis' => 'デービス基地時間',
        'Antarctica/DumontDUrville' => 'デュモン・デュルヴィル基地時間',
        'Antarctica/Macquarie' => 'オーストラリア東部時間（マッコリー）',
        'Antarctica/Mawson' => 'モーソン基地時間',
        'Antarctica/McMurdo' => 'ニュージーランド時間（マクマード基地）',
        'Antarctica/Palmer' => 'チリ時間（パーマー基地）',
        'Antarctica/Rothera' => 'ロゼラ基地時間',
        'Antarctica/Syowa' => '昭和基地時間',
        'Antarctica/Troll' => 'グリニッジ標準時（トロル基地）',
        'Antarctica/Vostok' => 'ボストーク基地時間',
        'Arctic/Longyearbyen' => '中央ヨーロッパ時間（ロングイェールビーン）',
        'Asia/Aden' => 'アラビア時間（アデン）',
        'Asia/Almaty' => 'カザフスタン時間（アルマトイ）',
        'Asia/Amman' => '東ヨーロッパ時間（アンマン）',
        'Asia/Anadyr' => 'ペトロパブロフスク・カムチャツキー時間（アナディリ）',
        'Asia/Aqtau' => 'カザフスタン時間（アクタウ）',
        'Asia/Aqtobe' => 'カザフスタン時間（アクトベ）',
        'Asia/Ashgabat' => 'トルクメニスタン時間（アシガバード）',
        'Asia/Atyrau' => 'カザフスタン時間（アティラウ）',
        'Asia/Baghdad' => 'アラビア時間（バグダッド）',
        'Asia/Bahrain' => 'アラビア時間（バーレーン）',
        'Asia/Baku' => 'アゼルバイジャン時間（バクー）',
        'Asia/Bangkok' => 'インドシナ時間（バンコク）',
        'Asia/Barnaul' => 'クラスノヤルスク時間（バルナウル）',
        'Asia/Beirut' => '東ヨーロッパ時間（ベイルート）',
        'Asia/Bishkek' => 'キルギス時間（ビシュケク）',
        'Asia/Brunei' => 'ブルネイ時間',
        'Asia/Calcutta' => 'インド標準時（コルカタ）',
        'Asia/Kolkata' => 'インド標準時（コルカタ）',
        'Asia/Chita' => 'ヤクーツク時間（チタ）',
        'Asia/Colombo' => 'インド標準時（コロンボ）',
        'Asia/Damascus' => '東ヨーロッパ時間（ダマスカス）',
        'Asia/Dhaka' => 'バングラデシュ時間（ダッカ）',
        'Asia/Dili' => '東ティモール時間（ディリ）',
        'Asia/Dubai' => '湾岸標準時（ドバイ）',
        'Asia/Dushanbe' => 'タジキスタン時間（ドゥシャンベ）',
        'Asia/Famagusta' => '東ヨーロッパ時間（ファマグスタ）',
        'Asia/Gaza' => '東ヨーロッパ時間（ガザ）',
        'Asia/Hebron' => '東ヨーロッパ時間（ヘブロン）',
        'Asia/Hong_Kong' => '香港時間',
        'Asia/Hovd' => 'ホブド時間',
        'Asia/Irkutsk' => 'イルクーツク時間',
        'Asia/Jakarta' => 'インドネシア西部時間（ジャカルタ）',
        'Asia/Jayapura' => 'インドネシア東部時間（ジャヤプラ）',
        'Asia/Jerusalem' => 'イスラエル時間（エルサレム）',
        'Asia/Kabul' => 'アフガニスタン時間（カブール）',
        'Asia/Kamchatka' => 'ペトロパブロフスク・カムチャツキー時間（カムチャッカ）',
        'Asia/Karachi' => 'パキスタン時間（カラチ）',
        'Asia/Katmandu' => 'ネパール時間（カトマンズ）',
        'Asia/Kathmandu' => 'ネパール時間（カトマンズ）',
        'Asia/Khandyga' => 'ヤクーツク時間（ハンドゥイガ）',
        'Asia/Krasnoyarsk' => 'クラスノヤルスク時間',
        'Asia/Kuala_Lumpur' => 'マレーシア時間（クアラルンプール）',
        'Asia/Kuching' => 'マレーシア時間（クチン）',
        'Asia/Kuwait' => 'アラビア時間（クウェート）',
        'Asia/Macau' => '中国時間（マカオ）',
        'Asia/Magadan' => 'マガダン時間',
        'Asia/Makassar' => 'インドネシア中部時間（マカッサル）',
        'Asia/Manila' => 'フィリピン時間（マニラ）',
        'Asia/Muscat' => '湾岸標準時（マスカット）',
        'Asia/Nicosia' => '東ヨーロッパ時間（ニコシア）',
        'Asia/Novokuznetsk' => 'クラスノヤルスク時間（ノヴォクズネツク）',
        'Asia/Novosibirsk' => 'クラスノヤルスク時間（ノヴォシビルスク）',
        'Asia/Omsk' => 'オムスク時間',
        'Asia/Oral' => 'カザフスタン時間（オラル）',
        'Asia/Phnom_Penh' => 'インドシナ時間（プノンペン）',
        'Asia/Pontianak' => 'インドネシア西部時間（ポンティアナック）',
        'Asia/Pyongyang' => '韓国時間（平壌）',
        'Asia/Qatar' => 'アラビア時間（カタール）',
        'Asia/Qostanay' => 'カザフスタン時間（コスタナイ）',
        'Asia/Qyzylorda' => 'カザフスタン時間（クズロルダ）',
        'Asia/Rangoon' => 'ミャンマー時間（ヤンゴン）',
        'Asia/Yangon' => 'ミャンマー時間（ヤンゴン）',
        'Asia/Riyadh' => 'アラビア時間（リヤド）',
        'Asia/Saigon' => 'インドシナ時間（ホーチミン）',
        'Asia/Ho_Chi_Minh' => 'インドシナ時間（ホーチミン）',
        'Asia/Sakhalin' => 'マガダン時間（サハリン）',
        'Asia/Samarkand' => 'ウズベキスタン時間（サマルカンド）',
        'Asia/Seoul' => '韓国時間（ソウル）',
        'Asia/Shanghai' => '中国時間（上海）',
        'Asia/Singapore' => 'シンガポール標準時',
        'Asia/Srednekolymsk' => 'マガダン時間（スレドネコリムスク）',
        'Asia/Taipei' => '台湾時間（台北）',
        'Asia/Tashkent' => 'ウズベキスタン時間（タシケント）',
        'Asia/Tbilisi' => 'ジョージア時間（トビリシ）',
        'Asia/Tehran' => 'イラン時間（テヘラン）',
        'Asia/Thimphu' => 'ブータン時間（ティンプー）',
        'Asia/Tokyo' => '日本時間（東京）',
        'Asia/Tomsk' => 'クラスノヤルスク時間（トムスク）',
        'Asia/Ulaanbaatar' => 'ウランバートル時間',
        'Asia/Urumqi' => '中国時間（ウルムチ）',
        'Asia/Ust-Nera' => 'ウラジオストク時間（ウスチネラ）',
        'Asia/Vientiane' => 'インドシナ時間（ビエンチャン）',
        'Asia/Vladivostok' => 'ウラジオストク時間',
        'Asia/Yakutsk' => 'ヤクーツク時間',
        'Asia/Yekaterinburg' => 'エカテリンブルグ時間',
        'Asia/Yerevan' => 'アルメニア時間（エレバン）',
        'Atlantic/Azores' => 'アゾレス時間',
        'Atlantic/Bermuda' => '大西洋時間（バミューダ）',
        'Atlantic/Canary' => '西ヨーロッパ時間（カナリア）',
        'Atlantic/Cape_Verde' => 'カーボベルデ時間',
        'Atlantic/Faeroe' => '西ヨーロッパ時間（フェロー）',
        'Atlantic/Faroe' => '西ヨーロッパ時間（フェロー）',
        'Atlantic/Madeira' => '西ヨーロッパ時間（マデイラ）',
        'Atlantic/Reykjavik' => 'グリニッジ標準時（レイキャビク）',
        'Atlantic/South_Georgia' => 'サウスジョージア時間',
        'Atlantic/St_Helena' => 'グリニッジ標準時（セントヘレナ）',
        'Atlantic/Stanley' => 'フォークランド諸島時間（スタンレー）',
        'Australia/Adelaide' => 'オーストラリア中部時間（アデレード）',
        'Australia/Brisbane' => 'オーストラリア東部時間（ブリスベン）',
        'Australia/Broken_Hill' => 'オーストラリア中部時間（ブロークンヒル）',
        'Australia/Darwin' => 'オーストラリア中部時間（ダーウィン）',
        'Australia/Eucla' => 'オーストラリア中西部時間（ユークラ）',
        'Australia/Hobart' => 'オーストラリア東部時間（ホバート）',
        'Australia/Lindeman' => 'オーストラリア東部時間（リンデマン）',
        'Australia/Lord_Howe' => 'ロードハウ時間',
        'Australia/Melbourne' => 'オーストラリア東部時間（メルボルン）',
        'Australia/Perth' => 'オーストラリア西部時間（パース）',
        'Australia/Sydney' => 'オーストラリア東部時間（シドニー）',
        'Etc/GMT' => 'グリニッジ標準時',
        'Etc/UTC' => '協定世界時',
        'Europe/Amsterdam' => '中央ヨーロッパ時間（アムステルダム）',
        'Europe/Andorra' => '中央ヨーロッパ時間（アンドラ）',
        'Europe/Astrakhan' => 'サマラ時間（アストラハン）',
        'Europe/Athens' => '東ヨーロッパ時間（アテネ）',
        'Europe/Belgrade' => '中央ヨーロッパ時間（ベオグラード）',
        'Europe/Berlin' => '中央ヨーロッパ時間（ベルリン）',
        'Europe/Bratislava' => '中央ヨーロッパ時間（ブラチスラバ）',
        'Europe/Brussels' => '中央ヨーロッパ時間（ブリュッセル）',
        'Europe/Bucharest' => '東ヨーロッパ時間（ブカレスト）',
        'Europe/Budapest' => '中央ヨーロッパ時間（ブダペスト）',
        'Europe/Busingen' => '中央ヨーロッパ時間（ビュージンゲン）',
        'Europe/Chisinau' => '東ヨーロッパ時間（キシナウ）',
        'Europe/Copenhagen' => '中央ヨーロッパ時間（コペンハーゲン）',
        'Europe/Dublin' => 'グリニッジ標準時（ダブリン）',
        'Europe/Gibraltar' => '中央ヨーロッパ時間（ジブラルタル）',
        'Europe/Guernsey' => 'グリニッジ標準時（ガーンジー）',
        'Europe/Helsinki' => '東ヨーロッパ時間（ヘルシンキ）',
        'Europe/Isle_of_Man' => 'グリニッジ標準時（マン島）',
        'Europe/Istanbul' => 'トルコ時間（イスタンブール）',
        'Europe/Jersey' => 'グリニッジ標準時（ジャージー）',
        'Europe/Kaliningrad' => '東ヨーロッパ時間（カリーニングラード）',
        'Europe/Kiev' => '東ヨーロッパ時間（キーウ）',
        'Europe/Kyiv' => '東ヨーロッパ時間（キーウ）',
        'Europe/Kirov' => 'モスクワ時間（キーロフ）',
        'Europe/Lisbon' => '西ヨーロッパ時間（リスボン）',
        'Europe/Ljubljana' => '中央ヨーロッパ時間（リュブリャナ）',
        'Europe/London' => 'グリニッジ標準時（ロンドン）',
        'Europe/Luxembourg' => '中央ヨーロッパ時間（ルクセンブルク）',
        'Europe/Madrid' => '中央ヨーロッパ時間（マドリード）',
        'Europe/Malta' => '中央ヨーロッパ時間（マルタ）',
        'Europe/Mariehamn' => '東ヨーロッパ時間（マリエハムン）',
        'Europe/Minsk' => 'モスクワ時間（ミンスク）',
        'Europe/Monaco' => '中央ヨーロッパ時間（モナコ）',
        'Europe/Moscow' => 'モスクワ時間',
        'Europe/Oslo' => '中央ヨーロッパ時間（オスロ）',
        'Europe/Paris' => '中央ヨーロッパ時間（パリ）',
        'Europe/Podgorica' => '中央ヨーロッパ時間（ポドゴリツァ）',
        'Europe/Prague' => '中央ヨーロッパ時間（プラハ）',
        'Europe/Riga' => '東ヨーロッパ時間（リガ）',
        'Europe/Rome' => '中央ヨーロッパ時間（ローマ）',
        'Europe/Samara' => 'サマラ時間',
        'Europe/San_Marino' => '中央ヨーロッパ時間（サンマリノ）',
        'Europe/Sarajevo' => '中央ヨーロッパ時間（サラエボ）',
        'Europe/Saratov' => 'サマラ時間（サラトフ）',
        'Europe/Simferopol' => 'モスクワ時間（シンフェロポリ）',
        'Europe/Skopje' => '中央ヨーロッパ時間（スコピエ）',
        'Europe/Sofia' => '東ヨーロッパ時間（ソフィア）',
        'Europe/Stockholm' => '中央ヨーロッパ時間（ストックホルム）',
        'Europe/Tallinn' => '東ヨーロッパ時間（タリン）',
        'Europe/Tirane' => '中央ヨーロッパ時間（ティラナ）',
        'Europe/Ulyanovsk' => 'サマラ時間（ウリヤノフスク）',
        'Europe/Vaduz' => '中央ヨーロッパ時間（ファドゥーツ）',
        'Europe/Vatican' => '中央ヨーロッパ時間（バチカン）',
        'Europe/Vienna' => '中央ヨーロッパ時間（ウィーン）',
        'Europe/Vilnius' => '東ヨーロッパ時間（ヴィリニュス）',
        'Europe/Volgograd' => 'モスクワ時間（ボルゴグラード）',
        'Europe/Warsaw' => '中央ヨーロッパ時間（ワルシャワ）',
        'Europe/Zagreb' => '中央ヨーロッパ時間（ザグレブ）',
        'Europe/Zurich' => '中央ヨーロッパ時間（チューリッヒ）',
        'Indian/Antananarivo' => '東アフリカ時間（アンタナナリボ）',
        'Indian/Chagos' => 'インド洋時間（チャゴス）',
        'Indian/Christmas' => 'クリスマス島時間',
        'Indian/Cocos' => 'ココス諸島時間',
        'Indian/Comoro' => '東アフリカ時間（コモロ）',
        'Indian/Kerguelen' => '仏領南方南極時間（ケルゲレン諸島）',
        'Indian/Mahe' => 'セーシェル時間（マヘ）',
        'Indian/Maldives' => 'モルディブ時間',
        'Indian/Mauritius' => 'モーリシャス時間',
        'Indian/Mayotte' => '東アフリカ時間（マヨット）',
        'Indian/Reunion' => 'レユニオン時間',
        'Pacific/Apia' => 'サモア時間（アピア）',
        'Pacific/Auckland' => 'ニュージーランド時間（オークランド）',
        'Pacific/Bougainville' => 'パプアニューギニア時間（ブーゲンビル）',
        'Pacific/Chatham' => 'チャタム時間',
        'Pacific/Easter' => 'イースター島時間',
        'Pacific/Efate' => 'バヌアツ時間（エフェテ島）',
        'Pacific/Enderbury' => 'フェニックス諸島時間（カントン島）',
        'Pacific/Kanton' => 'フェニックス諸島時間（カントン島）',
        'Pacific/Fakaofo' => 'トケラウ時間（ファカオフォ）',
        'Pacific/Fiji' => 'フィジー時間',
        'Pacific/Funafuti' => 'ツバル時間（フナフティ）',
        'Pacific/Galapagos' => 'ガラパゴス時間',
        'Pacific/Gambier' => 'ガンビエ諸島時間',
        'Pacific/Guadalcanal' => 'ソロモン諸島時間（ガダルカナル）',
        'Pacific/Guam' => 'チャモロ時間（グアム）',
        'Pacific/Honolulu' => 'ハワイ・アリューシャン標準時（ホノルル）',
        'Pacific/Kiritimati' => 'ライン諸島時間（キリスィマスィ島）',
        'Pacific/Kosrae' => 'コスラエ時間',
        'Pacific/Kwajalein' => 'マーシャル諸島時間（クェゼリン）',
        'Pacific/Majuro' => 'マーシャル諸島時間（マジュロ）',
        'Pacific/Marquesas' => 'マルキーズ時間',
        'Pacific/Midway' => '米領サモア時間（ミッドウェー島）',
        'Pacific/Nauru' => 'ナウル時間',
        'Pacific/Niue' => 'ニウエ時間',
        'Pacific/Norfolk' => 'ノーフォーク島時間',
        'Pacific/Noumea' => 'ニューカレドニア時間（ヌメア）',
        'Pacific/Pago_Pago' => '米領サモア時間（パゴパゴ）',
        'Pacific/Palau' => 'パラオ時間',
        'Pacific/Pitcairn' => 'ピトケアン時間（ピトケアン諸島）',
        'Pacific/Ponape' => 'ポンペイ時間（ポンペイ島）',
        'Pacific/Pohnpei' => 'ポンペイ時間（ポンペイ島）',
        'Pacific/Port_Moresby' => 'パプアニューギニア時間（ポートモレスビー）',
        'Pacific/Rarotonga' => 'クック諸島時間（ラロトンガ）',
        'Pacific/Saipan' => 'チャモロ時間（サイパン）',
        'Pacific/Tahiti' => 'タヒチ時間',
        'Pacific/Tarawa' => 'ギルバート諸島時間（タラワ）',
        'Pacific/Tongatapu' => 'トンガ時間（トンガタプ）',
        'Pacific/Truk' => 'チューク時間',
        'Pacific/Chuuk' => 'チューク時間',
        'Pacific/Wake' => 'ウェーク島時間',
        'Pacific/Wallis' => 'ウォリス・フツナ時間（ウォリス諸島）',
    ],
    'Meta' => [],
];
