<?php

return [
    '🧑‍🦰' => 'ᱦᱚᱲ ᱜᱮ: ᱟᱨᱟᱜ ᱩᱵ',
    '🧑‍🦳' => 'ᱦᱚᱲ ᱜᱮ: ᱯᱩᱸᱱᱰ ᱩᱵ',
    '👨‍🦰' => 'ᱦᱚᱲ: ᱟᱨᱟᱜ ᱩᱵ',
    '👨‍🦳' => 'ᱦᱚᱲ: ᱯᱩᱸᱱᱰ ᱩᱵ',
    '👩‍🦰' => 'ᱢᱟᱹᱭᱡᱩ: ᱟᱨᱟᱜ ᱩᱵ',
    '👩‍🦳' => 'ᱢᱟᱹᱭᱡᱩ: ᱯᱩᱸᱱᱰ ᱩᱵ',
    '😶‍🌫' => 'ᱢᱚᱲᱟ ᱨᱮ ᱨᱤᱢᱤᱞ',
    '😮‍💨' => 'ᱦᱟᱣᱟ ᱚᱰᱚᱠ ᱢᱚᱲᱟ',
    '😵‍💫' => 'ᱜᱷᱩᱨᱟᱹᱣ ᱢᱮᱫ ᱢᱚᱲᱟ',
    '👁‍🗨' => 'ᱨᱮᱲ ᱢᱮᱫ ᱨᱤᱢᱤᱞ',
    '🧔‍♂' => 'ᱦᱚᱲᱟᱜ ᱰᱟᱹᱰᱦᱤ',
    '🧔‍♀' => 'ᱢᱟᱹᱭᱡᱩ ᱫᱟᱹᱰᱦᱤ',
    '🧏‍♂' => 'ᱠᱟᱞᱟ ᱦᱚᱲ',
    '🐕‍🦺' => 'ᱠᱟᱹᱢᱤ ᱥᱮᱛᱟ',
    '🐈‍⬛' => 'ᱦᱮᱱᱫᱮ ᱯᱩᱥᱤ',
    '🐦‍⬛' => 'ᱦᱮᱱᱫᱮ ᱪᱮᱬᱮ',
    '🇦🇨' => 'ᱪᱤᱨ: ᱟᱥᱮᱱᱥᱤᱭᱟᱹᱱ ᱟᱭᱞᱮᱸᱰ',
    '🇦🇩' => 'ᱪᱤᱨ: ᱟᱱᱰᱚᱨᱟ',
    '🇦🇪' => 'ᱪᱤᱨ: ᱡᱩᱢᱤᱫ ᱟᱨᱟᱹᱵ ᱮᱢᱤᱨᱮᱴᱥ',
    '🇦🇫' => 'ᱪᱤᱨ: ᱟᱯᱷᱜᱟᱱᱤᱥᱛᱟᱱ',
    '🇦🇬' => 'ᱪᱤᱨ: ᱟᱱᱴᱤᱜᱩᱣᱟ ᱟᱨ ᱵᱟᱹᱨᱢᱩᱱᱰᱟ',
    '🇦🇮' => 'ᱪᱤᱨ: ᱟᱹᱱᱜᱩᱭᱞᱟ',
    '🇦🇱' => 'ᱪᱤᱨ: ᱟᱞᱵᱟᱱᱤᱭᱟ',
    '🇦🇲' => 'ᱪᱤᱨ: ᱟᱨᱢᱮᱱᱤᱭᱟ',
    '🇦🇴' => 'ᱪᱤᱨ: ᱟᱹᱱᱜᱚᱞᱟ',
    '🇦🇶' => 'ᱪᱤᱨ: ᱟᱱᱴᱟᱨᱠᱴᱤᱠᱟ',
    '🇦🇷' => 'ᱪᱤᱨ: ᱟᱨᱡᱮᱱᱴᱤᱱᱟ',
    '🇦🇸' => 'ᱪᱤᱨ: ᱟᱢᱮᱨᱤᱠᱟᱹᱱ ᱥᱟᱢᱚᱣᱟ',
    '🇦🇹' => 'ᱪᱤᱨ: ᱟᱥᱴᱨᱮᱞᱤᱭᱟ',
    '🇦🇺' => 'ᱪᱤᱨ: ᱚᱥᱴᱨᱮᱞᱤᱭᱟ',
    '🇦🇼' => 'ᱪᱤᱨ: ᱟᱹᱨᱩᱵᱟ',
    '🇦🇽' => 'ᱪᱤᱨ: ᱮᱞᱮᱸᱰ ᱫᱣᱤᱯᱫᱳᱞ',
    '🇦🇿' => 'ᱪᱤᱨ: ᱟᱹᱡᱟᱹᱨᱵᱮᱭᱡᱟᱱ',
    '🇧🇦' => 'ᱪᱤᱨ: ᱵᱚᱥᱱᱤᱭᱟ ᱟᱨ ᱦᱟᱹᱨᱡᱮᱜᱚᱣᱤᱭᱟ',
    '🇧🇧' => 'ᱪᱤᱨ: ᱵᱟᱨᱵᱟᱰᱚᱥ',
    '🇧🇩' => 'ᱪᱤᱨ: ᱵᱟᱝᱞᱟᱫᱮᱥ',
    '🇧🇪' => 'ᱪᱤᱨ: ᱵᱮᱞᱡᱤᱭᱟᱹᱢ',
    '🇧🇫' => 'ᱪᱤᱨ: ᱵᱩᱨᱠᱤᱱᱟ ᱯᱷᱟᱥᱚ',
    '🇧🇬' => 'ᱪᱤᱨ: ᱵᱩᱞᱜᱟᱨᱤᱭᱟ',
    '🇧🇭' => 'ᱪᱤᱨ: ᱵᱟᱦᱨᱮᱱ',
    '🇧🇮' => 'ᱪᱤᱨ: ᱵᱩᱨᱩᱱᱰᱤ',
    '🇧🇯' => 'ᱪᱤᱨ: ᱵᱮᱱᱤᱱ',
    '🇧🇱' => 'ᱪᱤᱨ: ᱮᱥ ᱴᱤ ᱵᱟᱨᱛᱷᱮᱞᱮᱢᱤ',
    '🇧🇲' => 'ᱪᱤᱨ: ᱵᱟᱹᱨᱢᱩᱱᱰᱟ',
    '🇧🇳' => 'ᱪᱤᱨ: ᱵᱽᱨᱩᱱᱮᱭ',
    '🇧🇴' => 'ᱪᱤᱨ: ᱵᱚᱞᱤᱣᱤᱭᱟ',
    '🇧🇶' => 'ᱪᱤᱨ: ᱠᱟᱹᱨᱮᱱᱤᱭᱟᱹᱱ ᱱᱮᱫᱚᱨᱞᱮᱸᱰ',
    '🇧🇷' => 'ᱪᱤᱨ: ᱵᱨᱟᱡᱤᱞ',
    '🇧🇸' => 'ᱪᱤᱨ: ᱵᱟᱦᱟᱢᱟᱥ',
    '🇧🇹' => 'ᱪᱤᱨ: ᱵᱷᱩᱴᱟᱱ',
    '🇧🇻' => 'ᱪᱤᱨ: ᱵᱚᱣᱮᱴ ᱟᱭᱞᱮᱸᱰ',
    '🇧🇼' => 'ᱪᱤᱨ: ᱵᱚᱴᱥᱣᱟᱱᱟ',
    '🇧🇾' => 'ᱪᱤᱨ: ᱵᱮᱞᱟᱨᱩᱥ',
    '🇧🇿' => 'ᱪᱤᱨ: ᱵᱮᱞᱤᱡᱽ',
    '🇨🇦' => 'ᱪᱤᱨ: ᱠᱟᱱᱟᱰᱟ',
    '🇨🇨' => 'ᱪᱤᱨ: ᱠᱚᱠᱚᱥ (ᱠᱤᱞᱤᱝ) ᱟᱭᱞᱮᱸᱰ',
    '🇨🇩' => 'ᱪᱤᱨ: ᱠᱚᱝᱜᱚ ᱼ ᱠᱤᱱᱥᱟᱥᱟ',
    '🇨🇫' => 'ᱪᱤᱨ: ᱛᱟᱞᱟ ᱟᱯᱷᱨᱤᱠᱟ ᱟᱹᱯᱱᱟᱹᱛ',
    '🇨🇬' => 'ᱪᱤᱨ: ᱠᱚᱝᱜᱚ ᱼ ᱵᱽᱨᱟᱡᱟᱣᱤᱞ',
    '🇨🇭' => 'ᱪᱤᱨ: ᱥᱮᱤᱡᱟᱹᱨᱞᱮᱸᱰ',
    '🇨🇮' => 'ᱪᱤᱨ: ᱠᱚᱛᱮ ᱫᱤᱣᱚᱭᱮᱨ',
    '🇨🇰' => 'ᱪᱤᱨ: ᱠᱩᱠ ᱟᱭᱞᱮᱸᱰ',
    '🇨🇱' => 'ᱪᱤᱨ: ᱪᱟᱭᱤᱞ',
    '🇨🇲' => 'ᱪᱤᱨ: ᱠᱟᱢᱮᱨᱩᱱ',
    '🇨🇳' => 'ᱪᱤᱨ: ᱪᱤᱱ',
    '🇨🇴' => 'ᱪᱤᱨ: ᱠᱚᱞᱚᱢᱵᱤᱭᱟ',
    '🇨🇵' => 'ᱪᱤᱨ: ᱠᱞᱤᱯᱮᱴᱨᱚᱱ ᱟᱭᱞᱮᱸᱰ',
    '🇨🇷' => 'ᱪᱤᱨ: ᱠᱚᱥᱴᱟ ᱨᱤᱠᱟ',
    '🇨🇺' => 'ᱪᱤᱨ: ᱠᱭᱩᱵᱟ',
    '🇨🇻' => 'ᱪᱤᱨ: ᱠᱮᱯ ᱣᱟᱹᱨᱰᱮ',
    '🇨🇼' => 'ᱪᱤᱨ: ᱠᱩᱨᱟᱠᱟᱣ',
    '🇨🇽' => 'ᱪᱤᱨ: ᱠᱨᱤᱥᱢᱟᱹᱥ ᱟᱭᱞᱮᱸᱰ',
    '🇨🇾' => 'ᱪᱤᱨ: ᱥᱟᱭᱯᱨᱟᱹᱥ',
    '🇨🇿' => 'ᱪᱤᱨ: ᱪᱮᱠᱤᱭᱟ',
    '🇩🇪' => 'ᱪᱤᱨ: ᱡᱟᱨᱢᱟᱱᱤ',
    '🇩🇬' => 'ᱪᱤᱨ: ᱰᱤᱭᱮᱜᱚ ᱜᱟᱨᱥᱤᱭᱟ',
    '🇩🇯' => 'ᱪᱤᱨ: ᱡᱤᱵᱩᱛᱤ',
    '🇩🇰' => 'ᱪᱤᱨ: ᱰᱮᱱᱢᱟᱨᱠ',
    '🇩🇲' => 'ᱪᱤᱨ: ᱰᱚᱢᱤᱱᱤᱠᱟ',
    '🇩🇴' => 'ᱪᱤᱨ: ᱰᱚᱢᱤᱱᱤᱠᱟᱱ ᱨᱤᱯᱚᱵᱞᱤᱠ',
    '🇩🇿' => 'ᱪᱤᱨ: ᱟᱞᱡᱮᱨᱤᱭᱟ',
    '🇪🇦' => 'ᱪᱤᱨ: ᱥᱮᱣᱴᱟ ᱟᱨ ᱢᱮᱞᱤᱞᱟ',
    '🇪🇨' => 'ᱪᱤᱨ: ᱤᱠᱣᱟᱰᱚᱨ',
    '🇪🇪' => 'ᱪᱤᱨ: ᱮᱥᱴᱚᱱᱤᱭᱟ',
    '🇪🇬' => 'ᱪᱤᱨ: ᱤᱡᱤᱯᱴ',
    '🇪🇭' => 'ᱪᱤᱨ: ᱯᱟᱪᱮ ᱥᱟᱦᱟᱨᱟ',
    '🇪🇷' => 'ᱪᱤᱨ: ᱤᱨᱤᱴᱨᱤᱭᱟ',
    '🇪🇸' => 'ᱪᱤᱨ: ᱥᱯᱮᱱ',
    '🇪🇹' => 'ᱪᱤᱨ: ᱤᱛᱷᱤᱭᱚᱯᱤᱭᱟ',
    '🇪🇺' => 'ᱪᱤᱨ: ᱭᱩᱨᱚᱯᱤᱭᱟᱹᱱ ᱡᱩᱢᱤᱫ',
    '🇫🇮' => 'ᱪᱤᱨ: ᱯᱷᱤᱱᱞᱮᱸᱰ',
    '🇫🇯' => 'ᱪᱤᱨ: ᱯᱷᱤᱡᱤ',
    '🇫🇰' => 'ᱪᱤᱨ: ᱯᱷᱟᱞᱠᱞᱮᱸᱰ ᱟᱭᱞᱮᱸᱰ',
    '🇫🇲' => 'ᱪᱤᱨ: ᱢᱟᱭᱠᱨᱚᱱᱮᱥᱤᱭᱟ',
    '🇫🇴' => 'ᱪᱤᱨ: ᱯᱷᱮᱨᱚ ᱫᱣᱤᱯᱫᱳᱞ',
    '🇫🇷' => 'ᱪᱤᱨ: ᱯᱷᱨᱟᱱᱥ',
    '🇬🇦' => 'ᱪᱤᱨ: ᱜᱟᱵᱚᱱ',
    '🇬🇧' => 'ᱪᱤᱨ: ᱭᱩᱱᱤᱭᱴᱮᱰ ᱠᱤᱝᱰᱚᱢ',
    '🇬🇩' => 'ᱪᱤᱨ: ᱜᱽᱨᱮᱱᱟᱰᱟ',
    '🇬🇪' => 'ᱪᱤᱨ: ᱡᱭᱚᱨᱡᱤᱭᱟ',
    '🇬🇫' => 'ᱪᱤᱨ: ᱯᱷᱨᱮᱧᱪ ᱜᱩᱭᱟᱱᱟ',
    '🇬🇬' => 'ᱪᱤᱨ: ᱜᱣᱮᱨᱱᱮᱥᱭ',
    '🇬🇭' => 'ᱪᱤᱨ: ᱜᱷᱟᱱᱟ',
    '🇬🇮' => 'ᱪᱤᱨ: ᱜᱤᱵᱽᱨᱟᱞᱴᱟᱹᱨ',
    '🇬🇱' => 'ᱪᱤᱨ: ᱜᱽᱨᱤᱱᱞᱮᱸᱰ',
    '🇬🇲' => 'ᱪᱤᱨ: ᱜᱟᱢᱵᱤᱭᱟ',
    '🇬🇳' => 'ᱪᱤᱨ: ᱜᱩᱭᱱᱤᱭᱟ',
    '🇬🇵' => 'ᱪᱤᱨ: ᱜᱩᱟᱰᱮᱞᱚᱣᱯ',
    '🇬🇶' => 'ᱪᱤᱨ: ᱤᱠᱣᱤᱴᱚᱨᱤᱭᱟᱹᱞ ᱜᱤᱱᱤ',
    '🇬🇷' => 'ᱪᱤᱨ: ᱜᱽᱨᱤᱥ',
    '🇬🇸' => 'ᱪᱤᱨ: ᱠᱚᱸᱭᱮ ᱡᱤᱭᱚᱨᱡᱤᱭᱟ ᱟᱨ ᱠᱚᱸᱭᱮ ᱥᱮᱸᱰᱣᱤᱪ ᱟᱭᱞᱮᱸᱰ',
    '🇬🇹' => 'ᱪᱤᱨ: ᱜᱩᱣᱟᱴᱮᱢᱟᱞᱟ',
    '🇬🇺' => 'ᱪᱤᱨ: ᱜᱩᱣᱟᱢ',
    '🇬🇼' => 'ᱪᱤᱨ: ᱜᱩᱭᱱᱤᱭᱟᱼᱵᱤᱥᱟᱣ',
    '🇬🇾' => 'ᱪᱤᱨ: ᱜᱩᱭᱟᱱᱟ',
    '🇭🇰' => 'ᱪᱤᱨ: ᱦᱚᱝ ᱠᱚᱝ ᱥᱟᱨ ᱪᱟᱭᱱᱟ',
    '🇭🇲' => 'ᱪᱤᱨ: ᱦᱟᱹᱰ ᱟᱨ ᱢᱮᱠᱰᱚᱱᱟᱹᱞᱰ ᱟᱭᱞᱮᱸᱰ',
    '🇭🇳' => 'ᱪᱤᱨ: ᱦᱚᱱᱰᱩᱨᱟᱥ',
    '🇭🇷' => 'ᱪᱤᱨ: ᱠᱨᱚᱮᱥᱤᱭᱟ',
    '🇭🇹' => 'ᱪᱤᱨ: ᱦᱟᱭᱴᱤ',
    '🇭🇺' => 'ᱪᱤᱨ: ᱦᱟᱹᱝᱜᱟᱨᱤ',
    '🇮🇨' => 'ᱪᱤᱨ: ᱠᱟᱱᱟᱨᱭ ᱟᱭᱞᱮᱸᱰᱥ',
    '🇮🇩' => 'ᱪᱤᱨ: ᱤᱱᱰᱚᱱᱮᱥᱤᱭᱟ',
    '🇮🇪' => 'ᱪᱤᱨ: ᱟᱭᱟᱹᱨᱞᱮᱸᱰ',
    '🇮🇱' => 'ᱪᱤᱨ: ᱤᱥᱨᱟᱭᱮᱞ',
    '🇮🇲' => 'ᱪᱤᱨ: ᱟᱭᱞ ᱚᱯᱷ ᱢᱮᱱ',
    '🇮🇳' => 'ᱪᱤᱨ: ᱤᱱᱰᱤᱭᱟ',
    '🇮🇴' => 'ᱪᱤᱨ: ᱵᱽᱨᱤᱴᱤᱥ ᱵᱷᱟᱨᱚᱛ ᱢᱟᱦᱟᱥᱟᱜᱚᱨ ᱡᱟᱭᱜᱟ',
    '🇮🇶' => 'ᱪᱤᱨ: ᱤᱨᱟᱠ',
    '🇮🇷' => 'ᱪᱤᱨ: ᱤᱨᱟᱱ',
    '🇮🇸' => 'ᱪᱤᱨ: ᱟᱭᱥᱞᱮᱸᱰ',
    '🇮🇹' => 'ᱪᱤᱨ: ᱤᱴᱞᱤ',
    '🇯🇪' => 'ᱪᱤᱨ: ᱡᱟᱹᱨᱥᱤ',
    '🇯🇲' => 'ᱪᱤᱨ: ᱡᱟᱢᱟᱭᱠᱟ',
    '🇯🇴' => 'ᱪᱤᱨ: ᱡᱚᱨᱰᱟᱱ',
    '🇯🇵' => 'ᱪᱤᱨ: ᱡᱟᱯᱟᱱ',
    '🇰🇪' => 'ᱪᱤᱨ: ᱠᱮᱱᱭᱟ',
    '🇰🇬' => 'ᱪᱤᱨ: ᱠᱤᱨᱜᱤᱥᱛᱟᱱ',
    '🇰🇭' => 'ᱪᱤᱨ: ᱠᱟᱹᱢᱵᱚᱰᱤᱭᱟ',
    '🇰🇮' => 'ᱪᱤᱨ: ᱠᱤᱨᱤᱵᱚᱛᱤ',
    '🇰🇲' => 'ᱪᱤᱨ: ᱠᱚᱢᱚᱨᱚᱥ',
    '🇰🇳' => 'ᱪᱤᱨ: ᱮᱥ ᱴᱤ ᱠᱤᱴᱥ ᱟᱨ ᱱᱮᱣᱤᱥ',
    '🇰🇵' => 'ᱪᱤᱨ: ᱮᱛᱚᱢ ᱠᱚᱨᱤᱭᱟ',
    '🇰🇷' => 'ᱪᱤᱨ: ᱠᱚᱧᱮ ᱠᱚᱨᱤᱭᱟ',
    '🇰🇼' => 'ᱪᱤᱨ: ᱠᱩᱣᱟᱹᱭᱛ',
    '🇰🇾' => 'ᱪᱤᱨ: ᱠᱮᱢᱮᱱ ᱟᱭᱞᱮᱸᱰᱥ',
    '🇰🇿' => 'ᱪᱤᱨ: ᱠᱟᱡᱟᱠᱷᱟᱥᱛᱷᱟᱱ',
    '🇱🇦' => 'ᱪᱤᱨ: ᱞᱟᱣᱚᱥ',
    '🇱🇧' => 'ᱪᱤᱨ: ᱞᱮᱵᱟᱱᱟᱱ',
    '🇱🇨' => 'ᱪᱤᱨ: ᱮᱥ ᱴᱤ ᱞᱩᱥᱤᱭᱟ',
    '🇱🇮' => 'ᱪᱤᱨ: ᱞᱤᱪᱮᱥᱴᱤᱱ',
    '🇱🇰' => 'ᱪᱤᱨ: ᱥᱨᱤ ᱞᱚᱝᱟ',
    '🇱🇷' => 'ᱪᱤᱨ: ᱞᱟᱭᱵᱮᱨᱤᱭᱟ',
    '🇱🇸' => 'ᱪᱤᱨ: ᱞᱮᱥᱚᱛᱷᱚ',
    '🇱🇹' => 'ᱪᱤᱨ: ᱞᱤᱛᱷᱩᱣᱟᱱᱤᱭᱟ',
    '🇱🇺' => 'ᱪᱤᱨ: ᱞᱤᱠᱡᱟᱹᱢᱵᱟᱹᱨᱜᱽ',
    '🇱🇻' => 'ᱪᱤᱨ: ᱞᱟᱛᱣᱤᱭᱟ',
    '🇱🇾' => 'ᱪᱤᱨ: ᱞᱤᱵᱭᱟ',
    '🇲🇦' => 'ᱪᱤᱨ: ᱢᱚᱨᱚᱠᱚ',
    '🇲🇨' => 'ᱪᱤᱨ: ᱢᱚᱱᱟᱠᱚ',
    '🇲🇩' => 'ᱪᱤᱨ: ᱢᱚᱞᱰᱚᱣᱟ',
    '🇲🇪' => 'ᱪᱤᱨ: ᱢᱚᱱᱴᱮᱱᱜᱽᱨᱚ',
    '🇲🇫' => 'ᱪᱤᱨ: ᱮᱥ ᱴᱤ ᱢᱟᱨᱴᱤᱱ',
    '🇲🇬' => 'ᱪᱤᱨ: ᱢᱟᱰᱟᱜᱟᱥᱠᱚᱨ',
    '🇲🇭' => 'ᱪᱤᱨ: ᱢᱟᱨᱥᱟᱞ ᱟᱭᱞᱮᱸᱰ',
    '🇲🇰' => 'ᱪᱤᱨ: ᱮᱛᱚᱢ ᱢᱟᱥᱮᱰᱚᱱᱤᱭᱟ',
    '🇲🇱' => 'ᱪᱤᱨ: ᱢᱟᱞᱤ',
    '🇲🇲' => 'ᱪᱤᱨ: ᱢᱭᱟᱱᱢᱟᱨ (ᱵᱟᱹᱨᱢᱟ)',
    '🇲🇳' => 'ᱪᱤᱨ: ᱢᱚᱝᱜᱚᱞᱤᱭᱟ',
    '🇲🇴' => 'ᱪᱤᱨ: ᱢᱟᱠᱟᱣ ᱥᱟᱨ ᱪᱟᱭᱱᱟ',
    '🇲🇵' => 'ᱪᱤᱨ: ᱮᱛᱚᱢ ᱢᱟᱨᱤᱭᱟᱱᱟ ᱟᱭᱞᱮᱸᱰ',
    '🇲🇶' => 'ᱪᱤᱨ: ᱢᱟᱨᱴᱤᱱᱠᱤᱣ',
    '🇲🇷' => 'ᱪᱤᱨ: ᱢᱟᱣᱨᱤᱴᱟᱱᱤᱭᱟ',
    '🇲🇸' => 'ᱪᱤᱨ: ᱢᱚᱱᱴᱥᱮᱨᱟᱴ',
    '🇲🇹' => 'ᱪᱤᱨ: ᱢᱟᱞᱴᱟ',
    '🇲🇺' => 'ᱪᱤᱨ: ᱢᱚᱨᱤᱥᱟᱹᱥ',
    '🇲🇻' => 'ᱪᱤᱨ: ᱢᱟᱞᱰᱤᱵᱷᱥ',
    '🇲🇼' => 'ᱪᱤᱨ: ᱢᱟᱹᱞᱟᱣᱤ',
    '🇲🇽' => 'ᱪᱤᱨ: ᱢᱮᱠᱥᱤᱠᱚ',
    '🇲🇾' => 'ᱪᱤᱨ: ᱢᱟᱹᱞᱮᱥᱤᱭᱟ',
    '🇲🇿' => 'ᱪᱤᱨ: ᱢᱚᱡᱟᱢᱵᱤᱠ',
    '🇳🇦' => 'ᱪᱤᱨ: ᱱᱟᱢᱤᱵᱤᱭᱟ',
    '🇳🇨' => 'ᱪᱤᱨ: ᱱᱟᱶᱟ ᱠᱟᱞᱮᱰᱚᱱᱤᱭᱟ',
    '🇳🇪' => 'ᱪᱤᱨ: ᱱᱟᱭᱡᱟᱹᱨ',
    '🇳🇫' => 'ᱪᱤᱨ: ᱱᱚᱨᱯᱷᱚᱞᱠ ᱟᱭᱞᱮᱸᱰ',
    '🇳🇬' => 'ᱪᱤᱨ: ᱱᱟᱭᱡᱮᱨᱤᱭᱟ',
    '🇳🇮' => 'ᱪᱤᱨ: ᱱᱤᱠᱟᱨᱟᱜᱩᱣᱟ',
    '🇳🇱' => 'ᱪᱤᱨ: ᱱᱮᱫᱚᱨᱞᱮᱸᱰ',
    '🇳🇴' => 'ᱪᱤᱨ: ᱱᱚᱨᱣᱮ',
    '🇳🇵' => 'ᱪᱤᱨ: ᱱᱮᱯᱟᱞ',
    '🇳🇷' => 'ᱪᱤᱨ: ᱱᱟᱶᱨᱩ',
    '🇳🇺' => 'ᱪᱤᱨ: ᱱᱟᱭᱩ',
    '🇳🇿' => 'ᱪᱤᱨ: ᱱᱤᱭᱩ ᱡᱤᱞᱮᱸᱰ',
    '🇴🇲' => 'ᱪᱤᱨ: ᱳᱢᱟᱱ',
    '🇵🇦' => 'ᱪᱤᱨ: ᱯᱟᱱᱟᱢᱟ',
    '🇵🇪' => 'ᱪᱤᱨ: ᱯᱮᱨᱩ',
    '🇵🇫' => 'ᱪᱤᱨ: ᱯᱷᱨᱮᱧᱪ ᱯᱚᱞᱤᱱᱮᱥᱤᱭᱟ',
    '🇵🇬' => 'ᱪᱤᱨ: ᱯᱟᱹᱯᱩᱣᱟ ᱱᱟᱶᱟ ᱡᱤᱱᱤᱭᱟ',
    '🇵🇭' => 'ᱪᱤᱨ: ᱯᱷᱤᱞᱤᱯᱤᱱᱥ',
    '🇵🇰' => 'ᱪᱤᱨ: ᱯᱟᱠᱮᱥᱛᱟᱱ',
    '🇵🇱' => 'ᱪᱤᱨ: ᱯᱚᱞᱮᱸᱰ',
    '🇵🇲' => 'ᱪᱤᱨ: ᱮᱥ ᱴᱤ ᱯᱟᱭᱨᱮ ᱟᱨ ᱢᱤᱠᱣᱮᱞᱮᱱ',
    '🇵🇳' => 'ᱪᱤᱨ: ᱯᱤᱴᱠᱮᱨᱱ ᱟᱭᱞᱮᱸᱰ',
    '🇵🇷' => 'ᱪᱤᱨ: ᱯᱩᱣᱮᱨᱴᱚ ᱨᱤᱠᱚ',
    '🇵🇸' => 'ᱪᱤᱨ: ᱯᱟᱞᱮᱥᱴᱤᱱᱤᱭᱟᱹᱱ ᱡᱟᱭᱜᱟ',
    '🇵🇹' => 'ᱪᱤᱨ: ᱯᱚᱨᱛᱩᱜᱟᱞ',
    '🇵🇼' => 'ᱪᱤᱨ: ᱯᱟᱞᱟᱣ',
    '🇵🇾' => 'ᱪᱤᱨ: ᱯᱟᱨᱟᱜᱩᱣᱮ',
    '🇶🇦' => 'ᱪᱤᱨ: ᱠᱚᱛᱚᱨ',
    '🇷🇪' => 'ᱪᱤᱨ: ᱨᱤᱭᱩᱱᱤᱭᱟᱹᱱ',
    '🇷🇴' => 'ᱪᱤᱨ: ᱨᱚᱢᱟᱱᱤᱭᱟ',
    '🇷🇸' => 'ᱪᱤᱨ: ᱥᱟᱹᱨᱵᱤᱭᱟ',
    '🇷🇺' => 'ᱪᱤᱨ: ᱨᱩᱥ',
    '🇷🇼' => 'ᱪᱤᱨ: ᱨᱟᱹᱣᱟᱹᱱᱰᱟ',
    '🇸🇦' => 'ᱪᱤᱨ: ᱥᱟᱹᱣᱫᱤ ᱚᱨᱚᱵ',
    '🇸🇧' => 'ᱪᱤᱨ: ᱥᱚᱞᱚᱢᱚᱱ ᱟᱭᱞᱮᱸᱰ',
    '🇸🇨' => 'ᱪᱤᱨ: ᱥᱮᱥᱮᱞᱥ',
    '🇸🇩' => 'ᱪᱤᱨ: ᱥᱩᱫᱟᱱ',
    '🇸🇪' => 'ᱪᱤᱨ: ᱥᱣᱤᱰᱮᱱ',
    '🇸🇬' => 'ᱪᱤᱨ: ᱥᱤᱝᱜᱟᱯᱩᱨ',
    '🇸🇭' => 'ᱪᱤᱨ: ᱮᱥ ᱴᱤ ᱦᱮᱞᱮᱱᱟ',
    '🇸🇮' => 'ᱪᱤᱨ: ᱥᱞᱚᱣᱮᱱᱤᱭᱟ',
    '🇸🇯' => 'ᱪᱤᱨ: ᱥᱣᱟᱞᱵᱟᱰ ᱟᱨ ᱡᱟᱱ ᱢᱟᱭᱮᱱ',
    '🇸🇰' => 'ᱪᱤᱨ: ᱥᱞᱚᱣᱮᱠᱤᱭᱟ',
    '🇸🇱' => 'ᱪᱤᱨ: ᱥᱟᱭᱨᱟ ᱞᱮᱭᱚᱱᱤ',
    '🇸🇲' => 'ᱪᱤᱨ: ᱥᱟᱱ ᱢᱟᱨᱤᱱᱚ',
    '🇸🇳' => 'ᱪᱤᱨ: ᱥᱮᱱᱮᱜᱚᱞ',
    '🇸🇴' => 'ᱪᱤᱨ: ᱥᱚᱢᱟᱞᱤᱭᱟ',
    '🇸🇷' => 'ᱪᱤᱨ: ᱥᱩᱨᱤᱱᱟᱢ',
    '🇸🇸' => 'ᱪᱤᱨ: ᱠᱚᱧᱮ ᱥᱩᱫᱟᱱ',
    '🇸🇹' => 'ᱪᱤᱨ: ᱥᱟᱣ ᱴᱚᱢ ᱟᱨ ᱯᱨᱤᱱᱥᱤᱯᱮ',
    '🇸🇻' => 'ᱪᱤᱨ: ᱮᱞ ᱥᱟᱞᱣᱟᱰᱚᱨ',
    '🇸🇽' => 'ᱪᱤᱨ: ᱥᱤᱱᱴ ᱢᱟᱨᱴᱮᱱ',
    '🇸🇾' => 'ᱪᱤᱨ: ᱥᱤᱨᱤᱭᱟ',
    '🇸🇿' => 'ᱪᱤᱨ: ᱮᱥᱣᱟᱴᱤᱱᱟ',
    '🇹🇦' => 'ᱪᱤᱨ: ᱛᱨᱤᱥᱛᱟᱱ ᱰᱟ ᱠᱩᱱᱦᱟ',
    '🇹🇨' => 'ᱪᱤᱨ: ᱛᱩᱨᱠᱥ ᱟᱨ ᱠᱟᱭᱠᱚᱥ ᱟᱭᱞᱮᱸᱰ',
    '🇹🇩' => 'ᱪᱤᱨ: ᱪᱟᱰ',
    '🇹🇫' => 'ᱪᱤᱨ: ᱯᱷᱨᱟᱱᱥᱤᱥ ᱠᱚᱧᱮ ᱡᱟᱭᱜᱟ',
    '🇹🇬' => 'ᱪᱤᱨ: ᱴᱚᱜᱚ',
    '🇹🇭' => 'ᱪᱤᱨ: ᱛᱷᱟᱭᱞᱮᱸᱰ',
    '🇹🇯' => 'ᱪᱤᱨ: ᱛᱟᱡᱤᱠᱤᱥᱛᱟᱱ',
    '🇹🇰' => 'ᱪᱤᱨ: ᱴᱚᱠᱮᱞᱟᱣ',
    '🇹🇱' => 'ᱪᱤᱨ: ᱴᱤᱢᱚᱨᱼᱞᱮᱥᱴᱮ',
    '🇹🇲' => 'ᱪᱤᱨ: ᱛᱩᱨᱠᱢᱮᱱᱤᱥᱛᱟᱱ',
    '🇹🇳' => 'ᱪᱤᱨ: ᱴᱩᱱᱤᱥᱤᱭᱟ',
    '🇹🇴' => 'ᱪᱤᱨ: ᱴᱚᱝᱜᱟ',
    '🇹🇷' => 'ᱪᱤᱨ: ᱛᱟᱹᱨᱠᱤ',
    '🇹🇹' => 'ᱪᱤᱨ: ᱴᱨᱤᱱᱤᱰᱟᱰ ᱟᱨ ᱴᱚᱵᱟᱜᱚ',
    '🇹🇻' => 'ᱪᱤᱨ: ᱴᱩᱣᱟᱞᱩ',
    '🇹🇼' => 'ᱪᱤᱨ: ᱛᱟᱭᱣᱟᱱ',
    '🇹🇿' => 'ᱪᱤᱨ: ᱛᱟᱹᱱᱡᱟᱱᱤᱭᱟ',
    '🇺🇦' => 'ᱪᱤᱨ: ᱭᱩᱠᱨᱮᱱ',
    '🇺🇬' => 'ᱪᱤᱨ: ᱩᱜᱟᱱᱰᱟ',
    '🇺🇲' => 'ᱪᱤᱨ: ᱭᱩ ᱮᱥ ᱵᱟᱷᱨᱮ ᱟᱭᱞᱮᱸᱰ',
    '🇺🇳' => 'ᱪᱤᱨ: ᱡᱩᱢᱤᱫ ᱫᱤᱥᱚᱢ',
    '🇺🇸' => 'ᱪᱤᱨ: ᱭᱩᱱᱟᱭᱴᱮᱰ ᱮᱥᱴᱮᱴ',
    '🇺🇾' => 'ᱪᱤᱨ: ᱩᱨᱩᱜᱩᱣᱮ',
    '🇺🇿' => 'ᱪᱤᱨ: ᱩᱡᱽᱵᱮᱠᱤᱥᱛᱟᱱ',
    '🇻🇦' => 'ᱪᱤᱨ: ᱣᱟᱴᱤᱠᱟᱱ ᱥᱚᱦᱚᱨ',
    '🇻🇨' => 'ᱪᱤᱨ: ᱮᱥ ᱴᱤ ᱵᱷᱤᱱᱥᱮᱴ ᱟᱨ ᱜᱽᱨᱮᱱᱟᱰᱤᱱᱥ',
    '🇻🇪' => 'ᱪᱤᱨ: ᱣᱮᱱᱮᱡᱣᱮᱞᱟ',
    '🇻🇬' => 'ᱪᱤᱨ: ᱵᱽᱨᱤᱴᱤᱥ ᱣᱟᱹᱨᱡᱤᱱ ᱟᱭᱞᱮᱸᱰ',
    '🇻🇮' => 'ᱪᱤᱨ: ᱭᱩ ᱮᱥ ᱣᱟᱹᱨᱡᱤᱱ ᱟᱭᱞᱮᱸᱰ',
    '🇻🇳' => 'ᱪᱤᱨ: ᱣᱤᱭᱮᱛᱱᱟᱢ',
    '🇻🇺' => 'ᱪᱤᱨ: ᱵᱷᱟᱱᱩᱟᱴᱩ',
    '🇼🇫' => 'ᱪᱤᱨ: ᱣᱟᱞᱤᱥ ᱟᱨ ᱯᱷᱩᱴᱩᱱᱟ',
    '🇼🇸' => 'ᱪᱤᱨ: ᱥᱟᱢᱚᱣᱟ',
    '🇽🇰' => 'ᱪᱤᱨ: ᱠᱚᱥᱚᱣᱚ',
    '🇾🇪' => 'ᱪᱤᱨ: ᱭᱮᱢᱮᱱ',
    '🇾🇹' => 'ᱪᱤᱨ: ᱢᱟᱭᱚᱴᱮ',
    '🇿🇦' => 'ᱪᱤᱨ: ᱠᱚᱧᱮ ᱟᱯᱷᱨᱤᱠᱟ',
    '🇿🇲' => 'ᱪᱤᱨ: ᱡᱟᱢᱵᱤᱭᱟ',
    '🇿🇼' => 'ᱪᱤᱨ: ᱡᱤᱢᱵᱟᱣᱮ',
    '🔟' => 'ᱠᱤᱠᱮᱯ: 10',
    '😀' => 'ᱞᱟᱱᱫᱟ ᱪᱮᱦᱨᱟ',
    '😃' => 'ᱢᱟᱨᱟᱝ ᱢᱮᱫ ᱥᱟᱞᱟᱜ ᱢᱩᱞᱩᱡ ᱞᱟᱱᱫᱟ',
    '😄' => 'ᱢᱚᱲᱟ ᱤᱥᱤᱲ ᱠᱟᱫ ᱛᱮ ᱞᱟᱱᱫᱟᱮᱫ ᱞᱮᱠᱷᱟ ᱢᱮᱫ',
    '😁' => 'ᱤᱥᱤᱲ ᱢᱚᱪᱟ',
    '😆' => 'ᱞᱟᱱᱫᱟ ᱢᱚᱪᱟ',
    '😅' => 'ᱩᱫᱽᱜᱟᱹᱨ ᱥᱟᱶᱛᱮ ᱰᱟᱴᱟ ᱤᱥᱤᱲ ᱢᱚᱲᱟ',
    '🤣' => 'ᱞᱟᱱᱫᱟ ᱜᱩᱲᱫᱟᱹᱣ',
    '😂' => 'ᱢᱚᱡᱽ ᱢᱚᱲᱟ',
    '🙂' => 'ᱱᱟᱥᱮ ᱞᱟᱱᱫᱟᱮᱫ ᱞᱮᱠᱷᱟ ᱪᱮᱦᱨᱟ',
    '🙃' => 'ᱩᱞᱴᱟᱹ ᱪᱮᱦᱨᱟ',
    '🫠' => 'ᱛᱚᱨᱲᱟᱣ ᱢᱚᱲᱟ',
    '😉' => 'ᱵᱤᱱᱰᱩᱡ ᱢᱚᱲᱟ',
    '😊' => 'ᱞᱟᱸᱫᱟ ᱢᱚᱲᱟ ᱥᱟᱶ ᱞᱟᱸᱫᱟ ᱢᱮᱫ',
    '😇' => 'ᱦᱟᱞᱚ ᱥᱟᱶᱛᱮ ᱞᱟᱱᱫᱟᱮᱫ ᱢᱚᱲᱟ',
    '🥰' => 'ᱫᱩᱞᱟᱹᱲ ᱞᱟᱱᱫᱟ',
    '😍' => 'ᱞᱟᱱᱫᱟ ᱢᱚᱲᱟ ᱥᱟᱶᱛᱮ ᱫᱩᱞᱟᱹᱲ ᱢᱮᱫ',
    '🤩' => 'ᱤᱯᱤᱞ ᱢᱚᱲᱟ',
    '😘' => 'ᱪᱚᱜᱮᱫ ᱢᱚᱲᱟ',
    '😗' => 'ᱪᱚᱜ ᱢᱚᱲᱟ',
    '☺' => 'ᱞᱟᱱᱫᱟᱮᱫ ᱢᱚᱲᱟ',
    '😚' => 'ᱢᱮᱫ ᱵᱚᱸᱫ ᱠᱟᱛᱮ ᱪᱚᱜ',
    '😙' => 'ᱪᱚᱜ ᱢᱚᱲᱟ ᱠᱟᱱᱟ',
    '🥲' => 'ᱢᱮᱫ ᱫᱟᱜ ᱡᱚᱨᱚ ᱢᱚᱲᱟ',
    '😋' => 'ᱢᱚᱡᱽ ᱡᱚᱢ',
    '😛' => 'ᱢᱚᱲᱟ ᱥᱟᱞᱟᱜ ᱟᱞᱟᱝ',
    '😜' => 'ᱟᱞᱟᱝ ᱥᱟᱞᱟᱜ ᱢᱚᱲᱟ ᱵᱤᱱᱰᱩᱡ',
    '🤪' => 'ᱯᱟᱜᱽᱞᱟ ᱢᱚᱲᱟ',
    '😝' => 'ᱟᱞᱟᱝ ᱟᱨ ᱵᱟᱱᱴᱷᱤᱠ',
    '🤑' => 'ᱯᱩᱭᱥᱟᱹ ᱢᱚᱪᱟ ᱢᱚᱲᱟ',
    '🤗' => 'ᱠᱷᱩᱞᱟᱹᱛᱤ ᱛᱮ ᱞᱟᱱᱫᱟᱮᱫ ᱢᱚᱲᱟ',
    '🤭' => 'ᱢᱚᱪᱟ ᱨᱮ ᱛᱤ ᱫᱚᱦᱚ',
    '🫢' => 'ᱢᱩᱸ ᱨᱮ ᱛᱤ ᱫᱚᱦᱚ ᱟᱨ ᱠᱷᱩᱞᱟᱹ ᱢᱮᱫ ᱞᱮᱠᱷᱟ',
    '🫣' => 'ᱢᱮᱫ ᱛᱮ ᱩᱭᱩᱝᱮᱫ ᱢᱚᱲᱟ',
    '🤫' => 'ᱪᱩᱯ ᱢᱚᱲᱟ',
    '🤔' => 'ᱵᱤᱪᱟᱹᱨ ᱢᱚᱲᱟ',
    '🫡' => 'ᱥᱮᱞᱭᱩᱴ ᱢᱚᱲᱟ',
    '🤐' => 'ᱢᱚᱲᱟ ᱡᱤᱯ',
    '🤨' => 'ᱢᱚᱲᱟ ᱨᱮ ᱢᱮᱫ ᱠᱩᱴᱤ ᱩᱵ ᱛᱩᱞ ᱠᱟᱱᱟ',
    '😐' => 'ᱛᱟᱞᱟᱢᱟᱞᱤ ᱢᱚᱲᱟ',
    '😑' => 'ᱥᱩᱱ ᱞᱟᱹᱭᱯᱟᱥᱱᱟᱣ ᱢᱚᱲᱟ',
    '😶' => 'ᱵᱤᱱ ᱢᱚᱪᱟ ᱢᱚᱲᱟ',
    '🫥' => 'ᱰᱚᱴ ᱞᱟᱭᱤᱱ ᱢᱚᱲᱟ',
    '😏' => 'ᱞᱟᱱᱫᱟ ᱢᱚᱲᱟ',
    '😒' => 'ᱵᱮᱠᱷᱟᱛᱤᱨ ᱢᱚᱲᱟ',
    '🙄' => 'ᱜᱩᱰᱨᱟᱹᱣ ᱢᱮᱫ ᱠᱩᱴᱤ ᱢᱚᱲᱟ',
    '😬' => 'ᱤᱥᱤᱲ ᱢᱚᱲᱟ',
    '🤥' => 'ᱮᱲᱮ ᱢᱚᱲᱟ',
    '🫨' => 'ᱨᱩᱠᱩ ᱢᱚᱲᱟ',
    '😌' => 'ᱚᱪᱤᱱᱛᱟᱹ ᱢᱚᱲᱟ',
    '😔' => 'ᱪᱤᱱᱛᱟᱹ ᱢᱚᱲᱟ',
    '😪' => 'ᱡᱟᱹᱯᱤᱫ ᱢᱚᱲᱟ',
    '🤤' => 'ᱩᱞᱤ ᱫᱟᱜ ᱢᱚᱲᱟ',
    '😴' => 'ᱜᱤᱛᱤᱡ ᱢᱚᱲᱟ',
    '😷' => 'ᱢᱮᱰᱤᱠᱟᱞ ᱢᱟᱥᱠ ᱢᱚᱲᱟ',
    '🤒' => 'ᱢᱚᱲᱟ ᱥᱟᱞᱟᱜ ᱛᱷᱚᱨᱢᱚᱢᱤᱴᱚᱨ',
    '🤕' => 'ᱵᱮᱱᱰᱮᱡ ᱥᱟᱞᱟᱜ ᱛᱮ ᱢᱚᱲᱟ',
    '🤢' => 'ᱩᱞᱟᱹ ᱢᱚᱲᱟ',
    '🤮' => 'ᱩᱞᱟᱹᱮᱫ ᱢᱚᱲᱟ',
    '🤧' => 'ᱪᱷᱩᱨ ᱢᱚᱲᱟ',
    '🥵' => 'ᱜᱚᱨᱚᱢ ᱢᱚᱲᱟ',
    '🥶' => 'ᱨᱟᱵᱟᱝ ᱢᱚᱲᱟ',
    '🥴' => 'ᱟᱹᱰᱤ ᱢᱚᱡᱽ ᱢᱚᱲᱟ',
    '😵' => 'ᱛᱤᱨᱪᱷᱟᱹ ᱢᱚᱲᱟ',
    '🤯' => 'ᱵᱚᱦᱚᱜ ᱚᱴᱚᱡᱚᱜ',
    '🤠' => 'ᱰᱟᱹᱝᱜᱽᱨᱤ ᱜᱩᱯᱤ ᱜᱤᱫᱽᱨᱟᱹ ᱴᱩᱯᱤ',
    '🥳' => 'ᱥᱚᱲᱮ ᱢᱚᱲᱟ',
    '🤡' => 'ᱡᱚᱠᱚᱨ ᱢᱚᱲᱟ',
    '👻' => 'ᱵᱷᱩᱛ',
    '😺' => 'ᱯᱩᱥᱤ ᱤᱥᱤᱲ ᱠᱟᱫᱟᱭ',
    '💌' => 'ᱫᱩᱞᱟᱹᱲᱤᱭᱟᱹ ᱪᱤᱴᱷᱤ',
    '💕' => 'ᱵᱟᱨᱭᱟ ᱨᱤᱫᱟᱹᱭ',
    '💋' => 'ᱪᱚᱜ ᱪᱤᱱᱦᱟᱹ',
    '💯' => 'ᱥᱟᱭ ᱯᱚᱮᱱᱴᱥ',
    '💢' => 'ᱨᱟᱹᱜᱤ ᱪᱤᱱᱦᱟᱹ',
    '💦' => 'ᱩᱫᱽᱜᱟᱹᱨ ᱡᱚᱨᱚ',
    '🕳' => 'ᱵᱷᱩᱜᱟᱹᱜ',
    '💬' => 'ᱨᱚᱲ ᱵᱮᱞᱩᱱ',
    '🗨' => 'ᱞᱮᱝᱜᱟ ᱨᱚᱲ ᱨᱤᱢᱤᱞ',
    '🗯' => 'ᱡᱚᱡᱚᱢ ᱨᱟᱹᱜᱤ ᱨᱤᱢᱤᱞ',
    '💭' => 'ᱩᱭᱦᱟᱹᱨ ᱯᱷᱩᱠᱟᱹ',
    '💤' => 'ᱡᱟᱹᱯᱤᱫ',
    '👋' => 'ᱛᱤ ᱦᱩᱨᱞᱟᱹ',
    '🤚' => 'ᱛᱤ ᱛᱩᱞ ᱨᱟᱠᱟᱵ',
    '🖐' => 'ᱛᱤ ᱠᱟᱹᱴᱩᱵ ᱠᱚ ᱯᱟᱥᱱᱟᱣ ᱠᱟᱱᱟ',
    '✋' => 'ᱛᱤ ᱛᱩᱞ',
    '🖖' => 'ᱛᱤ ᱥᱮᱞᱭᱩᱴ',
    '🫱' => 'ᱡᱚᱡᱚᱢ ᱛᱤ',
    '🫲' => 'ᱞᱮᱝᱜᱟ ᱛᱤ',
    '🫳' => 'ᱛᱤ ᱛᱟᱞᱠᱷᱟ ᱞᱟᱛᱟᱨ',
    '🫴' => 'ᱛᱤ ᱛᱟᱞᱠᱷᱟ ᱪᱮᱛᱟᱱ',
    '👌' => 'ᱛᱤ ᱛᱮ ᱜᱩᱞᱟᱹᱭ',
    '🖕' => 'ᱛᱟᱞᱟ ᱠᱟᱹᱴᱩᱵ',
    '👇' => 'ᱞᱟᱛᱟᱨ ᱥᱮᱫ ᱩᱫᱩᱜ',
    '☝' => 'ᱪᱮᱛᱟᱱ ᱥᱮᱫ ᱩᱫᱩᱜ',
    '🫵' => 'ᱦᱚᱲ ᱥᱮᱱ ᱩᱫᱩᱜ',
    '👍' => 'ᱮᱝᱜᱟ ᱠᱟᱹᱴᱩᱵ ᱫᱮᱠᱷᱟᱣ',
    '👎' => 'ᱮᱝᱜᱟ ᱠᱟᱹᱴᱩᱵ ᱩᱞᱴᱟᱹ',
    '✊' => 'ᱢᱩᱴᱷᱟᱹ ᱛᱩᱞ ᱠᱟᱱᱟ',
    '👊' => 'ᱦᱟᱹᱡᱩᱜ ᱠᱟᱱ ᱢᱩᱴᱷᱟᱹ',
    '🤛' => 'ᱞᱮᱝᱜᱟ ᱢᱩᱦᱟᱹ ᱢᱩᱴᱷᱟᱹ',
    '🤜' => 'ᱡᱚᱡᱚᱢ ᱢᱩᱦᱟᱹ ᱢᱩᱴᱷᱟᱹ',
    '👏' => 'ᱛᱷᱟᱭᱚ ᱛᱤ',
    '🙌' => 'ᱛᱩᱞ ᱛᱤ',
    '🫶' => 'ᱫᱩᱞᱟᱹᱲ ᱛᱤ',
    '👐' => 'ᱠᱷᱩᱞᱟᱹ ᱛᱤ',
    '🤲' => 'ᱥᱟᱶᱛᱮ ᱛᱤ ᱛᱟᱞᱠᱷᱟ',
    '🤝' => 'ᱛᱤ ᱢᱮᱲᱟᱣ',
    '🙏' => 'ᱡᱚᱦᱟᱨ',
    '✍' => 'ᱚᱞ ᱛᱤ',
    '💅' => 'ᱨᱟᱢᱟ ᱡᱚᱛᱚᱱ',
    '🤳' => 'ᱥᱮᱞᱯᱷᱤ',
    '👂' => 'ᱞᱩᱛᱩᱨ',
    '🦷' => 'ᱰᱟᱴᱟ',
    '🦴' => 'ᱡᱟᱝ',
    '👀' => 'ᱢᱮᱫ',
    '👶' => 'ᱜᱤᱫᱽᱨᱟ',
    '🧒' => 'ᱜᱤᱫᱽᱨᱟᱹ',
    '👦' => 'ᱠᱚᱲᱟ',
    '👧' => 'ᱠᱩᱲᱤ',
    '🧑' => 'ᱦᱚᱲ ᱜᱮ',
    '👨' => 'ᱦᱚᱲ',
    '👩' => 'ᱢᱟᱹᱭᱡᱩ',
    '🧓' => 'ᱦᱟᱲᱟᱢ ᱦᱚᱲ ᱜᱮ',
    '👴' => 'ᱢᱟᱲᱟᱢ ᱦᱚᱲ',
    '👵' => 'ᱵᱩᱰᱷᱤ',
    '🦰' => 'ᱟᱨᱟᱜ ᱩᱵ',
    '🦳' => 'ᱯᱩᱸᱱᱰ ᱩᱵ',
    '🐵' => 'ᱦᱟᱹᱬᱩ ᱢᱚᱲᱟ',
    '🐒' => 'ᱦᱟᱹᱬᱩ',
    '🦍' => 'ᱜᱚᱨᱤᱞᱟ',
    '🦧' => 'ᱚᱨᱟᱝᱜᱩᱴᱟᱱ',
    '🐶' => 'ᱥᱮᱛᱟ ᱢᱚᱲᱟ',
    '🐕' => 'ᱥᱮᱛᱟ',
    '🦮' => 'ᱜᱚᱲᱚ ᱥᱮᱛᱟ',
    '🐩' => 'ᱞᱚᱢᱚᱥ ᱥᱮᱛᱟ',
    '🐺' => 'ᱦᱟᱰᱜᱟᱨ',
    '🦊' => 'ᱛᱩᱭᱩ',
    '🐱' => 'ᱯᱩᱥᱤ ᱢᱚᱲᱟ',
    '🐈' => 'ᱯᱩᱥᱤ',
    '🦁' => 'ᱠᱩᱞ',
    '🐯' => 'ᱛᱟᱹᱨᱩᱵ ᱢᱚᱲᱟ',
    '🐅' => 'ᱛᱟᱹᱨᱩᱵ',
    '🐆' => 'ᱪᱮᱴᱨᱟ',
    '🐴' => 'ᱥᱟᱫᱚᱢ ᱢᱚᱲᱟ',
    '🫏' => 'ᱜᱟᱫᱷᱟ',
    '🐎' => 'ᱥᱟᱫᱚᱢ',
    '🦌' => 'ᱥᱮᱞᱮᱵ',
    '🐮' => 'ᱰᱟᱹᱝᱜᱽᱨᱤ ᱢᱚᱲᱟ',
    '🐃' => 'ᱫᱟᱜ ᱠᱟᱲᱟ',
    '🐄' => 'ᱰᱟᱹᱝᱜᱽᱨᱤ',
    '🐷' => 'ᱥᱩᱠᱨᱤ ᱢᱚᱲᱟ',
    '🐖' => 'ᱥᱩᱠᱨᱤ',
    '🐐' => 'ᱢᱮᱨᱚᱢ',
    '🐪' => 'ᱩᱱᱴᱷ',
    '🐘' => 'ᱦᱟᱹᱛᱤ',
    '🐁' => 'ᱜᱩᱰᱩ',
    '🐀' => 'ᱪᱩᱱᱫ',
    '🐰' => 'ᱠᱩᱞᱟᱹᱭ ᱢᱚᱲᱟ',
    '🐇' => 'ᱠᱩᱞᱟᱹᱭ',
    '🦇' => 'ᱵᱟᱹᱨᱫᱩᱬᱤᱡ',
    '🐻' => 'ᱵᱟᱱᱟ',
    '🐔' => 'ᱥᱤᱢ',
    '🐤' => 'ᱜᱤᱫᱽᱨᱟᱹ ᱥᱤᱢ',
    '🐥' => 'ᱥᱤᱫᱷᱟᱹ ᱥᱟᱢᱟᱝᱮᱫ ᱜᱤᱫᱽᱨᱟᱹ ᱥᱤᱢ',
    '🐦' => 'ᱪᱮᱬᱮᱸ',
    '🦉' => 'ᱠᱚᱠᱚᱨ',
    '🪶' => 'ᱤᱞ',
    '🦜' => 'ᱢᱤᱨᱩ',
    '🪽' => 'ᱯᱷᱟᱹᱠᱬᱟᱹᱜ',
    '🐸' => 'ᱨᱮᱴᱚ',
    '🐢' => 'ᱦᱚᱨᱚ',
    '🦎' => 'ᱪᱮᱨᱪᱮᱴᱮᱡ',
    '🐍' => 'ᱵᱤᱝ',
    '🐲' => 'ᱢᱚᱲᱟ',
    '🐟' => 'ᱦᱟᱹᱠᱩ',
    '🐙' => 'ᱤᱨᱟᱹᱞ ᱠᱟᱴᱟ ᱦᱟᱹᱠᱩ',
    '🐚' => 'ᱨᱚᱠᱚᱡ ᱪᱷᱤᱞᱠᱟᱹ',
    '🦀' => 'ᱠᱟᱴᱠᱚᱢ',
    '🐌' => 'ᱨᱚᱠᱚᱡ',
    '🦋' => 'ᱯᱤᱯᱤᱲᱤᱭᱟᱹ',
    '🐛' => 'ᱩᱨᱩ',
    '🐜' => 'ᱢᱩᱡ',
    '🐝' => 'ᱥᱩᱥᱩᱨᱵᱟᱝ',
    '🕷' => 'ᱵᱤᱱᱫᱤ',
    '🕸' => 'ᱵᱤᱱᱫᱤ ᱡᱟᱹᱞᱤ',
    '🦟' => 'ᱥᱤᱠᱬᱤᱡ',
    '🪱' => 'ᱛᱤᱡᱩ',
    '💐' => 'ᱵᱟᱦᱟ ᱜᱩᱪᱷᱟᱹ',
    '🌸' => 'ᱪᱮᱨᱭ ᱠᱷᱤᱞᱟᱹᱣ',
    '💮' => 'ᱯᱩᱸᱰ ᱵᱟᱦᱟ',
    '🪷' => 'ᱯᱚᱨᱟᱭᱱᱤ',
    '🌹' => 'ᱜᱩᱞᱟᱹᱯ',
    '🌱' => 'ᱜᱚᱡᱟ',
    '🍄' => 'ᱩᱫ',
    '🍇' => 'ᱚᱝᱜᱩᱨ',
    '🍈' => 'ᱛᱟᱹᱨᱵᱩᱡ',
    '🍉' => 'ᱫᱟᱜ ᱛᱟᱹᱨᱵᱩᱡ',
    '🍊' => 'ᱡᱟᱹᱢᱵᱤᱨ',
    '🍋' => 'ᱞᱮᱢᱵᱩ',
    '🍌' => 'ᱠᱟᱭᱨᱟ',
    '🍍' => 'ᱚᱱᱟᱨ',
    '🥭' => 'ᱩᱞ',
    '🍎' => 'ᱟᱨᱟᱜ ᱥᱮᱣ',
    '🍏' => 'ᱦᱟᱹᱨᱤᱭᱟᱹᱲ ᱥᱮᱣ',
    '🥝' => 'ᱠᱤᱣᱤ ᱡᱚ',
    '🍅' => 'ᱵᱤᱞᱟᱹᱛ',
    '🫒' => 'ᱚᱞᱟᱭᱤᱵ',
    '🥥' => 'ᱱᱩᱲᱤᱭᱟᱹ',
    '🥑' => 'ᱟᱣᱚᱠᱟᱨᱰᱚ',
    '🍆' => 'ᱵᱮᱝᱜᱟᱲ',
    '🥔' => 'ᱟᱹᱲᱩ',
    '🥕' => 'ᱜᱚᱡᱚᱨ',
    '🌶' => 'ᱢᱟᱹᱨᱤᱪ',
    '🫑' => 'ᱥᱤᱢᱞᱟᱹ ᱢᱟᱹᱨᱤᱪ',
    '🥒' => 'ᱛᱟᱦᱮᱨ',
    '🥬' => 'ᱦᱟᱹᱨᱤᱭᱟᱹᱲ ᱥᱟᱠᱟᱢ',
    '🥦' => 'ᱵᱽᱨᱚᱠᱚᱞᱤ',
    '🧄' => 'ᱞᱮᱥᱩᱱ',
    '🧅' => 'ᱯᱮᱭᱟᱡᱽ',
    '🥜' => 'ᱵᱟᱫᱟᱢ',
    '🫘' => 'ᱢᱚᱴᱚᱨ',
    '🫚' => 'ᱚᱫᱟ ᱨᱮᱦᱮᱫ',
    '🫛' => 'ᱢᱚᱴᱚᱨ ᱡᱚ',
    '🍞' => 'ᱯᱟᱸ ᱨᱩᱴᱤ',
    '🥖' => 'ᱡᱷᱟᱹᱞ ᱯᱟᱸ ᱨᱩᱴᱤ',
    '🫓' => 'ᱪᱚᱯᱴᱟ ᱯᱟᱸ ᱨᱩᱴᱤ',
    '🥨' => 'ᱯᱨᱮᱴᱡᱟᱞ',
    '🥯' => 'ᱜᱩᱞ ᱞᱟᱹᱰᱩ',
    '🥞' => 'ᱠᱚᱰᱷᱟ ᱯᱟᱸ ᱨᱩᱴᱤ',
    '🍖' => 'ᱡᱟᱝ ᱨᱮ ᱡᱤᱞ',
    '🍗' => 'ᱡᱟᱝ ᱡᱤᱞ',
    '🥩' => 'ᱜᱮᱫ ᱠᱟᱱ ᱡᱤᱞ',
    '🍕' => 'ᱯᱤᱡᱟ',
    '🥚' => 'ᱵᱤᱞᱤ',
    '🍳' => 'ᱤᱥᱤᱱ',
    '🥗' => 'ᱦᱟᱹᱨᱤᱭᱟᱹᱲ ᱥᱟᱞᱟᱰ',
    '🧂' => 'ᱵᱩᱞᱩᱢ',
    '🍙' => 'ᱫᱟᱠᱟ ᱜᱩᱞᱟᱹᱭ',
    '🍚' => 'ᱤᱥᱤᱱ ᱠᱟᱱ ᱪᱟᱣᱞᱮ',
    '🍨' => 'ᱵᱚᱨᱚᱯᱷ ᱪᱷᱟᱞᱮ',
    '🍪' => 'ᱞᱟᱹᱰᱩ',
    '🎂' => 'ᱡᱟᱱᱟᱢ ᱢᱟᱦᱟᱸ ᱯᱤᱴᱷᱟᱹ',
    '🍰' => 'ᱠᱷᱟᱴᱚ ᱯᱤᱴᱷᱟᱹ',
    '🍬' => 'ᱪᱚᱠᱞᱮᱴ',
    '🥛' => 'ᱢᱤᱫ ᱜᱤᱞᱟᱹᱥ ᱛᱚᱣᱟ',
    '🧊' => 'ᱵᱚᱨᱚᱯᱷ',
    '🥄' => 'ᱪᱟᱹᱢᱩᱪ',
    '🔪' => 'ᱫᱟᱠᱟ ᱚᱲᱟᱜ ᱪᱷᱩᱨᱤ',
    '🫙' => 'ᱡᱟᱨ',
    '🗺' => 'ᱡᱮᱜᱮᱛ ᱱᱚᱠᱥᱟ',
    '🗾' => 'ᱡᱟᱯᱟᱱ ᱨᱮᱭᱟᱜ ᱱᱚᱠᱥᱟ',
    '🏔' => 'ᱵᱚᱨᱚᱯᱷ ᱠᱟᱱ ᱵᱩᱨᱩ',
    '⛰' => 'ᱵᱩᱨᱩ',
    '🏟' => 'ᱥᱴᱮᱰᱤᱭᱚᱢ',
    '🧱' => 'ᱤᱴᱟᱹ',
    '🪨' => 'ᱪᱟᱹᱴᱱᱤ',
    '🪵' => 'ᱠᱟᱴᱷ',
    '🛖' => 'ᱚᱲᱟᱜ',
    '🏘' => 'ᱚᱲᱟᱜ ᱠᱚ',
    '🏨' => 'ᱦᱚᱴᱮᱞ',
    '🏩' => 'ᱫᱩᱞᱟᱹᱲ ᱦᱚᱴᱮᱞ',
    '🎈' => 'ᱯᱷᱩᱠᱟᱹ',
    '🏏' => 'ᱠᱨᱤᱠᱮᱴ ᱠᱷᱮᱞ',
    '🏸' => 'ᱵᱮᱰᱢᱤᱱᱴᱚᱱ',
    '👓' => 'ᱪᱚᱥᱢᱟ',
    '🕶' => 'ᱦᱮᱱᱫᱮ ᱪᱚᱥᱢᱟ',
    '🥽' => 'ᱢᱚᱴᱟ ᱪᱮᱥᱢᱟ',
    '🥼' => 'ᱞᱮᱯ ᱠᱚᱴ',
    '👕' => 'ᱥᱟᱴ',
    '👖' => 'ᱡᱤᱱᱥ',
    '👗' => 'ᱫᱚᱛᱚ',
    '🥻' => 'ᱥᱟᱹᱰᱤ',
    '👛' => 'ᱯᱚᱨᱥ',
    '👜' => 'ᱛᱤᱵᱮᱜᱽ',
    '🔔' => 'ᱜᱷᱚᱱᱴᱤ',
    '📱' => 'ᱢᱚᱵᱟᱭᱤᱞ ᱯᱷᱚᱱ',
    '🔋' => 'ᱵᱮᱴᱨᱭ',
    '🪫' => 'ᱠᱚᱢ ᱵᱮᱴᱨᱭ',
    '💻' => 'ᱞᱮᱯᱴᱚᱯ',
    '🖥' => 'ᱰᱮᱥᱠᱴᱚᱯ ᱠᱚᱢᱯᱩᱴᱚᱨ',
    '💣' => 'ᱵᱚᱢ',
    '🏧' => 'ATM ᱪᱤᱱᱦᱟᱹ',
    '🚼' => 'ᱜᱤᱫᱽᱨᱟᱹ ᱪᱤᱱᱦᱟᱹ',
    '⚠' => 'ᱦᱩᱥᱤᱭᱟᱹᱨ',
    '⛔' => 'ᱵᱚᱞᱚ ᱢᱟᱱᱟ ᱜᱮᱭᱟ',
    '🎦' => 'ᱥᱤᱱᱮᱢᱟ',
    '🏴' => 'ᱦᱮᱸᱫᱮ ᱪᱤᱨ',
    '🏳' => 'ᱯᱩᱸᱰ ᱪᱤᱨ',
];
