<?php

return [
    '👨‍👩‍👧‍👦' => 'familh : gwaz, maouez, placʼh, paotr',
    '👨‍👩‍👦‍👦' => 'familh : gwaz, maouez, paotr, paotr',
    '👨‍👩‍👧‍👧' => 'familh : gwaz, maouez, placʼh, placʼh',
    '👨‍👨‍👧‍👦' => 'familh : gwaz, gwaz, placʼh, paotr',
    '👨‍👨‍👦‍👦' => 'familh : gwaz, gwaz, paotr, paotr',
    '👨‍👨‍👧‍👧' => 'familh : gwaz, gwaz, placʼh, placʼh',
    '👩‍👩‍👧‍👦' => 'familh : maouez, maouez, placʼh, paotr',
    '👩‍👩‍👦‍👦' => 'familh : maouez, maouez, paotr, paotr',
    '👩‍👩‍👧‍👧' => 'familh : maouez, maouez, placʼh, placʼh',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'banniel : Bro-Saoz',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'banniel : Skos',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'banniel : Kembre',
    '👨‍👩‍👦' => 'familh : gwaz, maouez, paotr',
    '👨‍👩‍👧' => 'familh : gwaz, maouez, placʼh',
    '👨‍👨‍👦' => 'familh : gwaz, gwaz, paotr',
    '👨‍👨‍👧' => 'familh : gwaz, gwaz, placʼh',
    '👩‍👩‍👦' => 'familh : maouez, maouez, paotr',
    '👩‍👩‍👧' => 'familh : maouez, maouez, placʼh',
    '👨‍👦‍👦' => 'familh : gwaz, paotr, paotr',
    '👨‍👧‍👦' => 'familh : gwaz, placʼh, paotr',
    '👨‍👧‍👧' => 'familh : gwaz, placʼh, placʼh',
    '👩‍👦‍👦' => 'familh : maouez, paotr, paotr',
    '👩‍👧‍👦' => 'familh : maouez, placʼh, paotr',
    '👩‍👧‍👧' => 'familh : maouez, placʼh, placʼh',
    '🧑🏿‍🦰' => 'den deuet : krocʼhen teñval, blev ruz',
    '🧑🏿‍🦱' => 'den deuet : krocʼhen teñval, blev rodellek',
    '🧑🏿‍🦳' => 'den deuet : krocʼhen teñval, blev gwenn',
    '🧑🏿‍🦲' => 'den deuet : krocʼhen teñval, moal',
    '👱🏿‍♂' => 'melegan : krocʼhen teñval',
    '👨🏿‍🦰' => 'gwaz : krocʼhen teñval, blev ruz',
    '👨🏿‍🦱' => 'gwaz : krocʼhen teñval, blev rodellek',
    '👨🏿‍🦳' => 'gwaz : krocʼhen teñval, blev gwenn',
    '👨🏿‍🦲' => 'gwaz : krocʼhen teñval, moal',
    '👱🏿‍♀' => 'meleganez : krocʼhen teñval',
    '👩🏿‍🦰' => 'maouez : krocʼhen teñval, blev ruz',
    '👩🏿‍🦱' => 'maouez : krocʼhen teñval, blev rodellek',
    '👩🏿‍🦳' => 'maouez : krocʼhen teñval, blev gwenn',
    '👩🏿‍🦲' => 'maouez : krocʼhen teñval, moal',
    '👨🏿‍🎓' => 'studier : krocʼhen teñval',
    '👩🏿‍🎓' => 'studierez : krocʼhen teñval',
    '👨🏿‍🏫' => 'kelenner : krocʼhen teñval',
    '👩🏿‍🏫' => 'kelennerez : krocʼhen teñval',
    '👨🏿‍⚖' => 'barner : krocʼhen teñval',
    '👩🏿‍⚖' => 'barnerez : krocʼhen teñval',
    '👨🏿‍🌾' => 'labourer-douar : krocʼhen teñval',
    '👩🏿‍🌾' => 'labourerez-douar : krocʼhen teñval',
    '👨🏿‍🍳' => 'keginer : krocʼhen teñval',
    '👩🏿‍🍳' => 'keginerez : krocʼhen teñval',
    '👨🏿‍🏭' => 'micherour : krocʼhen teñval',
    '👩🏿‍🏭' => 'micherourez : krocʼhen teñval',
    '👨🏿‍💼' => 'implijad : krocʼhen teñval',
    '👩🏿‍💼' => 'implijadez : krocʼhen teñval',
    '👨🏿‍🔬' => 'skiantour : krocʼhen teñval',
    '👩🏿‍🔬' => 'skiantourez : krocʼhen teñval',
    '👨🏿‍💻' => 'stlennegour : krocʼhen teñval',
    '👩🏿‍💻' => 'stlennegourez : krocʼhen teñval',
    '🧑🏿‍🎤' => 'den a gan : krocʼhen teñval',
    '👨🏿‍🎤' => 'kaner : krocʼhen teñval',
    '👩🏿‍🎤' => 'kanerez : krocʼhen teñval',
    '👨🏿‍🎨' => 'arzour : krocʼhen teñval',
    '👩🏿‍🎨' => 'arzourez : krocʼhen teñval',
    '👨🏿‍✈' => 'levier : krocʼhen teñval',
    '👩🏿‍✈' => 'levierez : krocʼhen teñval',
    '👨🏿‍🚀' => 'astraer : krocʼhen teñval',
    '👩🏿‍🚀' => 'astraerez : krocʼhen teñval',
    '👨🏿‍🚒' => 'pomper : krocʼhen teñval',
    '👩🏿‍🚒' => 'pomperez : krocʼhen teñval',
    '👮🏿‍♂' => 'poliser : krocʼhen teñval',
    '👮🏿‍♀' => 'poliserez : krocʼhen teñval',
    '🕵🏿‍♂' => 'igounier : krocʼhen teñval',
    '🕵🏿‍♀' => 'igounierez : krocʼhen teñval',
    '🧙🏿‍♂' => 'hudour : krocʼhen teñval',
    '🧙🏿‍♀' => 'hudourez : krocʼhen teñval',
    '🧛🏿‍♂' => 'suner-gwad : krocʼhen teñval',
    '🧛🏿‍♀' => 'sunerez-gwad : krocʼhen teñval',
    '🧜🏿‍♂' => 'morgan : krocʼhen teñval',
    '🧜🏿‍♀' => 'morganez : krocʼhen teñval',
    '🧝🏿‍♂' => 'elf : krocʼhen teñval',
    '🧝🏿‍♀' => 'elfez : krocʼhen teñval',
    '🧑‍🦰' => 'den deuet : blev ruz',
    '🧑‍🦱' => 'den deuet : blev rodellek',
    '🧑‍🦳' => 'den deuet : blev gwenn',
    '🧑‍🦲' => 'den deuet : moal',
    '👨‍🦰' => 'gwaz : blev ruz',
    '👨‍🦱' => 'gwaz : blev rodellek',
    '👨‍🦳' => 'gwaz : blev gwenn',
    '👨‍🦲' => 'gwaz : moal',
    '👩‍🦰' => 'maouez : blev ruz',
    '👩‍🦱' => 'maouez : blev rodellek',
    '👩‍🦳' => 'maouez : blev gwenn',
    '👩‍🦲' => 'maouez : moal',
    '👨‍👦' => 'familh : gwaz, paotr',
    '👨‍👧' => 'familh : gwaz, placʼh',
    '👩‍👦' => 'familh : maouez, paotr',
    '👩‍👧' => 'familh : maouez, placʼh',
    '👱‍♂' => 'melegan',
    '👱‍♀' => 'meleganez',
    '👨‍🎓' => 'studier',
    '👩‍🎓' => 'studierez',
    '👨‍🏫' => 'kelenner',
    '👩‍🏫' => 'kelennerez',
    '👨‍⚖' => 'barner',
    '👩‍⚖' => 'barnerez',
    '👨‍🌾' => 'labourer-douar',
    '👩‍🌾' => 'labourerez-douar',
    '👨‍🍳' => 'keginer',
    '👩‍🍳' => 'keginerez',
    '👨‍🏭' => 'micherour',
    '👩‍🏭' => 'micherourez',
    '👨‍💼' => 'implijad',
    '👩‍💼' => 'implijadez',
    '👨‍🔬' => 'skiantour',
    '👩‍🔬' => 'skiantourez',
    '👨‍💻' => 'stlennegour',
    '👩‍💻' => 'stlennegourez',
    '🧑‍🎤' => 'den a gan',
    '👨‍🎤' => 'kaner',
    '👩‍🎤' => 'kanerez',
    '👨‍🎨' => 'arzour',
    '👩‍🎨' => 'arzourez',
    '👨‍✈' => 'levier',
    '👩‍✈' => 'levierez',
    '👨‍🚀' => 'astraer',
    '👩‍🚀' => 'astraerez',
    '👨‍🚒' => 'pomper',
    '👩‍🚒' => 'pomperez',
    '👮‍♂' => 'poliser',
    '👮‍♀' => 'poliserez',
    '🕵‍♂' => 'igounier',
    '🕵‍♀' => 'igounierez',
    '🧙‍♂' => 'hudour',
    '🧙‍♀' => 'hudourez',
    '🧛‍♂' => 'suner-gwad',
    '🧛‍♀' => 'sunerez-gwad',
    '🧜‍♂' => 'morgan',
    '🧜‍♀' => 'morganez',
    '🧝‍♂' => 'elf',
    '🧝‍♀' => 'elfez',
    '🧟‍♂' => 'zombi',
    '🧟‍♀' => 'zombiez',
    '🐈‍⬛' => 'kazh du',
    '🐻‍❄' => 'arzh gwenn',
    '🏳‍🌈' => 'banniel kanevedenn',
    '🏳‍⚧' => 'banniel treuzjener',
    '🏴‍☠' => 'banniel ar vorlaeron',
    '🤳🏿' => 'emboltred : krocʼhen teñval',
    '💪🏿' => 'kigenn daoubennek argrezet : krocʼhen teñval',
    '🦵🏿' => 'gar : krocʼhen teñval',
    '🦶🏿' => 'troad : krocʼhen teñval',
    '👂🏿' => 'skouarn : krocʼhen teñval',
    '👃🏿' => 'fri : krocʼhen teñval',
    '👶🏿' => 'babig : krocʼhen teñval',
    '🧒🏿' => 'bugel : krocʼhen teñval',
    '👦🏿' => 'paotr : krocʼhen teñval',
    '👧🏿' => 'placʼh : krocʼhen teñval',
    '🧑🏿' => 'den deuet : krocʼhen teñval',
    '👱🏿' => 'den melegan : krocʼhen teñval',
    '👨🏿' => 'gwaz : krocʼhen teñval',
    '👩🏿' => 'maouez : krocʼhen teñval',
    '🧓🏿' => 'den kozh : krocʼhen teñval',
    '👴🏿' => 'gwaz kozh : krocʼhen teñval',
    '👵🏿' => 'maouez kozh : krocʼhen teñval',
    '👮🏿' => 'polis : krocʼhen teñval',
    '🕵🏿' => 'igoun : krocʼhen teñval',
    '💂🏿' => 'gward : krocʼhen teñval',
    '🥷🏿' => 'ninja : krocʼhen teñval',
    '🤴🏿' => 'priñs : krocʼhen teñval',
    '👸🏿' => 'priñsez : krocʼhen teñval',
    '👼🏿' => 'babig ael : krocʼhen teñval',
    '🎅🏿' => 'Tad Nedeleg : krocʼhen teñval',
    '🤶🏿' => 'Mamm Nedeleg : krocʼhen teñval',
    '🦸🏿' => 'gourharoz : krocʼhen teñval',
    '🧙🏿' => 'maj : krocʼhen teñval',
    '🧚🏿' => 'boudig : krocʼhen teñval',
    '🧛🏿' => 'suner/ez-gwad : krocʼhen teñval',
    '🇦🇨' => 'banniel : Enez Ascension',
    '🇦🇩' => 'banniel : Andorra',
    '🇦🇪' => 'banniel : Emirelezhioù-Arab-Unanet',
    '🇦🇫' => 'banniel : Afghanistan',
    '🇦🇬' => 'banniel : Antigua-ha-Barbuda',
    '🇦🇮' => 'banniel : Anguilla',
    '🇦🇱' => 'banniel : Albania',
    '🇦🇲' => 'banniel : Armenia',
    '🇦🇴' => 'banniel : Angola',
    '🇦🇶' => 'banniel : Antarktika',
    '🇦🇷' => 'banniel : Arcʼhantina',
    '🇦🇸' => 'banniel : Samoa Amerikan',
    '🇦🇹' => 'banniel : Aostria',
    '🇦🇺' => 'banniel : Aostralia',
    '🇦🇼' => 'banniel : Aruba',
    '🇦🇽' => 'banniel : Inizi Åland',
    '🇦🇿' => 'banniel : Azerbaidjan',
    '🇧🇦' => 'banniel : Bosnia-ha-Herzegovina',
    '🇧🇧' => 'banniel : Barbados',
    '🇧🇩' => 'banniel : Bangladesh',
    '🇧🇪' => 'banniel : Belgia',
    '🇧🇫' => 'banniel : Burkina Faso',
    '🇧🇬' => 'banniel : Bulgaria',
    '🇧🇭' => 'banniel : Bahrein',
    '🇧🇮' => 'banniel : Burundi',
    '🇧🇯' => 'banniel : Benin',
    '🇧🇱' => 'banniel : Sant-Bertele',
    '🇧🇲' => 'banniel : Bermudez',
    '🇧🇳' => 'banniel : Brunei',
    '🇧🇴' => 'banniel : Bolivia',
    '🇧🇶' => 'banniel : Karib Nederlandat',
    '🇧🇷' => 'banniel : Brazil',
    '🇧🇸' => 'banniel : Bahamas',
    '🇧🇹' => 'banniel : Bhoutan',
    '🇧🇻' => 'banniel : Enez Bouvet',
    '🇧🇼' => 'banniel : Botswana',
    '🇧🇾' => 'banniel : Belarus',
    '🇧🇿' => 'banniel : Belize',
    '🇨🇦' => 'banniel : Kanada',
    '🇨🇨' => 'banniel : Inizi Kokoz',
    '🇨🇩' => 'banniel : Kongo - Kinshasa',
    '🇨🇫' => 'banniel : Republik Kreizafrikan',
    '🇨🇬' => 'banniel : Kongo - Brazzaville',
    '🇨🇭' => 'banniel : Suis',
    '🇨🇮' => 'banniel : Aod-an-Olifant',
    '🇨🇰' => 'banniel : Inizi Cook',
    '🇨🇱' => 'banniel : Chile',
    '🇨🇲' => 'banniel : Kameroun',
    '🇨🇳' => 'banniel : Sina',
    '🇨🇴' => 'banniel : Kolombia',
    '🇨🇵' => 'banniel : Enez Clipperton',
    '🇨🇶' => 'banniel : Sark',
    '🇨🇷' => 'banniel : Costa Rica',
    '🇨🇺' => 'banniel : Kuba',
    '🇨🇻' => 'banniel : Kab-Glas',
    '🇨🇼' => 'banniel : Curaçao',
    '🇨🇽' => 'banniel : Enez Christmas',
    '🇨🇾' => 'banniel : Kiprenez',
    '🇨🇿' => 'banniel : Tchekia',
    '🇩🇪' => 'banniel : Alamagn',
    '🇩🇬' => 'banniel : Diego Garcia',
    '🇩🇯' => 'banniel : Djibouti',
    '🇩🇰' => 'banniel : Danmark',
    '🇩🇲' => 'banniel : Dominica',
    '🇩🇴' => 'banniel : Republik Dominikan',
    '🇩🇿' => 'banniel : Aljeria',
    '🇪🇦' => 'banniel : Ceuta ha Melilla',
    '🇪🇨' => 'banniel : Ecuador',
    '🇪🇪' => 'banniel : Estonia',
    '🇪🇬' => 'banniel : Egipt',
    '🇪🇭' => 'banniel : Sahara ar Cʼhornôg',
    '🇪🇷' => 'banniel : Eritrea',
    '🇪🇸' => 'banniel : Spagn',
    '🇪🇹' => 'banniel : Etiopia',
    '🇪🇺' => 'banniel : Unaniezh Europa',
    '🇫🇮' => 'banniel : Finland',
    '🇫🇯' => 'banniel : Fidji',
    '🇫🇰' => 'banniel : Inizi Falkland',
    '🇫🇲' => 'banniel : Mikronezia',
    '🇫🇴' => 'banniel : Inizi Faero',
    '🇫🇷' => 'banniel : Frañs',
    '🇬🇦' => 'banniel : Gabon',
    '🇬🇧' => 'banniel : Rouantelezh-Unanet',
    '🇬🇩' => 'banniel : Grenada',
    '🇬🇪' => 'banniel : Jorjia',
    '🇬🇫' => 'banniel : Gwiana cʼhall',
    '🇬🇬' => 'banniel : Gwernenez',
    '🇬🇭' => 'banniel : Ghana',
    '🇬🇮' => 'banniel : Jibraltar',
    '🇬🇱' => 'banniel : Greunland',
    '🇬🇲' => 'banniel : Gambia',
    '🇬🇳' => 'banniel : Ginea',
    '🇬🇵' => 'banniel : Gwadeloup',
    '🇬🇶' => 'banniel : Ginea-ar-Cʼheheder',
    '🇬🇷' => 'banniel : Gres',
    '🇬🇸' => 'banniel : Inizi Georgia ar Su hag Inizi Sandwich ar Su',
    '🇬🇹' => 'banniel : Guatemala',
    '🇬🇺' => 'banniel : Guam',
    '🇬🇼' => 'banniel : Ginea-Bissau',
    '🇬🇾' => 'banniel : Guyana',
    '🇭🇰' => 'banniel : Hong Kong RMD Sina',
    '🇭🇲' => 'banniel : Inizi Heard-ha-McDonald',
    '🇭🇳' => 'banniel : Honduras',
    '🇭🇷' => 'banniel : Kroatia',
    '🇭🇹' => 'banniel : Haiti',
    '🇭🇺' => 'banniel : Hungaria',
    '🇮🇨' => 'banniel : Inizi Kanariez',
    '🇮🇩' => 'banniel : Indonezia',
    '🇮🇪' => 'banniel : Iwerzhon',
    '🇮🇱' => 'banniel : Israel',
    '🇮🇲' => 'banniel : Enez-Vanav',
    '🇮🇳' => 'banniel : India',
    '🇮🇴' => 'banniel : Tiriad breizhveurat Meurvor Indez',
    '🇮🇶' => 'banniel : Iraq',
    '🇮🇷' => 'banniel : Iran',
    '🇮🇸' => 'banniel : Island',
    '🇮🇹' => 'banniel : Italia',
    '🇯🇪' => 'banniel : Jerzenez',
    '🇯🇲' => 'banniel : Jamaika',
    '🇯🇴' => 'banniel : Jordania',
    '🇯🇵' => 'banniel : Japan',
    '🇰🇪' => 'banniel : Kenya',
    '🇰🇬' => 'banniel : Kyrgyzstan',
    '🇰🇭' => 'banniel : Kambodja',
    '🇰🇮' => 'banniel : Kiribati',
    '🇰🇲' => 'banniel : Komorez',
    '🇰🇳' => 'banniel : Saint Kitts-ha-Nevis',
    '🇰🇵' => 'banniel : Norzhkorea',
    '🇰🇷' => 'banniel : Sukorea',
    '🇰🇼' => 'banniel : Koweit',
    '🇰🇾' => 'banniel : Inizi Cayman',
    '🇰🇿' => 'banniel : Kazakstan',
    '🇱🇦' => 'banniel : Laos',
    '🇱🇧' => 'banniel : Liban',
    '🇱🇨' => 'banniel : Saint Lucia',
    '🇱🇮' => 'banniel : Liechtenstein',
    '🇱🇰' => 'banniel : Sri Lanka',
    '🇱🇷' => 'banniel : Liberia',
    '🇱🇸' => 'banniel : Lesotho',
    '🇱🇹' => 'banniel : Lituania',
    '🇱🇺' => 'banniel : Luksembourg',
    '🇱🇻' => 'banniel : Latvia',
    '🇱🇾' => 'banniel : Libia',
    '🇲🇦' => 'banniel : Maroko',
    '🇲🇨' => 'banniel : Monaco',
    '🇲🇩' => 'banniel : Moldova',
    '🇲🇪' => 'banniel : Montenegro',
    '🇲🇫' => 'banniel : Sant-Martin',
    '🇲🇬' => 'banniel : Madagaskar',
    '🇲🇭' => 'banniel : Inizi Marshall',
    '🇲🇰' => 'banniel : Makedonia an Norzh',
    '🇲🇱' => 'banniel : Mali',
    '🇲🇲' => 'banniel : Myanmar (Birmania)',
    '🇲🇳' => 'banniel : Mongolia',
    '🇲🇴' => 'banniel : Makao RMD Sina',
    '🇲🇵' => 'banniel : Inizi Mariana an Norzh',
    '🇲🇶' => 'banniel : Martinik',
    '🇲🇷' => 'banniel : Maouritania',
    '🇲🇸' => 'banniel : Montserrat',
    '🇲🇹' => 'banniel : Malta',
    '🇲🇺' => 'banniel : Moris',
    '🇲🇻' => 'banniel : Maldivez',
    '🇲🇼' => 'banniel : Malawi',
    '🇲🇽' => 'banniel : Mecʼhiko',
    '🇲🇾' => 'banniel : Malaysia',
    '🇲🇿' => 'banniel : Mozambik',
    '🇳🇦' => 'banniel : Namibia',
    '🇳🇨' => 'banniel : Kaledonia-Nevez',
    '🇳🇪' => 'banniel : Niger',
    '🇳🇫' => 'banniel : Enez Norfolk',
    '🇳🇬' => 'banniel : Nigeria',
    '🇳🇮' => 'banniel : Nicaragua',
    '🇳🇱' => 'banniel : Izelvroioù',
    '🇳🇴' => 'banniel : Norvegia',
    '🇳🇵' => 'banniel : Nepal',
    '🇳🇷' => 'banniel : Nauru',
    '🇳🇺' => 'banniel : Niue',
    '🇳🇿' => 'banniel : Zeland-Nevez',
    '🇴🇲' => 'banniel : Oman',
    '🇵🇦' => 'banniel : Panamá',
    '🇵🇪' => 'banniel : Perou',
    '🇵🇫' => 'banniel : Polinezia Cʼhall',
    '🇵🇬' => 'banniel : Papoua Ginea-Nevez',
    '🇵🇭' => 'banniel : Filipinez',
    '🇵🇰' => 'banniel : Pakistan',
    '🇵🇱' => 'banniel : Polonia',
    '🇵🇲' => 'banniel : Sant-Pêr-ha-Mikelon',
    '🇵🇳' => 'banniel : Enez Pitcairn',
    '🇵🇷' => 'banniel : Puerto Rico',
    '🇵🇸' => 'banniel : Tiriadoù Palestina',
    '🇵🇹' => 'banniel : Portugal',
    '🇵🇼' => 'banniel : Palau',
    '🇵🇾' => 'banniel : Paraguay',
    '🇶🇦' => 'banniel : Qatar',
    '🇷🇪' => 'banniel : Ar Reünion',
    '🇷🇴' => 'banniel : Roumania',
    '🇷🇸' => 'banniel : Serbia',
    '🇷🇺' => 'banniel : Rusia',
    '🇷🇼' => 'banniel : Rwanda',
    '🇸🇦' => 'banniel : Arabia Saoudat',
    '🇸🇧' => 'banniel : Inizi Salomon',
    '🇸🇨' => 'banniel : Sechelez',
    '🇸🇩' => 'banniel : Soudan',
    '🇸🇪' => 'banniel : Sveden',
    '🇸🇬' => 'banniel : Singapoura',
    '🇸🇭' => 'banniel : Saint-Helena',
    '🇸🇮' => 'banniel : Slovenia',
    '🇸🇯' => 'banniel : Svalbard',
    '🇸🇰' => 'banniel : Slovakia',
    '🇸🇱' => 'banniel : Sierra Leone',
    '🇸🇲' => 'banniel : San Marino',
    '🇸🇳' => 'banniel : Senegal',
    '🇸🇴' => 'banniel : Somalia',
    '🇸🇷' => 'banniel : Surinam',
    '🇸🇸' => 'banniel : Soudan ar Su',
    '🇸🇹' => 'banniel : São-Tomé-ha-Príncipe',
    '🇸🇻' => 'banniel : Salvador',
    '🇸🇽' => 'banniel : Sint Maarten',
    '🇸🇾' => 'banniel : Siria',
    '🇸🇿' => 'banniel : Eswatini',
    '🇹🇦' => 'banniel : Tristan da Cunha',
    '🇹🇨' => 'banniel : Inizi Turks-ha-Caicos',
    '🇹🇩' => 'banniel : Tchad',
    '🇹🇫' => 'banniel : Douaroù aostral Frañs',
    '🇹🇬' => 'banniel : Togo',
    '🇹🇭' => 'banniel : Thailand',
    '🇹🇯' => 'banniel : Tadjikistan',
    '🇹🇰' => 'banniel : Tokelau',
    '🇹🇱' => 'banniel : Timor-Leste',
    '🇹🇲' => 'banniel : Turkmenistan',
    '🇹🇳' => 'banniel : Tunizia',
    '🇹🇴' => 'banniel : Tonga',
    '🇹🇷' => 'banniel : Turkia',
    '🇹🇹' => 'banniel : Trinidad-ha-Tobago',
    '🇹🇻' => 'banniel : Tuvalu',
    '🇹🇼' => 'banniel : Taiwan',
    '🇹🇿' => 'banniel : Tanzania',
    '🇺🇦' => 'banniel : Ukraina',
    '🇺🇬' => 'banniel : Ouganda',
    '🇺🇲' => 'banniel : Inizi diabell ar Stadoù-Unanet',
    '🇺🇳' => 'banniel : Broadoù unanet',
    '🇺🇸' => 'banniel : Stadoù-Unanet',
    '🇺🇾' => 'banniel : Uruguay',
    '🇺🇿' => 'banniel : Ouzbekistan',
    '🇻🇦' => 'banniel : Vatikan',
    '🇻🇨' => 'banniel : Sant-Visant hag ar Grenadinez',
    '🇻🇪' => 'banniel : Venezuela',
    '🇻🇬' => 'banniel : Inizi Gwercʼh Breizh-Veur',
    '🇻🇮' => 'banniel : Inizi Gwercʼh ar Stadoù-Unanet',
    '🇻🇳' => 'banniel : Viêt Nam',
    '🇻🇺' => 'banniel : Vanuatu',
    '🇼🇫' => 'banniel : Wallis-ha-Futuna',
    '🇼🇸' => 'banniel : Samoa',
    '🇽🇰' => 'banniel : Kosovo',
    '🇾🇪' => 'banniel : Yemen',
    '🇾🇹' => 'banniel : Mayotte',
    '🇿🇦' => 'banniel : Suafrika',
    '🇿🇲' => 'banniel : Zambia',
    '🇿🇼' => 'banniel : Zimbabwe',
    '🏿' => 'krocʼhen teñval',
    '💀' => 'klopenn',
    '💩' => 'bern kaocʼh',
    '🤡' => 'penn furlukin',
    '👹' => 'roñfl',
    '👺' => 'gobilin',
    '👻' => 'tasmant',
    '👽' => 'ezdouarad',
    '👾' => 'euzhvil an egor',
    '🤖' => 'robot',
    '💕' => 'div galon',
    '💔' => 'kalon rannet',
    '❤' => 'kalon ruz',
    '🧡' => 'kalon orañjez',
    '💛' => 'kalon velen',
    '💚' => 'kalon wer',
    '💙' => 'kalon cʼhlas',
    '💜' => 'kalon limestra',
    '🤎' => 'kalon cʼhell',
    '🖤' => 'kalon zu',
    '🤍' => 'kalon wenn',
    '💯' => 'kant poent',
    '💥' => 'tarzhadenn',
    '🕳' => 'toull',
    '💤' => 'ZZZ',
    '🤳' => 'emboltred',
    '💪' => 'kigenn daoubennek argrezet',
    '🦾' => 'brecʼh vekanikel',
    '🦿' => 'gar vekanikel',
    '🦵' => 'gar',
    '🦶' => 'troad',
    '👂' => 'skouarn',
    '👃' => 'fri',
    '🧠' => 'empenn',
    '🫀' => 'kalon korfadurel',
    '🫁' => 'skevent',
    '🦷' => 'dant',
    '🦴' => 'askorn',
    '👀' => 'daoulagad',
    '👁' => 'lagad',
    '👅' => 'teod',
    '👶' => 'babig',
    '🧒' => 'bugel',
    '👦' => 'paotr',
    '👧' => 'placʼh',
    '🧑' => 'den deuet',
    '👱' => 'den melegan',
    '👨' => 'gwaz',
    '👩' => 'maouez',
    '🧓' => 'den kozh',
    '👴' => 'gwaz kozh',
    '👵' => 'maouez kozh',
    '👮' => 'polis',
    '🕵' => 'igoun',
    '💂' => 'gward',
    '🥷' => 'ninja',
    '🤴' => 'priñs',
    '👸' => 'priñsez',
    '👼' => 'babig ael',
    '🎅' => 'Tad Nedeleg',
    '🤶' => 'Mamm Nedeleg',
    '🦸' => 'gourharoz',
    '🧙' => 'maj',
    '🧚' => 'boudig',
    '🧛' => 'suner/ez-gwad',
    '👪' => 'familh',
    '🦰' => 'blev ruz',
    '🦱' => 'blev rodellek',
    '🦳' => 'blev gwenn',
    '🦲' => 'moal',
    '🐵' => 'penn marmouz',
    '🐒' => 'marmouz',
    '🦍' => 'gorilh',
    '🦧' => 'orangoutan',
    '🐶' => 'penn ki',
    '🐕' => 'ki',
    '🦮' => 'ki-heñchañ',
    '🐩' => 'ki rodellek',
    '🐺' => 'bleiz',
    '🦊' => 'louarn',
    '🦝' => 'rakoun',
    '🐱' => 'penn kazh',
    '🐈' => 'kazh',
    '🦁' => 'leon',
    '🐯' => 'penn tigr',
    '🐅' => 'tigr',
    '🐆' => 'loupard',
    '🐴' => 'penn marcʼh',
    '🐎' => 'marcʼh',
    '🦄' => 'unkorneg',
    '🦓' => 'roudenneg',
    '🦌' => 'karv',
    '🦬' => 'bizon',
    '🐮' => 'penn buocʼh',
    '🐂' => 'ejen',
    '🐃' => 'bual',
    '🐄' => 'buocʼh',
    '🐷' => 'penn mocʼh',
    '🐖' => 'pemocʼh',
    '🐗' => 'hocʼh gouez',
    '🐽' => 'moj',
    '🐏' => 'tourz',
    '🐑' => 'dañvad',
    '🐐' => 'gavr',
    '🐪' => 'dremedal',
    '🐫' => 'kañval',
    '🦙' => 'lama',
    '🦒' => 'jirafenn',
    '🐘' => 'olifant',
    '🦣' => 'mammout',
    '🦏' => 'frikorneg',
    '🦛' => 'dourvarc’h',
    '🐭' => 'penn logodenn',
    '🐁' => 'logodenn',
    '🐀' => 'razh',
    '🐹' => 'hamster',
    '🐰' => 'penn lapin',
    '🐇' => 'lapin',
    '🐿' => 'gwiñver',
    '🦫' => 'avank',
    '🦔' => 'heureuchin',
    '🦇' => 'logodenn-zall',
    '🐻' => 'arzh',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'lezireg',
    '🦦' => 'dourgi',
    '🦨' => 'skoñs',
    '🦘' => 'kangourou',
    '🦡' => 'brocʼh',
    '🐾' => 'loucʼhadoù pavioù',
    '🦃' => 'kog-Spagn',
    '🐔' => 'yar',
    '🐓' => 'kilhog',
    '🐤' => 'poñsin',
    '🐦' => 'evn',
    '🐧' => 'god',
    '🕊' => 'koulm',
    '🦅' => 'erer',
    '🦆' => 'houad',
    '🦢' => 'alarcʼh',
    '🦉' => 'kaouenn',
    '🦤' => 'dodo',
    '🪶' => 'pluenn',
    '🦩' => 'flammeg',
    '🦚' => 'paun',
    '🦜' => 'peroked',
    '🐸' => 'ran',
    '🐊' => 'krokodil',
    '🐢' => 'baot',
    '🦎' => 'glazard',
    '🐍' => 'naer',
    '🐲' => 'penn dragon',
    '🐉' => 'dragon',
    '🦕' => 'saoropod',
    '🦖' => 'tiranosaor roue',
    '🐋' => 'balum',
    '🐬' => 'delfin',
    '🫍' => 'skoazog',
    '🦭' => 'reunig',
    '🐟' => 'pesk',
    '🐠' => 'pesk trovanel',
    '🐡' => 'loar-vor',
    '🦈' => 'rinkin',
    '🐙' => 'morgazh',
    '🐚' => 'krogenn droellennek',
    '🦀' => 'krank',
    '🦞' => 'legestr',
    '🦐' => 'chevr',
    '🦑' => 'stivell',
    '🦪' => 'istr',
    '🐌' => 'maligorn',
    '🦋' => 'balafenn',
    '🐛' => 'biskoulenn',
    '🐜' => 'merienenn',
    '🐝' => 'gwenanenn',
    '🪲' => 'cʼhwil',
    '🐞' => 'buocʼhan',
    '🦗' => 'krank-raden',
    '🪳' => 'cʼhwil-du',
    '🕷' => 'kevnidenn',
    '🕸' => 'gwiad-kevnid',
    '🦂' => 'krug',
    '🦟' => 'moustik',
    '🪰' => 'kelienenn',
    '🪱' => 'buzhugenn',
    '🦠' => 'mikrob',
    '💐' => 'boked bleunioù',
    '🌸' => 'bleunienn gerez',
    '💮' => 'bleunienn wenn',
    '🏵' => 'rozetenn',
    '🌹' => 'rozenn',
    '🥀' => 'boked goeñvet',
    '🌺' => 'hibiskuz',
    '🌻' => 'tro-heol',
    '🌼' => 'broñs',
    '🌷' => 'tulipezenn',
    '🌱' => 'strujenn yaouank',
    '🪴' => 'plantenn podet',
    '🌲' => 'avalpineg',
    '🌳' => 'deliaoueg',
    '🌴' => 'gwez-palmez',
    '🌵' => 'kaktuz',
    '🌾' => 'plant riz',
    '🌿' => 'louzaouenn',
    '☘' => 'melchon',
    '🍀' => 'melchon peder',
    '🍁' => 'delienn skav-gwracʼh',
    '🍂' => 'delioù secʼh',
    '🍃' => 'delienn en avel',
    '🍄' => 'kabell-touseg',
    '🍇' => 'rezin',
    '🍈' => 'meloñs',
    '🍉' => 'pastekez',
    '🍊' => 'mandarin',
    '🍋' => 'sitroñs',
    '🍌' => 'bananez',
    '🍍' => 'ananaz',
    '🥭' => 'mangez',
    '🍎' => 'aval ruz',
    '🍏' => 'aval glas',
    '🍐' => 'per',
    '🍑' => 'pechez',
    '🍒' => 'kerez',
    '🍓' => 'sivi',
    '🫐' => 'lus',
    '🥝' => 'kiwi',
    '🍅' => 'tomatez',
    '🫒' => 'olivez',
    '🥥' => 'kraoñ-kokoz',
    '🥑' => 'avoukez',
    '🍆' => 'berjinez',
    '🥔' => 'aval-douar',
    '🥕' => 'karotez',
    '🌽' => 'penn-maiz',
    '🌶' => 'pimant ruz',
    '🫑' => 'skilbebr',
    '🥒' => 'kokombrez',
    '🥬' => 'legumaj glas',
    '🥦' => 'brikoli',
    '🧄' => 'kignen',
    '🧅' => 'ognon',
    '🥜' => 'kakaouetez',
    '🌰' => 'kistin',
    '🍞' => 'bara',
    '🥐' => 'kornegenn',
    '🥖' => 'baget',
    '🫓' => 'galetez',
    '🥨' => 'bretzel',
    '🥯' => 'bagel',
    '🥞' => 'krampouezh',
    '🧇' => 'galfrez',
    '🧀' => 'tamm formaj-laezh',
    '🍖' => 'kig war askorn',
    '🍗' => 'morzhed yar',
    '🥩' => 'tamm kig',
    '🥓' => 'bacon',
    '🍔' => 'hamburger',
    '🍟' => 'fritez',
    '🍕' => 'pizza',
    '🌭' => 'hot-dog',
    '🥪' => 'sandwich',
    '🌮' => 'tako',
    '🌯' => 'burrito',
    '🫔' => 'tamal',
    '🥙' => 'kebab',
    '🧆' => 'falafel',
    '🥚' => 'vi',
    '🍳' => 'vi war ar plad',
    '🥘' => 'meuz mitonet',
    '🍲' => 'pothouarnad',
    '🫕' => 'teuzadell',
    '🥣' => 'bolennad gant loa',
    '🥗' => 'saladenn',
    '🍿' => 'popcorn',
    '🧈' => 'amann',
    '🧂' => 'holen',
    '🥫' => 'boued-mir',
    '🍱' => 'bento',
    '🍘' => 'galetez riz',
    '🍙' => 'boulig riz',
    '🍚' => 'bolennad riz',
    '🍛' => 'riz dre gari',
    '🍜' => 'bolennad tomm',
    '🍝' => 'spaghetti',
    '🍠' => 'patatez dous rostet',
    '🍢' => 'beriad pesked',
    '🍣' => 'sushi',
    '🍤' => 'bignez chevr',
    '🍥' => 'krokedenn besked',
    '🥮' => 'gwastell-loar',
    '🍡' => 'beriad madigoù',
    '🥟' => 'pouloud',
    '🍦' => 'dienn-skorn mod Italia',
    '🍧' => 'greunitad',
    '🍨' => 'dienn-skorn',
    '🍩' => 'donut',
    '🍪' => 'cookie',
    '🎂' => 'gwastell deiz-ha-bloaz',
    '🍰' => 'sablegenn',
    '🧁' => 'gwastellig',
    '🥧' => 'tartezenn',
    '🍫' => 'barrenn chokolad',
    '🍬' => 'madig',
    '🍭' => 'sunig',
    '🍮' => 'dienn war e cʼhenoù',
    '🍯' => 'podad mel',
    '🍼' => 'bured',
    '🥛' => 'gwerennad laezh',
    '☕' => 'evaj tomm',
    '🫖' => 'pod-te',
    '🍵' => 'tasenn',
    '🍶' => 'sake',
    '🍾' => 'boutailhad champagn',
    '🍷' => 'gwerennad gwin',
    '🍸' => 'koktel',
    '🍹' => 'koktel trovanel',
    '🍺' => 'chopad bier',
    '🍻' => 'chopadoù bier',
    '🥤' => 'gobeled gant plouzenn',
    '🧃' => 'brikennigad evaj',
    '🧉' => 'mate',
    '🧊' => 'skornenn',
    '🥢' => 'bizhier',
    '🍽' => 'kontell ha fourchetez gant asied',
    '🍴' => 'kontell ha fourchetez',
    '🥄' => 'loa',
    '🔪' => 'kontell-gegin',
    '🏺' => 'añforenn',
    '🌍' => 'boul douar o tiskouez Europa hag Afrika',
    '🌎' => 'boul douar o tiskouez Amerika',
    '🌏' => 'boul douar o tiskouez Azia hag Aostralia',
    '🌐' => 'boul douar gant hedredennoù',
    '🗺' => 'kartenn ar bed',
    '🗾' => 'kartenn Japan',
    '🧭' => 'nadoz-vor',
    '🏔' => 'menez ercʼhek',
    '⛰' => 'menez',
    '🛘' => 'riskladur douar',
    '🌋' => 'menez-tan',
    '🗻' => 'menez Fuji',
    '🏕' => 'kampiñ',
    '🏖' => 'traezhenn gant disheolier',
    '🏜' => 'dezerzh',
    '🏝' => 'enezenn didud',
    '🏞' => 'park broadel',
    '🏟' => 'stad',
    '🏛' => 'savadur klasel',
    '🏗' => 'savadur war sevel',
    '🧱' => 'brikenn',
    '🪨' => 'rocʼh',
    '🪵' => 'koad',
    '🛖' => 'foukenn',
    '🏘' => 'tiez',
    '🏚' => 'ti dilezet',
    '🏠' => 'ti',
    '🏡' => 'ti ha liorzh',
    '🏢' => 'savadur burevioù',
    '🏣' => 'ti-post japanat',
    '🏤' => 'ti-post',
    '🏥' => 'ospital',
    '🏦' => 'bank',
    '🏨' => 'leti',
    '🏩' => 'love hotel',
    '🏪' => 'gourstalig',
    '🏫' => 'skol',
    '🏬' => 'stal vras',
    '🏭' => 'labouradeg',
    '🏯' => 'kastell japanat',
    '🏰' => 'kastell',
    '💒' => 'eured',
    '🗼' => 'tour Tokyo',
    '🗽' => 'delwenn ar Frankiz',
    '⛪' => 'iliz',
    '🕌' => 'moskeenn',
    '🛕' => 'templ hindou',
    '🕍' => 'sinagogenn',
    '⛩' => 'santual shinto',
    '🕋' => 'kaaba',
    '⛲' => 'feunteun',
    '⛺' => 'teltenn',
    '🌁' => 'brumennek',
    '🌃' => 'stergann',
    '🏙' => 'gweledva kêr',
    '🌄' => 'sav-heol war ar menezioù',
    '🌅' => 'sav-heol',
    '🌆' => 'gweledva kêr da serr-noz',
    '🌇' => 'kuzh-heol',
    '🌉' => 'pont en noz',
    '♨' => 'andon tomm',
    '🎠' => 'kazeg-vezevenn',
    '🎡' => 'rod vras',
    '🎢' => 'sav-diskenn',
    '💈' => 'barr-ti barver',
    '🎪' => 'pabell sirk',
    '🚂' => 'stlejerez',
    '🚃' => 'bagon',
    '🚄' => 'TTB',
    '🚅' => 'tren tizh bras',
    '🚆' => 'tren',
    '🚇' => 'metro',
    '🚈' => 'metro skañv',
    '🚉' => 'porzh-houarn',
    '🚊' => 'tramgarr',
    '🚝' => 'unroudenn',
    '🚞' => 'tren ar menezioù',
    '🚋' => 'bagon tramgarr',
    '🚌' => 'bus',
    '🚎' => 'trollebus',
    '🚐' => 'minibus',
    '🚑' => 'ambulañs',
    '🚒' => 'sammgarr pomperien',
    '🚓' => 'karr polis',
    '🚕' => 'taksi',
    '🚗' => 'karr-tan',
    '🚚' => 'karr-samm degas',
    '🚛' => 'sammgarr-ramoker',
    '🚜' => 'traktor',
    '🏍' => 'marcʼh-tan',
    '🛵' => 'skouter',
    '🛴' => 'troterez',
    '🛹' => 'plankenn-ruilh',
    '🛼' => 'botez-ruilh',
    '🚏' => 'arsav bus',
    '🛣' => 'gourhent',
    '🛤' => 'hent-houarn',
    '🛢' => 'barilhad tireoul',
    '⛽' => 'plomenn strilheoul',
    '🚨' => 'letern-tro',
    '⚓' => 'eor',
    '⛵' => 'gouelier',
    '🛶' => 'kanoe',
    '🚤' => 'bag herrek',
    '🛳' => 'mordreizher',
    '⛴' => 'lestr-treizh',
    '🛥' => 'bag-a-dan',
    '🚢' => 'lestr',
    '✈' => 'karr-nij',
    '🛩' => 'karr-nij bihan',
    '🪂' => 'harz-lamm',
    '💺' => 'azezenn',
    '🚁' => 'biñsaskell',
    '🚟' => 'fundren',
    '🚠' => 'fungarr',
    '🚡' => 'fundramgarr',
    '🛰' => 'loarell',
    '🚀' => 'fuzeenn',
    '🛸' => 'pladenn-nij',
    '🛎' => 'sonerez kontouer',
    '🧳' => 'bagaj',
    '⌛' => 'eurier-traezh',
    '⌚' => 'montr',
    '⏰' => 'dihuner',
    '⏱' => 'kronometr',
    '⏲' => 'horolaj',
    '🕰' => 'pandulenn',
    '🕛' => 'kreisteiz/hanternoz',
    '🕧' => 'kreisteiz/hanternoz hanter',
    '🕐' => 'un eur',
    '🕜' => 'un eur hanter',
    '🕑' => 'div eur',
    '🕝' => 'div eur hanter',
    '🕒' => 'teir eur',
    '🕞' => 'teir eur hanter',
    '🕓' => 'peder eur',
    '🕟' => 'peder eur hanter',
    '🕔' => 'pemp eur',
    '🕠' => 'pemp eur hanter',
    '🕕' => 'cʼhwecʼh eur',
    '🕡' => 'cʼhwecʼh eur hanter',
    '🕖' => 'seizh eur',
    '🕢' => 'seizh eur hanter',
    '🕗' => 'eizh eur',
    '🕣' => 'eizh eur hanter',
    '🕘' => 'nav eur',
    '🕤' => 'nav eur hanter',
    '🕙' => 'dek eur',
    '🕥' => 'dek eur hanter',
    '🕚' => 'unnek eur',
    '🕦' => 'unnek eur hanter',
    '🌑' => 'loar nevez',
    '🌒' => 'loar vihan ar cʼhresk',
    '🌓' => 'hanterloar ar cʼhresk',
    '🌔' => 'loar vras ar c’hresk',
    '🌕' => 'loargann',
    '🌖' => 'loar vras an digresk',
    '🌗' => 'hanterloar an digresk',
    '🌘' => 'loar vihan an digresk',
    '🌙' => 'kreskenn loar',
    '🌚' => 'penn loar nevez',
    '🌛' => 'penn loar vihan ar cʼhresk',
    '🌜' => 'penn loar vihan an digresk',
    '🌡' => 'gwerzverker',
    '☀' => 'heol',
    '🌝' => 'penn loargann',
    '🌞' => 'penn heol',
    '🪐' => 'planedenn gant gwalennoù',
    '⭐' => 'steredenn',
    '🌟' => 'steredenn skedus',
    '🌠' => 'steredenn-dared',
    '🌌' => 'Hent-sant-Jakez',
    '☁' => 'koumoulenn',
    '⛅' => 'heol a-dreñv dʼar cʼhoumoul',
    '⛈' => 'koumoulenn gant lucʼhedenn ha glav',
    '🌤' => 'heol a-dreñv dʼur goumoulennig',
    '🌥' => 'heol a-dreñv dʼur goumoulenn vras',
    '🌦' => 'heol a-dreñv dʼur goumoulenn cʼhlav',
    '🌧' => 'koumoulenn gant glav',
    '🌨' => 'koumoulenn gant ercʼh',
    '🌩' => 'koumoulenn gant lucʼhedenn',
    '🌪' => 'tornadenn',
    '🌫' => 'latar',
    '🌀' => 'kelcʼhwidenn',
    '🌈' => 'kanevedenn',
    '🌂' => 'disglavier serr',
    '☂' => 'disglavier',
    '☔' => 'disglavier gant glav',
    '⛱' => 'disheolier',
    '⚡' => 'tredanvarr uhel',
    '❄' => 'malzenn ercʼh',
    '☃' => 'boulom ercʼh gant ercʼh',
    '⛄' => 'boulom ercʼh hep ercʼh',
    '☄' => 'kometenn',
    '🔥' => 'tan',
    '💧' => 'takenn',
    '🌊' => 'gwagenn',
    '🎃' => 'jack-oʼ-lantern',
    '🎄' => 'gwezenn Nedeleg',
    '🎆' => 'tan-arvest',
    '🎇' => 'piled-hud',
    '🧨' => 'strakerez',
    '✨' => 'fulennoù',
    '🎈' => 'cʼhwezigell',
    '🎉' => 'kotilhon',
    '🎊' => 'koñfeti',
    '🎋' => 'gwez-hetoù',
    '🎍' => 'kadomatsu',
    '🎎' => 'poupinelloù japanat',
    '🎏' => 'koinobori',
    '🎐' => 'karilhon-avel',
    '🎑' => 'lid al loar',
    '🧧' => 'golo ruz',
    '🎀' => 'seizenn',
    '🎁' => 'prof',
    '🎗' => 'seizenn-goun',
    '🎟' => 'bilhed mont e-barzh',
    '🎫' => 'bilhed',
    '🎖' => 'medalenn vilourel',
    '🏆' => 'trofe',
    '🏅' => 'medalenn sport',
    '🥇' => 'medalenn aour',
    '🥈' => 'medalenn arcʼhant',
    '🥉' => 'medalenn arem',
    '⚽' => 'mell fobal',
    '⚾' => 'baseball',
    '🥎' => 'softball',
    '🏀' => 'basket-ball',
    '🏐' => 'volley-ball',
    '🏈' => 'fobal amerikan',
    '🏉' => 'rugbi',
    '🎾' => 'tennis',
    '🥏' => 'frizbi',
    '🎳' => 'bowling',
    '🏏' => 'kriked',
    '🏑' => 'hoke war leton',
    '🏒' => 'hoke war skorn',
    '🥍' => 'cʼhoari-horell',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'maneg boks',
    '🥋' => 'dilhad arzoù-emgannañ',
    '🥅' => 'kaoued-pal',
    '⛳' => 'bannielig golf',
    '⛸' => 'botez-ruzikat',
    '🎣' => 'lazheta',
    '🤿' => 'maskl-splujañ',
    '🎽' => 'krez redek',
    '🎿' => 'ski',
    '🛷' => 'luj',
    '🥌' => 'maen curling',
    '🎯' => 'ober mil',
    '🪀' => 'pun-dibun',
    '🪁' => 'sarpant-nij',
    '🔫' => 'pistolenn',
    '🎱' => 'bilhard saoz',
    '🔮' => 'boulenn strink',
    '🪄' => 'gwialenn-hud',
    '🎮' => 'cʼhoari video',
    '🕹' => 'lanker cʼhoari',
    '🎲' => 'diñs',
    '🧩' => 'miltamm',
    '🧸' => 'arzh-feur',
    '🪅' => 'piñata',
    '🪆' => 'matriochka',
    '♠' => 'pikez',
    '♥' => 'keur',
    '♦' => 'karo',
    '♣' => 'treflez',
    '♟' => 'pezh echedoù',
    '🃏' => 'joker',
    '🎭' => 'arvestoù bev',
    '🖼' => 'skeudenn sterniet',
    '🎨' => 'pladennad livioù',
    '🧵' => 'kanellad neud',
    '🪡' => 'nadoz da wriat',
    '🧶' => 'pellenn neud',
    '🪢' => 'skoulm',
    '👓' => 'lunedoù gwelet',
    '🕶' => 'lunedoù-heol',
    '🥽' => 'lunedoù-kouronkañ',
    '🥼' => 'flotantenn wenn',
    '🦺' => 'jiletenn surentez',
    '👔' => 'kravatenn',
    '👕' => 'tee-shirt',
    '👖' => 'jeanʼs',
    '🧣' => 'skerb',
    '🧤' => 'manegoù',
    '🧥' => 'mantell',
    '🧦' => 'loeroù',
    '👗' => 'sae',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'sae-gouronkañ unpezh',
    '🩲' => 'slip',
    '🩳' => 'bragoù-berr',
    '👙' => 'bikini',
    '👚' => 'dilhad mercʼhed',
    '👛' => 'doug-moneiz',
    '👜' => 'sacʼh-dorn',
    '👝' => 'godellig',
    '🛍' => 'seier kabas',
    '🎒' => 'sacʼh-kein',
    '🩴' => 'tong',
    '👟' => 'botez sport',
    '🥾' => 'botez bale',
    '👠' => 'skarpin',
    '👑' => 'kurunenn',
    '🎩' => 'tog moull uhel',
    '🎓' => 'tok skol-veur',
    '🧢' => 'kasketenn amerikan',
    '🪖' => 'tokarn soudard',
    '⛑' => 'tokarn sikourer',
    '📿' => 'chapeled',
    '💄' => 'ruz-muzelloù',
    '💍' => 'gwalenn',
    '💎' => 'maen prizius',
    '🔇' => 'mut',
    '📢' => 'uhelgomzer',
    '📣' => 'korn-mouezh',
    '📯' => 'korn ar paotr-marc’h',
    '🔔' => 'kloc’h',
    '🎼' => 'skrid-sonerezh',
    '🎵' => 'notenn sonerezh',
    '🎶' => 'notennoù sonerezh',
    '🎙' => 'mikrofon studio',
    '🎤' => 'mikrofon',
    '🎧' => 'selaouelloù',
    '📻' => 'skingomzer',
    '🎷' => 'saksofon',
    '🎺' => 'trompilh',
    '🪊' => 'trombon',
    '🪗' => 'akordeoñs',
    '🎸' => 'gitar',
    '🎹' => 'klavier sonerezh',
    '🎻' => 'violoñs',
    '🪕' => 'banjo',
    '🥁' => 'taboulin',
    '🪘' => 'djembe',
    '📱' => 'pellgomzer hezoug',
    '📲' => 'pellgomzer hezoug gant bir',
    '☎' => 'pellgomzer',
    '📞' => 'yevenn bellgomz',
    '📟' => 'galver',
    '📠' => 'pelleiler',
    '🔋' => 'pil',
    '🔌' => 'sankell dredan',
    '💻' => 'urzhiataer hezoug',
    '🖥' => 'urzhiataer burev',
    '🖨' => 'moullerez',
    '⌨' => 'klavier',
    '🖱' => 'logodenn urzhiataer',
    '💽' => 'pladenn urzhiater',
    '💾' => 'pladennig',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🧮' => 'boulaoueg',
    '🎥' => 'kamera',
    '🎞' => 'kocʼhenn',
    '📽' => 'lucʼhvanner',
    '🎬' => 'klek',
    '📺' => 'skinwel',
    '📷' => 'lucʼhskeudennerez',
    '📸' => 'lucʼhskeudennerez gant lucʼheder',
    '📹' => 'kamenroller',
    '📼' => 'kasedig-video',
    '🔍' => 'gwerenn-greskiñ a-gleiz',
    '🔎' => 'gwerenn-greskiñ a-zehoù',
    '🕯' => 'goulaouenn',
    '💡' => 'klogorenn',
    '🔦' => 'etev-goulaouiñ',
    '🏮' => 'lampig ruz',
    '🪔' => 'diya',
    '📔' => 'karned gant golo kinklet',
    '📕' => 'levr serr',
    '📖' => 'levr digor',
    '📗' => 'levr gwer',
    '📘' => 'levr glas',
    '📙' => 'levr orañjez',
    '📚' => 'levrioù',
    '📓' => 'karned',
    '📒' => 'marilh',
    '📃' => 'pajenn rollet',
    '📜' => 'parchenn',
    '📄' => 'pajenn',
    '📰' => 'kazetenn',
    '🗞' => 'kazetenn rollet',
    '📑' => 'sinedoù',
    '🔖' => 'merk-pajenn',
    '🏷' => 'tikedenn',
    '🪙' => 'pezh moneiz',
    '💰' => 'sacʼhad moneiz',
    '💴' => 'bilhed e yenoù',
    '💵' => 'bilhed e dollaroù',
    '💶' => 'bilhed en euroioù',
    '💷' => 'bilhed e lurioù',
    '💸' => 'moneiz o nijal',
    '💳' => 'kartenn-vank',
    '🧾' => 'skrid-degemer',
    '💹' => 'krommenn kreskiñ ar yen',
    '✉' => 'golo-lizher',
    '📧' => 'postel',
    '📦' => 'pakad',
    '📮' => 'boest-lizheroù ar post',
    '🗳' => 'mouezharcʼh',
    '✏' => 'kreion',
    '✒' => 'stilo pluenn du',
    '🖋' => 'stilo pluenn',
    '🖊' => 'stilo',
    '🖌' => 'barr-livañ',
    '🖍' => 'kreion pastel',
    '📝' => 'notennoù personel',
    '💼' => 'sakochenn',
    '📁' => 'kleurenn',
    '📂' => 'kleurenn digor',
    '🗂' => 'dispartier',
    '📅' => 'deiziadur',
    '📆' => 'deiziadur efemerid',
    '🗒' => 'blocʼh-notennoù gant troellennoù',
    '🗓' => 'deiziadur gant troellennoù',
    '📇' => 'karned chomlecʼhioù',
    '📈' => 'krommenn kreskiñ',
    '📉' => 'krommenn digreskiñ',
    '📊' => 'diagramm barrennoù',
    '📌' => 'tach-meud',
    '📍' => 'tach-meud ront',
    '📎' => 'strobell',
    '🖇' => 'strobelloù',
    '📏' => 'reolenn',
    '📐' => 'skouer',
    '✂' => 'sizailhoù',
    '🗑' => 'kest ar paper',
    '🔒' => 'kadranas serr',
    '🔓' => 'kadranas digor',
    '🔏' => 'kadranas serr gant stilo',
    '🔐' => 'kadranas serr gant alcʼhwez',
    '🔑' => 'alcʼhwez',
    '🗝' => 'alcʼhwez kozh',
    '🔨' => 'morzhol',
    '🪓' => 'boucʼhal',
    '⛏' => 'pigell',
    '⚒' => 'morzhol ha pig',
    '🛠' => 'morzhol hag alcʼhwez plat',
    '🗡' => 'badalenn',
    '⚔' => 'klezeier kroaziet',
    '💣' => 'bombezenn',
    '🪃' => 'boumerang',
    '🏹' => 'gwareg ha saezh',
    '🛡' => 'skoed',
    '🪚' => 'heskenn',
    '🔧' => 'alcʼhwez plat',
    '🪛' => 'troer-biñsoù',
    '🔩' => 'biñs ha kraouenn',
    '⚙' => 'rod dantek',
    '🗜' => 'serjant',
    '⚖' => 'balañs',
    '🔗' => 'mailh',
    '⛓' => 'chadennoù',
    '🪝' => 'krog',
    '🧰' => 'boest-ostilhoù',
    '🧲' => 'gwarell',
    '🪜' => 'skeul',
    '⚗' => 'lambig',
    '🧪' => 'pibenn amprou',
    '🧫' => 'boest Petri',
    '🧬' => 'TDN',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'stign loarell',
    '💉' => 'strinkell',
    '🩸' => 'takenn wad',
    '💊' => 'pilulenn',
    '🩹' => 'lienad-peg',
    '🩺' => 'stetoskop',
    '🚪' => 'dor',
    '🛗' => 'pignerez',
    '🪞' => 'melezour',
    '🪟' => 'prenestr',
    '🛏' => 'gwele',
    '🛋' => 'gourvezvank ha lamp',
    '🪑' => 'kador',
    '🚽' => 'privezioù',
    '🪠' => 'mandoz',
    '🚿' => 'strinkerez',
    '🛁' => 'kibell',
    '🪤' => 'logotouer',
    '🪒' => 'aotenn',
    '🧴' => 'boutailhad golcʼhad',
    '🧷' => 'spilhenn-alcʼhwez',
    '🧹' => 'skubellenn',
    '🧺' => 'paner',
    '🧻' => 'roll paper',
    '🪣' => 'sailh',
    '🧼' => 'soavon',
    '🪥' => 'broust-dent',
    '🧽' => 'spoueenn',
    '🧯' => 'mouger-tan',
    '🛒' => 'karrigell',
    '🚬' => 'sigaretenn',
    '⚰' => 'charke',
    '🪦' => 'maen-bez',
    '⚱' => 'jarl-kañv',
    '🧿' => 'amuzetez nazar',
    '🗿' => 'moai',
    '🏧' => 'arlun bilhedaouer',
    '🚮' => 'arlun pod-lastez',
    '🚰' => 'dour mat da evañ',
    '♿' => 'arouez kador-ruilh',
    '🚹' => 'privezioù paotred',
    '🚺' => 'privezioù mercʼhed',
    '🚻' => 'golcʼhiri',
    '🚼' => 'arouez babig',
    '🚾' => 'WC',
    '🛂' => 'kontroll paseporzhioù',
    '🛃' => 'maltouterezh',
    '🛄' => 'adtapout bagajoù',
    '🛅' => 'fizlecʼh',
    '⚠' => 'diwall',
    '🚸' => 'bugale o treuziñ',
    '⛔' => 'tu berzet',
    '🚫' => 'berzet',
    '🚳' => 'beloioù difennet',
    '🚭' => 'arabat butunat',
    '🚯' => 'arabat lakaat lastez',
    '🚱' => 'dour fall da evañ',
    '🚷' => 'difennet dʼar gerzhourien',
    '📵' => 'pellgomzerioù difennet',
    '☢' => 'skinoberiek',
    '☣' => 'riskl bevoniel',
    '🛐' => 'lec’h azeuliñ',
    '⚛' => 'arouez an atom',
    '🕉' => 'om',
    '✡' => 'steredenn David',
    '☸' => 'rod an dharma',
    '☯' => 'yin yang',
    '✝' => 'kroaz latin',
    '☦' => 'kroaz ortodoks',
    '☪' => 'steredenn ha kreskenn',
    '☮' => 'arouez ar peocʼh',
    '🕎' => 'menorah',
    '🔯' => 'steredenn cʼhwecʼh brecʼh',
    '♈' => 'an Tourz',
    '♉' => 'an Tarv',
    '♊' => 'ar Gevelled',
    '♋' => 'ar Cʼhrank',
    '♌' => 'al Leon',
    '♍' => 'ar Wercʼhez',
    '♎' => 'ar Balañsoù',
    '♏' => 'ar Grug',
    '♐' => 'ar Saezhataer',
    '♑' => 'ar Cʼhavr',
    '♒' => 'ar Skuilher-dour',
    '♓' => 'ar Pesked',
    '⛎' => 'Naeretaer',
    '🔀' => 'bouton lenn mell-divell',
    '🔁' => 'bouton lenn en-dro',
    '▶' => 'bouton lenn',
    '🎦' => 'sinema',
    '📳' => 'mod froumer',
    '📴' => 'pellgomzer lazhet',
    '♀' => 'arouez ar mercʼhed',
    '♂' => 'arouez ar paotred',
    '⚧' => 'arouez treuzjener',
    '✖' => 'liesaat',
    '➕' => 'mui',
    '➖' => 'nemet',
    '➗' => 'rannañ',
    '♾' => 'anfin',
    '‼' => 'pik-estlamm doubl',
    '⁉' => 'pik-goulenn estlamm',
    '❓' => 'pik-goulenn ruz',
    '❔' => 'pik-goulenn gwenn',
    '❕' => 'pik-estlamm gwenn',
    '❗' => 'pik-estlamm ruz',
    '⚕' => 'naerwialenn',
    '♻' => 'arouez adaozañ',
    '⚜' => 'flourdiliz',
    '🔱' => 'tridant',
    '📛' => 'badj-anv',
    '🔰' => 'arouez japanat evit an deraouidi',
    '⭕' => 'kelcʼh ruz',
    '✅' => 'bouton askañ',
    '☑' => 'log asket',
    '✔' => 'ask',
    '❌' => 'kroaz',
    '❎' => 'bouton kroaz',
    '➰' => 'boukl',
    '➿' => 'boukl doubl',
    '〽' => 'pebeilad',
    '✳' => 'steredennig eizh brecʼh',
    '✴' => 'steredenn eizh brecʼh',
    '❇' => 'strinkad',
    '™' => 'merk kenwerzhel marilhet',
    '🔠' => 'bizskriv pennlizherennoù latin',
    '🔡' => 'bizskriv lizherennoù bihan latin',
    '🔢' => 'bizskriv niveroù',
    '🔣' => 'bizskriv arouezioù',
    '🔤' => 'bizskriv lizherennoù latin',
    '🅰' => 'bouton A (rumm-gwad)',
    '🆎' => 'bouton AB (rumm-gwad)',
    '🅱' => 'bouton B (rumm-gwad)',
    '🆑' => 'bouton Diverkañ',
    '🆒' => 'bouton Cool',
    '🆓' => 'bouton Digoust',
    'ℹ' => 'titouroù',
    '🆔' => 'bouton Anaouder',
    'Ⓜ' => 'M kelcʼhiet',
    '🆕' => 'bouton Nevez',
    '🅾' => 'bouton O (rumm-gwad)',
    '🆗' => 'bouton OK',
    '🅿' => 'bouton P',
    '🆘' => 'bouton SOS',
    '🆚' => 'bouton VS',
    '🈁' => 'bouton "amañ" e japaneg',
    '🈚' => 'bouton "digoust" e japaneg',
    '🈲' => 'bouton "difennet" e japaneg',
    '㊗' => 'bouton "gourcʼhemennoù" e japaneg',
    '🟥' => 'karrez ruz',
    '🟧' => 'karrez orañjez',
    '🟨' => 'karrez melen',
    '🟩' => 'karrez gwer',
    '🟦' => 'karrez glas',
    '🟪' => 'karrez limestra',
    '🟫' => 'karrez gell',
    '⬛' => 'karrez bras du',
    '⬜' => 'karrez bras gwenn',
    '◼' => 'karrez etre du',
    '◻' => 'karrez etre gwenn',
    '▪' => 'karrez bihan du',
    '▫' => 'karrez bihan gwenn',
    '🔶' => 'romb bras orañjez',
    '🔷' => 'romb bras glas',
    '🔸' => 'romb bihan orañjez',
    '🔹' => 'romb bihan glas',
    '🔘' => 'bouton radio',
    '🏁' => 'banniel karrezek',
    '🚩' => 'banniel tricʼhornek',
    '🎌' => 'bannieloù kroaziet',
    '🏴' => 'banniel du',
    '🏳' => 'banniel gwenn',
];
