<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich Mean Time (Abidjan)',
        'Africa/Accra' => 'Greenwich Mean Time (Accra)',
        'Africa/Addis_Ababa' => 'Àkókò Ìlà-Oòrùn Afírikà (Addis Ababa)',
        'Africa/Algiers' => 'Àkókò Àárin Europe (Algiers)',
        'Africa/Asmera' => 'Àkókò Ìlà-Oòrùn Afírikà (Asmara)',
        'Africa/Asmara' => 'Àkókò Ìlà-Oòrùn Afírikà (Asmara)',
        'Africa/Bamako' => 'Greenwich Mean Time (Bamako)',
        'Africa/Bangui' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Bangui)',
        'Africa/Banjul' => 'Greenwich Mean Time (Banjul)',
        'Africa/Bissau' => 'Greenwich Mean Time (Bissau)',
        'Africa/Blantyre' => 'Àkókò Àárín Afírikà (Blantyre)',
        'Africa/Brazzaville' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Brazzaville)',
        'Africa/Bujumbura' => 'Àkókò Àárín Afírikà (Bujumbura)',
        'Africa/Cairo' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Cairo)',
        'Africa/Casablanca' => 'Àkókò Ìwọ Oòrùn Europe (Casablanca)',
        'Africa/Ceuta' => 'Àkókò Àárin Europe (Ceuta)',
        'Africa/Conakry' => 'Greenwich Mean Time (Conakry)',
        'Africa/Dakar' => 'Greenwich Mean Time (Dakar)',
        'Africa/Dar_es_Salaam' => 'Àkókò Ìlà-Oòrùn Afírikà (Dar es Salaam)',
        'Africa/Djibouti' => 'Àkókò Ìlà-Oòrùn Afírikà (Djibouti)',
        'Africa/Douala' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Douala)',
        'Africa/El_Aaiun' => 'Àkókò Ìwọ Oòrùn Europe (El Aaiún)',
        'Africa/Freetown' => 'Greenwich Mean Time (Freetown)',
        'Africa/Gaborone' => 'Àkókò Àárín Afírikà (Gaborone)',
        'Africa/Harare' => 'Àkókò Àárín Afírikà (Harare)',
        'Africa/Johannesburg' => 'South Africa Standard Time (Johannesburg)',
        'Africa/Juba' => 'Àkókò Àárín Afírikà (Juba)',
        'Africa/Kampala' => 'Àkókò Ìlà-Oòrùn Afírikà (Kampala)',
        'Africa/Khartoum' => 'Àkókò Àárín Afírikà (Khartoum)',
        'Africa/Kigali' => 'Àkókò Àárín Afírikà (Kigali)',
        'Africa/Kinshasa' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Kinshasa)',
        'Africa/Lagos' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Lagos)',
        'Africa/Libreville' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Libreville)',
        'Africa/Lome' => 'Greenwich Mean Time (Lomé)',
        'Africa/Luanda' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Luanda)',
        'Africa/Lubumbashi' => 'Àkókò Àárín Afírikà (Lubumbashi)',
        'Africa/Lusaka' => 'Àkókò Àárín Afírikà (Lusaka)',
        'Africa/Malabo' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Malabo)',
        'Africa/Maputo' => 'Àkókò Àárín Afírikà (Maputo)',
        'Africa/Maseru' => 'South Africa Standard Time (Maseru)',
        'Africa/Mbabane' => 'South Africa Standard Time (Mbabane)',
        'Africa/Mogadishu' => 'Àkókò Ìlà-Oòrùn Afírikà (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich Mean Time (Monrovia)',
        'Africa/Nairobi' => 'Àkókò Ìlà-Oòrùn Afírikà (Nairobi)',
        'Africa/Ndjamena' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (N’Djamena)',
        'Africa/Niamey' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Niamey)',
        'Africa/Nouakchott' => 'Greenwich Mean Time (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich Mean Time (Ouagadougou)',
        'Africa/Porto-Novo' => 'Àkókò Ìwọ̀-Oòrùn Afírikà (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich Mean Time (São Tomé)',
        'Africa/Tripoli' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Tripoli)',
        'Africa/Tunis' => 'Àkókò Àárin Europe (Tunis)',
        'Africa/Windhoek' => 'Àkókò Àárín Afírikà (Windhoek)',
        'America/Adak' => 'Àkókò Hawaii-Aleutian (ìlú Adákì)',
        'America/Anchorage' => 'Àkókò Alásíkà (ìlú Ankọ́réèjì)',
        'America/Anguilla' => 'Àkókò Àtìláńtíìkì (ìlú Angúílà)',
        'America/Antigua' => 'Àkókò Àtìláńtíìkì (ìlú Antígùà)',
        'America/Araguaina' => 'Aago Bùràsílíà (Araguaína)',
        'America/Argentina/La_Rioja' => 'Aago Ajẹntìnà (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Aago Ajẹntìnà (Río Gallegos)',
        'America/Argentina/Salta' => 'Aago Ajẹntìnà (Salta)',
        'America/Argentina/San_Juan' => 'Aago Ajẹntìnà (San Juan)',
        'America/Argentina/San_Luis' => 'Aago Ajẹntìnà (San Luis)',
        'America/Argentina/Tucuman' => 'Aago Ajẹntìnà (Tucumán)',
        'America/Argentina/Ushuaia' => 'Aago Ajẹntìnà (Ushuaia)',
        'America/Aruba' => 'Àkókò Àtìláńtíìkì (ìlú Arúbá)',
        'America/Asuncion' => 'Àkókò Párágúwè (Asunción)',
        'America/Bahia' => 'Aago Bùràsílíà (Bahia)',
        'America/Bahia_Banderas' => 'àkókò àárín gbùngbùn (ìlú Báhì Bándẹ́rásì)',
        'America/Barbados' => 'Àkókò Àtìláńtíìkì (ìlú Bábádọ́ọ̀sì)',
        'America/Belem' => 'Aago Bùràsílíà (Belém)',
        'America/Belize' => 'àkókò àárín gbùngbùn (ìlú Bẹ̀líìsì)',
        'America/Blanc-Sablon' => 'Àkókò Àtìláńtíìkì (ìlú Blank Sabulọ́ọ̀nì)',
        'America/Boa_Vista' => 'Àkókò Amásọ́nì (Boa Vista)',
        'America/Bogota' => 'Aago Kolombia (Bogotá)',
        'America/Boise' => 'Àkókò òkè (ìlú Bọ́isè)',
        'America/Buenos_Aires' => 'Aago Ajẹntìnà (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Aago Ajẹntìnà (Buenos Aires)',
        'America/Cambridge_Bay' => 'Àkókò òkè (ìlú òkun kambíríìjì)',
        'America/Campo_Grande' => 'Àkókò Amásọ́nì (Campo Grande)',
        'America/Cancun' => 'Àkókò ìhà ìlà oòrùn (ìlú Kancun)',
        'America/Caracas' => 'Aago Venezuela (Caracas)',
        'America/Catamarca' => 'Aago Ajẹntìnà (Catamarca)',
        'America/Argentina/Catamarca' => 'Aago Ajẹntìnà (Catamarca)',
        'America/Cayenne' => 'Àkókò Gúyánà Fáránsè (Cayenne)',
        'America/Cayman' => 'Àkókò ìhà ìlà oòrùn (ilú Kayman)',
        'America/Chicago' => 'àkókò àárín gbùngbùn (ìlú Chicago)',
        'America/Chihuahua' => 'àkókò àárín gbùngbùn (ìlú Ṣihuahua)',
        'America/Ciudad_Juarez' => 'Àkókò òkè (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Àkókò ìhà ìlà oòrùn (ìlú àtikọkàn)',
        'America/Atikokan' => 'Àkókò ìhà ìlà oòrùn (ìlú àtikọkàn)',
        'America/Cordoba' => 'Aago Ajẹntìnà (Córdoba)',
        'America/Argentina/Cordoba' => 'Aago Ajẹntìnà (Córdoba)',
        'America/Costa_Rica' => 'àkókò àárín gbùngbùn (ìlú Kosta Ríkà)',
        'America/Coyhaique' => 'Àkókò Ṣílè (Coyhaique)',
        'America/Creston' => 'Àkókò òkè (ìlú Kírẹstọ́ọ̀nù)',
        'America/Cuiaba' => 'Àkókò Amásọ́nì (Cuiabá)',
        'America/Curacao' => 'Àkókò Àtìláńtíìkì (ìlú Kuraṣao)',
        'America/Danmarkshavn' => 'Greenwich Mean Time (ìlú Banmarkshan)',
        'America/Dawson' => 'Àkókò Yúkọ́nì (ìlú Dawson)',
        'America/Dawson_Creek' => 'Àkókò òkè (ìlú Dawson Creek)',
        'America/Denver' => 'Àkókò òkè (ìlú Denver)',
        'America/Detroit' => 'Àkókò ìhà ìlà oòrùn (ìlú Detroit)',
        'America/Dominica' => 'Àkókò Àtìláńtíìkì (ìlú Dominika)',
        'America/Edmonton' => 'Àkókò òkè (ìlú Edmonton)',
        'America/Eirunepe' => 'Ìgbà Bàràsílì (Eirunepé)',
        'America/El_Salvador' => 'àkókò àárín gbùngbùn (ìlú El Savador)',
        'America/Fort_Nelson' => 'Àkókò òkè (ìlú Fort Nelson)',
        'America/Fortaleza' => 'Aago Bùràsílíà (Fortaleza)',
        'America/Glace_Bay' => 'Àkókò Àtìláńtíìkì (ìlú omi Glace)',
        'America/Godthab' => 'Ìgbà Gerelandi (ìlú Nuuk)',
        'America/Nuuk' => 'Ìgbà Gerelandi (ìlú Nuuk)',
        'America/Goose_Bay' => 'Àkókò Àtìláńtíìkì (ìlú omi Goosù)',
        'America/Grand_Turk' => 'Àkókò ìhà ìlà oòrùn (ìlú Grand Turk)',
        'America/Grenada' => 'Àkókò Àtìláńtíìkì (ìlú Grenada)',
        'America/Guadeloupe' => 'Àkókò Àtìláńtíìkì (ìlú Guadeloupe)',
        'America/Guatemala' => 'àkókò àárín gbùngbùn (ìlú Guatemala)',
        'America/Guayaquil' => 'Aago Ecuador (Guayaquil)',
        'America/Guyana' => 'Àkókò Gúyànà (Guyana)',
        'America/Halifax' => 'Àkókò Àtìláńtíìkì (ìlú Halifásì)',
        'America/Havana' => 'Àkókò Kúbà (ìlú Havana)',
        'America/Hermosillo' => 'Àkókò Pásífíìkì Mẹ́ṣíkò (ìlú Hermosilo)',
        'America/Indiana/Knox' => 'àkókò àárín gbùngbùn (ìlú nọ́sì)',
        'America/Indiana/Marengo' => 'Àkókò ìhà ìlà oòrùn (ìlú Marẹ́ngo)',
        'America/Indiana/Petersburg' => 'Àkókò ìhà ìlà oòrùn (ìlú Petersburg)',
        'America/Indiana/Tell_City' => 'àkókò àárín gbùngbùn (ìlú Tell City)',
        'America/Indiana/Vevay' => 'Àkókò ìhà ìlà oòrùn (ìlú Vevay)',
        'America/Indiana/Vincennes' => 'Àkókò ìhà ìlà oòrùn (ìlú Vincennes ní Indiana)',
        'America/Indiana/Winamac' => 'Àkókò ìhà ìlà oòrùn (ìlú Winamak ní Indiana)',
        'America/Indianapolis' => 'Àkókò ìhà ìlà oòrùn (ìlú Indianapolis)',
        'America/Indiana/Indianapolis' => 'Àkókò ìhà ìlà oòrùn (ìlú Indianapolis)',
        'America/Inuvik' => 'Àkókò òkè (ìlú Inuvik)',
        'America/Iqaluit' => 'Àkókò ìhà ìlà oòrùn (ìlú Iqaluit)',
        'America/Jamaica' => 'Àkókò ìhà ìlà oòrùn (ìlú Jamaikà)',
        'America/Jujuy' => 'Aago Ajẹntìnà (Jujuy)',
        'America/Argentina/Jujuy' => 'Aago Ajẹntìnà (Jujuy)',
        'America/Juneau' => 'Àkókò Alásíkà (ìlú Junu)',
        'America/Kentucky/Monticello' => 'Àkókò ìhà ìlà oòrùn (ìlú Montisẹ́lò)',
        'America/Kralendijk' => 'Àkókò Àtìláńtíìkì (ìlú Kíralẹ́ndáikì)',
        'America/La_Paz' => 'Aago Bolivia (La Paz)',
        'America/Lima' => 'Àkókò Pérù (Lima)',
        'America/Los_Angeles' => 'Àkókò Pàsífíìkì (ìlú Los Angeles)',
        'America/Louisville' => 'Àkókò ìhà ìlà oòrùn (ìlú Lúífíìlì)',
        'America/Kentucky/Louisville' => 'Àkókò ìhà ìlà oòrùn (ìlú Lúífíìlì)',
        'America/Lower_Princes' => 'Àkókò Àtìláńtíìkì (ìlú Lower Prince’s Quarter)',
        'America/Maceio' => 'Aago Bùràsílíà (Maceió)',
        'America/Managua' => 'àkókò àárín gbùngbùn (ìlú Managua)',
        'America/Manaus' => 'Àkókò Amásọ́nì (Manaus)',
        'America/Marigot' => 'Àkókò Àtìláńtíìkì (ìlú Marigọ́ọ̀tì)',
        'America/Martinique' => 'Àkókò Àtìláńtíìkì (ìlú Mátíníkì)',
        'America/Matamoros' => 'àkókò àárín gbùngbùn (ìlú Matamorosì)',
        'America/Mazatlan' => 'Àkókò Pásífíìkì Mẹ́ṣíkò (ìlú Masatiani)',
        'America/Mendoza' => 'Aago Ajẹntìnà (Mendoza)',
        'America/Argentina/Mendoza' => 'Aago Ajẹntìnà (Mendoza)',
        'America/Menominee' => 'àkókò àárín gbùngbùn (ìlú Menominì)',
        'America/Merida' => 'àkókò àárín gbùngbùn (ìlú Merida)',
        'America/Metlakatla' => 'Àkókò Alásíkà (ìlú Metilakatila)',
        'America/Mexico_City' => 'àkókò àárín gbùngbùn (ìlú Mẹ́síkò)',
        'America/Miquelon' => 'Àkókò Pierre & Miquelon (ìlú Mikulọ́nì)',
        'America/Moncton' => 'Àkókò Àtìláńtíìkì (ìlú Montoni)',
        'America/Monterrey' => 'àkókò àárín gbùngbùn (ìlú Monteri)',
        'America/Montevideo' => 'Aago Uruguay (Montevideo)',
        'America/Montserrat' => 'Àkókò Àtìláńtíìkì (ìlú Monseratì)',
        'America/Nassau' => 'Àkókò ìhà ìlà oòrùn (ìlú Nasaò)',
        'America/New_York' => 'Àkókò ìhà ìlà oòrùn (ìlú New York)',
        'America/Nome' => 'Àkókò Alásíkà (ìlú Nomi)',
        'America/Noronha' => 'Aago Fenando de Norona (Fernando de Noronha)',
        'America/North_Dakota/Beulah' => 'àkókò àárín gbùngbùn (ìlú Beulà ní North Dakota)',
        'America/North_Dakota/Center' => 'àkókò àárín gbùngbùn (ìlú Senta North Dakota)',
        'America/North_Dakota/New_Salem' => 'àkókò àárín gbùngbùn (ìlú New Salem ni North Dakota)',
        'America/Ojinaga' => 'àkókò àárín gbùngbùn (ìlú Ojinaga)',
        'America/Panama' => 'Àkókò ìhà ìlà oòrùn (ìlú Panama)',
        'America/Paramaribo' => 'Àkókò Súrínámù (Paramaribo)',
        'America/Phoenix' => 'Àkókò òkè (ìlú Fínísì)',
        'America/Port-au-Prince' => 'Àkókò ìhà ìlà oòrùn (ìlú Port-au-Prince)',
        'America/Port_of_Spain' => 'Àkókò Àtìláńtíìkì (ìlú etí omi Sípéènì)',
        'America/Porto_Velho' => 'Àkókò Amásọ́nì (Porto Velho)',
        'America/Puerto_Rico' => 'Àkókò Àtìláńtíìkì (ìlú Puerto Riko)',
        'America/Punta_Arenas' => 'Àkókò Ṣílè (Punta Arenas)',
        'America/Rankin_Inlet' => 'àkókò àárín gbùngbùn (ìlú Rankin Inlet)',
        'America/Recife' => 'Aago Bùràsílíà (Recife)',
        'America/Regina' => 'àkókò àárín gbùngbùn (ìlú Regina)',
        'America/Resolute' => 'àkókò àárín gbùngbùn (ìlú Resolútì)',
        'America/Rio_Branco' => 'Ìgbà Bàràsílì (Rio Branco)',
        'America/Santarem' => 'Aago Bùràsílíà (Santarém)',
        'America/Santiago' => 'Àkókò Ṣílè (Santiago)',
        'America/Santo_Domingo' => 'Àkókò Àtìláńtíìkì (ìlú Santo Domigo)',
        'America/Sao_Paulo' => 'Aago Bùràsílíà (São Paulo)',
        'America/Scoresbysund' => 'Ìgbà Gerelandi (ìlú Itokotomiti)',
        'America/Sitka' => 'Àkókò Alásíkà (ìlú Sika)',
        'America/St_Barthelemy' => 'Àkókò Àtìláńtíìkì (ìlú Batilemì)',
        'America/St_Johns' => 'Àkókò Newfoundland (ìlú St Jọ́ọ̀nù)',
        'America/St_Kitts' => 'Àkókò Àtìláńtíìkì (ìlú St kitisì)',
        'America/St_Lucia' => 'Àkókò Àtìláńtíìkì (ìlú St Lusia)',
        'America/St_Thomas' => 'Àkókò Àtìláńtíìkì (ìlú St Tọ́màsì)',
        'America/St_Vincent' => 'Àkókò Àtìláńtíìkì (ìlú Finsentì)',
        'America/Swift_Current' => 'àkókò àárín gbùngbùn (ìlú Súfítù Kọ̀rentì)',
        'America/Tegucigalpa' => 'àkókò àárín gbùngbùn (ìlú Tegusigapà)',
        'America/Thule' => 'Àkókò Àtìláńtíìkì (ìlú Tulè)',
        'America/Tijuana' => 'Àkókò Pàsífíìkì (ìlú Tíjúana)',
        'America/Toronto' => 'Àkókò ìhà ìlà oòrùn (ìlú Toronto)',
        'America/Tortola' => 'Àkókò Àtìláńtíìkì (ìlú Totola)',
        'America/Vancouver' => 'Àkókò Pàsífíìkì (ìlú Vankuva)',
        'America/Whitehorse' => 'Àkókò Yúkọ́nì (ìlú Whitehosì)',
        'America/Winnipeg' => 'àkókò àárín gbùngbùn (ìlú Winipegì)',
        'America/Yakutat' => 'Àkókò Alásíkà (ìlú Yakuta)',
        'Antarctica/Casey' => 'Àkókò Ìwọ̀-Oòrùn Australia (Casey)',
        'Antarctica/Davis' => 'Àkókò Davis',
        'Antarctica/DumontDUrville' => 'Àkókò Dumont-d’Urville',
        'Antarctica/Macquarie' => 'Àkókò Ìlà-Oòrùn Australia (Macquarie)',
        'Antarctica/Mawson' => 'Àkókò Mawson',
        'Antarctica/McMurdo' => 'Àkókò New Zealand (McMurdo)',
        'Antarctica/Palmer' => 'Àkókò Ṣílè (Palmer)',
        'Antarctica/Rothera' => 'Àkókò Rothera',
        'Antarctica/Syowa' => 'Àkókò Syowa (Showa)',
        'Antarctica/Troll' => 'Greenwich Mean Time (Troll)',
        'Antarctica/Vostok' => 'Àkókò Vostok',
        'Arctic/Longyearbyen' => 'Àkókò Àárin Europe (Longyearbyen)',
        'Asia/Aden' => 'Àkókò Arabia (Aden)',
        'Asia/Almaty' => 'Aago Kasasitáànì (Almaty)',
        'Asia/Amman' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Amman)',
        'Asia/Anadyr' => 'Ìgbà Rọṣia (Anadyr)',
        'Asia/Aqtau' => 'Aago Kasasitáànì (Aqtau)',
        'Asia/Aqtobe' => 'Aago Kasasitáànì (Aqtobe)',
        'Asia/Ashgabat' => 'Àkókò Turkimenistani (Ashgabat)',
        'Asia/Atyrau' => 'Aago Kasasitáànì (Atyrau)',
        'Asia/Baghdad' => 'Àkókò Arabia (Baghdad)',
        'Asia/Bahrain' => 'Àkókò Arabia (Bahrain)',
        'Asia/Baku' => 'Àkókò Azerbaijan (Baku)',
        'Asia/Bangkok' => 'Àkókò Indochina (Bangkok)',
        'Asia/Barnaul' => 'Àkókò Krasinoyasiki (Barnaul)',
        'Asia/Beirut' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Beirut)',
        'Asia/Bishkek' => 'Àkókò Kirigisitaani (Bishkek)',
        'Asia/Brunei' => 'Brunei Darussalam Time',
        'Asia/Calcutta' => 'Àkókò Àfẹnukò India (Kolkata)',
        'Asia/Kolkata' => 'Àkókò Àfẹnukò India (Kolkata)',
        'Asia/Chita' => 'Àkókò Yatutsk (Chita)',
        'Asia/Colombo' => 'Àkókò Àfẹnukò India (Colombo)',
        'Asia/Damascus' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Damascus)',
        'Asia/Dhaka' => 'Àkókò Bangladesh (Dhaka)',
        'Asia/Dili' => 'Àkókò Ìlà oorùn Timor (Dili)',
        'Asia/Dubai' => 'Àkókò Àfẹnukò Gulf (Dubai)',
        'Asia/Dushanbe' => 'Àkókò Tajikisitaani (Dushanbe)',
        'Asia/Famagusta' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Famagusta)',
        'Asia/Gaza' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Gaza)',
        'Asia/Hebron' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Hebron)',
        'Asia/Hong_Kong' => 'Àkókò Hong Kong',
        'Asia/Hovd' => 'Àkókò Hofidi (Khovd)',
        'Asia/Irkutsk' => 'Àkókò Íkósíkì (Irkutsk)',
        'Asia/Jakarta' => 'Àkókò Ìwọ̀ oorùn Indonesia (Jakarta)',
        'Asia/Jayapura' => 'Àkókò Ìlà oorùn Indonesia (Jayapura)',
        'Asia/Jerusalem' => 'Àkókò Israel (Jerusalem)',
        'Asia/Kabul' => 'Àkókò Afghanistan (Kabul)',
        'Asia/Kamchatka' => 'Ìgbà Rọṣia (Kamchatka)',
        'Asia/Karachi' => 'Àkókò Pakistani (Karachi)',
        'Asia/Katmandu' => 'Àkókò Nepali (Kathmandu)',
        'Asia/Kathmandu' => 'Àkókò Nepali (Kathmandu)',
        'Asia/Khandyga' => 'Àkókò Yatutsk (Khandyga)',
        'Asia/Krasnoyarsk' => 'Àkókò Krasinoyasiki (Krasnoyarsk)',
        'Asia/Kuala_Lumpur' => 'Àkókò Malaysia (Kuala Lumpur)',
        'Asia/Kuching' => 'Àkókò Malaysia (Kuching)',
        'Asia/Kuwait' => 'Àkókò Arabia (Kuwait)',
        'Asia/Macau' => 'Àkókò Ṣáínà (Macao)',
        'Asia/Magadan' => 'Àkókò Magadani',
        'Asia/Makassar' => 'Àkókò Ààrin Gbùngbùn Indonesia (Makassar)',
        'Asia/Manila' => 'Àkókò Filipininni (Manila)',
        'Asia/Muscat' => 'Àkókò Àfẹnukò Gulf (Muscat)',
        'Asia/Nicosia' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Nicosia)',
        'Asia/Novokuznetsk' => 'Àkókò Krasinoyasiki (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Àkókò Krasinoyasiki (Novosibirsk)',
        'Asia/Omsk' => 'Àkókò Omisiki (Omsk)',
        'Asia/Oral' => 'Aago Kasasitáànì (Oral)',
        'Asia/Phnom_Penh' => 'Àkókò Indochina (Phnom Penh)',
        'Asia/Pontianak' => 'Àkókò Ìwọ̀ oorùn Indonesia (Pontianak)',
        'Asia/Pyongyang' => 'Àkókò Koria (Pyongyang)',
        'Asia/Qatar' => 'Àkókò Arabia (Qatar)',
        'Asia/Qostanay' => 'Aago Kasasitáànì (Qostanay)',
        'Asia/Qyzylorda' => 'Aago Kasasitáànì (Qyzylorda)',
        'Asia/Rangoon' => 'Àkókò Ìlà Myanmar (Yangon)',
        'Asia/Yangon' => 'Àkókò Ìlà Myanmar (Yangon)',
        'Asia/Riyadh' => 'Àkókò Arabia (Riyadh)',
        'Asia/Saigon' => 'Àkókò Indochina (Ilu Ho Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'Àkókò Indochina (Ilu Ho Chi Minh)',
        'Asia/Sakhalin' => 'Àkókò Magadani (Sakhalin)',
        'Asia/Samarkand' => 'Àkókò Usibekistani (Samarkand)',
        'Asia/Seoul' => 'Àkókò Koria (Seoul)',
        'Asia/Shanghai' => 'Àkókò Ṣáínà (Shanghai)',
        'Asia/Singapore' => 'Àkókò Àfẹnukò Singapore',
        'Asia/Srednekolymsk' => 'Àkókò Magadani (Srednekolymsk)',
        'Asia/Taipei' => 'Àkókò Taipei',
        'Asia/Tashkent' => 'Àkókò Usibekistani (Tashkent)',
        'Asia/Tbilisi' => 'Àkókò Georgia (Tbilisi)',
        'Asia/Tehran' => 'Àkókò Irani (Tehran)',
        'Asia/Thimphu' => 'Àkókò Bhutan (Thimphu)',
        'Asia/Tokyo' => 'Àkókò Japan (Tokyo)',
        'Asia/Tomsk' => 'Àkókò Krasinoyasiki (Tomsk)',
        'Asia/Ulaanbaatar' => 'Àkókò Ulaanbaatar',
        'Asia/Urumqi' => 'Ìgbà Ṣáínà (Ürümqi)',
        'Asia/Ust-Nera' => 'Àkókò Filadifositoki (Ust-Nera)',
        'Asia/Vientiane' => 'Àkókò Indochina (Vientiane)',
        'Asia/Vladivostok' => 'Àkókò Filadifositoki (Vladivostok)',
        'Asia/Yakutsk' => 'Àkókò Yatutsk (Yakutsk)',
        'Asia/Yekaterinburg' => 'Àkókò Yekaterinburg',
        'Asia/Yerevan' => 'Àkókò Armenia (Yerevan)',
        'Atlantic/Azores' => 'Àkókò Ásọ́sì (Azores)',
        'Atlantic/Bermuda' => 'Àkókò Àtìláńtíìkì (ìlú Bẹ̀múdà)',
        'Atlantic/Canary' => 'Àkókò Ìwọ Oòrùn Europe (Canarias)',
        'Atlantic/Cape_Verde' => 'Àkókò Képú Fáàdì (Cape Verde)',
        'Atlantic/Faeroe' => 'Àkókò Ìwọ Oòrùn Europe (Faroe)',
        'Atlantic/Faroe' => 'Àkókò Ìwọ Oòrùn Europe (Faroe)',
        'Atlantic/Madeira' => 'Àkókò Ìwọ Oòrùn Europe (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich Mean Time (Reykjavik)',
        'Atlantic/South_Georgia' => 'Àkókò Gúsù Jọ́jíà (South Georgia)',
        'Atlantic/St_Helena' => 'Greenwich Mean Time (St. Helena)',
        'Atlantic/Stanley' => 'Àkókò Fókílándì (Stanley)',
        'Australia/Adelaide' => 'Àkókò Ààrin Gùngùn Australia (Adelaide)',
        'Australia/Brisbane' => 'Àkókò Ìlà-Oòrùn Australia (Brisbane)',
        'Australia/Broken_Hill' => 'Àkókò Ààrin Gùngùn Australia (Broken Hill)',
        'Australia/Darwin' => 'Àkókò Ààrin Gùngùn Australia (Darwin)',
        'Australia/Eucla' => 'Àkókò Ààrin Gùngùn Ìwọ̀-Oòrùn Australia (Eucla)',
        'Australia/Hobart' => 'Àkókò Ìlà-Oòrùn Australia (Hobart)',
        'Australia/Lindeman' => 'Àkókò Ìlà-Oòrùn Australia (Lindeman)',
        'Australia/Lord_Howe' => 'Àkókò Lord Howe',
        'Australia/Melbourne' => 'Àkókò Ìlà-Oòrùn Australia (Melbourne)',
        'Australia/Perth' => 'Àkókò Ìwọ̀-Oòrùn Australia (Perth)',
        'Australia/Sydney' => 'Àkókò Ìlà-Oòrùn Australia (Sydney)',
        'Etc/GMT' => 'Greenwich Mean Time',
        'Etc/UTC' => 'Àpapọ̀ Àkókò Àgbáyé',
        'Europe/Amsterdam' => 'Àkókò Àárin Europe (Amsterdam)',
        'Europe/Andorra' => 'Àkókò Àárin Europe (Andorra)',
        'Europe/Astrakhan' => 'Ìgbà Rọṣia (Astrakhan)',
        'Europe/Athens' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Athens)',
        'Europe/Belgrade' => 'Àkókò Àárin Europe (Belgrade)',
        'Europe/Berlin' => 'Àkókò Àárin Europe (Berlin)',
        'Europe/Bratislava' => 'Àkókò Àárin Europe (Bratislava)',
        'Europe/Brussels' => 'Àkókò Àárin Europe (Brussels)',
        'Europe/Bucharest' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Bucharest)',
        'Europe/Budapest' => 'Àkókò Àárin Europe (Budapest)',
        'Europe/Busingen' => 'Àkókò Àárin Europe (Büsingen)',
        'Europe/Chisinau' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Chișinău)',
        'Europe/Copenhagen' => 'Àkókò Àárin Europe (Copenhagen)',
        'Europe/Dublin' => 'Greenwich Mean Time (Dublin)',
        'Europe/Gibraltar' => 'Àkókò Àárin Europe (Gibraltar)',
        'Europe/Guernsey' => 'Greenwich Mean Time (Guernsey)',
        'Europe/Helsinki' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Helsinki)',
        'Europe/Isle_of_Man' => 'Greenwich Mean Time (Isle of Man)',
        'Europe/Istanbul' => 'Ìgbà Tọọki (Istanbul)',
        'Europe/Jersey' => 'Greenwich Mean Time (Jersey)',
        'Europe/Kaliningrad' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Kaliningrad)',
        'Europe/Kiev' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Kyiv)',
        'Europe/Kyiv' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Kyiv)',
        'Europe/Kirov' => 'Àkókò Mosiko (Kirov)',
        'Europe/Lisbon' => 'Àkókò Ìwọ Oòrùn Europe (Lisbon)',
        'Europe/Ljubljana' => 'Àkókò Àárin Europe (Ljubljana)',
        'Europe/London' => 'Greenwich Mean Time (London)',
        'Europe/Luxembourg' => 'Àkókò Àárin Europe (Luxembourg)',
        'Europe/Madrid' => 'Àkókò Àárin Europe (Madrid)',
        'Europe/Malta' => 'Àkókò Àárin Europe (Malta)',
        'Europe/Mariehamn' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Mariehamn)',
        'Europe/Minsk' => 'Àkókò Mosiko (Minsk)',
        'Europe/Monaco' => 'Àkókò Àárin Europe (Monaco)',
        'Europe/Moscow' => 'Àkókò Mosiko (Moscow)',
        'Europe/Oslo' => 'Àkókò Àárin Europe (Oslo)',
        'Europe/Paris' => 'Àkókò Àárin Europe (Paris)',
        'Europe/Podgorica' => 'Àkókò Àárin Europe (Podgorica)',
        'Europe/Prague' => 'Àkókò Àárin Europe (Prague)',
        'Europe/Riga' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Riga)',
        'Europe/Rome' => 'Àkókò Àárin Europe (Rome)',
        'Europe/Samara' => 'Ìgbà Rọṣia (Samara)',
        'Europe/San_Marino' => 'Àkókò Àárin Europe (San Marino)',
        'Europe/Sarajevo' => 'Àkókò Àárin Europe (Sarajevo)',
        'Europe/Saratov' => 'Ìgbà Rọṣia (Saratov)',
        'Europe/Simferopol' => 'Àkókò Mosiko (Simferopol)',
        'Europe/Skopje' => 'Àkókò Àárin Europe (Skopje)',
        'Europe/Sofia' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Sofia)',
        'Europe/Stockholm' => 'Àkókò Àárin Europe (Stockholm)',
        'Europe/Tallinn' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Tallinn)',
        'Europe/Tirane' => 'Àkókò Àárin Europe (Tirana)',
        'Europe/Ulyanovsk' => 'Ìgbà Rọṣia (Ulyanovsk)',
        'Europe/Vaduz' => 'Àkókò Àárin Europe (Vaduz)',
        'Europe/Vatican' => 'Àkókò Àárin Europe (Vatican)',
        'Europe/Vienna' => 'Àkókò Àárin Europe (Vienna)',
        'Europe/Vilnius' => 'Àkókò Ìhà Ìlà Oòrùn Europe (Vilnius)',
        'Europe/Volgograd' => 'Àkókò Mosiko (Volgograd)',
        'Europe/Warsaw' => 'Àkókò Àárin Europe (Warsaw)',
        'Europe/Zagreb' => 'Àkókò Àárin Europe (Zagreb)',
        'Europe/Zurich' => 'Àkókò Àárin Europe (Zurich)',
        'Indian/Antananarivo' => 'Àkókò Ìlà-Oòrùn Afírikà (Antananarivo)',
        'Indian/Chagos' => 'Àkókò Etíkun Índíà (Chagos)',
        'Indian/Christmas' => 'Àkókò Erékùsù Christmas',
        'Indian/Cocos' => 'Àkókò Àwọn Erékùsù Cocos',
        'Indian/Comoro' => 'Àkókò Ìlà-Oòrùn Afírikà (Comores)',
        'Indian/Kerguelen' => 'Àkókò Gúsù Fáransé àti Àntátíìkì (Kerguelen)',
        'Indian/Mahe' => 'Àkókò Sèṣẹ́ẹ̀lì (Mahé)',
        'Indian/Maldives' => 'Àkókò Maldives',
        'Indian/Mauritius' => 'Àkókò Máríṣúṣì (Mauritius)',
        'Indian/Mayotte' => 'Àkókò Ìlà-Oòrùn Afírikà (Mayotte)',
        'Indian/Reunion' => 'Àkókò Rẹ́yúníọ́nì (Réunion)',
        'Pacific/Apia' => 'Àkókò Apia',
        'Pacific/Auckland' => 'Àkókò New Zealand (Auckland)',
        'Pacific/Bougainville' => 'Àkókò Papua New Guinea (Bougainville)',
        'Pacific/Chatham' => 'Àkókò Chatam (Chatham)',
        'Pacific/Easter' => 'Aago Ajnde Ibùgbé Omi (Easter)',
        'Pacific/Efate' => 'Àkókò Fanuatu (Efate)',
        'Pacific/Enderbury' => 'Àkókò Àwọn Erékùsù Phoenix (Canton)',
        'Pacific/Kanton' => 'Àkókò Àwọn Erékùsù Phoenix (Canton)',
        'Pacific/Fakaofo' => 'Àkókò Tokelau (Fakaofo)',
        'Pacific/Fiji' => 'Àkókò Fiji',
        'Pacific/Funafuti' => 'Àkókò Tufalu (Funafuti)',
        'Pacific/Galapagos' => 'Aago Galapago (Galápagos)',
        'Pacific/Gambier' => 'Àkókò Gambia (Gambier)',
        'Pacific/Guadalcanal' => 'Àkókò Àwọn Erekusu Solomon (Guadalcanal)',
        'Pacific/Guam' => 'Àkókò Àfẹnukò Chamorro (Guam)',
        'Pacific/Honolulu' => 'Àkókò Àfẹnukò Hawaii-Aleutian (Honolulu)',
        'Pacific/Kiritimati' => 'Àkókò Àwọn Erekusu Laini (Kiritimati)',
        'Pacific/Kosrae' => 'Àkókò Kosirai (Kosrae)',
        'Pacific/Kwajalein' => 'Àkókò Àwọn Erekusu Masaali (Kwajalein)',
        'Pacific/Majuro' => 'Àkókò Àwọn Erekusu Masaali (Majuro)',
        'Pacific/Marquesas' => 'Àkókò Makuesasi (Marquesas)',
        'Pacific/Midway' => 'Àkókò Samoa (Midway)',
        'Pacific/Nauru' => 'Àkókò Nauru',
        'Pacific/Niue' => 'Àkókò Niue',
        'Pacific/Norfolk' => 'Àkókò Erékùsù Norfolk',
        'Pacific/Noumea' => 'Àkókò Kalidonia Tuntun (Nouméa)',
        'Pacific/Pago_Pago' => 'Àkókò Samoa (Pago Pago)',
        'Pacific/Palau' => 'Àkókò Palau',
        'Pacific/Pitcairn' => 'Àkókò Pitcairn',
        'Pacific/Ponape' => 'Àkókò Ponape (Pohnpei)',
        'Pacific/Pohnpei' => 'Àkókò Ponape (Pohnpei)',
        'Pacific/Port_Moresby' => 'Àkókò Papua New Guinea (Port Moresby)',
        'Pacific/Rarotonga' => 'Àkókò Àwọn Erekusu Kuuku (Rarotonga)',
        'Pacific/Saipan' => 'Àkókò Àfẹnukò Chamorro (Saipan)',
        'Pacific/Tahiti' => 'Àkókò Tahiti',
        'Pacific/Tarawa' => 'Àkókò Àwọn Erekusu Gilibati (Tarawa)',
        'Pacific/Tongatapu' => 'Àkókò Tonga (Tongatapu)',
        'Pacific/Truk' => 'Àkókò Chuuk',
        'Pacific/Chuuk' => 'Àkókò Chuuk',
        'Pacific/Wake' => 'Àkókò Erékùsù Wake',
        'Pacific/Wallis' => 'Àkókò Wallis & Futuina (Wallis & Futuna)',
    ],
    'Meta' => [
        'GmtFormat' => 'WAT%s',
    ],
];
