<?php

return [
    'Names' => [
        'ak' => 'isi-Akhani',
        'ak_GH' => 'isi-Akhani (Ghana)',
        'am' => 'isi-Amaharikhi',
        'am_ET' => 'isi-Amaharikhi (Ethiopia)',
        'ar' => 'isi-Alabhu',
        'ar_AE' => 'isi-Alabhu (United Arab Emirates)',
        'ar_BH' => 'isi-Alabhu (Bhahareni)',
        'ar_DJ' => 'isi-Alabhu (Djibouti)',
        'ar_DZ' => 'isi-Alabhu (Aljeriya)',
        'ar_EG' => 'isi-Alabhu (Egypt)',
        'ar_ER' => 'isi-Alabhu (Eritrea)',
        'ar_IL' => 'isi-Alabhu (Isuraeli)',
        'ar_IQ' => 'isi-Alabhu (Iraki)',
        'ar_JO' => 'isi-Alabhu (Jodani)',
        'ar_KM' => 'isi-Alabhu (Khomoro)',
        'ar_KW' => 'isi-Alabhu (Khuweiti)',
        'ar_LB' => 'isi-Alabhu (Lebhanoni)',
        'ar_LY' => 'isi-Alabhu (Libhiya)',
        'ar_MA' => 'isi-Alabhu (Morokho)',
        'ar_MR' => 'isi-Alabhu (Mauritania)',
        'ar_OM' => 'isi-Alabhu (Omani)',
        'ar_PS' => 'isi-Alabhu (Palestinian West Bank and Gaza)',
        'ar_QA' => 'isi-Alabhu (Kathari)',
        'ar_SA' => 'isi-Alabhu (Saudi Arabia)',
        'ar_SD' => 'isi-Alabhu (Sudani)',
        'ar_SO' => 'isi-Alabhu (Somaliya)',
        'ar_SY' => 'isi-Alabhu (Syria)',
        'ar_TD' => 'isi-Alabhu (Chadi)',
        'ar_TN' => 'isi-Alabhu (Tunisiya)',
        'ar_YE' => 'isi-Alabhu (Yemeni)',
        'be' => 'isi-Bhelarashiyani',
        'be_BY' => 'isi-Bhelarashiyani (Bhelarusi)',
        'bg' => 'isi-Bulgaria',
        'bg_BG' => 'isi-Bulgaria (Bhulgariya)',
        'bn' => 'isi-Bhengali',
        'bn_BD' => 'isi-Bhengali (Bhangiladeshi)',
        'bn_IN' => 'isi-Bhengali (Indiya)',
        'cs' => 'isi-Czech',
        'cs_CZ' => 'isi-Czech (Czech Republic)',
        'de' => 'isi-Jalimani',
        'de_AT' => 'isi-Jalimani (Austria)',
        'de_BE' => 'isi-Jalimani (Bhelgium)',
        'de_CH' => 'isi-Jalimani (Switzerland)',
        'de_DE' => 'isi-Jalimani (Germany)',
        'de_IT' => 'isi-Jalimani (Itali)',
        'de_LI' => 'isi-Jalimani (Liechtenstein)',
        'de_LU' => 'isi-Jalimani (Luxembourg)',
        'el' => 'isi-Giliki',
        'el_CY' => 'isi-Giliki (Cyprus)',
        'el_GR' => 'isi-Giliki (Greece)',
        'en' => 'isi-Ngisi',
        'en_AE' => 'isi-Ngisi (United Arab Emirates)',
        'en_AG' => 'isi-Ngisi (Antigua le Barbuda)',
        'en_AI' => 'isi-Ngisi (Anguilla)',
        'en_AS' => 'isi-Ngisi (Samoa ye Amelika)',
        'en_AT' => 'isi-Ngisi (Austria)',
        'en_AU' => 'isi-Ngisi (Australia)',
        'en_BB' => 'isi-Ngisi (Bhabhadosi)',
        'en_BE' => 'isi-Ngisi (Bhelgium)',
        'en_BI' => 'isi-Ngisi (Bhurundi)',
        'en_BM' => 'isi-Ngisi (Bhemuda)',
        'en_BS' => 'isi-Ngisi (Bhahamas)',
        'en_BW' => 'isi-Ngisi (Botswana)',
        'en_BZ' => 'isi-Ngisi (Bhelize)',
        'en_CA' => 'isi-Ngisi (Khanada)',
        'en_CH' => 'isi-Ngisi (Switzerland)',
        'en_CK' => 'isi-Ngisi (Cook Islands)',
        'en_CM' => 'isi-Ngisi (Khameruni)',
        'en_CY' => 'isi-Ngisi (Cyprus)',
        'en_CZ' => 'isi-Ngisi (Czech Republic)',
        'en_DE' => 'isi-Ngisi (Germany)',
        'en_DK' => 'isi-Ngisi (Denmakhi)',
        'en_DM' => 'isi-Ngisi (Dominikha)',
        'en_EE' => 'isi-Ngisi (Estonia)',
        'en_ER' => 'isi-Ngisi (Eritrea)',
        'en_ES' => 'isi-Ngisi (Spain)',
        'en_FI' => 'isi-Ngisi (Finland)',
        'en_FJ' => 'isi-Ngisi (Fiji)',
        'en_FK' => 'isi-Ngisi (Falkland Islands)',
        'en_FM' => 'isi-Ngisi (Micronesia)',
        'en_FR' => 'isi-Ngisi (Furansi)',
        'en_GB' => 'isi-Ngisi (United Kingdom)',
        'en_GD' => 'isi-Ngisi (Grenada)',
        'en_GE' => 'isi-Ngisi (Georgia)',
        'en_GH' => 'isi-Ngisi (Ghana)',
        'en_GI' => 'isi-Ngisi (Gibraltar)',
        'en_GM' => 'isi-Ngisi (Gambiya)',
        'en_GU' => 'isi-Ngisi (Guam)',
        'en_GY' => 'isi-Ngisi (Guyana)',
        'en_HU' => 'isi-Ngisi (Hungary)',
        'en_ID' => 'isi-Ngisi (Indonesiya)',
        'en_IE' => 'isi-Ngisi (Ireland)',
        'en_IL' => 'isi-Ngisi (Isuraeli)',
        'en_IN' => 'isi-Ngisi (Indiya)',
        'en_IT' => 'isi-Ngisi (Itali)',
        'en_JM' => 'isi-Ngisi (Jamaica)',
        'en_JP' => 'isi-Ngisi (Japan)',
        'en_KE' => 'isi-Ngisi (Khenya)',
        'en_KI' => 'isi-Ngisi (Khiribati)',
        'en_KN' => 'isi-Ngisi (Saint Kitts and Nevis)',
        'en_KY' => 'isi-Ngisi (Cayman Islands)',
        'en_LC' => 'isi-Ngisi (Saint Lucia)',
        'en_LR' => 'isi-Ngisi (Libheriya)',
        'en_LS' => 'isi-Ngisi (Lesotho)',
        'en_LT' => 'isi-Ngisi (Lithuania)',
        'en_LV' => 'isi-Ngisi (Latvia)',
        'en_MG' => 'isi-Ngisi (Madagaska)',
        'en_MH' => 'isi-Ngisi (Marshall Islands)',
        'en_MP' => 'isi-Ngisi (Northern Mariana Islands)',
        'en_MS' => 'isi-Ngisi (Montserrat)',
        'en_MT' => 'isi-Ngisi (Malta)',
        'en_MU' => 'isi-Ngisi (Mauritius)',
        'en_MV' => 'isi-Ngisi (Maldives)',
        'en_MW' => 'isi-Ngisi (Malawi)',
        'en_MY' => 'isi-Ngisi (Malezhiya)',
        'en_NA' => 'isi-Ngisi (Namibhiya)',
        'en_NF' => 'isi-Ngisi (Norfolk Island)',
        'en_NG' => 'isi-Ngisi (Nigeriya)',
        'en_NL' => 'isi-Ngisi (Netherlands)',
        'en_NO' => 'isi-Ngisi (Noweyi)',
        'en_NR' => 'isi-Ngisi (Nauru)',
        'en_NU' => 'isi-Ngisi (Niue)',
        'en_NZ' => 'isi-Ngisi (New Zealand)',
        'en_PG' => 'isi-Ngisi (Papua New Guinea)',
        'en_PH' => 'isi-Ngisi (Philippines)',
        'en_PK' => 'isi-Ngisi (Phakistani)',
        'en_PL' => 'isi-Ngisi (Pholandi)',
        'en_PN' => 'isi-Ngisi (Pitcairn)',
        'en_PR' => 'isi-Ngisi (Puerto Rico)',
        'en_PT' => 'isi-Ngisi (Portugal)',
        'en_PW' => 'isi-Ngisi (Palau)',
        'en_RO' => 'isi-Ngisi (Romania)',
        'en_RW' => 'isi-Ngisi (Ruwanda)',
        'en_SB' => 'isi-Ngisi (Solomon Islands)',
        'en_SC' => 'isi-Ngisi (Seychelles)',
        'en_SD' => 'isi-Ngisi (Sudani)',
        'en_SE' => 'isi-Ngisi (Sweden)',
        'en_SG' => 'isi-Ngisi (Singapore)',
        'en_SH' => 'isi-Ngisi (Saint Helena)',
        'en_SI' => 'isi-Ngisi (Slovenia)',
        'en_SK' => 'isi-Ngisi (Slovakia)',
        'en_SL' => 'isi-Ngisi (Sierra Leone)',
        'en_SZ' => 'isi-Ngisi (Swaziland)',
        'en_TC' => 'isi-Ngisi (Turks and Caicos Islands)',
        'en_TK' => 'isi-Ngisi (Thokelawu)',
        'en_TO' => 'isi-Ngisi (Thonga)',
        'en_TT' => 'isi-Ngisi (Trinidad le Tobago)',
        'en_TV' => 'isi-Ngisi (Thuvalu)',
        'en_TZ' => 'isi-Ngisi (Tanzaniya)',
        'en_UA' => 'isi-Ngisi (Yukreini)',
        'en_UG' => 'isi-Ngisi (Uganda)',
        'en_US' => 'isi-Ngisi (Amelika)',
        'en_VC' => 'isi-Ngisi (Saint Vincent and the Grenadines)',
        'en_VG' => 'isi-Ngisi (British Virgin Islands)',
        'en_VI' => 'isi-Ngisi (U.S. Virgin Islands)',
        'en_VU' => 'isi-Ngisi (Vhanuatu)',
        'en_WS' => 'isi-Ngisi (Samowa)',
        'en_ZA' => 'isi-Ngisi (Mzansi ye Afrika)',
        'en_ZM' => 'isi-Ngisi (Zambiya)',
        'en_ZW' => 'isi-Ngisi (Zimbabwe)',
        'es' => 'isi-Sipeyini',
        'es_AR' => 'isi-Sipeyini (Ajentina)',
        'es_BO' => 'isi-Sipeyini (Bholiviya)',
        'es_BR' => 'isi-Sipeyini (Brazili)',
        'es_BZ' => 'isi-Sipeyini (Bhelize)',
        'es_CL' => 'isi-Sipeyini (Chile)',
        'es_CO' => 'isi-Sipeyini (Kholombiya)',
        'es_CR' => 'isi-Sipeyini (Khosta Rikha)',
        'es_CU' => 'isi-Sipeyini (Cuba)',
        'es_DO' => 'isi-Sipeyini (Dominican Republic)',
        'es_EC' => 'isi-Sipeyini (Ecuador)',
        'es_ES' => 'isi-Sipeyini (Spain)',
        'es_GQ' => 'isi-Sipeyini (Equatorial Guinea)',
        'es_GT' => 'isi-Sipeyini (Guatemala)',
        'es_HN' => 'isi-Sipeyini (Honduras)',
        'es_MX' => 'isi-Sipeyini (Meksikho)',
        'es_NI' => 'isi-Sipeyini (Nicaragua)',
        'es_PA' => 'isi-Sipeyini (Panama)',
        'es_PE' => 'isi-Sipeyini (Pheru)',
        'es_PH' => 'isi-Sipeyini (Philippines)',
        'es_PR' => 'isi-Sipeyini (Puerto Rico)',
        'es_PY' => 'isi-Sipeyini (Paraguay)',
        'es_SV' => 'isi-Sipeyini (El Salvador)',
        'es_US' => 'isi-Sipeyini (Amelika)',
        'es_UY' => 'isi-Sipeyini (Yurugwai)',
        'es_VE' => 'isi-Sipeyini (Venezuela)',
        'fa' => 'isi-Pheshiyani',
        'fa_AF' => 'isi-Pheshiyani (Afghanistan)',
        'fa_IR' => 'isi-Pheshiyani (Iran)',
        'fr' => 'isi-Fulentshi',
        'fr_BE' => 'isi-Fulentshi (Bhelgium)',
        'fr_BF' => 'isi-Fulentshi (Bhukina Faso)',
        'fr_BI' => 'isi-Fulentshi (Bhurundi)',
        'fr_BJ' => 'isi-Fulentshi (Bhenini)',
        'fr_CA' => 'isi-Fulentshi (Khanada)',
        'fr_CD' => 'isi-Fulentshi (Democratic Republic of the Congo)',
        'fr_CF' => 'isi-Fulentshi (Central African Republic)',
        'fr_CG' => 'isi-Fulentshi (Khongo)',
        'fr_CH' => 'isi-Fulentshi (Switzerland)',
        'fr_CI' => 'isi-Fulentshi (Ivory Coast)',
        'fr_CM' => 'isi-Fulentshi (Khameruni)',
        'fr_DJ' => 'isi-Fulentshi (Djibouti)',
        'fr_DZ' => 'isi-Fulentshi (Aljeriya)',
        'fr_FR' => 'isi-Fulentshi (Furansi)',
        'fr_GA' => 'isi-Fulentshi (Gabhoni)',
        'fr_GF' => 'isi-Fulentshi (Gwiyana ye Furansi)',
        'fr_GN' => 'isi-Fulentshi (Guinea)',
        'fr_GP' => 'isi-Fulentshi (Guadeloupe)',
        'fr_GQ' => 'isi-Fulentshi (Equatorial Guinea)',
        'fr_HT' => 'isi-Fulentshi (Hayiti)',
        'fr_KM' => 'isi-Fulentshi (Khomoro)',
        'fr_LU' => 'isi-Fulentshi (Luxembourg)',
        'fr_MA' => 'isi-Fulentshi (Morokho)',
        'fr_MC' => 'isi-Fulentshi (Monakho)',
        'fr_MG' => 'isi-Fulentshi (Madagaska)',
        'fr_ML' => 'isi-Fulentshi (Mali)',
        'fr_MQ' => 'isi-Fulentshi (Martinique)',
        'fr_MR' => 'isi-Fulentshi (Mauritania)',
        'fr_MU' => 'isi-Fulentshi (Mauritius)',
        'fr_NC' => 'isi-Fulentshi (New Caledonia)',
        'fr_NE' => 'isi-Fulentshi (Niger)',
        'fr_PF' => 'isi-Fulentshi (Pholinesiya ye Fulansi)',
        'fr_PM' => 'isi-Fulentshi (Saint Pierre and Miquelon)',
        'fr_RE' => 'isi-Fulentshi (Réunion)',
        'fr_RW' => 'isi-Fulentshi (Ruwanda)',
        'fr_SC' => 'isi-Fulentshi (Seychelles)',
        'fr_SN' => 'isi-Fulentshi (Senegali)',
        'fr_SY' => 'isi-Fulentshi (Syria)',
        'fr_TD' => 'isi-Fulentshi (Chadi)',
        'fr_TG' => 'isi-Fulentshi (Thogo)',
        'fr_TN' => 'isi-Fulentshi (Tunisiya)',
        'fr_VU' => 'isi-Fulentshi (Vhanuatu)',
        'fr_WF' => 'isi-Fulentshi (Wallis and Futuna)',
        'fr_YT' => 'isi-Fulentshi (Mayotte)',
        'ha' => 'isi-Hausa',
        'ha_GH' => 'isi-Hausa (Ghana)',
        'ha_NE' => 'isi-Hausa (Niger)',
        'ha_NG' => 'isi-Hausa (Nigeriya)',
        'hi' => 'isi-Hindi',
        'hi_IN' => 'isi-Hindi (Indiya)',
        'hu' => 'isi-Hangari',
        'hu_HU' => 'isi-Hangari (Hungary)',
        'id' => 'isi-Indonesia',
        'id_ID' => 'isi-Indonesia (Indonesiya)',
        'ig' => 'isi-Igbo',
        'ig_NG' => 'isi-Igbo (Nigeriya)',
        'it' => 'isi-Italiano',
        'it_CH' => 'isi-Italiano (Switzerland)',
        'it_IT' => 'isi-Italiano (Itali)',
        'it_SM' => 'isi-Italiano (San Marino)',
        'it_VA' => 'isi-Italiano (Vatican State)',
        'ja' => 'isi-Japhani',
        'ja_JP' => 'isi-Japhani (Japan)',
        'jv' => 'isi-Java',
        'jv_ID' => 'isi-Java (Indonesiya)',
        'km' => 'isi-Khambodiya',
        'km_KH' => 'isi-Khambodiya (Cambodia)',
        'ko' => 'isi-Koriya',
        'ko_CN' => 'isi-Koriya (China)',
        'ko_KP' => 'isi-Koriya (North Korea)',
        'ko_KR' => 'isi-Koriya (South Korea)',
        'ms' => 'isi-Malayi',
        'ms_BN' => 'isi-Malayi (Brunei)',
        'ms_ID' => 'isi-Malayi (Indonesiya)',
        'ms_MY' => 'isi-Malayi (Malezhiya)',
        'ms_SG' => 'isi-Malayi (Singapore)',
        'my' => 'isi-Burma',
        'my_MM' => 'isi-Burma (Myanmar)',
        'nd' => 'isiNdebele',
        'nd_ZW' => 'isiNdebele (Zimbabwe)',
        'ne' => 'isi-Nepali',
        'ne_IN' => 'isi-Nepali (Indiya)',
        'ne_NP' => 'isi-Nepali (Nephali)',
        'nl' => 'isi-Dutch',
        'nl_AW' => 'isi-Dutch (Arubha)',
        'nl_BE' => 'isi-Dutch (Bhelgium)',
        'nl_NL' => 'isi-Dutch (Netherlands)',
        'nl_SR' => 'isi-Dutch (Suriname)',
        'pa' => 'isi-Phunjabi',
        'pa_IN' => 'isi-Phunjabi (Indiya)',
        'pa_PK' => 'isi-Phunjabi (Phakistani)',
        'pl' => 'isi-Pholoshi',
        'pl_PL' => 'isi-Pholoshi (Pholandi)',
        'pt' => 'isi-Potukezi',
        'pt_AO' => 'isi-Potukezi (Angola)',
        'pt_BR' => 'isi-Potukezi (Brazili)',
        'pt_CH' => 'isi-Potukezi (Switzerland)',
        'pt_CV' => 'isi-Potukezi (Cape Verde Islands)',
        'pt_GQ' => 'isi-Potukezi (Equatorial Guinea)',
        'pt_GW' => 'isi-Potukezi (Guinea-Bissau)',
        'pt_LU' => 'isi-Potukezi (Luxembourg)',
        'pt_MZ' => 'isi-Potukezi (Mozambique)',
        'pt_PT' => 'isi-Potukezi (Portugal)',
        'pt_ST' => 'isi-Potukezi (São Tomé and Príncipe)',
        'pt_TL' => 'isi-Potukezi (East Timor)',
        'ro' => 'isi-Romani',
        'ro_MD' => 'isi-Romani (Moldova)',
        'ro_RO' => 'isi-Romani (Romania)',
        'ru' => 'isi-Rashiya',
        'ru_BY' => 'isi-Rashiya (Bhelarusi)',
        'ru_KG' => 'isi-Rashiya (Kyrgyzstan)',
        'ru_KZ' => 'isi-Rashiya (Kazakhstan)',
        'ru_MD' => 'isi-Rashiya (Moldova)',
        'ru_RU' => 'isi-Rashiya (Rashiya)',
        'ru_UA' => 'isi-Rashiya (Yukreini)',
        'rw' => 'isi-Ruwanda',
        'rw_RW' => 'isi-Ruwanda (Ruwanda)',
        'so' => 'isi-Somali',
        'so_DJ' => 'isi-Somali (Djibouti)',
        'so_ET' => 'isi-Somali (Ethiopia)',
        'so_KE' => 'isi-Somali (Khenya)',
        'so_SO' => 'isi-Somali (Somaliya)',
        'sv' => 'isi-Swidishi',
        'sv_FI' => 'isi-Swidishi (Finland)',
        'sv_SE' => 'isi-Swidishi (Sweden)',
        'ta' => 'isi-Thamil',
        'ta_IN' => 'isi-Thamil (Indiya)',
        'ta_LK' => 'isi-Thamil (Sri Lanka)',
        'ta_MY' => 'isi-Thamil (Malezhiya)',
        'ta_SG' => 'isi-Thamil (Singapore)',
        'th' => 'isi-Thayi',
        'th_TH' => 'isi-Thayi (Thayilandi)',
        'tr' => 'isi-Thekishi',
        'tr_CY' => 'isi-Thekishi (Cyprus)',
        'tr_TR' => 'isi-Thekishi (Thekhi)',
        'uk' => 'isi-Ukrain',
        'uk_UA' => 'isi-Ukrain (Yukreini)',
        'ur' => 'isi-Udu',
        'ur_IN' => 'isi-Udu (Indiya)',
        'ur_PK' => 'isi-Udu (Phakistani)',
        'vi' => 'isi-Vietnamese',
        'vi_VN' => 'isi-Vietnamese (Vietnam)',
        'yo' => 'isi-Yorubha',
        'yo_BJ' => 'isi-Yorubha (Bhenini)',
        'yo_NG' => 'isi-Yorubha (Nigeriya)',
        'zh' => 'isi-China',
        'zh_CN' => 'isi-China (China)',
        'zh_SG' => 'isi-China (Singapore)',
        'zh_TW' => 'isi-China (Thayiwani)',
        'zu' => 'isi-Zulu',
        'zu_ZA' => 'isi-Zulu (Mzansi ye Afrika)',
    ],
];
