<?php

return [
    'Names' => [
        'af' => 'آفريڪي',
        'af_NA' => 'آفريڪي (نيميبيا)',
        'af_ZA' => 'آفريڪي (ڏکڻ آفريقا)',
        'ak' => 'اڪان',
        'ak_GH' => 'اڪان (گهانا)',
        'am' => 'امهاري',
        'am_ET' => 'امهاري (ايٿوپيا)',
        'ar' => 'عربي',
        'ar_001' => 'عربي (دنيا)',
        'ar_AE' => 'عربي (متحده عرب امارات)',
        'ar_BH' => 'عربي (بحرين)',
        'ar_DJ' => 'عربي (ڊجبيوتي)',
        'ar_DZ' => 'عربي (الجيريا)',
        'ar_EG' => 'عربي (مصر)',
        'ar_EH' => 'عربي (اولهه صحارا)',
        'ar_ER' => 'عربي (ايريٽيريا)',
        'ar_IL' => 'عربي (اسرائيل)',
        'ar_IQ' => 'عربي (عراق)',
        'ar_JO' => 'عربي (اردن)',
        'ar_KM' => 'عربي (ڪوموروس)',
        'ar_KW' => 'عربي (ڪويت)',
        'ar_LB' => 'عربي (لبنان)',
        'ar_LY' => 'عربي (لبيا)',
        'ar_MA' => 'عربي (مراڪش)',
        'ar_MR' => 'عربي (موريتانيا)',
        'ar_OM' => 'عربي (عمان)',
        'ar_PS' => 'عربي (فلسطيني علائقا)',
        'ar_QA' => 'عربي (قطر)',
        'ar_SA' => 'عربي (سعودي عرب)',
        'ar_SD' => 'عربي (سوڊان)',
        'ar_SO' => 'عربي (سوماليا)',
        'ar_SS' => 'عربي (ڏکڻ سوڊان)',
        'ar_SY' => 'عربي (شام)',
        'ar_TD' => 'عربي (چاڊ)',
        'ar_TN' => 'عربي (تيونيسيا)',
        'ar_YE' => 'عربي (يمن)',
        'as' => 'آسامي',
        'as_IN' => 'آسامي (ڀارت)',
        'az' => 'آزربائيجاني',
        'az_AZ' => 'آزربائيجاني (آذربائيجان)',
        'az_Cyrl' => 'آزربائيجاني (سيريلي)',
        'az_Cyrl_AZ' => 'آزربائيجاني (سيريلي, آذربائيجان)',
        'az_Latn' => 'آزربائيجاني (لاطيني)',
        'az_Latn_AZ' => 'آزربائيجاني (لاطيني, آذربائيجان)',
        'ba' => 'ڪينيڊا',
        'ba_RU' => 'ڪينيڊا (روس)',
        'be' => 'بيلاروسي',
        'be_BY' => 'بيلاروسي (بيلاروس)',
        'bg' => 'بلغاريائي',
        'bg_BG' => 'بلغاريائي (بلغاريا)',
        'bm' => 'بمبارا',
        'bm_ML' => 'بمبارا (مالي)',
        'bn' => 'بنگلا',
        'bn_BD' => 'بنگلا (بنگلاديش)',
        'bn_IN' => 'بنگلا (ڀارت)',
        'bo' => 'تبيتائي',
        'bo_CN' => 'تبيتائي (چين)',
        'bo_IN' => 'تبيتائي (ڀارت)',
        'br' => 'بريٽن',
        'br_FR' => 'بريٽن (فرانس)',
        'bs' => 'بوسنيائي',
        'bs_BA' => 'بوسنيائي (بوسنيا ۽ هرزيگووينا)',
        'bs_Cyrl' => 'بوسنيائي (سيريلي)',
        'bs_Cyrl_BA' => 'بوسنيائي (سيريلي, بوسنيا ۽ هرزيگووينا)',
        'bs_Latn' => 'بوسنيائي (لاطيني)',
        'bs_Latn_BA' => 'بوسنيائي (لاطيني, بوسنيا ۽ هرزيگووينا)',
        'ca' => 'ڪيٽالان',
        'ca_AD' => 'ڪيٽالان (اندورا)',
        'ca_ES' => 'ڪيٽالان (اسپين)',
        'ca_FR' => 'ڪيٽالان (فرانس)',
        'ca_IT' => 'ڪيٽالان (اٽلي)',
        'ce' => 'چیچن',
        'ce_RU' => 'چیچن (روس)',
        'cs' => 'چيڪ',
        'cs_CZ' => 'چيڪ (چيڪيا)',
        'cv' => 'چو واش',
        'cv_RU' => 'چو واش (روس)',
        'cy' => 'ويلش',
        'cy_GB' => 'ويلش (برطانيہ)',
        'da' => 'ڊينش',
        'da_DK' => 'ڊينش (ڊينمارڪ)',
        'da_GL' => 'ڊينش (گرين لينڊ)',
        'de' => 'جرمن',
        'de_AT' => 'جرمن (آسٽريا)',
        'de_BE' => 'جرمن (بيلجيم)',
        'de_CH' => 'جرمن (سوئزرلينڊ)',
        'de_DE' => 'جرمن (جرمني)',
        'de_IT' => 'جرمن (اٽلي)',
        'de_LI' => 'جرمن (لچي ٽينسٽين)',
        'de_LU' => 'جرمن (لگزمبرگ)',
        'dz' => 'زونخا',
        'dz_BT' => 'زونخا (ڀوٽان)',
        'ee' => 'ايو',
        'ee_GH' => 'ايو (گهانا)',
        'ee_TG' => 'ايو (ٽوگو)',
        'el' => 'يوناني',
        'el_CY' => 'يوناني (سائپرس)',
        'el_GR' => 'يوناني (يونان)',
        'en' => 'انگريزي',
        'en_001' => 'انگريزي (دنيا)',
        'en_150' => 'انگريزي (يورپ)',
        'en_AE' => 'انگريزي (متحده عرب امارات)',
        'en_AG' => 'انگريزي (اينٽيگا ۽ باربوڊا)',
        'en_AI' => 'انگريزي (انگويلا)',
        'en_AS' => 'انگريزي (آمريڪي ساموا)',
        'en_AT' => 'انگريزي (آسٽريا)',
        'en_AU' => 'انگريزي (آسٽريليا)',
        'en_BB' => 'انگريزي (باربڊوس)',
        'en_BE' => 'انگريزي (بيلجيم)',
        'en_BI' => 'انگريزي (برونڊي)',
        'en_BM' => 'انگريزي (برمودا)',
        'en_BS' => 'انگريزي (باهاماس)',
        'en_BW' => 'انگريزي (بوٽسوانا)',
        'en_BZ' => 'انگريزي (بيليز)',
        'en_CA' => 'انگريزي (ڪينيڊا)',
        'en_CC' => 'انگريزي (ڪوڪوس ٻيٽ)',
        'en_CH' => 'انگريزي (سوئزرلينڊ)',
        'en_CK' => 'انگريزي (ڪوڪ ٻيٽ)',
        'en_CM' => 'انگريزي (ڪيمرون)',
        'en_CX' => 'انگريزي (ڪرسمس ٻيٽ)',
        'en_CY' => 'انگريزي (سائپرس)',
        'en_CZ' => 'انگريزي (چيڪيا)',
        'en_DE' => 'انگريزي (جرمني)',
        'en_DK' => 'انگريزي (ڊينمارڪ)',
        'en_DM' => 'انگريزي (ڊومينيڪا)',
        'en_EE' => 'انگريزي (ايسٽونيا)',
        'en_ER' => 'انگريزي (ايريٽيريا)',
        'en_ES' => 'انگريزي (اسپين)',
        'en_FI' => 'انگريزي (فن لينڊ)',
        'en_FJ' => 'انگريزي (فجي)',
        'en_FK' => 'انگريزي (فاڪ لينڊ ٻيٽ)',
        'en_FM' => 'انگريزي (مائڪرونيشيا)',
        'en_FR' => 'انگريزي (فرانس)',
        'en_GB' => 'انگريزي (برطانيہ)',
        'en_GD' => 'انگريزي (گريناڊا)',
        'en_GE' => 'انگريزي (جارجيا)',
        'en_GG' => 'انگريزي (گورنسي)',
        'en_GH' => 'انگريزي (گهانا)',
        'en_GI' => 'انگريزي (جبرالٽر)',
        'en_GM' => 'انگريزي (گيمبيا)',
        'en_GS' => 'انگريزي (ڏکڻ جارجيا ۽ ڏکڻ سينڊوچ ٻيٽ)',
        'en_GU' => 'انگريزي (گوام)',
        'en_GY' => 'انگريزي (گيانا)',
        'en_HK' => 'انگريزي (هانگ ڪانگ SAR چين)',
        'en_HU' => 'انگريزي (هنگري)',
        'en_ID' => 'انگريزي (انڊونيشيا)',
        'en_IE' => 'انگريزي (آئرلينڊ)',
        'en_IL' => 'انگريزي (اسرائيل)',
        'en_IM' => 'انگريزي (انسانن جو ٻيٽ)',
        'en_IN' => 'انگريزي (ڀارت)',
        'en_IO' => 'انگريزي (برطانوي هندي سمنڊ خطو)',
        'en_IT' => 'انگريزي (اٽلي)',
        'en_JE' => 'انگريزي (جرسي)',
        'en_JM' => 'انگريزي (جميڪا)',
        'en_JP' => 'انگريزي (جاپان)',
        'en_KE' => 'انگريزي (ڪينيا)',
        'en_KI' => 'انگريزي (ڪرباتي)',
        'en_KN' => 'انگريزي (سينٽ ڪٽس و نيوس)',
        'en_KY' => 'انگريزي (ڪي مين ٻيٽ)',
        'en_LC' => 'انگريزي (سينٽ لوسيا)',
        'en_LR' => 'انگريزي (لائبیریا)',
        'en_LS' => 'انگريزي (ليسوٿو)',
        'en_LT' => 'انگريزي (لٿونيا)',
        'en_LV' => 'انگريزي (لاتويا)',
        'en_MG' => 'انگريزي (مدگاسڪر)',
        'en_MH' => 'انگريزي (مارشل ٻيٽ)',
        'en_MO' => 'انگريزي (مڪائو SAR چين)',
        'en_MP' => 'انگريزي (اتريان ماريانا ٻيٽ)',
        'en_MS' => 'انگريزي (مونٽسراٽ)',
        'en_MT' => 'انگريزي (مالٽا)',
        'en_MU' => 'انگريزي (موريشس)',
        'en_MV' => 'انگريزي (مالديپ)',
        'en_MW' => 'انگريزي (مالاوي)',
        'en_MY' => 'انگريزي (ملائيشيا)',
        'en_NA' => 'انگريزي (نيميبيا)',
        'en_NF' => 'انگريزي (نورفوڪ ٻيٽ)',
        'en_NG' => 'انگريزي (نائيجيريا)',
        'en_NL' => 'انگريزي (نيدرلينڊ)',
        'en_NO' => 'انگريزي (ناروي)',
        'en_NR' => 'انگريزي (نائورو)',
        'en_NU' => 'انگريزي (نووي)',
        'en_NZ' => 'انگريزي (نيو زيلينڊ)',
        'en_PG' => 'انگريزي (پاپوا نیو گني)',
        'en_PH' => 'انگريزي (فلپائن)',
        'en_PK' => 'انگريزي (پاڪستان)',
        'en_PL' => 'انگريزي (پولينڊ)',
        'en_PN' => 'انگريزي (پٽڪئرن ٻيٽ)',
        'en_PR' => 'انگريزي (پيوئرٽو ريڪو)',
        'en_PT' => 'انگريزي (پرتگال)',
        'en_PW' => 'انگريزي (پلائو)',
        'en_RO' => 'انگريزي (رومانيا)',
        'en_RW' => 'انگريزي (روانڊا)',
        'en_SB' => 'انگريزي (سولومون ٻيٽَ)',
        'en_SC' => 'انگريزي (شي شلز)',
        'en_SD' => 'انگريزي (سوڊان)',
        'en_SE' => 'انگريزي (سوئيڊن)',
        'en_SG' => 'انگريزي (سنگاپور)',
        'en_SH' => 'انگريزي (سينٽ ھيلينا)',
        'en_SI' => 'انگريزي (سلوینیا)',
        'en_SK' => 'انگريزي (سلوواڪيا)',
        'en_SL' => 'انگريزي (سيرا ليون)',
        'en_SS' => 'انگريزي (ڏکڻ سوڊان)',
        'en_SX' => 'انگريزي (سنٽ مارٽن)',
        'en_SZ' => 'انگريزي (ايسواٽني)',
        'en_TC' => 'انگريزي (ترڪ ۽ ڪيڪوس ٻيٽ)',
        'en_TK' => 'انگريزي (ٽوڪلائو)',
        'en_TO' => 'انگريزي (ٽونگا)',
        'en_TT' => 'انگريزي (ٽرينيڊاڊ ۽ ٽوباگو)',
        'en_TV' => 'انگريزي (توالو)',
        'en_TZ' => 'انگريزي (تنزانيا)',
        'en_UA' => 'انگريزي (يوڪرين)',
        'en_UG' => 'انگريزي (يوگنڊا)',
        'en_UM' => 'انگريزي (آمريڪي خارجي ٻيٽ)',
        'en_US' => 'انگريزي (آمريڪا جون گڏيل رياستون)',
        'en_VC' => 'انگريزي (سینٽ ونسنت ۽ گریناڊینز)',
        'en_VG' => 'انگريزي (برطانوي ورجن ٻيٽ)',
        'en_VI' => 'انگريزي (آمريڪي ورجن ٻيٽ)',
        'en_VU' => 'انگريزي (وينيٽيو)',
        'en_WS' => 'انگريزي (ساموا)',
        'en_ZA' => 'انگريزي (ڏکڻ آفريقا)',
        'en_ZM' => 'انگريزي (زيمبيا)',
        'en_ZW' => 'انگريزي (زمبابوي)',
        'eo' => 'ايسپرانٽو',
        'eo_001' => 'ايسپرانٽو (دنيا)',
        'es' => 'هسپانوي',
        'es_419' => 'هسپانوي (لاطيني آمريڪا)',
        'es_AR' => 'هسپانوي (ارجنٽينا)',
        'es_BO' => 'هسپانوي (بوليويا)',
        'es_BR' => 'هسپانوي (برازيل)',
        'es_BZ' => 'هسپانوي (بيليز)',
        'es_CL' => 'هسپانوي (چلي)',
        'es_CO' => 'هسپانوي (ڪولمبيا)',
        'es_CR' => 'هسپانوي (ڪوسٽا ريڪا)',
        'es_CU' => 'هسپانوي (ڪيوبا)',
        'es_DO' => 'هسپانوي (ڊومينيڪن جمهوريه)',
        'es_EC' => 'هسپانوي (ايڪواڊور)',
        'es_ES' => 'هسپانوي (اسپين)',
        'es_GQ' => 'هسپانوي (ايڪوٽوريل گائينا)',
        'es_GT' => 'هسپانوي (گوئٽي مالا)',
        'es_HN' => 'هسپانوي (هنڊورس)',
        'es_MX' => 'هسپانوي (ميڪسيڪو)',
        'es_NI' => 'هسپانوي (نڪراگوا)',
        'es_PA' => 'هسپانوي (پناما)',
        'es_PE' => 'هسپانوي (پيرو)',
        'es_PH' => 'هسپانوي (فلپائن)',
        'es_PR' => 'هسپانوي (پيوئرٽو ريڪو)',
        'es_PY' => 'هسپانوي (پيراگوءِ)',
        'es_SV' => 'هسپانوي (ال سلواڊور)',
        'es_US' => 'هسپانوي (آمريڪا جون گڏيل رياستون)',
        'es_UY' => 'هسپانوي (يوروگوءِ)',
        'es_VE' => 'هسپانوي (وينزويلا)',
        'et' => 'ايستونائي',
        'et_EE' => 'ايستونائي (ايسٽونيا)',
        'eu' => 'باسق',
        'eu_ES' => 'باسق (اسپين)',
        'fa' => 'فارسي',
        'fa_AF' => 'فارسي (افغانستان)',
        'fa_IR' => 'فارسي (ايران)',
        'ff' => 'فلاهه',
        'ff_Adlm' => 'فلاهه (ايڊلام)',
        'ff_Adlm_BF' => 'فلاهه (ايڊلام, برڪينا فاسو)',
        'ff_Adlm_CM' => 'فلاهه (ايڊلام, ڪيمرون)',
        'ff_Adlm_GH' => 'فلاهه (ايڊلام, گهانا)',
        'ff_Adlm_GM' => 'فلاهه (ايڊلام, گيمبيا)',
        'ff_Adlm_GN' => 'فلاهه (ايڊلام, گني)',
        'ff_Adlm_GW' => 'فلاهه (ايڊلام, گني بسائو)',
        'ff_Adlm_LR' => 'فلاهه (ايڊلام, لائبیریا)',
        'ff_Adlm_MR' => 'فلاهه (ايڊلام, موريتانيا)',
        'ff_Adlm_NE' => 'فلاهه (ايڊلام, نائيجر)',
        'ff_Adlm_NG' => 'فلاهه (ايڊلام, نائيجيريا)',
        'ff_Adlm_SL' => 'فلاهه (ايڊلام, سيرا ليون)',
        'ff_Adlm_SN' => 'فلاهه (ايڊلام, سينيگال)',
        'ff_CM' => 'فلاهه (ڪيمرون)',
        'ff_GN' => 'فلاهه (گني)',
        'ff_Latn' => 'فلاهه (لاطيني)',
        'ff_Latn_BF' => 'فلاهه (لاطيني, برڪينا فاسو)',
        'ff_Latn_CM' => 'فلاهه (لاطيني, ڪيمرون)',
        'ff_Latn_GH' => 'فلاهه (لاطيني, گهانا)',
        'ff_Latn_GM' => 'فلاهه (لاطيني, گيمبيا)',
        'ff_Latn_GN' => 'فلاهه (لاطيني, گني)',
        'ff_Latn_GW' => 'فلاهه (لاطيني, گني بسائو)',
        'ff_Latn_LR' => 'فلاهه (لاطيني, لائبیریا)',
        'ff_Latn_MR' => 'فلاهه (لاطيني, موريتانيا)',
        'ff_Latn_NE' => 'فلاهه (لاطيني, نائيجر)',
        'ff_Latn_NG' => 'فلاهه (لاطيني, نائيجيريا)',
        'ff_Latn_SL' => 'فلاهه (لاطيني, سيرا ليون)',
        'ff_Latn_SN' => 'فلاهه (لاطيني, سينيگال)',
        'ff_MR' => 'فلاهه (موريتانيا)',
        'ff_SN' => 'فلاهه (سينيگال)',
        'fi' => 'فنش',
        'fi_FI' => 'فنش (فن لينڊ)',
        'fo' => 'فيروايس',
        'fo_DK' => 'فيروايس (ڊينمارڪ)',
        'fo_FO' => 'فيروايس (فارو ٻيٽ)',
        'fr' => 'فرانسيسي',
        'fr_BE' => 'فرانسيسي (بيلجيم)',
        'fr_BF' => 'فرانسيسي (برڪينا فاسو)',
        'fr_BI' => 'فرانسيسي (برونڊي)',
        'fr_BJ' => 'فرانسيسي (بينن)',
        'fr_BL' => 'فرانسيسي (سینٽ برٿلیمی)',
        'fr_CA' => 'فرانسيسي (ڪينيڊا)',
        'fr_CD' => 'فرانسيسي (ڪانگو -ڪنشاسا)',
        'fr_CF' => 'فرانسيسي (وچ آفريقي جمهوريه)',
        'fr_CG' => 'فرانسيسي (ڪانگو - برازاویل)',
        'fr_CH' => 'فرانسيسي (سوئزرلينڊ)',
        'fr_CI' => 'فرانسيسي (ڪوٽي ويرا)',
        'fr_CM' => 'فرانسيسي (ڪيمرون)',
        'fr_DJ' => 'فرانسيسي (ڊجبيوتي)',
        'fr_DZ' => 'فرانسيسي (الجيريا)',
        'fr_FR' => 'فرانسيسي (فرانس)',
        'fr_GA' => 'فرانسيسي (گبون)',
        'fr_GF' => 'فرانسيسي (فرانسيسي گيانا)',
        'fr_GN' => 'فرانسيسي (گني)',
        'fr_GP' => 'فرانسيسي (گواڊیلوپ)',
        'fr_GQ' => 'فرانسيسي (ايڪوٽوريل گائينا)',
        'fr_HT' => 'فرانسيسي (هيٽي)',
        'fr_KM' => 'فرانسيسي (ڪوموروس)',
        'fr_LU' => 'فرانسيسي (لگزمبرگ)',
        'fr_MA' => 'فرانسيسي (مراڪش)',
        'fr_MC' => 'فرانسيسي (موناڪو)',
        'fr_MF' => 'فرانسيسي (سينٽ مارٽن)',
        'fr_MG' => 'فرانسيسي (مدگاسڪر)',
        'fr_ML' => 'فرانسيسي (مالي)',
        'fr_MQ' => 'فرانسيسي (مارتينڪ)',
        'fr_MR' => 'فرانسيسي (موريتانيا)',
        'fr_MU' => 'فرانسيسي (موريشس)',
        'fr_NC' => 'فرانسيسي (نیو ڪالیڊونیا)',
        'fr_NE' => 'فرانسيسي (نائيجر)',
        'fr_PF' => 'فرانسيسي (فرانسيسي پولينيشيا)',
        'fr_PM' => 'فرانسيسي (سينٽ پيئر ۽ ميڪيلون)',
        'fr_RE' => 'فرانسيسي (ري يونين)',
        'fr_RW' => 'فرانسيسي (روانڊا)',
        'fr_SC' => 'فرانسيسي (شي شلز)',
        'fr_SN' => 'فرانسيسي (سينيگال)',
        'fr_SY' => 'فرانسيسي (شام)',
        'fr_TD' => 'فرانسيسي (چاڊ)',
        'fr_TG' => 'فرانسيسي (ٽوگو)',
        'fr_TN' => 'فرانسيسي (تيونيسيا)',
        'fr_VU' => 'فرانسيسي (وينيٽيو)',
        'fr_WF' => 'فرانسيسي (والس ۽ فتونا)',
        'fr_YT' => 'فرانسيسي (مياتي)',
        'fy' => 'مغربي فريشن',
        'fy_NL' => 'مغربي فريشن (نيدرلينڊ)',
        'ga' => 'آئرش',
        'ga_GB' => 'آئرش (برطانيہ)',
        'ga_IE' => 'آئرش (آئرلينڊ)',
        'gd' => 'اسڪاٽش گيلڪ',
        'gd_GB' => 'اسڪاٽش گيلڪ (برطانيہ)',
        'gl' => 'گليشئين',
        'gl_ES' => 'گليشئين (اسپين)',
        'gu' => 'گجراتي',
        'gu_IN' => 'گجراتي (ڀارت)',
        'gv' => 'مينڪس',
        'gv_IM' => 'مينڪس (انسانن جو ٻيٽ)',
        'ha' => 'هوسا',
        'ha_GH' => 'هوسا (گهانا)',
        'ha_NE' => 'هوسا (نائيجر)',
        'ha_NG' => 'هوسا (نائيجيريا)',
        'he' => 'عبراني',
        'he_IL' => 'عبراني (اسرائيل)',
        'hi' => 'هندي',
        'hi_IN' => 'هندي (ڀارت)',
        'hi_Latn' => 'هندي (لاطيني)',
        'hi_Latn_IN' => 'هندي (لاطيني, ڀارت)',
        'hr' => 'ڪروشيائي',
        'hr_BA' => 'ڪروشيائي (بوسنيا ۽ هرزيگووينا)',
        'hr_HR' => 'ڪروشيائي (ڪروئيشيا)',
        'hu' => 'هنگري',
        'hu_HU' => 'هنگري (هنگري)',
        'hy' => 'ارماني',
        'hy_AM' => 'ارماني (آرمينيا)',
        'ia' => 'انٽرلنگئا',
        'ia_001' => 'انٽرلنگئا (دنيا)',
        'id' => 'انڊونيشي',
        'id_ID' => 'انڊونيشي (انڊونيشيا)',
        'ie' => 'انٽرلنگئي',
        'ie_EE' => 'انٽرلنگئي (ايسٽونيا)',
        'ig' => 'اگبو',
        'ig_NG' => 'اگبو (نائيجيريا)',
        'ii' => 'سچوان يي',
        'ii_CN' => 'سچوان يي (چين)',
        'is' => 'آئيس لينڊڪ',
        'is_IS' => 'آئيس لينڊڪ (آئس لينڊ)',
        'it' => 'اطالوي',
        'it_CH' => 'اطالوي (سوئزرلينڊ)',
        'it_IT' => 'اطالوي (اٽلي)',
        'it_SM' => 'اطالوي (سان مرینو)',
        'it_VA' => 'اطالوي (ويٽڪين سٽي)',
        'ja' => 'جاپاني',
        'ja_JP' => 'جاپاني (جاپان)',
        'jv' => 'جاونيز',
        'jv_ID' => 'جاونيز (انڊونيشيا)',
        'ka' => 'جارجيائي',
        'ka_GE' => 'جارجيائي (جارجيا)',
        'ki' => 'اڪويو',
        'ki_KE' => 'اڪويو (ڪينيا)',
        'kk' => 'قازق',
        'kk_Arab' => 'قازق (عربي)',
        'kk_Arab_CN' => 'قازق (عربي, چين)',
        'kk_Cyrl' => 'قازق (سيريلي)',
        'kk_Cyrl_KZ' => 'قازق (سيريلي, قازقستان)',
        'kk_KZ' => 'قازق (قازقستان)',
        'kl' => 'ڪالا ليسٽ',
        'kl_GL' => 'ڪالا ليسٽ (گرين لينڊ)',
        'km' => 'خمر',
        'km_KH' => 'خمر (ڪمبوڊيا)',
        'kn' => 'ڪناڊا',
        'kn_IN' => 'ڪناڊا (ڀارت)',
        'ko' => 'ڪوريائي',
        'ko_CN' => 'ڪوريائي (چين)',
        'ko_KP' => 'ڪوريائي (اتر ڪوريا)',
        'ko_KR' => 'ڪوريائي (ڏکڻ ڪوريا)',
        'ks' => 'ڪشميري',
        'ks_Arab' => 'ڪشميري (عربي)',
        'ks_Arab_IN' => 'ڪشميري (عربي, ڀارت)',
        'ks_Deva' => 'ڪشميري (ديوناگري)',
        'ks_Deva_IN' => 'ڪشميري (ديوناگري, ڀارت)',
        'ks_IN' => 'ڪشميري (ڀارت)',
        'ku' => 'ڪردي',
        'ku_Latn' => 'ڪردي (لاطيني)',
        'ku_Latn_IQ' => 'ڪردي (لاطيني, عراق)',
        'ku_Latn_SY' => 'ڪردي (لاطيني, شام)',
        'ku_Latn_TR' => 'ڪردي (لاطيني, ترڪييي)',
        'ku_SY' => 'ڪردي (شام)',
        'ku_TR' => 'ڪردي (ترڪييي)',
        'kw' => 'ڪورنش',
        'kw_GB' => 'ڪورنش (برطانيہ)',
        'ky' => 'ڪرغيز',
        'ky_KG' => 'ڪرغيز (ڪرغستان)',
        'lb' => 'لگزمبرگ',
        'lb_LU' => 'لگزمبرگ (لگزمبرگ)',
        'lg' => 'گاندا',
        'lg_UG' => 'گاندا (يوگنڊا)',
        'ln' => 'لنگالا',
        'ln_AO' => 'لنگالا (انگولا)',
        'ln_CD' => 'لنگالا (ڪانگو -ڪنشاسا)',
        'ln_CF' => 'لنگالا (وچ آفريقي جمهوريه)',
        'ln_CG' => 'لنگالا (ڪانگو - برازاویل)',
        'lo' => 'لائو',
        'lo_LA' => 'لائو (لائوس)',
        'lt' => 'ليٿونيائي',
        'lt_LT' => 'ليٿونيائي (لٿونيا)',
        'lu' => 'لوبا-ڪتانگا',
        'lu_CD' => 'لوبا-ڪتانگا (ڪانگو -ڪنشاسا)',
        'lv' => 'لاتوين',
        'lv_LV' => 'لاتوين (لاتويا)',
        'mg' => 'ملاگاسي',
        'mg_MG' => 'ملاگاسي (مدگاسڪر)',
        'mi' => 'مائوري',
        'mi_NZ' => 'مائوري (نيو زيلينڊ)',
        'mk' => 'ميسي ڊونيائي',
        'mk_MK' => 'ميسي ڊونيائي (اتر مقدونيا)',
        'ml' => 'مليالم',
        'ml_IN' => 'مليالم (ڀارت)',
        'mn' => 'منگولي',
        'mn_MN' => 'منگولي (منگوليا)',
        'mr' => 'مراٺي',
        'mr_IN' => 'مراٺي (ڀارت)',
        'ms' => 'ملي',
        'ms_BN' => 'ملي (برونائي)',
        'ms_ID' => 'ملي (انڊونيشيا)',
        'ms_MY' => 'ملي (ملائيشيا)',
        'ms_SG' => 'ملي (سنگاپور)',
        'mt' => 'مالٽي',
        'mt_MT' => 'مالٽي (مالٽا)',
        'my' => 'برمي',
        'my_MM' => 'برمي (ميانمار [برما])',
        'nb' => 'نارويائي بوڪمال',
        'nb_NO' => 'نارويائي بوڪمال (ناروي)',
        'nb_SJ' => 'نارويائي بوڪمال (سوالبارڊ ۽ يان ماین)',
        'nd' => 'اتر دبيلي',
        'nd_ZW' => 'اتر دبيلي (زمبابوي)',
        'ne' => 'نيپالي',
        'ne_IN' => 'نيپالي (ڀارت)',
        'ne_NP' => 'نيپالي (نيپال)',
        'nl' => 'ڊچ',
        'nl_AW' => 'ڊچ (عروبا)',
        'nl_BE' => 'ڊچ (بيلجيم)',
        'nl_BQ' => 'ڊچ (ڪيريبين نيدرلينڊ)',
        'nl_CW' => 'ڊچ (ڪيوراسائو)',
        'nl_NL' => 'ڊچ (نيدرلينڊ)',
        'nl_SR' => 'ڊچ (سورينام)',
        'nl_SX' => 'ڊچ (سنٽ مارٽن)',
        'nn' => 'نارويائي نيوناسڪ',
        'nn_NO' => 'نارويائي نيوناسڪ (ناروي)',
        'no' => 'نارويجيائي',
        'no_NO' => 'نارويجيائي (ناروي)',
        'oc' => 'آڪسيٽن',
        'oc_ES' => 'آڪسيٽن (اسپين)',
        'oc_FR' => 'آڪسيٽن (فرانس)',
        'om' => 'اورومو',
        'om_ET' => 'اورومو (ايٿوپيا)',
        'om_KE' => 'اورومو (ڪينيا)',
        'or' => 'اوڊيا',
        'or_IN' => 'اوڊيا (ڀارت)',
        'os' => 'اوسيٽڪ',
        'os_GE' => 'اوسيٽڪ (جارجيا)',
        'os_RU' => 'اوسيٽڪ (روس)',
        'pa' => 'پنجابي',
        'pa_Arab' => 'پنجابي (عربي)',
        'pa_Arab_PK' => 'پنجابي (عربي, پاڪستان)',
        'pa_Guru' => 'پنجابي (گرمکي)',
        'pa_Guru_IN' => 'پنجابي (گرمکي, ڀارت)',
        'pa_IN' => 'پنجابي (ڀارت)',
        'pa_PK' => 'پنجابي (پاڪستان)',
        'pl' => 'پولش',
        'pl_PL' => 'پولش (پولينڊ)',
        'ps' => 'پشتو',
        'ps_AF' => 'پشتو (افغانستان)',
        'ps_PK' => 'پشتو (پاڪستان)',
        'pt' => 'پورٽگليز',
        'pt_AO' => 'پورٽگليز (انگولا)',
        'pt_BR' => 'پورٽگليز (برازيل)',
        'pt_CH' => 'پورٽگليز (سوئزرلينڊ)',
        'pt_CV' => 'پورٽگليز (ڪيپ وردي)',
        'pt_GQ' => 'پورٽگليز (ايڪوٽوريل گائينا)',
        'pt_GW' => 'پورٽگليز (گني بسائو)',
        'pt_LU' => 'پورٽگليز (لگزمبرگ)',
        'pt_MO' => 'پورٽگليز (مڪائو SAR چين)',
        'pt_MZ' => 'پورٽگليز (موزمبیق)',
        'pt_PT' => 'پورٽگليز (پرتگال)',
        'pt_ST' => 'پورٽگليز (سائو ٽومي ۽ پرنسپیي)',
        'pt_TL' => 'پورٽگليز (تيمور ليستي)',
        'qu' => 'ڪيچوا',
        'qu_BO' => 'ڪيچوا (بوليويا)',
        'qu_EC' => 'ڪيچوا (ايڪواڊور)',
        'qu_PE' => 'ڪيچوا (پيرو)',
        'rm' => 'رومانش',
        'rm_CH' => 'رومانش (سوئزرلينڊ)',
        'rn' => 'رونڊي',
        'rn_BI' => 'رونڊي (برونڊي)',
        'ro' => 'روماني',
        'ro_MD' => 'روماني (مالدووا)',
        'ro_RO' => 'روماني (رومانيا)',
        'ru' => 'روسي',
        'ru_BY' => 'روسي (بيلاروس)',
        'ru_KG' => 'روسي (ڪرغستان)',
        'ru_KZ' => 'روسي (قازقستان)',
        'ru_MD' => 'روسي (مالدووا)',
        'ru_RU' => 'روسي (روس)',
        'ru_UA' => 'روسي (يوڪرين)',
        'rw' => 'ڪنيار وانڊا',
        'rw_RW' => 'ڪنيار وانڊا (روانڊا)',
        'sa' => 'سنسڪرت',
        'sa_IN' => 'سنسڪرت (ڀارت)',
        'sc' => 'سارڊيني',
        'sc_IT' => 'سارڊيني (اٽلي)',
        'sd' => 'سنڌي',
        'sd_Arab' => 'سنڌي (عربي)',
        'sd_Arab_PK' => 'سنڌي (عربي, پاڪستان)',
        'sd_Deva' => 'سنڌي (ديوناگري)',
        'sd_Deva_IN' => 'سنڌي (ديوناگري, ڀارت)',
        'sd_IN' => 'سنڌي (ڀارت)',
        'sd_PK' => 'سنڌي (پاڪستان)',
        'se' => 'اتر سامي',
        'se_FI' => 'اتر سامي (فن لينڊ)',
        'se_NO' => 'اتر سامي (ناروي)',
        'se_SE' => 'اتر سامي (سوئيڊن)',
        'sg' => 'سانگو',
        'sg_CF' => 'سانگو (وچ آفريقي جمهوريه)',
        'si' => 'سنهالا',
        'si_LK' => 'سنهالا (سري لنڪا)',
        'sk' => 'سلواڪي',
        'sk_SK' => 'سلواڪي (سلوواڪيا)',
        'sl' => 'سلوويني',
        'sl_SI' => 'سلوويني (سلوینیا)',
        'sn' => 'شونا',
        'sn_ZW' => 'شونا (زمبابوي)',
        'so' => 'سومالي',
        'so_DJ' => 'سومالي (ڊجبيوتي)',
        'so_ET' => 'سومالي (ايٿوپيا)',
        'so_KE' => 'سومالي (ڪينيا)',
        'so_SO' => 'سومالي (سوماليا)',
        'sq' => 'الباني',
        'sq_AL' => 'الباني (البانيا)',
        'sq_MK' => 'الباني (اتر مقدونيا)',
        'sr' => 'سربيائي',
        'sr_BA' => 'سربيائي (بوسنيا ۽ هرزيگووينا)',
        'sr_Cyrl' => 'سربيائي (سيريلي)',
        'sr_Cyrl_BA' => 'سربيائي (سيريلي, بوسنيا ۽ هرزيگووينا)',
        'sr_Cyrl_ME' => 'سربيائي (سيريلي, مونٽي نيگرو)',
        'sr_Cyrl_RS' => 'سربيائي (سيريلي, سربيا)',
        'sr_Latn' => 'سربيائي (لاطيني)',
        'sr_Latn_BA' => 'سربيائي (لاطيني, بوسنيا ۽ هرزيگووينا)',
        'sr_Latn_ME' => 'سربيائي (لاطيني, مونٽي نيگرو)',
        'sr_Latn_RS' => 'سربيائي (لاطيني, سربيا)',
        'sr_ME' => 'سربيائي (مونٽي نيگرو)',
        'sr_RS' => 'سربيائي (سربيا)',
        'st' => 'ڏکڻ سوٿي',
        'st_LS' => 'ڏکڻ سوٿي (ليسوٿو)',
        'st_ZA' => 'ڏکڻ سوٿي (ڏکڻ آفريقا)',
        'su' => 'سوڊاني',
        'su_ID' => 'سوڊاني (انڊونيشيا)',
        'su_Latn' => 'سوڊاني (لاطيني)',
        'su_Latn_ID' => 'سوڊاني (لاطيني, انڊونيشيا)',
        'sv' => 'سويڊش',
        'sv_AX' => 'سويڊش (الند ٻيٽ)',
        'sv_FI' => 'سويڊش (فن لينڊ)',
        'sv_SE' => 'سويڊش (سوئيڊن)',
        'sw' => 'سواحيلي',
        'sw_CD' => 'سواحيلي (ڪانگو -ڪنشاسا)',
        'sw_KE' => 'سواحيلي (ڪينيا)',
        'sw_TZ' => 'سواحيلي (تنزانيا)',
        'sw_UG' => 'سواحيلي (يوگنڊا)',
        'ta' => 'تامل',
        'ta_IN' => 'تامل (ڀارت)',
        'ta_LK' => 'تامل (سري لنڪا)',
        'ta_MY' => 'تامل (ملائيشيا)',
        'ta_SG' => 'تامل (سنگاپور)',
        'te' => 'تلگو',
        'te_IN' => 'تلگو (ڀارت)',
        'tg' => 'تاجڪ',
        'tg_TJ' => 'تاجڪ (تاجڪستان)',
        'th' => 'ٿائي',
        'th_TH' => 'ٿائي (ٿائيليند)',
        'ti' => 'تگرينيائي',
        'ti_ER' => 'تگرينيائي (ايريٽيريا)',
        'ti_ET' => 'تگرينيائي (ايٿوپيا)',
        'tk' => 'ترڪمين',
        'tk_TM' => 'ترڪمين (ترڪمانستان)',
        'tn' => 'تسوانا',
        'tn_BW' => 'تسوانا (بوٽسوانا)',
        'tn_ZA' => 'تسوانا (ڏکڻ آفريقا)',
        'to' => 'تونگن',
        'to_TO' => 'تونگن (ٽونگا)',
        'tr' => 'ترڪي',
        'tr_CY' => 'ترڪي (سائپرس)',
        'tr_TR' => 'ترڪي (ترڪييي)',
        'tt' => 'تاتار',
        'tt_RU' => 'تاتار (روس)',
        'ug' => 'يوغور',
        'ug_CN' => 'يوغور (چين)',
        'uk' => 'يوڪراني',
        'uk_UA' => 'يوڪراني (يوڪرين)',
        'ur' => 'اردو',
        'ur_IN' => 'اردو (ڀارت)',
        'ur_PK' => 'اردو (پاڪستان)',
        'uz' => 'ازبڪ',
        'uz_AF' => 'ازبڪ (افغانستان)',
        'uz_Arab' => 'ازبڪ (عربي)',
        'uz_Arab_AF' => 'ازبڪ (عربي, افغانستان)',
        'uz_Cyrl' => 'ازبڪ (سيريلي)',
        'uz_Cyrl_UZ' => 'ازبڪ (سيريلي, ازبڪستان)',
        'uz_Latn' => 'ازبڪ (لاطيني)',
        'uz_Latn_UZ' => 'ازبڪ (لاطيني, ازبڪستان)',
        'uz_UZ' => 'ازبڪ (ازبڪستان)',
        'vi' => 'ويتنامي',
        'vi_VN' => 'ويتنامي (ويتنام)',
        'wo' => 'وولوف',
        'wo_SN' => 'وولوف (سينيگال)',
        'xh' => 'زھوسا',
        'xh_ZA' => 'زھوسا (ڏکڻ آفريقا)',
        'yi' => 'يدش',
        'yi_UA' => 'يدش (يوڪرين)',
        'yo' => 'يوروبا',
        'yo_BJ' => 'يوروبا (بينن)',
        'yo_NG' => 'يوروبا (نائيجيريا)',
        'za' => 'جوئنگ',
        'za_CN' => 'جوئنگ (چين)',
        'zh' => 'چيني',
        'zh_CN' => 'چيني (چين)',
        'zh_HK' => 'چيني (هانگ ڪانگ SAR چين)',
        'zh_Hans' => 'چيني (سادي)',
        'zh_Hans_CN' => 'چيني (سادي, چين)',
        'zh_Hans_HK' => 'چيني (سادي, هانگ ڪانگ SAR چين)',
        'zh_Hans_MO' => 'چيني (سادي, مڪائو SAR چين)',
        'zh_Hans_MY' => 'چيني (سادي, ملائيشيا)',
        'zh_Hans_SG' => 'چيني (سادي, سنگاپور)',
        'zh_Hant' => 'چيني (روايتي)',
        'zh_Hant_HK' => 'چيني (روايتي, هانگ ڪانگ SAR چين)',
        'zh_Hant_MO' => 'چيني (روايتي, مڪائو SAR چين)',
        'zh_Hant_MY' => 'چيني (روايتي, ملائيشيا)',
        'zh_Hant_TW' => 'چيني (روايتي, تائیوان)',
        'zh_MO' => 'چيني (مڪائو SAR چين)',
        'zh_SG' => 'چيني (سنگاپور)',
        'zh_TW' => 'چيني (تائیوان)',
        'zu' => 'زولو',
        'zu_ZA' => 'زولو (ڏکڻ آفريقا)',
    ],
];
