<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Arab' => 'árabe',
        'Aran' => 'nastaliq',
        'Armn' => 'armenio',
        'Beng' => 'bengalí',
        'Bopo' => 'bopomofo',
        'Brai' => 'braille',
        'Cakm' => 'chakma',
        'Cans' => 'silabario aborixe canadense unificado',
        'Cher' => 'cherokee',
        'Cyrl' => 'cirílico',
        'Deva' => 'devanágari',
        'Ethi' => 'etíope',
        'Geor' => 'xeorxiano',
        'Grek' => 'grego',
        'Gujr' => 'guxarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'han con bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hans' => 'simplificado',
        'Hant' => 'tradicional',
        'Hebr' => 'hebreo',
        'Hira' => 'hiragana',
        'Hrkt' => 'silabarios xaponeses',
        'Jamo' => 'jamo',
        'Jpan' => 'xaponés',
        'Kana' => 'katakana',
        'Khmr' => 'khmer',
        'Knda' => 'kannará',
        'Kore' => 'coreano',
        'Laoo' => 'laosiano',
        'Latn' => 'latino',
        'Mlym' => 'malabar',
        'Mong' => 'mongol',
        'Mtei' => 'meitei mayek',
        'Mymr' => 'birmano',
        'Nkoo' => 'n’ko',
        'Olck' => 'ol chiki',
        'Orya' => 'odiá',
        'Rohg' => 'hanifi',
        'Sinh' => 'cingalés',
        'Sund' => 'sundanés',
        'Syrc' => 'siríaco',
        'Taml' => 'támil',
        'Telu' => 'telugu',
        'Tfng' => 'tifinagh',
        'Thaa' => 'thaana',
        'Thai' => 'tailandés',
        'Tibt' => 'tibetano',
        'Vaii' => 'vai',
        'Yiii' => 'yi',
        'Zmth' => 'notación matemática',
        'Zsye' => 'emojis',
        'Zsym' => 'símbolos',
        'Zxxx' => 'non escrito',
        'Zyyy' => 'común',
    ],
];
