<?php

return [
    'Names' => [
        'af' => 'آفریکانس',
        'af_NA' => 'آفریکانس (نامیبیا)',
        'af_ZA' => 'آفریکانس (افریقای جنوبی)',
        'ak' => 'آکان',
        'ak_GH' => 'آکان (غنا)',
        'am' => 'امهری',
        'am_ET' => 'امهری (اتیوپی)',
        'ar' => 'عربی',
        'ar_001' => 'عربی (جهان)',
        'ar_AE' => 'عربی (امارات متحدهٔ عربی)',
        'ar_BH' => 'عربی (بحرین)',
        'ar_DJ' => 'عربی (جیبوتی)',
        'ar_DZ' => 'عربی (الجزایر)',
        'ar_EG' => 'عربی (مصر)',
        'ar_EH' => 'عربی (صحرای غربی)',
        'ar_ER' => 'عربی (اریتره)',
        'ar_IL' => 'عربی (اسرائیل)',
        'ar_IQ' => 'عربی (عراق)',
        'ar_JO' => 'عربی (اردن)',
        'ar_KM' => 'عربی (کومور)',
        'ar_KW' => 'عربی (کویت)',
        'ar_LB' => 'عربی (لبنان)',
        'ar_LY' => 'عربی (لیبی)',
        'ar_MA' => 'عربی (مراکش)',
        'ar_MR' => 'عربی (موریتانی)',
        'ar_OM' => 'عربی (عمان)',
        'ar_PS' => 'عربی (سرزمین‌های فلسطینی)',
        'ar_QA' => 'عربی (قطر)',
        'ar_SA' => 'عربی (عربستان سعودی)',
        'ar_SD' => 'عربی (سودان)',
        'ar_SO' => 'عربی (سومالی)',
        'ar_SS' => 'عربی (سودان جنوبی)',
        'ar_SY' => 'عربی (سوریه)',
        'ar_TD' => 'عربی (چاد)',
        'ar_TN' => 'عربی (تونس)',
        'ar_YE' => 'عربی (یمن)',
        'as' => 'آسامی',
        'as_IN' => 'آسامی (هند)',
        'az' => 'ترکی آذربایجانی',
        'az_AZ' => 'ترکی آذربایجانی (جمهوری آذربایجان)',
        'az_Cyrl' => 'ترکی آذربایجانی (سیریلی)',
        'az_Cyrl_AZ' => 'ترکی آذربایجانی (سیریلی، جمهوری آذربایجان)',
        'az_Latn' => 'ترکی آذربایجانی (لاتین)',
        'az_Latn_AZ' => 'ترکی آذربایجانی (لاتین، جمهوری آذربایجان)',
        'ba' => 'باشقیری',
        'ba_RU' => 'باشقیری (روسیه)',
        'be' => 'بلاروسی',
        'be_BY' => 'بلاروسی (بلاروس)',
        'bg' => 'بلغاری',
        'bg_BG' => 'بلغاری (بلغارستان)',
        'bm' => 'بامبارایی',
        'bm_ML' => 'بامبارایی (مالی)',
        'bn' => 'بنگالی',
        'bn_BD' => 'بنگالی (بنگلادش)',
        'bn_IN' => 'بنگالی (هند)',
        'bo' => 'تبتی',
        'bo_CN' => 'تبتی (چین)',
        'bo_IN' => 'تبتی (هند)',
        'br' => 'برتون',
        'br_FR' => 'برتون (فرانسه)',
        'bs' => 'بوسنیایی',
        'bs_BA' => 'بوسنیایی (بوسنی و هرزگوین)',
        'bs_Cyrl' => 'بوسنیایی (سیریلی)',
        'bs_Cyrl_BA' => 'بوسنیایی (سیریلی، بوسنی و هرزگوین)',
        'bs_Latn' => 'بوسنیایی (لاتین)',
        'bs_Latn_BA' => 'بوسنیایی (لاتین، بوسنی و هرزگوین)',
        'ca' => 'کاتالان',
        'ca_AD' => 'کاتالان (آندورا)',
        'ca_ES' => 'کاتالان (اسپانیا)',
        'ca_FR' => 'کاتالان (فرانسه)',
        'ca_IT' => 'کاتالان (ایتالیا)',
        'ce' => 'چچنی',
        'ce_RU' => 'چچنی (روسیه)',
        'cs' => 'چکی',
        'cs_CZ' => 'چکی (چک)',
        'cv' => 'چوواشی',
        'cv_RU' => 'چوواشی (روسیه)',
        'cy' => 'ولزی',
        'cy_GB' => 'ولزی (بریتانیا)',
        'da' => 'دانمارکی',
        'da_DK' => 'دانمارکی (دانمارک)',
        'da_GL' => 'دانمارکی (گرینلند)',
        'de' => 'آلمانی',
        'de_AT' => 'آلمانی (اتریش)',
        'de_BE' => 'آلمانی (بلژیک)',
        'de_CH' => 'آلمانی (سوئیس)',
        'de_DE' => 'آلمانی (آلمان)',
        'de_IT' => 'آلمانی (ایتالیا)',
        'de_LI' => 'آلمانی (لیختن‌اشتاین)',
        'de_LU' => 'آلمانی (لوکزامبورگ)',
        'dz' => 'دزونگخا',
        'dz_BT' => 'دزونگخا (بوتان)',
        'ee' => 'اوه‌ای',
        'ee_GH' => 'اوه‌ای (غنا)',
        'ee_TG' => 'اوه‌ای (توگو)',
        'el' => 'یونانی',
        'el_CY' => 'یونانی (قبرس)',
        'el_GR' => 'یونانی (یونان)',
        'en' => 'انگلیسی',
        'en_001' => 'انگلیسی (جهان)',
        'en_150' => 'انگلیسی (اروپا)',
        'en_AE' => 'انگلیسی (امارات متحدهٔ عربی)',
        'en_AG' => 'انگلیسی (آنتیگوا و باربودا)',
        'en_AI' => 'انگلیسی (آنگویلا)',
        'en_AS' => 'انگلیسی (ساموآی امریکا)',
        'en_AT' => 'انگلیسی (اتریش)',
        'en_AU' => 'انگلیسی (استرالیا)',
        'en_BB' => 'انگلیسی (باربادوس)',
        'en_BE' => 'انگلیسی (بلژیک)',
        'en_BI' => 'انگلیسی (بوروندی)',
        'en_BM' => 'انگلیسی (برمودا)',
        'en_BS' => 'انگلیسی (باهاما)',
        'en_BW' => 'انگلیسی (بوتسوانا)',
        'en_BZ' => 'انگلیسی (بلیز)',
        'en_CA' => 'انگلیسی (کانادا)',
        'en_CC' => 'انگلیسی (جزایر کوکوس)',
        'en_CH' => 'انگلیسی (سوئیس)',
        'en_CK' => 'انگلیسی (جزایر کوک)',
        'en_CM' => 'انگلیسی (کامرون)',
        'en_CX' => 'انگلیسی (جزیرهٔ کریسمس)',
        'en_CY' => 'انگلیسی (قبرس)',
        'en_CZ' => 'انگلیسی (چک)',
        'en_DE' => 'انگلیسی (آلمان)',
        'en_DK' => 'انگلیسی (دانمارک)',
        'en_DM' => 'انگلیسی (دومینیکا)',
        'en_EE' => 'انگلیسی (استونی)',
        'en_ER' => 'انگلیسی (اریتره)',
        'en_ES' => 'انگلیسی (اسپانیا)',
        'en_FI' => 'انگلیسی (فنلاند)',
        'en_FJ' => 'انگلیسی (فیجی)',
        'en_FK' => 'انگلیسی (جزایر فالکلند)',
        'en_FM' => 'انگلیسی (میکرونزی)',
        'en_FR' => 'انگلیسی (فرانسه)',
        'en_GB' => 'انگلیسی (بریتانیا)',
        'en_GD' => 'انگلیسی (گرنادا)',
        'en_GE' => 'انگلیسی (گرجستان)',
        'en_GG' => 'انگلیسی (گرنزی)',
        'en_GH' => 'انگلیسی (غنا)',
        'en_GI' => 'انگلیسی (جبل‌الطارق)',
        'en_GM' => 'انگلیسی (گامبیا)',
        'en_GS' => 'انگلیسی (جورجیای جنوبی و جزایر ساندویچ جنوبی)',
        'en_GU' => 'انگلیسی (گوام)',
        'en_GY' => 'انگلیسی (گویان)',
        'en_HK' => 'انگلیسی (هنگ‌کنگ، منطقهٔ ویژهٔ اداری چین)',
        'en_HU' => 'انگلیسی (مجارستان)',
        'en_ID' => 'انگلیسی (اندونزی)',
        'en_IE' => 'انگلیسی (ایرلند)',
        'en_IL' => 'انگلیسی (اسرائیل)',
        'en_IM' => 'انگلیسی (جزیرهٔ من)',
        'en_IN' => 'انگلیسی (هند)',
        'en_IO' => 'انگلیسی (قلمرو بریتانیا در اقیانوس هند)',
        'en_IT' => 'انگلیسی (ایتالیا)',
        'en_JE' => 'انگلیسی (جرزی)',
        'en_JM' => 'انگلیسی (جامائیکا)',
        'en_JP' => 'انگلیسی (ژاپن)',
        'en_KE' => 'انگلیسی (کنیا)',
        'en_KI' => 'انگلیسی (کیریباتی)',
        'en_KN' => 'انگلیسی (سنت کیتس و نویس)',
        'en_KY' => 'انگلیسی (جزایر کِیمن)',
        'en_LC' => 'انگلیسی (سنت لوسیا)',
        'en_LR' => 'انگلیسی (لیبریا)',
        'en_LS' => 'انگلیسی (لسوتو)',
        'en_LT' => 'انگلیسی (لیتوانی)',
        'en_LV' => 'انگلیسی (لتونی)',
        'en_MG' => 'انگلیسی (ماداگاسکار)',
        'en_MH' => 'انگلیسی (جزایر مارشال)',
        'en_MO' => 'انگلیسی (ماکائو، منطقهٔ ویژهٔ اداری چین)',
        'en_MP' => 'انگلیسی (جزایر ماریانای شمالی)',
        'en_MS' => 'انگلیسی (مونت‌سرات)',
        'en_MT' => 'انگلیسی (مالت)',
        'en_MU' => 'انگلیسی (موریس)',
        'en_MV' => 'انگلیسی (مالدیو)',
        'en_MW' => 'انگلیسی (مالاوی)',
        'en_MY' => 'انگلیسی (مالزی)',
        'en_NA' => 'انگلیسی (نامیبیا)',
        'en_NF' => 'انگلیسی (جزیرهٔ نورفولک)',
        'en_NG' => 'انگلیسی (نیجریه)',
        'en_NL' => 'انگلیسی (هلند)',
        'en_NO' => 'انگلیسی (نروژ)',
        'en_NR' => 'انگلیسی (نائورو)',
        'en_NU' => 'انگلیسی (نیوئه)',
        'en_NZ' => 'انگلیسی (نیوزیلند)',
        'en_PG' => 'انگلیسی (پاپوا گینهٔ نو)',
        'en_PH' => 'انگلیسی (فیلیپین)',
        'en_PK' => 'انگلیسی (پاکستان)',
        'en_PL' => 'انگلیسی (لهستان)',
        'en_PN' => 'انگلیسی (جزایر پیت‌کرن)',
        'en_PR' => 'انگلیسی (پورتوریکو)',
        'en_PT' => 'انگلیسی (پرتغال)',
        'en_PW' => 'انگلیسی (پالائو)',
        'en_RO' => 'انگلیسی (رومانی)',
        'en_RW' => 'انگلیسی (رواندا)',
        'en_SB' => 'انگلیسی (جزایر سلیمان)',
        'en_SC' => 'انگلیسی (سیشل)',
        'en_SD' => 'انگلیسی (سودان)',
        'en_SE' => 'انگلیسی (سوئد)',
        'en_SG' => 'انگلیسی (سنگاپور)',
        'en_SH' => 'انگلیسی (سنت هلن)',
        'en_SI' => 'انگلیسی (اسلوونی)',
        'en_SK' => 'انگلیسی (اسلواکی)',
        'en_SL' => 'انگلیسی (سیرالئون)',
        'en_SS' => 'انگلیسی (سودان جنوبی)',
        'en_SX' => 'انگلیسی (سنت مارتن)',
        'en_SZ' => 'انگلیسی (اسواتینی)',
        'en_TC' => 'انگلیسی (جزایر تورکس و کایکوس)',
        'en_TK' => 'انگلیسی (توکلائو)',
        'en_TO' => 'انگلیسی (تونگا)',
        'en_TT' => 'انگلیسی (ترینیداد و توباگو)',
        'en_TV' => 'انگلیسی (تووالو)',
        'en_TZ' => 'انگلیسی (تانزانیا)',
        'en_UA' => 'انگلیسی (اوکراین)',
        'en_UG' => 'انگلیسی (اوگاندا)',
        'en_UM' => 'انگلیسی (جزایر دورافتادهٔ ایالات متحده)',
        'en_US' => 'انگلیسی (ایالات متحده)',
        'en_VC' => 'انگلیسی (سنت وینسنت و گرنادین)',
        'en_VG' => 'انگلیسی (جزایر ویرجین بریتانیا)',
        'en_VI' => 'انگلیسی (جزایر ویرجین ایالات متحده)',
        'en_VU' => 'انگلیسی (وانواتو)',
        'en_WS' => 'انگلیسی (ساموآ)',
        'en_ZA' => 'انگلیسی (افریقای جنوبی)',
        'en_ZM' => 'انگلیسی (زامبیا)',
        'en_ZW' => 'انگلیسی (زیمبابوه)',
        'eo' => 'اسپرانتو',
        'eo_001' => 'اسپرانتو (جهان)',
        'es' => 'اسپانیایی',
        'es_419' => 'اسپانیایی (امریکای لاتین)',
        'es_AR' => 'اسپانیایی (آرژانتین)',
        'es_BO' => 'اسپانیایی (بولیوی)',
        'es_BR' => 'اسپانیایی (برزیل)',
        'es_BZ' => 'اسپانیایی (بلیز)',
        'es_CL' => 'اسپانیایی (شیلی)',
        'es_CO' => 'اسپانیایی (کلمبیا)',
        'es_CR' => 'اسپانیایی (کاستاریکا)',
        'es_CU' => 'اسپانیایی (کوبا)',
        'es_DO' => 'اسپانیایی (جمهوری دومینیکن)',
        'es_EC' => 'اسپانیایی (اکوادور)',
        'es_ES' => 'اسپانیایی (اسپانیا)',
        'es_GQ' => 'اسپانیایی (گینهٔ استوایی)',
        'es_GT' => 'اسپانیایی (گواتمالا)',
        'es_HN' => 'اسپانیایی (هندوراس)',
        'es_MX' => 'اسپانیایی (مکزیک)',
        'es_NI' => 'اسپانیایی (نیکاراگوئه)',
        'es_PA' => 'اسپانیایی (پاناما)',
        'es_PE' => 'اسپانیایی (پرو)',
        'es_PH' => 'اسپانیایی (فیلیپین)',
        'es_PR' => 'اسپانیایی (پورتوریکو)',
        'es_PY' => 'اسپانیایی (پاراگوئه)',
        'es_SV' => 'اسپانیایی (السالوادور)',
        'es_US' => 'اسپانیایی (ایالات متحده)',
        'es_UY' => 'اسپانیایی (اروگوئه)',
        'es_VE' => 'اسپانیایی (ونزوئلا)',
        'et' => 'استونیایی',
        'et_EE' => 'استونیایی (استونی)',
        'eu' => 'باسکی',
        'eu_ES' => 'باسکی (اسپانیا)',
        'fa' => 'فارسی',
        'fa_AF' => 'فارسی (افغانستان)',
        'fa_IR' => 'فارسی (ایران)',
        'ff' => 'فولانی',
        'ff_Adlm' => 'فولانی (آدلام)',
        'ff_Adlm_BF' => 'فولانی (آدلام، بورکینافاسو)',
        'ff_Adlm_CM' => 'فولانی (آدلام، کامرون)',
        'ff_Adlm_GH' => 'فولانی (آدلام، غنا)',
        'ff_Adlm_GM' => 'فولانی (آدلام، گامبیا)',
        'ff_Adlm_GN' => 'فولانی (آدلام، گینه)',
        'ff_Adlm_GW' => 'فولانی (آدلام، گینهٔ بیسائو)',
        'ff_Adlm_LR' => 'فولانی (آدلام، لیبریا)',
        'ff_Adlm_MR' => 'فولانی (آدلام، موریتانی)',
        'ff_Adlm_NE' => 'فولانی (آدلام، نیجر)',
        'ff_Adlm_NG' => 'فولانی (آدلام، نیجریه)',
        'ff_Adlm_SL' => 'فولانی (آدلام، سیرالئون)',
        'ff_Adlm_SN' => 'فولانی (آدلام، سنگال)',
        'ff_CM' => 'فولانی (کامرون)',
        'ff_GN' => 'فولانی (گینه)',
        'ff_Latn' => 'فولانی (لاتین)',
        'ff_Latn_BF' => 'فولانی (لاتین، بورکینافاسو)',
        'ff_Latn_CM' => 'فولانی (لاتین، کامرون)',
        'ff_Latn_GH' => 'فولانی (لاتین، غنا)',
        'ff_Latn_GM' => 'فولانی (لاتین، گامبیا)',
        'ff_Latn_GN' => 'فولانی (لاتین، گینه)',
        'ff_Latn_GW' => 'فولانی (لاتین، گینهٔ بیسائو)',
        'ff_Latn_LR' => 'فولانی (لاتین، لیبریا)',
        'ff_Latn_MR' => 'فولانی (لاتین، موریتانی)',
        'ff_Latn_NE' => 'فولانی (لاتین، نیجر)',
        'ff_Latn_NG' => 'فولانی (لاتین، نیجریه)',
        'ff_Latn_SL' => 'فولانی (لاتین، سیرالئون)',
        'ff_Latn_SN' => 'فولانی (لاتین، سنگال)',
        'ff_MR' => 'فولانی (موریتانی)',
        'ff_SN' => 'فولانی (سنگال)',
        'fi' => 'فنلاندی',
        'fi_FI' => 'فنلاندی (فنلاند)',
        'fo' => 'فارویی',
        'fo_DK' => 'فارویی (دانمارک)',
        'fo_FO' => 'فارویی (جزایر فارو)',
        'fr' => 'فرانسوی',
        'fr_BE' => 'فرانسوی (بلژیک)',
        'fr_BF' => 'فرانسوی (بورکینافاسو)',
        'fr_BI' => 'فرانسوی (بوروندی)',
        'fr_BJ' => 'فرانسوی (بنین)',
        'fr_BL' => 'فرانسوی (سن بارتلمی)',
        'fr_CA' => 'فرانسوی (کانادا)',
        'fr_CD' => 'فرانسوی (کنگو - کینشاسا)',
        'fr_CF' => 'فرانسوی (جمهوری افریقای مرکزی)',
        'fr_CG' => 'فرانسوی (کنگو - برازویل)',
        'fr_CH' => 'فرانسوی (سوئیس)',
        'fr_CI' => 'فرانسوی (ساحل عاج)',
        'fr_CM' => 'فرانسوی (کامرون)',
        'fr_DJ' => 'فرانسوی (جیبوتی)',
        'fr_DZ' => 'فرانسوی (الجزایر)',
        'fr_FR' => 'فرانسوی (فرانسه)',
        'fr_GA' => 'فرانسوی (گابن)',
        'fr_GF' => 'فرانسوی (گویان فرانسه)',
        'fr_GN' => 'فرانسوی (گینه)',
        'fr_GP' => 'فرانسوی (گوادلوپ)',
        'fr_GQ' => 'فرانسوی (گینهٔ استوایی)',
        'fr_HT' => 'فرانسوی (هائیتی)',
        'fr_KM' => 'فرانسوی (کومور)',
        'fr_LU' => 'فرانسوی (لوکزامبورگ)',
        'fr_MA' => 'فرانسوی (مراکش)',
        'fr_MC' => 'فرانسوی (موناکو)',
        'fr_MF' => 'فرانسوی (سنت مارتین)',
        'fr_MG' => 'فرانسوی (ماداگاسکار)',
        'fr_ML' => 'فرانسوی (مالی)',
        'fr_MQ' => 'فرانسوی (مارتینیک)',
        'fr_MR' => 'فرانسوی (موریتانی)',
        'fr_MU' => 'فرانسوی (موریس)',
        'fr_NC' => 'فرانسوی (کالدونیای جدید)',
        'fr_NE' => 'فرانسوی (نیجر)',
        'fr_PF' => 'فرانسوی (پلی‌نزی فرانسه)',
        'fr_PM' => 'فرانسوی (سن پیر و میکلن)',
        'fr_RE' => 'فرانسوی (رئونیون)',
        'fr_RW' => 'فرانسوی (رواندا)',
        'fr_SC' => 'فرانسوی (سیشل)',
        'fr_SN' => 'فرانسوی (سنگال)',
        'fr_SY' => 'فرانسوی (سوریه)',
        'fr_TD' => 'فرانسوی (چاد)',
        'fr_TG' => 'فرانسوی (توگو)',
        'fr_TN' => 'فرانسوی (تونس)',
        'fr_VU' => 'فرانسوی (وانواتو)',
        'fr_WF' => 'فرانسوی (والیس و فوتونا)',
        'fr_YT' => 'فرانسوی (مایوت)',
        'fy' => 'فریسی غربی',
        'fy_NL' => 'فریسی غربی (هلند)',
        'ga' => 'ایرلندی',
        'ga_GB' => 'ایرلندی (بریتانیا)',
        'ga_IE' => 'ایرلندی (ایرلند)',
        'gd' => 'گیلی اسکاتلندی',
        'gd_GB' => 'گیلی اسکاتلندی (بریتانیا)',
        'gl' => 'گالیسیایی',
        'gl_ES' => 'گالیسیایی (اسپانیا)',
        'gu' => 'گجراتی',
        'gu_IN' => 'گجراتی (هند)',
        'gv' => 'مانی',
        'gv_IM' => 'مانی (جزیرهٔ من)',
        'ha' => 'هوسایی',
        'ha_GH' => 'هوسایی (غنا)',
        'ha_NE' => 'هوسایی (نیجر)',
        'ha_NG' => 'هوسایی (نیجریه)',
        'he' => 'عبری',
        'he_IL' => 'عبری (اسرائیل)',
        'hi' => 'هندی',
        'hi_IN' => 'هندی (هند)',
        'hi_Latn' => 'هندی (لاتین)',
        'hi_Latn_IN' => 'هندی (لاتین، هند)',
        'hr' => 'کروات',
        'hr_BA' => 'کروات (بوسنی و هرزگوین)',
        'hr_HR' => 'کروات (کرواسی)',
        'hu' => 'مجاری',
        'hu_HU' => 'مجاری (مجارستان)',
        'hy' => 'ارمنی',
        'hy_AM' => 'ارمنی (ارمنستان)',
        'ia' => 'اینترلینگوا',
        'ia_001' => 'اینترلینگوا (جهان)',
        'id' => 'اندونزیایی',
        'id_ID' => 'اندونزیایی (اندونزی)',
        'ie' => 'اکسیدنتال',
        'ie_EE' => 'اکسیدنتال (استونی)',
        'ig' => 'ایگبویی',
        'ig_NG' => 'ایگبویی (نیجریه)',
        'ii' => 'یی سیچوان',
        'ii_CN' => 'یی سیچوان (چین)',
        'is' => 'ایسلندی',
        'is_IS' => 'ایسلندی (ایسلند)',
        'it' => 'ایتالیایی',
        'it_CH' => 'ایتالیایی (سوئیس)',
        'it_IT' => 'ایتالیایی (ایتالیا)',
        'it_SM' => 'ایتالیایی (سان‌مارینو)',
        'it_VA' => 'ایتالیایی (واتیکان)',
        'ja' => 'ژاپنی',
        'ja_JP' => 'ژاپنی (ژاپن)',
        'jv' => 'جاوه‌ای',
        'jv_ID' => 'جاوه‌ای (اندونزی)',
        'ka' => 'گرجی',
        'ka_GE' => 'گرجی (گرجستان)',
        'ki' => 'کیکویویی',
        'ki_KE' => 'کیکویویی (کنیا)',
        'kk' => 'قزاقی',
        'kk_Arab' => 'قزاقی (عربی)',
        'kk_Arab_CN' => 'قزاقی (عربی، چین)',
        'kk_Cyrl' => 'قزاقی (سیریلی)',
        'kk_Cyrl_KZ' => 'قزاقی (سیریلی، قزاقستان)',
        'kk_KZ' => 'قزاقی (قزاقستان)',
        'kl' => 'گرینلندی',
        'kl_GL' => 'گرینلندی (گرینلند)',
        'km' => 'خمری',
        'km_KH' => 'خمری (کامبوج)',
        'kn' => 'کانارا',
        'kn_IN' => 'کانارا (هند)',
        'ko' => 'کره‌ای',
        'ko_CN' => 'کره‌ای (چین)',
        'ko_KP' => 'کره‌ای (کرهٔ شمالی)',
        'ko_KR' => 'کره‌ای (کرهٔ جنوبی)',
        'ks' => 'کشمیری',
        'ks_Arab' => 'کشمیری (عربی)',
        'ks_Arab_IN' => 'کشمیری (عربی، هند)',
        'ks_Deva' => 'کشمیری (دوناگری)',
        'ks_Deva_IN' => 'کشمیری (دوناگری، هند)',
        'ks_IN' => 'کشمیری (هند)',
        'ku' => 'کردی',
        'ku_Latn' => 'کردی (لاتین)',
        'ku_Latn_IQ' => 'کردی (لاتین، عراق)',
        'ku_Latn_SY' => 'کردی (لاتین، سوریه)',
        'ku_Latn_TR' => 'کردی (لاتین، ترکیه)',
        'ku_SY' => 'کردی (سوریه)',
        'ku_TR' => 'کردی (ترکیه)',
        'kw' => 'کورنی',
        'kw_GB' => 'کورنی (بریتانیا)',
        'ky' => 'قرقیزی',
        'ky_KG' => 'قرقیزی (قرقیزستان)',
        'lb' => 'لوگزامبورگی',
        'lb_LU' => 'لوگزامبورگی (لوکزامبورگ)',
        'lg' => 'گاندایی',
        'lg_UG' => 'گاندایی (اوگاندا)',
        'ln' => 'لینگالا',
        'ln_AO' => 'لینگالا (آنگولا)',
        'ln_CD' => 'لینگالا (کنگو - کینشاسا)',
        'ln_CF' => 'لینگالا (جمهوری افریقای مرکزی)',
        'ln_CG' => 'لینگالا (کنگو - برازویل)',
        'lo' => 'لائوسی',
        'lo_LA' => 'لائوسی (لائوس)',
        'lt' => 'لیتوانیایی',
        'lt_LT' => 'لیتوانیایی (لیتوانی)',
        'lu' => 'لوبایی‐کاتانگا',
        'lu_CD' => 'لوبایی‐کاتانگا (کنگو - کینشاسا)',
        'lv' => 'لتونیایی',
        'lv_LV' => 'لتونیایی (لتونی)',
        'mg' => 'مالاگاسی',
        'mg_MG' => 'مالاگاسی (ماداگاسکار)',
        'mi' => 'مائوری',
        'mi_NZ' => 'مائوری (نیوزیلند)',
        'mk' => 'مقدونی',
        'mk_MK' => 'مقدونی (مقدونیهٔ شمالی)',
        'ml' => 'مالایالامی',
        'ml_IN' => 'مالایالامی (هند)',
        'mn' => 'مغولی',
        'mn_MN' => 'مغولی (مغولستان)',
        'mr' => 'مراتی',
        'mr_IN' => 'مراتی (هند)',
        'ms' => 'مالایی',
        'ms_BN' => 'مالایی (برونئی)',
        'ms_ID' => 'مالایی (اندونزی)',
        'ms_MY' => 'مالایی (مالزی)',
        'ms_SG' => 'مالایی (سنگاپور)',
        'mt' => 'مالتی',
        'mt_MT' => 'مالتی (مالت)',
        'my' => 'برمه‌ای',
        'my_MM' => 'برمه‌ای (میانمار [برمه])',
        'nb' => 'نروژی بوک‌مُل',
        'nb_NO' => 'نروژی بوک‌مُل (نروژ)',
        'nb_SJ' => 'نروژی بوک‌مُل (سوالبارد و یان ماین)',
        'nd' => 'انده‌بله‌ای شمالی',
        'nd_ZW' => 'انده‌بله‌ای شمالی (زیمبابوه)',
        'ne' => 'نپالی',
        'ne_IN' => 'نپالی (هند)',
        'ne_NP' => 'نپالی (نپال)',
        'nl' => 'هلندی',
        'nl_AW' => 'هلندی (آروبا)',
        'nl_BE' => 'هلندی (بلژیک)',
        'nl_BQ' => 'هلندی (جزایر کارائیب هلند)',
        'nl_CW' => 'هلندی (کوراسائو)',
        'nl_NL' => 'هلندی (هلند)',
        'nl_SR' => 'هلندی (سورینام)',
        'nl_SX' => 'هلندی (سنت مارتن)',
        'nn' => 'نروژی نی‌نُشک',
        'nn_NO' => 'نروژی نی‌نُشک (نروژ)',
        'no' => 'نروژی',
        'no_NO' => 'نروژی (نروژ)',
        'oc' => 'اکسیتان',
        'oc_ES' => 'اکسیتان (اسپانیا)',
        'oc_FR' => 'اکسیتان (فرانسه)',
        'om' => 'اورومویی',
        'om_ET' => 'اورومویی (اتیوپی)',
        'om_KE' => 'اورومویی (کنیا)',
        'or' => 'اوریه‌ای',
        'or_IN' => 'اوریه‌ای (هند)',
        'os' => 'آسی',
        'os_GE' => 'آسی (گرجستان)',
        'os_RU' => 'آسی (روسیه)',
        'pa' => 'پنجابی',
        'pa_Arab' => 'پنجابی (عربی)',
        'pa_Arab_PK' => 'پنجابی (عربی، پاکستان)',
        'pa_Guru' => 'پنجابی (گورومخی)',
        'pa_Guru_IN' => 'پنجابی (گورومخی، هند)',
        'pa_IN' => 'پنجابی (هند)',
        'pa_PK' => 'پنجابی (پاکستان)',
        'pl' => 'لهستانی',
        'pl_PL' => 'لهستانی (لهستان)',
        'ps' => 'پشتو',
        'ps_AF' => 'پشتو (افغانستان)',
        'ps_PK' => 'پشتو (پاکستان)',
        'pt' => 'پرتغالی',
        'pt_AO' => 'پرتغالی (آنگولا)',
        'pt_BR' => 'پرتغالی (برزیل)',
        'pt_CH' => 'پرتغالی (سوئیس)',
        'pt_CV' => 'پرتغالی (کیپ‌ورد)',
        'pt_GQ' => 'پرتغالی (گینهٔ استوایی)',
        'pt_GW' => 'پرتغالی (گینهٔ بیسائو)',
        'pt_LU' => 'پرتغالی (لوکزامبورگ)',
        'pt_MO' => 'پرتغالی (ماکائو، منطقهٔ ویژهٔ اداری چین)',
        'pt_MZ' => 'پرتغالی (موزامبیک)',
        'pt_PT' => 'پرتغالی (پرتغال)',
        'pt_ST' => 'پرتغالی (سائوتومه و پرینسیپ)',
        'pt_TL' => 'پرتغالی (تیمور-لسته)',
        'qu' => 'کچوایی',
        'qu_BO' => 'کچوایی (بولیوی)',
        'qu_EC' => 'کچوایی (اکوادور)',
        'qu_PE' => 'کچوایی (پرو)',
        'rm' => 'رومانش',
        'rm_CH' => 'رومانش (سوئیس)',
        'rn' => 'روندیایی',
        'rn_BI' => 'روندیایی (بوروندی)',
        'ro' => 'رومانیایی',
        'ro_MD' => 'رومانیایی (مولداوی)',
        'ro_RO' => 'رومانیایی (رومانی)',
        'ru' => 'روسی',
        'ru_BY' => 'روسی (بلاروس)',
        'ru_KG' => 'روسی (قرقیزستان)',
        'ru_KZ' => 'روسی (قزاقستان)',
        'ru_MD' => 'روسی (مولداوی)',
        'ru_RU' => 'روسی (روسیه)',
        'ru_UA' => 'روسی (اوکراین)',
        'rw' => 'کینیارواندایی',
        'rw_RW' => 'کینیارواندایی (رواندا)',
        'sa' => 'سانسکریت',
        'sa_IN' => 'سانسکریت (هند)',
        'sc' => 'ساردینیایی',
        'sc_IT' => 'ساردینیایی (ایتالیا)',
        'sd' => 'سندی',
        'sd_Arab' => 'سندی (عربی)',
        'sd_Arab_PK' => 'سندی (عربی، پاکستان)',
        'sd_Deva' => 'سندی (دوناگری)',
        'sd_Deva_IN' => 'سندی (دوناگری، هند)',
        'sd_IN' => 'سندی (هند)',
        'sd_PK' => 'سندی (پاکستان)',
        'se' => 'سامی شمالی',
        'se_FI' => 'سامی شمالی (فنلاند)',
        'se_NO' => 'سامی شمالی (نروژ)',
        'se_SE' => 'سامی شمالی (سوئد)',
        'sg' => 'سانگو',
        'sg_CF' => 'سانگو (جمهوری افریقای مرکزی)',
        'sh' => 'صرب و کرواتی',
        'sh_BA' => 'صرب و کرواتی (بوسنی و هرزگوین)',
        'si' => 'سینهالی',
        'si_LK' => 'سینهالی (سری‌لانکا)',
        'sk' => 'اسلواکی',
        'sk_SK' => 'اسلواکی (اسلواکی)',
        'sl' => 'اسلوونیایی',
        'sl_SI' => 'اسلوونیایی (اسلوونی)',
        'sn' => 'شونایی',
        'sn_ZW' => 'شونایی (زیمبابوه)',
        'so' => 'سومالیایی',
        'so_DJ' => 'سومالیایی (جیبوتی)',
        'so_ET' => 'سومالیایی (اتیوپی)',
        'so_KE' => 'سومالیایی (کنیا)',
        'so_SO' => 'سومالیایی (سومالی)',
        'sq' => 'آلبانیایی',
        'sq_AL' => 'آلبانیایی (آلبانی)',
        'sq_MK' => 'آلبانیایی (مقدونیهٔ شمالی)',
        'sr' => 'صربی',
        'sr_BA' => 'صربی (بوسنی و هرزگوین)',
        'sr_Cyrl' => 'صربی (سیریلی)',
        'sr_Cyrl_BA' => 'صربی (سیریلی، بوسنی و هرزگوین)',
        'sr_Cyrl_ME' => 'صربی (سیریلی، مونته‌نگرو)',
        'sr_Cyrl_RS' => 'صربی (سیریلی، صربستان)',
        'sr_Latn' => 'صربی (لاتین)',
        'sr_Latn_BA' => 'صربی (لاتین، بوسنی و هرزگوین)',
        'sr_Latn_ME' => 'صربی (لاتین، مونته‌نگرو)',
        'sr_Latn_RS' => 'صربی (لاتین، صربستان)',
        'sr_ME' => 'صربی (مونته‌نگرو)',
        'sr_RS' => 'صربی (صربستان)',
        'st' => 'سوتوی جنوبی',
        'st_LS' => 'سوتوی جنوبی (لسوتو)',
        'st_ZA' => 'سوتوی جنوبی (افریقای جنوبی)',
        'su' => 'سوندایی',
        'su_ID' => 'سوندایی (اندونزی)',
        'su_Latn' => 'سوندایی (لاتین)',
        'su_Latn_ID' => 'سوندایی (لاتین، اندونزی)',
        'sv' => 'سوئدی',
        'sv_AX' => 'سوئدی (جزایر آلاند)',
        'sv_FI' => 'سوئدی (فنلاند)',
        'sv_SE' => 'سوئدی (سوئد)',
        'sw' => 'سواحیلی',
        'sw_CD' => 'سواحیلی (کنگو - کینشاسا)',
        'sw_KE' => 'سواحیلی (کنیا)',
        'sw_TZ' => 'سواحیلی (تانزانیا)',
        'sw_UG' => 'سواحیلی (اوگاندا)',
        'ta' => 'تامیلی',
        'ta_IN' => 'تامیلی (هند)',
        'ta_LK' => 'تامیلی (سری‌لانکا)',
        'ta_MY' => 'تامیلی (مالزی)',
        'ta_SG' => 'تامیلی (سنگاپور)',
        'te' => 'تلوگویی',
        'te_IN' => 'تلوگویی (هند)',
        'tg' => 'تاجیکی',
        'tg_TJ' => 'تاجیکی (تاجیکستان)',
        'th' => 'تایلندی',
        'th_TH' => 'تایلندی (تایلند)',
        'ti' => 'تیگرینیایی',
        'ti_ER' => 'تیگرینیایی (اریتره)',
        'ti_ET' => 'تیگرینیایی (اتیوپی)',
        'tk' => 'ترکمنی',
        'tk_TM' => 'ترکمنی (ترکمنستان)',
        'tl' => 'تاگالوگی',
        'tl_PH' => 'تاگالوگی (فیلیپین)',
        'tn' => 'تسوانایی',
        'tn_BW' => 'تسوانایی (بوتسوانا)',
        'tn_ZA' => 'تسوانایی (افریقای جنوبی)',
        'to' => 'تونگایی',
        'to_TO' => 'تونگایی (تونگا)',
        'tr' => 'ترکی استانبولی',
        'tr_CY' => 'ترکی استانبولی (قبرس)',
        'tr_TR' => 'ترکی استانبولی (ترکیه)',
        'tt' => 'تاتاری',
        'tt_RU' => 'تاتاری (روسیه)',
        'ug' => 'اویغوری',
        'ug_CN' => 'اویغوری (چین)',
        'uk' => 'اوکراینی',
        'uk_UA' => 'اوکراینی (اوکراین)',
        'ur' => 'اردو',
        'ur_IN' => 'اردو (هند)',
        'ur_PK' => 'اردو (پاکستان)',
        'uz' => 'ازبکی',
        'uz_AF' => 'ازبکی (افغانستان)',
        'uz_Arab' => 'ازبکی (عربی)',
        'uz_Arab_AF' => 'ازبکی (عربی، افغانستان)',
        'uz_Cyrl' => 'ازبکی (سیریلی)',
        'uz_Cyrl_UZ' => 'ازبکی (سیریلی، ازبکستان)',
        'uz_Latn' => 'ازبکی (لاتین)',
        'uz_Latn_UZ' => 'ازبکی (لاتین، ازبکستان)',
        'uz_UZ' => 'ازبکی (ازبکستان)',
        'vi' => 'ویتنامی',
        'vi_VN' => 'ویتنامی (ویتنام)',
        'wo' => 'ولوفی',
        'wo_SN' => 'ولوفی (سنگال)',
        'xh' => 'خوسایی',
        'xh_ZA' => 'خوسایی (افریقای جنوبی)',
        'yi' => 'یدی',
        'yi_UA' => 'یدی (اوکراین)',
        'yo' => 'یوروبایی',
        'yo_BJ' => 'یوروبایی (بنین)',
        'yo_NG' => 'یوروبایی (نیجریه)',
        'za' => 'ژوانگی',
        'za_CN' => 'ژوانگی (چین)',
        'zh' => 'چینی',
        'zh_CN' => 'چینی (چین)',
        'zh_HK' => 'چینی (هنگ‌کنگ، منطقهٔ ویژهٔ اداری چین)',
        'zh_Hans' => 'چینی (ساده‌شده)',
        'zh_Hans_CN' => 'چینی (ساده‌شده، چین)',
        'zh_Hans_HK' => 'چینی (ساده‌شده، هنگ‌کنگ، منطقهٔ ویژهٔ اداری چین)',
        'zh_Hans_MO' => 'چینی (ساده‌شده، ماکائو، منطقهٔ ویژهٔ اداری چین)',
        'zh_Hans_MY' => 'چینی (ساده‌شده، مالزی)',
        'zh_Hans_SG' => 'چینی (ساده‌شده، سنگاپور)',
        'zh_Hant' => 'چینی (سنتی)',
        'zh_Hant_HK' => 'چینی (سنتی، هنگ‌کنگ، منطقهٔ ویژهٔ اداری چین)',
        'zh_Hant_MO' => 'چینی (سنتی، ماکائو، منطقهٔ ویژهٔ اداری چین)',
        'zh_Hant_MY' => 'چینی (سنتی، مالزی)',
        'zh_Hant_TW' => 'چینی (سنتی، تایوان)',
        'zh_MO' => 'چینی (ماکائو، منطقهٔ ویژهٔ اداری چین)',
        'zh_SG' => 'چینی (سنگاپور)',
        'zh_TW' => 'چینی (تایوان)',
        'zu' => 'زولویی',
        'zu_ZA' => 'زولویی (افریقای جنوبی)',
    ],
];
