<?php

/**
 * Urdu PHPMailer language file: refer to English translation for definitive list
 * @package PHPMailer
 * @author Saqib Ali Siddiqui <saqibsra@gmail.com>
 */

$PHPMAILER_LANG['authenticate']         = 'SMTP خرابی: تصدیق کرنے سے قاصر۔';
$PHPMAILER_LANG['connect_host']         = 'SMTP خرابی: سرور سے منسلک ہونے سے قاصر۔';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTP خرابی: ڈیٹا قبول نہیں کیا گیا۔';
$PHPMAILER_LANG['empty_message']        = 'پیغام کی باڈی خالی ہے۔';
$PHPMAILER_LANG['encoding']             = 'نامعلوم انکوڈنگ: ';
$PHPMAILER_LANG['execute']              = 'عمل کرنے کے قابل نہیں ';
$PHPMAILER_LANG['file_access']          = 'فائل تک رسائی سے قاصر:';
$PHPMAILER_LANG['file_open']            = 'فائل کی خرابی: فائل کو کھولنے سے قاصر:';
$PHPMAILER_LANG['from_failed']          = 'درج ذیل بھیجنے والے کا پتہ ناکام ہو گیا:';
$PHPMAILER_LANG['instantiate']          = 'میل فنکشن کی مثال بنانے سے قاصر۔';
$PHPMAILER_LANG['invalid_address']      = 'بھیجنے سے قاصر: غلط ای میل پتہ:';
$PHPMAILER_LANG['mailer_not_supported'] = ' میلر تعاون یافتہ نہیں ہے۔';
$PHPMAILER_LANG['provide_address']      = 'آپ کو کم از کم ایک منزل کا ای میل پتہ فراہم کرنا چاہیے۔';
$PHPMAILER_LANG['recipients_failed']    = 'SMTP خرابی: درج ذیل پتہ پر نہیں بھیجا جاسکا: ';
$PHPMAILER_LANG['signing']              = 'دستخط کی خرابی: ';
$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP ملنا ناکام ہوا';
$PHPMAILER_LANG['smtp_error']           = 'SMTP سرور کی خرابی: ';
$PHPMAILER_LANG['variable_set']         = 'متغیر سیٹ نہیں کیا جا سکا: ';
$PHPMAILER_LANG['extension_missing']    = 'ایکٹینشن موجود نہیں ہے۔ ';
$PHPMAILER_LANG['smtp_code']            = 'SMTP سرور کوڈ: ';
$PHPMAILER_LANG['smtp_code_ex']         = 'اضافی SMTP سرور کی معلومات:';
$PHPMAILER_LANG['invalid_header']       = 'غلط ہیڈر کا نام یا قدر';
