<?php

return [
    'Names' => [
        'Adlm' => 'адламско',
        'Afak' => 'афака',
        'Aghb' => 'кавкаскоалбански',
        'Arab' => 'арапско писмо',
        'Aran' => 'насталик',
        'Armi' => 'царскоарамејски',
        'Armn' => 'ерменско писмо',
        'Avst' => 'авестанско',
        'Bali' => 'балиско',
        'Bamu' => 'бамумско',
        'Bass' => 'баса',
        'Batk' => 'батачко',
        'Beng' => 'бенгалско писмо',
        'Blis' => 'блиссимболи',
        'Bopo' => 'бопомофо',
        'Brah' => 'брами',
        'Brai' => 'брајово писмо',
        'Bugi' => 'бугиско',
        'Buhd' => 'бухидско',
        'Cakm' => 'чакманско',
        'Cans' => 'канадско слоговно',
        'Cari' => 'кариско',
        'Cham' => 'чамско',
        'Cher' => 'черокиско',
        'Cirt' => 'кирт',
        'Copt' => 'коптско',
        'Cprt' => 'кипарско',
        'Cyrl' => 'кирилско писмо',
        'Cyrs' => 'старословенска кирилица',
        'Deva' => 'деванагари',
        'Dsrt' => 'дезеретско',
        'Dupl' => 'Диплојеево стенографско',
        'Egyd' => 'египетско демотско',
        'Egyh' => 'египетско хиератско',
        'Egyp' => 'египетски хиероглифи',
        'Elba' => 'елбасанско',
        'Ethi' => 'етиопско писмо',
        'Geok' => 'грузиски хуцури',
        'Geor' => 'грузиско писмо',
        'Glag' => 'глаголица',
        'Goth' => 'готско',
        'Gran' => 'гранта',
        'Grek' => 'грчко писмо',
        'Gujr' => 'гуџарати',
        'Guru' => 'гурмуки',
        'Hanb' => 'ханб',
        'Hang' => 'хангул',
        'Hani' => 'ханско писмо',
        'Hano' => 'хануноовско',
        'Hans' => 'поедноставено',
        'Hant' => 'традиционално',
        'Hebr' => 'хебрејско писмо',
        'Hira' => 'хирагана',
        'Hluw' => 'анадолски хиероглифи',
        'Hmng' => 'пахауанско хмоншко',
        'Hrkt' => 'јапонско слоговно',
        'Hung' => 'староунгарско',
        'Inds' => 'харапско',
        'Ital' => 'староиталско',
        'Jamo' => 'џамо',
        'Java' => 'јаванско',
        'Jpan' => 'јапонско писмо',
        'Jurc' => 'џурченско',
        'Kali' => 'каја ли',
        'Kana' => 'катакана',
        'Khar' => 'карошти',
        'Khmr' => 'кмерско писмо',
        'Khoj' => 'хоџки',
        'Knda' => 'каннада',
        'Kore' => 'корејско писмо',
        'Kpel' => 'кпелско',
        'Kthi' => 'кајти',
        'Lana' => 'ланско',
        'Laoo' => 'лаошко писмо',
        'Latf' => 'фрактурна латиница',
        'Latg' => 'гелска латиница',
        'Latn' => 'латинично писмо',
        'Lepc' => 'лепчанско',
        'Limb' => 'лимбу',
        'Lina' => 'линеарно А',
        'Linb' => 'линеарно Б',
        'Lisu' => 'Фрејзерово',
        'Loma' => 'ломско',
        'Lyci' => 'ликиско',
        'Lydi' => 'лидиско',
        'Mahj' => 'махаџани',
        'Mand' => 'мандејско',
        'Mani' => 'манихејско',
        'Maya' => 'мајански хиероглифи',
        'Mend' => 'мендско',
        'Merc' => 'мероитско ракописно',
        'Mero' => 'мероитско',
        'Mlym' => 'малајалско писмо',
        'Modi' => 'моди',
        'Mong' => 'монголско писмо',
        'Moon' => 'Муново',
        'Mroo' => 'мро',
        'Mtei' => 'мејтејско',
        'Mymr' => 'мјанмарско писмо',
        'Narb' => 'старосеверноарапско',
        'Nbat' => 'набатејско',
        'Nkgb' => 'насиска геба',
        'Nkoo' => 'нко',
        'Nshu' => 'нишу',
        'Ogam' => 'огам',
        'Olck' => 'ол чики',
        'Orkh' => 'старотурско',
        'Orya' => 'оријанско писмо',
        'Osma' => 'сомалиско',
        'Palm' => 'палмирско',
        'Pauc' => 'Паучинхауово',
        'Perm' => 'старопермско',
        'Phag' => 'пагспа',
        'Phli' => 'натписно средноперсиско',
        'Phlp' => 'псалтирско средноперсиско',
        'Phlv' => 'книжевно староперсиско',
        'Phnx' => 'феникиско',
        'Plrd' => 'Полардово',
        'Prti' => 'натписно партиско',
        'Rjng' => 'реџаншко',
        'Rohg' => 'ханифи',
        'Roro' => 'ронгоронго',
        'Runr' => 'рунско',
        'Samr' => 'самарјанско',
        'Sara' => 'сарати',
        'Sarb' => 'старојужноарапско',
        'Saur' => 'саураштранско',
        'Sgnw' => 'знаковно пишување',
        'Shaw' => 'Шоово',
        'Shrd' => 'шарада',
        'Sidd' => 'сидам',
        'Sind' => 'кудабади',
        'Sinh' => 'синхалско писмо',
        'Sora' => 'соранг сомпенг',
        'Sund' => 'сунданско',
        'Sylo' => 'силхетско нагари',
        'Syrc' => 'сириско',
        'Syre' => 'естрангелско сириско',
        'Syrj' => 'западносириско',
        'Syrn' => 'источносириско',
        'Tagb' => 'тагбанванско',
        'Takr' => 'такри',
        'Tale' => 'тај ле',
        'Talu' => 'ново тај луе',
        'Taml' => 'тамилско писмо',
        'Tang' => 'тангутско',
        'Tavt' => 'тај вјет',
        'Telu' => 'телугу',
        'Teng' => 'тенгвар',
        'Tfng' => 'тифинаг',
        'Tglg' => 'тагалошко',
        'Thaa' => 'тана',
        'Thai' => 'тајландско писмо',
        'Tibt' => 'тибетско писмо',
        'Tirh' => 'тирхута',
        'Ugar' => 'угаритско',
        'Vaii' => 'вај',
        'Visp' => 'видлив говор',
        'Wara' => 'варанг кшити',
        'Wole' => 'волеајско',
        'Xpeo' => 'староперсиско',
        'Xsux' => 'сумероакадско клинесто',
        'Yiii' => 'ји',
        'Zinh' => 'наследено',
        'Zmth' => 'математичка нотација',
        'Zsye' => 'емоџи',
        'Zsym' => 'симболи',
        'Zxxx' => 'без писмо',
        'Zyyy' => 'општо',
    ],
];
