<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Andorra peseeta',
        ],
        'AED' => [
            'AED',
            'Araabia Ühendemiraatide dirhem',
        ],
        'AFA' => [
            'AFA',
            'Afganistani afgaani (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'Afganistani afgaani',
        ],
        'ALK' => [
            'ALK',
            'Albaania lekk (1946–1965)',
        ],
        'ALL' => [
            'ALL',
            'Albaania lekk',
        ],
        'AMD' => [
            'AMD',
            'Armeenia dramm',
        ],
        'ANG' => [
            'ANG',
            'Hollandi Antillide kulden',
        ],
        'AOA' => [
            'AOA',
            'Angola kvanza',
        ],
        'AOK' => [
            'AOK',
            'Angola kvanza (1977–1990)',
        ],
        'AON' => [
            'AON',
            'Angola kvanza (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Angola reformitud kvanza, 1995–1999',
        ],
        'ARA' => [
            'ARA',
            'Argentina austral',
        ],
        'ARM' => [
            'ARM',
            'Argentina peeso (1881–1970)',
        ],
        'ARP' => [
            'ARP',
            'Argentina peeso (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'Argentina peeso',
        ],
        'ATS' => [
            'ATS',
            'Austria šilling',
        ],
        'AUD' => [
            'AU$',
            'Austraalia dollar',
        ],
        'AWG' => [
            'AWG',
            'Aruba kulden',
        ],
        'AZM' => [
            'AZM',
            'Aserbaidžaani manat (1993–2006)',
        ],
        'AZN' => [
            'AZN',
            'Aserbaidžaani manat',
        ],
        'BAD' => [
            'BAD',
            'Bosnia ja Hertsegoviina dinaar (1992–1994)',
        ],
        'BAM' => [
            'BAM',
            'Bosnia ja Hertsegoviina konverteeritav mark',
        ],
        'BAN' => [
            'BAN',
            'Bosnia ja Hertsegoviina uus dinaar (1994–1997)',
        ],
        'BBD' => [
            'BBD',
            'Barbadose dollar',
        ],
        'BDT' => [
            'BDT',
            'Bangladeshi taka',
        ],
        'BEC' => [
            'BEC',
            'Belgia konverteeritav frank',
        ],
        'BEF' => [
            'BEF',
            'Belgia frank',
        ],
        'BEL' => [
            'BEL',
            'Belgia arveldusfrank',
        ],
        'BGL' => [
            'BGL',
            'Bulgaaria püsiv leev',
        ],
        'BGN' => [
            'BGN',
            'Bulgaaria leev',
        ],
        'BGO' => [
            'BGO',
            'Bulgaaria leev (1879–1952)',
        ],
        'BHD' => [
            'BHD',
            'Bahreini dinaar',
        ],
        'BIF' => [
            'BIF',
            'Burundi frank',
        ],
        'BMD' => [
            'BMD',
            'Bermuda dollar',
        ],
        'BND' => [
            'BND',
            'Brunei dollar',
        ],
        'BOB' => [
            'BOB',
            'Boliivia boliviaano',
        ],
        'BOL' => [
            'BOL',
            'Boliivia boliviaano (1863–1963)',
        ],
        'BOP' => [
            'BOP',
            'Boliivia peeso',
        ],
        'BRB' => [
            'BRB',
            'Brasiilia uus kruseiro (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Brasiilia krusado',
        ],
        'BRE' => [
            'BRE',
            'Brasiilia kruseiro (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'Brasiilia reaal',
        ],
        'BRR' => [
            'BRR',
            'Brasiilia kruseiro (1993–1994)',
        ],
        'BRZ' => [
            'BRZ',
            'Brasiilia kruseiro (1942–1967)',
        ],
        'BSD' => [
            'BSD',
            'Bahama dollar',
        ],
        'BTN' => [
            'BTN',
            'Bhutani ngultrum',
        ],
        'BUK' => [
            'BUK',
            'Birma kjatt',
        ],
        'BWP' => [
            'BWP',
            'Botswana pula',
        ],
        'BYB' => [
            'BYB',
            'Valgevene uus rubla (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'Valgevene rubla',
        ],
        'BYR' => [
            'BYR',
            'Valgevene rubla (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'Belize’i dollar',
        ],
        'CAD' => [
            'CA$',
            'Kanada dollar',
        ],
        'CDF' => [
            'CDF',
            'Kongo frank',
        ],
        'CHF' => [
            'CHF',
            'Šveitsi frank',
        ],
        'CLE' => [
            'CLE',
            'Tšiili eskuudo',
        ],
        'CLP' => [
            'CLP',
            'Tšiili peeso',
        ],
        'CNH' => [
            'CNH',
            'Hiina jüaan (välismaine turg)',
        ],
        'CNY' => [
            'CN¥',
            'Hiina jüaan',
        ],
        'COP' => [
            'COP',
            'Colombia peeso',
        ],
        'CRC' => [
            'CRC',
            'Costa Rica koloon',
        ],
        'CSD' => [
            'CSD',
            'Serbia dinaar (2002–2006)',
        ],
        'CSK' => [
            'CSK',
            'Tšehhoslovakkia kõva kroon',
        ],
        'CUC' => [
            'CUC',
            'Kuuba konverteeritav peeso',
        ],
        'CUP' => [
            'CUP',
            'Kuuba peeso',
        ],
        'CVE' => [
            'CVE',
            'Cabo Verde eskuudo',
        ],
        'CYP' => [
            'CYP',
            'Küprose nael',
        ],
        'CZK' => [
            'CZK',
            'Tšehhi kroon',
        ],
        'DDM' => [
            'DDM',
            'Ida-Saksa mark',
        ],
        'DEM' => [
            'DEM',
            'Saksa mark',
        ],
        'DJF' => [
            'DJF',
            'Djibouti frank',
        ],
        'DKK' => [
            'DKK',
            'Taani kroon',
        ],
        'DOP' => [
            'DOP',
            'Dominikaani peeso',
        ],
        'DZD' => [
            'DZD',
            'Alžeeria dinaar',
        ],
        'ECS' => [
            'ECS',
            'Ecuadori sukre',
        ],
        'EEK' => [
            'kr',
            'Eesti kroon',
        ],
        'EGP' => [
            'EGP',
            'Egiptuse nael',
        ],
        'ERN' => [
            'ERN',
            'Eritrea nakfa',
        ],
        'ESP' => [
            'ESP',
            'Hispaania peseeta',
        ],
        'ETB' => [
            'ETB',
            'Etioopia birr',
        ],
        'EUR' => [
            '€',
            'euro',
        ],
        'FIM' => [
            'FIM',
            'Soome mark',
        ],
        'FJD' => [
            'FJD',
            'Fidži dollar',
        ],
        'FKP' => [
            'FKP',
            'Falklandi saarte nael',
        ],
        'FRF' => [
            'FRF',
            'Prantsuse frank',
        ],
        'GBP' => [
            '£',
            'Suurbritannia naelsterling',
        ],
        'GEL' => [
            'GEL',
            'Gruusia lari',
        ],
        'GHC' => [
            'GHC',
            'Ghana sedi (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'Ghana sedi',
        ],
        'GIP' => [
            'GIP',
            'Gibraltari nael',
        ],
        'GMD' => [
            'GMD',
            'Gambia dalasi',
        ],
        'GNF' => [
            'GNF',
            'Guinea frank',
        ],
        'GNS' => [
            'GNS',
            'Guinea syli',
        ],
        'GRD' => [
            'GRD',
            'Kreeka drahm',
        ],
        'GTQ' => [
            'GTQ',
            'Guatemala ketsaal',
        ],
        'GWE' => [
            'GWE',
            'Portugali Guinea eskuudo',
        ],
        'GWP' => [
            'GWP',
            'Guinea-Bissau peeso',
        ],
        'GYD' => [
            'GYD',
            'Guyana dollar',
        ],
        'HKD' => [
            'HK$',
            'Hongkongi dollar',
        ],
        'HNL' => [
            'HNL',
            'Hondurase lempiira',
        ],
        'HRD' => [
            'HRD',
            'Horvaatia dinaar',
        ],
        'HRK' => [
            'HRK',
            'Horvaatia kuna',
        ],
        'HTG' => [
            'HTG',
            'Haiti gurd',
        ],
        'HUF' => [
            'HUF',
            'Ungari forint',
        ],
        'IDR' => [
            'IDR',
            'Indoneesia ruupia',
        ],
        'IEP' => [
            'IEP',
            'Iiri nael',
        ],
        'ILP' => [
            'ILP',
            'Iisraeli nael',
        ],
        'ILR' => [
            'ILR',
            'Iisraeli seekel (1980–1985)',
        ],
        'ILS' => [
            '₪',
            'Iisraeli uus seekel',
        ],
        'INR' => [
            '₹',
            'India ruupia',
        ],
        'IQD' => [
            'IQD',
            'Iraagi dinaar',
        ],
        'IRR' => [
            'IRR',
            'Iraani riaal',
        ],
        'ISJ' => [
            'ISJ',
            'Islandi kroon (1918–1981)',
        ],
        'ISK' => [
            'ISK',
            'Islandi kroon',
        ],
        'ITL' => [
            'ITL',
            'Itaalia liir',
        ],
        'JMD' => [
            'JMD',
            'Jamaica dollar',
        ],
        'JOD' => [
            'JOD',
            'Jordaania dinaar',
        ],
        'JPY' => [
            '¥',
            'Jaapani jeen',
        ],
        'KES' => [
            'KES',
            'Keenia šilling',
        ],
        'KGS' => [
            'KGS',
            'Kõrgõzstani somm',
        ],
        'KHR' => [
            'KHR',
            'Kambodža riaal',
        ],
        'KMF' => [
            'KMF',
            'Komoori frank',
        ],
        'KPW' => [
            'KPW',
            'Põhja-Korea vonn',
        ],
        'KRO' => [
            'KRO',
            'Lõuna-Korea vonn (1945–1953)',
        ],
        'KRW' => [
            '₩',
            'Lõuna-Korea vonn',
        ],
        'KWD' => [
            'KWD',
            'Kuveidi dinaar',
        ],
        'KYD' => [
            'KYD',
            'Kaimanisaarte dollar',
        ],
        'KZT' => [
            'KZT',
            'Kasahstani tenge',
        ],
        'LAK' => [
            'LAK',
            'Laose kiip',
        ],
        'LBP' => [
            'LBP',
            'Liibanoni nael',
        ],
        'LKR' => [
            'LKR',
            'Sri Lanka ruupia',
        ],
        'LRD' => [
            'LRD',
            'Libeeria dollar',
        ],
        'LSL' => [
            'LSL',
            'Lesotho loti',
        ],
        'LTL' => [
            'LTL',
            'Leedu litt',
        ],
        'LUC' => [
            'LUC',
            'Luksemburgi konverteeritav frank',
        ],
        'LUF' => [
            'LUF',
            'Luksemburgi frank',
        ],
        'LVL' => [
            'LVL',
            'Läti latt',
        ],
        'LVR' => [
            'LVR',
            'Läti rubla',
        ],
        'LYD' => [
            'LYD',
            'Liibüa dinaar',
        ],
        'MAD' => [
            'MAD',
            'Maroko dirhem',
        ],
        'MAF' => [
            'MAF',
            'Maroko frank',
        ],
        'MCF' => [
            'MCF',
            'Monaco frank',
        ],
        'MDL' => [
            'MDL',
            'Moldova leu',
        ],
        'MGA' => [
            'MGA',
            'Madagaskari ariari',
        ],
        'MGF' => [
            'MGF',
            'Madagaskari frank',
        ],
        'MKD' => [
            'MKD',
            'Makedoonia dinaar',
        ],
        'MKN' => [
            'MKN',
            'Makedoonia dinaar (1992–1993)',
        ],
        'MLF' => [
            'MLF',
            'Mali frank',
        ],
        'MMK' => [
            'MMK',
            'Myanmari kjatt',
        ],
        'MNT' => [
            'MNT',
            'Mongoolia tugrik',
        ],
        'MOP' => [
            'MOP',
            'Macau pataaka',
        ],
        'MRO' => [
            'MRO',
            'Mauritaania ugia (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Mauritaania ugia',
        ],
        'MTL' => [
            'MTL',
            'Malta liir',
        ],
        'MTP' => [
            'MTP',
            'Malta nael',
        ],
        'MUR' => [
            'MUR',
            'Mauritiuse ruupia',
        ],
        'MVP' => [
            'MVP',
            'Maldiivi ruupia (1947–1981)',
        ],
        'MVR' => [
            'MVR',
            'Maldiivi ruupia',
        ],
        'MWK' => [
            'MWK',
            'Malawi kvatša',
        ],
        'MXN' => [
            'MX$',
            'Mehhiko peeso',
        ],
        'MXP' => [
            'MXP',
            'Mehhiko peeso (1861–1992)',
        ],
        'MYR' => [
            'MYR',
            'Malaisia ringgit',
        ],
        'MZE' => [
            'MZE',
            'Mosambiigi eskuudo',
        ],
        'MZM' => [
            'MZM',
            'Mosambiigi metikal (1980–2006)',
        ],
        'MZN' => [
            'MZN',
            'Mosambiigi metikal',
        ],
        'NAD' => [
            'NAD',
            'Namiibia dollar',
        ],
        'NGN' => [
            'NGN',
            'Nigeeria naira',
        ],
        'NIC' => [
            'NIC',
            'Nicaragua kordoba (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'Nicaragua kordoba',
        ],
        'NLG' => [
            'NLG',
            'Hollandi kulden',
        ],
        'NOK' => [
            'NOK',
            'Norra kroon',
        ],
        'NPR' => [
            'NPR',
            'Nepali ruupia',
        ],
        'NZD' => [
            'NZ$',
            'Uus-Meremaa dollar',
        ],
        'OMR' => [
            'OMR',
            'Omaani riaal',
        ],
        'PAB' => [
            'PAB',
            'Panama balboa',
        ],
        'PEI' => [
            'PEI',
            'Peruu inti',
        ],
        'PEN' => [
            'PEN',
            'Peruu soll',
        ],
        'PES' => [
            'PES',
            'Peruu soll (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'Paapua Uus-Guinea kina',
        ],
        'PHP' => [
            'PHP',
            'Filipiini peeso',
        ],
        'PKR' => [
            'PKR',
            'Pakistani ruupia',
        ],
        'PLN' => [
            'PLN',
            'Poola zlott',
        ],
        'PLZ' => [
            'PLZ',
            'Poola zlott (1950–1995)',
        ],
        'PTE' => [
            'PTE',
            'Portugali eskuudo',
        ],
        'PYG' => [
            'PYG',
            'Paraguay guaranii',
        ],
        'QAR' => [
            'QAR',
            'Katari riaal',
        ],
        'RHD' => [
            'RHD',
            'Rodeesia dollar',
        ],
        'ROL' => [
            'ROL',
            'Rumeenia leu (1952–2006)',
        ],
        'RON' => [
            'RON',
            'Rumeenia leu',
        ],
        'RSD' => [
            'RSD',
            'Serbia dinaar',
        ],
        'RUB' => [
            'RUB',
            'Venemaa rubla',
        ],
        'RUR' => [
            'RUR',
            'Venemaa rubla (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'Rwanda frank',
        ],
        'SAR' => [
            'SAR',
            'Saudi Araabia riaal',
        ],
        'SBD' => [
            'SBD',
            'Saalomoni Saarte dollar',
        ],
        'SCR' => [
            'SCR',
            'Seišelli ruupia',
        ],
        'SDD' => [
            'SDD',
            'Sudaani dinaar (1992–2007)',
        ],
        'SDG' => [
            'SDG',
            'Sudaani nael',
        ],
        'SDP' => [
            'SDP',
            'Sudaani nael (1957–1998)',
        ],
        'SEK' => [
            'SEK',
            'Rootsi kroon',
        ],
        'SGD' => [
            'SGD',
            'Singapuri dollar',
        ],
        'SHP' => [
            'SHP',
            'Saint Helena nael',
        ],
        'SIT' => [
            'SIT',
            'Sloveenia tolar',
        ],
        'SKK' => [
            'SKK',
            'Slovaki kroon',
        ],
        'SLE' => [
            'SLE',
            'Sierra Leone leoone',
        ],
        'SLL' => [
            'SLL',
            'Sierra Leone leoone (1964–2022)',
        ],
        'SOS' => [
            'SOS',
            'Somaalia šilling',
        ],
        'SRD' => [
            'SRD',
            'Suriname dollar',
        ],
        'SRG' => [
            'SRG',
            'Suriname kulden',
        ],
        'SSP' => [
            'SSP',
            'Lõuna-Sudaani nael',
        ],
        'STD' => [
            'STD',
            'São Tomé ja Príncipe dobra (1977–2017)',
        ],
        'STN' => [
            'STN',
            'São Tomé ja Príncipe dobra',
        ],
        'SUR' => [
            'SUR',
            'NSVL-i rubla',
        ],
        'SVC' => [
            'SVC',
            'El Salvadori koloon',
        ],
        'SYP' => [
            'SYP',
            'Süüria nael',
        ],
        'SZL' => [
            'SZL',
            'Svaasimaa lilangeni',
        ],
        'THB' => [
            '฿',
            'Tai baat',
        ],
        'TJR' => [
            'TJR',
            'Tadžikistani rubla',
        ],
        'TJS' => [
            'TJS',
            'Tadžikistani somoni',
        ],
        'TMM' => [
            'TMM',
            'Türkmenistani manat (1993–2009)',
        ],
        'TMT' => [
            'TMT',
            'Türkmenistani manat',
        ],
        'TND' => [
            'TND',
            'Tuneesia dinaar',
        ],
        'TOP' => [
            'TOP',
            'Tonga pa’anga',
        ],
        'TPE' => [
            'TPE',
            'Timori eskuudo',
        ],
        'TRL' => [
            'TRL',
            'Türgi liir (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'Türgi liir',
        ],
        'TTD' => [
            'TTD',
            'Trinidadi ja Tobago dollar',
        ],
        'TWD' => [
            'NT$',
            'uus Taiwani dollar',
        ],
        'TZS' => [
            'TZS',
            'Tansaania šilling',
        ],
        'UAH' => [
            'UAH',
            'Ukraina grivna',
        ],
        'UAK' => [
            'UAK',
            'Ukraina karbovanets',
        ],
        'UGS' => [
            'UGS',
            'Uganda šilling (1966–1987)',
        ],
        'UGX' => [
            'UGX',
            'Uganda šilling',
        ],
        'USD' => [
            '$',
            'USA dollar',
        ],
        'USN' => [
            'USN',
            'USA järgmise päeva dollar',
        ],
        'USS' => [
            'USS',
            'USA sama päeva dollar',
        ],
        'UYP' => [
            'UYP',
            'Uruguay peeso (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'Uruguay peeso',
        ],
        'UZS' => [
            'UZS',
            'Usbekistani somm',
        ],
        'VEB' => [
            'VEB',
            'Venezuela boliivar (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'Venezuela boliivar (2008–2018)',
        ],
        'VES' => [
            'VES',
            'Venezuela boliivar',
        ],
        'VND' => [
            '₫',
            'Vietnami dong',
        ],
        'VNN' => [
            'VNN',
            'Vietnami dong (1978–1985)',
        ],
        'VUV' => [
            'VUV',
            'Vanuatu vatu',
        ],
        'WST' => [
            'WST',
            'Samoa taala',
        ],
        'XAF' => [
            'FCFA',
            'Kesk-Aafrika CFA frank',
        ],
        'XCD' => [
            'EC$',
            'Ida-Kariibi dollar',
        ],
        'XCG' => [
            'Cg.',
            'Kariibi kulden',
        ],
        'XEU' => [
            'XEU',
            'eküü',
        ],
        'XFO' => [
            'XFO',
            'Prantsuse kuldfrank',
        ],
        'XFU' => [
            'XFU',
            'Prantsuse UIC-frank',
        ],
        'XOF' => [
            'F CFA',
            'Lääne-Aafrika CFA frank',
        ],
        'XPF' => [
            'CFPF',
            'CFP frank',
        ],
        'YDD' => [
            'YDD',
            'Jeemeni dinaar',
        ],
        'YER' => [
            'YER',
            'Jeemeni riaal',
        ],
        'YUD' => [
            'YUD',
            'Jugoslaavia kõva dinaar (1966–1990)',
        ],
        'YUM' => [
            'YUM',
            'Jugoslaavia uus dinaar (1994–2002)',
        ],
        'YUN' => [
            'YUN',
            'Jugoslaavia konverteeritav dinaar (1990–1992)',
        ],
        'YUR' => [
            'YUR',
            'Jugoslaavia reformitud dinaar (1992–1993)',
        ],
        'ZAR' => [
            'ZAR',
            'Lõuna-Aafrika rand',
        ],
        'ZMK' => [
            'ZMK',
            'Sambia kvatša (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Sambia kvatša',
        ],
        'ZRZ' => [
            'ZRZ',
            'Sairi zaire',
        ],
        'ZWD' => [
            'ZWD',
            'Zimbabwe dollar (1980–2008)',
        ],
        'ZWG' => [
            'ZWG',
            'Zimbabwe kuld',
        ],
        'ZWL' => [
            'ZWL',
            'Zimbabwe dollar (2009)',
        ],
        'ZWR' => [
            'ZWR',
            'Zimbabwe dollar (2008)',
        ],
    ],
];
