<?php

return [
    '🏳‍🌈' => 'bandiera iride',
    '🏴‍☠' => 'bandiera de pirata',
    '💪🏻' => 'biceps flectite: tono de pelle clar',
    '💪🏼' => 'biceps flectite: tono de pelle medio clar',
    '💪🏽' => 'biceps flectite: tono de pelle medie',
    '💪🏾' => 'biceps flectite: tono de pelle medio-obscur',
    '💪🏿' => 'biceps flectite: tono de pelle obscur',
    '🦵🏻' => 'gamba: tono de pelle clar',
    '🦵🏼' => 'gamba: tono de pelle medio clar',
    '🦵🏽' => 'gamba: tono de pelle medie',
    '🦵🏾' => 'gamba: tono de pelle medio-obscur',
    '🦵🏿' => 'gamba: tono de pelle obscur',
    '🦶🏻' => 'pede: tono de pelle clar',
    '🦶🏼' => 'pede: tono de pelle medio clar',
    '🦶🏽' => 'pede: tono de pelle medie',
    '🦶🏾' => 'pede: tono de pelle medio-obscur',
    '🦶🏿' => 'pede: tono de pelle obscur',
    '👂🏻' => 'aure: tono de pelle clar',
    '👂🏼' => 'aure: tono de pelle medio clar',
    '👂🏽' => 'aure: tono de pelle medie',
    '👂🏾' => 'aure: tono de pelle medio-obscur',
    '👂🏿' => 'aure: tono de pelle obscur',
    '🦻🏻' => 'aure con audiophono: tono de pelle clar',
    '🦻🏼' => 'aure con audiophono: tono de pelle medio clar',
    '🦻🏽' => 'aure con audiophono: tono de pelle medie',
    '🦻🏾' => 'aure con audiophono: tono de pelle medio-obscur',
    '🦻🏿' => 'aure con audiophono: tono de pelle obscur',
    '👃🏻' => 'naso: tono de pelle clar',
    '👃🏼' => 'naso: tono de pelle medio clar',
    '👃🏽' => 'naso: tono de pelle medie',
    '👃🏾' => 'naso: tono de pelle medio-obscur',
    '👃🏿' => 'naso: tono de pelle obscur',
    '🤵🏻' => 'persona in tuxedo: tono de pelle clar',
    '🤵🏼' => 'persona in tuxedo: tono de pelle medio clar',
    '🤵🏽' => 'persona in tuxedo: tono de pelle medie',
    '🤵🏾' => 'persona in tuxedo: tono de pelle medio-obscur',
    '🤵🏿' => 'persona in tuxedo: tono de pelle obscur',
    '👰🏻' => 'persona con vela: tono de pelle clar',
    '👰🏼' => 'persona con vela: tono de pelle medio clar',
    '👰🏽' => 'persona con vela: tono de pelle medie',
    '👰🏾' => 'persona con vela: tono de pelle medio-obscur',
    '👰🏿' => 'persona con vela: tono de pelle obscur',
    '🇦🇨' => 'bandiera: Insula del Ascension',
    '🇦🇩' => 'bandiera: Andorra',
    '🇦🇪' => 'bandiera: Emiratos Arabe Unite',
    '🇦🇫' => 'bandiera: Afghanistan',
    '🇦🇬' => 'bandiera: Antigua e Barbuda',
    '🇦🇮' => 'bandiera: Anguilla',
    '🇦🇱' => 'bandiera: Albania',
    '🇦🇲' => 'bandiera: Armenia',
    '🇦🇴' => 'bandiera: Angola',
    '🇦🇶' => 'bandiera: Antarctica',
    '🇦🇷' => 'bandiera: Argentina',
    '🇦🇸' => 'bandiera: Samoa american',
    '🇦🇹' => 'bandiera: Austria',
    '🇦🇺' => 'bandiera: Australia',
    '🇦🇼' => 'bandiera: Aruba',
    '🇦🇽' => 'bandiera: Insulas Åland',
    '🇦🇿' => 'bandiera: Azerbaidzhan',
    '🇧🇦' => 'bandiera: Bosnia e Herzegovina',
    '🇧🇧' => 'bandiera: Barbados',
    '🇧🇩' => 'bandiera: Bangladesh',
    '🇧🇪' => 'bandiera: Belgica',
    '🇧🇫' => 'bandiera: Burkina Faso',
    '🇧🇬' => 'bandiera: Bulgaria',
    '🇧🇭' => 'bandiera: Bahrain',
    '🇧🇮' => 'bandiera: Burundi',
    '🇧🇯' => 'bandiera: Benin',
    '🇧🇱' => 'bandiera: Sancte Bartholomeo',
    '🇧🇲' => 'bandiera: Bermuda',
    '🇧🇳' => 'bandiera: Brunei',
    '🇧🇴' => 'bandiera: Bolivia',
    '🇧🇶' => 'bandiera: Paises Basse caribe',
    '🇧🇷' => 'bandiera: Brasil',
    '🇧🇸' => 'bandiera: Bahamas',
    '🇧🇹' => 'bandiera: Bhutan',
    '🇧🇻' => 'bandiera: Insula de Bouvet',
    '🇧🇼' => 'bandiera: Botswana',
    '🇧🇾' => 'bandiera: Bielorussia',
    '🇧🇿' => 'bandiera: Belize',
    '🇨🇦' => 'bandiera: Canada',
    '🇨🇨' => 'bandiera: Insulas Cocos (Keeling)',
    '🇨🇩' => 'bandiera: Congo - Kinshasa',
    '🇨🇫' => 'bandiera: Republica African Central',
    '🇨🇬' => 'bandiera: Congo - Brazzaville',
    '🇨🇭' => 'bandiera: Suissa',
    '🇨🇮' => 'bandiera: Costa de Ebore',
    '🇨🇰' => 'bandiera: Insulas Cook',
    '🇨🇱' => 'bandiera: Chile',
    '🇨🇲' => 'bandiera: Camerun',
    '🇨🇳' => 'bandiera: China',
    '🇨🇴' => 'bandiera: Colombia',
    '🇨🇵' => 'bandiera: Insula Clipperton',
    '🇨🇶' => 'bandiera: Sark',
    '🇨🇷' => 'bandiera: Costa Rica',
    '🇨🇺' => 'bandiera: Cuba',
    '🇨🇻' => 'bandiera: Capo Verde',
    '🇨🇼' => 'bandiera: Curaçao',
    '🇨🇽' => 'bandiera: Insula de Natal',
    '🇨🇾' => 'bandiera: Cypro',
    '🇨🇿' => 'bandiera: Chechia',
    '🇩🇪' => 'bandiera: Germania',
    '🇩🇬' => 'bandiera: Diego Garcia',
    '🇩🇯' => 'bandiera: Djibuti',
    '🇩🇰' => 'bandiera: Danmark',
    '🇩🇲' => 'bandiera: Dominica',
    '🇩🇴' => 'bandiera: Republica Dominican',
    '🇩🇿' => 'bandiera: Algeria',
    '🇪🇦' => 'bandiera: Ceuta e Melilla',
    '🇪🇨' => 'bandiera: Ecuador',
    '🇪🇪' => 'bandiera: Estonia',
    '🇪🇬' => 'bandiera: Egypto',
    '🇪🇭' => 'bandiera: Sahara occidental',
    '🇪🇷' => 'bandiera: Eritrea',
    '🇪🇸' => 'bandiera: Espania',
    '🇪🇹' => 'bandiera: Ethiopia',
    '🇪🇺' => 'bandiera: Union Europee',
    '🇫🇮' => 'bandiera: Finlandia',
    '🇫🇯' => 'bandiera: Fiji',
    '🇫🇰' => 'bandiera: Insulas Falkland',
    '🇫🇲' => 'bandiera: Micronesia',
    '🇫🇴' => 'bandiera: Insulas Feroe',
    '🇫🇷' => 'bandiera: Francia',
    '🇬🇦' => 'bandiera: Gabon',
    '🇬🇧' => 'bandiera: Regno Unite',
    '🇬🇩' => 'bandiera: Grenada',
    '🇬🇪' => 'bandiera: Georgia',
    '🇬🇫' => 'bandiera: Guyana francese',
    '🇬🇬' => 'bandiera: Guernsey',
    '🇬🇭' => 'bandiera: Ghana',
    '🇬🇮' => 'bandiera: Gibraltar',
    '🇬🇱' => 'bandiera: Groenlandia',
    '🇬🇲' => 'bandiera: Gambia',
    '🇬🇳' => 'bandiera: Guinea',
    '🇬🇵' => 'bandiera: Guadeloupe',
    '🇬🇶' => 'bandiera: Guinea equatorial',
    '🇬🇷' => 'bandiera: Grecia',
    '🇬🇸' => 'bandiera: Georgia del Sud e Insulas Sandwich Austral',
    '🇬🇹' => 'bandiera: Guatemala',
    '🇬🇺' => 'bandiera: Guam',
    '🇬🇼' => 'bandiera: Guinea-Bissau',
    '🇬🇾' => 'bandiera: Guyana',
    '🇭🇰' => 'bandiera: Hongkong, R.A.S. de China',
    '🇭🇲' => 'bandiera: Insulas Heard e McDonald',
    '🇭🇳' => 'bandiera: Honduras',
    '🇭🇷' => 'bandiera: Croatia',
    '🇭🇹' => 'bandiera: Haiti',
    '🇭🇺' => 'bandiera: Hungaria',
    '🇮🇨' => 'bandiera: Insulas Canari',
    '🇮🇩' => 'bandiera: Indonesia',
    '🇮🇪' => 'bandiera: Irlanda',
    '🇮🇱' => 'bandiera: Israel',
    '🇮🇲' => 'bandiera: Insula de Man',
    '🇮🇳' => 'bandiera: India',
    '🇮🇴' => 'bandiera: Territorio oceanic britanno-indian',
    '🇮🇶' => 'bandiera: Irak',
    '🇮🇷' => 'bandiera: Iran',
    '🇮🇸' => 'bandiera: Islanda',
    '🇮🇹' => 'bandiera: Italia',
    '🇯🇪' => 'bandiera: Jersey',
    '🇯🇲' => 'bandiera: Jamaica',
    '🇯🇴' => 'bandiera: Jordania',
    '🇯🇵' => 'bandiera: Japon',
    '🇰🇪' => 'bandiera: Kenya',
    '🇰🇬' => 'bandiera: Kirghizistan',
    '🇰🇭' => 'bandiera: Cambodgia',
    '🇰🇮' => 'bandiera: Kiribati',
    '🇰🇲' => 'bandiera: Comoros',
    '🇰🇳' => 'bandiera: Sancte Christophoro e Nevis',
    '🇰🇵' => 'bandiera: Corea del Nord',
    '🇰🇷' => 'bandiera: Corea del Sud',
    '🇰🇼' => 'bandiera: Kuwait',
    '🇰🇾' => 'bandiera: Insulas de Caiman',
    '🇰🇿' => 'bandiera: Kazakhstan',
    '🇱🇦' => 'bandiera: Laos',
    '🇱🇧' => 'bandiera: Libano',
    '🇱🇨' => 'bandiera: Sancte Lucia',
    '🇱🇮' => 'bandiera: Liechtenstein',
    '🇱🇰' => 'bandiera: Sri Lanka',
    '🇱🇷' => 'bandiera: Liberia',
    '🇱🇸' => 'bandiera: Lesotho',
    '🇱🇹' => 'bandiera: Lituania',
    '🇱🇺' => 'bandiera: Luxemburg',
    '🇱🇻' => 'bandiera: Lettonia',
    '🇱🇾' => 'bandiera: Libya',
    '🇲🇦' => 'bandiera: Marocco',
    '🇲🇨' => 'bandiera: Monaco',
    '🇲🇩' => 'bandiera: Moldavia',
    '🇲🇪' => 'bandiera: Montenegro',
    '🇲🇫' => 'bandiera: Sancte Martino francese',
    '🇲🇬' => 'bandiera: Madagascar',
    '🇲🇭' => 'bandiera: Insulas Marshall',
    '🇲🇰' => 'bandiera: Macedonia del Nord',
    '🇲🇱' => 'bandiera: Mali',
    '🇲🇲' => 'bandiera: Myanmar (Birmania)',
    '🇲🇳' => 'bandiera: Mongolia',
    '🇲🇴' => 'bandiera: Macao, R.A.S. de China',
    '🇲🇵' => 'bandiera: Insulas Marianna del Nord',
    '🇲🇶' => 'bandiera: Martinica',
    '🇲🇷' => 'bandiera: Mauritania',
    '🇲🇸' => 'bandiera: Montserrat',
    '🇲🇹' => 'bandiera: Malta',
    '🇲🇺' => 'bandiera: Mauritio',
    '🇲🇻' => 'bandiera: Maldivas',
    '🇲🇼' => 'bandiera: Malawi',
    '🇲🇽' => 'bandiera: Mexico',
    '🇲🇾' => 'bandiera: Malaysia',
    '🇲🇿' => 'bandiera: Mozambique',
    '🇳🇦' => 'bandiera: Namibia',
    '🇳🇨' => 'bandiera: Nove Caledonia',
    '🇳🇪' => 'bandiera: Niger',
    '🇳🇫' => 'bandiera: Insula Norfolk',
    '🇳🇬' => 'bandiera: Nigeria',
    '🇳🇮' => 'bandiera: Nicaragua',
    '🇳🇱' => 'bandiera: Nederlandia',
    '🇳🇴' => 'bandiera: Norvegia',
    '🇳🇵' => 'bandiera: Nepal',
    '🇳🇷' => 'bandiera: Nauru',
    '🇳🇺' => 'bandiera: Niue',
    '🇳🇿' => 'bandiera: Nove Zelanda',
    '🇴🇲' => 'bandiera: Oman',
    '🇵🇦' => 'bandiera: Panama',
    '🇵🇪' => 'bandiera: Peru',
    '🇵🇫' => 'bandiera: Polynesia francese',
    '🇵🇬' => 'bandiera: Papua Nove Guinea',
    '🇵🇭' => 'bandiera: Philippinas',
    '🇵🇰' => 'bandiera: Pakistan',
    '🇵🇱' => 'bandiera: Polonia',
    '🇵🇲' => 'bandiera: St. Pierre e Miquelon',
    '🇵🇳' => 'bandiera: Insulas Pitcairn',
    '🇵🇷' => 'bandiera: Porto Rico',
    '🇵🇸' => 'bandiera: Territorios palestin',
    '🇵🇹' => 'bandiera: Portugal',
    '🇵🇼' => 'bandiera: Palau',
    '🇵🇾' => 'bandiera: Paraguay',
    '🇶🇦' => 'bandiera: Qatar',
    '🇷🇪' => 'bandiera: Reunion',
    '🇷🇴' => 'bandiera: Romania',
    '🇷🇸' => 'bandiera: Serbia',
    '🇷🇺' => 'bandiera: Russia',
    '🇷🇼' => 'bandiera: Ruanda',
    '🇸🇦' => 'bandiera: Arabia Saudita',
    '🇸🇧' => 'bandiera: Insulas Solomon',
    '🇸🇨' => 'bandiera: Seychelles',
    '🇸🇩' => 'bandiera: Sudan',
    '🇸🇪' => 'bandiera: Svedia',
    '🇸🇬' => 'bandiera: Singapur',
    '🇸🇭' => 'bandiera: Sancte Helena',
    '🇸🇮' => 'bandiera: Slovenia',
    '🇸🇯' => 'bandiera: Svalbard e Jan Mayen',
    '🇸🇰' => 'bandiera: Slovachia',
    '🇸🇱' => 'bandiera: Sierra Leone',
    '🇸🇲' => 'bandiera: San Marino',
    '🇸🇳' => 'bandiera: Senegal',
    '🇸🇴' => 'bandiera: Somalia',
    '🇸🇷' => 'bandiera: Suriname',
    '🇸🇸' => 'bandiera: Sudan del Sud',
    '🇸🇹' => 'bandiera: São Tomé e Príncipe',
    '🇸🇻' => 'bandiera: El Salvador',
    '🇸🇽' => 'bandiera: Sancte Martino nederlandese',
    '🇸🇾' => 'bandiera: Syria',
    '🇸🇿' => 'bandiera: Eswatini',
    '🇹🇦' => 'bandiera: Tristan da Cunha',
    '🇹🇨' => 'bandiera: Insulas Turcos e Caicos',
    '🇹🇩' => 'bandiera: Tchad',
    '🇹🇫' => 'bandiera: Territorios meridional francese',
    '🇹🇬' => 'bandiera: Togo',
    '🇹🇭' => 'bandiera: Thailandia',
    '🇹🇯' => 'bandiera: Tadzhikistan',
    '🇹🇰' => 'bandiera: Tokelau',
    '🇹🇱' => 'bandiera: Timor del Est',
    '🇹🇲' => 'bandiera: Turkmenistan',
    '🇹🇳' => 'bandiera: Tunisia',
    '🇹🇴' => 'bandiera: Tonga',
    '🇹🇷' => 'bandiera: Turchia',
    '🇹🇹' => 'bandiera: Trinidad e Tobago',
    '🇹🇻' => 'bandiera: Tuvalu',
    '🇹🇼' => 'bandiera: Taiwan',
    '🇹🇿' => 'bandiera: Tanzania',
    '🇺🇦' => 'bandiera: Ukraina',
    '🇺🇬' => 'bandiera: Uganda',
    '🇺🇲' => 'bandiera: Insulas peripheric del SUA',
    '🇺🇳' => 'bandiera: Nationes Unite',
    '🇺🇸' => 'bandiera: Statos Unite',
    '🇺🇾' => 'bandiera: Uruguay',
    '🇺🇿' => 'bandiera: Uzbekistan',
    '🇻🇦' => 'bandiera: Citate del Vaticano',
    '🇻🇨' => 'bandiera: Sancte Vincente e le Grenadinas',
    '🇻🇪' => 'bandiera: Venezuela',
    '🇻🇬' => 'bandiera: Insulas Virgine britannic',
    '🇻🇮' => 'bandiera: Insulas Virgine statounitese',
    '🇻🇳' => 'bandiera: Vietnam',
    '🇻🇺' => 'bandiera: Vanuatu',
    '🇼🇫' => 'bandiera: Wallis e Futuna',
    '🇼🇸' => 'bandiera: Samoa',
    '🇽🇰' => 'bandiera: Kosovo',
    '🇾🇪' => 'bandiera: Yemen',
    '🇾🇹' => 'bandiera: Mayotte',
    '🇿🇦' => 'bandiera: Africa del Sud',
    '🇿🇲' => 'bandiera: Zambia',
    '🇿🇼' => 'bandiera: Zimbabwe',
    '🔟' => 'clave: 10',
    '🏻' => 'tono de pelle clar',
    '🏼' => 'tono de pelle medio clar',
    '🏽' => 'tono de pelle medie',
    '🏾' => 'tono de pelle medio-obscur',
    '🏿' => 'tono de pelle obscur',
    '😀' => 'visage con grande surriso',
    '😃' => 'grande surriso con grande oculos',
    '😄' => 'grande surriso con oculos surridente',
    '😁' => 'visage radiante con oculos surridente',
    '😆' => 'grande surriso con oculos semiclaudite',
    '😅' => 'grande surriso con gutta de sudor',
    '🤣' => 'rolante se per terra de rider',
    '😂' => 'visage plorante de riso',
    '😉' => 'visage que batte le palpebras',
    '😊' => 'surriso con oculos surridente',
    '😍' => 'surriso con oculos in forma de corde',
    '😋' => 'visage que sapora un bon repasto',
    '😎' => 'surriso con oculares de sol',
    '💪' => 'biceps flectite',
    '🦾' => 'bracio mechanic',
    '🦿' => 'gamba mechanic',
    '🦵' => 'gamba',
    '🦶' => 'pede',
    '👂' => 'aure',
    '🦻' => 'aure con audiophono',
    '👃' => 'naso',
    '🧠' => 'cerebro',
    '🫀' => 'corde',
    '🫁' => 'pulmones',
    '🦷' => 'dente',
    '🦴' => 'osso',
    '👀' => 'oculos',
    '👁' => 'oculo',
    '👅' => 'lingua',
    '👄' => 'bucca',
    '🤵' => 'persona in tuxedo',
    '👰' => 'persona con vela',
    '🦰' => 'capillos rosse',
    '🦱' => 'capillos crispe',
    '🦳' => 'capillos blanc',
    '🦲' => 'calve',
    '🏧' => 'signo de cassa automatic',
    '🚮' => 'signo de receptaculo de immunditias',
    '🚰' => 'aqua potabile',
    '♿' => 'symbolo de sedia rolante',
    '🚹' => 'lavatorio pro homines',
    '🚺' => 'lavatorio pro feminas',
    '🚻' => 'lavatorio',
    '🚼' => 'symbolo de bebe',
    '🚾' => 'water-closet',
    '🛂' => 'controlo de passaportos',
    '🛃' => 'doana',
    '🛄' => 'collecta de bagage',
    '🛅' => 'deposito de bagage',
    '⚠' => 'aviso',
    '🚸' => 'transversata de infantes',
    '⛔' => 'entrata prohibite',
    '🚫' => 'prohibite',
    '🚳' => 'bicyclettas prohibite',
    '🚭' => 'non fumar',
    '🚯' => 'non abandonar immunditias',
    '🚱' => 'aqua non potabile',
    '🚷' => 'prohibite al pedones',
    '📵' => 'telephonos mobile prohibite',
    '✖' => 'multiplication',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'division',
    '🏁' => 'bandiera a quadros',
    '🚩' => 'bandiera triangular',
    '🎌' => 'bandieras cruciate',
    '🏴' => 'bandiera nigre',
    '🏳' => 'bandiera blanc',
];
