<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwich Mean Berɛ (Abigyan)',
        'Africa/Accra' => 'Greenwich Mean Berɛ (Akraa)',
        'Africa/Addis_Ababa' => 'Afrika Apueeɛ Berɛ (Addis Ababa)',
        'Africa/Algiers' => 'Yuropu Mfinimfini Berɛ (Ɔlgyese)',
        'Africa/Asmera' => 'Afrika Apueeɛ Berɛ (Asmara)',
        'Africa/Asmara' => 'Afrika Apueeɛ Berɛ (Asmara)',
        'Africa/Bamako' => 'Greenwich Mean Berɛ (Bamako)',
        'Africa/Bangui' => 'Afrika Atɔeɛ Berɛ (Bangui)',
        'Africa/Banjul' => 'Greenwich Mean Berɛ (Bandwuu)',
        'Africa/Bissau' => 'Greenwich Mean Berɛ (Bisaw)',
        'Africa/Blantyre' => 'Afrika Finimfin Berɛ (Blantai)',
        'Africa/Brazzaville' => 'Afrika Atɔeɛ Berɛ (Brazzaville)',
        'Africa/Bujumbura' => 'Afrika Finimfin Berɛ (Budwumbura)',
        'Africa/Cairo' => 'Yuropu Apueeɛ Berɛ (Kairo)',
        'Africa/Casablanca' => 'Yuropu Atɔeeɛ Berɛ (Casablanca)',
        'Africa/Ceuta' => 'Yuropu Mfinimfini Berɛ (kiweta)',
        'Africa/Conakry' => 'Greenwich Mean Berɛ (Kɔnakri)',
        'Africa/Dakar' => 'Greenwich Mean Berɛ (Dakaa)',
        'Africa/Dar_es_Salaam' => 'Afrika Apueeɛ Berɛ (Dar es Salaam)',
        'Africa/Djibouti' => 'Afrika Apueeɛ Berɛ (Gyibuuti)',
        'Africa/Douala' => 'Afrika Atɔeɛ Berɛ (Douala)',
        'Africa/El_Aaiun' => 'Yuropu Atɔeeɛ Berɛ (El Aaiún)',
        'Africa/Freetown' => 'Greenwich Mean Berɛ (Freetown)',
        'Africa/Gaborone' => 'Afrika Finimfin Berɛ (Gaborone)',
        'Africa/Harare' => 'Afrika Finimfin Berɛ (Harare)',
        'Africa/Johannesburg' => 'Afrika Anaafoɔ Susudua Berɛ (Johannesburg)',
        'Africa/Juba' => 'Afrika Finimfin Berɛ (Dwuba)',
        'Africa/Kampala' => 'Afrika Apueeɛ Berɛ (Kampala)',
        'Africa/Khartoum' => 'Afrika Finimfin Berɛ (Khartoum)',
        'Africa/Kigali' => 'Afrika Finimfin Berɛ (Kigali)',
        'Africa/Kinshasa' => 'Afrika Atɔeɛ Berɛ (Kinhyaahya)',
        'Africa/Lagos' => 'Afrika Atɔeɛ Berɛ (Legɔs)',
        'Africa/Libreville' => 'Afrika Atɔeɛ Berɛ (Libreville)',
        'Africa/Lome' => 'Greenwich Mean Berɛ (Lomé)',
        'Africa/Luanda' => 'Afrika Atɔeɛ Berɛ (Luanda)',
        'Africa/Lubumbashi' => 'Afrika Finimfin Berɛ (Lubumbashi)',
        'Africa/Lusaka' => 'Afrika Finimfin Berɛ (Lusaka)',
        'Africa/Malabo' => 'Afrika Atɔeɛ Berɛ (Malabo)',
        'Africa/Maputo' => 'Afrika Finimfin Berɛ (Maputo)',
        'Africa/Maseru' => 'Afrika Anaafoɔ Susudua Berɛ (Maseru)',
        'Africa/Mbabane' => 'Afrika Anaafoɔ Susudua Berɛ (Mbabane)',
        'Africa/Mogadishu' => 'Afrika Apueeɛ Berɛ (Mogadishu)',
        'Africa/Monrovia' => 'Greenwich Mean Berɛ (Monrovia)',
        'Africa/Nairobi' => 'Afrika Apueeɛ Berɛ (Nairobi)',
        'Africa/Ndjamena' => 'Afrika Atɔeɛ Berɛ (Ngyamena)',
        'Africa/Niamey' => 'Afrika Atɔeɛ Berɛ (Niamey)',
        'Africa/Nouakchott' => 'Greenwich Mean Berɛ (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwich Mean Berɛ (Wagadugu)',
        'Africa/Porto-Novo' => 'Afrika Atɔeɛ Berɛ (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwich Mean Berɛ (São Tomé)',
        'Africa/Tripoli' => 'Yuropu Apueeɛ Berɛ (Tripoli)',
        'Africa/Tunis' => 'Yuropu Mfinimfini Berɛ (Tunis)',
        'Africa/Windhoek' => 'Afrika Finimfin Berɛ (Windhoek)',
        'America/Adak' => 'Hawaii-Aleutian Berɛ (Adak)',
        'America/Anchorage' => 'Alaska Berɛ (Ankɔragyi)',
        'America/Anguilla' => 'Atlantik Berɛ (Anguila)',
        'America/Antigua' => 'Atlantik Berɛ (Antigua)',
        'America/Araguaina' => 'Brasilia Berɛ (Araguaína)',
        'America/Argentina/La_Rioja' => 'Agyɛntina Berɛ (La Riogya)',
        'America/Argentina/Rio_Gallegos' => 'Agyɛntina Berɛ (Rio Gallegɔs)',
        'America/Argentina/Salta' => 'Agyɛntina Berɛ (Salta)',
        'America/Argentina/San_Juan' => 'Agyɛntina Berɛ (San Dwuan)',
        'America/Argentina/San_Luis' => 'Agyɛntina Berɛ (San Luis)',
        'America/Argentina/Tucuman' => 'Agyɛntina Berɛ (Tukuman)',
        'America/Argentina/Ushuaia' => 'Agyɛntina Berɛ (Ushuaia)',
        'America/Aruba' => 'Atlantik Berɛ (Aruba)',
        'America/Asuncion' => 'Paraguae Berɛ (Asunción)',
        'America/Bahia' => 'Brasilia Berɛ (Bahia)',
        'America/Bahia_Banderas' => 'Mfinimfini Berɛ (Bahía de Banderas)',
        'America/Barbados' => 'Atlantik Berɛ (Baabados)',
        'America/Belem' => 'Brasilia Berɛ (Bɛlɛm)',
        'America/Belize' => 'Mfinimfini Berɛ (Bɛlisi)',
        'America/Blanc-Sablon' => 'Atlantik Berɛ (Blanc-Sablɔn)',
        'America/Boa_Vista' => 'Amazon Berɛ (Boa Vista)',
        'America/Bogota' => 'Kolombia Berɛ (Bogotá)',
        'America/Boise' => 'Bepɔ Berɛ (Bɔisi)',
        'America/Buenos_Aires' => 'Agyɛntina Berɛ (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Agyɛntina Berɛ (Buenos Aires)',
        'America/Cambridge_Bay' => 'Bepɔ Berɛ (Kambrigyi Bay)',
        'America/Campo_Grande' => 'Amazon Berɛ (Kampo Grande)',
        'America/Cancun' => 'Apueeɛ Berɛ (Kankun)',
        'America/Caracas' => 'Venezuela Berɛ (Karakas)',
        'America/Catamarca' => 'Agyɛntina Berɛ (Katamaaka)',
        'America/Argentina/Catamarca' => 'Agyɛntina Berɛ (Katamaaka)',
        'America/Cayenne' => 'Frɛnkye Gayana Berɛ (Kayiini)',
        'America/Cayman' => 'Apueeɛ Berɛ (Cayman)',
        'America/Chicago' => 'Mfinimfini Berɛ (Kyikago)',
        'America/Chihuahua' => 'Mfinimfini Berɛ (Kyihuahua)',
        'America/Ciudad_Juarez' => 'Bepɔ Berɛ (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Apueeɛ Berɛ (Atikokan)',
        'America/Atikokan' => 'Apueeɛ Berɛ (Atikokan)',
        'America/Cordoba' => 'Agyɛntina Berɛ (Kɔɔdɔba)',
        'America/Argentina/Cordoba' => 'Agyɛntina Berɛ (Kɔɔdɔba)',
        'America/Costa_Rica' => 'Mfinimfini Berɛ (Kɔsta Rika)',
        'America/Coyhaique' => 'Kyili Berɛ (Coyhaique)',
        'America/Creston' => 'Bepɔ Berɛ (Krɛston)',
        'America/Cuiaba' => 'Amazon Berɛ (Kuiaba)',
        'America/Curacao' => 'Atlantik Berɛ (Kurukaw)',
        'America/Danmarkshavn' => 'Greenwich Mean Berɛ (Danmarkshavn)',
        'America/Dawson' => 'Yukɔn Berɛ (Dɔɔson)',
        'America/Dawson_Creek' => 'Bepɔ Berɛ (Dɔɔson Kreek)',
        'America/Denver' => 'Bepɔ Berɛ (Dɛnva)',
        'America/Detroit' => 'Apueeɛ Berɛ (Detrɔit)',
        'America/Dominica' => 'Atlantik Berɛ (Dɔmeneka)',
        'America/Edmonton' => 'Bepɔ Berɛ (Edmɔnton)',
        'America/Eirunepe' => 'Berɛ Brazil (Eirunepé)',
        'America/El_Salvador' => 'Mfinimfini Berɛ (El Salvadɔɔ)',
        'America/Fort_Nelson' => 'Bepɔ Berɛ (Fɔt Nɛlson)',
        'America/Fortaleza' => 'Brasilia Berɛ (Fɔɔtalɛsa)',
        'America/Glace_Bay' => 'Atlantik Berɛ (Glace Bay)',
        'America/Godthab' => 'Berɛ Greenman (Nuuk)',
        'America/Nuuk' => 'Berɛ Greenman (Nuuk)',
        'America/Goose_Bay' => 'Atlantik Berɛ (Guus Bay)',
        'America/Grand_Turk' => 'Apueeɛ Berɛ (Grand Tuk)',
        'America/Grenada' => 'Atlantik Berɛ (Grenada)',
        'America/Guadeloupe' => 'Atlantik Berɛ (Guwadelup)',
        'America/Guatemala' => 'Mfinimfini Berɛ (Guwatemala)',
        'America/Guayaquil' => 'Yikuwedɔ Berɛ (Gayakwuil)',
        'America/Guyana' => 'Gayana Berɛ',
        'America/Halifax' => 'Atlantik Berɛ (Halifax)',
        'America/Havana' => 'Kuba Berɛ (Havana)',
        'America/Hermosillo' => 'Mɛksiko Pasifik Berɛ (Hɛmɔsilo)',
        'America/Indiana/Knox' => 'Mfinimfini Berɛ (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Apueeɛ Berɛ (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Apueeɛ Berɛ (Pitɛsbɛgye, Indiana)',
        'America/Indiana/Tell_City' => 'Mfinimfini Berɛ (Tell Siti, Indiana)',
        'America/Indiana/Vevay' => 'Apueeɛ Berɛ (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Apueeɛ Berɛ (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Apueeɛ Berɛ (Winamak, Indiana)',
        'America/Indianapolis' => 'Apueeɛ Berɛ (Indianapɔlis)',
        'America/Indiana/Indianapolis' => 'Apueeɛ Berɛ (Indianapɔlis)',
        'America/Inuvik' => 'Bepɔ Berɛ (Inuvik)',
        'America/Iqaluit' => 'Apueeɛ Berɛ (Ikaluit)',
        'America/Jamaica' => 'Apueeɛ Berɛ (Gyameka)',
        'America/Jujuy' => 'Agyɛntina Berɛ (Dwudwui)',
        'America/Argentina/Jujuy' => 'Agyɛntina Berɛ (Dwudwui)',
        'America/Juneau' => 'Alaska Berɛ (Juneau)',
        'America/Kentucky/Monticello' => 'Apueeɛ Berɛ (Mɔntisɛlo, Kɛntɛki)',
        'America/Kralendijk' => 'Atlantik Berɛ (Kralɛngyik)',
        'America/La_Paz' => 'Bolivia Berɛ (La Paz)',
        'America/Lima' => 'Peru Berɛ (Lima)',
        'America/Los_Angeles' => 'Pasifik Berɛ (Lɔs Angyɛlis)',
        'America/Louisville' => 'Apueeɛ Berɛ (Louisville)',
        'America/Kentucky/Louisville' => 'Apueeɛ Berɛ (Louisville)',
        'America/Lower_Princes' => 'Atlantik Berɛ (Lowa Prinse Kɔta)',
        'America/Maceio' => 'Brasilia Berɛ (Makeio)',
        'America/Managua' => 'Mfinimfini Berɛ (Managua)',
        'America/Manaus' => 'Amazon Berɛ (Manaus)',
        'America/Marigot' => 'Atlantik Berɛ (Marigɔt)',
        'America/Martinique' => 'Atlantik Berɛ (Martinike)',
        'America/Matamoros' => 'Mfinimfini Berɛ (Matamɔrɔso)',
        'America/Mazatlan' => 'Mɛksiko Pasifik Berɛ (Masatlan)',
        'America/Mendoza' => 'Agyɛntina Berɛ (Mɛndɔsa)',
        'America/Argentina/Mendoza' => 'Agyɛntina Berɛ (Mɛndɔsa)',
        'America/Menominee' => 'Mfinimfini Berɛ (Mɛnɔminee)',
        'America/Merida' => 'Mfinimfini Berɛ (Mérida)',
        'America/Metlakatla' => 'Alaska Berɛ (Mɛtlakatla)',
        'America/Mexico_City' => 'Mfinimfini Berɛ (Mɛksiko Siti)',
        'America/Miquelon' => 'St. Pierre & Miquelon Berɛ (Saint-Pierre)',
        'America/Moncton' => 'Atlantik Berɛ (Mɔnktin)',
        'America/Monterrey' => 'Mfinimfini Berɛ (Mɔntirii)',
        'America/Montevideo' => 'Yurugwae Berɛ (Montevideo)',
        'America/Montserrat' => 'Atlantik Berɛ (Mantserat)',
        'America/Nassau' => 'Apueeɛ Berɛ (Nassau)',
        'America/New_York' => 'Apueeɛ Berɛ (New Yɔk)',
        'America/Nome' => 'Alaska Berɛ (Nome)',
        'America/Noronha' => 'Fernando de Noronha Berɛ',
        'America/North_Dakota/Beulah' => 'Mfinimfini Berɛ (Beula, Nɔf Dakota)',
        'America/North_Dakota/Center' => 'Mfinimfini Berɛ (Sɛnta, Nɔf Dakota)',
        'America/North_Dakota/New_Salem' => 'Mfinimfini Berɛ (New Salɛm, Nɔf Dakota)',
        'America/Ojinaga' => 'Mfinimfini Berɛ (Ogyinaga)',
        'America/Panama' => 'Apueeɛ Berɛ (Panama)',
        'America/Paramaribo' => 'Suriname Berɛ (Paramaribɔ)',
        'America/Phoenix' => 'Bepɔ Berɛ (Finisk)',
        'America/Port-au-Prince' => 'Apueeɛ Berɛ (Port-au-Prince)',
        'America/Port_of_Spain' => 'Atlantik Berɛ (Spain Pɔɔto)',
        'America/Porto_Velho' => 'Amazon Berɛ (Pɔɔto Velho)',
        'America/Puerto_Rico' => 'Atlantik Berɛ (Puɛto Riko)',
        'America/Punta_Arenas' => 'Kyili Berɛ (Punta Arenas)',
        'America/Rankin_Inlet' => 'Mfinimfini Berɛ (Rankin Inlet)',
        'America/Recife' => 'Brasilia Berɛ (Rɛsifɛ)',
        'America/Regina' => 'Mfinimfini Berɛ (Rɛgyina)',
        'America/Resolute' => 'Mfinimfini Berɛ (Rɛsɔlut)',
        'America/Rio_Branco' => 'Berɛ Brazil (Rio Branko)',
        'America/Santarem' => 'Brasilia Berɛ (Santarém)',
        'America/Santiago' => 'Kyili Berɛ (Santiago)',
        'America/Santo_Domingo' => 'Atlantik Berɛ (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasilia Berɛ (São Paulo)',
        'America/Scoresbysund' => 'Berɛ Greenman (Yitokɔtuɔmete)',
        'America/Sitka' => 'Alaska Berɛ (Sitka)',
        'America/St_Barthelemy' => 'Atlantik Berɛ (St. Baatilemi)',
        'America/St_Johns' => 'Newfoundland Berɛ (St. John’s)',
        'America/St_Kitts' => 'Atlantik Berɛ (St. Kitts)',
        'America/St_Lucia' => 'Atlantik Berɛ (St. Lucia)',
        'America/St_Thomas' => 'Atlantik Berɛ (St. Thomas)',
        'America/St_Vincent' => 'Atlantik Berɛ (St. Vincent)',
        'America/Swift_Current' => 'Mfinimfini Berɛ (Swift Kɛrɛnt)',
        'America/Tegucigalpa' => 'Mfinimfini Berɛ (Tegusigalpa)',
        'America/Thule' => 'Atlantik Berɛ (Thule)',
        'America/Tijuana' => 'Pasifik Berɛ (Tidwuana)',
        'America/Toronto' => 'Apueeɛ Berɛ (Toronto)',
        'America/Tortola' => 'Atlantik Berɛ (Tɔɔtola)',
        'America/Vancouver' => 'Pasifik Berɛ (Vancouver)',
        'America/Whitehorse' => 'Yukɔn Berɛ (Whitehorse)',
        'America/Winnipeg' => 'Mfinimfini Berɛ (Winipɛg)',
        'America/Yakutat' => 'Alaska Berɛ (Yakutat)',
        'Antarctica/Casey' => 'Ɔstrelia Atɔeeɛ Berɛ (Kasi)',
        'Antarctica/Davis' => 'Davis Berɛ',
        'Antarctica/DumontDUrville' => 'Dumont-d’Urville Berɛ',
        'Antarctica/Macquarie' => 'Ɔstrelia Apueeɛ Berɛ (Makaari)',
        'Antarctica/Mawson' => 'Mɔɔson Berɛ',
        'Antarctica/McMurdo' => 'Ziland Foforɔ Berɛ (McMurdo)',
        'Antarctica/Palmer' => 'Kyili Berɛ (Paama)',
        'Antarctica/Rothera' => 'Rotera Berɛ',
        'Antarctica/Syowa' => 'Syowa Berɛ (Showa)',
        'Antarctica/Troll' => 'Greenwich Mean Berɛ (Trɔɔ)',
        'Antarctica/Vostok' => 'Vostok Berɛ (Vɔstɔk)',
        'Arctic/Longyearbyen' => 'Yuropu Mfinimfini Berɛ (Longyearbyen)',
        'Asia/Aden' => 'Arabia Berɛ (Aden)',
        'Asia/Almaty' => 'Kazakstan Berɛ (Aamati)',
        'Asia/Amman' => 'Yuropu Apueeɛ Berɛ (Aman)',
        'Asia/Anadyr' => 'Berɛ Rɔhyea (Anadyr)',
        'Asia/Aqtau' => 'Kazakstan Berɛ (Aktau)',
        'Asia/Aqtobe' => 'Kazakstan Berɛ (Aatobe)',
        'Asia/Ashgabat' => 'Tɛkmɛnistan Berɛ (Ashgabat)',
        'Asia/Atyrau' => 'Kazakstan Berɛ (Atyrau)',
        'Asia/Baghdad' => 'Arabia Berɛ (Baghdad)',
        'Asia/Bahrain' => 'Arabia Berɛ (Bahrain)',
        'Asia/Baku' => 'Asabegyan Berɛ (Baku)',
        'Asia/Bangkok' => 'Indɔkyina Berɛ (Bankɔk)',
        'Asia/Barnaul' => 'Krasnoyarsk Berɛ (Barnaul)',
        'Asia/Beirut' => 'Yuropu Apueeɛ Berɛ (Bɛɛrut)',
        'Asia/Bishkek' => 'Kɛɛgestan Berɛ (Bishkek)',
        'Asia/Brunei' => 'Brunei Berɛ',
        'Asia/Calcutta' => 'India Susudua Berɛ (Kolkata)',
        'Asia/Kolkata' => 'India Susudua Berɛ (Kolkata)',
        'Asia/Chita' => 'Yakutsk Berɛ (Kyita)',
        'Asia/Colombo' => 'India Susudua Berɛ (Kolombo)',
        'Asia/Damascus' => 'Yuropu Apueeɛ Berɛ (Damascus)',
        'Asia/Dhaka' => 'Bangladɛhye Berɛ (Daka)',
        'Asia/Dili' => 'Timɔɔ Apueeɛ Berɛ (Dili)',
        'Asia/Dubai' => 'Gɔɔfo Susudua Berɛ (Dubai)',
        'Asia/Dushanbe' => 'Tagyikistan Berɛ (Dushanbe)',
        'Asia/Famagusta' => 'Yuropu Apueeɛ Berɛ (Famagusta)',
        'Asia/Gaza' => 'Yuropu Apueeɛ Berɛ (Gaza)',
        'Asia/Hebron' => 'Yuropu Apueeɛ Berɛ (Hɛbrɔn)',
        'Asia/Hong_Kong' => 'Hɔnkɔn Berɛ (Hong Kong)',
        'Asia/Hovd' => 'Hovd Berɛ (Khovd)',
        'Asia/Irkutsk' => 'Yiikusk Berɛ',
        'Asia/Jakarta' => 'Indɔnehyia Atɔeeɛ Berɛ (Gyakaata)',
        'Asia/Jayapura' => 'Indɔnehyia Apueeɛ Berɛ (Gyayapura)',
        'Asia/Jerusalem' => 'Israel Berɛ (Yerusalem)',
        'Asia/Kabul' => 'Afganistan Berɛ (Kabul)',
        'Asia/Kamchatka' => 'Berɛ Rɔhyea (Kamkyatka)',
        'Asia/Karachi' => 'Pakistan Berɛ (Karakyi)',
        'Asia/Katmandu' => 'Nɛpal Berɛ (Katmandu)',
        'Asia/Kathmandu' => 'Nɛpal Berɛ (Katmandu)',
        'Asia/Khandyga' => 'Yakutsk Berɛ (Khandyga)',
        'Asia/Krasnoyarsk' => 'Krasnoyarsk Berɛ',
        'Asia/Kuala_Lumpur' => 'Malehyia Berɛ (Kuala Lumpur)',
        'Asia/Kuching' => 'Malehyia Berɛ (Kukyin)',
        'Asia/Kuwait' => 'Arabia Berɛ (Kuwait)',
        'Asia/Macau' => 'Kyaena Berɛ (Macao)',
        'Asia/Magadan' => 'Magadan Berɛ',
        'Asia/Makassar' => 'Indɔnehyia Mfinimfini Berɛ (Makasa)',
        'Asia/Manila' => 'Filipin Berɛ (Manila)',
        'Asia/Muscat' => 'Gɔɔfo Susudua Berɛ (Muskat)',
        'Asia/Nicosia' => 'Yuropu Apueeɛ Berɛ (Nikosia)',
        'Asia/Novokuznetsk' => 'Krasnoyarsk Berɛ (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Krasnoyarsk Berɛ (Novosibirsk)',
        'Asia/Omsk' => 'Omsk Berɛ',
        'Asia/Oral' => 'Kazakstan Berɛ (Oral)',
        'Asia/Phnom_Penh' => 'Indɔkyina Berɛ (Phnom Penh)',
        'Asia/Pontianak' => 'Indɔnehyia Atɔeeɛ Berɛ (Pontianak)',
        'Asia/Pyongyang' => 'Korean Berɛ (Pyongyang)',
        'Asia/Qatar' => 'Arabia Berɛ (Kata)',
        'Asia/Qostanay' => 'Kazakstan Berɛ (Kostanay)',
        'Asia/Qyzylorda' => 'Kazakstan Berɛ (Qyzylorda)',
        'Asia/Rangoon' => 'Mayaama Berɛ (Yangon)',
        'Asia/Yangon' => 'Mayaama Berɛ (Yangon)',
        'Asia/Riyadh' => 'Arabia Berɛ (Riyadh)',
        'Asia/Saigon' => 'Indɔkyina Berɛ (Ho Kyi Min)',
        'Asia/Ho_Chi_Minh' => 'Indɔkyina Berɛ (Ho Kyi Min)',
        'Asia/Sakhalin' => 'Magadan Berɛ (Sakhalin)',
        'Asia/Samarkand' => 'Usbɛkistan Berɛ (Samarkand)',
        'Asia/Seoul' => 'Korean Berɛ (Seoul)',
        'Asia/Shanghai' => 'Kyaena Berɛ (Shanghai)',
        'Asia/Singapore' => 'Singapɔ Susudua Berɛ',
        'Asia/Srednekolymsk' => 'Magadan Berɛ (Srednekolymsk)',
        'Asia/Taipei' => 'Taipei Berɛ',
        'Asia/Tashkent' => 'Usbɛkistan Berɛ (Tashkent)',
        'Asia/Tbilisi' => 'Gyɔgyea Berɛ (Tbilisi)',
        'Asia/Tehran' => 'Iran Berɛ (Tɛɛran)',
        'Asia/Thimphu' => 'Butan Berɛ (Timphu)',
        'Asia/Tokyo' => 'Gyapan Berɛ (Tokyo)',
        'Asia/Tomsk' => 'Krasnoyarsk Berɛ (Tomsk)',
        'Asia/Ulaanbaatar' => 'Yulanbata Berɛ',
        'Asia/Urumqi' => 'Berɛ Kyaena (Yurymki)',
        'Asia/Ust-Nera' => 'Vladivostok Berɛ (Ust-Nera)',
        'Asia/Vientiane' => 'Indɔkyina Berɛ (Vienhyiane)',
        'Asia/Vladivostok' => 'Vladivostok Berɛ',
        'Asia/Yakutsk' => 'Yakutsk Berɛ',
        'Asia/Yekaterinburg' => 'Yɛkatɛrinbɛg Berɛ',
        'Asia/Yerevan' => 'Aamenia Berɛ (Yerevan)',
        'Atlantic/Azores' => 'Azores Berɛ',
        'Atlantic/Bermuda' => 'Atlantik Berɛ (Bɛmuda)',
        'Atlantic/Canary' => 'Yuropu Atɔeeɛ Berɛ (Kanari)',
        'Atlantic/Cape_Verde' => 'Kepvɛde Berɛ',
        'Atlantic/Faeroe' => 'Yuropu Atɔeeɛ Berɛ (Farosu)',
        'Atlantic/Faroe' => 'Yuropu Atɔeeɛ Berɛ (Farosu)',
        'Atlantic/Madeira' => 'Yuropu Atɔeeɛ Berɛ (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwich Mean Berɛ (Rɛɛkgyavik)',
        'Atlantic/South_Georgia' => 'Gyɔɔgyia Anaafoɔ Berɛ',
        'Atlantic/St_Helena' => 'Greenwich Mean Berɛ (St. Helena)',
        'Atlantic/Stanley' => 'Fɔkman Aeland Berɛ (Stanli)',
        'Australia/Adelaide' => 'Ɔstrelia Mfinimfini Berɛ (Adelaide)',
        'Australia/Brisbane' => 'Ɔstrelia Apueeɛ Berɛ (Brisbane)',
        'Australia/Broken_Hill' => 'Ɔstrelia Mfinimfini Berɛ (Brɔken Hill)',
        'Australia/Darwin' => 'Ɔstrelia Mfinimfini Berɛ (Daawin)',
        'Australia/Eucla' => 'Ɔstrelia Mfinimfini Atɔeeɛ Berɛ (Eukla)',
        'Australia/Hobart' => 'Ɔstrelia Apueeɛ Berɛ (Hɔbat)',
        'Australia/Lindeman' => 'Ɔstrelia Apueeɛ Berɛ (Lindeman)',
        'Australia/Lord_Howe' => 'Lɔd Howe Berɛ',
        'Australia/Melbourne' => 'Ɔstrelia Apueeɛ Berɛ (Mɛɛbɔn)',
        'Australia/Perth' => 'Ɔstrelia Atɔeeɛ Berɛ (Pɛɛt)',
        'Australia/Sydney' => 'Ɔstrelia Apueeɛ Berɛ (Sidni)',
        'Etc/GMT' => 'Greenwich Mean Berɛ',
        'Etc/UTC' => 'Amansan Kɔdinatɛde Berɛ',
        'Europe/Amsterdam' => 'Yuropu Mfinimfini Berɛ (Amstadam)',
        'Europe/Andorra' => 'Yuropu Mfinimfini Berɛ (Andɔra)',
        'Europe/Astrakhan' => 'Berɛ Rɔhyea (Astrakhan)',
        'Europe/Athens' => 'Yuropu Apueeɛ Berɛ (Atene)',
        'Europe/Belgrade' => 'Yuropu Mfinimfini Berɛ (Bɛlgrade)',
        'Europe/Berlin' => 'Yuropu Mfinimfini Berɛ (Bɛɛlin)',
        'Europe/Bratislava' => 'Yuropu Mfinimfini Berɛ (Bratislava)',
        'Europe/Brussels' => 'Yuropu Mfinimfini Berɛ (Brɛsɛlse)',
        'Europe/Bucharest' => 'Yuropu Apueeɛ Berɛ (Bukyarɛst)',
        'Europe/Budapest' => 'Yuropu Mfinimfini Berɛ (Budapɛsh)',
        'Europe/Busingen' => 'Yuropu Mfinimfini Berɛ (Busingye)',
        'Europe/Chisinau' => 'Yuropu Apueeɛ Berɛ (Kyisinau)',
        'Europe/Copenhagen' => 'Yuropu Mfinimfini Berɛ (Kopehegan)',
        'Europe/Dublin' => 'Greenwich Mean Berɛ (Dɔblin)',
        'Europe/Gibraltar' => 'Yuropu Mfinimfini Berɛ (Gyebrota)',
        'Europe/Guernsey' => 'Greenwich Mean Berɛ (Guernsey)',
        'Europe/Helsinki' => 'Yuropu Apueeɛ Berɛ (Hɛlsinki)',
        'Europe/Isle_of_Man' => 'Greenwich Mean Berɛ (Isle of Man)',
        'Europe/Istanbul' => 'Berɛ Tɛɛki (Istanbul)',
        'Europe/Jersey' => 'Greenwich Mean Berɛ (Jɛɛsi)',
        'Europe/Kaliningrad' => 'Yuropu Apueeɛ Berɛ (Kaliningrad)',
        'Europe/Kiev' => 'Yuropu Apueeɛ Berɛ (Kiivu)',
        'Europe/Kyiv' => 'Yuropu Apueeɛ Berɛ (Kiivu)',
        'Europe/Kirov' => 'Mɔsko Berɛ (Kirov)',
        'Europe/Lisbon' => 'Yuropu Atɔeeɛ Berɛ (Lisbɔn)',
        'Europe/Ljubljana' => 'Yuropu Mfinimfini Berɛ (Ldwubdwana)',
        'Europe/London' => 'Greenwich Mean Berɛ (Lɔndɔn)',
        'Europe/Luxembourg' => 'Yuropu Mfinimfini Berɛ (Lɛsembɛg)',
        'Europe/Madrid' => 'Yuropu Mfinimfini Berɛ (Madrid)',
        'Europe/Malta' => 'Yuropu Mfinimfini Berɛ (Mɔɔta)',
        'Europe/Mariehamn' => 'Yuropu Apueeɛ Berɛ (Mariehamn)',
        'Europe/Minsk' => 'Mɔsko Berɛ (Minsk)',
        'Europe/Monaco' => 'Yuropu Mfinimfini Berɛ (Monaco)',
        'Europe/Moscow' => 'Mɔsko Berɛ',
        'Europe/Oslo' => 'Yuropu Mfinimfini Berɛ (Oslo)',
        'Europe/Paris' => 'Yuropu Mfinimfini Berɛ (Paris)',
        'Europe/Podgorica' => 'Yuropu Mfinimfini Berɛ (Podgorika)',
        'Europe/Prague' => 'Yuropu Mfinimfini Berɛ (Prage)',
        'Europe/Riga' => 'Yuropu Apueeɛ Berɛ (Riga)',
        'Europe/Rome' => 'Yuropu Mfinimfini Berɛ (Rome)',
        'Europe/Samara' => 'Berɛ Rɔhyea (Samara)',
        'Europe/San_Marino' => 'Yuropu Mfinimfini Berɛ (San Marino)',
        'Europe/Sarajevo' => 'Yuropu Mfinimfini Berɛ (Saragyevo)',
        'Europe/Saratov' => 'Berɛ Rɔhyea (Saratov)',
        'Europe/Simferopol' => 'Mɔsko Berɛ (Simferopol)',
        'Europe/Skopje' => 'Yuropu Mfinimfini Berɛ (Skɔpgye)',
        'Europe/Sofia' => 'Yuropu Apueeɛ Berɛ (Sofia)',
        'Europe/Stockholm' => 'Yuropu Mfinimfini Berɛ (Stɔkhɔm)',
        'Europe/Tallinn' => 'Yuropu Apueeɛ Berɛ (Tallinn)',
        'Europe/Tirane' => 'Yuropu Mfinimfini Berɛ (Tirana)',
        'Europe/Ulyanovsk' => 'Berɛ Rɔhyea (Ulyanovsk)',
        'Europe/Vaduz' => 'Yuropu Mfinimfini Berɛ (Vaduz)',
        'Europe/Vatican' => 'Yuropu Mfinimfini Berɛ (Vatikan)',
        'Europe/Vienna' => 'Yuropu Mfinimfini Berɛ (Veɛna)',
        'Europe/Vilnius' => 'Yuropu Apueeɛ Berɛ (Vilnius)',
        'Europe/Volgograd' => 'Mɔsko Berɛ (Volgograd)',
        'Europe/Warsaw' => 'Yuropu Mfinimfini Berɛ (Wɔɔsɔɔ)',
        'Europe/Zagreb' => 'Yuropu Mfinimfini Berɛ (Zagreb)',
        'Europe/Zurich' => 'Yuropu Mfinimfini Berɛ (Zurekye)',
        'Indian/Antananarivo' => 'Afrika Apueeɛ Berɛ (Antananarivo)',
        'Indian/Chagos' => 'India Po Berɛ (Kyagɔs)',
        'Indian/Christmas' => 'Buronya Aeland Berɛ',
        'Indian/Cocos' => 'Kokoso Aeland Berɛ',
        'Indian/Comoro' => 'Afrika Apueeɛ Berɛ (Kɔmɔrɔ)',
        'Indian/Kerguelen' => 'Frɛnkye Anaafoɔ ne Antaatik Berɛ (Kɛguelɛn)',
        'Indian/Mahe' => 'Seyhyɛl Berɛ (Mahé)',
        'Indian/Maldives' => 'Maldives Berɛ',
        'Indian/Mauritius' => 'Mɔrihyiɔso Berɛ',
        'Indian/Mayotte' => 'Afrika Apueeɛ Berɛ (Mayote)',
        'Indian/Reunion' => 'Réunion Berɛ',
        'Pacific/Apia' => 'Apia Berɛ',
        'Pacific/Auckland' => 'Ziland Foforɔ Berɛ (Aukland)',
        'Pacific/Bougainville' => 'Papua Gini Foforɔ Berɛ (Bougainville)',
        'Pacific/Chatham' => 'Kyatam Berɛ',
        'Pacific/Easter' => 'Easta Aeland Berɛ',
        'Pacific/Efate' => 'Vanuatu Berɛ (Efate)',
        'Pacific/Enderbury' => 'Finise Aeland Berɛ (Canton)',
        'Pacific/Kanton' => 'Finise Aeland Berɛ (Canton)',
        'Pacific/Fakaofo' => 'Tokelau Berɛ (Fakaofo)',
        'Pacific/Fiji' => 'Figyi Berɛ',
        'Pacific/Funafuti' => 'Tuvalu Berɛ (Funafuti)',
        'Pacific/Galapagos' => 'Galapagɔs Berɛ',
        'Pacific/Gambier' => 'Gambier Berɛ',
        'Pacific/Guadalcanal' => 'Solomon Aeland Berɛ (Guadalcanal)',
        'Pacific/Guam' => 'Kyamoro Susudua Berɛ (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleutian Susudua Berɛ (Honolulu)',
        'Pacific/Kiritimati' => 'Lai Aeland Berɛ (Kiritimati)',
        'Pacific/Kosrae' => 'Kosrae Berɛ',
        'Pacific/Kwajalein' => 'Mahyaa Aeland Berɛ (Kwagyaleene)',
        'Pacific/Majuro' => 'Mahyaa Aeland Berɛ (Madwuro)',
        'Pacific/Marquesas' => 'Makesase Berɛ (Maakesase Supᴐ)',
        'Pacific/Midway' => 'Samoa Berɛ (Midway)',
        'Pacific/Nauru' => 'Nauru Berɛ',
        'Pacific/Niue' => 'Niue Berɛ',
        'Pacific/Norfolk' => 'Nɔɔfɔk Aeland Berɛ',
        'Pacific/Noumea' => 'Kaledonia Foforɔ Berɛ (Nouméa)',
        'Pacific/Pago_Pago' => 'Samoa Berɛ (Pago Pago)',
        'Pacific/Palau' => 'Palau Berɛ',
        'Pacific/Pitcairn' => 'Pitkairn Berɛ (Pitkairne)',
        'Pacific/Ponape' => 'Ponape Berɛ (Pɔnpei)',
        'Pacific/Pohnpei' => 'Ponape Berɛ (Pɔnpei)',
        'Pacific/Port_Moresby' => 'Papua Gini Foforɔ Berɛ (Pɔt Morɛsbi)',
        'Pacific/Rarotonga' => 'Kuk Aeland Berɛ (Rarotonga)',
        'Pacific/Saipan' => 'Kyamoro Susudua Berɛ (Saipan)',
        'Pacific/Tahiti' => 'Tahiti Berɛ',
        'Pacific/Tarawa' => 'Geebɛt Aeland Berɛ (Tarawa)',
        'Pacific/Tongatapu' => 'Tonga Berɛ (Tongatapu)',
        'Pacific/Truk' => 'Kyuuk Berɛ',
        'Pacific/Chuuk' => 'Kyuuk Berɛ',
        'Pacific/Wake' => 'Wake Aeland Berɛ (Wake Supᴐ)',
        'Pacific/Wallis' => 'Wallis ne Futuna Berɛ (Wallis & Futuna)',
    ],
    'Meta' => [],
];
