<?php

return [
    'Names' => [
        'Adlm' => 'Адламӣ',
        'Aghb' => 'Албани Қафқозӣ',
        'Ahom' => 'Ахомӣ',
        'Arab' => 'Арабӣ',
        'Aran' => 'Насталиқӣ',
        'Armi' => 'Арамейкии Империалӣ',
        'Armn' => 'Арманӣ',
        'Avst' => 'Авестоӣ',
        'Bali' => 'Балинесӣ',
        'Bamu' => 'Бамумӣ',
        'Bass' => 'Басса Вахӣ',
        'Batk' => 'Батакӣ',
        'Beng' => 'Бангладешӣ',
        'Bhks' => 'Бхайксукӣ',
        'Bopo' => 'Бопомофоӣ',
        'Brah' => 'Брахмӣ',
        'Brai' => 'Брайл',
        'Bugi' => 'Бугинӣ',
        'Buhd' => 'Бухидӣ',
        'Cakm' => 'Чакама',
        'Cans' => 'Низоми ягонаи ҳиҷои аборигении каннадӣ',
        'Cari' => 'Карианӣ',
        'Cham' => 'Чамӣ',
        'Cher' => 'Черокӣ',
        'Chrs' => 'Хоразмиёнӣ',
        'Copt' => 'Коптӣ',
        'Cpmn' => 'Кипро-Миноанӣ',
        'Cprt' => 'Кипрӣ',
        'Cyrl' => 'Кириллӣ',
        'Deva' => 'Деванагарӣ',
        'Diak' => 'Дивс Акуру',
        'Dogr' => 'Догра',
        'Dsrt' => 'Дезерет',
        'Dupl' => 'Стенографияи Дуплоянӣ',
        'Egyp' => 'Иероглифҳои Мисрӣ',
        'Elba' => 'Элбасан',
        'Elym' => 'Элимайӣ',
        'Ethi' => 'Эфиопӣ',
        'Geor' => 'Гурҷӣ',
        'Glag' => 'Глаголитикӣ',
        'Gong' => 'Гунҷала Гондӣ',
        'Gonm' => 'Масарам Гондӣ',
        'Goth' => 'Готика',
        'Gran' => 'Гранта',
        'Grek' => 'Юнонӣ',
        'Gujr' => 'Гуҷаротӣ',
        'Guru' => 'Гумрухӣ',
        'Hanb' => 'Хан бо Бопомофо',
        'Hang' => 'Ҳангул',
        'Hani' => 'Хан',
        'Hano' => 'Хануну',
        'Hans' => 'Осонфаҳм',
        'Hant' => 'Анъанавӣ',
        'Hatr' => 'Хатран',
        'Hebr' => 'Яҳудӣ',
        'Hira' => 'Хирагана',
        'Hluw' => 'Иероглифҳои Анатолӣ',
        'Hmng' => 'Пахах Хмонг',
        'Hmnp' => 'Някенг Пуачэ Хмонг',
        'Hrkt' => 'Ҳиҷоҳои ҷопонӣ',
        'Hung' => 'Венгерии Куҳна',
        'Ital' => 'Курсиви Куҳна',
        'Jamo' => 'Ҷамо',
        'Java' => 'Ҷаванесӣ',
        'Jpan' => 'Ҷопонӣ',
        'Kali' => 'Кайя Ли',
        'Kana' => 'Катакана',
        'Kawi' => 'Кавӣ',
        'Khar' => 'Хароштӣ',
        'Khmr' => 'Хмерӣ',
        'Khoj' => 'Хочки',
        'Kits' => 'Хатти хурди Китонӣ',
        'Knda' => 'Каннада',
        'Kore' => 'Кореягӣ',
        'Kthi' => 'Кайтӣ',
        'Lana' => 'Ланна',
        'Laoo' => 'Лао',
        'Latn' => 'Лотинӣ',
        'Lepc' => 'Лепча',
        'Limb' => 'Лимбу',
        'Lina' => 'Хати А',
        'Linb' => 'Хати Б',
        'Lisu' => 'Фрейзер',
        'Lyci' => 'Ликия',
        'Lydi' => 'Лидия',
        'Mahj' => 'Махаҷанӣ',
        'Maka' => 'Макасарӣ',
        'Mand' => 'Мандаеан',
        'Mani' => 'Манихейӣ',
        'Marc' => 'Маршенӣ',
        'Medf' => 'Медефаидринӣ',
        'Mend' => 'Менде',
        'Merc' => 'Курсиви Мероитӣ',
        'Mero' => 'Мероитӣ',
        'Mlym' => 'Малаяламӣ',
        'Modi' => 'Модӣ',
        'Mong' => 'Муғулӣ',
        'Mroo' => 'Мро',
        'Mtei' => 'Мейтеи Майек',
        'Mult' => 'Мултанӣ',
        'Mymr' => 'Мянмар',
        'Nagm' => 'Наг Мундарӣ',
        'Nand' => 'Нандинагарӣ',
        'Narb' => 'Арабии Шимолии Куҳна',
        'Nbat' => 'Набатаинӣ',
        'Newa' => 'Нева',
        'Nkoo' => 'Н’Ко',
        'Nshu' => 'Нушу',
        'Ogam' => 'Огам',
        'Olck' => 'Ол Чикӣ',
        'Orkh' => 'Оркон',
        'Orya' => 'Одия',
        'Osge' => 'Осейҷӣ',
        'Osma' => 'Османияӣ',
        'Ougr' => 'Уйғури Куҳна',
        'Palm' => 'Палмирена',
        'Pauc' => 'Пау Син Хау',
        'Perm' => 'Пермикии Куҳна',
        'Phag' => 'Фагс-па',
        'Phli' => 'Паҳлавии Хаттӣ',
        'Phlp' => 'Паҳлавии Псалтирӣ',
        'Phnx' => 'Финикӣ',
        'Plrd' => 'Овоии поллардӣ',
        'Prti' => 'Парфияи Хаттӣ',
        'Qaag' => 'Завгӯйӣ',
        'Rjng' => 'Реҷанг',
        'Rohg' => 'Ханифӣ',
        'Runr' => 'Руникӣ',
        'Samr' => 'Самаританӣ',
        'Sarb' => 'Арабии Ҷанубии Куҳна',
        'Saur' => 'Саураштра',
        'Sgnw' => 'Аломатнависӣ',
        'Shaw' => 'Шавианӣ',
        'Shrd' => 'Шарада',
        'Sidd' => 'Сиддам',
        'Sind' => 'Худовадӣ',
        'Sinh' => 'Синхала',
        'Sogd' => 'Суғдӣ',
        'Sogo' => 'Суғдии Куҳна',
        'Sora' => 'Сора Сомпенг',
        'Soyo' => 'Соёмбо',
        'Sund' => 'Сунданезӣ',
        'Sylo' => 'Силоти Нагрӣ',
        'Syrc' => 'Сурёнӣ',
        'Tagb' => 'Тагбанва',
        'Takr' => 'Такрӣ',
        'Tale' => 'Тай Ле',
        'Talu' => 'Тай Леи Нав',
        'Taml' => 'Тамилӣ',
        'Tang' => 'Тангут',
        'Tavt' => 'Ветнамии Тайӣ',
        'Telu' => 'Телугу',
        'Tfng' => 'Тифинаг',
        'Tglg' => 'Тагалогӣ',
        'Thaa' => 'Таана',
        'Thai' => 'Тайӣ',
        'Tibt' => 'Тибетӣ',
        'Tirh' => 'Тирхута',
        'Tnsa' => 'Тангса',
        'Toto' => 'Тото',
        'Ugar' => 'Угаритӣ',
        'Vaii' => 'Вайӣ',
        'Vith' => 'Виткукӣ',
        'Wara' => 'Варанг Кшитӣ',
        'Wcho' => 'Ванчо',
        'Xpeo' => 'Форсии Куҳна',
        'Xsux' => 'Хати Сумеро-Аккадӣ',
        'Yezi' => 'Язидӣ',
        'Yiii' => 'Юйӣ',
        'Zanb' => 'Майдони Занабазорӣ',
        'Zinh' => 'Мерос',
        'Zmth' => 'Аломати риёзӣ',
        'Zsye' => 'Эмоҷи',
        'Zsym' => 'Аломатҳо',
        'Zxxx' => 'Нонавишта',
        'Zyyy' => 'Умумӣ',
    ],
];
