<?php

return [
    'Names' => [
        'aa' => 'афарийн',
        'ab' => 'абхазхойн',
        'ace' => 'ачехийн',
        'ada' => 'адангме',
        'ady' => 'адигейн',
        'af' => 'африкаанс',
        'agq' => 'агхӀем',
        'ain' => 'айнийн',
        'ak' => 'акан',
        'ale' => 'алеутийн',
        'alt' => 'къилба алтайн',
        'am' => 'амхаройн',
        'an' => 'арагонойн',
        'anp' => 'ангика',
        'ar' => 'Ӏаьрбийн',
        'arn' => 'арауканхойн',
        'arp' => 'арапахо',
        'as' => 'ассамийн',
        'asa' => 'асу',
        'ast' => 'астурийн',
        'av' => 'суьйлийн',
        'awa' => 'авадхи',
        'ay' => 'аймара',
        'az' => 'азербайджанийн',
        'ba' => 'башкирийн',
        'ban' => 'балийн',
        'bas' => 'баса',
        'be' => 'белорусийн',
        'bem' => 'бемба',
        'bez' => 'бена',
        'bg' => 'болгарийн',
        'bgn' => 'малхбузен-белуджийн',
        'bho' => 'бходжпури',
        'bi' => 'бислама',
        'bin' => 'бини',
        'bla' => 'сиксика',
        'bm' => 'бамбара',
        'bn' => 'бенгалийн',
        'bo' => 'тибетхойн',
        'br' => 'бретонийн',
        'brx' => 'бодо',
        'bs' => 'боснийн',
        'bug' => 'бугийн',
        'byn' => 'билийн',
        'ca' => 'каталонийн',
        'ce' => 'нохчийн',
        'ceb' => 'себуано',
        'cgg' => 'чига',
        'ch' => 'чаморро',
        'chk' => 'чукчийн',
        'chm' => 'марийн',
        'cho' => 'чоктавийн',
        'chr' => 'чероки',
        'chy' => 'шайенийн',
        'ckb' => 'юккъерчу курдийн',
        'co' => 'корсиканийн',
        'crs' => 'сейшелийн креолийн',
        'cs' => 'чехийн',
        'cu' => 'килсславянийн',
        'cv' => 'чувашийн',
        'cy' => 'валлийн',
        'da' => 'датхойн',
        'dak' => 'дакота',
        'dar' => 'даьргӀойн',
        'dav' => 'таита',
        'de' => 'немцойн',
        'dgr' => 'догриб',
        'dje' => 'зарма',
        'dsb' => 'сорбийн',
        'dua' => 'дуала',
        'dv' => 'мальдивийн',
        'dyo' => 'дьола-фоньи',
        'dz' => 'дзонг-кэ',
        'dzg' => 'даза',
        'ebu' => 'эмбу',
        'ee' => 'эве',
        'efi' => 'эфик',
        'eka' => 'экаджук',
        'el' => 'грекийн',
        'en' => 'ингалсан',
        'eo' => 'эсперанто',
        'es' => 'испанхойн',
        'et' => 'эстонийн',
        'eu' => 'баскийн',
        'ewo' => 'эвондо',
        'fa' => 'гӀажарийн',
        'ff' => 'фулах',
        'fi' => 'финнийн',
        'fil' => 'филиппинийн',
        'fj' => 'фиджи',
        'fo' => 'фарерийн',
        'fon' => 'фон',
        'fr' => 'французийн',
        'fur' => 'фриулийн',
        'fy' => 'малхбузен-фризийн',
        'ga' => 'ирландхойн',
        'gaa' => 'га',
        'gag' => 'гагаузийн',
        'gd' => 'гэлийн',
        'gez' => 'геэз',
        'gil' => 'гильбертийн',
        'gl' => 'галисийн',
        'gn' => 'гуарани',
        'gor' => 'горонтало',
        'gsw' => 'швейцарин немцойн',
        'gu' => 'гуджарати',
        'guz' => 'гусии',
        'gv' => 'мэнийн',
        'gwi' => 'гвичин',
        'ha' => 'хауса',
        'haw' => 'гавайн',
        'he' => 'жугтийн',
        'hi' => 'хӀинди',
        'hil' => 'хилигайнон',
        'hmn' => 'хмонг',
        'hr' => 'хорватийн',
        'hsb' => 'лакхара сербийн',
        'ht' => 'гаитийн',
        'hu' => 'венгрийн',
        'hup' => 'хупа',
        'hy' => 'эрмалойн',
        'hz' => 'гереро',
        'ia' => 'интерлингва',
        'iba' => 'ибанийн',
        'ibb' => 'ибибио',
        'id' => 'индонезихойн',
        'ig' => 'игбо',
        'ii' => 'сычуань',
        'ilo' => 'илоко',
        'inh' => 'гӀалгӀайн',
        'io' => 'идо',
        'is' => 'исландхойн',
        'it' => 'итальянийн',
        'iu' => 'инуктитут',
        'ja' => 'японийн',
        'jbo' => 'ложбан',
        'jgo' => 'нгомба',
        'jmc' => 'мачаме',
        'jv' => 'яванийн',
        'ka' => 'гуьржийн',
        'kab' => 'кабилийн',
        'kac' => 'качинийн',
        'kaj' => 'каджи',
        'kam' => 'камба',
        'kbd' => 'гӀебартойн',
        'kcg' => 'тьяп',
        'kde' => 'маконде',
        'kea' => 'кабувердьяну',
        'kfo' => 'коро',
        'kha' => 'кхаси',
        'khq' => 'койра чиини',
        'ki' => 'кикуйю',
        'kj' => 'кунама',
        'kk' => 'кхазакхийн',
        'kkj' => 'како',
        'kl' => 'гренландхойн',
        'kln' => 'календжин',
        'km' => 'кхмерийн',
        'kmb' => 'кимбунду',
        'kn' => 'каннада',
        'ko' => 'корейн',
        'koi' => 'коми-пермякийн',
        'kok' => 'конкани',
        'kpe' => 'кпелле',
        'kr' => 'канури',
        'krc' => 'кхарачойн-балкхаройн',
        'krl' => 'карелийн',
        'kru' => 'курух',
        'ks' => 'кашмири',
        'ksb' => 'шамбала',
        'ksf' => 'бафиа',
        'ksh' => 'коьлнийн',
        'ku' => 'курдийн',
        'kum' => 'гӀумкийн',
        'kv' => 'комийн',
        'kw' => 'корнуоллийн',
        'ky' => 'гӀиргӀизойн',
        'la' => 'латинан',
        'lad' => 'ладино',
        'lag' => 'ланги',
        'lb' => 'люксембургхойн',
        'lez' => 'лаьзгийн',
        'lg' => 'ганда',
        'li' => 'лимбургийн',
        'lkt' => 'лакота',
        'ln' => 'лингала',
        'lo' => 'лаоссийн',
        'loz' => 'лози',
        'lrc' => 'къилбаседа лури',
        'lt' => 'литвахойн',
        'lu' => 'луба-катанга',
        'lua' => 'луба-лулуа',
        'lun' => 'лунда',
        'luo' => 'луо (Кени а, Танзани а)',
        'lus' => 'лушей',
        'luy' => 'лухья',
        'lv' => 'латышийн',
        'mad' => 'мадурийн',
        'mag' => 'магахи',
        'mai' => 'майтхили',
        'mak' => 'макасарийн',
        'mas' => 'масаи',
        'mdf' => 'мокшанойн',
        'men' => 'менде',
        'mer' => 'меру',
        'mfe' => 'маврикин креолийн',
        'mg' => 'малагасийн',
        'mgh' => 'макуа-меетто',
        'mgo' => 'мета',
        'mh' => 'маршаллийн',
        'mi' => 'маори',
        'mic' => 'микмак',
        'min' => 'минангкабау',
        'mk' => 'македонхойн',
        'ml' => 'малаялам',
        'mn' => 'монголийн',
        'mni' => 'манипурийн',
        'moh' => 'мохаук',
        'mos' => 'моси',
        'mr' => 'маратхи',
        'ms' => 'малайн',
        'mt' => 'мальтойн',
        'mua' => 'мунданг',
        'mus' => 'крик',
        'mwl' => 'мирандойн',
        'my' => 'бирманийн',
        'myv' => 'эрзянийн',
        'mzn' => 'мазандеранхойн',
        'na' => 'науру',
        'nap' => 'неаполитанойн',
        'naq' => 'нама',
        'nb' => 'норвегийн букмол',
        'nd' => 'къилбаседа ндебели',
        'nds' => 'лахара германхойн',
        'ne' => 'непалхойн',
        'new' => 'неваройн',
        'ng' => 'ндонга',
        'nia' => 'ниас',
        'niu' => 'ниуэ',
        'nl' => 'голландхойн',
        'nmg' => 'квасио',
        'nn' => 'норвегийн нюнорск',
        'nnh' => 'нгиембунд',
        'nog' => 'ногӀийн',
        'nqo' => 'нко',
        'nr' => 'къилба ндебеле',
        'nso' => 'къилбаседа сото',
        'nus' => 'нуэр',
        'nv' => 'навахо',
        'ny' => 'ньянджа',
        'nyn' => 'ньянколе',
        'oc' => 'окситанойн',
        'om' => 'оромо',
        'or' => 'ори',
        'os' => 'хӀирийн',
        'pa' => 'панджаби',
        'pag' => 'пангасинан',
        'pam' => 'пампанга',
        'pap' => 'папьяменто',
        'pau' => 'палау',
        'pcm' => 'нигерийн-креолийн',
        'pl' => 'полякийн',
        'prg' => 'пруссийн',
        'ps' => 'пушту',
        'pt' => 'португалихойн',
        'qu' => 'кечуа',
        'quc' => 'киче',
        'rap' => 'рапануйн',
        'rar' => 'раротонга',
        'rm' => 'романшийн',
        'rn' => 'рунди',
        'ro' => 'румынийн',
        'rof' => 'ромбо',
        'ru' => 'оьрсийн',
        'rup' => 'аруминийн',
        'rw' => 'киньяруанда',
        'rwk' => 'руанда',
        'sa' => 'санскрит',
        'sad' => 'сандаве',
        'sah' => 'якутийн',
        'saq' => 'самбуру',
        'sat' => 'сантали',
        'sba' => 'нгамбайн',
        'sbp' => 'сангу',
        'sc' => 'сардинийн',
        'scn' => 'сицилийн',
        'sco' => 'шотландхойн',
        'sd' => 'синдхи',
        'se' => 'къилбаседа саамийн',
        'seh' => 'сена',
        'ses' => 'койраборо сенни',
        'sg' => 'санго',
        'shi' => 'тахелхит',
        'shn' => 'шанойн',
        'si' => 'сингалхойн',
        'sk' => 'словакийн',
        'sl' => 'словенийн',
        'sm' => 'самоанойн',
        'sma' => 'саамийн (къилба)',
        'smj' => 'луле-саамийн',
        'smn' => 'инари-саамийн',
        'sms' => 'скольт-саамийн',
        'sn' => 'шона',
        'snk' => 'сонинке',
        'so' => 'сомали',
        'sq' => 'албанойн',
        'sr' => 'сербийн',
        'srn' => 'сранан-тонго',
        'ss' => 'свази',
        'ssy' => 'сахо',
        'st' => 'къилба сото',
        'su' => 'сунданхойн',
        'suk' => 'сукума',
        'sv' => 'шведийн',
        'sw' => 'суахили',
        'swb' => 'коморийн',
        'syr' => 'шемахойн',
        'ta' => 'тамилхойн',
        'te' => 'телугу',
        'tem' => 'темне',
        'teo' => 'тесо',
        'tet' => 'тетум',
        'tg' => 'таджикийн',
        'th' => 'тайн',
        'ti' => 'тигринья',
        'tig' => 'тигре',
        'tk' => 'туркменийн',
        'tlh' => 'клингонин',
        'tn' => 'тсвана',
        'to' => 'тонганийн',
        'tpi' => 'ток-писин',
        'tr' => 'туркойн',
        'trv' => 'седекойн',
        'ts' => 'тсонга',
        'tt' => 'гӀезалойн',
        'tum' => 'тумбука',
        'tvl' => 'тувалу',
        'twq' => 'тасавак',
        'ty' => 'таитянойн',
        'tyv' => 'тувинийн',
        'tzm' => 'тамазигхтийн',
        'udm' => 'удмуртийн',
        'ug' => 'уйгурийн',
        'uk' => 'украинийн',
        'umb' => 'умбунду',
        'ur' => 'урду',
        'uz' => 'узбекийн',
        'vai' => 'ваи',
        've' => 'венда',
        'vi' => 'вьетнамхойн',
        'vo' => 'волапюк',
        'vun' => 'вунджо',
        'wa' => 'валлонойн',
        'wae' => 'валлисийн',
        'wal' => 'воламо',
        'war' => 'варай',
        'wbp' => 'варлпири',
        'wo' => 'волоф',
        'xal' => 'гӀалмакхойн',
        'xh' => 'коса',
        'xog' => 'сога',
        'yav' => 'янгбен',
        'ybb' => 'йемба',
        'yi' => 'идиш',
        'yo' => 'йоруба',
        'yue' => 'кантонийн',
        'zgh' => 'мороккон стандартан тамазигхтийн',
        'zh' => 'цийн',
        'zu' => 'зулу',
        'zun' => 'зуньи',
        'zza' => 'заза',
    ],
    'LocalizedNames' => [
        'ar_001' => 'ХӀинца болу стандартан Ӏаьрбийн',
        'de_AT' => 'австрин немцойн',
        'de_CH' => 'швейцарин литературин немцойн',
        'en_AU' => 'Австралин ингалсан',
        'en_CA' => 'канадан ингалсан',
        'en_GB' => 'британин ингалсан',
        'en_US' => 'американ ингалсан',
        'es_419' => 'латинан американ испанхойн',
        'es_ES' => 'европан испанхойн',
        'es_MX' => 'мексикан испанхойн',
        'fr_CA' => 'канадан французийн',
        'fr_CH' => 'швейцарин французийн',
        'nds_NL' => 'лахара саксонийн',
        'nl_BE' => 'фламандийн',
        'pt_BR' => 'бразилин португалихойн',
        'pt_PT' => 'европан португалихойн',
        'ro_MD' => 'молдавийн',
        'sw_CD' => 'суахили (Конго)',
        'zh_Hans' => 'атта цийн',
        'zh_Hant' => 'ламастан цийн',
    ],
];
