<?php

return [
    'Names' => [
        'ak' => 'Kiakan',
        'arq' => 'Kiarabu cha Aljeria',
        'az' => 'Kiazabajani',
        'gv' => 'Kimanksi',
        'gwi' => 'Kigwichiin',
        'hup' => 'Kihupa',
        'jbo' => 'Kilojban',
        'kac' => 'Kikachin',
        'kkj' => 'Kikako',
        'koi' => 'Kikomipermyak',
        'kru' => 'Kikurukh',
        'kum' => 'Kikumyk',
        'ky' => 'Kikirigizi',
        'lam' => 'Kilamba',
        'li' => 'Kilimburgi',
        'mdf' => 'Kimoksha',
        'mic' => 'Kimikmaki',
        'mk' => 'Kimasedonia',
        'moh' => 'Kimohoki',
        'mos' => 'Kimossi',
        'nnh' => 'Kingiemboon',
        'nqo' => 'Kiinko',
        'pcm' => 'Pijini ya Nijeria',
        'quc' => 'Kikiiche',
        'shu' => 'Kiarabu cha Chadi',
        'srn' => 'Kitongo cha Sranan',
        'swb' => 'Kikomoro',
        'syr' => 'Kisiria',
        'udm' => 'Kiudumurti',
        'yi' => 'Kiyidi',
    ],
    'LocalizedNames' => [
        'ar_001' => 'Kiarabu cha Dunia Kilichosanifishwa',
    ],
];
