<?php

return [
    'Names' => [
        'Arab' => 'arábalaš',
        'Hani' => 'kiinnálaš',
        'Hans' => 'álkes kiinnálaš',
        'Hant' => 'árbevirolaš kiinnálaš',
        'Zxxx' => 'orrut čállojuvvot',
    ],
];
