<?php

return [
    'Names' => [
        'BRL' => [
            'R$',
            'בראזיל רעאל',
        ],
        'BZD' => [
            'BZD',
            'בעליז דאלאַר',
        ],
        'CHF' => [
            'CHF',
            'שווייצער פֿראַנק',
        ],
        'CNY' => [
            'CN¥',
            'כינעזישער יואן',
        ],
        'EUR' => [
            '€',
            'איירא',
        ],
        'GBP' => [
            '£',
            'פֿונט שטערלינג',
        ],
        'INR' => [
            '₹',
            'אינדישער רופי',
        ],
        'JPY' => [
            'JP¥',
            'יאפאנעזישער יען',
        ],
        'RUB' => [
            'RUB',
            'רוסישער רובל',
        ],
        'SEK' => [
            'SEK',
            'שוועדישע קראנע',
        ],
        'USD' => [
            'US$',
            'אמעריקאנער דאלאר',
        ],
    ],
];
