<?php

declare(strict_types=1);

namespace SimpleSAML\SAML2\Assertion\Exception;

use SimpleSAML\SAML2\Exception\RuntimeException;

class InvalidSubjectConfirmationException extends RuntimeException
{
}
