<?php

return [
    '🇦🇫' => 'bandera: Afghanistan',
    '🇦🇬' => 'bandera: Antigua & Barbuda',
    '🇦🇮' => 'bandera: Anguilla',
    '🇦🇱' => 'bandera: Albania',
    '🇦🇴' => 'bandera: Angola',
    '🇦🇷' => 'bandera: Argentina',
    '🇦🇹' => 'bandera: Austria',
    '🇦🇺' => 'bandera: Australia',
    '🇦🇼' => 'bandera: Aruba',
    '🇧🇦' => 'bandera: Bosnia i Herzegowina',
    '🇧🇧' => 'bandera: Barbados',
    '🇧🇪' => 'bandera: Bèlgika',
    '🇧🇬' => 'bandera: Bulgaria',
    '🇧🇱' => 'bandera: Saint Bathélemy',
    '🇧🇲' => 'bandera: Bermuda',
    '🇧🇴' => 'bandera: Bolivia',
    '🇧🇶' => 'bandera: Antia Hulandes',
    '🇧🇷' => 'bandera: Brazil',
    '🇧🇸' => 'bandera: Bahamas',
    '🇧🇻' => 'bandera: Isla Bouvet',
    '🇧🇼' => 'bandera: Botswana',
    '🇧🇾' => 'bandera: Belarus',
    '🇧🇿' => 'bandera: Belize',
    '🇨🇦' => 'bandera: Canada',
    '🇨🇩' => 'bandera: Congo - Kinshasa',
    '🇨🇫' => 'bandera: Repúblika Sentroafrikano',
    '🇨🇬' => 'bandera: Congo - Brazzaville',
    '🇨🇭' => 'bandera: Suisa',
    '🇨🇮' => 'bandera: Côte d’Ivoire',
    '🇨🇱' => 'bandera: Chile',
    '🇨🇲' => 'bandera: Camerun',
    '🇨🇳' => 'bandera: China',
    '🇨🇴' => 'bandera: Colombia',
    '🇨🇷' => 'bandera: Costa Rica',
    '🇨🇺' => 'bandera: Cuba',
    '🇨🇻' => 'bandera: Kabo Verde',
    '🇨🇼' => 'bandera: Kòrsou',
    '🇨🇿' => 'bandera: Cheko',
    '🇩🇪' => 'bandera: Alemania',
    '🇩🇰' => 'bandera: Dinamarka',
    '🇩🇲' => 'bandera: Dominica',
    '🇩🇴' => 'bandera: Repúblika Dominikano',
    '🇩🇿' => 'bandera: Algeria',
    '🇪🇨' => 'bandera: Ecuador',
    '🇪🇪' => 'bandera: Estonia',
    '🇪🇬' => 'bandera: Egipto',
    '🇪🇭' => 'bandera: Western Sahara',
    '🇪🇷' => 'bandera: Eritrea',
    '🇪🇸' => 'bandera: Spaña',
    '🇪🇹' => 'bandera: Etiopia',
    '🇪🇺' => 'bandera: Union Europeo',
    '🇫🇮' => 'bandera: Finlandia',
    '🇫🇯' => 'bandera: Fiji',
    '🇫🇰' => 'bandera: Islanan Falkland',
    '🇫🇲' => 'bandera: Micronesia',
    '🇫🇷' => 'bandera: Fransia',
    '🇬🇧' => 'bandera: Gran Bretaña',
    '🇬🇩' => 'bandera: Grenada',
    '🇬🇫' => 'bandera: Guyana Franses',
    '🇬🇭' => 'bandera: Ghana',
    '🇬🇱' => 'bandera: Grunlandia',
    '🇬🇲' => 'bandera: Gambia',
    '🇬🇳' => 'bandera: Guinea',
    '🇬🇵' => 'bandera: Guadeloupe',
    '🇬🇶' => 'bandera: Guinea Ekuatorial',
    '🇬🇷' => 'bandera: Gresia',
    '🇬🇹' => 'bandera: Guatemala',
    '🇬🇺' => 'bandera: Guam',
    '🇬🇼' => 'bandera: Guinea-Bissau',
    '🇬🇾' => 'bandera: Guyana',
    '🇭🇰' => 'bandera: Hong Kong',
    '🇭🇳' => 'bandera: Honduras',
    '🇭🇷' => 'bandera: Kroasia',
    '🇭🇹' => 'bandera: Haiti',
    '🇭🇺' => 'bandera: Hungria',
    '🇮🇩' => 'bandera: Indonesia',
    '🇮🇪' => 'bandera: Irlanda',
    '🇮🇱' => 'bandera: Israel',
    '🇮🇳' => 'bandera: India',
    '🇮🇶' => 'bandera: Irak',
    '🇮🇷' => 'bandera: Iran',
    '🇮🇸' => 'bandera: Islandia',
    '🇮🇹' => 'bandera: Italia',
    '🇯🇲' => 'bandera: Jamaica',
    '🇯🇵' => 'bandera: Hapon',
    '🇰🇪' => 'bandera: Kenya',
    '🇰🇭' => 'bandera: Cambodia',
    '🇰🇲' => 'bandera: Comóros',
    '🇰🇳' => 'bandera: St. Kitts i Nevis',
    '🇰🇵' => 'bandera: Nort Korea',
    '🇰🇷' => 'bandera: Surkorea',
    '🇰🇾' => 'bandera: Islanan Caiman',
    '🇱🇨' => 'bandera: Sint Lucia',
    '🇱🇮' => 'bandera: Liechtenstein',
    '🇱🇰' => 'bandera: Sri Lanka',
    '🇱🇷' => 'bandera: Liberia',
    '🇱🇺' => 'bandera: Luxemburg',
    '🇲🇦' => 'bandera: Morocco',
    '🇲🇨' => 'bandera: Monaco',
    '🇲🇩' => 'bandera: Moldavia',
    '🇲🇪' => 'bandera: Montenegro',
    '🇲🇫' => 'bandera: Saint Martin',
    '🇲🇬' => 'bandera: Madagascar',
    '🇲🇱' => 'bandera: Mali',
    '🇲🇳' => 'bandera: Mongolia',
    '🇲🇴' => 'bandera: Macao',
    '🇲🇶' => 'bandera: Martinique',
    '🇲🇸' => 'bandera: Montserrat',
    '🇲🇹' => 'bandera: Malta',
    '🇲🇻' => 'bandera: Maldives',
    '🇲🇼' => 'bandera: Malawi',
    '🇲🇽' => 'bandera: México',
    '🇲🇿' => 'bandera: Mozambique',
    '🇳🇪' => 'bandera: Niger',
    '🇳🇬' => 'bandera: Nigeria',
    '🇳🇮' => 'bandera: Nicaragua',
    '🇳🇱' => 'bandera: Hulanda',
    '🇳🇴' => 'bandera: Noruega',
    '🇳🇵' => 'bandera: Nepal',
    '🇵🇦' => 'bandera: Panamá',
    '🇵🇪' => 'bandera: Perú',
    '🇵🇫' => 'bandera: Polinesia Franses',
    '🇵🇭' => 'bandera: Filipinas',
    '🇵🇱' => 'bandera: Polonia',
    '🇵🇲' => 'bandera: St. Pierre & Miquelon',
    '🇵🇷' => 'bandera: Puerto Rico',
    '🇵🇹' => 'bandera: Portugal',
    '🇵🇾' => 'bandera: Paraguay',
    '🇶🇦' => 'bandera: Qatar',
    '🇷🇴' => 'bandera: Romania',
    '🇷🇸' => 'bandera: Servia',
    '🇷🇺' => 'bandera: Rusia',
    '🇷🇼' => 'bandera: Rwanda',
    '🇸🇨' => 'bandera: Seychelles',
    '🇸🇩' => 'bandera: Sudan',
    '🇸🇪' => 'bandera: Suesia',
    '🇸🇬' => 'bandera: Singapore',
    '🇸🇭' => 'bandera: Sint Helena',
    '🇸🇮' => 'bandera: Slovenia',
    '🇸🇰' => 'bandera: Slovakia',
    '🇸🇱' => 'bandera: Sierra Leone',
    '🇸🇲' => 'bandera: San Marino',
    '🇸🇳' => 'bandera: Senegal',
    '🇸🇴' => 'bandera: Somalia',
    '🇸🇷' => 'bandera: Surinam',
    '🇸🇻' => 'bandera: El Salvador',
    '🇸🇽' => 'bandera: Sint Maarten',
    '🇹🇨' => 'bandera: Turks i Caicos',
    '🇹🇩' => 'bandera: Chad',
    '🇹🇭' => 'bandera: Tailandia',
    '🇹🇷' => 'bandera: Turkia',
    '🇹🇹' => 'bandera: Trinidad i Tobago',
    '🇹🇼' => 'bandera: Taiwan',
    '🇺🇦' => 'bandera: Ukrania',
    '🇺🇬' => 'bandera: Uganda',
    '🇺🇳' => 'bandera: Nashonnan Uní',
    '🇺🇸' => 'bandera: Merka',
    '🇺🇾' => 'bandera: Uruguay',
    '🇻🇨' => 'bandera: Sint Vicent i Grenadines',
    '🇻🇪' => 'bandera: Venezuela',
    '🇻🇬' => 'bandera: Virgin Islands (Britániko)',
    '🇻🇮' => 'bandera: Virgin Islands (Merikano)',
    '🇻🇳' => 'bandera: Vietnam',
    '🇿🇦' => 'bandera: Suráfrika',
    '🇿🇲' => 'bandera: Zambia',
    '🇿🇼' => 'bandera: Zimbabwe',
    '😀' => 'kara di smile',
    '😃' => 'kara di smile ku wowo grandi',
    '😄' => 'kara ta smile ku wowo di smile',
    '😁' => 'kara ta smile ku djente afó',
    '😆' => 'kara di smile ku wowo chikí',
    '😅' => 'kara di smile ku sodó',
    '🤣' => 'hari te lora abou',
    '😂' => 'kara ku lágrima di alegia',
    '🙂' => 'kara ku smile',
    '🙃' => 'kara kabes abou',
    '🫠' => 'kara di smèlt',
    '😉' => 'kinipí wowo',
    '😊' => 'kara di smile ku blos',
    '😇' => 'kara di smile ku halo',
];
