<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Greenwichi aeg (Abidjan)',
        'Africa/Accra' => 'Greenwichi aeg (Accra)',
        'Africa/Addis_Ababa' => 'Ida-Aafrika aeg (Addis Abeba)',
        'Africa/Algiers' => 'Kesk-Euroopa aeg (Alžiir)',
        'Africa/Asmera' => 'Ida-Aafrika aeg (Asmara)',
        'Africa/Asmara' => 'Ida-Aafrika aeg (Asmara)',
        'Africa/Bamako' => 'Greenwichi aeg (Bamako)',
        'Africa/Bangui' => 'Lääne-Aafrika aeg (Bangui)',
        'Africa/Banjul' => 'Greenwichi aeg (Banjul)',
        'Africa/Bissau' => 'Greenwichi aeg (Bissau)',
        'Africa/Blantyre' => 'Kesk-Aafrika aeg (Blantyre)',
        'Africa/Brazzaville' => 'Lääne-Aafrika aeg (Brazzaville)',
        'Africa/Bujumbura' => 'Kesk-Aafrika aeg (Bujumbura)',
        'Africa/Cairo' => 'Ida-Euroopa aeg (Kairo)',
        'Africa/Casablanca' => 'Lääne-Euroopa aeg (Casablanca)',
        'Africa/Ceuta' => 'Kesk-Euroopa aeg (Ceuta)',
        'Africa/Conakry' => 'Greenwichi aeg (Conakry)',
        'Africa/Dakar' => 'Greenwichi aeg (Dakar)',
        'Africa/Dar_es_Salaam' => 'Ida-Aafrika aeg (Dar es Salaam)',
        'Africa/Djibouti' => 'Ida-Aafrika aeg (Djibouti)',
        'Africa/Douala' => 'Lääne-Aafrika aeg (Douala)',
        'Africa/El_Aaiun' => 'Lääne-Euroopa aeg (El Aaiún)',
        'Africa/Freetown' => 'Greenwichi aeg (Freetown)',
        'Africa/Gaborone' => 'Kesk-Aafrika aeg (Gaborone)',
        'Africa/Harare' => 'Kesk-Aafrika aeg (Harare)',
        'Africa/Johannesburg' => 'Lõuna-Aafrika standardaeg (Johannesburg)',
        'Africa/Juba' => 'Kesk-Aafrika aeg (Juba)',
        'Africa/Kampala' => 'Ida-Aafrika aeg (Kampala)',
        'Africa/Khartoum' => 'Kesk-Aafrika aeg (Hartum)',
        'Africa/Kigali' => 'Kesk-Aafrika aeg (Kigali)',
        'Africa/Kinshasa' => 'Lääne-Aafrika aeg (Kinshasa)',
        'Africa/Lagos' => 'Lääne-Aafrika aeg (Lagos)',
        'Africa/Libreville' => 'Lääne-Aafrika aeg (Libreville)',
        'Africa/Lome' => 'Greenwichi aeg (Lomé)',
        'Africa/Luanda' => 'Lääne-Aafrika aeg (Luanda)',
        'Africa/Lubumbashi' => 'Kesk-Aafrika aeg (Lubumbashi)',
        'Africa/Lusaka' => 'Kesk-Aafrika aeg (Lusaka)',
        'Africa/Malabo' => 'Lääne-Aafrika aeg (Malabo)',
        'Africa/Maputo' => 'Kesk-Aafrika aeg (Maputo)',
        'Africa/Maseru' => 'Lõuna-Aafrika standardaeg (Maseru)',
        'Africa/Mbabane' => 'Lõuna-Aafrika standardaeg (Mbabane)',
        'Africa/Mogadishu' => 'Ida-Aafrika aeg (Muqdisho)',
        'Africa/Monrovia' => 'Greenwichi aeg (Monrovia)',
        'Africa/Nairobi' => 'Ida-Aafrika aeg (Nairobi)',
        'Africa/Ndjamena' => 'Lääne-Aafrika aeg (N’Djamena)',
        'Africa/Niamey' => 'Lääne-Aafrika aeg (Niamey)',
        'Africa/Nouakchott' => 'Greenwichi aeg (Nouakchott)',
        'Africa/Ouagadougou' => 'Greenwichi aeg (Ouagadougou)',
        'Africa/Porto-Novo' => 'Lääne-Aafrika aeg (Porto-Novo)',
        'Africa/Sao_Tome' => 'Greenwichi aeg (São Tomé)',
        'Africa/Tripoli' => 'Ida-Euroopa aeg (Tripoli)',
        'Africa/Tunis' => 'Kesk-Euroopa aeg (Tunis)',
        'Africa/Windhoek' => 'Kesk-Aafrika aeg (Windhoek)',
        'America/Adak' => 'Hawaii-Aleuudi aeg (Adak)',
        'America/Anchorage' => 'Alaska aeg (Anchorage)',
        'America/Anguilla' => 'Atlandi aeg (Anguilla)',
        'America/Antigua' => 'Atlandi aeg (Antigua)',
        'America/Araguaina' => 'Brasiilia aeg (Araguaína)',
        'America/Argentina/La_Rioja' => 'Argentina aeg (La Rioja)',
        'America/Argentina/Rio_Gallegos' => 'Argentina aeg (Río Gallegos)',
        'America/Argentina/Salta' => 'Argentina aeg (Salta)',
        'America/Argentina/San_Juan' => 'Argentina aeg (San Juan)',
        'America/Argentina/San_Luis' => 'Argentina aeg (San Luis)',
        'America/Argentina/Tucuman' => 'Argentina aeg (Tucumán)',
        'America/Argentina/Ushuaia' => 'Argentina aeg (Ushuaia)',
        'America/Aruba' => 'Atlandi aeg (Aruba)',
        'America/Asuncion' => 'Paraguay aeg (Asunción)',
        'America/Bahia' => 'Brasiilia aeg (Bahia)',
        'America/Bahia_Banderas' => 'Kesk-Ameerika aeg (Bahia Banderas)',
        'America/Barbados' => 'Atlandi aeg (Barbados)',
        'America/Belem' => 'Brasiilia aeg (Belém)',
        'America/Belize' => 'Kesk-Ameerika aeg (Belize)',
        'America/Blanc-Sablon' => 'Atlandi aeg (Blanc-Sablon)',
        'America/Boa_Vista' => 'Amazonase aeg (Boa Vista)',
        'America/Bogota' => 'Colombia aeg (Bogotá)',
        'America/Boise' => 'Mäestikuvööndi aeg (Boise)',
        'America/Buenos_Aires' => 'Argentina aeg (Buenos Aires)',
        'America/Argentina/Buenos_Aires' => 'Argentina aeg (Buenos Aires)',
        'America/Cambridge_Bay' => 'Mäestikuvööndi aeg (Cambridge Bay)',
        'America/Campo_Grande' => 'Amazonase aeg (Campo Grande)',
        'America/Cancun' => 'Idaranniku aeg (Cancún)',
        'America/Caracas' => 'Venezuela aeg (Caracas)',
        'America/Catamarca' => 'Argentina aeg (Catamarca)',
        'America/Argentina/Catamarca' => 'Argentina aeg (Catamarca)',
        'America/Cayenne' => 'Prantsuse Guajaana aeg (Cayenne)',
        'America/Cayman' => 'Idaranniku aeg (Cayman)',
        'America/Chicago' => 'Kesk-Ameerika aeg (Chicago)',
        'America/Chihuahua' => 'Kesk-Ameerika aeg (Chihuahua)',
        'America/Ciudad_Juarez' => 'Mäestikuvööndi aeg (Ciudad Juárez)',
        'America/Coral_Harbour' => 'Idaranniku aeg (Atikokan)',
        'America/Atikokan' => 'Idaranniku aeg (Atikokan)',
        'America/Cordoba' => 'Argentina aeg (Córdoba)',
        'America/Argentina/Cordoba' => 'Argentina aeg (Córdoba)',
        'America/Costa_Rica' => 'Kesk-Ameerika aeg (Costa Rica)',
        'America/Coyhaique' => 'Tšiili aeg (Coyhaique)',
        'America/Creston' => 'Mäestikuvööndi aeg (Creston)',
        'America/Cuiaba' => 'Amazonase aeg (Cuiabá)',
        'America/Curacao' => 'Atlandi aeg (Curaçao)',
        'America/Danmarkshavn' => 'Greenwichi aeg (Danmarkshavn)',
        'America/Dawson' => 'Yukoni aeg (Dawson)',
        'America/Dawson_Creek' => 'Mäestikuvööndi aeg (Dawson Creek)',
        'America/Denver' => 'Mäestikuvööndi aeg (Denver)',
        'America/Detroit' => 'Idaranniku aeg (Detroit)',
        'America/Dominica' => 'Atlandi aeg (Dominica)',
        'America/Edmonton' => 'Mäestikuvööndi aeg (Edmonton)',
        'America/Eirunepe' => 'Acre aeg (Eirunepé)',
        'America/El_Salvador' => 'Kesk-Ameerika aeg (El Salvador)',
        'America/Fort_Nelson' => 'Mäestikuvööndi aeg (Fort Nelson)',
        'America/Fortaleza' => 'Brasiilia aeg (Fortaleza)',
        'America/Glace_Bay' => 'Atlandi aeg (Glace Bay)',
        'America/Godthab' => 'Gröönimaa aeg (Nuuk)',
        'America/Nuuk' => 'Gröönimaa aeg (Nuuk)',
        'America/Goose_Bay' => 'Atlandi aeg (Goose Bay)',
        'America/Grand_Turk' => 'Idaranniku aeg (Grand Turk)',
        'America/Grenada' => 'Atlandi aeg (Grenada)',
        'America/Guadeloupe' => 'Atlandi aeg (Guadeloupe)',
        'America/Guatemala' => 'Kesk-Ameerika aeg (Guatemala)',
        'America/Guayaquil' => 'Ecuadori aeg (Guayaquil)',
        'America/Guyana' => 'Guyana aeg',
        'America/Halifax' => 'Atlandi aeg (Halifax)',
        'America/Havana' => 'Kuuba aeg (Havanna)',
        'America/Hermosillo' => 'Mehhiko Vaikse ookeani aeg (Hermosillo)',
        'America/Indiana/Knox' => 'Kesk-Ameerika aeg (Knox, Indiana)',
        'America/Indiana/Marengo' => 'Idaranniku aeg (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'Idaranniku aeg (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'Kesk-Ameerika aeg (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'Idaranniku aeg (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'Idaranniku aeg (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'Idaranniku aeg (Winamac, Indiana)',
        'America/Indianapolis' => 'Idaranniku aeg (Indianapolis)',
        'America/Indiana/Indianapolis' => 'Idaranniku aeg (Indianapolis)',
        'America/Inuvik' => 'Mäestikuvööndi aeg (Inuvik)',
        'America/Iqaluit' => 'Idaranniku aeg (Iqaluit)',
        'America/Jamaica' => 'Idaranniku aeg (Jamaica)',
        'America/Jujuy' => 'Argentina aeg (Jujuy)',
        'America/Argentina/Jujuy' => 'Argentina aeg (Jujuy)',
        'America/Juneau' => 'Alaska aeg (Juneau)',
        'America/Kentucky/Monticello' => 'Idaranniku aeg (Monticello, Kentucky)',
        'America/Kralendijk' => 'Atlandi aeg (Kralendijk)',
        'America/La_Paz' => 'Boliivia aeg (La Paz)',
        'America/Lima' => 'Peruu aeg (Lima)',
        'America/Los_Angeles' => 'Vaikse ookeani aeg (Los Angeles)',
        'America/Louisville' => 'Idaranniku aeg (Louisville)',
        'America/Kentucky/Louisville' => 'Idaranniku aeg (Louisville)',
        'America/Lower_Princes' => 'Atlandi aeg (Lower Prince’s Quarter)',
        'America/Maceio' => 'Brasiilia aeg (Maceió)',
        'America/Managua' => 'Kesk-Ameerika aeg (Managua)',
        'America/Manaus' => 'Amazonase aeg (Manaus)',
        'America/Marigot' => 'Atlandi aeg (Marigot)',
        'America/Martinique' => 'Atlandi aeg (Martinique)',
        'America/Matamoros' => 'Kesk-Ameerika aeg (Matamoros)',
        'America/Mazatlan' => 'Mehhiko Vaikse ookeani aeg (Mazatlán)',
        'America/Mendoza' => 'Argentina aeg (Mendoza)',
        'America/Argentina/Mendoza' => 'Argentina aeg (Mendoza)',
        'America/Menominee' => 'Kesk-Ameerika aeg (Menominee)',
        'America/Merida' => 'Kesk-Ameerika aeg (Mérida)',
        'America/Metlakatla' => 'Alaska aeg (Metlakatla)',
        'America/Mexico_City' => 'Kesk-Ameerika aeg (México)',
        'America/Miquelon' => 'Saint-Pierre’i ja Miqueloni aeg',
        'America/Moncton' => 'Atlandi aeg (Moncton)',
        'America/Monterrey' => 'Kesk-Ameerika aeg (Monterrey)',
        'America/Montevideo' => 'Uruguay aeg (Montevideo)',
        'America/Montserrat' => 'Atlandi aeg (Montserrat)',
        'America/Nassau' => 'Idaranniku aeg (Nassau)',
        'America/New_York' => 'Idaranniku aeg (New York)',
        'America/Nome' => 'Alaska aeg (Nome)',
        'America/Noronha' => 'Fernando de Noronha aeg',
        'America/North_Dakota/Beulah' => 'Kesk-Ameerika aeg (Beulah, Põhja-Dakota)',
        'America/North_Dakota/Center' => 'Kesk-Ameerika aeg (Center, Põhja-Dakota)',
        'America/North_Dakota/New_Salem' => 'Kesk-Ameerika aeg (New Salem, Põhja-Dakota)',
        'America/Ojinaga' => 'Kesk-Ameerika aeg (Ojinaga)',
        'America/Panama' => 'Idaranniku aeg (Panama)',
        'America/Paramaribo' => 'Suriname aeg (Paramaribo)',
        'America/Phoenix' => 'Mäestikuvööndi aeg (Phoenix)',
        'America/Port-au-Prince' => 'Idaranniku aeg (Port-au-Prince)',
        'America/Port_of_Spain' => 'Atlandi aeg (Port of Spain)',
        'America/Porto_Velho' => 'Amazonase aeg (Porto Velho)',
        'America/Puerto_Rico' => 'Atlandi aeg (Puerto Rico)',
        'America/Punta_Arenas' => 'Tšiili aeg (Punta Arenas)',
        'America/Rankin_Inlet' => 'Kesk-Ameerika aeg (Rankin Inlet)',
        'America/Recife' => 'Brasiilia aeg (Recife)',
        'America/Regina' => 'Kesk-Ameerika aeg (Regina)',
        'America/Resolute' => 'Kesk-Ameerika aeg (Resolute)',
        'America/Rio_Branco' => 'Acre aeg (Rio Branco)',
        'America/Santarem' => 'Brasiilia aeg (Santarém)',
        'America/Santiago' => 'Tšiili aeg (Santiago)',
        'America/Santo_Domingo' => 'Atlandi aeg (Santo Domingo)',
        'America/Sao_Paulo' => 'Brasiilia aeg (São Paulo)',
        'America/Scoresbysund' => 'Gröönimaa aeg (Ittoqqortoormiit)',
        'America/Sitka' => 'Alaska aeg (Sitka)',
        'America/St_Barthelemy' => 'Atlandi aeg (Saint-Barthélemy)',
        'America/St_Johns' => 'Newfoundlandi aeg (Saint John’s)',
        'America/St_Kitts' => 'Atlandi aeg (Saint Kitts)',
        'America/St_Lucia' => 'Atlandi aeg (Saint Lucia)',
        'America/St_Thomas' => 'Atlandi aeg (Saint Thomas)',
        'America/St_Vincent' => 'Atlandi aeg (Saint Vincent)',
        'America/Swift_Current' => 'Kesk-Ameerika aeg (Swift Current)',
        'America/Tegucigalpa' => 'Kesk-Ameerika aeg (Tegucigalpa)',
        'America/Thule' => 'Atlandi aeg (Thule)',
        'America/Tijuana' => 'Vaikse ookeani aeg (Tijuana)',
        'America/Toronto' => 'Idaranniku aeg (Toronto)',
        'America/Tortola' => 'Atlandi aeg (Tortola)',
        'America/Vancouver' => 'Vaikse ookeani aeg (Vancouver)',
        'America/Whitehorse' => 'Yukoni aeg (Whitehorse)',
        'America/Winnipeg' => 'Kesk-Ameerika aeg (Winnipeg)',
        'America/Yakutat' => 'Alaska aeg (Yakutat)',
        'Antarctica/Casey' => 'Lääne-Austraalia aeg (Casey)',
        'Antarctica/Davis' => 'Davise aeg',
        'Antarctica/DumontDUrville' => 'Dumont d’Urville’i aeg',
        'Antarctica/Macquarie' => 'Ida-Austraalia aeg (Macquarie)',
        'Antarctica/Mawson' => 'Mawsoni aeg',
        'Antarctica/McMurdo' => 'Uus-Meremaa aeg (McMurdo)',
        'Antarctica/Palmer' => 'Tšiili aeg (Palmer)',
        'Antarctica/Rothera' => 'Rothera aeg',
        'Antarctica/Syowa' => 'Syowa aeg (Showa)',
        'Antarctica/Troll' => 'Greenwichi aeg (Troll)',
        'Antarctica/Vostok' => 'Vostoki aeg',
        'Arctic/Longyearbyen' => 'Kesk-Euroopa aeg (Longyearbyen)',
        'Asia/Aden' => 'Araabia aeg (Aden)',
        'Asia/Almaty' => 'Kasahstani aeg (Almatõ)',
        'Asia/Amman' => 'Ida-Euroopa aeg (Amman)',
        'Asia/Anadyr' => 'Petropavlovsk-Kamtšatski aeg (Anadõr)',
        'Asia/Aqtau' => 'Kasahstani aeg (Aktau)',
        'Asia/Aqtobe' => 'Kasahstani aeg (Aktöbe)',
        'Asia/Ashgabat' => 'Türkmenistani aeg (Aşgabat)',
        'Asia/Atyrau' => 'Kasahstani aeg (Atõrau)',
        'Asia/Baghdad' => 'Araabia aeg (Bagdad)',
        'Asia/Bahrain' => 'Araabia aeg (Bahrein)',
        'Asia/Baku' => 'Aserbaidžaani aeg (Bakuu)',
        'Asia/Bangkok' => 'Indohiina aeg (Bangkok)',
        'Asia/Barnaul' => 'Krasnojarski aeg (Barnaul)',
        'Asia/Beirut' => 'Ida-Euroopa aeg (Beirut)',
        'Asia/Bishkek' => 'Kõrgõzstani aeg (Biškek)',
        'Asia/Brunei' => 'Brunei aeg',
        'Asia/Calcutta' => 'India aeg (Kolkata)',
        'Asia/Kolkata' => 'India aeg (Kolkata)',
        'Asia/Chita' => 'Jakutski aeg (Tšita)',
        'Asia/Colombo' => 'India aeg (Colombo)',
        'Asia/Damascus' => 'Ida-Euroopa aeg (Damaskus)',
        'Asia/Dhaka' => 'Bangladeshi aeg (Dhaka)',
        'Asia/Dili' => 'Ida-Timori aeg (Dili)',
        'Asia/Dubai' => 'Pärsia lahe standardaeg (Dubai)',
        'Asia/Dushanbe' => 'Tadžikistani aeg (Dušanbe)',
        'Asia/Famagusta' => 'Ida-Euroopa aeg (Famagusta)',
        'Asia/Gaza' => 'Ida-Euroopa aeg (Gaza)',
        'Asia/Hebron' => 'Ida-Euroopa aeg (Hebron)',
        'Asia/Hong_Kong' => 'Hongkongi aeg',
        'Asia/Hovd' => 'Hovdi aeg (Khovd)',
        'Asia/Irkutsk' => 'Irkutski aeg',
        'Asia/Jakarta' => 'Lääne-Indoneesia aeg (Jakarta)',
        'Asia/Jayapura' => 'Ida-Indoneesia aeg (Jayapura)',
        'Asia/Jerusalem' => 'Iisraeli aeg (Jeruusalemm)',
        'Asia/Kabul' => 'Afganistani aeg (Kabul)',
        'Asia/Kamchatka' => 'Petropavlovsk-Kamtšatski aeg (Kamtšatka)',
        'Asia/Karachi' => 'Pakistani aeg (Karachi)',
        'Asia/Katmandu' => 'Nepali aeg (Katmandu)',
        'Asia/Kathmandu' => 'Nepali aeg (Katmandu)',
        'Asia/Khandyga' => 'Jakutski aeg (Handõga)',
        'Asia/Krasnoyarsk' => 'Krasnojarski aeg',
        'Asia/Kuala_Lumpur' => 'Malaisia aeg (Kuala Lumpur)',
        'Asia/Kuching' => 'Malaisia aeg (Kuching)',
        'Asia/Kuwait' => 'Araabia aeg (Kuveit)',
        'Asia/Macau' => 'Hiina aeg (Macau)',
        'Asia/Magadan' => 'Magadani aeg',
        'Asia/Makassar' => 'Kesk-Indoneesia aeg (Makassar)',
        'Asia/Manila' => 'Filipiini aeg (Manila)',
        'Asia/Muscat' => 'Pärsia lahe standardaeg (Masqaţ)',
        'Asia/Nicosia' => 'Ida-Euroopa aeg (Nikosia)',
        'Asia/Novokuznetsk' => 'Krasnojarski aeg (Novokuznetsk)',
        'Asia/Novosibirsk' => 'Krasnojarski aeg (Novosibirsk)',
        'Asia/Omsk' => 'Omski aeg',
        'Asia/Oral' => 'Kasahstani aeg (Oral)',
        'Asia/Phnom_Penh' => 'Indohiina aeg (Phnom Penh)',
        'Asia/Pontianak' => 'Lääne-Indoneesia aeg (Pontianak)',
        'Asia/Pyongyang' => 'Korea aeg (Pyongyang)',
        'Asia/Qatar' => 'Araabia aeg (Katar)',
        'Asia/Qostanay' => 'Kasahstani aeg (Kostanaj)',
        'Asia/Qyzylorda' => 'Kasahstani aeg (Kõzõlorda)',
        'Asia/Rangoon' => 'Birma aeg (Yangon)',
        'Asia/Yangon' => 'Birma aeg (Yangon)',
        'Asia/Riyadh' => 'Araabia aeg (Ar-Riyāḑ)',
        'Asia/Saigon' => 'Indohiina aeg (Hô Chi Minh)',
        'Asia/Ho_Chi_Minh' => 'Indohiina aeg (Hô Chi Minh)',
        'Asia/Sakhalin' => 'Magadani aeg (Sahhalin)',
        'Asia/Samarkand' => 'Usbekistani aeg (Samarkand)',
        'Asia/Seoul' => 'Korea aeg (Soul)',
        'Asia/Shanghai' => 'Hiina aeg (Shanghai)',
        'Asia/Singapore' => 'Singapuri standardaeg',
        'Asia/Srednekolymsk' => 'Magadani aeg (Srednekolõmsk)',
        'Asia/Taipei' => 'Taipei aeg',
        'Asia/Tashkent' => 'Usbekistani aeg (Taškent)',
        'Asia/Tbilisi' => 'Gruusia aeg (Thbilisi)',
        'Asia/Tehran' => 'Iraani aeg (Teheran)',
        'Asia/Thimphu' => 'Bhutani aeg (Thimphu)',
        'Asia/Tokyo' => 'Jaapani aeg (Tōkyō)',
        'Asia/Tomsk' => 'Krasnojarski aeg (Tomsk)',
        'Asia/Ulaanbaatar' => 'Ulaanbaatari aeg',
        'Asia/Urumqi' => '(Hiina) (Ürümqi)',
        'Asia/Ust-Nera' => 'Vladivostoki aeg (Ust-Nera)',
        'Asia/Vientiane' => 'Indohiina aeg (Vientiane)',
        'Asia/Vladivostok' => 'Vladivostoki aeg',
        'Asia/Yakutsk' => 'Jakutski aeg',
        'Asia/Yekaterinburg' => 'Jekaterinburgi aeg',
        'Asia/Yerevan' => 'Armeenia aeg (Jerevan)',
        'Atlantic/Azores' => 'Assooride aeg',
        'Atlantic/Bermuda' => 'Atlandi aeg (Bermuda)',
        'Atlantic/Canary' => 'Lääne-Euroopa aeg (Kanaari saared)',
        'Atlantic/Cape_Verde' => 'Roheneemesaarte aeg (Roheneemesaared)',
        'Atlantic/Faeroe' => 'Lääne-Euroopa aeg (Fääri saared)',
        'Atlantic/Faroe' => 'Lääne-Euroopa aeg (Fääri saared)',
        'Atlantic/Madeira' => 'Lääne-Euroopa aeg (Madeira)',
        'Atlantic/Reykjavik' => 'Greenwichi aeg (Reykjavík)',
        'Atlantic/South_Georgia' => 'Lõuna-Georgia aeg',
        'Atlantic/St_Helena' => 'Greenwichi aeg (Saint Helena)',
        'Atlantic/Stanley' => 'Falklandi saarte aeg (Stanley)',
        'Australia/Adelaide' => 'Kesk-Austraalia aeg (Adelaide)',
        'Australia/Brisbane' => 'Ida-Austraalia aeg (Brisbane)',
        'Australia/Broken_Hill' => 'Kesk-Austraalia aeg (Broken Hill)',
        'Australia/Darwin' => 'Kesk-Austraalia aeg (Darwin)',
        'Australia/Eucla' => 'Austraalia Kesk-Lääne aeg (Eucla)',
        'Australia/Hobart' => 'Ida-Austraalia aeg (Hobart)',
        'Australia/Lindeman' => 'Ida-Austraalia aeg (Lindeman)',
        'Australia/Lord_Howe' => 'Lord Howe’i aeg',
        'Australia/Melbourne' => 'Ida-Austraalia aeg (Melbourne)',
        'Australia/Perth' => 'Lääne-Austraalia aeg (Perth)',
        'Australia/Sydney' => 'Ida-Austraalia aeg (Sydney)',
        'Etc/GMT' => 'Greenwichi aeg',
        'Etc/UTC' => 'Koordineeritud maailmaaeg',
        'Europe/Amsterdam' => 'Kesk-Euroopa aeg (Amsterdam)',
        'Europe/Andorra' => 'Kesk-Euroopa aeg (Andorra)',
        'Europe/Astrakhan' => 'Samara aeg (Astrahan)',
        'Europe/Athens' => 'Ida-Euroopa aeg (Ateena)',
        'Europe/Belgrade' => 'Kesk-Euroopa aeg (Belgrad)',
        'Europe/Berlin' => 'Kesk-Euroopa aeg (Berliin)',
        'Europe/Bratislava' => 'Kesk-Euroopa aeg (Bratislava)',
        'Europe/Brussels' => 'Kesk-Euroopa aeg (Brüssel)',
        'Europe/Bucharest' => 'Ida-Euroopa aeg (Bukarest)',
        'Europe/Budapest' => 'Kesk-Euroopa aeg (Budapest)',
        'Europe/Busingen' => 'Kesk-Euroopa aeg (Büsingen)',
        'Europe/Chisinau' => 'Ida-Euroopa aeg (Chișinău)',
        'Europe/Copenhagen' => 'Kesk-Euroopa aeg (Kopenhaagen)',
        'Europe/Dublin' => 'Greenwichi aeg (Dublin)',
        'Europe/Gibraltar' => 'Kesk-Euroopa aeg (Gibraltar)',
        'Europe/Guernsey' => 'Greenwichi aeg (Guernsey)',
        'Europe/Helsinki' => 'Ida-Euroopa aeg (Helsingi)',
        'Europe/Isle_of_Man' => 'Greenwichi aeg (Mani saar)',
        'Europe/Istanbul' => 'Türgi aeg (İstanbul)',
        'Europe/Jersey' => 'Greenwichi aeg (Jersey)',
        'Europe/Kaliningrad' => 'Ida-Euroopa aeg (Kaliningrad)',
        'Europe/Kiev' => 'Ida-Euroopa aeg (Kiiev)',
        'Europe/Kyiv' => 'Ida-Euroopa aeg (Kiiev)',
        'Europe/Kirov' => 'Moskva aeg (Kirov)',
        'Europe/Lisbon' => 'Lääne-Euroopa aeg (Lissabon)',
        'Europe/Ljubljana' => 'Kesk-Euroopa aeg (Ljubljana)',
        'Europe/London' => 'Greenwichi aeg (London)',
        'Europe/Luxembourg' => 'Kesk-Euroopa aeg (Luxembourg)',
        'Europe/Madrid' => 'Kesk-Euroopa aeg (Madrid)',
        'Europe/Malta' => 'Kesk-Euroopa aeg (Malta)',
        'Europe/Mariehamn' => 'Ida-Euroopa aeg (Maarianhamina)',
        'Europe/Minsk' => 'Moskva aeg (Minsk)',
        'Europe/Monaco' => 'Kesk-Euroopa aeg (Monaco)',
        'Europe/Moscow' => 'Moskva aeg',
        'Europe/Oslo' => 'Kesk-Euroopa aeg (Oslo)',
        'Europe/Paris' => 'Kesk-Euroopa aeg (Pariis)',
        'Europe/Podgorica' => 'Kesk-Euroopa aeg (Podgorica)',
        'Europe/Prague' => 'Kesk-Euroopa aeg (Praha)',
        'Europe/Riga' => 'Ida-Euroopa aeg (Riia)',
        'Europe/Rome' => 'Kesk-Euroopa aeg (Rooma)',
        'Europe/Samara' => 'Samara aeg',
        'Europe/San_Marino' => 'Kesk-Euroopa aeg (San Marino)',
        'Europe/Sarajevo' => 'Kesk-Euroopa aeg (Sarajevo)',
        'Europe/Saratov' => 'Samara aeg (Saratov)',
        'Europe/Simferopol' => 'Moskva aeg (Simferopol)',
        'Europe/Skopje' => 'Kesk-Euroopa aeg (Skopje)',
        'Europe/Sofia' => 'Ida-Euroopa aeg (Sofia)',
        'Europe/Stockholm' => 'Kesk-Euroopa aeg (Stockholm)',
        'Europe/Tallinn' => 'Ida-Euroopa aeg (Tallinn)',
        'Europe/Tirane' => 'Kesk-Euroopa aeg (Tirana)',
        'Europe/Ulyanovsk' => 'Samara aeg (Uljanovsk)',
        'Europe/Vaduz' => 'Kesk-Euroopa aeg (Vaduz)',
        'Europe/Vatican' => 'Kesk-Euroopa aeg (Vatikan)',
        'Europe/Vienna' => 'Kesk-Euroopa aeg (Viin)',
        'Europe/Vilnius' => 'Ida-Euroopa aeg (Vilnius)',
        'Europe/Volgograd' => 'Moskva aeg (Volgograd)',
        'Europe/Warsaw' => 'Kesk-Euroopa aeg (Varssavi)',
        'Europe/Zagreb' => 'Kesk-Euroopa aeg (Zagreb)',
        'Europe/Zurich' => 'Kesk-Euroopa aeg (Zürich)',
        'Indian/Antananarivo' => 'Ida-Aafrika aeg (Antananarivo)',
        'Indian/Chagos' => 'India ookeani aeg (Chagos)',
        'Indian/Christmas' => 'Jõulusaare aeg',
        'Indian/Cocos' => 'Kookossaarte aeg (Kookossaared)',
        'Indian/Comoro' => 'Ida-Aafrika aeg (Comores)',
        'Indian/Kerguelen' => 'Prantsuse Antarktiliste ja Lõunaalade aeg (Kerguelen)',
        'Indian/Mahe' => 'Seišelli aeg (Mahé)',
        'Indian/Maldives' => 'Maldiivi aeg (Maldiivid)',
        'Indian/Mauritius' => 'Mauritiuse aeg',
        'Indian/Mayotte' => 'Ida-Aafrika aeg (Mayotte)',
        'Indian/Reunion' => 'Réunioni aeg',
        'Pacific/Apia' => 'Apia aeg',
        'Pacific/Auckland' => 'Uus-Meremaa aeg (Auckland)',
        'Pacific/Bougainville' => 'Paapua Uus-Guinea aeg (Bougainville)',
        'Pacific/Chatham' => 'Chathami aeg',
        'Pacific/Easter' => 'Lihavõttesaare aeg',
        'Pacific/Efate' => 'Vanuatu aeg (Efate)',
        'Pacific/Enderbury' => 'Fööniksisaarte aeg (Abariringa)',
        'Pacific/Kanton' => 'Fööniksisaarte aeg (Abariringa)',
        'Pacific/Fakaofo' => 'Tokelau aeg (Fakaofo)',
        'Pacific/Fiji' => 'Fidži aeg',
        'Pacific/Funafuti' => 'Tuvalu aeg (Funafuti)',
        'Pacific/Galapagos' => 'Galapagose aeg (Galápagos)',
        'Pacific/Gambier' => 'Gambier’ aeg',
        'Pacific/Guadalcanal' => 'Saalomoni Saarte aeg (Guadalcanal)',
        'Pacific/Guam' => 'Tšamorro standardaeg (Guam)',
        'Pacific/Honolulu' => 'Hawaii-Aleuudi standardaeg (Honolulu)',
        'Pacific/Kiritimati' => 'Line’i saarte aeg (Kiritimati)',
        'Pacific/Kosrae' => 'Kosrae aeg',
        'Pacific/Kwajalein' => 'Marshalli Saarte aeg (Kwajalein)',
        'Pacific/Majuro' => 'Marshalli Saarte aeg (Majuro)',
        'Pacific/Marquesas' => 'Markiisaarte aeg (Markiisaared)',
        'Pacific/Midway' => 'Samoa aeg (Midway)',
        'Pacific/Nauru' => 'Nauru aeg',
        'Pacific/Niue' => 'Niue aeg',
        'Pacific/Norfolk' => 'Norfolki saare aeg',
        'Pacific/Noumea' => 'Uus-Kaledoonia aeg (Nouméa)',
        'Pacific/Pago_Pago' => 'Samoa aeg (Pago Pago)',
        'Pacific/Palau' => 'Belau aeg',
        'Pacific/Pitcairn' => 'Pitcairni aeg',
        'Pacific/Ponape' => 'Pohnpei aeg',
        'Pacific/Pohnpei' => 'Pohnpei aeg',
        'Pacific/Port_Moresby' => 'Paapua Uus-Guinea aeg (Port Moresby)',
        'Pacific/Rarotonga' => 'Cooki saarte aeg (Rarotonga)',
        'Pacific/Saipan' => 'Tšamorro standardaeg (Saipan)',
        'Pacific/Tahiti' => 'Tahiti aeg',
        'Pacific/Tarawa' => 'Gilberti saarte aeg (Tarawa)',
        'Pacific/Tongatapu' => 'Tonga aeg (Tongatapu)',
        'Pacific/Truk' => 'Chuuki aeg',
        'Pacific/Chuuk' => 'Chuuki aeg',
        'Pacific/Wake' => 'Wake’i aeg',
        'Pacific/Wallis' => 'Wallise ja Futuna aeg (Wallis & Futuna)',
    ],
    'Meta' => [
        'GmtFormat' => 'GMT %s',
        'HourFormatNeg' => '−%02d:%02d',
    ],
];
