<?php

return [
    'UserAssignedNames' => [],
    'Names' => [
        'BA' => 'Bosnia y Herzegovina',
        'EH' => 'Sahara Occidental',
        'GG' => 'Guernsey',
        'UM' => 'Islas menores alejadas de EE. UU.',
    ],
];
