<?php

return [
    'Names' => [
        'ADP' => [
            'ADP',
            'Андоррская песета',
        ],
        'AED' => [
            'AED',
            'дирхам ОАЭ',
        ],
        'AFA' => [
            'AFA',
            'Афгани (1927–2002)',
        ],
        'AFN' => [
            'AFN',
            'афгани',
        ],
        'ALL' => [
            'ALL',
            'албанский лек',
        ],
        'AMD' => [
            'AMD',
            'армянский драм',
        ],
        'ANG' => [
            'ANG',
            'нидерландский антильский гульден',
        ],
        'AOA' => [
            'AOA',
            'ангольская кванза',
        ],
        'AOK' => [
            'AOK',
            'Ангольская кванза (1977–1990)',
        ],
        'AON' => [
            'AON',
            'Ангольская новая кванза (1990–2000)',
        ],
        'AOR' => [
            'AOR',
            'Ангольская кванза реюстадо (1995–1999)',
        ],
        'ARA' => [
            'ARA',
            'Аргентинский аустрал',
        ],
        'ARP' => [
            'ARP',
            'Аргентинское песо (1983–1985)',
        ],
        'ARS' => [
            'ARS',
            'аргентинский песо',
        ],
        'ATS' => [
            'ATS',
            'Австрийский шиллинг',
        ],
        'AUD' => [
            'A$',
            'австралийский доллар',
        ],
        'AWG' => [
            'AWG',
            'арубанский флорин',
        ],
        'AZM' => [
            'AZM',
            'Старый азербайджанский манат',
        ],
        'AZN' => [
            'AZN',
            'азербайджанский манат',
        ],
        'BAD' => [
            'BAD',
            'Динар Боснии и Герцеговины',
        ],
        'BAM' => [
            'BAM',
            'конвертируемая марка Боснии и Герцеговины',
        ],
        'BBD' => [
            'BBD',
            'барбадосский доллар',
        ],
        'BDT' => [
            'BDT',
            'бангладешская така',
        ],
        'BEC' => [
            'BEC',
            'Бельгийский франк (конвертируемый)',
        ],
        'BEF' => [
            'BEF',
            'Бельгийский франк',
        ],
        'BEL' => [
            'BEL',
            'Бельгийский франк (финансовый)',
        ],
        'BGL' => [
            'BGL',
            'Лев',
        ],
        'BGN' => [
            'BGN',
            'болгарский лев',
        ],
        'BHD' => [
            'BHD',
            'бахрейнский динар',
        ],
        'BIF' => [
            'BIF',
            'бурундийский франк',
        ],
        'BMD' => [
            'BMD',
            'бермудский доллар',
        ],
        'BND' => [
            'BND',
            'брунейский доллар',
        ],
        'BOB' => [
            'BOB',
            'боливийский боливиано',
        ],
        'BOP' => [
            'BOP',
            'Боливийское песо',
        ],
        'BOV' => [
            'BOV',
            'Боливийский мвдол',
        ],
        'BRB' => [
            'BRB',
            'Бразильский новый крузейро (1967–1986)',
        ],
        'BRC' => [
            'BRC',
            'Бразильское крузадо',
        ],
        'BRE' => [
            'BRE',
            'Бразильский крузейро (1990–1993)',
        ],
        'BRL' => [
            'R$',
            'бразильский реал',
        ],
        'BRN' => [
            'BRN',
            'Бразильское новое крузадо',
        ],
        'BRR' => [
            'BRR',
            'Бразильский крузейро',
        ],
        'BSD' => [
            'BSD',
            'багамский доллар',
        ],
        'BTN' => [
            'BTN',
            'бутанский нгултрум',
        ],
        'BUK' => [
            'BUK',
            'Джа',
        ],
        'BWP' => [
            'BWP',
            'ботсванская пула',
        ],
        'BYB' => [
            'BYB',
            'Белорусский рубль (1994–1999)',
        ],
        'BYN' => [
            'BYN',
            'белорусский рубль',
        ],
        'BYR' => [
            'BYR',
            'Белорусский рубль (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'белизский доллар',
        ],
        'CAD' => [
            'CA$',
            'канадский доллар',
        ],
        'CDF' => [
            'CDF',
            'конголезский франк',
        ],
        'CHE' => [
            'CHE',
            'WIR евро',
        ],
        'CHF' => [
            'CHF',
            'швейцарский франк',
        ],
        'CHW' => [
            'CHW',
            'WIR франк',
        ],
        'CLF' => [
            'CLF',
            'Условная расчетная единица Чили',
        ],
        'CLP' => [
            'CLP',
            'чилийский песо',
        ],
        'CNH' => [
            'CNH',
            'китайский офшорный юань',
        ],
        'CNY' => [
            'CN¥',
            'китайский юань',
        ],
        'COP' => [
            'COP',
            'колумбийский песо',
        ],
        'COU' => [
            'COU',
            'Единица реальной стоимости Колумбии',
        ],
        'CRC' => [
            'CRC',
            'костариканский колон',
        ],
        'CSD' => [
            'CSD',
            'Старый Сербский динар',
        ],
        'CSK' => [
            'CSK',
            'Чехословацкая твердая крона',
        ],
        'CUC' => [
            'CUC',
            'кубинский конвертируемый песо',
        ],
        'CUP' => [
            'CUP',
            'кубинский песо',
        ],
        'CVE' => [
            'CVE',
            'эскудо Кабо-Верде',
        ],
        'CYP' => [
            'CYP',
            'Кипрский фунт',
        ],
        'CZK' => [
            'CZK',
            'чешская крона',
        ],
        'DDM' => [
            'DDM',
            'Восточногерманская марка',
        ],
        'DEM' => [
            'DEM',
            'Немецкая марка',
        ],
        'DJF' => [
            'DJF',
            'франк Джибути',
        ],
        'DKK' => [
            'DKK',
            'датская крона',
        ],
        'DOP' => [
            'DOP',
            'доминиканский песо',
        ],
        'DZD' => [
            'DZD',
            'алжирский динар',
        ],
        'ECS' => [
            'ECS',
            'Эквадорский сукре',
        ],
        'ECV' => [
            'ECV',
            'Постоянная единица стоимости Эквадора',
        ],
        'EEK' => [
            'EEK',
            'Эстонская крона',
        ],
        'EGP' => [
            'EGP',
            'египетский фунт',
        ],
        'ERN' => [
            'ERN',
            'эритрейская накфа',
        ],
        'ESA' => [
            'ESA',
            'Испанская песета (А)',
        ],
        'ESB' => [
            'ESB',
            'Испанская песета (конвертируемая)',
        ],
        'ESP' => [
            'ESP',
            'Испанская песета',
        ],
        'ETB' => [
            'ETB',
            'эфиопский быр',
        ],
        'EUR' => [
            '€',
            'евро',
        ],
        'FIM' => [
            'FIM',
            'Финская марка',
        ],
        'FJD' => [
            'FJD',
            'доллар Фиджи',
        ],
        'FKP' => [
            'FKP',
            'фунт Фолклендских островов',
        ],
        'FRF' => [
            'FRF',
            'Французский франк',
        ],
        'GBP' => [
            '£',
            'британский фунт стерлингов',
        ],
        'GEK' => [
            'GEK',
            'Грузинский купон',
        ],
        'GEL' => [
            'GEL',
            'грузинский лари',
        ],
        'GHC' => [
            'GHC',
            'Ганский седи (1979–2007)',
        ],
        'GHS' => [
            'GHS',
            'ганский седи',
        ],
        'GIP' => [
            'GIP',
            'гибралтарский фунт',
        ],
        'GMD' => [
            'GMD',
            'гамбийский даласи',
        ],
        'GNF' => [
            'GNF',
            'гвинейский франк',
        ],
        'GNS' => [
            'GNS',
            'Гвинейская сили',
        ],
        'GQE' => [
            'GQE',
            'Эквеле экваториальной Гвинеи',
        ],
        'GRD' => [
            'GRD',
            'Греческая драхма',
        ],
        'GTQ' => [
            'GTQ',
            'гватемальский кетсаль',
        ],
        'GWE' => [
            'GWE',
            'Эскудо Португальской Гвинеи',
        ],
        'GWP' => [
            'GWP',
            'Песо Гвинеи-Бисау',
        ],
        'GYD' => [
            'GYD',
            'гайанский доллар',
        ],
        'HKD' => [
            'HK$',
            'гонконгский доллар',
        ],
        'HNL' => [
            'HNL',
            'гондурасская лемпира',
        ],
        'HRD' => [
            'HRD',
            'Хорватский динар',
        ],
        'HRK' => [
            'HRK',
            'хорватская куна',
        ],
        'HTG' => [
            'HTG',
            'гаитянский гурд',
        ],
        'HUF' => [
            'HUF',
            'венгерский форинт',
        ],
        'IDR' => [
            'IDR',
            'индонезийская рупия',
        ],
        'IEP' => [
            'IEP',
            'Ирландский фунт',
        ],
        'ILP' => [
            'ILP',
            'Израильский фунт',
        ],
        'ILS' => [
            '₪',
            'новый израильский шекель',
        ],
        'INR' => [
            '₹',
            'индийская рупия',
        ],
        'IQD' => [
            'IQD',
            'иракский динар',
        ],
        'IRR' => [
            'IRR',
            'иранский риал',
        ],
        'ISK' => [
            'ISK',
            'исландская крона',
        ],
        'ITL' => [
            'ITL',
            'Итальянская лира',
        ],
        'JMD' => [
            'JMD',
            'ямайский доллар',
        ],
        'JOD' => [
            'JOD',
            'иорданский динар',
        ],
        'JPY' => [
            '¥',
            'японская иена',
        ],
        'KES' => [
            'KES',
            'кенийский шиллинг',
        ],
        'KGS' => [
            'KGS',
            'киргизский сом',
        ],
        'KHR' => [
            'KHR',
            'камбоджийский риель',
        ],
        'KMF' => [
            'KMF',
            'коморский франк',
        ],
        'KPW' => [
            'KPW',
            'северокорейская вона',
        ],
        'KRW' => [
            '₩',
            'южнокорейская вона',
        ],
        'KWD' => [
            'KWD',
            'кувейтский динар',
        ],
        'KYD' => [
            'KYD',
            'доллар Островов Кайман',
        ],
        'KZT' => [
            'KZT',
            'казахский тенге',
        ],
        'LAK' => [
            'LAK',
            'лаосский кип',
        ],
        'LBP' => [
            'LBP',
            'ливанский фунт',
        ],
        'LKR' => [
            'LKR',
            'шри-ланкийская рупия',
        ],
        'LRD' => [
            'LRD',
            'либерийский доллар',
        ],
        'LSL' => [
            'LSL',
            'лоти',
        ],
        'LTL' => [
            'LTL',
            'Литовский лит',
        ],
        'LTT' => [
            'LTT',
            'Литовский талон',
        ],
        'LUC' => [
            'LUC',
            'Конвертируемый франк Люксембурга',
        ],
        'LUF' => [
            'LUF',
            'Люксембургский франк',
        ],
        'LUL' => [
            'LUL',
            'Финансовый франк Люксембурга',
        ],
        'LVL' => [
            'LVL',
            'Латвийский лат',
        ],
        'LVR' => [
            'LVR',
            'Латвийский рубль',
        ],
        'LYD' => [
            'LYD',
            'ливийский динар',
        ],
        'MAD' => [
            'MAD',
            'марокканский дирхам',
        ],
        'MAF' => [
            'MAF',
            'Марокканский франк',
        ],
        'MDL' => [
            'MDL',
            'молдавский лей',
        ],
        'MGA' => [
            'MGA',
            'малагасийский ариари',
        ],
        'MGF' => [
            'MGF',
            'Малагасийский франк',
        ],
        'MKD' => [
            'MKD',
            'македонский денар',
        ],
        'MLF' => [
            'MLF',
            'Малийский франк',
        ],
        'MMK' => [
            'MMK',
            'мьянманский кьят',
        ],
        'MNT' => [
            'MNT',
            'монгольский тугрик',
        ],
        'MOP' => [
            'MOP',
            'патака Макао',
        ],
        'MRO' => [
            'MRO',
            'мавританская угия (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'мавританская угия',
        ],
        'MTL' => [
            'MTL',
            'Мальтийская лира',
        ],
        'MTP' => [
            'MTP',
            'Мальтийский фунт',
        ],
        'MUR' => [
            'MUR',
            'маврикийская рупия',
        ],
        'MVR' => [
            'MVR',
            'мальдивская руфия',
        ],
        'MWK' => [
            'MWK',
            'малавийская квача',
        ],
        'MXN' => [
            'MX$',
            'мексиканский песо',
        ],
        'MXP' => [
            'MXP',
            'Мексиканское серебряное песо (1861–1992)',
        ],
        'MXV' => [
            'MXV',
            'Мексиканская пересчетная единица (UDI)',
        ],
        'MYR' => [
            'MYR',
            'малайзийский ринггит',
        ],
        'MZE' => [
            'MZE',
            'Мозамбикское эскудо',
        ],
        'MZM' => [
            'MZM',
            'Старый мозамбикский метикал',
        ],
        'MZN' => [
            'MZN',
            'мозамбикский метикал',
        ],
        'NAD' => [
            'NAD',
            'доллар Намибии',
        ],
        'NGN' => [
            'NGN',
            'нигерийская найра',
        ],
        'NIC' => [
            'NIC',
            'Никарагуанская кордоба (1988–1991)',
        ],
        'NIO' => [
            'NIO',
            'никарагуанская кордоба',
        ],
        'NLG' => [
            'NLG',
            'Нидерландский гульден',
        ],
        'NOK' => [
            'NOK',
            'норвежская крона',
        ],
        'NPR' => [
            'NPR',
            'непальская рупия',
        ],
        'NZD' => [
            'NZ$',
            'новозеландский доллар',
        ],
        'OMR' => [
            'OMR',
            'оманский риал',
        ],
        'PAB' => [
            'PAB',
            'панамский бальбоа',
        ],
        'PEI' => [
            'PEI',
            'Перуанское инти',
        ],
        'PEN' => [
            'PEN',
            'перуанский соль',
        ],
        'PES' => [
            'PES',
            'Перуанский соль (1863–1965)',
        ],
        'PGK' => [
            'PGK',
            'кина Папуа – Новой Гвинеи',
        ],
        'PHP' => [
            'PHP',
            'филиппинский песо',
        ],
        'PKR' => [
            'PKR',
            'пакистанская рупия',
        ],
        'PLN' => [
            'PLN',
            'польский злотый',
        ],
        'PLZ' => [
            'PLZ',
            'Злотый',
        ],
        'PTE' => [
            'PTE',
            'Португальское эскудо',
        ],
        'PYG' => [
            'PYG',
            'парагвайский гуарани',
        ],
        'QAR' => [
            'QAR',
            'катарский риал',
        ],
        'RHD' => [
            'RHD',
            'Родезийский доллар',
        ],
        'ROL' => [
            'ROL',
            'Старый Румынский лей',
        ],
        'RON' => [
            'RON',
            'румынский лей',
        ],
        'RSD' => [
            'RSD',
            'сербский динар',
        ],
        'RUB' => [
            '₽',
            'российский рубль',
        ],
        'RUR' => [
            'р.',
            'Российский рубль (1991–1998)',
        ],
        'RWF' => [
            'RWF',
            'франк Руанды',
        ],
        'SAR' => [
            'SAR',
            'саудовский риял',
        ],
        'SBD' => [
            'SBD',
            'доллар Соломоновых Островов',
        ],
        'SCR' => [
            'SCR',
            'сейшельская рупия',
        ],
        'SDD' => [
            'SDD',
            'Суданский динар',
        ],
        'SDG' => [
            'SDG',
            'суданский фунт',
        ],
        'SDP' => [
            'SDP',
            'Старый суданский фунт',
        ],
        'SEK' => [
            'SEK',
            'шведская крона',
        ],
        'SGD' => [
            'SGD',
            'сингапурский доллар',
        ],
        'SHP' => [
            'SHP',
            'фунт острова Святой Елены',
        ],
        'SIT' => [
            'SIT',
            'Словенский толар',
        ],
        'SKK' => [
            'SKK',
            'Словацкая крона',
        ],
        'SLE' => [
            'SLE',
            'леоне',
        ],
        'SLL' => [
            'SLL',
            'леоне (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'сомалийский шиллинг',
        ],
        'SRD' => [
            'SRD',
            'суринамский доллар',
        ],
        'SRG' => [
            'SRG',
            'Суринамский гульден',
        ],
        'SSP' => [
            'SSP',
            'южносуданский фунт',
        ],
        'STD' => [
            'STD',
            'добра Сан-Томе и Принсипи (1977–2017)',
        ],
        'STN' => [
            'STN',
            'добра Сан-Томе и Принсипи',
        ],
        'SUR' => [
            'SUR',
            'Рубль СССР',
        ],
        'SVC' => [
            'SVC',
            'Сальвадорский колон',
        ],
        'SYP' => [
            'SYP',
            'сирийский фунт',
        ],
        'SZL' => [
            'SZL',
            'свазилендский лилангени',
        ],
        'THB' => [
            '฿',
            'таиландский бат',
        ],
        'TJR' => [
            'TJR',
            'Таджикский рубль',
        ],
        'TJS' => [
            'TJS',
            'таджикский сомони',
        ],
        'TMM' => [
            'TMM',
            'Туркменский манат',
        ],
        'TMT' => [
            'ТМТ',
            'новый туркменский манат',
        ],
        'TND' => [
            'TND',
            'тунисский динар',
        ],
        'TOP' => [
            'TOP',
            'тонганская паанга',
        ],
        'TPE' => [
            'TPE',
            'Тиморское эскудо',
        ],
        'TRL' => [
            'TRL',
            'Турецкая лира (1922–2005)',
        ],
        'TRY' => [
            'TRY',
            'турецкая лира',
        ],
        'TTD' => [
            'TTD',
            'доллар Тринидада и Тобаго',
        ],
        'TWD' => [
            'NT$',
            'новый тайваньский доллар',
        ],
        'TZS' => [
            'TZS',
            'танзанийский шиллинг',
        ],
        'UAH' => [
            '₴',
            'украинская гривна',
        ],
        'UAK' => [
            'UAK',
            'Карбованец (украинский)',
        ],
        'UGS' => [
            'UGS',
            'Старый угандийский шиллинг',
        ],
        'UGX' => [
            'UGX',
            'угандийский шиллинг',
        ],
        'USD' => [
            '$',
            'доллар США',
        ],
        'USN' => [
            'USN',
            'Доллар США следующего дня',
        ],
        'USS' => [
            'USS',
            'Доллар США текущего дня',
        ],
        'UYI' => [
            'UYI',
            'Уругвайский песо (индекс инфляции)',
        ],
        'UYP' => [
            'UYP',
            'Уругвайское старое песо (1975–1993)',
        ],
        'UYU' => [
            'UYU',
            'уругвайский песо',
        ],
        'UZS' => [
            'UZS',
            'узбекский сум',
        ],
        'VEB' => [
            'VEB',
            'Венесуэльский боливар (1871–2008)',
        ],
        'VEF' => [
            'VEF',
            'венесуэльский боливар (2008–2018)',
        ],
        'VES' => [
            'VES',
            'венесуэльский боливар',
        ],
        'VND' => [
            '₫',
            'вьетнамский донг',
        ],
        'VUV' => [
            'VUV',
            'вату Вануату',
        ],
        'WST' => [
            'WST',
            'самоанская тала',
        ],
        'XAF' => [
            'FCFA',
            'франк КФА BEAC',
        ],
        'XCD' => [
            'EC$',
            'восточно-карибский доллар',
        ],
        'XCG' => [
            'Cg',
            'карибский гульден',
        ],
        'XEU' => [
            'XEU',
            'ЭКЮ (единица европейской валюты)',
        ],
        'XFO' => [
            'XFO',
            'Французский золотой франк',
        ],
        'XFU' => [
            'XFU',
            'Французский UIC-франк',
        ],
        'XOF' => [
            'F CFA',
            'франк КФА ВСЕАО',
        ],
        'XPF' => [
            'CFPF',
            'французский тихоокеанский франк',
        ],
        'XRE' => [
            'XRE',
            'единица RINET-фондов',
        ],
        'YDD' => [
            'YDD',
            'Йеменский динар',
        ],
        'YER' => [
            'YER',
            'йеменский риал',
        ],
        'YUD' => [
            'YUD',
            'Югославский твердый динар',
        ],
        'YUM' => [
            'YUM',
            'Югославский новый динар',
        ],
        'YUN' => [
            'YUN',
            'Югославский динар',
        ],
        'ZAL' => [
            'ZAL',
            'Южноафриканский рэнд (финансовый)',
        ],
        'ZAR' => [
            'ZAR',
            'южноафриканский рэнд',
        ],
        'ZMK' => [
            'ZMK',
            'Квача (замбийская) (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'замбийская квача',
        ],
        'ZRN' => [
            'ZRN',
            'Новый заир',
        ],
        'ZRZ' => [
            'ZRZ',
            'Заир',
        ],
        'ZWD' => [
            'ZWD',
            'Доллар Зимбабве',
        ],
        'ZWG' => [
            'ZWG',
            'зимбабвийский золотой',
        ],
        'ZWL' => [
            'ZWL',
            'Доллар Зимбабве (2009)',
        ],
    ],
];
