<?php

return [
    'Names' => [
        'af' => '南非荷蘭文',
        'af_NA' => '南非荷蘭文（納米比亞）',
        'af_ZA' => '南非荷蘭文（南非）',
        'ak' => '阿坎文',
        'ak_GH' => '阿坎文（迦納）',
        'am' => '阿姆哈拉文',
        'am_ET' => '阿姆哈拉文（衣索比亞）',
        'ar' => '阿拉伯文',
        'ar_001' => '阿拉伯文（世界）',
        'ar_AE' => '阿拉伯文（阿拉伯聯合大公國）',
        'ar_BH' => '阿拉伯文（巴林）',
        'ar_DJ' => '阿拉伯文（吉布地）',
        'ar_DZ' => '阿拉伯文（阿爾及利亞）',
        'ar_EG' => '阿拉伯文（埃及）',
        'ar_EH' => '阿拉伯文（西撒哈拉）',
        'ar_ER' => '阿拉伯文（厄利垂亞）',
        'ar_IL' => '阿拉伯文（以色列）',
        'ar_IQ' => '阿拉伯文（伊拉克）',
        'ar_JO' => '阿拉伯文（約旦）',
        'ar_KM' => '阿拉伯文（葛摩）',
        'ar_KW' => '阿拉伯文（科威特）',
        'ar_LB' => '阿拉伯文（黎巴嫩）',
        'ar_LY' => '阿拉伯文（利比亞）',
        'ar_MA' => '阿拉伯文（摩洛哥）',
        'ar_MR' => '阿拉伯文（茅利塔尼亞）',
        'ar_OM' => '阿拉伯文（阿曼）',
        'ar_PS' => '阿拉伯文（巴勒斯坦自治區）',
        'ar_QA' => '阿拉伯文（卡達）',
        'ar_SA' => '阿拉伯文（沙烏地阿拉伯）',
        'ar_SD' => '阿拉伯文（蘇丹）',
        'ar_SO' => '阿拉伯文（索馬利亞）',
        'ar_SS' => '阿拉伯文（南蘇丹）',
        'ar_SY' => '阿拉伯文（敘利亞）',
        'ar_TD' => '阿拉伯文（查德）',
        'ar_TN' => '阿拉伯文（突尼西亞）',
        'ar_YE' => '阿拉伯文（葉門）',
        'as' => '阿薩姆文',
        'as_IN' => '阿薩姆文（印度）',
        'az' => '亞塞拜然文',
        'az_AZ' => '亞塞拜然文（亞塞拜然）',
        'az_Cyrl' => '亞塞拜然文（西里爾文字）',
        'az_Cyrl_AZ' => '亞塞拜然文（西里爾文字，亞塞拜然）',
        'az_Latn' => '亞塞拜然文（拉丁字母）',
        'az_Latn_AZ' => '亞塞拜然文（拉丁字母，亞塞拜然）',
        'ba' => '巴什喀爾文',
        'ba_RU' => '巴什喀爾文（俄羅斯）',
        'be' => '白俄羅斯文',
        'be_BY' => '白俄羅斯文（白俄羅斯）',
        'bg' => '保加利亞文',
        'bg_BG' => '保加利亞文（保加利亞）',
        'bm' => '班巴拉文',
        'bm_ML' => '班巴拉文（馬利）',
        'bn' => '孟加拉文',
        'bn_BD' => '孟加拉文（孟加拉）',
        'bn_IN' => '孟加拉文（印度）',
        'bo' => '藏文',
        'bo_CN' => '藏文（中國）',
        'bo_IN' => '藏文（印度）',
        'br' => '布列塔尼文',
        'br_FR' => '布列塔尼文（法國）',
        'bs' => '波士尼亞文',
        'bs_BA' => '波士尼亞文（波士尼亞與赫塞哥維納）',
        'bs_Cyrl' => '波士尼亞文（西里爾文字）',
        'bs_Cyrl_BA' => '波士尼亞文（西里爾文字，波士尼亞與赫塞哥維納）',
        'bs_Latn' => '波士尼亞文（拉丁字母）',
        'bs_Latn_BA' => '波士尼亞文（拉丁字母，波士尼亞與赫塞哥維納）',
        'ca' => '加泰蘭文',
        'ca_AD' => '加泰蘭文（安道爾）',
        'ca_ES' => '加泰蘭文（西班牙）',
        'ca_FR' => '加泰蘭文（法國）',
        'ca_IT' => '加泰蘭文（義大利）',
        'ce' => '車臣文',
        'ce_RU' => '車臣文（俄羅斯）',
        'cs' => '捷克文',
        'cs_CZ' => '捷克文（捷克）',
        'cv' => '楚瓦什文',
        'cv_RU' => '楚瓦什文（俄羅斯）',
        'cy' => '威爾斯文',
        'cy_GB' => '威爾斯文（英國）',
        'da' => '丹麥文',
        'da_DK' => '丹麥文（丹麥）',
        'da_GL' => '丹麥文（格陵蘭）',
        'de' => '德文',
        'de_AT' => '德文（奧地利）',
        'de_BE' => '德文（比利時）',
        'de_CH' => '德文（瑞士）',
        'de_DE' => '德文（德國）',
        'de_IT' => '德文（義大利）',
        'de_LI' => '德文（列支敦斯登）',
        'de_LU' => '德文（盧森堡）',
        'dz' => '宗卡文',
        'dz_BT' => '宗卡文（不丹）',
        'ee' => '埃維文',
        'ee_GH' => '埃維文（迦納）',
        'ee_TG' => '埃維文（多哥）',
        'el' => '希臘文',
        'el_CY' => '希臘文（賽普勒斯）',
        'el_GR' => '希臘文（希臘）',
        'en' => '英文',
        'en_001' => '英文（世界）',
        'en_150' => '英文（歐洲）',
        'en_AE' => '英文（阿拉伯聯合大公國）',
        'en_AG' => '英文（安地卡及巴布達）',
        'en_AI' => '英文（安奎拉）',
        'en_AS' => '英文（美屬薩摩亞）',
        'en_AT' => '英文（奧地利）',
        'en_AU' => '英文（澳洲）',
        'en_BB' => '英文（巴貝多）',
        'en_BE' => '英文（比利時）',
        'en_BI' => '英文（蒲隆地）',
        'en_BM' => '英文（百慕達）',
        'en_BS' => '英文（巴哈馬）',
        'en_BW' => '英文（波札那）',
        'en_BZ' => '英文（貝里斯）',
        'en_CA' => '英文（加拿大）',
        'en_CC' => '英文（科克斯（基靈）群島）',
        'en_CH' => '英文（瑞士）',
        'en_CK' => '英文（庫克群島）',
        'en_CM' => '英文（喀麥隆）',
        'en_CX' => '英文（聖誕島）',
        'en_CY' => '英文（賽普勒斯）',
        'en_CZ' => '英文（捷克）',
        'en_DE' => '英文（德國）',
        'en_DK' => '英文（丹麥）',
        'en_DM' => '英文（多米尼克）',
        'en_EE' => '英文（愛沙尼亞）',
        'en_ER' => '英文（厄利垂亞）',
        'en_ES' => '英文（西班牙）',
        'en_FI' => '英文（芬蘭）',
        'en_FJ' => '英文（斐濟）',
        'en_FK' => '英文（福克蘭群島）',
        'en_FM' => '英文（密克羅尼西亞）',
        'en_FR' => '英文（法國）',
        'en_GB' => '英文（英國）',
        'en_GD' => '英文（格瑞那達）',
        'en_GE' => '英文（喬治亞）',
        'en_GG' => '英文（根息）',
        'en_GH' => '英文（迦納）',
        'en_GI' => '英文（直布羅陀）',
        'en_GM' => '英文（甘比亞）',
        'en_GS' => '英文（南喬治亞與南三明治群島）',
        'en_GU' => '英文（關島）',
        'en_GY' => '英文（蓋亞那）',
        'en_HK' => '英文（中國香港特別行政區）',
        'en_HU' => '英文（匈牙利）',
        'en_ID' => '英文（印尼）',
        'en_IE' => '英文（愛爾蘭）',
        'en_IL' => '英文（以色列）',
        'en_IM' => '英文（曼島）',
        'en_IN' => '英文（印度）',
        'en_IO' => '英文（英屬印度洋領地）',
        'en_IT' => '英文（義大利）',
        'en_JE' => '英文（澤西島）',
        'en_JM' => '英文（牙買加）',
        'en_JP' => '英文（日本）',
        'en_KE' => '英文（肯亞）',
        'en_KI' => '英文（吉里巴斯）',
        'en_KN' => '英文（聖克里斯多福及尼維斯）',
        'en_KY' => '英文（開曼群島）',
        'en_LC' => '英文（聖露西亞）',
        'en_LR' => '英文（賴比瑞亞）',
        'en_LS' => '英文（賴索托）',
        'en_LT' => '英文（立陶宛）',
        'en_LV' => '英文（拉脫維亞）',
        'en_MG' => '英文（馬達加斯加）',
        'en_MH' => '英文（馬紹爾群島）',
        'en_MO' => '英文（中國澳門特別行政區）',
        'en_MP' => '英文（北馬利安納群島）',
        'en_MS' => '英文（蒙哲臘）',
        'en_MT' => '英文（馬爾他）',
        'en_MU' => '英文（模里西斯）',
        'en_MV' => '英文（馬爾地夫）',
        'en_MW' => '英文（馬拉威）',
        'en_MY' => '英文（馬來西亞）',
        'en_NA' => '英文（納米比亞）',
        'en_NF' => '英文（諾福克島）',
        'en_NG' => '英文（奈及利亞）',
        'en_NL' => '英文（荷蘭）',
        'en_NO' => '英文（挪威）',
        'en_NR' => '英文（諾魯）',
        'en_NU' => '英文（紐埃島）',
        'en_NZ' => '英文（紐西蘭）',
        'en_PG' => '英文（巴布亞紐幾內亞）',
        'en_PH' => '英文（菲律賓）',
        'en_PK' => '英文（巴基斯坦）',
        'en_PL' => '英文（波蘭）',
        'en_PN' => '英文（皮特肯群島）',
        'en_PR' => '英文（波多黎各）',
        'en_PT' => '英文（葡萄牙）',
        'en_PW' => '英文（帛琉）',
        'en_RO' => '英文（羅馬尼亞）',
        'en_RW' => '英文（盧安達）',
        'en_SB' => '英文（索羅門群島）',
        'en_SC' => '英文（塞席爾）',
        'en_SD' => '英文（蘇丹）',
        'en_SE' => '英文（瑞典）',
        'en_SG' => '英文（新加坡）',
        'en_SH' => '英文（聖赫勒拿島）',
        'en_SI' => '英文（斯洛維尼亞）',
        'en_SK' => '英文（斯洛伐克）',
        'en_SL' => '英文（獅子山）',
        'en_SS' => '英文（南蘇丹）',
        'en_SX' => '英文（荷屬聖馬丁）',
        'en_SZ' => '英文（史瓦帝尼）',
        'en_TC' => '英文（土克斯及開科斯群島）',
        'en_TK' => '英文（托克勞群島）',
        'en_TO' => '英文（東加）',
        'en_TT' => '英文（千里達及托巴哥）',
        'en_TV' => '英文（吐瓦魯）',
        'en_TZ' => '英文（坦尚尼亞）',
        'en_UA' => '英文（烏克蘭）',
        'en_UG' => '英文（烏干達）',
        'en_UM' => '英文（美國本土外小島嶼）',
        'en_US' => '英文（美國）',
        'en_VC' => '英文（聖文森及格瑞那丁）',
        'en_VG' => '英文（英屬維京群島）',
        'en_VI' => '英文（美屬維京群島）',
        'en_VU' => '英文（萬那杜）',
        'en_WS' => '英文（薩摩亞）',
        'en_ZA' => '英文（南非）',
        'en_ZM' => '英文（尚比亞）',
        'en_ZW' => '英文（辛巴威）',
        'eo' => '世界文',
        'eo_001' => '世界文（世界）',
        'es' => '西班牙文',
        'es_419' => '西班牙文（拉丁美洲）',
        'es_AR' => '西班牙文（阿根廷）',
        'es_BO' => '西班牙文（玻利維亞）',
        'es_BR' => '西班牙文（巴西）',
        'es_BZ' => '西班牙文（貝里斯）',
        'es_CL' => '西班牙文（智利）',
        'es_CO' => '西班牙文（哥倫比亞）',
        'es_CR' => '西班牙文（哥斯大黎加）',
        'es_CU' => '西班牙文（古巴）',
        'es_DO' => '西班牙文（多明尼加共和國）',
        'es_EC' => '西班牙文（厄瓜多）',
        'es_ES' => '西班牙文（西班牙）',
        'es_GQ' => '西班牙文（赤道幾內亞）',
        'es_GT' => '西班牙文（瓜地馬拉）',
        'es_HN' => '西班牙文（宏都拉斯）',
        'es_MX' => '西班牙文（墨西哥）',
        'es_NI' => '西班牙文（尼加拉瓜）',
        'es_PA' => '西班牙文（巴拿馬）',
        'es_PE' => '西班牙文（秘魯）',
        'es_PH' => '西班牙文（菲律賓）',
        'es_PR' => '西班牙文（波多黎各）',
        'es_PY' => '西班牙文（巴拉圭）',
        'es_SV' => '西班牙文（薩爾瓦多）',
        'es_US' => '西班牙文（美國）',
        'es_UY' => '西班牙文（烏拉圭）',
        'es_VE' => '西班牙文（委內瑞拉）',
        'et' => '愛沙尼亞文',
        'et_EE' => '愛沙尼亞文（愛沙尼亞）',
        'eu' => '巴斯克文',
        'eu_ES' => '巴斯克文（西班牙）',
        'fa' => '波斯文',
        'fa_AF' => '波斯文（阿富汗）',
        'fa_IR' => '波斯文（伊朗）',
        'ff' => '富拉文',
        'ff_Adlm' => '富拉文（富拉文）',
        'ff_Adlm_BF' => '富拉文（富拉文，布吉納法索）',
        'ff_Adlm_CM' => '富拉文（富拉文，喀麥隆）',
        'ff_Adlm_GH' => '富拉文（富拉文，迦納）',
        'ff_Adlm_GM' => '富拉文（富拉文，甘比亞）',
        'ff_Adlm_GN' => '富拉文（富拉文，幾內亞）',
        'ff_Adlm_GW' => '富拉文（富拉文，幾內亞比索）',
        'ff_Adlm_LR' => '富拉文（富拉文，賴比瑞亞）',
        'ff_Adlm_MR' => '富拉文（富拉文，茅利塔尼亞）',
        'ff_Adlm_NE' => '富拉文（富拉文，尼日）',
        'ff_Adlm_NG' => '富拉文（富拉文，奈及利亞）',
        'ff_Adlm_SL' => '富拉文（富拉文，獅子山）',
        'ff_Adlm_SN' => '富拉文（富拉文，塞內加爾）',
        'ff_CM' => '富拉文（喀麥隆）',
        'ff_GN' => '富拉文（幾內亞）',
        'ff_Latn' => '富拉文（拉丁字母）',
        'ff_Latn_BF' => '富拉文（拉丁字母，布吉納法索）',
        'ff_Latn_CM' => '富拉文（拉丁字母，喀麥隆）',
        'ff_Latn_GH' => '富拉文（拉丁字母，迦納）',
        'ff_Latn_GM' => '富拉文（拉丁字母，甘比亞）',
        'ff_Latn_GN' => '富拉文（拉丁字母，幾內亞）',
        'ff_Latn_GW' => '富拉文（拉丁字母，幾內亞比索）',
        'ff_Latn_LR' => '富拉文（拉丁字母，賴比瑞亞）',
        'ff_Latn_MR' => '富拉文（拉丁字母，茅利塔尼亞）',
        'ff_Latn_NE' => '富拉文（拉丁字母，尼日）',
        'ff_Latn_NG' => '富拉文（拉丁字母，奈及利亞）',
        'ff_Latn_SL' => '富拉文（拉丁字母，獅子山）',
        'ff_Latn_SN' => '富拉文（拉丁字母，塞內加爾）',
        'ff_MR' => '富拉文（茅利塔尼亞）',
        'ff_SN' => '富拉文（塞內加爾）',
        'fi' => '芬蘭文',
        'fi_FI' => '芬蘭文（芬蘭）',
        'fo' => '法羅文',
        'fo_DK' => '法羅文（丹麥）',
        'fo_FO' => '法羅文（法羅群島）',
        'fr' => '法文',
        'fr_BE' => '法文（比利時）',
        'fr_BF' => '法文（布吉納法索）',
        'fr_BI' => '法文（蒲隆地）',
        'fr_BJ' => '法文（貝南）',
        'fr_BL' => '法文（聖巴瑟米）',
        'fr_CA' => '法文（加拿大）',
        'fr_CD' => '法文（剛果（金夏沙））',
        'fr_CF' => '法文（中非共和國）',
        'fr_CG' => '法文（剛果（布拉薩））',
        'fr_CH' => '法文（瑞士）',
        'fr_CI' => '法文（象牙海岸）',
        'fr_CM' => '法文（喀麥隆）',
        'fr_DJ' => '法文（吉布地）',
        'fr_DZ' => '法文（阿爾及利亞）',
        'fr_FR' => '法文（法國）',
        'fr_GA' => '法文（加彭）',
        'fr_GF' => '法文（法屬圭亞那）',
        'fr_GN' => '法文（幾內亞）',
        'fr_GP' => '法文（瓜地洛普）',
        'fr_GQ' => '法文（赤道幾內亞）',
        'fr_HT' => '法文（海地）',
        'fr_KM' => '法文（葛摩）',
        'fr_LU' => '法文（盧森堡）',
        'fr_MA' => '法文（摩洛哥）',
        'fr_MC' => '法文（摩納哥）',
        'fr_MF' => '法文（法屬聖馬丁）',
        'fr_MG' => '法文（馬達加斯加）',
        'fr_ML' => '法文（馬利）',
        'fr_MQ' => '法文（馬丁尼克）',
        'fr_MR' => '法文（茅利塔尼亞）',
        'fr_MU' => '法文（模里西斯）',
        'fr_NC' => '法文（新喀里多尼亞）',
        'fr_NE' => '法文（尼日）',
        'fr_PF' => '法文（法屬玻里尼西亞）',
        'fr_PM' => '法文（聖皮埃與密克隆群島）',
        'fr_RE' => '法文（留尼旺）',
        'fr_RW' => '法文（盧安達）',
        'fr_SC' => '法文（塞席爾）',
        'fr_SN' => '法文（塞內加爾）',
        'fr_SY' => '法文（敘利亞）',
        'fr_TD' => '法文（查德）',
        'fr_TG' => '法文（多哥）',
        'fr_TN' => '法文（突尼西亞）',
        'fr_VU' => '法文（萬那杜）',
        'fr_WF' => '法文（瓦利斯群島和富圖那群島）',
        'fr_YT' => '法文（馬約特島）',
        'fy' => '西弗里西亞文',
        'fy_NL' => '西弗里西亞文（荷蘭）',
        'ga' => '愛爾蘭文',
        'ga_GB' => '愛爾蘭文（英國）',
        'ga_IE' => '愛爾蘭文（愛爾蘭）',
        'gd' => '蘇格蘭蓋爾文',
        'gd_GB' => '蘇格蘭蓋爾文（英國）',
        'gl' => '加利西亞文',
        'gl_ES' => '加利西亞文（西班牙）',
        'gu' => '古吉拉特文',
        'gu_IN' => '古吉拉特文（印度）',
        'gv' => '曼島文',
        'gv_IM' => '曼島文（曼島）',
        'ha' => '豪薩文',
        'ha_GH' => '豪薩文（迦納）',
        'ha_NE' => '豪薩文（尼日）',
        'ha_NG' => '豪薩文（奈及利亞）',
        'he' => '希伯來文',
        'he_IL' => '希伯來文（以色列）',
        'hi' => '印地文',
        'hi_IN' => '印地文（印度）',
        'hi_Latn' => '印地文（拉丁字母）',
        'hi_Latn_IN' => '印地文（拉丁字母，印度）',
        'hr' => '克羅埃西亞文',
        'hr_BA' => '克羅埃西亞文（波士尼亞與赫塞哥維納）',
        'hr_HR' => '克羅埃西亞文（克羅埃西亞）',
        'hu' => '匈牙利文',
        'hu_HU' => '匈牙利文（匈牙利）',
        'hy' => '亞美尼亞文',
        'hy_AM' => '亞美尼亞文（亞美尼亞）',
        'ia' => '國際文',
        'ia_001' => '國際文（世界）',
        'id' => '印尼文',
        'id_ID' => '印尼文（印尼）',
        'ie' => '國際文（E）',
        'ie_EE' => '國際文（E）（愛沙尼亞）',
        'ig' => '伊布文',
        'ig_NG' => '伊布文（奈及利亞）',
        'ii' => '四川彝文',
        'ii_CN' => '四川彝文（中國）',
        'is' => '冰島文',
        'is_IS' => '冰島文（冰島）',
        'it' => '義大利文',
        'it_CH' => '義大利文（瑞士）',
        'it_IT' => '義大利文（義大利）',
        'it_SM' => '義大利文（聖馬利諾）',
        'it_VA' => '義大利文（梵蒂岡）',
        'ja' => '日文',
        'ja_JP' => '日文（日本）',
        'jv' => '爪哇文',
        'jv_ID' => '爪哇文（印尼）',
        'ka' => '喬治亞文',
        'ka_GE' => '喬治亞文（喬治亞）',
        'ki' => '吉庫尤文',
        'ki_KE' => '吉庫尤文（肯亞）',
        'kk' => '哈薩克文',
        'kk_Arab' => '哈薩克文（阿拉伯字母）',
        'kk_Arab_CN' => '哈薩克文（阿拉伯字母，中國）',
        'kk_Cyrl' => '哈薩克文（西里爾文字）',
        'kk_Cyrl_KZ' => '哈薩克文（西里爾文字，哈薩克）',
        'kk_KZ' => '哈薩克文（哈薩克）',
        'kl' => '格陵蘭文',
        'kl_GL' => '格陵蘭文（格陵蘭）',
        'km' => '高棉文',
        'km_KH' => '高棉文（柬埔寨）',
        'kn' => '坎那達文',
        'kn_IN' => '坎那達文（印度）',
        'ko' => '韓文',
        'ko_CN' => '韓文（中國）',
        'ko_KP' => '韓文（北韓）',
        'ko_KR' => '韓文（南韓）',
        'ks' => '喀什米爾文',
        'ks_Arab' => '喀什米爾文（阿拉伯字母）',
        'ks_Arab_IN' => '喀什米爾文（阿拉伯字母，印度）',
        'ks_Deva' => '喀什米爾文（天城文）',
        'ks_Deva_IN' => '喀什米爾文（天城文，印度）',
        'ks_IN' => '喀什米爾文（印度）',
        'ku' => '庫德文',
        'ku_Latn' => '庫德文（拉丁字母）',
        'ku_Latn_IQ' => '庫德文（拉丁字母，伊拉克）',
        'ku_Latn_SY' => '庫德文（拉丁字母，敘利亞）',
        'ku_Latn_TR' => '庫德文（拉丁字母，土耳其）',
        'ku_SY' => '庫德文（敘利亞）',
        'ku_TR' => '庫德文（土耳其）',
        'kw' => '康瓦耳文',
        'kw_GB' => '康瓦耳文（英國）',
        'ky' => '吉爾吉斯文',
        'ky_KG' => '吉爾吉斯文（吉爾吉斯）',
        'lb' => '盧森堡文',
        'lb_LU' => '盧森堡文（盧森堡）',
        'lg' => '干達文',
        'lg_UG' => '干達文（烏干達）',
        'ln' => '林加拉文',
        'ln_AO' => '林加拉文（安哥拉）',
        'ln_CD' => '林加拉文（剛果（金夏沙））',
        'ln_CF' => '林加拉文（中非共和國）',
        'ln_CG' => '林加拉文（剛果（布拉薩））',
        'lo' => '寮文',
        'lo_LA' => '寮文（寮國）',
        'lt' => '立陶宛文',
        'lt_LT' => '立陶宛文（立陶宛）',
        'lu' => '魯巴加丹加文',
        'lu_CD' => '魯巴加丹加文（剛果（金夏沙））',
        'lv' => '拉脫維亞文',
        'lv_LV' => '拉脫維亞文（拉脫維亞）',
        'mg' => '馬達加斯加文',
        'mg_MG' => '馬達加斯加文（馬達加斯加）',
        'mi' => '毛利文',
        'mi_NZ' => '毛利文（紐西蘭）',
        'mk' => '馬其頓文',
        'mk_MK' => '馬其頓文（北馬其頓）',
        'ml' => '馬來亞拉姆文',
        'ml_IN' => '馬來亞拉姆文（印度）',
        'mn' => '蒙古文',
        'mn_MN' => '蒙古文（蒙古）',
        'mr' => '馬拉地文',
        'mr_IN' => '馬拉地文（印度）',
        'ms' => '馬來文',
        'ms_BN' => '馬來文（汶萊）',
        'ms_ID' => '馬來文（印尼）',
        'ms_MY' => '馬來文（馬來西亞）',
        'ms_SG' => '馬來文（新加坡）',
        'mt' => '馬爾他文',
        'mt_MT' => '馬爾他文（馬爾他）',
        'my' => '緬甸文',
        'my_MM' => '緬甸文（緬甸）',
        'nb' => '書面挪威文',
        'nb_NO' => '書面挪威文（挪威）',
        'nb_SJ' => '書面挪威文（挪威屬斯瓦巴及尖棉）',
        'nd' => '北地畢列文',
        'nd_ZW' => '北地畢列文（辛巴威）',
        'ne' => '尼泊爾文',
        'ne_IN' => '尼泊爾文（印度）',
        'ne_NP' => '尼泊爾文（尼泊爾）',
        'nl' => '荷蘭文',
        'nl_AW' => '荷蘭文（荷屬阿魯巴）',
        'nl_BE' => '荷蘭文（比利時）',
        'nl_BQ' => '荷蘭文（荷蘭加勒比區）',
        'nl_CW' => '荷蘭文（庫拉索）',
        'nl_NL' => '荷蘭文（荷蘭）',
        'nl_SR' => '荷蘭文（蘇利南）',
        'nl_SX' => '荷蘭文（荷屬聖馬丁）',
        'nn' => '新挪威文',
        'nn_NO' => '新挪威文（挪威）',
        'no' => '挪威文',
        'no_NO' => '挪威文（挪威）',
        'oc' => '奧克西坦文',
        'oc_ES' => '奧克西坦文（西班牙）',
        'oc_FR' => '奧克西坦文（法國）',
        'om' => '奧羅莫文',
        'om_ET' => '奧羅莫文（衣索比亞）',
        'om_KE' => '奧羅莫文（肯亞）',
        'or' => '歐迪亞文',
        'or_IN' => '歐迪亞文（印度）',
        'os' => '奧塞提文',
        'os_GE' => '奧塞提文（喬治亞）',
        'os_RU' => '奧塞提文（俄羅斯）',
        'pa' => '旁遮普文',
        'pa_Arab' => '旁遮普文（阿拉伯字母）',
        'pa_Arab_PK' => '旁遮普文（阿拉伯字母，巴基斯坦）',
        'pa_Guru' => '旁遮普文（古魯穆奇文）',
        'pa_Guru_IN' => '旁遮普文（古魯穆奇文，印度）',
        'pa_IN' => '旁遮普文（印度）',
        'pa_PK' => '旁遮普文（巴基斯坦）',
        'pl' => '波蘭文',
        'pl_PL' => '波蘭文（波蘭）',
        'ps' => '普什圖文',
        'ps_AF' => '普什圖文（阿富汗）',
        'ps_PK' => '普什圖文（巴基斯坦）',
        'pt' => '葡萄牙文',
        'pt_AO' => '葡萄牙文（安哥拉）',
        'pt_BR' => '葡萄牙文（巴西）',
        'pt_CH' => '葡萄牙文（瑞士）',
        'pt_CV' => '葡萄牙文（維德角）',
        'pt_GQ' => '葡萄牙文（赤道幾內亞）',
        'pt_GW' => '葡萄牙文（幾內亞比索）',
        'pt_LU' => '葡萄牙文（盧森堡）',
        'pt_MO' => '葡萄牙文（中國澳門特別行政區）',
        'pt_MZ' => '葡萄牙文（莫三比克）',
        'pt_PT' => '葡萄牙文（葡萄牙）',
        'pt_ST' => '葡萄牙文（聖多美普林西比）',
        'pt_TL' => '葡萄牙文（東帝汶）',
        'qu' => '蓋楚瓦文',
        'qu_BO' => '蓋楚瓦文（玻利維亞）',
        'qu_EC' => '蓋楚瓦文（厄瓜多）',
        'qu_PE' => '蓋楚瓦文（秘魯）',
        'rm' => '羅曼斯文',
        'rm_CH' => '羅曼斯文（瑞士）',
        'rn' => '隆迪文',
        'rn_BI' => '隆迪文（蒲隆地）',
        'ro' => '羅馬尼亞文',
        'ro_MD' => '羅馬尼亞文（摩爾多瓦）',
        'ro_RO' => '羅馬尼亞文（羅馬尼亞）',
        'ru' => '俄文',
        'ru_BY' => '俄文（白俄羅斯）',
        'ru_KG' => '俄文（吉爾吉斯）',
        'ru_KZ' => '俄文（哈薩克）',
        'ru_MD' => '俄文（摩爾多瓦）',
        'ru_RU' => '俄文（俄羅斯）',
        'ru_UA' => '俄文（烏克蘭）',
        'rw' => '盧安達文',
        'rw_RW' => '盧安達文（盧安達）',
        'sa' => '梵文',
        'sa_IN' => '梵文（印度）',
        'sc' => '撒丁文',
        'sc_IT' => '撒丁文（義大利）',
        'sd' => '信德文',
        'sd_Arab' => '信德文（阿拉伯字母）',
        'sd_Arab_PK' => '信德文（阿拉伯字母，巴基斯坦）',
        'sd_Deva' => '信德文（天城文）',
        'sd_Deva_IN' => '信德文（天城文，印度）',
        'sd_IN' => '信德文（印度）',
        'sd_PK' => '信德文（巴基斯坦）',
        'se' => '北薩米文',
        'se_FI' => '北薩米文（芬蘭）',
        'se_NO' => '北薩米文（挪威）',
        'se_SE' => '北薩米文（瑞典）',
        'sg' => '桑戈文',
        'sg_CF' => '桑戈文（中非共和國）',
        'sh' => '塞爾維亞克羅埃西亞文',
        'sh_BA' => '塞爾維亞克羅埃西亞文（波士尼亞與赫塞哥維納）',
        'si' => '僧伽羅文',
        'si_LK' => '僧伽羅文（斯里蘭卡）',
        'sk' => '斯洛伐克文',
        'sk_SK' => '斯洛伐克文（斯洛伐克）',
        'sl' => '斯洛維尼亞文',
        'sl_SI' => '斯洛維尼亞文（斯洛維尼亞）',
        'sn' => '紹納文',
        'sn_ZW' => '紹納文（辛巴威）',
        'so' => '索馬利文',
        'so_DJ' => '索馬利文（吉布地）',
        'so_ET' => '索馬利文（衣索比亞）',
        'so_KE' => '索馬利文（肯亞）',
        'so_SO' => '索馬利文（索馬利亞）',
        'sq' => '阿爾巴尼亞文',
        'sq_AL' => '阿爾巴尼亞文（阿爾巴尼亞）',
        'sq_MK' => '阿爾巴尼亞文（北馬其頓）',
        'sr' => '塞爾維亞文',
        'sr_BA' => '塞爾維亞文（波士尼亞與赫塞哥維納）',
        'sr_Cyrl' => '塞爾維亞文（西里爾文字）',
        'sr_Cyrl_BA' => '塞爾維亞文（西里爾文字，波士尼亞與赫塞哥維納）',
        'sr_Cyrl_ME' => '塞爾維亞文（西里爾文字，蒙特內哥羅）',
        'sr_Cyrl_RS' => '塞爾維亞文（西里爾文字，塞爾維亞）',
        'sr_Latn' => '塞爾維亞文（拉丁字母）',
        'sr_Latn_BA' => '塞爾維亞文（拉丁字母，波士尼亞與赫塞哥維納）',
        'sr_Latn_ME' => '塞爾維亞文（拉丁字母，蒙特內哥羅）',
        'sr_Latn_RS' => '塞爾維亞文（拉丁字母，塞爾維亞）',
        'sr_ME' => '塞爾維亞文（蒙特內哥羅）',
        'sr_RS' => '塞爾維亞文（塞爾維亞）',
        'st' => '塞索托文',
        'st_LS' => '塞索托文（賴索托）',
        'st_ZA' => '塞索托文（南非）',
        'su' => '巽他文',
        'su_ID' => '巽他文（印尼）',
        'su_Latn' => '巽他文（拉丁字母）',
        'su_Latn_ID' => '巽他文（拉丁字母，印尼）',
        'sv' => '瑞典文',
        'sv_AX' => '瑞典文（奧蘭群島）',
        'sv_FI' => '瑞典文（芬蘭）',
        'sv_SE' => '瑞典文（瑞典）',
        'sw' => '史瓦希里文',
        'sw_CD' => '史瓦希里文（剛果（金夏沙））',
        'sw_KE' => '史瓦希里文（肯亞）',
        'sw_TZ' => '史瓦希里文（坦尚尼亞）',
        'sw_UG' => '史瓦希里文（烏干達）',
        'ta' => '坦米爾文',
        'ta_IN' => '坦米爾文（印度）',
        'ta_LK' => '坦米爾文（斯里蘭卡）',
        'ta_MY' => '坦米爾文（馬來西亞）',
        'ta_SG' => '坦米爾文（新加坡）',
        'te' => '泰盧固文',
        'te_IN' => '泰盧固文（印度）',
        'tg' => '塔吉克文',
        'tg_TJ' => '塔吉克文（塔吉克）',
        'th' => '泰文',
        'th_TH' => '泰文（泰國）',
        'ti' => '提格利尼亞文',
        'ti_ER' => '提格利尼亞文（厄利垂亞）',
        'ti_ET' => '提格利尼亞文（衣索比亞）',
        'tk' => '土庫曼文',
        'tk_TM' => '土庫曼文（土庫曼）',
        'tl' => '他加祿文',
        'tl_PH' => '他加祿文（菲律賓）',
        'tn' => '塞茲瓦納文',
        'tn_BW' => '塞茲瓦納文（波札那）',
        'tn_ZA' => '塞茲瓦納文（南非）',
        'to' => '東加文',
        'to_TO' => '東加文（東加）',
        'tr' => '土耳其文',
        'tr_CY' => '土耳其文（賽普勒斯）',
        'tr_TR' => '土耳其文（土耳其）',
        'tt' => '韃靼文',
        'tt_RU' => '韃靼文（俄羅斯）',
        'ug' => '維吾爾文',
        'ug_CN' => '維吾爾文（中國）',
        'uk' => '烏克蘭文',
        'uk_UA' => '烏克蘭文（烏克蘭）',
        'ur' => '烏都文',
        'ur_IN' => '烏都文（印度）',
        'ur_PK' => '烏都文（巴基斯坦）',
        'uz' => '烏茲別克文',
        'uz_AF' => '烏茲別克文（阿富汗）',
        'uz_Arab' => '烏茲別克文（阿拉伯字母）',
        'uz_Arab_AF' => '烏茲別克文（阿拉伯字母，阿富汗）',
        'uz_Cyrl' => '烏茲別克文（西里爾文字）',
        'uz_Cyrl_UZ' => '烏茲別克文（西里爾文字，烏茲別克）',
        'uz_Latn' => '烏茲別克文（拉丁字母）',
        'uz_Latn_UZ' => '烏茲別克文（拉丁字母，烏茲別克）',
        'uz_UZ' => '烏茲別克文（烏茲別克）',
        'vi' => '越南文',
        'vi_VN' => '越南文（越南）',
        'wo' => '沃洛夫文',
        'wo_SN' => '沃洛夫文（塞內加爾）',
        'xh' => '科薩文',
        'xh_ZA' => '科薩文（南非）',
        'yi' => '意第緒文',
        'yi_UA' => '意第緒文（烏克蘭）',
        'yo' => '約魯巴文',
        'yo_BJ' => '約魯巴文（貝南）',
        'yo_NG' => '約魯巴文（奈及利亞）',
        'za' => '壯文',
        'za_CN' => '壯文（中國）',
        'zh_CN' => '中文（中國）',
        'zh_HK' => '中文（中國香港特別行政區）',
        'zh_Hans' => '中文（簡體）',
        'zh_Hans_CN' => '中文（簡體，中國）',
        'zh_Hans_HK' => '中文（簡體，中國香港特別行政區）',
        'zh_Hans_MO' => '中文（簡體，中國澳門特別行政區）',
        'zh_Hans_MY' => '中文（簡體，馬來西亞）',
        'zh_Hans_SG' => '中文（簡體，新加坡）',
        'zh_Hant' => '中文（繁體）',
        'zh_Hant_HK' => '中文（繁體，中國香港特別行政區）',
        'zh_Hant_MO' => '中文（繁體，中國澳門特別行政區）',
        'zh_Hant_MY' => '中文（繁體，馬來西亞）',
        'zh_Hant_TW' => '中文（繁體，台灣）',
        'zh_MO' => '中文（中國澳門特別行政區）',
        'zh_TW' => '中文（台灣）',
        'zu' => '祖魯文',
        'zu_ZA' => '祖魯文（南非）',
    ],
];
