<?php

return [
    'Names' => [
        'af' => 'Afrikaans',
        'af_NA' => 'Afrikaans (Namibia)',
        'af_ZA' => 'Afrikaans (Abibirem Anaafoɔ)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Gaana)',
        'am' => 'Amariki',
        'am_ET' => 'Amariki (Yitiopia)',
        'ar' => 'Arabeke',
        'ar_001' => 'Arabeke (wiase)',
        'ar_AE' => 'Arabeke (United Arab Emirates)',
        'ar_BH' => 'Arabeke (Baren)',
        'ar_DJ' => 'Arabeke (Gyibuti)',
        'ar_DZ' => 'Arabeke (Ɔlgyeria)',
        'ar_EG' => 'Arabeke (Misrim)',
        'ar_EH' => 'Arabeke (Sahara Atɔeɛ)',
        'ar_ER' => 'Arabeke (Ɛritrea)',
        'ar_IL' => 'Arabeke (Israe)',
        'ar_IQ' => 'Arabeke (Irak)',
        'ar_JO' => 'Arabeke (Gyɔdan)',
        'ar_KM' => 'Arabeke (Kɔmɔrɔs)',
        'ar_KW' => 'Arabeke (Kuweti)',
        'ar_LB' => 'Arabeke (Lɛbanɔn)',
        'ar_LY' => 'Arabeke (Libya)',
        'ar_MA' => 'Arabeke (Moroko)',
        'ar_MR' => 'Arabeke (Mɔretenia)',
        'ar_OM' => 'Arabeke (Oman)',
        'ar_PS' => 'Arabeke (Palestaen West Bank ne Gaza)',
        'ar_QA' => 'Arabeke (Kata)',
        'ar_SA' => 'Arabeke (Saudi Arabia)',
        'ar_SD' => 'Arabeke (Sudan)',
        'ar_SO' => 'Arabeke (Somalia)',
        'ar_SS' => 'Arabeke (Sudan Anaafoɔ)',
        'ar_SY' => 'Arabeke (Siria)',
        'ar_TD' => 'Arabeke (Kyad)',
        'ar_TN' => 'Arabeke (Tunihyia)',
        'ar_YE' => 'Arabeke (Yɛmɛn)',
        'as' => 'Asamese',
        'as_IN' => 'Asamese (India)',
        'az' => 'Asabegyanni',
        'az_AZ' => 'Asabegyanni (Asabegyan)',
        'az_Cyrl' => 'Asabegyanni (Kreleke)',
        'az_Cyrl_AZ' => 'Asabegyanni (Kreleke, Asabegyan)',
        'az_Latn' => 'Asabegyanni (Laatin)',
        'az_Latn_AZ' => 'Asabegyanni (Laatin, Asabegyan)',
        'be' => 'Belarus kasa',
        'be_BY' => 'Belarus kasa (Bɛlarus)',
        'bg' => 'Bɔlgeria kasa',
        'bg_BG' => 'Bɔlgeria kasa (Bɔlgeria)',
        'bn' => 'Bengali kasa',
        'bn_BD' => 'Bengali kasa (Bangladɛhye)',
        'bn_IN' => 'Bengali kasa (India)',
        'br' => 'Britenni',
        'br_FR' => 'Britenni (Franse)',
        'bs' => 'Bosniani',
        'bs_BA' => 'Bosniani (Bosnia ne Hɛzegovina)',
        'bs_Cyrl' => 'Bosniani (Kreleke)',
        'bs_Cyrl_BA' => 'Bosniani (Kreleke, Bosnia ne Hɛzegovina)',
        'bs_Latn' => 'Bosniani (Laatin)',
        'bs_Latn_BA' => 'Bosniani (Laatin, Bosnia ne Hɛzegovina)',
        'ca' => 'Katalan',
        'ca_AD' => 'Katalan (Andora)',
        'ca_ES' => 'Katalan (Spain)',
        'ca_FR' => 'Katalan (Franse)',
        'ca_IT' => 'Katalan (Itali)',
        'cs' => 'Kyɛk kasa',
        'cs_CZ' => 'Kyɛk kasa (Kyɛk)',
        'cv' => 'Kyuvahyi',
        'cv_RU' => 'Kyuvahyi (Rɔhyea)',
        'cy' => 'Wɛɛhye Kasa',
        'cy_GB' => 'Wɛɛhye Kasa (UK)',
        'da' => 'Dane kasa',
        'da_DK' => 'Dane kasa (Dɛnmak)',
        'da_GL' => 'Dane kasa (Greenman)',
        'de' => 'Gyaaman',
        'de_AT' => 'Gyaaman (Ɔstria)',
        'de_BE' => 'Gyaaman (Bɛlgyium)',
        'de_CH' => 'Gyaaman (Swetzaland)',
        'de_DE' => 'Gyaaman (Gyaaman)',
        'de_IT' => 'Gyaaman (Itali)',
        'de_LI' => 'Gyaaman (Lektenstaen)',
        'de_LU' => 'Gyaaman (Lusimbɛg)',
        'ee' => 'Ayigbe',
        'ee_GH' => 'Ayigbe (Gaana)',
        'ee_TG' => 'Ayigbe (Togo)',
        'el' => 'Greek kasa',
        'el_CY' => 'Greek kasa (Saeprɔso)',
        'el_GR' => 'Greek kasa (Greekman)',
        'en' => 'Borɔfo',
        'en_001' => 'Borɔfo (wiase)',
        'en_150' => 'Borɔfo (Yuropu)',
        'en_AE' => 'Borɔfo (United Arab Emirates)',
        'en_AG' => 'Borɔfo (Antigua ne Baabuda)',
        'en_AI' => 'Borɔfo (Anguila)',
        'en_AS' => 'Borɔfo (Amɛrika Samoa)',
        'en_AT' => 'Borɔfo (Ɔstria)',
        'en_AU' => 'Borɔfo (Ɔstrelia)',
        'en_BB' => 'Borɔfo (Baabados)',
        'en_BE' => 'Borɔfo (Bɛlgyium)',
        'en_BI' => 'Borɔfo (Burundi)',
        'en_BM' => 'Borɔfo (Bɛmuda)',
        'en_BS' => 'Borɔfo (Bahamase)',
        'en_BW' => 'Borɔfo (Bɔtswana)',
        'en_BZ' => 'Borɔfo (Beliz)',
        'en_CA' => 'Borɔfo (Kanada)',
        'en_CC' => 'Borɔfo (Kokoso Supɔ)',
        'en_CH' => 'Borɔfo (Swetzaland)',
        'en_CK' => 'Borɔfo (Kuk Nsupɔ)',
        'en_CM' => 'Borɔfo (Kamɛrun)',
        'en_CX' => 'Borɔfo (Buronya Supɔ)',
        'en_CY' => 'Borɔfo (Saeprɔso)',
        'en_CZ' => 'Borɔfo (Kyɛk)',
        'en_DE' => 'Borɔfo (Gyaaman)',
        'en_DK' => 'Borɔfo (Dɛnmak)',
        'en_DM' => 'Borɔfo (Dɔmeneka)',
        'en_EE' => 'Borɔfo (Ɛstonia)',
        'en_ER' => 'Borɔfo (Ɛritrea)',
        'en_ES' => 'Borɔfo (Spain)',
        'en_FI' => 'Borɔfo (Finland)',
        'en_FJ' => 'Borɔfo (Figyi)',
        'en_FK' => 'Borɔfo (Fɔkman Aeland)',
        'en_FM' => 'Borɔfo (Maekronehyia)',
        'en_FR' => 'Borɔfo (Franse)',
        'en_GB' => 'Borɔfo (UK)',
        'en_GD' => 'Borɔfo (Grenada)',
        'en_GE' => 'Borɔfo (Gyɔgyea)',
        'en_GG' => 'Borɔfo (Guɛnse)',
        'en_GH' => 'Borɔfo (Gaana)',
        'en_GI' => 'Borɔfo (Gyebralta)',
        'en_GM' => 'Borɔfo (Gambia)',
        'en_GS' => 'Borɔfo (Gyɔɔgyia Anaafoɔ ne Sandwich Aeland Anaafoɔ)',
        'en_GU' => 'Borɔfo (Guam)',
        'en_GY' => 'Borɔfo (Gayana)',
        'en_HK' => 'Borɔfo (Hɔnkɔn Kyaena)',
        'en_HU' => 'Borɔfo (Hangari)',
        'en_ID' => 'Borɔfo (Ndoniihyia)',
        'en_IE' => 'Borɔfo (Aereland)',
        'en_IL' => 'Borɔfo (Israe)',
        'en_IM' => 'Borɔfo (Isle of Man)',
        'en_IN' => 'Borɔfo (India)',
        'en_IO' => 'Borɔfo (Britenfo Man Wɔ India Po No Mu)',
        'en_IT' => 'Borɔfo (Itali)',
        'en_JE' => 'Borɔfo (Gyɛsi)',
        'en_JM' => 'Borɔfo (Gyameka)',
        'en_JP' => 'Borɔfo (Gyapan)',
        'en_KE' => 'Borɔfo (Kenya)',
        'en_KI' => 'Borɔfo (Kiribati)',
        'en_KN' => 'Borɔfo (Saint Kitts ne Nevis)',
        'en_KY' => 'Borɔfo (Kemanfo Islands)',
        'en_LC' => 'Borɔfo (Saint Lucia)',
        'en_LR' => 'Borɔfo (Laeberia)',
        'en_LS' => 'Borɔfo (Lesoto)',
        'en_LT' => 'Borɔfo (Lituwenia)',
        'en_LV' => 'Borɔfo (Latvia)',
        'en_MG' => 'Borɔfo (Madagaska)',
        'en_MH' => 'Borɔfo (Mahyaa Aeland)',
        'en_MO' => 'Borɔfo (Makaw Kyaena)',
        'en_MP' => 'Borɔfo (Mariana Atifi Fam Aeland)',
        'en_MS' => 'Borɔfo (Mantserat)',
        'en_MT' => 'Borɔfo (Mɔlta)',
        'en_MU' => 'Borɔfo (Mɔrehyeɔs)',
        'en_MV' => 'Borɔfo (Maldives)',
        'en_MW' => 'Borɔfo (Malawi)',
        'en_MY' => 'Borɔfo (Malehyia)',
        'en_NA' => 'Borɔfo (Namibia)',
        'en_NF' => 'Borɔfo (Norfold Supɔ)',
        'en_NG' => 'Borɔfo (Naegyeria)',
        'en_NL' => 'Borɔfo (Nɛdɛland)',
        'en_NO' => 'Borɔfo (Nɔɔwe)',
        'en_NR' => 'Borɔfo (Naworu)',
        'en_NU' => 'Borɔfo (Niyu)',
        'en_NZ' => 'Borɔfo (Ziland Foforo)',
        'en_PG' => 'Borɔfo (Papua Gini Foforɔ)',
        'en_PH' => 'Borɔfo (Filipin)',
        'en_PK' => 'Borɔfo (Pakistan)',
        'en_PL' => 'Borɔfo (Pɔland)',
        'en_PN' => 'Borɔfo (Pitkaan Nsupɔ)',
        'en_PR' => 'Borɔfo (Puɛto Riko)',
        'en_PT' => 'Borɔfo (Pɔtugal)',
        'en_PW' => 'Borɔfo (Palau)',
        'en_RO' => 'Borɔfo (Romenia)',
        'en_RW' => 'Borɔfo (Rewanda)',
        'en_SB' => 'Borɔfo (Solomɔn Aeland)',
        'en_SC' => 'Borɔfo (Seyhyɛl)',
        'en_SD' => 'Borɔfo (Sudan)',
        'en_SE' => 'Borɔfo (Sweden)',
        'en_SG' => 'Borɔfo (Singapɔ)',
        'en_SH' => 'Borɔfo (Saint Helena)',
        'en_SI' => 'Borɔfo (Slovenia)',
        'en_SK' => 'Borɔfo (Slovakia)',
        'en_SL' => 'Borɔfo (Sɛra Liɔn)',
        'en_SS' => 'Borɔfo (Sudan Anaafoɔ)',
        'en_SX' => 'Borɔfo (Sint Maaten)',
        'en_SZ' => 'Borɔfo (Swaziland)',
        'en_TC' => 'Borɔfo (Turks ne Caicos Islands)',
        'en_TK' => 'Borɔfo (Tokelau)',
        'en_TO' => 'Borɔfo (Tonga)',
        'en_TT' => 'Borɔfo (Trinidad ne Tobago)',
        'en_TV' => 'Borɔfo (Tuvalu)',
        'en_TZ' => 'Borɔfo (Tansania)',
        'en_UA' => 'Borɔfo (Ukren)',
        'en_UG' => 'Borɔfo (Yuganda)',
        'en_UM' => 'Borɔfo (U.S. Nkyɛnnkyɛn Supɔ Ahodoɔ)',
        'en_US' => 'Borɔfo (Amɛrika)',
        'en_VC' => 'Borɔfo (Saint Vincent ne Grenadines)',
        'en_VG' => 'Borɔfo (Ngresifoɔ Virgin Island)',
        'en_VI' => 'Borɔfo (Amɛrika Virgin Islands)',
        'en_VU' => 'Borɔfo (Vanuatu)',
        'en_WS' => 'Borɔfo (Samoa)',
        'en_ZA' => 'Borɔfo (Abibirem Anaafoɔ)',
        'en_ZM' => 'Borɔfo (Zambia)',
        'en_ZW' => 'Borɔfo (Zimbabue)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (wiase)',
        'es' => 'Spain kasa',
        'es_419' => 'Spain kasa (Laaten Amɛrika)',
        'es_AR' => 'Spain kasa (Agyɛntina)',
        'es_BO' => 'Spain kasa (Bolivia)',
        'es_BR' => 'Spain kasa (Brazil)',
        'es_BZ' => 'Spain kasa (Beliz)',
        'es_CL' => 'Spain kasa (Kyili)',
        'es_CO' => 'Spain kasa (Kolombia)',
        'es_CR' => 'Spain kasa (Kɔsta Rika)',
        'es_CU' => 'Spain kasa (Kiuba)',
        'es_DO' => 'Spain kasa (Dɔmeneka Man)',
        'es_EC' => 'Spain kasa (Yikuwedɔ)',
        'es_ES' => 'Spain kasa (Spain)',
        'es_GQ' => 'Spain kasa (Gini Ikuweta)',
        'es_GT' => 'Spain kasa (Guwatemala)',
        'es_HN' => 'Spain kasa (Hɔnduras)',
        'es_MX' => 'Spain kasa (Mɛksiko)',
        'es_NI' => 'Spain kasa (Nekaraguwa)',
        'es_PA' => 'Spain kasa (Panama)',
        'es_PE' => 'Spain kasa (Peru)',
        'es_PH' => 'Spain kasa (Filipin)',
        'es_PR' => 'Spain kasa (Puɛto Riko)',
        'es_PY' => 'Spain kasa (Paraguae)',
        'es_SV' => 'Spain kasa (Ɛl Salvadɔ)',
        'es_US' => 'Spain kasa (Amɛrika)',
        'es_UY' => 'Spain kasa (Yurugwae)',
        'es_VE' => 'Spain kasa (Venezuela)',
        'et' => 'Estonia kasa',
        'et_EE' => 'Estonia kasa (Ɛstonia)',
        'eu' => 'Baske',
        'eu_ES' => 'Baske (Spain)',
        'fa' => 'Pɛɛhyia kasa',
        'fa_AF' => 'Pɛɛhyia kasa (Afganistan)',
        'fa_IR' => 'Pɛɛhyia kasa (Yiran)',
        'ff' => 'Fula kasa',
        'ff_Adlm' => 'Fula kasa (Adlam kasa)',
        'ff_Adlm_BF' => 'Fula kasa (Adlam kasa, Bɔkina Faso)',
        'ff_Adlm_CM' => 'Fula kasa (Adlam kasa, Kamɛrun)',
        'ff_Adlm_GH' => 'Fula kasa (Adlam kasa, Gaana)',
        'ff_Adlm_GM' => 'Fula kasa (Adlam kasa, Gambia)',
        'ff_Adlm_GN' => 'Fula kasa (Adlam kasa, Gini)',
        'ff_Adlm_GW' => 'Fula kasa (Adlam kasa, Gini Bisaw)',
        'ff_Adlm_LR' => 'Fula kasa (Adlam kasa, Laeberia)',
        'ff_Adlm_MR' => 'Fula kasa (Adlam kasa, Mɔretenia)',
        'ff_Adlm_NE' => 'Fula kasa (Adlam kasa, Nigyɛɛ)',
        'ff_Adlm_NG' => 'Fula kasa (Adlam kasa, Naegyeria)',
        'ff_Adlm_SL' => 'Fula kasa (Adlam kasa, Sɛra Liɔn)',
        'ff_Adlm_SN' => 'Fula kasa (Adlam kasa, Senegal)',
        'ff_CM' => 'Fula kasa (Kamɛrun)',
        'ff_GN' => 'Fula kasa (Gini)',
        'ff_Latn' => 'Fula kasa (Laatin)',
        'ff_Latn_BF' => 'Fula kasa (Laatin, Bɔkina Faso)',
        'ff_Latn_CM' => 'Fula kasa (Laatin, Kamɛrun)',
        'ff_Latn_GH' => 'Fula kasa (Laatin, Gaana)',
        'ff_Latn_GM' => 'Fula kasa (Laatin, Gambia)',
        'ff_Latn_GN' => 'Fula kasa (Laatin, Gini)',
        'ff_Latn_GW' => 'Fula kasa (Laatin, Gini Bisaw)',
        'ff_Latn_LR' => 'Fula kasa (Laatin, Laeberia)',
        'ff_Latn_MR' => 'Fula kasa (Laatin, Mɔretenia)',
        'ff_Latn_NE' => 'Fula kasa (Laatin, Nigyɛɛ)',
        'ff_Latn_NG' => 'Fula kasa (Laatin, Naegyeria)',
        'ff_Latn_SL' => 'Fula kasa (Laatin, Sɛra Liɔn)',
        'ff_Latn_SN' => 'Fula kasa (Laatin, Senegal)',
        'ff_MR' => 'Fula kasa (Mɔretenia)',
        'ff_SN' => 'Fula kasa (Senegal)',
        'fi' => 'Finlande kasa',
        'fi_FI' => 'Finlande kasa (Finland)',
        'fo' => 'Farosi',
        'fo_DK' => 'Farosi (Dɛnmak)',
        'fo_FO' => 'Farosi (Faro Aeland)',
        'fr' => 'Frɛnkye',
        'fr_BE' => 'Frɛnkye (Bɛlgyium)',
        'fr_BF' => 'Frɛnkye (Bɔkina Faso)',
        'fr_BI' => 'Frɛnkye (Burundi)',
        'fr_BJ' => 'Frɛnkye (Bɛnin)',
        'fr_BL' => 'Frɛnkye (St. Baatilemi)',
        'fr_CA' => 'Frɛnkye (Kanada)',
        'fr_CD' => 'Frɛnkye (Kongo Kinhyaahya)',
        'fr_CF' => 'Frɛnkye (Afrika Finimfin Man)',
        'fr_CG' => 'Frɛnkye (Kongo)',
        'fr_CH' => 'Frɛnkye (Swetzaland)',
        'fr_CI' => 'Frɛnkye (Kodivuwa)',
        'fr_CM' => 'Frɛnkye (Kamɛrun)',
        'fr_DJ' => 'Frɛnkye (Gyibuti)',
        'fr_DZ' => 'Frɛnkye (Ɔlgyeria)',
        'fr_FR' => 'Frɛnkye (Franse)',
        'fr_GA' => 'Frɛnkye (Gabɔn)',
        'fr_GF' => 'Frɛnkye (Frɛnkye Gayana)',
        'fr_GN' => 'Frɛnkye (Gini)',
        'fr_GP' => 'Frɛnkye (Guwadelup)',
        'fr_GQ' => 'Frɛnkye (Gini Ikuweta)',
        'fr_HT' => 'Frɛnkye (Heiti)',
        'fr_KM' => 'Frɛnkye (Kɔmɔrɔs)',
        'fr_LU' => 'Frɛnkye (Lusimbɛg)',
        'fr_MA' => 'Frɛnkye (Moroko)',
        'fr_MC' => 'Frɛnkye (Monako)',
        'fr_MF' => 'Frɛnkye (St. Maatin)',
        'fr_MG' => 'Frɛnkye (Madagaska)',
        'fr_ML' => 'Frɛnkye (Mali)',
        'fr_MQ' => 'Frɛnkye (Matinik)',
        'fr_MR' => 'Frɛnkye (Mɔretenia)',
        'fr_MU' => 'Frɛnkye (Mɔrehyeɔs)',
        'fr_NC' => 'Frɛnkye (Kaledonia Foforo)',
        'fr_NE' => 'Frɛnkye (Nigyɛɛ)',
        'fr_PF' => 'Frɛnkye (Frɛnkye Pɔlenehyia)',
        'fr_PM' => 'Frɛnkye (Saint Pierre ne Miquelon)',
        'fr_RE' => 'Frɛnkye (Reyuniɔn)',
        'fr_RW' => 'Frɛnkye (Rewanda)',
        'fr_SC' => 'Frɛnkye (Seyhyɛl)',
        'fr_SN' => 'Frɛnkye (Senegal)',
        'fr_SY' => 'Frɛnkye (Siria)',
        'fr_TD' => 'Frɛnkye (Kyad)',
        'fr_TG' => 'Frɛnkye (Togo)',
        'fr_TN' => 'Frɛnkye (Tunihyia)',
        'fr_VU' => 'Frɛnkye (Vanuatu)',
        'fr_WF' => 'Frɛnkye (Wallis ne Futuna)',
        'fr_YT' => 'Frɛnkye (Mayɔte)',
        'fy' => 'Atɔeɛ Fam Frihyia Kasa',
        'fy_NL' => 'Atɔeɛ Fam Frihyia Kasa (Nɛdɛland)',
        'ga' => 'Aerelande kasa',
        'ga_GB' => 'Aerelande kasa (UK)',
        'ga_IE' => 'Aerelande kasa (Aereland)',
        'gd' => 'Skotlandfoɔ Galek Kasa',
        'gd_GB' => 'Skotlandfoɔ Galek Kasa (UK)',
        'gl' => 'Galisia kasa',
        'gl_ES' => 'Galisia kasa (Spain)',
        'gu' => 'Gugyarata',
        'gu_IN' => 'Gugyarata (India)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Gaana)',
        'ha_NE' => 'Hausa (Nigyɛɛ)',
        'ha_NG' => 'Hausa (Naegyeria)',
        'he' => 'Hibri kasa',
        'he_IL' => 'Hibri kasa (Israe)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (India)',
        'hi_Latn' => 'Hindi (Laatin)',
        'hi_Latn_IN' => 'Hindi (Laatin, India)',
        'hr' => 'Kurowehyia kasa',
        'hr_BA' => 'Kurowehyia kasa (Bosnia ne Hɛzegovina)',
        'hr_HR' => 'Kurowehyia kasa (Krowehyia)',
        'hu' => 'Hangri kasa',
        'hu_HU' => 'Hangri kasa (Hangari)',
        'hy' => 'Aameniani',
        'hy_AM' => 'Aameniani (Aamenia)',
        'ia' => 'Kasa ntam',
        'ia_001' => 'Kasa ntam (wiase)',
        'id' => 'Indonihyia kasa',
        'id_ID' => 'Indonihyia kasa (Ndoniihyia)',
        'ie' => 'Kasa afrafra',
        'ie_EE' => 'Kasa afrafra (Ɛstonia)',
        'ig' => 'Igbo kasa',
        'ig_NG' => 'Igbo kasa (Naegyeria)',
        'is' => 'Aeslande kasa',
        'is_IS' => 'Aeslande kasa (Aesland)',
        'it' => 'Italy kasa',
        'it_CH' => 'Italy kasa (Swetzaland)',
        'it_IT' => 'Italy kasa (Itali)',
        'it_SM' => 'Italy kasa (San Marino)',
        'it_VA' => 'Italy kasa (Vatican Man)',
        'ja' => 'Gyapan kasa',
        'ja_JP' => 'Gyapan kasa (Gyapan)',
        'jv' => 'Gyabanis kasa',
        'jv_ID' => 'Gyabanis kasa (Ndoniihyia)',
        'ka' => 'Gyɔɔgyia kasa',
        'ka_GE' => 'Gyɔɔgyia kasa (Gyɔgyea)',
        'kk' => 'kasaki kasa',
        'kk_Arab' => 'kasaki kasa (Arabeke)',
        'kk_Arab_CN' => 'kasaki kasa (Arabeke, Kyaena)',
        'kk_Cyrl' => 'kasaki kasa (Kreleke)',
        'kk_Cyrl_KZ' => 'kasaki kasa (Kreleke, Kazakstan)',
        'kk_KZ' => 'kasaki kasa (Kazakstan)',
        'km' => 'Kambodia kasa',
        'km_KH' => 'Kambodia kasa (Kambodia)',
        'kn' => 'Kanada',
        'kn_IN' => 'Kanada (India)',
        'ko' => 'Korea kasa',
        'ko_CN' => 'Korea kasa (Kyaena)',
        'ko_KP' => 'Korea kasa (Korea Atifi)',
        'ko_KR' => 'Korea kasa (Korea Anaafoɔ)',
        'ks' => 'Kahyimiɛ',
        'ks_Arab' => 'Kahyimiɛ (Arabeke)',
        'ks_Arab_IN' => 'Kahyimiɛ (Arabeke, India)',
        'ks_Deva' => 'Kahyimiɛ (Dɛvanagari kasa)',
        'ks_Deva_IN' => 'Kahyimiɛ (Dɛvanagari kasa, India)',
        'ks_IN' => 'Kahyimiɛ (India)',
        'ku' => 'Kɛɛde kasa',
        'ku_Latn' => 'Kɛɛde kasa (Laatin)',
        'ku_Latn_IQ' => 'Kɛɛde kasa (Laatin, Irak)',
        'ku_Latn_SY' => 'Kɛɛde kasa (Laatin, Siria)',
        'ku_Latn_TR' => 'Kɛɛde kasa (Laatin, Tɛɛki)',
        'ku_SY' => 'Kɛɛde kasa (Siria)',
        'ku_TR' => 'Kɛɛde kasa (Tɛɛki)',
        'ky' => 'Kɛgyese kasa',
        'ky_KG' => 'Kɛgyese kasa (Kɛɛgestan)',
        'lb' => 'Lɔsimbɔge kasa',
        'lb_LU' => 'Lɔsimbɔge kasa (Lusimbɛg)',
        'lo' => 'Lawo kasa',
        'lo_LA' => 'Lawo kasa (Laos)',
        'lt' => 'Lituania kasa',
        'lt_LT' => 'Lituania kasa (Lituwenia)',
        'lv' => 'Latvia kasa',
        'lv_LV' => 'Latvia kasa (Latvia)',
        'mi' => 'Mawori',
        'mi_NZ' => 'Mawori (Ziland Foforo)',
        'mk' => 'Mɛsidonia kasa',
        'mk_MK' => 'Mɛsidonia kasa (Mesidonia Atifi)',
        'ml' => 'Malayalam kasa',
        'ml_IN' => 'Malayalam kasa (India)',
        'mn' => 'Mongoliafoɔ kasa',
        'mn_MN' => 'Mongoliafoɔ kasa (Mɔngolia)',
        'mr' => 'Marati',
        'mr_IN' => 'Marati (India)',
        'ms' => 'Malay kasa',
        'ms_BN' => 'Malay kasa (Brunae)',
        'ms_ID' => 'Malay kasa (Ndoniihyia)',
        'ms_MY' => 'Malay kasa (Malehyia)',
        'ms_SG' => 'Malay kasa (Singapɔ)',
        'mt' => 'Malta kasa',
        'mt_MT' => 'Malta kasa (Mɔlta)',
        'my' => 'Bɛɛmis kasa',
        'my_MM' => 'Bɛɛmis kasa (Mayaama [Bɛɛma])',
        'ne' => 'Nɛpal kasa',
        'ne_IN' => 'Nɛpal kasa (India)',
        'ne_NP' => 'Nɛpal kasa (Nɛpal)',
        'nl' => 'Dɛɛkye',
        'nl_AW' => 'Dɛɛkye (Aruba)',
        'nl_BE' => 'Dɛɛkye (Bɛlgyium)',
        'nl_BQ' => 'Dɛɛkye (Caribbean Netherlands)',
        'nl_CW' => 'Dɛɛkye (Kurakaw)',
        'nl_NL' => 'Dɛɛkye (Nɛdɛland)',
        'nl_SR' => 'Dɛɛkye (Suriname)',
        'nl_SX' => 'Dɛɛkye (Sint Maaten)',
        'nn' => 'Nɔwefoɔ Ninɔso',
        'nn_NO' => 'Nɔwefoɔ Ninɔso (Nɔɔwe)',
        'no' => 'Nɔwefoɔ kasa',
        'no_NO' => 'Nɔwefoɔ kasa (Nɔɔwe)',
        'oc' => 'Osita kasa',
        'oc_ES' => 'Osita kasa (Spain)',
        'oc_FR' => 'Osita kasa (Franse)',
        'or' => 'Odia',
        'or_IN' => 'Odia (India)',
        'pa' => 'Pungyabi kasa',
        'pa_Arab' => 'Pungyabi kasa (Arabeke)',
        'pa_Arab_PK' => 'Pungyabi kasa (Arabeke, Pakistan)',
        'pa_Guru' => 'Pungyabi kasa (Gurumuki kasa)',
        'pa_Guru_IN' => 'Pungyabi kasa (Gurumuki kasa, India)',
        'pa_IN' => 'Pungyabi kasa (India)',
        'pa_PK' => 'Pungyabi kasa (Pakistan)',
        'pl' => 'Pɔland kasa',
        'pl_PL' => 'Pɔland kasa (Pɔland)',
        'ps' => 'Pahyito',
        'ps_AF' => 'Pahyito (Afganistan)',
        'ps_PK' => 'Pahyito (Pakistan)',
        'pt' => 'Pɔɔtugal kasa',
        'pt_AO' => 'Pɔɔtugal kasa (Angola)',
        'pt_BR' => 'Pɔɔtugal kasa (Brazil)',
        'pt_CH' => 'Pɔɔtugal kasa (Swetzaland)',
        'pt_CV' => 'Pɔɔtugal kasa (Kepvɛdfo Islands)',
        'pt_GQ' => 'Pɔɔtugal kasa (Gini Ikuweta)',
        'pt_GW' => 'Pɔɔtugal kasa (Gini Bisaw)',
        'pt_LU' => 'Pɔɔtugal kasa (Lusimbɛg)',
        'pt_MO' => 'Pɔɔtugal kasa (Makaw Kyaena)',
        'pt_MZ' => 'Pɔɔtugal kasa (Mozambik)',
        'pt_PT' => 'Pɔɔtugal kasa (Pɔtugal)',
        'pt_ST' => 'Pɔɔtugal kasa (São Tomé ne Príncipe)',
        'pt_TL' => 'Pɔɔtugal kasa (Timɔ Boka)',
        'qu' => 'Kwɛkya',
        'qu_BO' => 'Kwɛkya (Bolivia)',
        'qu_EC' => 'Kwɛkya (Yikuwedɔ)',
        'qu_PE' => 'Kwɛkya (Peru)',
        'rm' => 'Romanhye kasa',
        'rm_CH' => 'Romanhye kasa (Swetzaland)',
        'ro' => 'Romenia kasa',
        'ro_MD' => 'Romenia kasa (Mɔldova)',
        'ro_RO' => 'Romenia kasa (Romenia)',
        'ru' => 'Rahyia kasa',
        'ru_BY' => 'Rahyia kasa (Bɛlarus)',
        'ru_KG' => 'Rahyia kasa (Kɛɛgestan)',
        'ru_KZ' => 'Rahyia kasa (Kazakstan)',
        'ru_MD' => 'Rahyia kasa (Mɔldova)',
        'ru_RU' => 'Rahyia kasa (Rɔhyea)',
        'ru_UA' => 'Rahyia kasa (Ukren)',
        'rw' => 'Rewanda kasa',
        'rw_RW' => 'Rewanda kasa (Rewanda)',
        'sa' => 'Sanskrit kasa',
        'sa_IN' => 'Sanskrit kasa (India)',
        'sc' => 'Saadinia kasa',
        'sc_IT' => 'Saadinia kasa (Itali)',
        'sd' => 'Sindi',
        'sd_Arab' => 'Sindi (Arabeke)',
        'sd_Arab_PK' => 'Sindi (Arabeke, Pakistan)',
        'sd_Deva' => 'Sindi (Dɛvanagari kasa)',
        'sd_Deva_IN' => 'Sindi (Dɛvanagari kasa, India)',
        'sd_IN' => 'Sindi (India)',
        'sd_PK' => 'Sindi (Pakistan)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (Sri Lanka)',
        'sk' => 'Slovak Kasa',
        'sk_SK' => 'Slovak Kasa (Slovakia)',
        'sl' => 'Slovɛniafoɔ Kasa',
        'sl_SI' => 'Slovɛniafoɔ Kasa (Slovenia)',
        'so' => 'Somalia kasa',
        'so_DJ' => 'Somalia kasa (Gyibuti)',
        'so_ET' => 'Somalia kasa (Yitiopia)',
        'so_KE' => 'Somalia kasa (Kenya)',
        'so_SO' => 'Somalia kasa (Somalia)',
        'sq' => 'Aabeniani',
        'sq_AL' => 'Aabeniani (Albenia)',
        'sq_MK' => 'Aabeniani (Mesidonia Atifi)',
        'sr' => 'Sɛbia Kasa',
        'sr_BA' => 'Sɛbia Kasa (Bosnia ne Hɛzegovina)',
        'sr_Cyrl' => 'Sɛbia Kasa (Kreleke)',
        'sr_Cyrl_BA' => 'Sɛbia Kasa (Kreleke, Bosnia ne Hɛzegovina)',
        'sr_Cyrl_ME' => 'Sɛbia Kasa (Kreleke, Mɔntenegro)',
        'sr_Cyrl_RS' => 'Sɛbia Kasa (Kreleke, Sɛbia)',
        'sr_Latn' => 'Sɛbia Kasa (Laatin)',
        'sr_Latn_BA' => 'Sɛbia Kasa (Laatin, Bosnia ne Hɛzegovina)',
        'sr_Latn_ME' => 'Sɛbia Kasa (Laatin, Mɔntenegro)',
        'sr_Latn_RS' => 'Sɛbia Kasa (Laatin, Sɛbia)',
        'sr_ME' => 'Sɛbia Kasa (Mɔntenegro)',
        'sr_RS' => 'Sɛbia Kasa (Sɛbia)',
        'su' => 'Sunda Kasa',
        'su_ID' => 'Sunda Kasa (Ndoniihyia)',
        'su_Latn' => 'Sunda Kasa (Laatin)',
        'su_Latn_ID' => 'Sunda Kasa (Laatin, Ndoniihyia)',
        'sv' => 'Sweden kasa',
        'sv_AX' => 'Sweden kasa (Aland Aeland)',
        'sv_FI' => 'Sweden kasa (Finland)',
        'sv_SE' => 'Sweden kasa (Sweden)',
        'sw' => 'Swahili',
        'sw_CD' => 'Swahili (Kongo Kinhyaahya)',
        'sw_KE' => 'Swahili (Kenya)',
        'sw_TZ' => 'Swahili (Tansania)',
        'sw_UG' => 'Swahili (Yuganda)',
        'ta' => 'Tamil kasa',
        'ta_IN' => 'Tamil kasa (India)',
        'ta_LK' => 'Tamil kasa (Sri Lanka)',
        'ta_MY' => 'Tamil kasa (Malehyia)',
        'ta_SG' => 'Tamil kasa (Singapɔ)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (India)',
        'tg' => 'Tɛgyeke kasa',
        'tg_TJ' => 'Tɛgyeke kasa (Tagyikistan)',
        'th' => 'Taeland kasa',
        'th_TH' => 'Taeland kasa (Taeland)',
        'ti' => 'Tigrinya kasa',
        'ti_ER' => 'Tigrinya kasa (Ɛritrea)',
        'ti_ET' => 'Tigrinya kasa (Yitiopia)',
        'tk' => 'Tɛkmɛnistan Kasa',
        'tk_TM' => 'Tɛkmɛnistan Kasa (Tɛkmɛnistan)',
        'to' => 'Tonga kasa',
        'to_TO' => 'Tonga kasa (Tonga)',
        'tr' => 'Tɛɛki kasa',
        'tr_CY' => 'Tɛɛki kasa (Saeprɔso)',
        'tr_TR' => 'Tɛɛki kasa (Tɛɛki)',
        'tt' => 'Tata kasa',
        'tt_RU' => 'Tata kasa (Rɔhyea)',
        'ug' => 'Yugaa Kasa',
        'ug_CN' => 'Yugaa Kasa (Kyaena)',
        'uk' => 'Ukren kasa',
        'uk_UA' => 'Ukren kasa (Ukren)',
        'ur' => 'Urdu kasa',
        'ur_IN' => 'Urdu kasa (India)',
        'ur_PK' => 'Urdu kasa (Pakistan)',
        'uz' => 'Usbɛkistan Kasa',
        'uz_AF' => 'Usbɛkistan Kasa (Afganistan)',
        'uz_Arab' => 'Usbɛkistan Kasa (Arabeke)',
        'uz_Arab_AF' => 'Usbɛkistan Kasa (Arabeke, Afganistan)',
        'uz_Cyrl' => 'Usbɛkistan Kasa (Kreleke)',
        'uz_Cyrl_UZ' => 'Usbɛkistan Kasa (Kreleke, Usbɛkistan)',
        'uz_Latn' => 'Usbɛkistan Kasa (Laatin)',
        'uz_Latn_UZ' => 'Usbɛkistan Kasa (Laatin, Usbɛkistan)',
        'uz_UZ' => 'Usbɛkistan Kasa (Usbɛkistan)',
        'vi' => 'Viɛtnam kasa',
        'vi_VN' => 'Viɛtnam kasa (Viɛtnam)',
        'wo' => 'Wolɔfo Kasa',
        'wo_SN' => 'Wolɔfo Kasa (Senegal)',
        'xh' => 'Hosa Kasa',
        'xh_ZA' => 'Hosa Kasa (Abibirem Anaafoɔ)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Bɛnin)',
        'yo_NG' => 'Yoruba (Naegyeria)',
        'za' => 'Zuang',
        'za_CN' => 'Zuang (Kyaena)',
        'zh' => 'Kyaena kasa',
        'zh_CN' => 'Kyaena kasa (Kyaena)',
        'zh_HK' => 'Kyaena kasa (Hɔnkɔn Kyaena)',
        'zh_Hans' => 'Kyaena kasa (Kyaena Kasa Hanse)',
        'zh_Hans_CN' => 'Kyaena kasa (Kyaena Kasa Hanse, Kyaena)',
        'zh_Hans_HK' => 'Kyaena kasa (Kyaena Kasa Hanse, Hɔnkɔn Kyaena)',
        'zh_Hans_MO' => 'Kyaena kasa (Kyaena Kasa Hanse, Makaw Kyaena)',
        'zh_Hans_MY' => 'Kyaena kasa (Kyaena Kasa Hanse, Malehyia)',
        'zh_Hans_SG' => 'Kyaena kasa (Kyaena Kasa Hanse, Singapɔ)',
        'zh_Hant' => 'Kyaena kasa (Tete)',
        'zh_Hant_HK' => 'Kyaena kasa (Tete, Hɔnkɔn Kyaena)',
        'zh_Hant_MO' => 'Kyaena kasa (Tete, Makaw Kyaena)',
        'zh_Hant_MY' => 'Kyaena kasa (Tete, Malehyia)',
        'zh_Hant_TW' => 'Kyaena kasa (Tete, Taiwan)',
        'zh_MO' => 'Kyaena kasa (Makaw Kyaena)',
        'zh_SG' => 'Kyaena kasa (Singapɔ)',
        'zh_TW' => 'Kyaena kasa (Taiwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (Abibirem Anaafoɔ)',
    ],
];
