<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'дырхам ААЭ',
        ],
        'AFN' => [
            'AFN',
            'афганскі афгані',
        ],
        'ALL' => [
            'ALL',
            'албанскі лек',
        ],
        'AMD' => [
            'AMD',
            'армянскі драм',
        ],
        'ANG' => [
            'ANG',
            'нідэрландскі антыльскі гульдэн',
        ],
        'AOA' => [
            'AOA',
            'ангольская кванза',
        ],
        'ARS' => [
            'ARS',
            'аргенцінскае песа',
        ],
        'AUD' => [
            'A$',
            'аўстралійскі долар',
        ],
        'AWG' => [
            'AWG',
            'арубанскі фларын',
        ],
        'AZN' => [
            'AZN',
            'азербайджанскі манат',
        ],
        'BAM' => [
            'BAM',
            'канверсоўная марка Босніі і Герцагавіны',
        ],
        'BBD' => [
            'BBD',
            'барбадаскі долар',
        ],
        'BDT' => [
            'BDT',
            'бангладэшская така',
        ],
        'BGN' => [
            'BGN',
            'балгарскі леў',
        ],
        'BHD' => [
            'BHD',
            'бахрэйнскі дынар',
        ],
        'BIF' => [
            'BIF',
            'бурундзійскі франк',
        ],
        'BMD' => [
            'BMD',
            'бермудскі долар',
        ],
        'BND' => [
            'BND',
            'брунейскі долар',
        ],
        'BOB' => [
            'BOB',
            'балівіяна',
        ],
        'BRL' => [
            'BRL',
            'бразільскі рэал',
        ],
        'BSD' => [
            'BSD',
            'багамскі долар',
        ],
        'BTN' => [
            'BTN',
            'бутанскі нгултрум',
        ],
        'BWP' => [
            'BWP',
            'батсванская пула',
        ],
        'BYN' => [
            'Br',
            'беларускі рубель',
        ],
        'BYR' => [
            'BYR',
            'беларускі рубель (2000–2016)',
        ],
        'BZD' => [
            'BZD',
            'белізскі долар',
        ],
        'CAD' => [
            'CAD',
            'канадскі долар',
        ],
        'CDF' => [
            'CDF',
            'кангалезскі франк',
        ],
        'CHF' => [
            'CHF',
            'швейцарскі франк',
        ],
        'CLP' => [
            'CLP',
            'чылійскае песа',
        ],
        'CNH' => [
            'CNH',
            'афшорны кітайскі юань',
        ],
        'CNY' => [
            'CN¥',
            'кітайскі юань',
        ],
        'COP' => [
            'COP',
            'калумбійскае песа',
        ],
        'CRC' => [
            'CRC',
            'коста-рыканскі калон',
        ],
        'CUC' => [
            'CUC',
            'кубінскае канверсоўнае песа',
        ],
        'CUP' => [
            'CUP',
            'кубінскае песа',
        ],
        'CVE' => [
            'CVE',
            'эскуда Каба-Вердэ',
        ],
        'CZK' => [
            'CZK',
            'чэшская крона',
        ],
        'DJF' => [
            'DJF',
            'джыбуційскі франк',
        ],
        'DKK' => [
            'DKK',
            'дацкая крона',
        ],
        'DOP' => [
            'DOP',
            'дамініканскае песа',
        ],
        'DZD' => [
            'DZD',
            'алжырскі дынар',
        ],
        'EGP' => [
            'EGP',
            'егіпецкі фунт',
        ],
        'ERN' => [
            'ERN',
            'эрытрэйская накфа',
        ],
        'ETB' => [
            'ETB',
            'эфіопскі быр',
        ],
        'EUR' => [
            '€',
            'еўра',
        ],
        'FJD' => [
            'FJD',
            'фіджыйскі долар',
        ],
        'FKP' => [
            'FKP',
            'фунт Фалклендскіх астравоў',
        ],
        'GBP' => [
            '£',
            'брытанскі фунт стэрлінгаў',
        ],
        'GEL' => [
            'GEL',
            'грузінскі лары',
        ],
        'GHS' => [
            'GHS',
            'ганскі седзі',
        ],
        'GIP' => [
            'GIP',
            'гібралтарскі фунт',
        ],
        'GMD' => [
            'GMD',
            'гамбійскі даласі',
        ],
        'GNF' => [
            'GNF',
            'гвінейскі франк',
        ],
        'GTQ' => [
            'GTQ',
            'гватэмальскі кетсаль',
        ],
        'GYD' => [
            'GYD',
            'гаянскі долар',
        ],
        'HKD' => [
            'HK$',
            'ганконгскі долар',
        ],
        'HNL' => [
            'HNL',
            'гандураская лемпіра',
        ],
        'HRK' => [
            'HRK',
            'харвацкая куна',
        ],
        'HTG' => [
            'HTG',
            'гаіцянскі гурд',
        ],
        'HUF' => [
            'HUF',
            'венгерскі форынт',
        ],
        'IDR' => [
            'IDR',
            'інданезійская рупія',
        ],
        'ILS' => [
            '₪',
            'новы ізраільскі шэкель',
        ],
        'INR' => [
            '₹',
            'індыйская рупія',
        ],
        'IQD' => [
            'IQD',
            'іракскі дынар',
        ],
        'IRR' => [
            'IRR',
            'іранскі рыял',
        ],
        'ISK' => [
            'ISK',
            'ісландская крона',
        ],
        'JMD' => [
            'JMD',
            'ямайскі долар',
        ],
        'JOD' => [
            'JOD',
            'іарданскі дынар',
        ],
        'JPY' => [
            '¥',
            'японская іена',
        ],
        'KES' => [
            'KES',
            'кенійскі шылінг',
        ],
        'KGS' => [
            'KGS',
            'кіргізскі сом',
        ],
        'KHR' => [
            'KHR',
            'камбаджыйскі рыель',
        ],
        'KMF' => [
            'KMF',
            'каморскі франк',
        ],
        'KPW' => [
            'KPW',
            'паўночнакарэйская вона',
        ],
        'KRW' => [
            '₩',
            'паўднёвакарэйская вона',
        ],
        'KWD' => [
            'KWD',
            'кувейцкі дынар',
        ],
        'KYD' => [
            'KYD',
            'долар Кайманавых астравоў',
        ],
        'KZT' => [
            'KZT',
            'казахстанскі тэнге',
        ],
        'LAK' => [
            'LAK',
            'лаоскі кіп',
        ],
        'LBP' => [
            'LBP',
            'ліванскі фунт',
        ],
        'LKR' => [
            'LKR',
            'шры-ланкійская рупія',
        ],
        'LRD' => [
            'LRD',
            'ліберыйскі долар',
        ],
        'LSL' => [
            'LSL',
            'лесоцкі лоці',
        ],
        'LYD' => [
            'LYD',
            'лівійскі дынар',
        ],
        'MAD' => [
            'MAD',
            'мараканскі дырхам',
        ],
        'MDL' => [
            'MDL',
            'малдаўскі лей',
        ],
        'MGA' => [
            'MGA',
            'малагасійскі арыяры',
        ],
        'MKD' => [
            'MKD',
            'македонскі дэнар',
        ],
        'MMK' => [
            'MMK',
            'м’янманскі к’ят',
        ],
        'MNT' => [
            'MNT',
            'мангольскі тугрык',
        ],
        'MOP' => [
            'MOP',
            'патака Макаа',
        ],
        'MRO' => [
            'MRO',
            'маўрытанская ўгія (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'маўрытанская угія',
        ],
        'MUR' => [
            'MUR',
            'маўрыкійская рупія',
        ],
        'MVR' => [
            'MVR',
            'мальдыўская руфія',
        ],
        'MWK' => [
            'MWK',
            'малавійская квача',
        ],
        'MXN' => [
            'MX$',
            'мексіканскае песа',
        ],
        'MYR' => [
            'MYR',
            'малайзійскі рынгіт',
        ],
        'MZN' => [
            'MZN',
            'мазамбікскі метыкал',
        ],
        'NAD' => [
            'NAD',
            'намібійскі долар',
        ],
        'NGN' => [
            'NGN',
            'нігерыйская наіра',
        ],
        'NIO' => [
            'NIO',
            'нікарагуанская кордаба',
        ],
        'NOK' => [
            'NOK',
            'нарвежская крона',
        ],
        'NPR' => [
            'NPR',
            'непальская рупія',
        ],
        'NZD' => [
            'NZD',
            'новазеландскі долар',
        ],
        'OMR' => [
            'OMR',
            'аманскі рыял',
        ],
        'PAB' => [
            'PAB',
            'панамскае бальбоа',
        ],
        'PEN' => [
            'PEN',
            'перуанскі соль',
        ],
        'PGK' => [
            'PGK',
            'кіна Папуа-Новай Гвінеі',
        ],
        'PHP' => [
            'PHP',
            'філіпінскае песа',
        ],
        'PKR' => [
            'PKR',
            'пакістанская рупія',
        ],
        'PLN' => [
            'PLN',
            'польскі злоты',
        ],
        'PYG' => [
            'PYG',
            'парагвайскі гуарані',
        ],
        'QAR' => [
            'QAR',
            'катарскі рыял',
        ],
        'RON' => [
            'RON',
            'румынскі лей',
        ],
        'RSD' => [
            'RSD',
            'сербскі дынар',
        ],
        'RUB' => [
            '₽',
            'расійскі рубель',
        ],
        'RWF' => [
            'RWF',
            'руандыйскі франк',
        ],
        'SAR' => [
            'SAR',
            'саудаўскі рыял',
        ],
        'SBD' => [
            'SBD',
            'долар Саламонавых астравоў',
        ],
        'SCR' => [
            'SCR',
            'сейшэльская рупія',
        ],
        'SDG' => [
            'SDG',
            'суданскі фунт',
        ],
        'SEK' => [
            'SEK',
            'шведская крона',
        ],
        'SGD' => [
            'SGD',
            'сінгапурскі долар',
        ],
        'SHP' => [
            'SHP',
            'фунт в-ва Святой Алены',
        ],
        'SLE' => [
            'SLE',
            'сьера-леонскі леонэ',
        ],
        'SLL' => [
            'SLL',
            'сьера-леонскі леонэ (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'самалійскі шылінг',
        ],
        'SRD' => [
            'SRD',
            'сурынамскі долар',
        ],
        'SSP' => [
            'SSP',
            'паўднёвасуданскі фунт',
        ],
        'STD' => [
            'STD',
            'добра Сан-Тамэ і Прынсіпі (1977–2017)',
        ],
        'STN' => [
            'STN',
            'добра Сан-Тамэ і Прынсіпі',
        ],
        'SYP' => [
            'SYP',
            'сірыйскі фунт',
        ],
        'SZL' => [
            'SZL',
            'свазілендскі лілангені',
        ],
        'THB' => [
            'THB',
            'тайскі бат',
        ],
        'TJS' => [
            'TJS',
            'таджыкскі самані',
        ],
        'TMT' => [
            'TMT',
            'туркменскі манат',
        ],
        'TND' => [
            'TND',
            'туніскі дынар',
        ],
        'TOP' => [
            'TOP',
            'танганская паанга',
        ],
        'TRY' => [
            'TRY',
            'турэцкая ліра',
        ],
        'TTD' => [
            'TTD',
            'долар Трынідада і Табага',
        ],
        'TWD' => [
            'NT$',
            'новы тайваньскі долар',
        ],
        'TZS' => [
            'TZS',
            'танзанійскі шылінг',
        ],
        'UAH' => [
            'UAH',
            'украінская грыўня',
        ],
        'UGX' => [
            'UGX',
            'угандыйскі шылінг',
        ],
        'USD' => [
            '$',
            'долар ЗША',
        ],
        'UYU' => [
            'UYU',
            'уругвайскае песа',
        ],
        'UZS' => [
            'UZS',
            'узбекскі сум',
        ],
        'VEF' => [
            'VEF',
            'венесуальскі балівар (2008–2018)',
        ],
        'VES' => [
            'VES',
            'венесуэльскі балівар',
        ],
        'VND' => [
            '₫',
            'в’етнамскі донг',
        ],
        'VUV' => [
            'VUV',
            'вануацкі вату',
        ],
        'WST' => [
            'WST',
            'самаанская тала',
        ],
        'XAF' => [
            'FCFA',
            'цэнтральнаафрыканскі франк КФА',
        ],
        'XCD' => [
            'EC$',
            'усходнекарыбскі долар',
        ],
        'XCG' => [
            'Cg.',
            'карыбскі гульдэн',
        ],
        'XOF' => [
            'F CFA',
            'заходнеафрыканскі франк КФА',
        ],
        'XPF' => [
            'CFPF',
            'французскі ціхаакіянскі франк',
        ],
        'YER' => [
            'YER',
            'еменскі рыал',
        ],
        'ZAR' => [
            'ZAR',
            'паўднёваафрыканскі рэнд',
        ],
        'ZMW' => [
            'ZMW',
            'замбійская квача',
        ],
        'ZWG' => [
            'ZWG',
            'зімбабвійскі залаты',
        ],
    ],
];
