<?php

return [
    'Names' => [
        'af' => 'afrikandu',
        'af_NA' => 'afrikandu (Namībija)',
        'af_ZA' => 'afrikandu (Dienvidāfrikas Republika)',
        'ak' => 'akanu',
        'ak_GH' => 'akanu (Gana)',
        'am' => 'amharu',
        'am_ET' => 'amharu (Etiopija)',
        'ar' => 'arābu',
        'ar_001' => 'arābu (pasaule)',
        'ar_AE' => 'arābu (Apvienotie Arābu Emirāti)',
        'ar_BH' => 'arābu (Bahreina)',
        'ar_DJ' => 'arābu (Džibutija)',
        'ar_DZ' => 'arābu (Alžīrija)',
        'ar_EG' => 'arābu (Ēģipte)',
        'ar_EH' => 'arābu (Rietumsahāra)',
        'ar_ER' => 'arābu (Eritreja)',
        'ar_IL' => 'arābu (Izraēla)',
        'ar_IQ' => 'arābu (Irāka)',
        'ar_JO' => 'arābu (Jordānija)',
        'ar_KM' => 'arābu (Komoru salas)',
        'ar_KW' => 'arābu (Kuveita)',
        'ar_LB' => 'arābu (Libāna)',
        'ar_LY' => 'arābu (Lībija)',
        'ar_MA' => 'arābu (Maroka)',
        'ar_MR' => 'arābu (Mauritānija)',
        'ar_OM' => 'arābu (Omāna)',
        'ar_PS' => 'arābu (Palestīnas teritorijas)',
        'ar_QA' => 'arābu (Katara)',
        'ar_SA' => 'arābu (Saūda Arābija)',
        'ar_SD' => 'arābu (Sudāna)',
        'ar_SO' => 'arābu (Somālija)',
        'ar_SS' => 'arābu (Dienvidsudāna)',
        'ar_SY' => 'arābu (Sīrija)',
        'ar_TD' => 'arābu (Čada)',
        'ar_TN' => 'arābu (Tunisija)',
        'ar_YE' => 'arābu (Jemena)',
        'as' => 'asamiešu',
        'as_IN' => 'asamiešu (Indija)',
        'az' => 'azerbaidžāņu',
        'az_AZ' => 'azerbaidžāņu (Azerbaidžāna)',
        'az_Cyrl' => 'azerbaidžāņu (kirilica)',
        'az_Cyrl_AZ' => 'azerbaidžāņu (kirilica, Azerbaidžāna)',
        'az_Latn' => 'azerbaidžāņu (latīņu)',
        'az_Latn_AZ' => 'azerbaidžāņu (latīņu, Azerbaidžāna)',
        'ba' => 'baškīru',
        'ba_RU' => 'baškīru (Krievija)',
        'be' => 'baltkrievu',
        'be_BY' => 'baltkrievu (Baltkrievija)',
        'bg' => 'bulgāru',
        'bg_BG' => 'bulgāru (Bulgārija)',
        'bm' => 'bambaru',
        'bm_ML' => 'bambaru (Mali)',
        'bn' => 'bengāļu',
        'bn_BD' => 'bengāļu (Bangladeša)',
        'bn_IN' => 'bengāļu (Indija)',
        'bo' => 'tibetiešu',
        'bo_CN' => 'tibetiešu (Ķīna)',
        'bo_IN' => 'tibetiešu (Indija)',
        'br' => 'bretoņu',
        'br_FR' => 'bretoņu (Francija)',
        'bs' => 'bosniešu',
        'bs_BA' => 'bosniešu (Bosnija un Hercegovina)',
        'bs_Cyrl' => 'bosniešu (kirilica)',
        'bs_Cyrl_BA' => 'bosniešu (kirilica, Bosnija un Hercegovina)',
        'bs_Latn' => 'bosniešu (latīņu)',
        'bs_Latn_BA' => 'bosniešu (latīņu, Bosnija un Hercegovina)',
        'ca' => 'katalāņu',
        'ca_AD' => 'katalāņu (Andora)',
        'ca_ES' => 'katalāņu (Spānija)',
        'ca_FR' => 'katalāņu (Francija)',
        'ca_IT' => 'katalāņu (Itālija)',
        'ce' => 'čečenu',
        'ce_RU' => 'čečenu (Krievija)',
        'cs' => 'čehu',
        'cs_CZ' => 'čehu (Čehija)',
        'cv' => 'čuvašu',
        'cv_RU' => 'čuvašu (Krievija)',
        'cy' => 'velsiešu',
        'cy_GB' => 'velsiešu (Apvienotā Karaliste)',
        'da' => 'dāņu',
        'da_DK' => 'dāņu (Dānija)',
        'da_GL' => 'dāņu (Grenlande)',
        'de' => 'vācu',
        'de_AT' => 'vācu (Austrija)',
        'de_BE' => 'vācu (Beļģija)',
        'de_CH' => 'vācu (Šveice)',
        'de_DE' => 'vācu (Vācija)',
        'de_IT' => 'vācu (Itālija)',
        'de_LI' => 'vācu (Lihtenšteina)',
        'de_LU' => 'vācu (Luksemburga)',
        'dz' => 'dzongke',
        'dz_BT' => 'dzongke (Butāna)',
        'ee' => 'evu',
        'ee_GH' => 'evu (Gana)',
        'ee_TG' => 'evu (Togo)',
        'el' => 'grieķu',
        'el_CY' => 'grieķu (Kipra)',
        'el_GR' => 'grieķu (Grieķija)',
        'en' => 'angļu',
        'en_001' => 'angļu (pasaule)',
        'en_150' => 'angļu (Eiropa)',
        'en_AE' => 'angļu (Apvienotie Arābu Emirāti)',
        'en_AG' => 'angļu (Antigva un Barbuda)',
        'en_AI' => 'angļu (Angilja)',
        'en_AS' => 'angļu (ASV Samoa)',
        'en_AT' => 'angļu (Austrija)',
        'en_AU' => 'angļu (Austrālija)',
        'en_BB' => 'angļu (Barbadosa)',
        'en_BE' => 'angļu (Beļģija)',
        'en_BI' => 'angļu (Burundija)',
        'en_BM' => 'angļu (Bermudu salas)',
        'en_BS' => 'angļu (Bahamu salas)',
        'en_BW' => 'angļu (Botsvāna)',
        'en_BZ' => 'angļu (Beliza)',
        'en_CA' => 'angļu (Kanāda)',
        'en_CC' => 'angļu (Kokosu [Kīlinga] salas)',
        'en_CH' => 'angļu (Šveice)',
        'en_CK' => 'angļu (Kuka salas)',
        'en_CM' => 'angļu (Kamerūna)',
        'en_CX' => 'angļu (Ziemsvētku sala)',
        'en_CY' => 'angļu (Kipra)',
        'en_CZ' => 'angļu (Čehija)',
        'en_DE' => 'angļu (Vācija)',
        'en_DK' => 'angļu (Dānija)',
        'en_DM' => 'angļu (Dominika)',
        'en_EE' => 'angļu (Igaunija)',
        'en_ER' => 'angļu (Eritreja)',
        'en_ES' => 'angļu (Spānija)',
        'en_FI' => 'angļu (Somija)',
        'en_FJ' => 'angļu (Fidži)',
        'en_FK' => 'angļu (Folklenda salas)',
        'en_FM' => 'angļu (Mikronēzija)',
        'en_FR' => 'angļu (Francija)',
        'en_GB' => 'angļu (Apvienotā Karaliste)',
        'en_GD' => 'angļu (Grenāda)',
        'en_GE' => 'angļu (Gruzija)',
        'en_GG' => 'angļu (Gērnsija)',
        'en_GH' => 'angļu (Gana)',
        'en_GI' => 'angļu (Gibraltārs)',
        'en_GM' => 'angļu (Gambija)',
        'en_GS' => 'angļu (Dienviddžordžija un Dienvidsendviču salas)',
        'en_GU' => 'angļu (Guama)',
        'en_GY' => 'angļu (Gajāna)',
        'en_HK' => 'angļu (Ķīnas īpašās pārvaldes apgabals Honkonga)',
        'en_HU' => 'angļu (Ungārija)',
        'en_ID' => 'angļu (Indonēzija)',
        'en_IE' => 'angļu (Īrija)',
        'en_IL' => 'angļu (Izraēla)',
        'en_IM' => 'angļu (Menas sala)',
        'en_IN' => 'angļu (Indija)',
        'en_IO' => 'angļu (Indijas okeāna Britu teritorija)',
        'en_IT' => 'angļu (Itālija)',
        'en_JE' => 'angļu (Džērsija)',
        'en_JM' => 'angļu (Jamaika)',
        'en_JP' => 'angļu (Japāna)',
        'en_KE' => 'angļu (Kenija)',
        'en_KI' => 'angļu (Kiribati)',
        'en_KN' => 'angļu (Sentkitsa un Nevisa)',
        'en_KY' => 'angļu (Kaimanu salas)',
        'en_LC' => 'angļu (Sentlūsija)',
        'en_LR' => 'angļu (Libērija)',
        'en_LS' => 'angļu (Lesoto)',
        'en_LT' => 'angļu (Lietuva)',
        'en_LV' => 'angļu (Latvija)',
        'en_MG' => 'angļu (Madagaskara)',
        'en_MH' => 'angļu (Māršala salas)',
        'en_MO' => 'angļu (ĶTR īpašais administratīvais reģions Makao)',
        'en_MP' => 'angļu (Ziemeļu Marianas salas)',
        'en_MS' => 'angļu (Montserrata)',
        'en_MT' => 'angļu (Malta)',
        'en_MU' => 'angļu (Maurīcija)',
        'en_MV' => 'angļu (Maldīvija)',
        'en_MW' => 'angļu (Malāvija)',
        'en_MY' => 'angļu (Malaizija)',
        'en_NA' => 'angļu (Namībija)',
        'en_NF' => 'angļu (Norfolkas sala)',
        'en_NG' => 'angļu (Nigērija)',
        'en_NL' => 'angļu (Nīderlande)',
        'en_NO' => 'angļu (Norvēģija)',
        'en_NR' => 'angļu (Nauru)',
        'en_NU' => 'angļu (Niue)',
        'en_NZ' => 'angļu (Jaunzēlande)',
        'en_PG' => 'angļu (Papua-Jaungvineja)',
        'en_PH' => 'angļu (Filipīnas)',
        'en_PK' => 'angļu (Pakistāna)',
        'en_PL' => 'angļu (Polija)',
        'en_PN' => 'angļu (Pitkērnas salas)',
        'en_PR' => 'angļu (Puertoriko)',
        'en_PT' => 'angļu (Portugāle)',
        'en_PW' => 'angļu (Palau)',
        'en_RO' => 'angļu (Rumānija)',
        'en_RW' => 'angļu (Ruanda)',
        'en_SB' => 'angļu (Zālamana salas)',
        'en_SC' => 'angļu (Seišelu salas)',
        'en_SD' => 'angļu (Sudāna)',
        'en_SE' => 'angļu (Zviedrija)',
        'en_SG' => 'angļu (Singapūra)',
        'en_SH' => 'angļu (Sv.Helēnas sala)',
        'en_SI' => 'angļu (Slovēnija)',
        'en_SK' => 'angļu (Slovākija)',
        'en_SL' => 'angļu (Sjerraleone)',
        'en_SS' => 'angļu (Dienvidsudāna)',
        'en_SX' => 'angļu (Sintmārtena)',
        'en_SZ' => 'angļu (Svatini)',
        'en_TC' => 'angļu (Tērksas un Kaikosas salas)',
        'en_TK' => 'angļu (Tokelau)',
        'en_TO' => 'angļu (Tonga)',
        'en_TT' => 'angļu (Trinidāda un Tobāgo)',
        'en_TV' => 'angļu (Tuvalu)',
        'en_TZ' => 'angļu (Tanzānija)',
        'en_UA' => 'angļu (Ukraina)',
        'en_UG' => 'angļu (Uganda)',
        'en_UM' => 'angļu (ASV Mazās Aizjūras salas)',
        'en_US' => 'angļu (Amerikas Savienotās Valstis)',
        'en_VC' => 'angļu (Sentvinsenta un Grenadīnas)',
        'en_VG' => 'angļu (Britu Virdžīnas)',
        'en_VI' => 'angļu (ASV Virdžīnas)',
        'en_VU' => 'angļu (Vanuatu)',
        'en_WS' => 'angļu (Samoa)',
        'en_ZA' => 'angļu (Dienvidāfrikas Republika)',
        'en_ZM' => 'angļu (Zambija)',
        'en_ZW' => 'angļu (Zimbabve)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (pasaule)',
        'es' => 'spāņu',
        'es_419' => 'spāņu (Latīņamerika)',
        'es_AR' => 'spāņu (Argentīna)',
        'es_BO' => 'spāņu (Bolīvija)',
        'es_BR' => 'spāņu (Brazīlija)',
        'es_BZ' => 'spāņu (Beliza)',
        'es_CL' => 'spāņu (Čīle)',
        'es_CO' => 'spāņu (Kolumbija)',
        'es_CR' => 'spāņu (Kostarika)',
        'es_CU' => 'spāņu (Kuba)',
        'es_DO' => 'spāņu (Dominikāna)',
        'es_EC' => 'spāņu (Ekvadora)',
        'es_ES' => 'spāņu (Spānija)',
        'es_GQ' => 'spāņu (Ekvatoriālā Gvineja)',
        'es_GT' => 'spāņu (Gvatemala)',
        'es_HN' => 'spāņu (Hondurasa)',
        'es_MX' => 'spāņu (Meksika)',
        'es_NI' => 'spāņu (Nikaragva)',
        'es_PA' => 'spāņu (Panama)',
        'es_PE' => 'spāņu (Peru)',
        'es_PH' => 'spāņu (Filipīnas)',
        'es_PR' => 'spāņu (Puertoriko)',
        'es_PY' => 'spāņu (Paragvaja)',
        'es_SV' => 'spāņu (Salvadora)',
        'es_US' => 'spāņu (Amerikas Savienotās Valstis)',
        'es_UY' => 'spāņu (Urugvaja)',
        'es_VE' => 'spāņu (Venecuēla)',
        'et' => 'igauņu',
        'et_EE' => 'igauņu (Igaunija)',
        'eu' => 'basku',
        'eu_ES' => 'basku (Spānija)',
        'fa' => 'persiešu',
        'fa_AF' => 'persiešu (Afganistāna)',
        'fa_IR' => 'persiešu (Irāna)',
        'ff' => 'fulu',
        'ff_Adlm' => 'fulu (adlama)',
        'ff_Adlm_BF' => 'fulu (adlama, Burkinafaso)',
        'ff_Adlm_CM' => 'fulu (adlama, Kamerūna)',
        'ff_Adlm_GH' => 'fulu (adlama, Gana)',
        'ff_Adlm_GM' => 'fulu (adlama, Gambija)',
        'ff_Adlm_GN' => 'fulu (adlama, Gvineja)',
        'ff_Adlm_GW' => 'fulu (adlama, Gvineja-Bisava)',
        'ff_Adlm_LR' => 'fulu (adlama, Libērija)',
        'ff_Adlm_MR' => 'fulu (adlama, Mauritānija)',
        'ff_Adlm_NE' => 'fulu (adlama, Nigēra)',
        'ff_Adlm_NG' => 'fulu (adlama, Nigērija)',
        'ff_Adlm_SL' => 'fulu (adlama, Sjerraleone)',
        'ff_Adlm_SN' => 'fulu (adlama, Senegāla)',
        'ff_CM' => 'fulu (Kamerūna)',
        'ff_GN' => 'fulu (Gvineja)',
        'ff_Latn' => 'fulu (latīņu)',
        'ff_Latn_BF' => 'fulu (latīņu, Burkinafaso)',
        'ff_Latn_CM' => 'fulu (latīņu, Kamerūna)',
        'ff_Latn_GH' => 'fulu (latīņu, Gana)',
        'ff_Latn_GM' => 'fulu (latīņu, Gambija)',
        'ff_Latn_GN' => 'fulu (latīņu, Gvineja)',
        'ff_Latn_GW' => 'fulu (latīņu, Gvineja-Bisava)',
        'ff_Latn_LR' => 'fulu (latīņu, Libērija)',
        'ff_Latn_MR' => 'fulu (latīņu, Mauritānija)',
        'ff_Latn_NE' => 'fulu (latīņu, Nigēra)',
        'ff_Latn_NG' => 'fulu (latīņu, Nigērija)',
        'ff_Latn_SL' => 'fulu (latīņu, Sjerraleone)',
        'ff_Latn_SN' => 'fulu (latīņu, Senegāla)',
        'ff_MR' => 'fulu (Mauritānija)',
        'ff_SN' => 'fulu (Senegāla)',
        'fi' => 'somu',
        'fi_FI' => 'somu (Somija)',
        'fo' => 'fēru',
        'fo_DK' => 'fēru (Dānija)',
        'fo_FO' => 'fēru (Fēru salas)',
        'fr' => 'franču',
        'fr_BE' => 'franču (Beļģija)',
        'fr_BF' => 'franču (Burkinafaso)',
        'fr_BI' => 'franču (Burundija)',
        'fr_BJ' => 'franču (Benina)',
        'fr_BL' => 'franču (Senbartelmī)',
        'fr_CA' => 'franču (Kanāda)',
        'fr_CD' => 'franču (Kongo [Kinšasa])',
        'fr_CF' => 'franču (Centrālāfrikas Republika)',
        'fr_CG' => 'franču (Kongo [Brazavila])',
        'fr_CH' => 'franču (Šveice)',
        'fr_CI' => 'franču (Kotdivuāra)',
        'fr_CM' => 'franču (Kamerūna)',
        'fr_DJ' => 'franču (Džibutija)',
        'fr_DZ' => 'franču (Alžīrija)',
        'fr_FR' => 'franču (Francija)',
        'fr_GA' => 'franču (Gabona)',
        'fr_GF' => 'franču (Francijas Gviāna)',
        'fr_GN' => 'franču (Gvineja)',
        'fr_GP' => 'franču (Gvadelupa)',
        'fr_GQ' => 'franču (Ekvatoriālā Gvineja)',
        'fr_HT' => 'franču (Haiti)',
        'fr_KM' => 'franču (Komoru salas)',
        'fr_LU' => 'franču (Luksemburga)',
        'fr_MA' => 'franču (Maroka)',
        'fr_MC' => 'franču (Monako)',
        'fr_MF' => 'franču (Senmartēna)',
        'fr_MG' => 'franču (Madagaskara)',
        'fr_ML' => 'franču (Mali)',
        'fr_MQ' => 'franču (Martinika)',
        'fr_MR' => 'franču (Mauritānija)',
        'fr_MU' => 'franču (Maurīcija)',
        'fr_NC' => 'franču (Jaunkaledonija)',
        'fr_NE' => 'franču (Nigēra)',
        'fr_PF' => 'franču (Francijas Polinēzija)',
        'fr_PM' => 'franču (Senpjēra un Mikelona)',
        'fr_RE' => 'franču (Reinjona)',
        'fr_RW' => 'franču (Ruanda)',
        'fr_SC' => 'franču (Seišelu salas)',
        'fr_SN' => 'franču (Senegāla)',
        'fr_SY' => 'franču (Sīrija)',
        'fr_TD' => 'franču (Čada)',
        'fr_TG' => 'franču (Togo)',
        'fr_TN' => 'franču (Tunisija)',
        'fr_VU' => 'franču (Vanuatu)',
        'fr_WF' => 'franču (Volisa un Futunas salas)',
        'fr_YT' => 'franču (Majota)',
        'fy' => 'rietumfrīzu',
        'fy_NL' => 'rietumfrīzu (Nīderlande)',
        'ga' => 'īru',
        'ga_GB' => 'īru (Apvienotā Karaliste)',
        'ga_IE' => 'īru (Īrija)',
        'gd' => 'skotu gēlu',
        'gd_GB' => 'skotu gēlu (Apvienotā Karaliste)',
        'gl' => 'galisiešu',
        'gl_ES' => 'galisiešu (Spānija)',
        'gu' => 'gudžaratu',
        'gu_IN' => 'gudžaratu (Indija)',
        'gv' => 'meniešu',
        'gv_IM' => 'meniešu (Menas sala)',
        'ha' => 'hausu',
        'ha_GH' => 'hausu (Gana)',
        'ha_NE' => 'hausu (Nigēra)',
        'ha_NG' => 'hausu (Nigērija)',
        'he' => 'ivrits',
        'he_IL' => 'ivrits (Izraēla)',
        'hi' => 'hindi',
        'hi_IN' => 'hindi (Indija)',
        'hi_Latn' => 'hindi (latīņu)',
        'hi_Latn_IN' => 'hindi (latīņu, Indija)',
        'hr' => 'horvātu',
        'hr_BA' => 'horvātu (Bosnija un Hercegovina)',
        'hr_HR' => 'horvātu (Horvātija)',
        'hu' => 'ungāru',
        'hu_HU' => 'ungāru (Ungārija)',
        'hy' => 'armēņu',
        'hy_AM' => 'armēņu (Armēnija)',
        'ia' => 'interlingva',
        'ia_001' => 'interlingva (pasaule)',
        'id' => 'indonēziešu',
        'id_ID' => 'indonēziešu (Indonēzija)',
        'ie' => 'interlingve',
        'ie_EE' => 'interlingve (Igaunija)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigērija)',
        'ii' => 'Sičuaņas ji',
        'ii_CN' => 'Sičuaņas ji (Ķīna)',
        'is' => 'islandiešu',
        'is_IS' => 'islandiešu (Islande)',
        'it' => 'itāļu',
        'it_CH' => 'itāļu (Šveice)',
        'it_IT' => 'itāļu (Itālija)',
        'it_SM' => 'itāļu (Sanmarīno)',
        'it_VA' => 'itāļu (Vatikāns)',
        'ja' => 'japāņu',
        'ja_JP' => 'japāņu (Japāna)',
        'jv' => 'javiešu',
        'jv_ID' => 'javiešu (Indonēzija)',
        'ka' => 'gruzīnu',
        'ka_GE' => 'gruzīnu (Gruzija)',
        'ki' => 'kikuju',
        'ki_KE' => 'kikuju (Kenija)',
        'kk' => 'kazahu',
        'kk_Arab' => 'kazahu (arābu)',
        'kk_Arab_CN' => 'kazahu (arābu, Ķīna)',
        'kk_Cyrl' => 'kazahu (kirilica)',
        'kk_Cyrl_KZ' => 'kazahu (kirilica, Kazahstāna)',
        'kk_KZ' => 'kazahu (Kazahstāna)',
        'kl' => 'grenlandiešu',
        'kl_GL' => 'grenlandiešu (Grenlande)',
        'km' => 'khmeru',
        'km_KH' => 'khmeru (Kambodža)',
        'kn' => 'kannadu',
        'kn_IN' => 'kannadu (Indija)',
        'ko' => 'korejiešu',
        'ko_CN' => 'korejiešu (Ķīna)',
        'ko_KP' => 'korejiešu (Ziemeļkoreja)',
        'ko_KR' => 'korejiešu (Dienvidkoreja)',
        'ks' => 'kašmiriešu',
        'ks_Arab' => 'kašmiriešu (arābu)',
        'ks_Arab_IN' => 'kašmiriešu (arābu, Indija)',
        'ks_Deva' => 'kašmiriešu (dēvanāgari)',
        'ks_Deva_IN' => 'kašmiriešu (dēvanāgari, Indija)',
        'ks_IN' => 'kašmiriešu (Indija)',
        'ku' => 'kurdu',
        'ku_Latn' => 'kurdu (latīņu)',
        'ku_Latn_IQ' => 'kurdu (latīņu, Irāka)',
        'ku_Latn_SY' => 'kurdu (latīņu, Sīrija)',
        'ku_Latn_TR' => 'kurdu (latīņu, Turcija)',
        'ku_SY' => 'kurdu (Sīrija)',
        'ku_TR' => 'kurdu (Turcija)',
        'kw' => 'korniešu',
        'kw_GB' => 'korniešu (Apvienotā Karaliste)',
        'ky' => 'kirgīzu',
        'ky_KG' => 'kirgīzu (Kirgizstāna)',
        'lb' => 'luksemburgiešu',
        'lb_LU' => 'luksemburgiešu (Luksemburga)',
        'lg' => 'gandu',
        'lg_UG' => 'gandu (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongo [Kinšasa])',
        'ln_CF' => 'lingala (Centrālāfrikas Republika)',
        'ln_CG' => 'lingala (Kongo [Brazavila])',
        'lo' => 'laosiešu',
        'lo_LA' => 'laosiešu (Laosa)',
        'lt' => 'lietuviešu',
        'lt_LT' => 'lietuviešu (Lietuva)',
        'lu' => 'lubakatanga',
        'lu_CD' => 'lubakatanga (Kongo [Kinšasa])',
        'lv' => 'latviešu',
        'lv_LV' => 'latviešu (Latvija)',
        'mg' => 'malagasu',
        'mg_MG' => 'malagasu (Madagaskara)',
        'mi' => 'maoru',
        'mi_NZ' => 'maoru (Jaunzēlande)',
        'mk' => 'maķedoniešu',
        'mk_MK' => 'maķedoniešu (Ziemeļmaķedonija)',
        'ml' => 'malajalu',
        'ml_IN' => 'malajalu (Indija)',
        'mn' => 'mongoļu',
        'mn_MN' => 'mongoļu (Mongolija)',
        'mr' => 'marathu',
        'mr_IN' => 'marathu (Indija)',
        'ms' => 'malajiešu',
        'ms_BN' => 'malajiešu (Bruneja)',
        'ms_ID' => 'malajiešu (Indonēzija)',
        'ms_MY' => 'malajiešu (Malaizija)',
        'ms_SG' => 'malajiešu (Singapūra)',
        'mt' => 'maltiešu',
        'mt_MT' => 'maltiešu (Malta)',
        'my' => 'birmiešu',
        'my_MM' => 'birmiešu (Mjanma [Birma])',
        'nb' => 'norvēģu bukmols',
        'nb_NO' => 'norvēģu bukmols (Norvēģija)',
        'nb_SJ' => 'norvēģu bukmols (Svalbāra un Jana Majena sala)',
        'nd' => 'ziemeļndebelu',
        'nd_ZW' => 'ziemeļndebelu (Zimbabve)',
        'ne' => 'nepāliešu',
        'ne_IN' => 'nepāliešu (Indija)',
        'ne_NP' => 'nepāliešu (Nepāla)',
        'nl' => 'holandiešu',
        'nl_AW' => 'holandiešu (Aruba)',
        'nl_BE' => 'holandiešu (Beļģija)',
        'nl_BQ' => 'holandiešu (Nīderlandes Karību salas)',
        'nl_CW' => 'holandiešu (Kirasao)',
        'nl_NL' => 'holandiešu (Nīderlande)',
        'nl_SR' => 'holandiešu (Surinama)',
        'nl_SX' => 'holandiešu (Sintmārtena)',
        'nn' => 'jaunnorvēģu',
        'nn_NO' => 'jaunnorvēģu (Norvēģija)',
        'no' => 'norvēģu',
        'no_NO' => 'norvēģu (Norvēģija)',
        'oc' => 'oksitāņu',
        'oc_ES' => 'oksitāņu (Spānija)',
        'oc_FR' => 'oksitāņu (Francija)',
        'om' => 'oromu',
        'om_ET' => 'oromu (Etiopija)',
        'om_KE' => 'oromu (Kenija)',
        'or' => 'oriju',
        'or_IN' => 'oriju (Indija)',
        'os' => 'osetīnu',
        'os_GE' => 'osetīnu (Gruzija)',
        'os_RU' => 'osetīnu (Krievija)',
        'pa' => 'pandžabu',
        'pa_Arab' => 'pandžabu (arābu)',
        'pa_Arab_PK' => 'pandžabu (arābu, Pakistāna)',
        'pa_Guru' => 'pandžabu (pandžabu)',
        'pa_Guru_IN' => 'pandžabu (pandžabu, Indija)',
        'pa_IN' => 'pandžabu (Indija)',
        'pa_PK' => 'pandžabu (Pakistāna)',
        'pl' => 'poļu',
        'pl_PL' => 'poļu (Polija)',
        'ps' => 'puštu',
        'ps_AF' => 'puštu (Afganistāna)',
        'ps_PK' => 'puštu (Pakistāna)',
        'pt' => 'portugāļu',
        'pt_AO' => 'portugāļu (Angola)',
        'pt_BR' => 'portugāļu (Brazīlija)',
        'pt_CH' => 'portugāļu (Šveice)',
        'pt_CV' => 'portugāļu (Kaboverde)',
        'pt_GQ' => 'portugāļu (Ekvatoriālā Gvineja)',
        'pt_GW' => 'portugāļu (Gvineja-Bisava)',
        'pt_LU' => 'portugāļu (Luksemburga)',
        'pt_MO' => 'portugāļu (ĶTR īpašais administratīvais reģions Makao)',
        'pt_MZ' => 'portugāļu (Mozambika)',
        'pt_PT' => 'portugāļu (Portugāle)',
        'pt_ST' => 'portugāļu (Santome un Prinsipi)',
        'pt_TL' => 'portugāļu (Austrumtimora)',
        'qu' => 'kečvu',
        'qu_BO' => 'kečvu (Bolīvija)',
        'qu_EC' => 'kečvu (Ekvadora)',
        'qu_PE' => 'kečvu (Peru)',
        'rm' => 'retoromāņu',
        'rm_CH' => 'retoromāņu (Šveice)',
        'rn' => 'rundu',
        'rn_BI' => 'rundu (Burundija)',
        'ro' => 'rumāņu',
        'ro_MD' => 'rumāņu (Moldova)',
        'ro_RO' => 'rumāņu (Rumānija)',
        'ru' => 'krievu',
        'ru_BY' => 'krievu (Baltkrievija)',
        'ru_KG' => 'krievu (Kirgizstāna)',
        'ru_KZ' => 'krievu (Kazahstāna)',
        'ru_MD' => 'krievu (Moldova)',
        'ru_RU' => 'krievu (Krievija)',
        'ru_UA' => 'krievu (Ukraina)',
        'rw' => 'kiņaruanda',
        'rw_RW' => 'kiņaruanda (Ruanda)',
        'sa' => 'sanskrits',
        'sa_IN' => 'sanskrits (Indija)',
        'sc' => 'sardīniešu',
        'sc_IT' => 'sardīniešu (Itālija)',
        'sd' => 'sindhu',
        'sd_Arab' => 'sindhu (arābu)',
        'sd_Arab_PK' => 'sindhu (arābu, Pakistāna)',
        'sd_Deva' => 'sindhu (dēvanāgari)',
        'sd_Deva_IN' => 'sindhu (dēvanāgari, Indija)',
        'sd_IN' => 'sindhu (Indija)',
        'sd_PK' => 'sindhu (Pakistāna)',
        'se' => 'ziemeļsāmu',
        'se_FI' => 'ziemeļsāmu (Somija)',
        'se_NO' => 'ziemeļsāmu (Norvēģija)',
        'se_SE' => 'ziemeļsāmu (Zviedrija)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Centrālāfrikas Republika)',
        'sh' => 'serbu–horvātu',
        'sh_BA' => 'serbu–horvātu (Bosnija un Hercegovina)',
        'si' => 'singāļu',
        'si_LK' => 'singāļu (Šrilanka)',
        'sk' => 'slovāku',
        'sk_SK' => 'slovāku (Slovākija)',
        'sl' => 'slovēņu',
        'sl_SI' => 'slovēņu (Slovēnija)',
        'sn' => 'šonu',
        'sn_ZW' => 'šonu (Zimbabve)',
        'so' => 'somāļu',
        'so_DJ' => 'somāļu (Džibutija)',
        'so_ET' => 'somāļu (Etiopija)',
        'so_KE' => 'somāļu (Kenija)',
        'so_SO' => 'somāļu (Somālija)',
        'sq' => 'albāņu',
        'sq_AL' => 'albāņu (Albānija)',
        'sq_MK' => 'albāņu (Ziemeļmaķedonija)',
        'sr' => 'serbu',
        'sr_BA' => 'serbu (Bosnija un Hercegovina)',
        'sr_Cyrl' => 'serbu (kirilica)',
        'sr_Cyrl_BA' => 'serbu (kirilica, Bosnija un Hercegovina)',
        'sr_Cyrl_ME' => 'serbu (kirilica, Melnkalne)',
        'sr_Cyrl_RS' => 'serbu (kirilica, Serbija)',
        'sr_Latn' => 'serbu (latīņu)',
        'sr_Latn_BA' => 'serbu (latīņu, Bosnija un Hercegovina)',
        'sr_Latn_ME' => 'serbu (latīņu, Melnkalne)',
        'sr_Latn_RS' => 'serbu (latīņu, Serbija)',
        'sr_ME' => 'serbu (Melnkalne)',
        'sr_RS' => 'serbu (Serbija)',
        'st' => 'dienvidsotu',
        'st_LS' => 'dienvidsotu (Lesoto)',
        'st_ZA' => 'dienvidsotu (Dienvidāfrikas Republika)',
        'su' => 'zundu',
        'su_ID' => 'zundu (Indonēzija)',
        'su_Latn' => 'zundu (latīņu)',
        'su_Latn_ID' => 'zundu (latīņu, Indonēzija)',
        'sv' => 'zviedru',
        'sv_AX' => 'zviedru (Olandes salas)',
        'sv_FI' => 'zviedru (Somija)',
        'sv_SE' => 'zviedru (Zviedrija)',
        'sw' => 'svahili',
        'sw_CD' => 'svahili (Kongo [Kinšasa])',
        'sw_KE' => 'svahili (Kenija)',
        'sw_TZ' => 'svahili (Tanzānija)',
        'sw_UG' => 'svahili (Uganda)',
        'ta' => 'tamilu',
        'ta_IN' => 'tamilu (Indija)',
        'ta_LK' => 'tamilu (Šrilanka)',
        'ta_MY' => 'tamilu (Malaizija)',
        'ta_SG' => 'tamilu (Singapūra)',
        'te' => 'telugu',
        'te_IN' => 'telugu (Indija)',
        'tg' => 'tadžiku',
        'tg_TJ' => 'tadžiku (Tadžikistāna)',
        'th' => 'taju',
        'th_TH' => 'taju (Taizeme)',
        'ti' => 'tigrinja',
        'ti_ER' => 'tigrinja (Eritreja)',
        'ti_ET' => 'tigrinja (Etiopija)',
        'tk' => 'turkmēņu',
        'tk_TM' => 'turkmēņu (Turkmenistāna)',
        'tl' => 'tagalu',
        'tl_PH' => 'tagalu (Filipīnas)',
        'tn' => 'cvanu',
        'tn_BW' => 'cvanu (Botsvāna)',
        'tn_ZA' => 'cvanu (Dienvidāfrikas Republika)',
        'to' => 'tongiešu',
        'to_TO' => 'tongiešu (Tonga)',
        'tr' => 'turku',
        'tr_CY' => 'turku (Kipra)',
        'tr_TR' => 'turku (Turcija)',
        'tt' => 'tatāru',
        'tt_RU' => 'tatāru (Krievija)',
        'ug' => 'uiguru',
        'ug_CN' => 'uiguru (Ķīna)',
        'uk' => 'ukraiņu',
        'uk_UA' => 'ukraiņu (Ukraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (Indija)',
        'ur_PK' => 'urdu (Pakistāna)',
        'uz' => 'uzbeku',
        'uz_AF' => 'uzbeku (Afganistāna)',
        'uz_Arab' => 'uzbeku (arābu)',
        'uz_Arab_AF' => 'uzbeku (arābu, Afganistāna)',
        'uz_Cyrl' => 'uzbeku (kirilica)',
        'uz_Cyrl_UZ' => 'uzbeku (kirilica, Uzbekistāna)',
        'uz_Latn' => 'uzbeku (latīņu)',
        'uz_Latn_UZ' => 'uzbeku (latīņu, Uzbekistāna)',
        'uz_UZ' => 'uzbeku (Uzbekistāna)',
        'vi' => 'vjetnamiešu',
        'vi_VN' => 'vjetnamiešu (Vjetnama)',
        'wo' => 'volofu',
        'wo_SN' => 'volofu (Senegāla)',
        'xh' => 'khosu',
        'xh_ZA' => 'khosu (Dienvidāfrikas Republika)',
        'yi' => 'jidišs',
        'yi_UA' => 'jidišs (Ukraina)',
        'yo' => 'jorubu',
        'yo_BJ' => 'jorubu (Benina)',
        'yo_NG' => 'jorubu (Nigērija)',
        'za' => 'džuanu',
        'za_CN' => 'džuanu (Ķīna)',
        'zh' => 'ķīniešu',
        'zh_CN' => 'ķīniešu (Ķīna)',
        'zh_HK' => 'ķīniešu (Ķīnas īpašās pārvaldes apgabals Honkonga)',
        'zh_Hans' => 'ķīniešu (vienkāršotā)',
        'zh_Hans_CN' => 'ķīniešu (vienkāršotā, Ķīna)',
        'zh_Hans_HK' => 'ķīniešu (vienkāršotā, Ķīnas īpašās pārvaldes apgabals Honkonga)',
        'zh_Hans_MO' => 'ķīniešu (vienkāršotā, ĶTR īpašais administratīvais reģions Makao)',
        'zh_Hans_MY' => 'ķīniešu (vienkāršotā, Malaizija)',
        'zh_Hans_SG' => 'ķīniešu (vienkāršotā, Singapūra)',
        'zh_Hant' => 'ķīniešu (tradicionālā)',
        'zh_Hant_HK' => 'ķīniešu (tradicionālā, Ķīnas īpašās pārvaldes apgabals Honkonga)',
        'zh_Hant_MO' => 'ķīniešu (tradicionālā, ĶTR īpašais administratīvais reģions Makao)',
        'zh_Hant_MY' => 'ķīniešu (tradicionālā, Malaizija)',
        'zh_Hant_TW' => 'ķīniešu (tradicionālā, Taivāna)',
        'zh_MO' => 'ķīniešu (ĶTR īpašais administratīvais reģions Makao)',
        'zh_SG' => 'ķīniešu (Singapūra)',
        'zh_TW' => 'ķīniešu (Taivāna)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Dienvidāfrikas Republika)',
    ],
];
