<?php

return [
    'Names' => [
        'af' => 'แอฟริกานส์',
        'af_NA' => 'แอฟริกานส์ (นามิเบีย)',
        'af_ZA' => 'แอฟริกานส์ (แอฟริกาใต้)',
        'ak' => 'อาคาน',
        'ak_GH' => 'อาคาน (กานา)',
        'am' => 'อัมฮารา',
        'am_ET' => 'อัมฮารา (เอธิโอเปีย)',
        'ar' => 'อาหรับ',
        'ar_001' => 'อาหรับ (โลก)',
        'ar_AE' => 'อาหรับ (สหรัฐอาหรับเอมิเรตส์)',
        'ar_BH' => 'อาหรับ (บาห์เรน)',
        'ar_DJ' => 'อาหรับ (จิบูตี)',
        'ar_DZ' => 'อาหรับ (แอลจีเรีย)',
        'ar_EG' => 'อาหรับ (อียิปต์)',
        'ar_EH' => 'อาหรับ (ซาฮาราตะวันตก)',
        'ar_ER' => 'อาหรับ (เอริเทรีย)',
        'ar_IL' => 'อาหรับ (อิสราเอล)',
        'ar_IQ' => 'อาหรับ (อิรัก)',
        'ar_JO' => 'อาหรับ (จอร์แดน)',
        'ar_KM' => 'อาหรับ (คอโมโรส)',
        'ar_KW' => 'อาหรับ (คูเวต)',
        'ar_LB' => 'อาหรับ (เลบานอน)',
        'ar_LY' => 'อาหรับ (ลิเบีย)',
        'ar_MA' => 'อาหรับ (โมร็อกโก)',
        'ar_MR' => 'อาหรับ (มอริเตเนีย)',
        'ar_OM' => 'อาหรับ (โอมาน)',
        'ar_PS' => 'อาหรับ (ดินแดนปาเลสไตน์)',
        'ar_QA' => 'อาหรับ (กาตาร์)',
        'ar_SA' => 'อาหรับ (ซาอุดีอาระเบีย)',
        'ar_SD' => 'อาหรับ (ซูดาน)',
        'ar_SO' => 'อาหรับ (โซมาเลีย)',
        'ar_SS' => 'อาหรับ (ซูดานใต้)',
        'ar_SY' => 'อาหรับ (ซีเรีย)',
        'ar_TD' => 'อาหรับ (ชาด)',
        'ar_TN' => 'อาหรับ (ตูนิเซีย)',
        'ar_YE' => 'อาหรับ (เยเมน)',
        'as' => 'อัสสัม',
        'as_IN' => 'อัสสัม (อินเดีย)',
        'az' => 'อาเซอร์ไบจาน',
        'az_AZ' => 'อาเซอร์ไบจาน (อาเซอร์ไบจาน)',
        'az_Cyrl' => 'อาเซอร์ไบจาน (ซีริลลิก)',
        'az_Cyrl_AZ' => 'อาเซอร์ไบจาน (ซีริลลิก, อาเซอร์ไบจาน)',
        'az_Latn' => 'อาเซอร์ไบจาน (ละติน)',
        'az_Latn_AZ' => 'อาเซอร์ไบจาน (ละติน, อาเซอร์ไบจาน)',
        'ba' => 'บัชคีร์',
        'ba_RU' => 'บัชคีร์ (รัสเซีย)',
        'be' => 'เบลารุส',
        'be_BY' => 'เบลารุส (เบลารุส)',
        'bg' => 'บัลแกเรีย',
        'bg_BG' => 'บัลแกเรีย (บัลแกเรีย)',
        'bm' => 'บัมบารา',
        'bm_ML' => 'บัมบารา (มาลี)',
        'bn' => 'บังกลา',
        'bn_BD' => 'บังกลา (บังกลาเทศ)',
        'bn_IN' => 'บังกลา (อินเดีย)',
        'bo' => 'ทิเบต',
        'bo_CN' => 'ทิเบต (จีน)',
        'bo_IN' => 'ทิเบต (อินเดีย)',
        'br' => 'เบรตัน',
        'br_FR' => 'เบรตัน (ฝรั่งเศส)',
        'bs' => 'บอสเนีย',
        'bs_BA' => 'บอสเนีย (บอสเนียและเฮอร์เซโกวีนา)',
        'bs_Cyrl' => 'บอสเนีย (ซีริลลิก)',
        'bs_Cyrl_BA' => 'บอสเนีย (ซีริลลิก, บอสเนียและเฮอร์เซโกวีนา)',
        'bs_Latn' => 'บอสเนีย (ละติน)',
        'bs_Latn_BA' => 'บอสเนีย (ละติน, บอสเนียและเฮอร์เซโกวีนา)',
        'ca' => 'คาตาลัน',
        'ca_AD' => 'คาตาลัน (อันดอร์รา)',
        'ca_ES' => 'คาตาลัน (สเปน)',
        'ca_FR' => 'คาตาลัน (ฝรั่งเศส)',
        'ca_IT' => 'คาตาลัน (อิตาลี)',
        'ce' => 'เชเชน',
        'ce_RU' => 'เชเชน (รัสเซีย)',
        'cs' => 'เช็ก',
        'cs_CZ' => 'เช็ก (เช็ก)',
        'cv' => 'ชูวัช',
        'cv_RU' => 'ชูวัช (รัสเซีย)',
        'cy' => 'เวลส์',
        'cy_GB' => 'เวลส์ (สหราชอาณาจักร)',
        'da' => 'เดนมาร์ก',
        'da_DK' => 'เดนมาร์ก (เดนมาร์ก)',
        'da_GL' => 'เดนมาร์ก (กรีนแลนด์)',
        'de' => 'เยอรมัน',
        'de_AT' => 'เยอรมัน (ออสเตรีย)',
        'de_BE' => 'เยอรมัน (เบลเยียม)',
        'de_CH' => 'เยอรมัน (สวิตเซอร์แลนด์)',
        'de_DE' => 'เยอรมัน (เยอรมนี)',
        'de_IT' => 'เยอรมัน (อิตาลี)',
        'de_LI' => 'เยอรมัน (ลิกเตนสไตน์)',
        'de_LU' => 'เยอรมัน (ลักเซมเบิร์ก)',
        'dz' => 'ซองคา',
        'dz_BT' => 'ซองคา (ภูฏาน)',
        'ee' => 'เอเว',
        'ee_GH' => 'เอเว (กานา)',
        'ee_TG' => 'เอเว (โตโก)',
        'el' => 'กรีก',
        'el_CY' => 'กรีก (ไซปรัส)',
        'el_GR' => 'กรีก (กรีซ)',
        'en' => 'อังกฤษ',
        'en_001' => 'อังกฤษ (โลก)',
        'en_150' => 'อังกฤษ (ยุโรป)',
        'en_AE' => 'อังกฤษ (สหรัฐอาหรับเอมิเรตส์)',
        'en_AG' => 'อังกฤษ (แอนติกาและบาร์บูดา)',
        'en_AI' => 'อังกฤษ (แองกวิลลา)',
        'en_AS' => 'อังกฤษ (อเมริกันซามัว)',
        'en_AT' => 'อังกฤษ (ออสเตรีย)',
        'en_AU' => 'อังกฤษ (ออสเตรเลีย)',
        'en_BB' => 'อังกฤษ (บาร์เบโดส)',
        'en_BE' => 'อังกฤษ (เบลเยียม)',
        'en_BI' => 'อังกฤษ (บุรุนดี)',
        'en_BM' => 'อังกฤษ (เบอร์มิวดา)',
        'en_BS' => 'อังกฤษ (บาฮามาส)',
        'en_BW' => 'อังกฤษ (บอตสวานา)',
        'en_BZ' => 'อังกฤษ (เบลีซ)',
        'en_CA' => 'อังกฤษ (แคนาดา)',
        'en_CC' => 'อังกฤษ (หมู่เกาะโคโคส [คีลิง])',
        'en_CH' => 'อังกฤษ (สวิตเซอร์แลนด์)',
        'en_CK' => 'อังกฤษ (หมู่เกาะคุก)',
        'en_CM' => 'อังกฤษ (แคเมอรูน)',
        'en_CX' => 'อังกฤษ (เกาะคริสต์มาส)',
        'en_CY' => 'อังกฤษ (ไซปรัส)',
        'en_CZ' => 'อังกฤษ (เช็ก)',
        'en_DE' => 'อังกฤษ (เยอรมนี)',
        'en_DK' => 'อังกฤษ (เดนมาร์ก)',
        'en_DM' => 'อังกฤษ (โดมินิกา)',
        'en_EE' => 'อังกฤษ (เอสโตเนีย)',
        'en_ER' => 'อังกฤษ (เอริเทรีย)',
        'en_ES' => 'อังกฤษ (สเปน)',
        'en_FI' => 'อังกฤษ (ฟินแลนด์)',
        'en_FJ' => 'อังกฤษ (ฟิจิ)',
        'en_FK' => 'อังกฤษ (หมู่เกาะฟอล์กแลนด์)',
        'en_FM' => 'อังกฤษ (ไมโครนีเซีย)',
        'en_FR' => 'อังกฤษ (ฝรั่งเศส)',
        'en_GB' => 'อังกฤษ (สหราชอาณาจักร)',
        'en_GD' => 'อังกฤษ (เกรเนดา)',
        'en_GE' => 'อังกฤษ (จอร์เจีย)',
        'en_GG' => 'อังกฤษ (เกิร์นซีย์)',
        'en_GH' => 'อังกฤษ (กานา)',
        'en_GI' => 'อังกฤษ (ยิบรอลตาร์)',
        'en_GM' => 'อังกฤษ (แกมเบีย)',
        'en_GS' => 'อังกฤษ (เกาะเซาท์จอร์เจียและหมู่เกาะเซาท์แซนด์วิช)',
        'en_GU' => 'อังกฤษ (กวม)',
        'en_GY' => 'อังกฤษ (กายอานา)',
        'en_HK' => 'อังกฤษ (เขตปกครองพิเศษฮ่องกงแห่งสาธารณรัฐประชาชนจีน)',
        'en_HU' => 'อังกฤษ (ฮังการี)',
        'en_ID' => 'อังกฤษ (อินโดนีเซีย)',
        'en_IE' => 'อังกฤษ (ไอร์แลนด์)',
        'en_IL' => 'อังกฤษ (อิสราเอล)',
        'en_IM' => 'อังกฤษ (เกาะแมน)',
        'en_IN' => 'อังกฤษ (อินเดีย)',
        'en_IO' => 'อังกฤษ (บริติชอินเดียนโอเชียนเทร์ริทอรี)',
        'en_IT' => 'อังกฤษ (อิตาลี)',
        'en_JE' => 'อังกฤษ (เจอร์ซีย์)',
        'en_JM' => 'อังกฤษ (จาเมกา)',
        'en_JP' => 'อังกฤษ (ญี่ปุ่น)',
        'en_KE' => 'อังกฤษ (เคนยา)',
        'en_KI' => 'อังกฤษ (คิริบาส)',
        'en_KN' => 'อังกฤษ (เซนต์คิตส์และเนวิส)',
        'en_KY' => 'อังกฤษ (หมู่เกาะเคย์แมน)',
        'en_LC' => 'อังกฤษ (เซนต์ลูเซีย)',
        'en_LR' => 'อังกฤษ (ไลบีเรีย)',
        'en_LS' => 'อังกฤษ (เลโซโท)',
        'en_LT' => 'อังกฤษ (ลิทัวเนีย)',
        'en_LV' => 'อังกฤษ (ลัตเวีย)',
        'en_MG' => 'อังกฤษ (มาดากัสการ์)',
        'en_MH' => 'อังกฤษ (หมู่เกาะมาร์แชลล์)',
        'en_MO' => 'อังกฤษ (เขตปกครองพิเศษมาเก๊าแห่งสาธารณรัฐประชาชนจีน)',
        'en_MP' => 'อังกฤษ (หมู่เกาะนอร์เทิร์นมาเรียนา)',
        'en_MS' => 'อังกฤษ (มอนต์เซอร์รัต)',
        'en_MT' => 'อังกฤษ (มอลตา)',
        'en_MU' => 'อังกฤษ (มอริเชียส)',
        'en_MV' => 'อังกฤษ (มัลดีฟส์)',
        'en_MW' => 'อังกฤษ (มาลาวี)',
        'en_MY' => 'อังกฤษ (มาเลเซีย)',
        'en_NA' => 'อังกฤษ (นามิเบีย)',
        'en_NF' => 'อังกฤษ (เกาะนอร์ฟอล์ก)',
        'en_NG' => 'อังกฤษ (ไนจีเรีย)',
        'en_NL' => 'อังกฤษ (เนเธอร์แลนด์)',
        'en_NO' => 'อังกฤษ (นอร์เวย์)',
        'en_NR' => 'อังกฤษ (นาอูรู)',
        'en_NU' => 'อังกฤษ (นีอูเอ)',
        'en_NZ' => 'อังกฤษ (นิวซีแลนด์)',
        'en_PG' => 'อังกฤษ (ปาปัวนิวกินี)',
        'en_PH' => 'อังกฤษ (ฟิลิปปินส์)',
        'en_PK' => 'อังกฤษ (ปากีสถาน)',
        'en_PL' => 'อังกฤษ (โปแลนด์)',
        'en_PN' => 'อังกฤษ (หมู่เกาะพิตแคร์น)',
        'en_PR' => 'อังกฤษ (เปอร์โตริโก)',
        'en_PT' => 'อังกฤษ (โปรตุเกส)',
        'en_PW' => 'อังกฤษ (ปาเลา)',
        'en_RO' => 'อังกฤษ (โรมาเนีย)',
        'en_RW' => 'อังกฤษ (รวันดา)',
        'en_SB' => 'อังกฤษ (หมู่เกาะโซโลมอน)',
        'en_SC' => 'อังกฤษ (เซเชลส์)',
        'en_SD' => 'อังกฤษ (ซูดาน)',
        'en_SE' => 'อังกฤษ (สวีเดน)',
        'en_SG' => 'อังกฤษ (สิงคโปร์)',
        'en_SH' => 'อังกฤษ (เซนต์เฮเลนา)',
        'en_SI' => 'อังกฤษ (สโลวีเนีย)',
        'en_SK' => 'อังกฤษ (สโลวะเกีย)',
        'en_SL' => 'อังกฤษ (เซียร์ราลีโอน)',
        'en_SS' => 'อังกฤษ (ซูดานใต้)',
        'en_SX' => 'อังกฤษ (ซินต์มาร์เทน)',
        'en_SZ' => 'อังกฤษ (เอสวาตีนี)',
        'en_TC' => 'อังกฤษ (หมู่เกาะเติกส์และหมู่เกาะเคคอส)',
        'en_TK' => 'อังกฤษ (โตเกเลา)',
        'en_TO' => 'อังกฤษ (ตองกา)',
        'en_TT' => 'อังกฤษ (ตรินิแดดและโตเบโก)',
        'en_TV' => 'อังกฤษ (ตูวาลู)',
        'en_TZ' => 'อังกฤษ (แทนซาเนีย)',
        'en_UA' => 'อังกฤษ (ยูเครน)',
        'en_UG' => 'อังกฤษ (ยูกันดา)',
        'en_UM' => 'อังกฤษ (หมู่เกาะรอบนอกของสหรัฐอเมริกา)',
        'en_US' => 'อังกฤษ (สหรัฐอเมริกา)',
        'en_VC' => 'อังกฤษ (เซนต์วินเซนต์และเกรนาดีนส์)',
        'en_VG' => 'อังกฤษ (หมู่เกาะบริติชเวอร์จิน)',
        'en_VI' => 'อังกฤษ (หมู่เกาะเวอร์จินของสหรัฐอเมริกา)',
        'en_VU' => 'อังกฤษ (วานูอาตู)',
        'en_WS' => 'อังกฤษ (ซามัว)',
        'en_ZA' => 'อังกฤษ (แอฟริกาใต้)',
        'en_ZM' => 'อังกฤษ (แซมเบีย)',
        'en_ZW' => 'อังกฤษ (ซิมบับเว)',
        'eo' => 'เอสเปรันโต',
        'eo_001' => 'เอสเปรันโต (โลก)',
        'es' => 'สเปน',
        'es_419' => 'สเปน (ละตินอเมริกา)',
        'es_AR' => 'สเปน (อาร์เจนตินา)',
        'es_BO' => 'สเปน (โบลิเวีย)',
        'es_BR' => 'สเปน (บราซิล)',
        'es_BZ' => 'สเปน (เบลีซ)',
        'es_CL' => 'สเปน (ชิลี)',
        'es_CO' => 'สเปน (โคลอมเบีย)',
        'es_CR' => 'สเปน (คอสตาริกา)',
        'es_CU' => 'สเปน (คิวบา)',
        'es_DO' => 'สเปน (สาธารณรัฐโดมินิกัน)',
        'es_EC' => 'สเปน (เอกวาดอร์)',
        'es_ES' => 'สเปน (สเปน)',
        'es_GQ' => 'สเปน (อิเควทอเรียลกินี)',
        'es_GT' => 'สเปน (กัวเตมาลา)',
        'es_HN' => 'สเปน (ฮอนดูรัส)',
        'es_MX' => 'สเปน (เม็กซิโก)',
        'es_NI' => 'สเปน (นิการากัว)',
        'es_PA' => 'สเปน (ปานามา)',
        'es_PE' => 'สเปน (เปรู)',
        'es_PH' => 'สเปน (ฟิลิปปินส์)',
        'es_PR' => 'สเปน (เปอร์โตริโก)',
        'es_PY' => 'สเปน (ปารากวัย)',
        'es_SV' => 'สเปน (เอลซัลวาดอร์)',
        'es_US' => 'สเปน (สหรัฐอเมริกา)',
        'es_UY' => 'สเปน (อุรุกวัย)',
        'es_VE' => 'สเปน (เวเนซุเอลา)',
        'et' => 'เอสโตเนีย',
        'et_EE' => 'เอสโตเนีย (เอสโตเนีย)',
        'eu' => 'บาสก์',
        'eu_ES' => 'บาสก์ (สเปน)',
        'fa' => 'เปอร์เซีย',
        'fa_AF' => 'เปอร์เซีย (อัฟกานิสถาน)',
        'fa_IR' => 'เปอร์เซีย (อิหร่าน)',
        'ff' => 'ฟูลาห์',
        'ff_Adlm' => 'ฟูลาห์ (อัดลัม)',
        'ff_Adlm_BF' => 'ฟูลาห์ (อัดลัม, บูร์กินาฟาโซ)',
        'ff_Adlm_CM' => 'ฟูลาห์ (อัดลัม, แคเมอรูน)',
        'ff_Adlm_GH' => 'ฟูลาห์ (อัดลัม, กานา)',
        'ff_Adlm_GM' => 'ฟูลาห์ (อัดลัม, แกมเบีย)',
        'ff_Adlm_GN' => 'ฟูลาห์ (อัดลัม, กินี)',
        'ff_Adlm_GW' => 'ฟูลาห์ (อัดลัม, กินี-บิสเซา)',
        'ff_Adlm_LR' => 'ฟูลาห์ (อัดลัม, ไลบีเรีย)',
        'ff_Adlm_MR' => 'ฟูลาห์ (อัดลัม, มอริเตเนีย)',
        'ff_Adlm_NE' => 'ฟูลาห์ (อัดลัม, ไนเจอร์)',
        'ff_Adlm_NG' => 'ฟูลาห์ (อัดลัม, ไนจีเรีย)',
        'ff_Adlm_SL' => 'ฟูลาห์ (อัดลัม, เซียร์ราลีโอน)',
        'ff_Adlm_SN' => 'ฟูลาห์ (อัดลัม, เซเนกัล)',
        'ff_CM' => 'ฟูลาห์ (แคเมอรูน)',
        'ff_GN' => 'ฟูลาห์ (กินี)',
        'ff_Latn' => 'ฟูลาห์ (ละติน)',
        'ff_Latn_BF' => 'ฟูลาห์ (ละติน, บูร์กินาฟาโซ)',
        'ff_Latn_CM' => 'ฟูลาห์ (ละติน, แคเมอรูน)',
        'ff_Latn_GH' => 'ฟูลาห์ (ละติน, กานา)',
        'ff_Latn_GM' => 'ฟูลาห์ (ละติน, แกมเบีย)',
        'ff_Latn_GN' => 'ฟูลาห์ (ละติน, กินี)',
        'ff_Latn_GW' => 'ฟูลาห์ (ละติน, กินี-บิสเซา)',
        'ff_Latn_LR' => 'ฟูลาห์ (ละติน, ไลบีเรีย)',
        'ff_Latn_MR' => 'ฟูลาห์ (ละติน, มอริเตเนีย)',
        'ff_Latn_NE' => 'ฟูลาห์ (ละติน, ไนเจอร์)',
        'ff_Latn_NG' => 'ฟูลาห์ (ละติน, ไนจีเรีย)',
        'ff_Latn_SL' => 'ฟูลาห์ (ละติน, เซียร์ราลีโอน)',
        'ff_Latn_SN' => 'ฟูลาห์ (ละติน, เซเนกัล)',
        'ff_MR' => 'ฟูลาห์ (มอริเตเนีย)',
        'ff_SN' => 'ฟูลาห์ (เซเนกัล)',
        'fi' => 'ฟินแลนด์',
        'fi_FI' => 'ฟินแลนด์ (ฟินแลนด์)',
        'fo' => 'แฟโร',
        'fo_DK' => 'แฟโร (เดนมาร์ก)',
        'fo_FO' => 'แฟโร (หมู่เกาะแฟโร)',
        'fr' => 'ฝรั่งเศส',
        'fr_BE' => 'ฝรั่งเศส (เบลเยียม)',
        'fr_BF' => 'ฝรั่งเศส (บูร์กินาฟาโซ)',
        'fr_BI' => 'ฝรั่งเศส (บุรุนดี)',
        'fr_BJ' => 'ฝรั่งเศส (เบนิน)',
        'fr_BL' => 'ฝรั่งเศส (เซนต์บาร์เธเลมี)',
        'fr_CA' => 'ฝรั่งเศส (แคนาดา)',
        'fr_CD' => 'ฝรั่งเศส (คองโก - กินชาซา)',
        'fr_CF' => 'ฝรั่งเศส (สาธารณรัฐแอฟริกากลาง)',
        'fr_CG' => 'ฝรั่งเศส (คองโก - บราซซาวิล)',
        'fr_CH' => 'ฝรั่งเศส (สวิตเซอร์แลนด์)',
        'fr_CI' => 'ฝรั่งเศส (โกตดิวัวร์)',
        'fr_CM' => 'ฝรั่งเศส (แคเมอรูน)',
        'fr_DJ' => 'ฝรั่งเศส (จิบูตี)',
        'fr_DZ' => 'ฝรั่งเศส (แอลจีเรีย)',
        'fr_FR' => 'ฝรั่งเศส (ฝรั่งเศส)',
        'fr_GA' => 'ฝรั่งเศส (กาบอง)',
        'fr_GF' => 'ฝรั่งเศส (เฟรนช์เกียนา)',
        'fr_GN' => 'ฝรั่งเศส (กินี)',
        'fr_GP' => 'ฝรั่งเศส (กวาเดอลูป)',
        'fr_GQ' => 'ฝรั่งเศส (อิเควทอเรียลกินี)',
        'fr_HT' => 'ฝรั่งเศส (เฮติ)',
        'fr_KM' => 'ฝรั่งเศส (คอโมโรส)',
        'fr_LU' => 'ฝรั่งเศส (ลักเซมเบิร์ก)',
        'fr_MA' => 'ฝรั่งเศส (โมร็อกโก)',
        'fr_MC' => 'ฝรั่งเศส (โมนาโก)',
        'fr_MF' => 'ฝรั่งเศส (เซนต์มาร์ติน)',
        'fr_MG' => 'ฝรั่งเศส (มาดากัสการ์)',
        'fr_ML' => 'ฝรั่งเศส (มาลี)',
        'fr_MQ' => 'ฝรั่งเศส (มาร์ตินีก)',
        'fr_MR' => 'ฝรั่งเศส (มอริเตเนีย)',
        'fr_MU' => 'ฝรั่งเศส (มอริเชียส)',
        'fr_NC' => 'ฝรั่งเศส (นิวแคลิโดเนีย)',
        'fr_NE' => 'ฝรั่งเศส (ไนเจอร์)',
        'fr_PF' => 'ฝรั่งเศส (เฟรนช์โปลินีเซีย)',
        'fr_PM' => 'ฝรั่งเศส (แซงปีแยร์และมีเกอลง)',
        'fr_RE' => 'ฝรั่งเศส (เรอูนียง)',
        'fr_RW' => 'ฝรั่งเศส (รวันดา)',
        'fr_SC' => 'ฝรั่งเศส (เซเชลส์)',
        'fr_SN' => 'ฝรั่งเศส (เซเนกัล)',
        'fr_SY' => 'ฝรั่งเศส (ซีเรีย)',
        'fr_TD' => 'ฝรั่งเศส (ชาด)',
        'fr_TG' => 'ฝรั่งเศส (โตโก)',
        'fr_TN' => 'ฝรั่งเศส (ตูนิเซีย)',
        'fr_VU' => 'ฝรั่งเศส (วานูอาตู)',
        'fr_WF' => 'ฝรั่งเศส (วาลลิสและฟุตูนา)',
        'fr_YT' => 'ฝรั่งเศส (มายอต)',
        'fy' => 'ฟริเซียนตะวันตก',
        'fy_NL' => 'ฟริเซียนตะวันตก (เนเธอร์แลนด์)',
        'ga' => 'ไอริช',
        'ga_GB' => 'ไอริช (สหราชอาณาจักร)',
        'ga_IE' => 'ไอริช (ไอร์แลนด์)',
        'gd' => 'เกลิกสกอต',
        'gd_GB' => 'เกลิกสกอต (สหราชอาณาจักร)',
        'gl' => 'กาลิเซีย',
        'gl_ES' => 'กาลิเซีย (สเปน)',
        'gu' => 'คุชราต',
        'gu_IN' => 'คุชราต (อินเดีย)',
        'gv' => 'มานซ์',
        'gv_IM' => 'มานซ์ (เกาะแมน)',
        'ha' => 'เฮาซา',
        'ha_GH' => 'เฮาซา (กานา)',
        'ha_NE' => 'เฮาซา (ไนเจอร์)',
        'ha_NG' => 'เฮาซา (ไนจีเรีย)',
        'he' => 'ฮิบรู',
        'he_IL' => 'ฮิบรู (อิสราเอล)',
        'hi' => 'ฮินดี',
        'hi_IN' => 'ฮินดี (อินเดีย)',
        'hi_Latn' => 'ฮินดี (ละติน)',
        'hi_Latn_IN' => 'ฮินดี (ละติน, อินเดีย)',
        'hr' => 'โครเอเชีย',
        'hr_BA' => 'โครเอเชีย (บอสเนียและเฮอร์เซโกวีนา)',
        'hr_HR' => 'โครเอเชีย (โครเอเชีย)',
        'hu' => 'ฮังการี',
        'hu_HU' => 'ฮังการี (ฮังการี)',
        'hy' => 'อาร์เมเนีย',
        'hy_AM' => 'อาร์เมเนีย (อาร์เมเนีย)',
        'ia' => 'อินเตอร์ลิงกัว',
        'ia_001' => 'อินเตอร์ลิงกัว (โลก)',
        'id' => 'อินโดนีเซีย',
        'id_ID' => 'อินโดนีเซีย (อินโดนีเซีย)',
        'ie' => 'อินเตอร์ลิงกิว',
        'ie_EE' => 'อินเตอร์ลิงกิว (เอสโตเนีย)',
        'ig' => 'อิกโบ',
        'ig_NG' => 'อิกโบ (ไนจีเรีย)',
        'ii' => 'เสฉวนยี่',
        'ii_CN' => 'เสฉวนยี่ (จีน)',
        'is' => 'ไอซ์แลนด์',
        'is_IS' => 'ไอซ์แลนด์ (ไอซ์แลนด์)',
        'it' => 'อิตาลี',
        'it_CH' => 'อิตาลี (สวิตเซอร์แลนด์)',
        'it_IT' => 'อิตาลี (อิตาลี)',
        'it_SM' => 'อิตาลี (ซานมาริโน)',
        'it_VA' => 'อิตาลี (นครวาติกัน)',
        'ja' => 'ญี่ปุ่น',
        'ja_JP' => 'ญี่ปุ่น (ญี่ปุ่น)',
        'jv' => 'ชวา',
        'jv_ID' => 'ชวา (อินโดนีเซีย)',
        'ka' => 'จอร์เจีย',
        'ka_GE' => 'จอร์เจีย (จอร์เจีย)',
        'ki' => 'กีกูยู',
        'ki_KE' => 'กีกูยู (เคนยา)',
        'kk' => 'คาซัค',
        'kk_Arab' => 'คาซัค (อาหรับ)',
        'kk_Arab_CN' => 'คาซัค (อาหรับ, จีน)',
        'kk_Cyrl' => 'คาซัค (ซีริลลิก)',
        'kk_Cyrl_KZ' => 'คาซัค (ซีริลลิก, คาซัคสถาน)',
        'kk_KZ' => 'คาซัค (คาซัคสถาน)',
        'kl' => 'กรีนแลนด์',
        'kl_GL' => 'กรีนแลนด์ (กรีนแลนด์)',
        'km' => 'เขมร',
        'km_KH' => 'เขมร (กัมพูชา)',
        'kn' => 'กันนาดา',
        'kn_IN' => 'กันนาดา (อินเดีย)',
        'ko' => 'เกาหลี',
        'ko_CN' => 'เกาหลี (จีน)',
        'ko_KP' => 'เกาหลี (เกาหลีเหนือ)',
        'ko_KR' => 'เกาหลี (เกาหลีใต้)',
        'ks' => 'แคชเมียร์',
        'ks_Arab' => 'แคชเมียร์ (อาหรับ)',
        'ks_Arab_IN' => 'แคชเมียร์ (อาหรับ, อินเดีย)',
        'ks_Deva' => 'แคชเมียร์ (เทวนาครี)',
        'ks_Deva_IN' => 'แคชเมียร์ (เทวนาครี, อินเดีย)',
        'ks_IN' => 'แคชเมียร์ (อินเดีย)',
        'ku' => 'เคิร์ด',
        'ku_Latn' => 'เคิร์ด (ละติน)',
        'ku_Latn_IQ' => 'เคิร์ด (ละติน, อิรัก)',
        'ku_Latn_SY' => 'เคิร์ด (ละติน, ซีเรีย)',
        'ku_Latn_TR' => 'เคิร์ด (ละติน, ตุรกี)',
        'ku_SY' => 'เคิร์ด (ซีเรีย)',
        'ku_TR' => 'เคิร์ด (ตุรกี)',
        'kw' => 'คอร์นิช',
        'kw_GB' => 'คอร์นิช (สหราชอาณาจักร)',
        'ky' => 'คีร์กีซ',
        'ky_KG' => 'คีร์กีซ (คีร์กีซสถาน)',
        'lb' => 'ลักเซมเบิร์ก',
        'lb_LU' => 'ลักเซมเบิร์ก (ลักเซมเบิร์ก)',
        'lg' => 'ยูกันดา',
        'lg_UG' => 'ยูกันดา (ยูกันดา)',
        'ln' => 'ลิงกาลา',
        'ln_AO' => 'ลิงกาลา (แองโกลา)',
        'ln_CD' => 'ลิงกาลา (คองโก - กินชาซา)',
        'ln_CF' => 'ลิงกาลา (สาธารณรัฐแอฟริกากลาง)',
        'ln_CG' => 'ลิงกาลา (คองโก - บราซซาวิล)',
        'lo' => 'ลาว',
        'lo_LA' => 'ลาว (ลาว)',
        'lt' => 'ลิทัวเนีย',
        'lt_LT' => 'ลิทัวเนีย (ลิทัวเนีย)',
        'lu' => 'ลูบา-กาตองกา',
        'lu_CD' => 'ลูบา-กาตองกา (คองโก - กินชาซา)',
        'lv' => 'ลัตเวีย',
        'lv_LV' => 'ลัตเวีย (ลัตเวีย)',
        'mg' => 'มาลากาซี',
        'mg_MG' => 'มาลากาซี (มาดากัสการ์)',
        'mi' => 'เมารี',
        'mi_NZ' => 'เมารี (นิวซีแลนด์)',
        'mk' => 'มาซิโดเนีย',
        'mk_MK' => 'มาซิโดเนีย (มาซิโดเนียเหนือ)',
        'ml' => 'มาลายาลัม',
        'ml_IN' => 'มาลายาลัม (อินเดีย)',
        'mn' => 'มองโกเลีย',
        'mn_MN' => 'มองโกเลีย (มองโกเลีย)',
        'mr' => 'มราฐี',
        'mr_IN' => 'มราฐี (อินเดีย)',
        'ms' => 'มาเลย์',
        'ms_BN' => 'มาเลย์ (บรูไน)',
        'ms_ID' => 'มาเลย์ (อินโดนีเซีย)',
        'ms_MY' => 'มาเลย์ (มาเลเซีย)',
        'ms_SG' => 'มาเลย์ (สิงคโปร์)',
        'mt' => 'มอลตา',
        'mt_MT' => 'มอลตา (มอลตา)',
        'my' => 'พม่า',
        'my_MM' => 'พม่า (เมียนมา [พม่า])',
        'nb' => 'นอร์เวย์บุคมอล',
        'nb_NO' => 'นอร์เวย์บุคมอล (นอร์เวย์)',
        'nb_SJ' => 'นอร์เวย์บุคมอล (สฟาลบาร์และยานไมเอน)',
        'nd' => 'เอ็นเดเบเลเหนือ',
        'nd_ZW' => 'เอ็นเดเบเลเหนือ (ซิมบับเว)',
        'ne' => 'เนปาล',
        'ne_IN' => 'เนปาล (อินเดีย)',
        'ne_NP' => 'เนปาล (เนปาล)',
        'nl' => 'ดัตช์',
        'nl_AW' => 'ดัตช์ (อารูบา)',
        'nl_BE' => 'ดัตช์ (เบลเยียม)',
        'nl_BQ' => 'ดัตช์ (เนเธอร์แลนด์แคริบเบียน)',
        'nl_CW' => 'ดัตช์ (คูราเซา)',
        'nl_NL' => 'ดัตช์ (เนเธอร์แลนด์)',
        'nl_SR' => 'ดัตช์ (ซูรินาเม)',
        'nl_SX' => 'ดัตช์ (ซินต์มาร์เทน)',
        'nn' => 'นอร์เวย์นีนอสก์',
        'nn_NO' => 'นอร์เวย์นีนอสก์ (นอร์เวย์)',
        'no' => 'นอร์เวย์',
        'no_NO' => 'นอร์เวย์ (นอร์เวย์)',
        'oc' => 'อ็อกซิตัน',
        'oc_ES' => 'อ็อกซิตัน (สเปน)',
        'oc_FR' => 'อ็อกซิตัน (ฝรั่งเศส)',
        'om' => 'โอโรโม',
        'om_ET' => 'โอโรโม (เอธิโอเปีย)',
        'om_KE' => 'โอโรโม (เคนยา)',
        'or' => 'โอดิยา',
        'or_IN' => 'โอดิยา (อินเดีย)',
        'os' => 'ออสเซเตีย',
        'os_GE' => 'ออสเซเตีย (จอร์เจีย)',
        'os_RU' => 'ออสเซเตีย (รัสเซีย)',
        'pa' => 'ปัญจาบ',
        'pa_Arab' => 'ปัญจาบ (อาหรับ)',
        'pa_Arab_PK' => 'ปัญจาบ (อาหรับ, ปากีสถาน)',
        'pa_Guru' => 'ปัญจาบ (กูร์มูคี)',
        'pa_Guru_IN' => 'ปัญจาบ (กูร์มูคี, อินเดีย)',
        'pa_IN' => 'ปัญจาบ (อินเดีย)',
        'pa_PK' => 'ปัญจาบ (ปากีสถาน)',
        'pl' => 'โปแลนด์',
        'pl_PL' => 'โปแลนด์ (โปแลนด์)',
        'ps' => 'พัชโต',
        'ps_AF' => 'พัชโต (อัฟกานิสถาน)',
        'ps_PK' => 'พัชโต (ปากีสถาน)',
        'pt' => 'โปรตุเกส',
        'pt_AO' => 'โปรตุเกส (แองโกลา)',
        'pt_BR' => 'โปรตุเกส (บราซิล)',
        'pt_CH' => 'โปรตุเกส (สวิตเซอร์แลนด์)',
        'pt_CV' => 'โปรตุเกส (เคปเวิร์ด)',
        'pt_GQ' => 'โปรตุเกส (อิเควทอเรียลกินี)',
        'pt_GW' => 'โปรตุเกส (กินี-บิสเซา)',
        'pt_LU' => 'โปรตุเกส (ลักเซมเบิร์ก)',
        'pt_MO' => 'โปรตุเกส (เขตปกครองพิเศษมาเก๊าแห่งสาธารณรัฐประชาชนจีน)',
        'pt_MZ' => 'โปรตุเกส (โมซัมบิก)',
        'pt_PT' => 'โปรตุเกส (โปรตุเกส)',
        'pt_ST' => 'โปรตุเกส (เซาตูเมและปรินซิปี)',
        'pt_TL' => 'โปรตุเกส (ติมอร์-เลสเต)',
        'qu' => 'เคชวา',
        'qu_BO' => 'เคชวา (โบลิเวีย)',
        'qu_EC' => 'เคชวา (เอกวาดอร์)',
        'qu_PE' => 'เคชวา (เปรู)',
        'rm' => 'โรแมนซ์',
        'rm_CH' => 'โรแมนซ์ (สวิตเซอร์แลนด์)',
        'rn' => 'บุรุนดี',
        'rn_BI' => 'บุรุนดี (บุรุนดี)',
        'ro' => 'โรมาเนีย',
        'ro_MD' => 'โรมาเนีย (มอลโดวา)',
        'ro_RO' => 'โรมาเนีย (โรมาเนีย)',
        'ru' => 'รัสเซีย',
        'ru_BY' => 'รัสเซีย (เบลารุส)',
        'ru_KG' => 'รัสเซีย (คีร์กีซสถาน)',
        'ru_KZ' => 'รัสเซีย (คาซัคสถาน)',
        'ru_MD' => 'รัสเซีย (มอลโดวา)',
        'ru_RU' => 'รัสเซีย (รัสเซีย)',
        'ru_UA' => 'รัสเซีย (ยูเครน)',
        'rw' => 'รวันดา',
        'rw_RW' => 'รวันดา (รวันดา)',
        'sa' => 'สันสกฤต',
        'sa_IN' => 'สันสกฤต (อินเดีย)',
        'sc' => 'ซาร์เดญา',
        'sc_IT' => 'ซาร์เดญา (อิตาลี)',
        'sd' => 'สินธิ',
        'sd_Arab' => 'สินธิ (อาหรับ)',
        'sd_Arab_PK' => 'สินธิ (อาหรับ, ปากีสถาน)',
        'sd_Deva' => 'สินธิ (เทวนาครี)',
        'sd_Deva_IN' => 'สินธิ (เทวนาครี, อินเดีย)',
        'sd_IN' => 'สินธิ (อินเดีย)',
        'sd_PK' => 'สินธิ (ปากีสถาน)',
        'se' => 'ซามิเหนือ',
        'se_FI' => 'ซามิเหนือ (ฟินแลนด์)',
        'se_NO' => 'ซามิเหนือ (นอร์เวย์)',
        'se_SE' => 'ซามิเหนือ (สวีเดน)',
        'sg' => 'ซันโก',
        'sg_CF' => 'ซันโก (สาธารณรัฐแอฟริกากลาง)',
        'sh' => 'เซอร์โบ-โครเอเชีย',
        'sh_BA' => 'เซอร์โบ-โครเอเชีย (บอสเนียและเฮอร์เซโกวีนา)',
        'si' => 'สิงหล',
        'si_LK' => 'สิงหล (ศรีลังกา)',
        'sk' => 'สโลวัก',
        'sk_SK' => 'สโลวัก (สโลวะเกีย)',
        'sl' => 'สโลวีเนีย',
        'sl_SI' => 'สโลวีเนีย (สโลวีเนีย)',
        'sn' => 'โชนา',
        'sn_ZW' => 'โชนา (ซิมบับเว)',
        'so' => 'โซมาลี',
        'so_DJ' => 'โซมาลี (จิบูตี)',
        'so_ET' => 'โซมาลี (เอธิโอเปีย)',
        'so_KE' => 'โซมาลี (เคนยา)',
        'so_SO' => 'โซมาลี (โซมาเลีย)',
        'sq' => 'แอลเบเนีย',
        'sq_AL' => 'แอลเบเนีย (แอลเบเนีย)',
        'sq_MK' => 'แอลเบเนีย (มาซิโดเนียเหนือ)',
        'sr' => 'เซอร์เบีย',
        'sr_BA' => 'เซอร์เบีย (บอสเนียและเฮอร์เซโกวีนา)',
        'sr_Cyrl' => 'เซอร์เบีย (ซีริลลิก)',
        'sr_Cyrl_BA' => 'เซอร์เบีย (ซีริลลิก, บอสเนียและเฮอร์เซโกวีนา)',
        'sr_Cyrl_ME' => 'เซอร์เบีย (ซีริลลิก, มอนเตเนโกร)',
        'sr_Cyrl_RS' => 'เซอร์เบีย (ซีริลลิก, เซอร์เบีย)',
        'sr_Latn' => 'เซอร์เบีย (ละติน)',
        'sr_Latn_BA' => 'เซอร์เบีย (ละติน, บอสเนียและเฮอร์เซโกวีนา)',
        'sr_Latn_ME' => 'เซอร์เบีย (ละติน, มอนเตเนโกร)',
        'sr_Latn_RS' => 'เซอร์เบีย (ละติน, เซอร์เบีย)',
        'sr_ME' => 'เซอร์เบีย (มอนเตเนโกร)',
        'sr_RS' => 'เซอร์เบีย (เซอร์เบีย)',
        'st' => 'โซโทใต้',
        'st_LS' => 'โซโทใต้ (เลโซโท)',
        'st_ZA' => 'โซโทใต้ (แอฟริกาใต้)',
        'su' => 'ซุนดา',
        'su_ID' => 'ซุนดา (อินโดนีเซีย)',
        'su_Latn' => 'ซุนดา (ละติน)',
        'su_Latn_ID' => 'ซุนดา (ละติน, อินโดนีเซีย)',
        'sv' => 'สวีเดน',
        'sv_AX' => 'สวีเดน (หมู่เกาะโอลันด์)',
        'sv_FI' => 'สวีเดน (ฟินแลนด์)',
        'sv_SE' => 'สวีเดน (สวีเดน)',
        'sw' => 'สวาฮีลี',
        'sw_CD' => 'สวาฮีลี (คองโก - กินชาซา)',
        'sw_KE' => 'สวาฮีลี (เคนยา)',
        'sw_TZ' => 'สวาฮีลี (แทนซาเนีย)',
        'sw_UG' => 'สวาฮีลี (ยูกันดา)',
        'ta' => 'ทมิฬ',
        'ta_IN' => 'ทมิฬ (อินเดีย)',
        'ta_LK' => 'ทมิฬ (ศรีลังกา)',
        'ta_MY' => 'ทมิฬ (มาเลเซีย)',
        'ta_SG' => 'ทมิฬ (สิงคโปร์)',
        'te' => 'เตลูกู',
        'te_IN' => 'เตลูกู (อินเดีย)',
        'tg' => 'ทาจิก',
        'tg_TJ' => 'ทาจิก (ทาจิกิสถาน)',
        'th' => 'ไทย',
        'th_TH' => 'ไทย (ไทย)',
        'ti' => 'ติกริญญา',
        'ti_ER' => 'ติกริญญา (เอริเทรีย)',
        'ti_ET' => 'ติกริญญา (เอธิโอเปีย)',
        'tk' => 'เติร์กเมน',
        'tk_TM' => 'เติร์กเมน (เติร์กเมนิสถาน)',
        'tl' => 'ตากาล็อก',
        'tl_PH' => 'ตากาล็อก (ฟิลิปปินส์)',
        'tn' => 'สวานา',
        'tn_BW' => 'สวานา (บอตสวานา)',
        'tn_ZA' => 'สวานา (แอฟริกาใต้)',
        'to' => 'ตองกา',
        'to_TO' => 'ตองกา (ตองกา)',
        'tr' => 'ตุรกี',
        'tr_CY' => 'ตุรกี (ไซปรัส)',
        'tr_TR' => 'ตุรกี (ตุรกี)',
        'tt' => 'ตาตาร์',
        'tt_RU' => 'ตาตาร์ (รัสเซีย)',
        'ug' => 'อุยกูร์',
        'ug_CN' => 'อุยกูร์ (จีน)',
        'uk' => 'ยูเครน',
        'uk_UA' => 'ยูเครน (ยูเครน)',
        'ur' => 'อูรดู',
        'ur_IN' => 'อูรดู (อินเดีย)',
        'ur_PK' => 'อูรดู (ปากีสถาน)',
        'uz' => 'อุซเบก',
        'uz_AF' => 'อุซเบก (อัฟกานิสถาน)',
        'uz_Arab' => 'อุซเบก (อาหรับ)',
        'uz_Arab_AF' => 'อุซเบก (อาหรับ, อัฟกานิสถาน)',
        'uz_Cyrl' => 'อุซเบก (ซีริลลิก)',
        'uz_Cyrl_UZ' => 'อุซเบก (ซีริลลิก, อุซเบกิสถาน)',
        'uz_Latn' => 'อุซเบก (ละติน)',
        'uz_Latn_UZ' => 'อุซเบก (ละติน, อุซเบกิสถาน)',
        'uz_UZ' => 'อุซเบก (อุซเบกิสถาน)',
        'vi' => 'เวียดนาม',
        'vi_VN' => 'เวียดนาม (เวียดนาม)',
        'wo' => 'โวลอฟ',
        'wo_SN' => 'โวลอฟ (เซเนกัล)',
        'xh' => 'คะห์โอซา',
        'xh_ZA' => 'คะห์โอซา (แอฟริกาใต้)',
        'yi' => 'ยิดดิช',
        'yi_UA' => 'ยิดดิช (ยูเครน)',
        'yo' => 'โยรูบา',
        'yo_BJ' => 'โยรูบา (เบนิน)',
        'yo_NG' => 'โยรูบา (ไนจีเรีย)',
        'za' => 'จ้วง',
        'za_CN' => 'จ้วง (จีน)',
        'zh' => 'จีน',
        'zh_CN' => 'จีน (จีน)',
        'zh_HK' => 'จีน (เขตปกครองพิเศษฮ่องกงแห่งสาธารณรัฐประชาชนจีน)',
        'zh_Hans' => 'จีน (ตัวย่อ)',
        'zh_Hans_CN' => 'จีน (ตัวย่อ, จีน)',
        'zh_Hans_HK' => 'จีน (ตัวย่อ, เขตปกครองพิเศษฮ่องกงแห่งสาธารณรัฐประชาชนจีน)',
        'zh_Hans_MO' => 'จีน (ตัวย่อ, เขตปกครองพิเศษมาเก๊าแห่งสาธารณรัฐประชาชนจีน)',
        'zh_Hans_MY' => 'จีน (ตัวย่อ, มาเลเซีย)',
        'zh_Hans_SG' => 'จีน (ตัวย่อ, สิงคโปร์)',
        'zh_Hant' => 'จีน (ตัวเต็ม)',
        'zh_Hant_HK' => 'จีน (ตัวเต็ม, เขตปกครองพิเศษฮ่องกงแห่งสาธารณรัฐประชาชนจีน)',
        'zh_Hant_MO' => 'จีน (ตัวเต็ม, เขตปกครองพิเศษมาเก๊าแห่งสาธารณรัฐประชาชนจีน)',
        'zh_Hant_MY' => 'จีน (ตัวเต็ม, มาเลเซีย)',
        'zh_Hant_TW' => 'จีน (ตัวเต็ม, ไต้หวัน)',
        'zh_MO' => 'จีน (เขตปกครองพิเศษมาเก๊าแห่งสาธารณรัฐประชาชนจีน)',
        'zh_SG' => 'จีน (สิงคโปร์)',
        'zh_TW' => 'จีน (ไต้หวัน)',
        'zu' => 'ซูลู',
        'zu_ZA' => 'ซูลู (แอฟริกาใต้)',
    ],
];
