<?php

return [
    'Names' => [
        'AED' => [
            'AED',
            'Diami ti Awon Orílẹ́ède Arabu',
        ],
        'AFN' => [
            'AFN',
            'Afugánì Afuganísítàànì',
        ],
        'ALL' => [
            'ALL',
            'Lẹ́ẹ̀kì Àlìbáníà',
        ],
        'AMD' => [
            'AMD',
            'Dírààmù Àmẹ́níà',
        ],
        'ANG' => [
            'ANG',
            'Gílídà Netherlands Antillean',
        ],
        'AOA' => [
            'AOA',
            'kíwánsà Angola',
        ],
        'ARS' => [
            'ARS',
            'Pẹ́sò Agẹntínà',
        ],
        'AUD' => [
            'A$',
            'Dọla ti Orílẹ́ède Ástràlìá',
        ],
        'AWG' => [
            'AWG',
            'Fuloríìnì Àrúbà',
        ],
        'AZN' => [
            'AZN',
            'Mánààtì Àsàbáíjáì',
        ],
        'BAM' => [
            'BAM',
            'Àmi Yíyípadà Bosnia-Herzegovina',
        ],
        'BBD' => [
            'BBD',
            'Dọ́là Bábádọ̀ọ̀sì',
        ],
        'BDT' => [
            'BDT',
            'Tákà Báńgíládẹ̀ẹ̀ṣì',
        ],
        'BGN' => [
            'BGN',
            'Owó Lẹ́fì Bọ̀lìgéríà',
        ],
        'BHD' => [
            'BHD',
            'Dina ti Orílẹ́ède Báránì',
        ],
        'BIF' => [
            'BIF',
            'Faransi Bùùrúndì',
        ],
        'BMD' => [
            'BMD',
            'Dọ́là Bẹ̀múdà',
        ],
        'BND' => [
            'BND',
            'Dọ́là Bùrùnéì',
        ],
        'BOB' => [
            'BOB',
            'Bọlifiánò Bọ̀lífíà',
        ],
        'BRL' => [
            'R$',
            'Owó ti Orílẹ̀-èdè Brazil',
        ],
        'BSD' => [
            'BSD',
            'Dọ́là Bàhámà',
        ],
        'BTN' => [
            'BTN',
            'Ìngọ́tírọ̀mù Bútàànì',
        ],
        'BWP' => [
            'BWP',
            'Pula Bọ̀tìsúwánà',
        ],
        'BYN' => [
            'BYN',
            'Rọ́bù Bẹ̀lárùùsì',
        ],
        'BZD' => [
            'BZD',
            'Dọ́là Bẹ̀lísè',
        ],
        'CAD' => [
            'CA$',
            'Dọ́là Kánádà',
        ],
        'CDF' => [
            'CDF',
            'Firanki Kongo',
        ],
        'CHF' => [
            'CHF',
            'Faransí Síwíìsì',
        ],
        'CLP' => [
            'CLP',
            'Pẹ́sò Ṣílè',
        ],
        'CNH' => [
            'CNH',
            'Yúànì Sháínà',
        ],
        'CNY' => [
            'CN¥',
            'Reminibi ti Orílẹ́ède ṣáínà',
        ],
        'COP' => [
            'COP',
            'Pẹ́sò Kòlóḿbíà',
        ],
        'CRC' => [
            'CRC',
            'Kólọ́ọ̀nì Kosita Ríkà',
        ],
        'CUC' => [
            'CUC',
            'Pẹ́sò Yíyípadà Kúbà',
        ],
        'CUP' => [
            'CUP',
            'Pẹ́sò Kúbà',
        ],
        'CVE' => [
            'CVE',
            'Èsìkúdò Kapú Faadì',
        ],
        'CZK' => [
            'CZK',
            'Koruna Ṣẹ́ẹ̀kì',
        ],
        'DJF' => [
            'DJF',
            'Faransi Dibouti',
        ],
        'DKK' => [
            'DKK',
            'Kírónì Dáníṣì',
        ],
        'DOP' => [
            'DOP',
            'Pẹ́sò Dòníníkà',
        ],
        'DZD' => [
            'DZD',
            'Dina ti Orílẹ́ède Àlùgèríánì',
        ],
        'EGP' => [
            'EGP',
            'pọọn ti Orílẹ́ède Egipiti',
        ],
        'ERN' => [
            'ERN',
            'Nakifasì Eritira',
        ],
        'ETB' => [
            'ETB',
            'Báà Etópíà',
        ],
        'EUR' => [
            '€',
            'owó Yúrò',
        ],
        'FJD' => [
            'FJD',
            'Dọ́là Fíjì',
        ],
        'FKP' => [
            'FKP',
            'Pọ́n-ùn Erékùsù Falkland',
        ],
        'GBP' => [
            '£',
            'Pọ́n-ùn ti Orilẹ̀-èdè Gẹ̀ẹ́sì',
        ],
        'GEL' => [
            'GEL',
            'Lárì Jọ́jíà',
        ],
        'GHC' => [
            'GHC',
            'ṣidi ti Orílẹ́ède Gana',
        ],
        'GHS' => [
            'GHS',
            'sídì Gana',
        ],
        'GIP' => [
            'GIP',
            'Pọ́n-ùn Gibúrátà',
        ],
        'GMD' => [
            'GMD',
            'Dalasi Gamibia',
        ],
        'GNF' => [
            'GNF',
            'Fírànkì Gínì',
        ],
        'GNS' => [
            'GNS',
            'Faransi ti Orílẹ́ède Gini',
        ],
        'GTQ' => [
            'GTQ',
            'Kúẹ́tísààlì Guatimílà',
        ],
        'GYD' => [
            'GYD',
            'Dọ́là Gùyánà',
        ],
        'HKD' => [
            'HK$',
            'Dọ́là Hong Kong',
        ],
        'HNL' => [
            'HNL',
            'Lẹmipírà Ọ́ńdúrà',
        ],
        'HRK' => [
            'HRK',
            'Kúnà Kúróṣíà',
        ],
        'HTG' => [
            'HTG',
            'Gọ́dì Àítì',
        ],
        'HUF' => [
            'HUF',
            'Fọ́ríǹtì Họ̀ngérí',
        ],
        'IDR' => [
            'IDR',
            'Rúpìyá Indonésíà',
        ],
        'ILS' => [
            '₪',
            'Ṣékélì Tuntun Ísírẹ̀ẹ̀lì',
        ],
        'INR' => [
            '₹',
            'Rupi ti Orílẹ́ède Indina',
        ],
        'IQD' => [
            'IQD',
            'Dínárì Ìráákì',
        ],
        'IRR' => [
            'IRR',
            'Rial Iranian',
        ],
        'ISK' => [
            'ISK',
            'Kòrónà Icelandic',
        ],
        'JMD' => [
            'JMD',
            'Dọ́là Jàmáíkà',
        ],
        'JOD' => [
            'JOD',
            'Dínárì Jọ́dàànì',
        ],
        'JPY' => [
            'JP¥',
            'Yeni ti Orílẹ́ède Japani',
        ],
        'KES' => [
            'KES',
            'Ṣiili Kenya',
        ],
        'KGS' => [
            'KGS',
            'Sómú Kirijísítàànì',
        ],
        'KHR' => [
            'KHR',
            'Ráyò Kàm̀bọ́díà',
        ],
        'KMF' => [
            'KMF',
            'Faransi Komori',
        ],
        'KPW' => [
            'KPW',
            'Wọ́ọ̀nù Àríwá Kòríà',
        ],
        'KRW' => [
            '₩',
            'Wọ́ọ̀nù Gúúsù Kòríà',
        ],
        'KWD' => [
            'KWD',
            'Dínárì Kuwaiti',
        ],
        'KYD' => [
            'KYD',
            'Dọ́là Erékùsù Cayman',
        ],
        'KZT' => [
            'KZT',
            'Tẹngé Kasakísítàànì',
        ],
        'LAK' => [
            'LAK',
            'Kíììpù Làótì',
        ],
        'LBP' => [
            'LBP',
            'Pọ́n-ùn Lebanese',
        ],
        'LKR' => [
            'LKR',
            'Rúpìì Siri Láńkà',
        ],
        'LRD' => [
            'LRD',
            'Dọla Liberia',
        ],
        'LSL' => [
            'LSL',
            'Loti ti Orílẹ́ède Lesoto',
        ],
        'LYD' => [
            'LYD',
            'Dínà Líbíyà',
        ],
        'MAD' => [
            'MAD',
            'Dírámì Morokò',
        ],
        'MDL' => [
            'MDL',
            'Owó Léhù Moldovan',
        ],
        'MGA' => [
            'MGA',
            'Faransi Malagasi',
        ],
        'MKD' => [
            'MKD',
            'Dẹ́nà Masidóníà',
        ],
        'MMK' => [
            'MMK',
            'Kíyàtì Myanmar',
        ],
        'MNT' => [
            'MNT',
            'Túgúrììkì Mòǹgólíà',
        ],
        'MOP' => [
            'MOP',
            'Pàtákà Màkáò',
        ],
        'MRO' => [
            'MRO',
            'Ouguiya ti Orílẹ́ède Maritania (1973–2017)',
        ],
        'MRU' => [
            'MRU',
            'Ouguiya ti Orílẹ́ède Maritania',
        ],
        'MUR' => [
            'MUR',
            'Rupi Maritusi',
        ],
        'MVR' => [
            'MVR',
            'Rúfìyá Mọ̀lìdífà',
        ],
        'MWK' => [
            'MWK',
            'Kásà Màláwì',
        ],
        'MXN' => [
            'MX$',
            'Pẹ́sò Mẹ́síkò',
        ],
        'MYR' => [
            'MYR',
            'Ríngìtì Màléṣíà',
        ],
        'MZM' => [
            'MZM',
            'Metika ti Orílẹ́ède Mosamibiki',
        ],
        'MZN' => [
            'MZN',
            'Mẹ́tíkààlì Mòsáḿbíìkì',
        ],
        'NAD' => [
            'NAD',
            'Dọla Namibíà',
        ],
        'NGN' => [
            '₦',
            'Náírà Nàìjíríà',
        ],
        'NIO' => [
            'NIO',
            'Kọ̀dóbà Naikarágúà',
        ],
        'NOK' => [
            'NOK',
            'kórónì Nọ́wè',
        ],
        'NPR' => [
            'NPR',
            'Rúpìì Nẹ̵́pààlì',
        ],
        'NZD' => [
            'NZ$',
            'Dọ́là New Zealand',
        ],
        'OMR' => [
            'OMR',
            'Ráyò Omani',
        ],
        'PAB' => [
            'PAB',
            'Bálíbóà Pànámà',
        ],
        'PEN' => [
            'PEN',
            'Sólì Pèrúù',
        ],
        'PGK' => [
            'PGK',
            'Kínà Papua Guinea Tuntun',
        ],
        'PHP' => [
            '₱',
            'Písò Fílípìnì',
        ],
        'PKR' => [
            'PKR',
            'Rúpìì Pakisitánì',
        ],
        'PLN' => [
            'PLN',
            'Sílọ̀tì Pọ́líṣì',
        ],
        'PYG' => [
            'PYG',
            'Gúáránì Párágúwè',
        ],
        'QAR' => [
            'QAR',
            'Ráyò Kàtárì',
        ],
        'RON' => [
            'RON',
            'Léhù Ròméníà',
        ],
        'RSD' => [
            'RSD',
            'Dínárì Sàbíà',
        ],
        'RUB' => [
            '₽',
            'Owó ruble ti ilẹ̀ Rọ́ṣíà',
        ],
        'RWF' => [
            'RWF',
            'Faransi Ruwanda',
        ],
        'SAR' => [
            'SAR',
            'Riya ti Orílẹ́ède Saudi',
        ],
        'SBD' => [
            'SBD',
            'Dọ́là Erékùsù Sọ́lómọ́nì',
        ],
        'SCR' => [
            'SCR',
            'Rúpì Sayiselesi',
        ],
        'SDG' => [
            'SDG',
            'Pọ́n-ùn Sùdáànì',
        ],
        'SDP' => [
            'SDP',
            'Pọọun ti Orílẹ́ède Sudani',
        ],
        'SEK' => [
            'SEK',
            'Kòrónà Súwídìn',
        ],
        'SGD' => [
            'SGD',
            'Dọ́là Síngápọ̀',
        ],
        'SHP' => [
            'SHP',
            'Pọ́n-un Elena',
        ],
        'SLE' => [
            'SLE',
            'Líónì Sira Líonì',
        ],
        'SLL' => [
            'SLL',
            'Líónì Sira Líonì (1964—2022)',
        ],
        'SOS' => [
            'SOS',
            'Ṣílè Somali',
        ],
        'SRD' => [
            'SRD',
            'Dọ́là Súrínámì',
        ],
        'SSP' => [
            'SSP',
            'Pọ́n-un Gúúsù Sùdáànì',
        ],
        'STD' => [
            'STD',
            'Dobira ti Orílẹ́ède Sao tome Ati Pirisipe (1977–2017)',
        ],
        'STN' => [
            'STN',
            'Dọbíra Sao tome àti Pirisipi',
        ],
        'SYP' => [
            'SYP',
            'Pọ́n-ùn Sírìà',
        ],
        'SZL' => [
            'SZL',
            'Lilangeni Suwasi',
        ],
        'THB' => [
            'THB',
            'Báàtì Tháì',
        ],
        'TJS' => [
            'TJS',
            'Sómónì Tajikístàànì',
        ],
        'TMT' => [
            'TMT',
            'Mánààtì Tọkimẹnístàànì',
        ],
        'TND' => [
            'TND',
            'Dínà Tuniṣíà',
        ],
        'TOP' => [
            'TOP',
            'Pàángà Tóńgà',
        ],
        'TRY' => [
            'TRY',
            'Lírà Tọ́kì',
        ],
        'TTD' => [
            'TTD',
            'Dọ́là Trinidad & Tobago',
        ],
        'TWD' => [
            'NT$',
            'Dọ́là Tàìwánì Tuntun',
        ],
        'TZS' => [
            'TZS',
            'Sile Tansania',
        ],
        'UAH' => [
            'UAH',
            'Ọrifiníyà Yukiréníà',
        ],
        'UGX' => [
            'UGX',
            'Ṣile Uganda',
        ],
        'USD' => [
            '$',
            'Dọ́là',
        ],
        'UYU' => [
            'UYU',
            'Pẹ́sò Úrúgúwè',
        ],
        'UZS' => [
            'UZS',
            'Sómú Usibẹkísítàànì',
        ],
        'VES' => [
            'VES',
            'Bọ̀lífà Fẹnẹsuẹ́là',
        ],
        'VND' => [
            '₫',
            'Dáhùn Vietnamese',
        ],
        'VUV' => [
            'VUV',
            'Fátù Vanuatu',
        ],
        'WST' => [
            'WST',
            'Tálà Sàmóà',
        ],
        'XAF' => [
            'FCFA',
            'Firanki àárín Afíríkà',
        ],
        'XCD' => [
            'EC$',
            'Dọ́là Ilà Oòrùn Karíbíà',
        ],
        'XCG' => [
            'Cg.',
            'Owó ìlú Kùrásọ̀ àti Saint Mátìnì',
        ],
        'XOF' => [
            'F CFA',
            'Faransì ìwọ̀-oorùn Afíríkà',
        ],
        'XPF' => [
            'CFPF',
            'Fírànkì CFP',
        ],
        'YER' => [
            'YER',
            'Ráyò Yẹ́mẹ̀nì',
        ],
        'ZAR' => [
            'ZAR',
            'Rándì Gúúsù Afíríkà',
        ],
        'ZMK' => [
            'ZMK',
            'Kawaṣa ti Orílẹ́ède Saabia (1968–2012)',
        ],
        'ZMW' => [
            'ZMW',
            'Kàwasà Sámbíà',
        ],
        'ZWD' => [
            'ZWD',
            'Dọla ti Orílẹ́ède Siibabuwe',
        ],
        'ZWG' => [
            'ZWG',
            'Owó ìlú Sìnbábúwè',
        ],
    ],
];
