<?php

return [
    'UserAssignedNames' => [
        'XK' => 'Kosoovoo',
    ],
    'Names' => [
        'AD' => 'Andooraa',
        'AE' => 'Yuunaatid Arab Emereet',
        'AF' => 'Afgaanistaan',
        'AG' => 'Antiiguyaa fi Barbuudaa',
        'AI' => 'Anguyilaa',
        'AL' => 'Albaaniyaa',
        'AM' => 'Armeeniyaa',
        'AO' => 'Angoolaa',
        'AQ' => 'Antaarkitikaa',
        'AR' => 'Arjentiinaa',
        'AS' => 'Saamowa Ameerikaa',
        'AT' => 'Awustiriyaa',
        'AU' => 'Awustiraaliyaa',
        'AW' => 'Arubaa',
        'AX' => 'Odoloota Alaand',
        'AZ' => 'Azerbaajiyaan',
        'BA' => 'Bosiiniyaa fi Herzoogovinaa',
        'BB' => 'Barbaaros',
        'BD' => 'Banglaadish',
        'BE' => 'Beeljiyeem',
        'BF' => 'Burkiinaa Faasoo',
        'BG' => 'Bulgaariyaa',
        'BH' => 'Baahireen',
        'BI' => 'Burundii',
        'BJ' => 'Beenii',
        'BL' => 'St. Barzeleemii',
        'BM' => 'Beermudaa',
        'BN' => 'Biruniyee',
        'BO' => 'Boliiviyaa',
        'BQ' => 'Neezerlaandota Kariibaan',
        'BR' => 'Biraazil',
        'BS' => 'Bahaamas',
        'BT' => 'Bihuutan',
        'BV' => 'Odola Bowuvet',
        'BW' => 'Botosowaanaa',
        'BY' => 'Beelaarus',
        'BZ' => 'Belize',
        'CA' => 'Kanaadaa',
        'CC' => 'Odoloota Kokos (Keeliing)',
        'CD' => 'Koongoo - Kinshaasaa',
        'CF' => 'Rippaablika Afrikaa Gidduugaleessaa',
        'CG' => 'Koongoo - Biraazaavil',
        'CH' => 'Siwizerlaand',
        'CI' => 'Koti divoor',
        'CK' => 'Odoloota Kuuk',
        'CL' => 'Chiilii',
        'CM' => 'Kaameruun',
        'CN' => 'Chaayinaa',
        'CO' => 'Kolombiyaa',
        'CR' => 'Kostaa Rikaa',
        'CU' => 'Kuubaa',
        'CV' => 'Keeppi Vaardee',
        'CW' => 'Kurakowaa',
        'CX' => 'Odola Kirismaas',
        'CY' => 'Qoophiroos',
        'CZ' => 'Cheechiya',
        'DE' => 'Jarmanii',
        'DJ' => 'Jibuutii',
        'DK' => 'Deenmaark',
        'DM' => 'Dominiikaa',
        'DO' => 'Dominikaa Rippaabilik',
        'DZ' => 'Aljeeriyaa',
        'EC' => 'Ekuwaador',
        'EE' => 'Istooniyaa',
        'EG' => 'Missir',
        'EH' => 'Sahaaraa Dhihaa',
        'ER' => 'Eertiraa',
        'ES' => 'Ispeen',
        'ET' => 'Itoophiyaa',
        'FI' => 'Fiinlaand',
        'FJ' => 'Fiijii',
        'FK' => 'Odoloota Faalklaand',
        'FM' => 'Maayikirooneeshiyaa',
        'FO' => 'Odoloota Fafo’ee',
        'FR' => 'Faransaay',
        'GA' => 'Gaaboon',
        'GB' => 'United Kingdom',
        'GD' => 'Girinaada',
        'GE' => 'Joorjiyaa',
        'GF' => 'Faransaay Guyiinaa',
        'GG' => 'Guwernisey',
        'GH' => 'Gaanaa',
        'GI' => 'Gibraaltar',
        'GL' => 'Giriinlaand',
        'GM' => 'Gaambiyaa',
        'GN' => 'Giinii',
        'GP' => 'Gowadelowape',
        'GQ' => 'Ikkuwaatooriyaal Giinii',
        'GR' => 'Giriik',
        'GS' => 'Joorjikaa Kibba fi Odoloota Saanduwiich Kibbaa',
        'GT' => 'Guwaatimaalaa',
        'GU' => 'Guwama',
        'GW' => 'Giinii-Bisaawoo',
        'GY' => 'Guyaanaa',
        'HK' => 'Hoong Koong SAR Chaayinaa',
        'HM' => 'Odoloota Herdii fi MaakDoonaald',
        'HN' => 'Hondurus',
        'HR' => 'Kirooshiyaa',
        'HT' => 'Haayitii',
        'HU' => 'Hangaarii',
        'ID' => 'Indooneeshiyaa',
        'IE' => 'Ayeerlaand',
        'IL' => 'Israa’eel',
        'IM' => 'Islee oof Maan',
        'IN' => 'Hindii',
        'IO' => 'Daangaa Galaana Hindii Biritish',
        'IQ' => 'Iraaq',
        'IR' => 'Iraan',
        'IS' => 'Ayeslaand',
        'IT' => 'Xaaliyaan',
        'JE' => 'Jeersii',
        'JM' => 'Jamaayikaa',
        'JO' => 'Jirdaan',
        'JP' => 'Jaappaan',
        'KE' => 'Keeniyaa',
        'KG' => 'Kiyirigiyizistan',
        'KH' => 'Kamboodiyaa',
        'KI' => 'Kiribaatii',
        'KM' => 'Komoroos',
        'KN' => 'St. Kiitis fi Neevis',
        'KP' => 'Kooriyaa Kaaba',
        'KR' => 'Kooriyaa Kibbaa',
        'KW' => 'Kuweet',
        'KY' => 'Odoloota Saaymaan',
        'KZ' => 'Kazakistaan',
        'LA' => 'Laa’oos',
        'LB' => 'Libaanoon',
        'LC' => 'St. Suusiyaa',
        'LI' => 'Lichistensteyin',
        'LK' => 'Siri Laankaa',
        'LR' => 'Laayibeeriyaa',
        'LS' => 'Leseettoo',
        'LT' => 'Lutaaniyaa',
        'LU' => 'Luksembarg',
        'LV' => 'Lativiyaa',
        'LY' => 'Liibiyaa',
        'MA' => 'Morookoo',
        'MC' => 'Moonaakoo',
        'MD' => 'Moldoovaa',
        'ME' => 'Montenegiroo',
        'MF' => 'St. Martiin',
        'MG' => 'Madagaaskaar',
        'MH' => 'Odoloota Maarshaal',
        'MK' => 'Maqdooniyaa Kaabaa',
        'ML' => 'Maalii',
        'MM' => 'Maayinaamar (Burma)',
        'MN' => 'Mongoliyaa',
        'MO' => 'Maka’oo SAR Chaayinaa',
        'MP' => 'Odola Maariyaanaa Kaabaa',
        'MQ' => 'Martinikuwee',
        'MR' => 'Mawuritaaniyaa',
        'MS' => 'Montiseerat',
        'MT' => 'Maaltaa',
        'MU' => 'Moorishiyees',
        'MV' => 'Maaldiivs',
        'MW' => 'Maalaawwii',
        'MX' => 'Meeksiikoo',
        'MY' => 'Maleeshiyaa',
        'MZ' => 'Moozaambik',
        'NA' => 'Namiibiyaa',
        'NC' => 'Neewu Kaaleedoniyaa',
        'NE' => 'Niijer',
        'NF' => 'Odola Noorfoolk',
        'NG' => 'Naayijeeriyaa',
        'NI' => 'Nikaraguwaa',
        'NL' => 'Neezerlaand',
        'NO' => 'Noorwey',
        'NP' => 'Neeppal',
        'NR' => 'Naawuruu',
        'NU' => 'Niwu’e',
        'NZ' => 'Neewu Zilaand',
        'OM' => 'Omaan',
        'PA' => 'Paanamaa',
        'PE' => 'Peeruu',
        'PF' => 'Polineeshiyaa Faransaay',
        'PG' => 'Papuwa Neawu Giinii',
        'PH' => 'Filippiins',
        'PK' => 'Paakistaan',
        'PL' => 'Poolaand',
        'PM' => 'Ql. Piyeeree fi Mikuyelon',
        'PN' => 'Odoloota Pitikaayirin',
        'PR' => 'Poortaar Riikoo',
        'PS' => 'Daangaawwan Paalestaayin',
        'PT' => 'Poorchugaal',
        'PW' => 'Palaawu',
        'PY' => 'Paaraguwaay',
        'QA' => 'Kuwaatar',
        'RE' => 'Riyuuniyeen',
        'RO' => 'Roomaaniyaa',
        'RS' => 'Serbiyaa',
        'RU' => 'Raashiyaa',
        'RW' => 'Ruwwandaa',
        'SA' => 'Saawud Arabiyaa',
        'SB' => 'Odoloota Solomoon',
        'SC' => 'Siisheels',
        'SD' => 'Sudaan',
        'SE' => 'Siwiidin',
        'SG' => 'Singaapoor',
        'SH' => 'St. Helenaa',
        'SI' => 'Islooveeniyaa',
        'SJ' => 'Isvaalbaard fi Jan Mayeen',
        'SK' => 'Isloovaakiyaa',
        'SL' => 'Seeraaliyoon',
        'SM' => 'Saan Mariinoo',
        'SN' => 'Senegaal',
        'SO' => 'Somaaliyaa',
        'SR' => 'Suriname',
        'SS' => 'Sudaan Kibbaa',
        'ST' => 'Sa’oo Toomee fi Prinsippee',
        'SV' => 'El Salvaadoor',
        'SX' => 'Siint Maarteen',
        'SY' => 'Sooriyaa',
        'SZ' => 'Iswaatinii',
        'TC' => 'Turkis fi Odoloota Kaayikos',
        'TD' => 'Chaad',
        'TF' => 'Daangaawwan Kibbaa Faransaay',
        'TG' => 'Toogoo',
        'TH' => 'Taayilaand',
        'TJ' => 'Tajikistaan',
        'TK' => 'Tokelau',
        'TL' => 'Tiimoor-Leestee',
        'TM' => 'Turkimenistaan',
        'TN' => 'Tuniiziyaa',
        'TO' => 'Tonga',
        'TR' => 'Tarkiye',
        'TT' => 'Tirinidan fi Tobaagoo',
        'TV' => 'Tuvalu',
        'TW' => 'Taayiwwan',
        'TZ' => 'Taanzaaniyaa',
        'UA' => 'Yuukireen',
        'UG' => 'Ugaandaa',
        'UM' => 'U.S. Odoloota Alaa',
        'US' => 'Yiinaayitid Isteet',
        'UY' => 'Yuraagaay',
        'UZ' => 'Uzbeekistaan',
        'VA' => 'Vaatikaan Siitii',
        'VC' => 'St. Vinseet fi Gireenadines',
        'VE' => 'Veenzuweelaa',
        'VG' => 'Odoloota Varjiin Biritish',
        'VI' => 'U.S. Odoloota Varjiin',
        'VN' => 'Veetinaam',
        'VU' => 'Vanuwaatu',
        'WF' => 'Waalis fi Futtuuna',
        'WS' => 'Saamowa',
        'YE' => 'Yemen',
        'YT' => 'Maayootee',
        'ZA' => 'Afrikaa Kibbaa',
        'ZM' => 'Zaambiyaa',
        'ZW' => 'Zimbaabuwee',
    ],
];
