<?php

return [
    'Names' => [
        'af' => 'Afrikaans',
        'af_NA' => 'Afrikaans (Namibië)',
        'af_ZA' => 'Afrikaans (Suid-Afrika)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Ghana)',
        'am' => 'Amharies',
        'am_ET' => 'Amharies (Ethiopië)',
        'ar' => 'Arabies',
        'ar_001' => 'Arabies (wêreld)',
        'ar_AE' => 'Arabies (Verenigde Arabiese Emirate)',
        'ar_BH' => 'Arabies (Bahrein)',
        'ar_DJ' => 'Arabies (Djiboeti)',
        'ar_DZ' => 'Arabies (Algerië)',
        'ar_EG' => 'Arabies (Egipte)',
        'ar_EH' => 'Arabies (Wes-Sahara)',
        'ar_ER' => 'Arabies (Eritrea)',
        'ar_IL' => 'Arabies (Israel)',
        'ar_IQ' => 'Arabies (Irak)',
        'ar_JO' => 'Arabies (Jordanië)',
        'ar_KM' => 'Arabies (Comore)',
        'ar_KW' => 'Arabies (Koeweit)',
        'ar_LB' => 'Arabies (Libanon)',
        'ar_LY' => 'Arabies (Libië)',
        'ar_MA' => 'Arabies (Marokko)',
        'ar_MR' => 'Arabies (Mauritanië)',
        'ar_OM' => 'Arabies (Oman)',
        'ar_PS' => 'Arabies (Palestynse Grondgebiede)',
        'ar_QA' => 'Arabies (Katar)',
        'ar_SA' => 'Arabies (Saoedi-Arabië)',
        'ar_SD' => 'Arabies (Soedan)',
        'ar_SO' => 'Arabies (Somalië)',
        'ar_SS' => 'Arabies (Suid-Soedan)',
        'ar_SY' => 'Arabies (Sirië)',
        'ar_TD' => 'Arabies (Tsjad)',
        'ar_TN' => 'Arabies (Tunisië)',
        'ar_YE' => 'Arabies (Jemen)',
        'as' => 'Assamees',
        'as_IN' => 'Assamees (Indië)',
        'az' => 'Azerbeidjans',
        'az_AZ' => 'Azerbeidjans (Azerbeidjan)',
        'az_Cyrl' => 'Azerbeidjans (Cyrillies)',
        'az_Cyrl_AZ' => 'Azerbeidjans (Cyrillies, Azerbeidjan)',
        'az_Latn' => 'Azerbeidjans (Latyn)',
        'az_Latn_AZ' => 'Azerbeidjans (Latyn, Azerbeidjan)',
        'ba' => 'Baskir',
        'ba_RU' => 'Baskir (Rusland)',
        'be' => 'Belarussies',
        'be_BY' => 'Belarussies (Belarus)',
        'bg' => 'Bulgaars',
        'bg_BG' => 'Bulgaars (Bulgarye)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Bengaals',
        'bn_BD' => 'Bengaals (Bangladesj)',
        'bn_IN' => 'Bengaals (Indië)',
        'bo' => 'Tibettaans',
        'bo_CN' => 'Tibettaans (China)',
        'bo_IN' => 'Tibettaans (Indië)',
        'br' => 'Bretons',
        'br_FR' => 'Bretons (Frankryk)',
        'bs' => 'Bosnies',
        'bs_BA' => 'Bosnies (Bosnië en Herzegowina)',
        'bs_Cyrl' => 'Bosnies (Cyrillies)',
        'bs_Cyrl_BA' => 'Bosnies (Cyrillies, Bosnië en Herzegowina)',
        'bs_Latn' => 'Bosnies (Latyn)',
        'bs_Latn_BA' => 'Bosnies (Latyn, Bosnië en Herzegowina)',
        'ca' => 'Katalaans',
        'ca_AD' => 'Katalaans (Andorra)',
        'ca_ES' => 'Katalaans (Spanje)',
        'ca_FR' => 'Katalaans (Frankryk)',
        'ca_IT' => 'Katalaans (Italië)',
        'ce' => 'Tsjetsjeens',
        'ce_RU' => 'Tsjetsjeens (Rusland)',
        'cs' => 'Tsjeggies',
        'cs_CZ' => 'Tsjeggies (Tsjeggië)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (Rusland)',
        'cy' => 'Wallies',
        'cy_GB' => 'Wallies (Verenigde Koninkryk)',
        'da' => 'Deens',
        'da_DK' => 'Deens (Denemarke)',
        'da_GL' => 'Deens (Groenland)',
        'de' => 'Duits',
        'de_AT' => 'Duits (Oostenryk)',
        'de_BE' => 'Duits (België)',
        'de_CH' => 'Duits (Switserland)',
        'de_DE' => 'Duits (Duitsland)',
        'de_IT' => 'Duits (Italië)',
        'de_LI' => 'Duits (Liechtenstein)',
        'de_LU' => 'Duits (Luxemburg)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Bhoetan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Ghana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Grieks',
        'el_CY' => 'Grieks (Siprus)',
        'el_GR' => 'Grieks (Griekeland)',
        'en' => 'Engels',
        'en_001' => 'Engels (wêreld)',
        'en_150' => 'Engels (Europa)',
        'en_AE' => 'Engels (Verenigde Arabiese Emirate)',
        'en_AG' => 'Engels (Antigua en Barbuda)',
        'en_AI' => 'Engels (Anguilla)',
        'en_AS' => 'Engels (Amerikaanse Samoa)',
        'en_AT' => 'Engels (Oostenryk)',
        'en_AU' => 'Engels (Australië)',
        'en_BB' => 'Engels (Barbados)',
        'en_BE' => 'Engels (België)',
        'en_BI' => 'Engels (Burundi)',
        'en_BM' => 'Engels (Bermuda)',
        'en_BS' => 'Engels (Bahamas)',
        'en_BW' => 'Engels (Botswana)',
        'en_BZ' => 'Engels (Belize)',
        'en_CA' => 'Engels (Kanada)',
        'en_CC' => 'Engels (Kokoseilande)',
        'en_CH' => 'Engels (Switserland)',
        'en_CK' => 'Engels (Cookeilande)',
        'en_CM' => 'Engels (Kameroen)',
        'en_CX' => 'Engels (Kerseiland)',
        'en_CY' => 'Engels (Siprus)',
        'en_CZ' => 'Engels (Tsjeggië)',
        'en_DE' => 'Engels (Duitsland)',
        'en_DK' => 'Engels (Denemarke)',
        'en_DM' => 'Engels (Dominica)',
        'en_EE' => 'Engels (Estland)',
        'en_ER' => 'Engels (Eritrea)',
        'en_ES' => 'Engels (Spanje)',
        'en_FI' => 'Engels (Finland)',
        'en_FJ' => 'Engels (Fidji)',
        'en_FK' => 'Engels (Falklandeilande)',
        'en_FM' => 'Engels (Mikronesië)',
        'en_FR' => 'Engels (Frankryk)',
        'en_GB' => 'Engels (Verenigde Koninkryk)',
        'en_GD' => 'Engels (Grenada)',
        'en_GE' => 'Engels (Georgië)',
        'en_GG' => 'Engels (Guernsey)',
        'en_GH' => 'Engels (Ghana)',
        'en_GI' => 'Engels (Gibraltar)',
        'en_GM' => 'Engels (Gambië)',
        'en_GS' => 'Engels (Suid-Georgië en die Suidelike Sandwicheilande)',
        'en_GU' => 'Engels (Guam)',
        'en_GY' => 'Engels (Guyana)',
        'en_HK' => 'Engels (Hongkong SAS China)',
        'en_HU' => 'Engels (Hongarye)',
        'en_ID' => 'Engels (Indonesië)',
        'en_IE' => 'Engels (Ierland)',
        'en_IL' => 'Engels (Israel)',
        'en_IM' => 'Engels (Eiland Man)',
        'en_IN' => 'Engels (Indië)',
        'en_IO' => 'Engels (Brits-Indiese Oseaangebied)',
        'en_IT' => 'Engels (Italië)',
        'en_JE' => 'Engels (Jersey)',
        'en_JM' => 'Engels (Jamaika)',
        'en_JP' => 'Engels (Japan)',
        'en_KE' => 'Engels (Kenia)',
        'en_KI' => 'Engels (Kiribati)',
        'en_KN' => 'Engels (Sint Kitts en Nevis)',
        'en_KY' => 'Engels (Kaaimanseilande)',
        'en_LC' => 'Engels (Sint Lucia)',
        'en_LR' => 'Engels (Liberië)',
        'en_LS' => 'Engels (Lesotho)',
        'en_LT' => 'Engels (Litaue)',
        'en_LV' => 'Engels (Letland)',
        'en_MG' => 'Engels (Madagaskar)',
        'en_MH' => 'Engels (Marshalleilande)',
        'en_MO' => 'Engels (Macau SAS China)',
        'en_MP' => 'Engels (Noord-Mariane-eilande)',
        'en_MS' => 'Engels (Montserrat)',
        'en_MT' => 'Engels (Malta)',
        'en_MU' => 'Engels (Mauritius)',
        'en_MV' => 'Engels (Maledive)',
        'en_MW' => 'Engels (Malawi)',
        'en_MY' => 'Engels (Maleisië)',
        'en_NA' => 'Engels (Namibië)',
        'en_NF' => 'Engels (Norfolkeiland)',
        'en_NG' => 'Engels (Nigerië)',
        'en_NL' => 'Engels (Nederland)',
        'en_NO' => 'Engels (Noorweë)',
        'en_NR' => 'Engels (Nauru)',
        'en_NU' => 'Engels (Niue)',
        'en_NZ' => 'Engels (Nieu-Seeland)',
        'en_PG' => 'Engels (Papoea-Nieu-Guinee)',
        'en_PH' => 'Engels (Filippyne)',
        'en_PK' => 'Engels (Pakistan)',
        'en_PL' => 'Engels (Pole)',
        'en_PN' => 'Engels (Pitcairneilande)',
        'en_PR' => 'Engels (Puerto Rico)',
        'en_PT' => 'Engels (Portugal)',
        'en_PW' => 'Engels (Palau)',
        'en_RO' => 'Engels (Roemenië)',
        'en_RW' => 'Engels (Rwanda)',
        'en_SB' => 'Engels (Salomonseilande)',
        'en_SC' => 'Engels (Seychelle)',
        'en_SD' => 'Engels (Soedan)',
        'en_SE' => 'Engels (Swede)',
        'en_SG' => 'Engels (Singapoer)',
        'en_SH' => 'Engels (Sint Helena)',
        'en_SI' => 'Engels (Slowenië)',
        'en_SK' => 'Engels (Slowakye)',
        'en_SL' => 'Engels (Sierra Leone)',
        'en_SS' => 'Engels (Suid-Soedan)',
        'en_SX' => 'Engels (Sint Maarten)',
        'en_SZ' => 'Engels (Eswatini)',
        'en_TC' => 'Engels (Turks- en Caicoseilande)',
        'en_TK' => 'Engels (Tokelau)',
        'en_TO' => 'Engels (Tonga)',
        'en_TT' => 'Engels (Trinidad en Tobago)',
        'en_TV' => 'Engels (Tuvalu)',
        'en_TZ' => 'Engels (Tanzanië)',
        'en_UA' => 'Engels (Oekraïne)',
        'en_UG' => 'Engels (Uganda)',
        'en_UM' => 'Engels (Klein afgeleë eilande van die VSA)',
        'en_US' => 'Engels (Verenigde State van Amerika)',
        'en_VC' => 'Engels (Sint Vincent en die Grenadine)',
        'en_VG' => 'Engels (Britse Maagde-eilande)',
        'en_VI' => 'Engels (VSA se Maagde-eilande)',
        'en_VU' => 'Engels (Vanuatu)',
        'en_WS' => 'Engels (Samoa)',
        'en_ZA' => 'Engels (Suid-Afrika)',
        'en_ZM' => 'Engels (Zambië)',
        'en_ZW' => 'Engels (Zimbabwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (wêreld)',
        'es' => 'Spaans',
        'es_419' => 'Spaans (Latyns-Amerika)',
        'es_AR' => 'Spaans (Argentinië)',
        'es_BO' => 'Spaans (Bolivië)',
        'es_BR' => 'Spaans (Brasilië)',
        'es_BZ' => 'Spaans (Belize)',
        'es_CL' => 'Spaans (Chili)',
        'es_CO' => 'Spaans (Colombië)',
        'es_CR' => 'Spaans (Costa Rica)',
        'es_CU' => 'Spaans (Kuba)',
        'es_DO' => 'Spaans (Dominikaanse Republiek)',
        'es_EC' => 'Spaans (Ecuador)',
        'es_ES' => 'Spaans (Spanje)',
        'es_GQ' => 'Spaans (Ekwatoriaal-Guinee)',
        'es_GT' => 'Spaans (Guatemala)',
        'es_HN' => 'Spaans (Honduras)',
        'es_MX' => 'Spaans (Meksiko)',
        'es_NI' => 'Spaans (Nicaragua)',
        'es_PA' => 'Spaans (Panama)',
        'es_PE' => 'Spaans (Peru)',
        'es_PH' => 'Spaans (Filippyne)',
        'es_PR' => 'Spaans (Puerto Rico)',
        'es_PY' => 'Spaans (Paraguay)',
        'es_SV' => 'Spaans (El Salvador)',
        'es_US' => 'Spaans (Verenigde State van Amerika)',
        'es_UY' => 'Spaans (Uruguay)',
        'es_VE' => 'Spaans (Venezuela)',
        'et' => 'Estnies',
        'et_EE' => 'Estnies (Estland)',
        'eu' => 'Baskies',
        'eu_ES' => 'Baskies (Spanje)',
        'fa' => 'Persies',
        'fa_AF' => 'Persies (Afganistan)',
        'fa_IR' => 'Persies (Iran)',
        'ff' => 'Fulah',
        'ff_Adlm' => 'Fulah (Adlam)',
        'ff_Adlm_BF' => 'Fulah (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Fulah (Adlam, Kameroen)',
        'ff_Adlm_GH' => 'Fulah (Adlam, Ghana)',
        'ff_Adlm_GM' => 'Fulah (Adlam, Gambië)',
        'ff_Adlm_GN' => 'Fulah (Adlam, Guinee)',
        'ff_Adlm_GW' => 'Fulah (Adlam, Guinee-Bissau)',
        'ff_Adlm_LR' => 'Fulah (Adlam, Liberië)',
        'ff_Adlm_MR' => 'Fulah (Adlam, Mauritanië)',
        'ff_Adlm_NE' => 'Fulah (Adlam, Niger)',
        'ff_Adlm_NG' => 'Fulah (Adlam, Nigerië)',
        'ff_Adlm_SL' => 'Fulah (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Fulah (Adlam, Senegal)',
        'ff_CM' => 'Fulah (Kameroen)',
        'ff_GN' => 'Fulah (Guinee)',
        'ff_Latn' => 'Fulah (Latyn)',
        'ff_Latn_BF' => 'Fulah (Latyn, Burkina Faso)',
        'ff_Latn_CM' => 'Fulah (Latyn, Kameroen)',
        'ff_Latn_GH' => 'Fulah (Latyn, Ghana)',
        'ff_Latn_GM' => 'Fulah (Latyn, Gambië)',
        'ff_Latn_GN' => 'Fulah (Latyn, Guinee)',
        'ff_Latn_GW' => 'Fulah (Latyn, Guinee-Bissau)',
        'ff_Latn_LR' => 'Fulah (Latyn, Liberië)',
        'ff_Latn_MR' => 'Fulah (Latyn, Mauritanië)',
        'ff_Latn_NE' => 'Fulah (Latyn, Niger)',
        'ff_Latn_NG' => 'Fulah (Latyn, Nigerië)',
        'ff_Latn_SL' => 'Fulah (Latyn, Sierra Leone)',
        'ff_Latn_SN' => 'Fulah (Latyn, Senegal)',
        'ff_MR' => 'Fulah (Mauritanië)',
        'ff_SN' => 'Fulah (Senegal)',
        'fi' => 'Fins',
        'fi_FI' => 'Fins (Finland)',
        'fo' => 'Faroëes',
        'fo_DK' => 'Faroëes (Denemarke)',
        'fo_FO' => 'Faroëes (Faroëreilande)',
        'fr' => 'Frans',
        'fr_BE' => 'Frans (België)',
        'fr_BF' => 'Frans (Burkina Faso)',
        'fr_BI' => 'Frans (Burundi)',
        'fr_BJ' => 'Frans (Benin)',
        'fr_BL' => 'Frans (Sint Barthélemy)',
        'fr_CA' => 'Frans (Kanada)',
        'fr_CD' => 'Frans (Demokratiese Republiek van die Kongo)',
        'fr_CF' => 'Frans (Sentraal-Afrikaanse Republiek)',
        'fr_CG' => 'Frans (Kongo-Brazzaville)',
        'fr_CH' => 'Frans (Switserland)',
        'fr_CI' => 'Frans (Ivoorkus)',
        'fr_CM' => 'Frans (Kameroen)',
        'fr_DJ' => 'Frans (Djiboeti)',
        'fr_DZ' => 'Frans (Algerië)',
        'fr_FR' => 'Frans (Frankryk)',
        'fr_GA' => 'Frans (Gaboen)',
        'fr_GF' => 'Frans (Frans-Guyana)',
        'fr_GN' => 'Frans (Guinee)',
        'fr_GP' => 'Frans (Guadeloupe)',
        'fr_GQ' => 'Frans (Ekwatoriaal-Guinee)',
        'fr_HT' => 'Frans (Haïti)',
        'fr_KM' => 'Frans (Comore)',
        'fr_LU' => 'Frans (Luxemburg)',
        'fr_MA' => 'Frans (Marokko)',
        'fr_MC' => 'Frans (Monaco)',
        'fr_MF' => 'Frans (Sint Martin)',
        'fr_MG' => 'Frans (Madagaskar)',
        'fr_ML' => 'Frans (Mali)',
        'fr_MQ' => 'Frans (Martinique)',
        'fr_MR' => 'Frans (Mauritanië)',
        'fr_MU' => 'Frans (Mauritius)',
        'fr_NC' => 'Frans (Nieu-Kaledonië)',
        'fr_NE' => 'Frans (Niger)',
        'fr_PF' => 'Frans (Frans-Polinesië)',
        'fr_PM' => 'Frans (Sint Pierre en Miquelon)',
        'fr_RE' => 'Frans (Réunion)',
        'fr_RW' => 'Frans (Rwanda)',
        'fr_SC' => 'Frans (Seychelle)',
        'fr_SN' => 'Frans (Senegal)',
        'fr_SY' => 'Frans (Sirië)',
        'fr_TD' => 'Frans (Tsjad)',
        'fr_TG' => 'Frans (Togo)',
        'fr_TN' => 'Frans (Tunisië)',
        'fr_VU' => 'Frans (Vanuatu)',
        'fr_WF' => 'Frans (Wallis en Futuna)',
        'fr_YT' => 'Frans (Mayotte)',
        'fy' => 'Fries',
        'fy_NL' => 'Fries (Nederland)',
        'ga' => 'Iers',
        'ga_GB' => 'Iers (Verenigde Koninkryk)',
        'ga_IE' => 'Iers (Ierland)',
        'gd' => 'Skotse Gallies',
        'gd_GB' => 'Skotse Gallies (Verenigde Koninkryk)',
        'gl' => 'Galisies',
        'gl_ES' => 'Galisies (Spanje)',
        'gu' => 'Goedjarati',
        'gu_IN' => 'Goedjarati (Indië)',
        'gv' => 'Manx',
        'gv_IM' => 'Manx (Eiland Man)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Ghana)',
        'ha_NE' => 'Hausa (Niger)',
        'ha_NG' => 'Hausa (Nigerië)',
        'he' => 'Hebreeus',
        'he_IL' => 'Hebreeus (Israel)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (Indië)',
        'hi_Latn' => 'Hindi (Latyn)',
        'hi_Latn_IN' => 'Hindi (Latyn, Indië)',
        'hr' => 'Kroaties',
        'hr_BA' => 'Kroaties (Bosnië en Herzegowina)',
        'hr_HR' => 'Kroaties (Kroasië)',
        'hu' => 'Hongaars',
        'hu_HU' => 'Hongaars (Hongarye)',
        'hy' => 'Armeens',
        'hy_AM' => 'Armeens (Armenië)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (wêreld)',
        'id' => 'Indonesies',
        'id_ID' => 'Indonesies (Indonesië)',
        'ie' => 'Interlingue',
        'ie_EE' => 'Interlingue (Estland)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nigerië)',
        'ii' => 'Sichuan Yi',
        'ii_CN' => 'Sichuan Yi (China)',
        'is' => 'Yslands',
        'is_IS' => 'Yslands (Ysland)',
        'it' => 'Italiaans',
        'it_CH' => 'Italiaans (Switserland)',
        'it_IT' => 'Italiaans (Italië)',
        'it_SM' => 'Italiaans (San Marino)',
        'it_VA' => 'Italiaans (Vatikaanstad)',
        'ja' => 'Japannees',
        'ja_JP' => 'Japannees (Japan)',
        'jv' => 'Javaans',
        'jv_ID' => 'Javaans (Indonesië)',
        'ka' => 'Georgies',
        'ka_GE' => 'Georgies (Georgië)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Kenia)',
        'kk' => 'Kazaks',
        'kk_Arab' => 'Kazaks (Arabies)',
        'kk_Arab_CN' => 'Kazaks (Arabies, China)',
        'kk_Cyrl' => 'Kazaks (Cyrillies)',
        'kk_Cyrl_KZ' => 'Kazaks (Cyrillies, Kazakstan)',
        'kk_KZ' => 'Kazaks (Kazakstan)',
        'kl' => 'Kalaallisut',
        'kl_GL' => 'Kalaallisut (Groenland)',
        'km' => 'Khmer',
        'km_KH' => 'Khmer (Kambodja)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (Indië)',
        'ko' => 'Koreaans',
        'ko_CN' => 'Koreaans (China)',
        'ko_KP' => 'Koreaans (Noord-Korea)',
        'ko_KR' => 'Koreaans (Suid-Korea)',
        'ks' => 'Kasjmiri',
        'ks_Arab' => 'Kasjmiri (Arabies)',
        'ks_Arab_IN' => 'Kasjmiri (Arabies, Indië)',
        'ks_Deva' => 'Kasjmiri (Devanagari)',
        'ks_Deva_IN' => 'Kasjmiri (Devanagari, Indië)',
        'ks_IN' => 'Kasjmiri (Indië)',
        'ku' => 'Koerdies',
        'ku_Latn' => 'Koerdies (Latyn)',
        'ku_Latn_IQ' => 'Koerdies (Latyn, Irak)',
        'ku_Latn_SY' => 'Koerdies (Latyn, Sirië)',
        'ku_Latn_TR' => 'Koerdies (Latyn, Turkye)',
        'ku_SY' => 'Koerdies (Sirië)',
        'ku_TR' => 'Koerdies (Turkye)',
        'kw' => 'Kornies',
        'kw_GB' => 'Kornies (Verenigde Koninkryk)',
        'ky' => 'Kirgisies',
        'ky_KG' => 'Kirgisies (Kirgistan)',
        'lb' => 'Luxemburgs',
        'lb_LU' => 'Luxemburgs (Luxemburg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lingaals',
        'ln_AO' => 'Lingaals (Angola)',
        'ln_CD' => 'Lingaals (Demokratiese Republiek van die Kongo)',
        'ln_CF' => 'Lingaals (Sentraal-Afrikaanse Republiek)',
        'ln_CG' => 'Lingaals (Kongo-Brazzaville)',
        'lo' => 'Lao',
        'lo_LA' => 'Lao (Laos)',
        'lt' => 'Litaus',
        'lt_LT' => 'Litaus (Litaue)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Demokratiese Republiek van die Kongo)',
        'lv' => 'Letties',
        'lv_LV' => 'Letties (Letland)',
        'mg' => 'Malgassies',
        'mg_MG' => 'Malgassies (Madagaskar)',
        'mi' => 'Maori',
        'mi_NZ' => 'Maori (Nieu-Seeland)',
        'mk' => 'Masedonies',
        'mk_MK' => 'Masedonies (Noord-Macedonië)',
        'ml' => 'Malabaars',
        'ml_IN' => 'Malabaars (Indië)',
        'mn' => 'Mongools',
        'mn_MN' => 'Mongools (Mongolië)',
        'mr' => 'Marathi',
        'mr_IN' => 'Marathi (Indië)',
        'ms' => 'Maleis',
        'ms_BN' => 'Maleis (Broenei)',
        'ms_ID' => 'Maleis (Indonesië)',
        'ms_MY' => 'Maleis (Maleisië)',
        'ms_SG' => 'Maleis (Singapoer)',
        'mt' => 'Maltees',
        'mt_MT' => 'Maltees (Malta)',
        'my' => 'Birmaans',
        'my_MM' => 'Birmaans (Mianmar [Birma])',
        'nb' => 'Boeknoors',
        'nb_NO' => 'Boeknoors (Noorweë)',
        'nb_SJ' => 'Boeknoors (Spitsbergen en Jan Mayen)',
        'nd' => 'Noord-Ndebele',
        'nd_ZW' => 'Noord-Ndebele (Zimbabwe)',
        'ne' => 'Nepalees',
        'ne_IN' => 'Nepalees (Indië)',
        'ne_NP' => 'Nepalees (Nepal)',
        'nl' => 'Nederlands',
        'nl_AW' => 'Nederlands (Aruba)',
        'nl_BE' => 'Nederlands (België)',
        'nl_BQ' => 'Nederlands (Karibiese Nederland)',
        'nl_CW' => 'Nederlands (Curaçao)',
        'nl_NL' => 'Nederlands (Nederland)',
        'nl_SR' => 'Nederlands (Suriname)',
        'nl_SX' => 'Nederlands (Sint Maarten)',
        'nn' => 'Nuwe Noors',
        'nn_NO' => 'Nuwe Noors (Noorweë)',
        'no' => 'Noors',
        'no_NO' => 'Noors (Noorweë)',
        'oc' => 'Oksitaans',
        'oc_ES' => 'Oksitaans (Spanje)',
        'oc_FR' => 'Oksitaans (Frankryk)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Ethiopië)',
        'om_KE' => 'Oromo (Kenia)',
        'or' => 'Odia',
        'or_IN' => 'Odia (Indië)',
        'os' => 'Osseties',
        'os_GE' => 'Osseties (Georgië)',
        'os_RU' => 'Osseties (Rusland)',
        'pa' => 'Pandjabi',
        'pa_Arab' => 'Pandjabi (Arabies)',
        'pa_Arab_PK' => 'Pandjabi (Arabies, Pakistan)',
        'pa_Guru' => 'Pandjabi (Gurmukhi)',
        'pa_Guru_IN' => 'Pandjabi (Gurmukhi, Indië)',
        'pa_IN' => 'Pandjabi (Indië)',
        'pa_PK' => 'Pandjabi (Pakistan)',
        'pl' => 'Pools',
        'pl_PL' => 'Pools (Pole)',
        'ps' => 'Pasjtoe',
        'ps_AF' => 'Pasjtoe (Afganistan)',
        'ps_PK' => 'Pasjtoe (Pakistan)',
        'pt' => 'Portugees',
        'pt_AO' => 'Portugees (Angola)',
        'pt_BR' => 'Portugees (Brasilië)',
        'pt_CH' => 'Portugees (Switserland)',
        'pt_CV' => 'Portugees (Kaap Verde)',
        'pt_GQ' => 'Portugees (Ekwatoriaal-Guinee)',
        'pt_GW' => 'Portugees (Guinee-Bissau)',
        'pt_LU' => 'Portugees (Luxemburg)',
        'pt_MO' => 'Portugees (Macau SAS China)',
        'pt_MZ' => 'Portugees (Mosambiek)',
        'pt_PT' => 'Portugees (Portugal)',
        'pt_ST' => 'Portugees (São Tomé en Príncipe)',
        'pt_TL' => 'Portugees (Oos-Timor)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Bolivië)',
        'qu_EC' => 'Quechua (Ecuador)',
        'qu_PE' => 'Quechua (Peru)',
        'rm' => 'Reto-Romaans',
        'rm_CH' => 'Reto-Romaans (Switserland)',
        'rn' => 'Rundi',
        'rn_BI' => 'Rundi (Burundi)',
        'ro' => 'Roemeens',
        'ro_MD' => 'Roemeens (Moldowa)',
        'ro_RO' => 'Roemeens (Roemenië)',
        'ru' => 'Russies',
        'ru_BY' => 'Russies (Belarus)',
        'ru_KG' => 'Russies (Kirgistan)',
        'ru_KZ' => 'Russies (Kazakstan)',
        'ru_MD' => 'Russies (Moldowa)',
        'ru_RU' => 'Russies (Rusland)',
        'ru_UA' => 'Russies (Oekraïne)',
        'rw' => 'Rwandees',
        'rw_RW' => 'Rwandees (Rwanda)',
        'sa' => 'Sanskrit',
        'sa_IN' => 'Sanskrit (Indië)',
        'sc' => 'Sardinies',
        'sc_IT' => 'Sardinies (Italië)',
        'sd' => 'Sindhi',
        'sd_Arab' => 'Sindhi (Arabies)',
        'sd_Arab_PK' => 'Sindhi (Arabies, Pakistan)',
        'sd_Deva' => 'Sindhi (Devanagari)',
        'sd_Deva_IN' => 'Sindhi (Devanagari, Indië)',
        'sd_IN' => 'Sindhi (Indië)',
        'sd_PK' => 'Sindhi (Pakistan)',
        'se' => 'Noord-Sami',
        'se_FI' => 'Noord-Sami (Finland)',
        'se_NO' => 'Noord-Sami (Noorweë)',
        'se_SE' => 'Noord-Sami (Swede)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Sentraal-Afrikaanse Republiek)',
        'sh' => 'Serwo-Kroaties',
        'sh_BA' => 'Serwo-Kroaties (Bosnië en Herzegowina)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (Sri Lanka)',
        'sk' => 'Slowaaks',
        'sk_SK' => 'Slowaaks (Slowakye)',
        'sl' => 'Sloweens',
        'sl_SI' => 'Sloweens (Slowenië)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (Zimbabwe)',
        'so' => 'Somalies',
        'so_DJ' => 'Somalies (Djiboeti)',
        'so_ET' => 'Somalies (Ethiopië)',
        'so_KE' => 'Somalies (Kenia)',
        'so_SO' => 'Somalies (Somalië)',
        'sq' => 'Albanees',
        'sq_AL' => 'Albanees (Albanië)',
        'sq_MK' => 'Albanees (Noord-Macedonië)',
        'sr' => 'Serwies',
        'sr_BA' => 'Serwies (Bosnië en Herzegowina)',
        'sr_Cyrl' => 'Serwies (Cyrillies)',
        'sr_Cyrl_BA' => 'Serwies (Cyrillies, Bosnië en Herzegowina)',
        'sr_Cyrl_ME' => 'Serwies (Cyrillies, Montenegro)',
        'sr_Cyrl_RS' => 'Serwies (Cyrillies, Serwië)',
        'sr_Latn' => 'Serwies (Latyn)',
        'sr_Latn_BA' => 'Serwies (Latyn, Bosnië en Herzegowina)',
        'sr_Latn_ME' => 'Serwies (Latyn, Montenegro)',
        'sr_Latn_RS' => 'Serwies (Latyn, Serwië)',
        'sr_ME' => 'Serwies (Montenegro)',
        'sr_RS' => 'Serwies (Serwië)',
        'st' => 'Suid-Sotho',
        'st_LS' => 'Suid-Sotho (Lesotho)',
        'st_ZA' => 'Suid-Sotho (Suid-Afrika)',
        'su' => 'Sundanees',
        'su_ID' => 'Sundanees (Indonesië)',
        'su_Latn' => 'Sundanees (Latyn)',
        'su_Latn_ID' => 'Sundanees (Latyn, Indonesië)',
        'sv' => 'Sweeds',
        'sv_AX' => 'Sweeds (Ålandeilande)',
        'sv_FI' => 'Sweeds (Finland)',
        'sv_SE' => 'Sweeds (Swede)',
        'sw' => 'Swahili',
        'sw_CD' => 'Swahili (Demokratiese Republiek van die Kongo)',
        'sw_KE' => 'Swahili (Kenia)',
        'sw_TZ' => 'Swahili (Tanzanië)',
        'sw_UG' => 'Swahili (Uganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (Indië)',
        'ta_LK' => 'Tamil (Sri Lanka)',
        'ta_MY' => 'Tamil (Maleisië)',
        'ta_SG' => 'Tamil (Singapoer)',
        'te' => 'Teloegoe',
        'te_IN' => 'Teloegoe (Indië)',
        'tg' => 'Tadjiks',
        'tg_TJ' => 'Tadjiks (Tadjikistan)',
        'th' => 'Thai',
        'th_TH' => 'Thai (Thailand)',
        'ti' => 'Tigrinja',
        'ti_ER' => 'Tigrinja (Eritrea)',
        'ti_ET' => 'Tigrinja (Ethiopië)',
        'tk' => 'Turkmeens',
        'tk_TM' => 'Turkmeens (Turkmenistan)',
        'tn' => 'Tswana',
        'tn_BW' => 'Tswana (Botswana)',
        'tn_ZA' => 'Tswana (Suid-Afrika)',
        'to' => 'Tongaans',
        'to_TO' => 'Tongaans (Tonga)',
        'tr' => 'Turks',
        'tr_CY' => 'Turks (Siprus)',
        'tr_TR' => 'Turks (Turkye)',
        'tt' => 'Tataars',
        'tt_RU' => 'Tataars (Rusland)',
        'ug' => 'Uighur',
        'ug_CN' => 'Uighur (China)',
        'uk' => 'Oekraïens',
        'uk_UA' => 'Oekraïens (Oekraïne)',
        'ur' => 'Oerdoe',
        'ur_IN' => 'Oerdoe (Indië)',
        'ur_PK' => 'Oerdoe (Pakistan)',
        'uz' => 'Oesbekies',
        'uz_AF' => 'Oesbekies (Afganistan)',
        'uz_Arab' => 'Oesbekies (Arabies)',
        'uz_Arab_AF' => 'Oesbekies (Arabies, Afganistan)',
        'uz_Cyrl' => 'Oesbekies (Cyrillies)',
        'uz_Cyrl_UZ' => 'Oesbekies (Cyrillies, Oesbekistan)',
        'uz_Latn' => 'Oesbekies (Latyn)',
        'uz_Latn_UZ' => 'Oesbekies (Latyn, Oesbekistan)',
        'uz_UZ' => 'Oesbekies (Oesbekistan)',
        'vi' => 'Viëtnamees',
        'vi_VN' => 'Viëtnamees (Viëtnam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (Senegal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (Suid-Afrika)',
        'yi' => 'Jiddisj',
        'yi_UA' => 'Jiddisj (Oekraïne)',
        'yo' => 'Joroeba',
        'yo_BJ' => 'Joroeba (Benin)',
        'yo_NG' => 'Joroeba (Nigerië)',
        'za' => 'Zhuang',
        'za_CN' => 'Zhuang (China)',
        'zh' => 'Chinees',
        'zh_CN' => 'Chinees (China)',
        'zh_HK' => 'Chinees (Hongkong SAS China)',
        'zh_Hans' => 'Chinees (Vereenvoudig)',
        'zh_Hans_CN' => 'Chinees (Vereenvoudig, China)',
        'zh_Hans_HK' => 'Chinees (Vereenvoudig, Hongkong SAS China)',
        'zh_Hans_MO' => 'Chinees (Vereenvoudig, Macau SAS China)',
        'zh_Hans_MY' => 'Chinees (Vereenvoudig, Maleisië)',
        'zh_Hans_SG' => 'Chinees (Vereenvoudig, Singapoer)',
        'zh_Hant' => 'Chinees (Tradisioneel)',
        'zh_Hant_HK' => 'Chinees (Tradisioneel, Hongkong SAS China)',
        'zh_Hant_MO' => 'Chinees (Tradisioneel, Macau SAS China)',
        'zh_Hant_MY' => 'Chinees (Tradisioneel, Maleisië)',
        'zh_Hant_TW' => 'Chinees (Tradisioneel, Taiwan)',
        'zh_MO' => 'Chinees (Macau SAS China)',
        'zh_SG' => 'Chinees (Singapoer)',
        'zh_TW' => 'Chinees (Taiwan)',
        'zu' => 'Zoeloe',
        'zu_ZA' => 'Zoeloe (Suid-Afrika)',
    ],
];
