<?php

return [
    'Names' => [
        'Adlm' => 'adlam',
        'Aghb' => 'albaneză caucaziană',
        'Ahom' => 'ahom',
        'Arab' => 'arabă',
        'Aran' => 'nastaaliq',
        'Armi' => 'aramaică imperială',
        'Armn' => 'armeană',
        'Avst' => 'avestică',
        'Bali' => 'balineză',
        'Bamu' => 'bamum',
        'Bass' => 'bassa vah',
        'Batk' => 'batak',
        'Beng' => 'bengaleză',
        'Bhks' => 'bhaiksuki',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmanică',
        'Brai' => 'braille',
        'Bugi' => 'bugineză',
        'Buhd' => 'buhidă',
        'Cakm' => 'chakma',
        'Cans' => 'silabică aborigenă canadiană unificată',
        'Cari' => 'cariană',
        'Cham' => 'cham',
        'Cher' => 'cherokee',
        'Chrs' => 'khorezmiană',
        'Copt' => 'coptă',
        'Cpmn' => 'cipro-minoană',
        'Cprt' => 'cipriotă',
        'Cyrl' => 'chirilică',
        'Cyrs' => 'chirilică slavonă bisericească veche',
        'Deva' => 'devanagari',
        'Diak' => 'dives akuru',
        'Dogr' => 'dogra',
        'Dsrt' => 'mormonă',
        'Dupl' => 'stenografie duployană',
        'Egyd' => 'demotică egipteană',
        'Egyh' => 'hieratică egipteană',
        'Egyp' => 'hieroglife egiptene',
        'Elba' => 'elbasan',
        'Elym' => 'elimaică',
        'Ethi' => 'etiopiană',
        'Geok' => 'georgiană bisericească',
        'Geor' => 'georgiană',
        'Glag' => 'glagolitică',
        'Gong' => 'gunjala gondi',
        'Gonm' => 'masaram gondi',
        'Goth' => 'gotică',
        'Gran' => 'grantha',
        'Grek' => 'greacă',
        'Gujr' => 'gujarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'hanb',
        'Hang' => 'hangul',
        'Hani' => 'han',
        'Hano' => 'hanunoo',
        'Hans' => 'simplificată',
        'Hant' => 'tradițională',
        'Hatr' => 'hatrană',
        'Hebr' => 'ebraică',
        'Hira' => 'hiragana',
        'Hluw' => 'hieroglife anatoliene',
        'Hmng' => 'pahawh hmong',
        'Hmnp' => 'nyiakeng puachue hmong',
        'Hrkt' => 'silabică japoneză',
        'Hung' => 'maghiară veche',
        'Inds' => 'indus',
        'Ital' => 'italică veche',
        'Jamo' => 'jamo',
        'Java' => 'javaneză',
        'Jpan' => 'japoneză',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Kawi' => 'kawi',
        'Khar' => 'kharosthi',
        'Khmr' => 'khmeră',
        'Khoj' => 'khojki',
        'Kits' => 'litere mici khitane',
        'Knda' => 'kannada',
        'Kore' => 'coreeană',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'laoțiană',
        'Latf' => 'latină Fraktur',
        'Latg' => 'latină gaelică',
        'Latn' => 'latină',
        'Lepc' => 'lepcha',
        'Limb' => 'limbu',
        'Lina' => 'lineară A',
        'Linb' => 'lineară B',
        'Lisu' => 'fraser',
        'Lyci' => 'liciană',
        'Lydi' => 'lidiană',
        'Mahj' => 'mahajani',
        'Maka' => 'makasar',
        'Mand' => 'mandeană',
        'Mani' => 'maniheeană',
        'Marc' => 'marchen',
        'Maya' => 'hieroglife maya',
        'Medf' => 'medefaidrin',
        'Mend' => 'mende',
        'Merc' => 'meroitică cursivă',
        'Mero' => 'meroitică',
        'Mlym' => 'malayalam',
        'Modi' => 'modi',
        'Mong' => 'mongolă',
        'Mroo' => 'mro',
        'Mtei' => 'meitei mayek',
        'Mult' => 'multani',
        'Mymr' => 'birmană',
        'Nagm' => 'nag mundari',
        'Nand' => 'nandinagari',
        'Narb' => 'arabă veche din nord',
        'Nbat' => 'nabateeană',
        'Newa' => 'newa',
        'Nkoo' => 'n’ko',
        'Nshu' => 'nüshu',
        'Ogam' => 'ogham',
        'Olck' => 'ol chiki',
        'Orkh' => 'orhon',
        'Orya' => 'oriya',
        'Osge' => 'osage',
        'Osma' => 'osmanya',
        'Ougr' => 'uigură veche',
        'Palm' => 'palmirenă',
        'Pauc' => 'pau cin hau',
        'Perm' => 'permică veche',
        'Phag' => 'phags-pa',
        'Phli' => 'pahlavi pentru inscripții',
        'Phlp' => 'pahlavi pentru psaltire',
        'Phnx' => 'feniciană',
        'Plrd' => 'pollardă fonetică',
        'Prti' => 'partă pentru inscripții',
        'Qaag' => 'zawgyi',
        'Rjng' => 'rejang',
        'Rohg' => 'hanifi',
        'Runr' => 'runică',
        'Samr' => 'samariteană',
        'Sarb' => 'arabă veche din sud',
        'Saur' => 'saurashtra',
        'Sgnw' => 'scrierea simbolică',
        'Shaw' => 'savă',
        'Shrd' => 'sharadă',
        'Sidd' => 'siddham',
        'Sind' => 'khudawadi',
        'Sinh' => 'singaleză',
        'Sogd' => 'sogdiană',
        'Sogo' => 'sogdiană veche',
        'Sora' => 'sora sompeng',
        'Soyo' => 'soyombo',
        'Sund' => 'sundaneză',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'siriacă',
        'Syrj' => 'siriacă occidentală',
        'Syrn' => 'siriacă orientală',
        'Tagb' => 'tagbanwa',
        'Takr' => 'takri',
        'Tale' => 'tai le',
        'Talu' => 'tai le nouă',
        'Taml' => 'tamilă',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugu',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalog',
        'Thaa' => 'thaana',
        'Thai' => 'thailandeză',
        'Tibt' => 'tibetană',
        'Tirh' => 'tirhuta',
        'Tnsa' => 'tangsa',
        'Toto' => 'toto',
        'Ugar' => 'ugaritică',
        'Vaii' => 'vai',
        'Vith' => 'vithkuqi',
        'Wara' => 'varang kshiti',
        'Wcho' => 'wancho',
        'Xpeo' => 'persană veche',
        'Xsux' => 'cuneiformă sumero-akkadiană',
        'Yezi' => 'yazidită',
        'Yiii' => 'yi',
        'Zanb' => 'Piața Zanabazar',
        'Zinh' => 'moștenită',
        'Zmth' => 'notație matematică',
        'Zsye' => 'emoji',
        'Zsym' => 'simboluri',
        'Zxxx' => 'nescrisă',
        'Zyyy' => 'comună',
    ],
];
