<?php

return [
    'Names' => [
        'Arab' => 'Араб',
        'Armn' => 'Арман',
        'Beng' => 'Бенгали',
        'Bopo' => 'Бопомофо',
        'Brai' => 'Браилле',
        'Cyrl' => 'Кирил',
        'Deva' => 'Девангари',
        'Ethi' => 'Ҳабаш',
        'Geor' => 'Грузин',
        'Grek' => 'Юнон',
        'Gujr' => 'Гужарати',
        'Guru' => 'Гурмухи',
        'Hang' => 'Хангул',
        'Hani' => 'Хан',
        'Hans' => 'Соддалаштирилган',
        'Hant' => 'Анъанавий',
        'Hebr' => 'Иброний',
        'Hira' => 'Хирагана',
        'Jpan' => 'Япон',
        'Kana' => 'Катакана',
        'Khmr' => 'Хмер',
        'Knda' => 'Каннада',
        'Kore' => 'Корейс',
        'Laoo' => 'Лао',
        'Latn' => 'Лотин',
        'Mlym' => 'Малайалам',
        'Mong' => 'Мўғулча',
        'Mymr' => 'Мьянма',
        'Orya' => 'Ория',
        'Sinh' => 'Синхала',
        'Taml' => 'Тамил',
        'Telu' => 'Телугу',
        'Thaa' => 'Таана',
        'Thai' => 'Тай',
        'Tibt' => 'Тибет',
        'Zsym' => 'Рамзлар',
        'Zxxx' => 'Ёзилмаган',
        'Zyyy' => 'Умумий',
    ],
];
