{% set pagetile = 'SimpleSAMLphp Show Metadata'|trans %}
{% extends 'base.twig' %}
{% block content %}

    <h2>{{ 'Metadata' | trans }}</h2>
    <div class="code-box hljs">
        <div class="pure-button-group top-right-corner">
            <a class="pure-button copy hljs" data-clipboard-target="#metadata"
                title="{% trans %}Copy to clipboard{% endtrans %}"><span class="fa fa-copy"></span></a>
        </div>
        <div id="metadata" class="code-box-content php">
            {#- #}$metadata["{{ entityid }}"] = {{ metadata|escape }};{# -#}
        </div>
    </div>
    <div class="center">
        <a href="{{ moduleURL('admin/federation') }}" class="pure-button pure-button-red">{{ 'Back'|trans }}</a>
    </div>
{% endblock content %}
