<?php

return [
    'Names' => [
        'aa' => '阿法爾文',
        'am' => '岩哈拉語',
        'az' => '阿塞拜疆文',
        'ba' => '巴什基爾文',
        'br' => '布里多尼文',
        'bs' => '波斯尼亞文',
        'ca' => '加泰隆尼亞文',
        'crs' => '塞舌爾克里奧爾法文',
        'den' => '斯拉夫文',
        'eo' => '世界語',
        'gil' => '吉爾伯特文',
        'gl' => '加里西亞文',
        'gsw' => '瑞士德文',
        'hr' => '克羅地亞文',
        'ig' => '伊博文',
        'it' => '意大利文',
        'jpr' => '猶太波斯文',
        'ka' => '格魯吉亞文',
        'kiu' => '扎扎其文',
        'kn' => '坎納達文',
        'kri' => '克裡奧爾文',
        'lo' => '老撾文',
        'luo' => '盧歐文',
        'mfe' => '毛里裘斯克里奧爾文',
        'mg' => '馬拉加斯文',
        'ml' => '馬拉雅拉姆文',
        'mt' => '馬耳他文',
        'nqo' => '西非書面語言（N’ko）',
        'or' => '奧里雅文',
        'pcm' => '尼日利亞皮欽文',
        'rup' => '阿羅馬尼亞語',
        'rw' => '盧旺達文',
        'sl' => '斯洛文尼亞文',
        'sn' => '修納文',
        'so' => '索馬里文',
        'syr' => '敍利亞文',
        'ta' => '泰米爾文',
        'tn' => '突尼西亞文',
        'to' => '湯加文',
        'ur' => '烏爾都文',
        'wbp' => '瓦爾皮里文',
        'yue' => '廣東話',
        'zgh' => '摩洛哥標準塔馬齊格特文',
    ],
    'LocalizedNames' => [
        'az_Arab' => '南阿塞拜疆文',
        'de_AT' => '奧地利德文',
        'de_CH' => '瑞士德語',
        'en_AU' => '澳洲英文',
        'en_CA' => '加拿大英文',
        'en_GB' => '英國英文',
        'en_US' => '美國英文',
        'es_419' => '拉丁美洲西班牙文',
        'es_ES' => '歐洲西班牙文',
        'es_MX' => '墨西哥西班牙文',
        'fa_AF' => '達利文',
        'fr_CA' => '加拿大法文',
        'fr_CH' => '瑞士法文',
        'nl_BE' => '比利時荷蘭文',
        'pt_BR' => '巴西葡萄牙文',
        'pt_PT' => '歐洲葡萄牙文',
        'ro_MD' => '摩爾多瓦羅馬尼亞文',
        'sw_CD' => '剛果史瓦希里文',
    ],
];
