<?php

return [
    'Names' => [
        'America/Adak' => 'ཨ་མེ་རི་ཀ། (Adak)',
        'America/Anchorage' => 'ཨ་མེ་རི་ཀ། (Anchorage)',
        'America/Boise' => 'ཨ་མེ་རི་ཀ། (Boise)',
        'America/Chicago' => 'ཨ་མེ་རི་ཀ། (Chicago)',
        'America/Denver' => 'ཨ་མེ་རི་ཀ། (Denver)',
        'America/Detroit' => 'ཨ་མེ་རི་ཀ། (Detroit)',
        'America/Indiana/Knox' => 'ཨ་མེ་རི་ཀ། (Knox, Indiana)',
        'America/Indiana/Marengo' => 'ཨ་མེ་རི་ཀ། (Marengo, Indiana)',
        'America/Indiana/Petersburg' => 'ཨ་མེ་རི་ཀ། (Petersburg, Indiana)',
        'America/Indiana/Tell_City' => 'ཨ་མེ་རི་ཀ། (Tell City, Indiana)',
        'America/Indiana/Vevay' => 'ཨ་མེ་རི་ཀ། (Vevay, Indiana)',
        'America/Indiana/Vincennes' => 'ཨ་མེ་རི་ཀ། (Vincennes, Indiana)',
        'America/Indiana/Winamac' => 'ཨ་མེ་རི་ཀ། (Winamac, Indiana)',
        'America/Indianapolis' => 'ཨ་མེ་རི་ཀ། (Indianapolis)',
        'America/Indiana/Indianapolis' => 'ཨ་མེ་རི་ཀ། (Indianapolis)',
        'America/Juneau' => 'ཨ་མེ་རི་ཀ། (Juneau)',
        'America/Kentucky/Monticello' => 'ཨ་མེ་རི་ཀ། (Monticello, Kentucky)',
        'America/Los_Angeles' => 'ཨ་མེ་རི་ཀ། (Los Angeles)',
        'America/Louisville' => 'ཨ་མེ་རི་ཀ། (Louisville)',
        'America/Kentucky/Louisville' => 'ཨ་མེ་རི་ཀ། (Louisville)',
        'America/Menominee' => 'ཨ་མེ་རི་ཀ། (Menominee)',
        'America/Metlakatla' => 'ཨ་མེ་རི་ཀ། (Metlakatla)',
        'America/New_York' => 'ཨ་མེ་རི་ཀ། (New York)',
        'America/Nome' => 'ཨ་མེ་རི་ཀ། (Nome)',
        'America/North_Dakota/Beulah' => 'ཨ་མེ་རི་ཀ། (Beulah, North Dakota)',
        'America/North_Dakota/Center' => 'ཨ་མེ་རི་ཀ། (Center, North Dakota)',
        'America/North_Dakota/New_Salem' => 'ཨ་མེ་རི་ཀ། (New Salem, North Dakota)',
        'America/Phoenix' => 'ཨ་མེ་རི་ཀ། (Phoenix)',
        'America/Sitka' => 'ཨ་མེ་རི་ཀ། (Sitka)',
        'America/Yakutat' => 'ཨ་མེ་རི་ཀ། (Yakutat)',
        'Antarctica/Troll' => 'Troll',
        'Asia/Anadyr' => 'ཨུ་རུ་སུ་ (Anadyr)',
        'Asia/Barnaul' => 'ཨུ་རུ་སུ་ (Barnaul)',
        'Asia/Calcutta' => 'རྒྱ་གར་ (Kolkata)',
        'Asia/Kolkata' => 'རྒྱ་གར་ (Kolkata)',
        'Asia/Chita' => 'ཨུ་རུ་སུ་ (Chita)',
        'Asia/Irkutsk' => 'ཨུ་རུ་སུ་ (Irkutsk)',
        'Asia/Kamchatka' => 'ཨུ་རུ་སུ་ (Kamchatka)',
        'Asia/Katmandu' => 'བལ་ཡུལ་ (Kathmandu)',
        'Asia/Kathmandu' => 'བལ་ཡུལ་ (Kathmandu)',
        'Asia/Khandyga' => 'ཨུ་རུ་སུ་ (Khandyga)',
        'Asia/Krasnoyarsk' => 'ཨུ་རུ་སུ་ (Krasnoyarsk)',
        'Asia/Magadan' => 'ཨུ་རུ་སུ་ (Magadan)',
        'Asia/Novokuznetsk' => 'ཨུ་རུ་སུ་ (Novokuznetsk)',
        'Asia/Novosibirsk' => 'ཨུ་རུ་སུ་ (Novosibirsk)',
        'Asia/Omsk' => 'ཨུ་རུ་སུ་ (Omsk)',
        'Asia/Sakhalin' => 'ཨུ་རུ་སུ་ (Sakhalin)',
        'Asia/Seoul' => 'ལྷོ་ཀོ་རི་ཡ། (Seoul)',
        'Asia/Shanghai' => 'རྒྱ་ནག (Shanghai)',
        'Asia/Srednekolymsk' => 'ཨུ་རུ་སུ་ (Srednekolymsk)',
        'Asia/Tokyo' => 'ཉི་ཧོང་ (Tokyo)',
        'Asia/Tomsk' => 'ཨུ་རུ་སུ་ (Tomsk)',
        'Asia/Urumqi' => 'རྒྱ་ནག (Ürümqi)',
        'Asia/Ust-Nera' => 'ཨུ་རུ་སུ་ (Ust-Nera)',
        'Asia/Vladivostok' => 'ཨུ་རུ་སུ་ (Vladivostok)',
        'Asia/Yakutsk' => 'ཨུ་རུ་སུ་ (Yakutsk)',
        'Asia/Yekaterinburg' => 'ཨུ་རུ་སུ་ (Yekaterinburg)',
        'Europe/Astrakhan' => 'ཨུ་རུ་སུ་ (Astrakhan)',
        'Europe/Berlin' => 'འཇར་མན་ (Berlin)',
        'Europe/Busingen' => 'འཇར་མན་ (Büsingen)',
        'Europe/Kaliningrad' => 'ཨུ་རུ་སུ་ (Kaliningrad)',
        'Europe/Kirov' => 'ཨུ་རུ་སུ་ (Kirov)',
        'Europe/London' => 'དབྱིན་ཇི་ (London)',
        'Europe/Moscow' => 'ཨུ་རུ་སུ་ (Moscow)',
        'Europe/Rome' => 'ཨི་ཀྲར་ལི་ (Rome)',
        'Europe/Samara' => 'ཨུ་རུ་སུ་ (Samara)',
        'Europe/Saratov' => 'ཨུ་རུ་སུ་ (Saratov)',
        'Europe/Ulyanovsk' => 'ཨུ་རུ་སུ་ (Ulyanovsk)',
        'Europe/Volgograd' => 'ཨུ་རུ་སུ་ (Volgograd)',
        'Pacific/Honolulu' => 'ཨ་མེ་རི་ཀ། (Honolulu)',
    ],
    'Meta' => [],
];
