<?php

return [
    'Names' => [
        'af' => 'afrikaans',
        'af_NA' => 'afrikaans (Namibiya)',
        'af_ZA' => 'afrikaans (Janubiy Afrika Respublikasi)',
        'ak' => 'akan',
        'ak_GH' => 'akan (Gana)',
        'am' => 'amxar',
        'am_ET' => 'amxar (Efiopiya)',
        'ar' => 'arab',
        'ar_001' => 'arab (Dunyo)',
        'ar_AE' => 'arab (Birlashgan Arab Amirliklari)',
        'ar_BH' => 'arab (Bahrayn)',
        'ar_DJ' => 'arab (Jibuti)',
        'ar_DZ' => 'arab (Jazoir)',
        'ar_EG' => 'arab (Misr)',
        'ar_EH' => 'arab (G‘arbiy Sahroi Kabir)',
        'ar_ER' => 'arab (Eritreya)',
        'ar_IL' => 'arab (Isroil)',
        'ar_IQ' => 'arab (Iroq)',
        'ar_JO' => 'arab (Iordaniya)',
        'ar_KM' => 'arab (Komor orollari)',
        'ar_KW' => 'arab (Quvayt)',
        'ar_LB' => 'arab (Livan)',
        'ar_LY' => 'arab (Liviya)',
        'ar_MA' => 'arab (Marokash)',
        'ar_MR' => 'arab (Mavritaniya)',
        'ar_OM' => 'arab (Ummon)',
        'ar_PS' => 'arab (Falastin hududlari)',
        'ar_QA' => 'arab (Qatar)',
        'ar_SA' => 'arab (Saudiya Arabistoni)',
        'ar_SD' => 'arab (Sudan)',
        'ar_SO' => 'arab (Somali)',
        'ar_SS' => 'arab (Janubiy Sudan)',
        'ar_SY' => 'arab (Suriya)',
        'ar_TD' => 'arab (Chad)',
        'ar_TN' => 'arab (Tunis)',
        'ar_YE' => 'arab (Yaman)',
        'as' => 'assam',
        'as_IN' => 'assam (Hindiston)',
        'az' => 'ozarbayjon',
        'az_AZ' => 'ozarbayjon (Ozarbayjon)',
        'az_Cyrl' => 'ozarbayjon (kirill)',
        'az_Cyrl_AZ' => 'ozarbayjon (kirill, Ozarbayjon)',
        'az_Latn' => 'ozarbayjon (lotin)',
        'az_Latn_AZ' => 'ozarbayjon (lotin, Ozarbayjon)',
        'ba' => 'boshqird',
        'ba_RU' => 'boshqird (Rossiya)',
        'be' => 'belarus',
        'be_BY' => 'belarus (Belarus)',
        'bg' => 'bolgar',
        'bg_BG' => 'bolgar (Bolgariya)',
        'bm' => 'bambara',
        'bm_ML' => 'bambara (Mali)',
        'bn' => 'bengal',
        'bn_BD' => 'bengal (Bangladesh)',
        'bn_IN' => 'bengal (Hindiston)',
        'bo' => 'tibet',
        'bo_CN' => 'tibet (Xitoy)',
        'bo_IN' => 'tibet (Hindiston)',
        'br' => 'breton',
        'br_FR' => 'breton (Fransiya)',
        'bs' => 'bosniy',
        'bs_BA' => 'bosniy (Bosniya va Gertsegovina)',
        'bs_Cyrl' => 'bosniy (kirill)',
        'bs_Cyrl_BA' => 'bosniy (kirill, Bosniya va Gertsegovina)',
        'bs_Latn' => 'bosniy (lotin)',
        'bs_Latn_BA' => 'bosniy (lotin, Bosniya va Gertsegovina)',
        'ca' => 'katalan',
        'ca_AD' => 'katalan (Andorra)',
        'ca_ES' => 'katalan (Ispaniya)',
        'ca_FR' => 'katalan (Fransiya)',
        'ca_IT' => 'katalan (Italiya)',
        'ce' => 'chechen',
        'ce_RU' => 'chechen (Rossiya)',
        'cs' => 'chex',
        'cs_CZ' => 'chex (Chexiya)',
        'cv' => 'chuvash',
        'cv_RU' => 'chuvash (Rossiya)',
        'cy' => 'valliy',
        'cy_GB' => 'valliy (Buyuk Britaniya)',
        'da' => 'dan',
        'da_DK' => 'dan (Daniya)',
        'da_GL' => 'dan (Grenlandiya)',
        'de' => 'nemischa',
        'de_AT' => 'nemischa (Avstriya)',
        'de_BE' => 'nemischa (Belgiya)',
        'de_CH' => 'nemischa (Shveytsariya)',
        'de_DE' => 'nemischa (Germaniya)',
        'de_IT' => 'nemischa (Italiya)',
        'de_LI' => 'nemischa (Lixtenshteyn)',
        'de_LU' => 'nemischa (Lyuksemburg)',
        'dz' => 'dzongka',
        'dz_BT' => 'dzongka (Butan)',
        'ee' => 'eve',
        'ee_GH' => 'eve (Gana)',
        'ee_TG' => 'eve (Togo)',
        'el' => 'grek',
        'el_CY' => 'grek (Kipr)',
        'el_GR' => 'grek (Gretsiya)',
        'en' => 'inglizcha',
        'en_001' => 'inglizcha (Dunyo)',
        'en_150' => 'inglizcha (Yevropa)',
        'en_AE' => 'inglizcha (Birlashgan Arab Amirliklari)',
        'en_AG' => 'inglizcha (Antigua va Barbuda)',
        'en_AI' => 'inglizcha (Angilya)',
        'en_AS' => 'inglizcha (Amerika Samoasi)',
        'en_AT' => 'inglizcha (Avstriya)',
        'en_AU' => 'inglizcha (Avstraliya)',
        'en_BB' => 'inglizcha (Barbados)',
        'en_BE' => 'inglizcha (Belgiya)',
        'en_BI' => 'inglizcha (Burundi)',
        'en_BM' => 'inglizcha (Bermuda orollari)',
        'en_BS' => 'inglizcha (Bagama orollari)',
        'en_BW' => 'inglizcha (Botsvana)',
        'en_BZ' => 'inglizcha (Beliz)',
        'en_CA' => 'inglizcha (Kanada)',
        'en_CC' => 'inglizcha (Kokos [Kiling] orollari)',
        'en_CH' => 'inglizcha (Shveytsariya)',
        'en_CK' => 'inglizcha (Kuk orollari)',
        'en_CM' => 'inglizcha (Kamerun)',
        'en_CX' => 'inglizcha (Rojdestvo oroli)',
        'en_CY' => 'inglizcha (Kipr)',
        'en_CZ' => 'inglizcha (Chexiya)',
        'en_DE' => 'inglizcha (Germaniya)',
        'en_DK' => 'inglizcha (Daniya)',
        'en_DM' => 'inglizcha (Dominika)',
        'en_EE' => 'inglizcha (Estoniya)',
        'en_ER' => 'inglizcha (Eritreya)',
        'en_ES' => 'inglizcha (Ispaniya)',
        'en_FI' => 'inglizcha (Finlandiya)',
        'en_FJ' => 'inglizcha (Fiji)',
        'en_FK' => 'inglizcha (Folklend orollari)',
        'en_FM' => 'inglizcha (Mikroneziya)',
        'en_FR' => 'inglizcha (Fransiya)',
        'en_GB' => 'inglizcha (Buyuk Britaniya)',
        'en_GD' => 'inglizcha (Grenada)',
        'en_GE' => 'inglizcha (Gruziya)',
        'en_GG' => 'inglizcha (Gernsi)',
        'en_GH' => 'inglizcha (Gana)',
        'en_GI' => 'inglizcha (Gibraltar)',
        'en_GM' => 'inglizcha (Gambiya)',
        'en_GS' => 'inglizcha (Janubiy Georgiya va Janubiy Sendvich orollari)',
        'en_GU' => 'inglizcha (Guam)',
        'en_GY' => 'inglizcha (Gayana)',
        'en_HK' => 'inglizcha (Gonkong [Xitoy MMH])',
        'en_HU' => 'inglizcha (Vengriya)',
        'en_ID' => 'inglizcha (Indoneziya)',
        'en_IE' => 'inglizcha (Irlandiya)',
        'en_IL' => 'inglizcha (Isroil)',
        'en_IM' => 'inglizcha (Men oroli)',
        'en_IN' => 'inglizcha (Hindiston)',
        'en_IO' => 'inglizcha (Britaniyaning Hind okeanidagi hududi)',
        'en_IT' => 'inglizcha (Italiya)',
        'en_JE' => 'inglizcha (Jersi)',
        'en_JM' => 'inglizcha (Yamayka)',
        'en_JP' => 'inglizcha (Yaponiya)',
        'en_KE' => 'inglizcha (Keniya)',
        'en_KI' => 'inglizcha (Kiribati)',
        'en_KN' => 'inglizcha (Sent-Kits va Nevis)',
        'en_KY' => 'inglizcha (Kayman orollari)',
        'en_LC' => 'inglizcha (Sent-Lyusiya)',
        'en_LR' => 'inglizcha (Liberiya)',
        'en_LS' => 'inglizcha (Lesoto)',
        'en_LT' => 'inglizcha (Litva)',
        'en_LV' => 'inglizcha (Latviya)',
        'en_MG' => 'inglizcha (Madagaskar)',
        'en_MH' => 'inglizcha (Marshall orollari)',
        'en_MO' => 'inglizcha (Makao [Xitoy MMH])',
        'en_MP' => 'inglizcha (Shimoliy Mariana orollari)',
        'en_MS' => 'inglizcha (Montserrat)',
        'en_MT' => 'inglizcha (Malta)',
        'en_MU' => 'inglizcha (Mavrikiy)',
        'en_MV' => 'inglizcha (Maldiv orollari)',
        'en_MW' => 'inglizcha (Malavi)',
        'en_MY' => 'inglizcha (Malayziya)',
        'en_NA' => 'inglizcha (Namibiya)',
        'en_NF' => 'inglizcha (Norfolk oroli)',
        'en_NG' => 'inglizcha (Nigeriya)',
        'en_NL' => 'inglizcha (Niderlandiya)',
        'en_NO' => 'inglizcha (Norvegiya)',
        'en_NR' => 'inglizcha (Nauru)',
        'en_NU' => 'inglizcha (Niue)',
        'en_NZ' => 'inglizcha (Yangi Zelandiya)',
        'en_PG' => 'inglizcha (Papua – Yangi Gvineya)',
        'en_PH' => 'inglizcha (Filippin)',
        'en_PK' => 'inglizcha (Pokiston)',
        'en_PL' => 'inglizcha (Polsha)',
        'en_PN' => 'inglizcha (Pitkern orollari)',
        'en_PR' => 'inglizcha (Puerto-Riko)',
        'en_PT' => 'inglizcha (Portugaliya)',
        'en_PW' => 'inglizcha (Palau)',
        'en_RO' => 'inglizcha (Ruminiya)',
        'en_RW' => 'inglizcha (Ruanda)',
        'en_SB' => 'inglizcha (Solomon orollari)',
        'en_SC' => 'inglizcha (Seyshel orollari)',
        'en_SD' => 'inglizcha (Sudan)',
        'en_SE' => 'inglizcha (Shvetsiya)',
        'en_SG' => 'inglizcha (Singapur)',
        'en_SH' => 'inglizcha (Muqaddas Yelena oroli)',
        'en_SI' => 'inglizcha (Sloveniya)',
        'en_SK' => 'inglizcha (Slovakiya)',
        'en_SL' => 'inglizcha (Syerra-Leone)',
        'en_SS' => 'inglizcha (Janubiy Sudan)',
        'en_SX' => 'inglizcha (Sint-Marten)',
        'en_SZ' => 'inglizcha (Svazilend)',
        'en_TC' => 'inglizcha (Turks va Kaykos orollari)',
        'en_TK' => 'inglizcha (Tokelau)',
        'en_TO' => 'inglizcha (Tonga)',
        'en_TT' => 'inglizcha (Trinidad va Tobago)',
        'en_TV' => 'inglizcha (Tuvalu)',
        'en_TZ' => 'inglizcha (Tanzaniya)',
        'en_UA' => 'inglizcha (Ukraina)',
        'en_UG' => 'inglizcha (Uganda)',
        'en_UM' => 'inglizcha (AQSH yondosh orollari)',
        'en_US' => 'inglizcha (Amerika Qo‘shma Shtatlari)',
        'en_VC' => 'inglizcha (Sent-Vinsent va Grenadin)',
        'en_VG' => 'inglizcha (Britaniya Virgin orollari)',
        'en_VI' => 'inglizcha (AQSH Virgin orollari)',
        'en_VU' => 'inglizcha (Vanuatu)',
        'en_WS' => 'inglizcha (Samoa)',
        'en_ZA' => 'inglizcha (Janubiy Afrika Respublikasi)',
        'en_ZM' => 'inglizcha (Zambiya)',
        'en_ZW' => 'inglizcha (Zimbabve)',
        'eo' => 'esperanto',
        'eo_001' => 'esperanto (Dunyo)',
        'es' => 'ispancha',
        'es_419' => 'ispancha (Lotin Amerikasi)',
        'es_AR' => 'ispancha (Argentina)',
        'es_BO' => 'ispancha (Boliviya)',
        'es_BR' => 'ispancha (Braziliya)',
        'es_BZ' => 'ispancha (Beliz)',
        'es_CL' => 'ispancha (Chili)',
        'es_CO' => 'ispancha (Kolumbiya)',
        'es_CR' => 'ispancha (Kosta-Rika)',
        'es_CU' => 'ispancha (Kuba)',
        'es_DO' => 'ispancha (Dominikan Respublikasi)',
        'es_EC' => 'ispancha (Ekvador)',
        'es_ES' => 'ispancha (Ispaniya)',
        'es_GQ' => 'ispancha (Ekvatorial Gvineya)',
        'es_GT' => 'ispancha (Gvatemala)',
        'es_HN' => 'ispancha (Gonduras)',
        'es_MX' => 'ispancha (Meksika)',
        'es_NI' => 'ispancha (Nikaragua)',
        'es_PA' => 'ispancha (Panama)',
        'es_PE' => 'ispancha (Peru)',
        'es_PH' => 'ispancha (Filippin)',
        'es_PR' => 'ispancha (Puerto-Riko)',
        'es_PY' => 'ispancha (Paragvay)',
        'es_SV' => 'ispancha (Salvador)',
        'es_US' => 'ispancha (Amerika Qo‘shma Shtatlari)',
        'es_UY' => 'ispancha (Urugvay)',
        'es_VE' => 'ispancha (Venesuela)',
        'et' => 'estoncha',
        'et_EE' => 'estoncha (Estoniya)',
        'eu' => 'bask',
        'eu_ES' => 'bask (Ispaniya)',
        'fa' => 'fors',
        'fa_AF' => 'fors (Afgʻoniston)',
        'fa_IR' => 'fors (Eron)',
        'ff' => 'fula',
        'ff_Adlm' => 'fula (adlam)',
        'ff_Adlm_BF' => 'fula (adlam, Burkina-Faso)',
        'ff_Adlm_CM' => 'fula (adlam, Kamerun)',
        'ff_Adlm_GH' => 'fula (adlam, Gana)',
        'ff_Adlm_GM' => 'fula (adlam, Gambiya)',
        'ff_Adlm_GN' => 'fula (adlam, Gvineya)',
        'ff_Adlm_GW' => 'fula (adlam, Gvineya-Bisau)',
        'ff_Adlm_LR' => 'fula (adlam, Liberiya)',
        'ff_Adlm_MR' => 'fula (adlam, Mavritaniya)',
        'ff_Adlm_NE' => 'fula (adlam, Niger)',
        'ff_Adlm_NG' => 'fula (adlam, Nigeriya)',
        'ff_Adlm_SL' => 'fula (adlam, Syerra-Leone)',
        'ff_Adlm_SN' => 'fula (adlam, Senegal)',
        'ff_CM' => 'fula (Kamerun)',
        'ff_GN' => 'fula (Gvineya)',
        'ff_Latn' => 'fula (lotin)',
        'ff_Latn_BF' => 'fula (lotin, Burkina-Faso)',
        'ff_Latn_CM' => 'fula (lotin, Kamerun)',
        'ff_Latn_GH' => 'fula (lotin, Gana)',
        'ff_Latn_GM' => 'fula (lotin, Gambiya)',
        'ff_Latn_GN' => 'fula (lotin, Gvineya)',
        'ff_Latn_GW' => 'fula (lotin, Gvineya-Bisau)',
        'ff_Latn_LR' => 'fula (lotin, Liberiya)',
        'ff_Latn_MR' => 'fula (lotin, Mavritaniya)',
        'ff_Latn_NE' => 'fula (lotin, Niger)',
        'ff_Latn_NG' => 'fula (lotin, Nigeriya)',
        'ff_Latn_SL' => 'fula (lotin, Syerra-Leone)',
        'ff_Latn_SN' => 'fula (lotin, Senegal)',
        'ff_MR' => 'fula (Mavritaniya)',
        'ff_SN' => 'fula (Senegal)',
        'fi' => 'fincha',
        'fi_FI' => 'fincha (Finlandiya)',
        'fo' => 'farercha',
        'fo_DK' => 'farercha (Daniya)',
        'fo_FO' => 'farercha (Farer orollari)',
        'fr' => 'fransuzcha',
        'fr_BE' => 'fransuzcha (Belgiya)',
        'fr_BF' => 'fransuzcha (Burkina-Faso)',
        'fr_BI' => 'fransuzcha (Burundi)',
        'fr_BJ' => 'fransuzcha (Benin)',
        'fr_BL' => 'fransuzcha (Sen-Bartelemi)',
        'fr_CA' => 'fransuzcha (Kanada)',
        'fr_CD' => 'fransuzcha (Kongo – Kinshasa)',
        'fr_CF' => 'fransuzcha (Markaziy Afrika Respublikasi)',
        'fr_CG' => 'fransuzcha (Kongo – Brazzavil)',
        'fr_CH' => 'fransuzcha (Shveytsariya)',
        'fr_CI' => 'fransuzcha (Kot-d’Ivuar)',
        'fr_CM' => 'fransuzcha (Kamerun)',
        'fr_DJ' => 'fransuzcha (Jibuti)',
        'fr_DZ' => 'fransuzcha (Jazoir)',
        'fr_FR' => 'fransuzcha (Fransiya)',
        'fr_GA' => 'fransuzcha (Gabon)',
        'fr_GF' => 'fransuzcha (Fransuz Gvianasi)',
        'fr_GN' => 'fransuzcha (Gvineya)',
        'fr_GP' => 'fransuzcha (Gvadelupe)',
        'fr_GQ' => 'fransuzcha (Ekvatorial Gvineya)',
        'fr_HT' => 'fransuzcha (Gaiti)',
        'fr_KM' => 'fransuzcha (Komor orollari)',
        'fr_LU' => 'fransuzcha (Lyuksemburg)',
        'fr_MA' => 'fransuzcha (Marokash)',
        'fr_MC' => 'fransuzcha (Monako)',
        'fr_MF' => 'fransuzcha (Sent-Martin)',
        'fr_MG' => 'fransuzcha (Madagaskar)',
        'fr_ML' => 'fransuzcha (Mali)',
        'fr_MQ' => 'fransuzcha (Martinika)',
        'fr_MR' => 'fransuzcha (Mavritaniya)',
        'fr_MU' => 'fransuzcha (Mavrikiy)',
        'fr_NC' => 'fransuzcha (Yangi Kaledoniya)',
        'fr_NE' => 'fransuzcha (Niger)',
        'fr_PF' => 'fransuzcha (Fransuz Polineziyasi)',
        'fr_PM' => 'fransuzcha (Sen-Pyer va Mikelon)',
        'fr_RE' => 'fransuzcha (Reyunion)',
        'fr_RW' => 'fransuzcha (Ruanda)',
        'fr_SC' => 'fransuzcha (Seyshel orollari)',
        'fr_SN' => 'fransuzcha (Senegal)',
        'fr_SY' => 'fransuzcha (Suriya)',
        'fr_TD' => 'fransuzcha (Chad)',
        'fr_TG' => 'fransuzcha (Togo)',
        'fr_TN' => 'fransuzcha (Tunis)',
        'fr_VU' => 'fransuzcha (Vanuatu)',
        'fr_WF' => 'fransuzcha (Uollis va Futuna)',
        'fr_YT' => 'fransuzcha (Mayotta)',
        'fy' => 'g‘arbiy friz',
        'fy_NL' => 'g‘arbiy friz (Niderlandiya)',
        'ga' => 'irland',
        'ga_GB' => 'irland (Buyuk Britaniya)',
        'ga_IE' => 'irland (Irlandiya)',
        'gd' => 'shotland-gel',
        'gd_GB' => 'shotland-gel (Buyuk Britaniya)',
        'gl' => 'galisiy',
        'gl_ES' => 'galisiy (Ispaniya)',
        'gu' => 'gujarot',
        'gu_IN' => 'gujarot (Hindiston)',
        'gv' => 'men',
        'gv_IM' => 'men (Men oroli)',
        'ha' => 'xausa',
        'ha_GH' => 'xausa (Gana)',
        'ha_NE' => 'xausa (Niger)',
        'ha_NG' => 'xausa (Nigeriya)',
        'he' => 'ivrit',
        'he_IL' => 'ivrit (Isroil)',
        'hi' => 'hind',
        'hi_IN' => 'hind (Hindiston)',
        'hi_Latn' => 'hind (lotin)',
        'hi_Latn_IN' => 'hind (lotin, Hindiston)',
        'hr' => 'xorvat',
        'hr_BA' => 'xorvat (Bosniya va Gertsegovina)',
        'hr_HR' => 'xorvat (Xorvatiya)',
        'hu' => 'venger',
        'hu_HU' => 'venger (Vengriya)',
        'hy' => 'arman',
        'hy_AM' => 'arman (Armaniston)',
        'ia' => 'interlingva',
        'ia_001' => 'interlingva (Dunyo)',
        'id' => 'indonez',
        'id_ID' => 'indonez (Indoneziya)',
        'ie' => 'interlingve',
        'ie_EE' => 'interlingve (Estoniya)',
        'ig' => 'igbo',
        'ig_NG' => 'igbo (Nigeriya)',
        'ii' => 'sichuan',
        'ii_CN' => 'sichuan (Xitoy)',
        'is' => 'island',
        'is_IS' => 'island (Islandiya)',
        'it' => 'italyan',
        'it_CH' => 'italyan (Shveytsariya)',
        'it_IT' => 'italyan (Italiya)',
        'it_SM' => 'italyan (San-Marino)',
        'it_VA' => 'italyan (Vatikan)',
        'ja' => 'yapon',
        'ja_JP' => 'yapon (Yaponiya)',
        'jv' => 'yavan',
        'jv_ID' => 'yavan (Indoneziya)',
        'ka' => 'gruzincha',
        'ka_GE' => 'gruzincha (Gruziya)',
        'ki' => 'kikuyu',
        'ki_KE' => 'kikuyu (Keniya)',
        'kk' => 'qozoqcha',
        'kk_Arab' => 'qozoqcha (arab)',
        'kk_Arab_CN' => 'qozoqcha (arab, Xitoy)',
        'kk_Cyrl' => 'qozoqcha (kirill)',
        'kk_Cyrl_KZ' => 'qozoqcha (kirill, Qozogʻiston)',
        'kk_KZ' => 'qozoqcha (Qozogʻiston)',
        'kl' => 'grenland',
        'kl_GL' => 'grenland (Grenlandiya)',
        'km' => 'xmer',
        'km_KH' => 'xmer (Kambodja)',
        'kn' => 'kannada',
        'kn_IN' => 'kannada (Hindiston)',
        'ko' => 'koreyscha',
        'ko_CN' => 'koreyscha (Xitoy)',
        'ko_KP' => 'koreyscha (Shimoliy Koreya)',
        'ko_KR' => 'koreyscha (Janubiy Koreya)',
        'ks' => 'kashmircha',
        'ks_Arab' => 'kashmircha (arab)',
        'ks_Arab_IN' => 'kashmircha (arab, Hindiston)',
        'ks_Deva' => 'kashmircha (devanagari)',
        'ks_Deva_IN' => 'kashmircha (devanagari, Hindiston)',
        'ks_IN' => 'kashmircha (Hindiston)',
        'ku' => 'kurdcha',
        'ku_Latn' => 'kurdcha (lotin)',
        'ku_Latn_IQ' => 'kurdcha (lotin, Iroq)',
        'ku_Latn_SY' => 'kurdcha (lotin, Suriya)',
        'ku_Latn_TR' => 'kurdcha (lotin, Turkiya)',
        'ku_SY' => 'kurdcha (Suriya)',
        'ku_TR' => 'kurdcha (Turkiya)',
        'kw' => 'korn',
        'kw_GB' => 'korn (Buyuk Britaniya)',
        'ky' => 'qirgʻizcha',
        'ky_KG' => 'qirgʻizcha (Qirgʻiziston)',
        'lb' => 'lyuksemburgcha',
        'lb_LU' => 'lyuksemburgcha (Lyuksemburg)',
        'lg' => 'ganda',
        'lg_UG' => 'ganda (Uganda)',
        'ln' => 'lingala',
        'ln_AO' => 'lingala (Angola)',
        'ln_CD' => 'lingala (Kongo – Kinshasa)',
        'ln_CF' => 'lingala (Markaziy Afrika Respublikasi)',
        'ln_CG' => 'lingala (Kongo – Brazzavil)',
        'lo' => 'laos',
        'lo_LA' => 'laos (Laos)',
        'lt' => 'litva',
        'lt_LT' => 'litva (Litva)',
        'lu' => 'luba-katanga',
        'lu_CD' => 'luba-katanga (Kongo – Kinshasa)',
        'lv' => 'latishcha',
        'lv_LV' => 'latishcha (Latviya)',
        'mg' => 'malagasiy',
        'mg_MG' => 'malagasiy (Madagaskar)',
        'mi' => 'maori',
        'mi_NZ' => 'maori (Yangi Zelandiya)',
        'mk' => 'makedon',
        'mk_MK' => 'makedon (Shimoliy Makedoniya)',
        'ml' => 'malayalam',
        'ml_IN' => 'malayalam (Hindiston)',
        'mn' => 'mongol',
        'mn_MN' => 'mongol (Mongoliya)',
        'mr' => 'maratxi',
        'mr_IN' => 'maratxi (Hindiston)',
        'ms' => 'malay',
        'ms_BN' => 'malay (Bruney)',
        'ms_ID' => 'malay (Indoneziya)',
        'ms_MY' => 'malay (Malayziya)',
        'ms_SG' => 'malay (Singapur)',
        'mt' => 'maltiy',
        'mt_MT' => 'maltiy (Malta)',
        'my' => 'birman',
        'my_MM' => 'birman (Myanma [Birma])',
        'nb' => 'norveg-bokmal',
        'nb_NO' => 'norveg-bokmal (Norvegiya)',
        'nb_SJ' => 'norveg-bokmal (Shpitsbergen va Yan-Mayen)',
        'nd' => 'shimoliy ndebele',
        'nd_ZW' => 'shimoliy ndebele (Zimbabve)',
        'ne' => 'nepal',
        'ne_IN' => 'nepal (Hindiston)',
        'ne_NP' => 'nepal (Nepal)',
        'nl' => 'niderland',
        'nl_AW' => 'niderland (Aruba)',
        'nl_BE' => 'niderland (Belgiya)',
        'nl_BQ' => 'niderland (Boneyr, Sint-Estatius va Saba)',
        'nl_CW' => 'niderland (Kyurasao)',
        'nl_NL' => 'niderland (Niderlandiya)',
        'nl_SR' => 'niderland (Surinam)',
        'nl_SX' => 'niderland (Sint-Marten)',
        'nn' => 'norveg-nyunorsk',
        'nn_NO' => 'norveg-nyunorsk (Norvegiya)',
        'no' => 'norveg',
        'no_NO' => 'norveg (Norvegiya)',
        'oc' => 'oksitan',
        'oc_ES' => 'oksitan (Ispaniya)',
        'oc_FR' => 'oksitan (Fransiya)',
        'om' => 'oromo',
        'om_ET' => 'oromo (Efiopiya)',
        'om_KE' => 'oromo (Keniya)',
        'or' => 'oriya',
        'or_IN' => 'oriya (Hindiston)',
        'os' => 'osetin',
        'os_GE' => 'osetin (Gruziya)',
        'os_RU' => 'osetin (Rossiya)',
        'pa' => 'panjobcha',
        'pa_Arab' => 'panjobcha (arab)',
        'pa_Arab_PK' => 'panjobcha (arab, Pokiston)',
        'pa_Guru' => 'panjobcha (gurmukxi)',
        'pa_Guru_IN' => 'panjobcha (gurmukxi, Hindiston)',
        'pa_IN' => 'panjobcha (Hindiston)',
        'pa_PK' => 'panjobcha (Pokiston)',
        'pl' => 'polyakcha',
        'pl_PL' => 'polyakcha (Polsha)',
        'ps' => 'pushtu',
        'ps_AF' => 'pushtu (Afgʻoniston)',
        'ps_PK' => 'pushtu (Pokiston)',
        'pt' => 'portugalcha',
        'pt_AO' => 'portugalcha (Angola)',
        'pt_BR' => 'portugalcha (Braziliya)',
        'pt_CH' => 'portugalcha (Shveytsariya)',
        'pt_CV' => 'portugalcha (Kabo-Verde)',
        'pt_GQ' => 'portugalcha (Ekvatorial Gvineya)',
        'pt_GW' => 'portugalcha (Gvineya-Bisau)',
        'pt_LU' => 'portugalcha (Lyuksemburg)',
        'pt_MO' => 'portugalcha (Makao [Xitoy MMH])',
        'pt_MZ' => 'portugalcha (Mozambik)',
        'pt_PT' => 'portugalcha (Portugaliya)',
        'pt_ST' => 'portugalcha (San-Tome va Prinsipi)',
        'pt_TL' => 'portugalcha (Timor-Leste)',
        'qu' => 'kechua',
        'qu_BO' => 'kechua (Boliviya)',
        'qu_EC' => 'kechua (Ekvador)',
        'qu_PE' => 'kechua (Peru)',
        'rm' => 'romansh',
        'rm_CH' => 'romansh (Shveytsariya)',
        'rn' => 'rundi',
        'rn_BI' => 'rundi (Burundi)',
        'ro' => 'rumincha',
        'ro_MD' => 'rumincha (Moldova)',
        'ro_RO' => 'rumincha (Ruminiya)',
        'ru' => 'ruscha',
        'ru_BY' => 'ruscha (Belarus)',
        'ru_KG' => 'ruscha (Qirgʻiziston)',
        'ru_KZ' => 'ruscha (Qozogʻiston)',
        'ru_MD' => 'ruscha (Moldova)',
        'ru_RU' => 'ruscha (Rossiya)',
        'ru_UA' => 'ruscha (Ukraina)',
        'rw' => 'kinyaruanda',
        'rw_RW' => 'kinyaruanda (Ruanda)',
        'sa' => 'sanskrit',
        'sa_IN' => 'sanskrit (Hindiston)',
        'sc' => 'sardin',
        'sc_IT' => 'sardin (Italiya)',
        'sd' => 'sindhi',
        'sd_Arab' => 'sindhi (arab)',
        'sd_Arab_PK' => 'sindhi (arab, Pokiston)',
        'sd_Deva' => 'sindhi (devanagari)',
        'sd_Deva_IN' => 'sindhi (devanagari, Hindiston)',
        'sd_IN' => 'sindhi (Hindiston)',
        'sd_PK' => 'sindhi (Pokiston)',
        'se' => 'shimoliy saam',
        'se_FI' => 'shimoliy saam (Finlandiya)',
        'se_NO' => 'shimoliy saam (Norvegiya)',
        'se_SE' => 'shimoliy saam (Shvetsiya)',
        'sg' => 'sango',
        'sg_CF' => 'sango (Markaziy Afrika Respublikasi)',
        'si' => 'singal',
        'si_LK' => 'singal (Shri-Lanka)',
        'sk' => 'slovakcha',
        'sk_SK' => 'slovakcha (Slovakiya)',
        'sl' => 'slovencha',
        'sl_SI' => 'slovencha (Sloveniya)',
        'sn' => 'shona',
        'sn_ZW' => 'shona (Zimbabve)',
        'so' => 'somalicha',
        'so_DJ' => 'somalicha (Jibuti)',
        'so_ET' => 'somalicha (Efiopiya)',
        'so_KE' => 'somalicha (Keniya)',
        'so_SO' => 'somalicha (Somali)',
        'sq' => 'alban',
        'sq_AL' => 'alban (Albaniya)',
        'sq_MK' => 'alban (Shimoliy Makedoniya)',
        'sr' => 'serbcha',
        'sr_BA' => 'serbcha (Bosniya va Gertsegovina)',
        'sr_Cyrl' => 'serbcha (kirill)',
        'sr_Cyrl_BA' => 'serbcha (kirill, Bosniya va Gertsegovina)',
        'sr_Cyrl_ME' => 'serbcha (kirill, Chernogoriya)',
        'sr_Cyrl_RS' => 'serbcha (kirill, Serbiya)',
        'sr_Latn' => 'serbcha (lotin)',
        'sr_Latn_BA' => 'serbcha (lotin, Bosniya va Gertsegovina)',
        'sr_Latn_ME' => 'serbcha (lotin, Chernogoriya)',
        'sr_Latn_RS' => 'serbcha (lotin, Serbiya)',
        'sr_ME' => 'serbcha (Chernogoriya)',
        'sr_RS' => 'serbcha (Serbiya)',
        'st' => 'janubiy soto',
        'st_LS' => 'janubiy soto (Lesoto)',
        'st_ZA' => 'janubiy soto (Janubiy Afrika Respublikasi)',
        'su' => 'sundan',
        'su_ID' => 'sundan (Indoneziya)',
        'su_Latn' => 'sundan (lotin)',
        'su_Latn_ID' => 'sundan (lotin, Indoneziya)',
        'sv' => 'shved',
        'sv_AX' => 'shved (Aland orollari)',
        'sv_FI' => 'shved (Finlandiya)',
        'sv_SE' => 'shved (Shvetsiya)',
        'sw' => 'suaxili',
        'sw_CD' => 'suaxili (Kongo – Kinshasa)',
        'sw_KE' => 'suaxili (Keniya)',
        'sw_TZ' => 'suaxili (Tanzaniya)',
        'sw_UG' => 'suaxili (Uganda)',
        'ta' => 'tamil',
        'ta_IN' => 'tamil (Hindiston)',
        'ta_LK' => 'tamil (Shri-Lanka)',
        'ta_MY' => 'tamil (Malayziya)',
        'ta_SG' => 'tamil (Singapur)',
        'te' => 'telugu',
        'te_IN' => 'telugu (Hindiston)',
        'tg' => 'tojik',
        'tg_TJ' => 'tojik (Tojikiston)',
        'th' => 'tay',
        'th_TH' => 'tay (Tailand)',
        'ti' => 'tigrinya',
        'ti_ER' => 'tigrinya (Eritreya)',
        'ti_ET' => 'tigrinya (Efiopiya)',
        'tk' => 'turkman',
        'tk_TM' => 'turkman (Turkmaniston)',
        'tn' => 'tsvana',
        'tn_BW' => 'tsvana (Botsvana)',
        'tn_ZA' => 'tsvana (Janubiy Afrika Respublikasi)',
        'to' => 'tongan',
        'to_TO' => 'tongan (Tonga)',
        'tr' => 'turk',
        'tr_CY' => 'turk (Kipr)',
        'tr_TR' => 'turk (Turkiya)',
        'tt' => 'tatar',
        'tt_RU' => 'tatar (Rossiya)',
        'ug' => 'uyg‘ur',
        'ug_CN' => 'uyg‘ur (Xitoy)',
        'uk' => 'ukrain',
        'uk_UA' => 'ukrain (Ukraina)',
        'ur' => 'urdu',
        'ur_IN' => 'urdu (Hindiston)',
        'ur_PK' => 'urdu (Pokiston)',
        'uz' => 'o‘zbek',
        'uz_AF' => 'o‘zbek (Afgʻoniston)',
        'uz_Arab' => 'o‘zbek (arab)',
        'uz_Arab_AF' => 'o‘zbek (arab, Afgʻoniston)',
        'uz_Cyrl' => 'o‘zbek (kirill)',
        'uz_Cyrl_UZ' => 'o‘zbek (kirill, Oʻzbekiston)',
        'uz_Latn' => 'o‘zbek (lotin)',
        'uz_Latn_UZ' => 'o‘zbek (lotin, Oʻzbekiston)',
        'uz_UZ' => 'o‘zbek (Oʻzbekiston)',
        'vi' => 'vyetnam',
        'vi_VN' => 'vyetnam (Vyetnam)',
        'wo' => 'volof',
        'wo_SN' => 'volof (Senegal)',
        'xh' => 'kxosa',
        'xh_ZA' => 'kxosa (Janubiy Afrika Respublikasi)',
        'yi' => 'idish',
        'yi_UA' => 'idish (Ukraina)',
        'yo' => 'yoruba',
        'yo_BJ' => 'yoruba (Benin)',
        'yo_NG' => 'yoruba (Nigeriya)',
        'za' => 'Chjuan',
        'za_CN' => 'Chjuan (Xitoy)',
        'zh' => 'xitoy',
        'zh_CN' => 'xitoy (Xitoy)',
        'zh_HK' => 'xitoy (Gonkong [Xitoy MMH])',
        'zh_Hans' => 'xitoy (soddalashgan)',
        'zh_Hans_CN' => 'xitoy (soddalashgan, Xitoy)',
        'zh_Hans_HK' => 'xitoy (soddalashgan, Gonkong [Xitoy MMH])',
        'zh_Hans_MO' => 'xitoy (soddalashgan, Makao [Xitoy MMH])',
        'zh_Hans_MY' => 'xitoy (soddalashgan, Malayziya)',
        'zh_Hans_SG' => 'xitoy (soddalashgan, Singapur)',
        'zh_Hant' => 'xitoy (anʼanaviy)',
        'zh_Hant_HK' => 'xitoy (anʼanaviy, Gonkong [Xitoy MMH])',
        'zh_Hant_MO' => 'xitoy (anʼanaviy, Makao [Xitoy MMH])',
        'zh_Hant_MY' => 'xitoy (anʼanaviy, Malayziya)',
        'zh_Hant_TW' => 'xitoy (anʼanaviy, Tayvan)',
        'zh_MO' => 'xitoy (Makao [Xitoy MMH])',
        'zh_SG' => 'xitoy (Singapur)',
        'zh_TW' => 'xitoy (Tayvan)',
        'zu' => 'zulu',
        'zu_ZA' => 'zulu (Janubiy Afrika Respublikasi)',
    ],
];
