<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'Среднее время по Гринвичу (Абиджан)',
        'Africa/Accra' => 'Среднее время по Гринвичу (Аккра)',
        'Africa/Addis_Ababa' => 'Восточная Африка (Аддис-Абеба)',
        'Africa/Algiers' => 'Центральная Европа (Алжир)',
        'Africa/Asmera' => 'Восточная Африка (Асмэра)',
        'Africa/Asmara' => 'Восточная Африка (Асмэра)',
        'Africa/Bamako' => 'Среднее время по Гринвичу (Бамако)',
        'Africa/Bangui' => 'Западная Африка (Банги)',
        'Africa/Banjul' => 'Среднее время по Гринвичу (Банжул)',
        'Africa/Bissau' => 'Среднее время по Гринвичу (Бисау)',
        'Africa/Blantyre' => 'Центральная Африка (Блантайр)',
        'Africa/Brazzaville' => 'Западная Африка (Браззавиль)',
        'Africa/Bujumbura' => 'Центральная Африка (Бужумбура)',
        'Africa/Cairo' => 'Восточная Европа (Каир)',
        'Africa/Casablanca' => 'Западная Европа (Касабланка)',
        'Africa/Ceuta' => 'Центральная Европа (Сеута)',
        'Africa/Conakry' => 'Среднее время по Гринвичу (Конакри)',
        'Africa/Dakar' => 'Среднее время по Гринвичу (Дакар)',
        'Africa/Dar_es_Salaam' => 'Восточная Африка (Дар-эс-Салам)',
        'Africa/Djibouti' => 'Восточная Африка (Джибути)',
        'Africa/Douala' => 'Западная Африка (Дуала)',
        'Africa/El_Aaiun' => 'Западная Европа (Эль-Аюн)',
        'Africa/Freetown' => 'Среднее время по Гринвичу (Фритаун)',
        'Africa/Gaborone' => 'Центральная Африка (Габороне)',
        'Africa/Harare' => 'Центральная Африка (Хараре)',
        'Africa/Johannesburg' => 'Южная Африка (Йоханнесбург)',
        'Africa/Juba' => 'Центральная Африка (Джуба)',
        'Africa/Kampala' => 'Восточная Африка (Кампала)',
        'Africa/Khartoum' => 'Центральная Африка (Хартум)',
        'Africa/Kigali' => 'Центральная Африка (Кигали)',
        'Africa/Kinshasa' => 'Западная Африка (Киншаса)',
        'Africa/Lagos' => 'Западная Африка (Лагос)',
        'Africa/Libreville' => 'Западная Африка (Либревиль)',
        'Africa/Lome' => 'Среднее время по Гринвичу (Ломе)',
        'Africa/Luanda' => 'Западная Африка (Луанда)',
        'Africa/Lubumbashi' => 'Центральная Африка (Лубумбаши)',
        'Africa/Lusaka' => 'Центральная Африка (Лусака)',
        'Africa/Malabo' => 'Западная Африка (Малабо)',
        'Africa/Maputo' => 'Центральная Африка (Мапуту)',
        'Africa/Maseru' => 'Южная Африка (Масеру)',
        'Africa/Mbabane' => 'Южная Африка (Мбабане)',
        'Africa/Mogadishu' => 'Восточная Африка (Могадишо)',
        'Africa/Monrovia' => 'Среднее время по Гринвичу (Монровия)',
        'Africa/Nairobi' => 'Восточная Африка (Найроби)',
        'Africa/Ndjamena' => 'Западная Африка (Нджамена)',
        'Africa/Niamey' => 'Западная Африка (Ниамей)',
        'Africa/Nouakchott' => 'Среднее время по Гринвичу (Нуакшот)',
        'Africa/Ouagadougou' => 'Среднее время по Гринвичу (Уагадугу)',
        'Africa/Porto-Novo' => 'Западная Африка (Порто-Ново)',
        'Africa/Sao_Tome' => 'Среднее время по Гринвичу (Сан-Томе)',
        'Africa/Tripoli' => 'Восточная Европа (Триполи)',
        'Africa/Tunis' => 'Центральная Европа (Тунис)',
        'Africa/Windhoek' => 'Центральная Африка (Виндхук)',
        'America/Adak' => 'Гавайско-алеутское время (Адак)',
        'America/Anchorage' => 'Аляска (Анкоридж)',
        'America/Anguilla' => 'Атлантическое время (Ангилья)',
        'America/Antigua' => 'Атлантическое время (Антигуа)',
        'America/Araguaina' => 'Бразилия (Арагуаина)',
        'America/Argentina/La_Rioja' => 'Аргентина (Ла-Риоха)',
        'America/Argentina/Rio_Gallegos' => 'Аргентина (Рио-Гальегос)',
        'America/Argentina/Salta' => 'Аргентина (Сальта)',
        'America/Argentina/San_Juan' => 'Аргентина (Сан-Хуан)',
        'America/Argentina/San_Luis' => 'Аргентина (Сан-Луис)',
        'America/Argentina/Tucuman' => 'Аргентина (Тукуман)',
        'America/Argentina/Ushuaia' => 'Аргентина (Ушуая)',
        'America/Aruba' => 'Атлантическое время (Аруба)',
        'America/Asuncion' => 'Парагвай (Асунсьон)',
        'America/Bahia' => 'Бразилия (Баия)',
        'America/Bahia_Banderas' => 'Центральная Америка (Баия-де-Бандерас)',
        'America/Barbados' => 'Атлантическое время (Барбадос)',
        'America/Belem' => 'Бразилия (Белен)',
        'America/Belize' => 'Центральная Америка (Белиз)',
        'America/Blanc-Sablon' => 'Атлантическое время (Бланк-Саблон)',
        'America/Boa_Vista' => 'Амазонка (Боа-Виста)',
        'America/Bogota' => 'Колумбия (Богота)',
        'America/Boise' => 'Горное время (Северная Америка) (Бойсе)',
        'America/Buenos_Aires' => 'Аргентина (Буэнос-Айрес)',
        'America/Argentina/Buenos_Aires' => 'Аргентина (Буэнос-Айрес)',
        'America/Cambridge_Bay' => 'Горное время (Северная Америка) (Кеймбридж-Бей)',
        'America/Campo_Grande' => 'Амазонка (Кампу-Гранди)',
        'America/Cancun' => 'Восточная Америка (Канкун)',
        'America/Caracas' => 'Венесуэла (Каракас)',
        'America/Catamarca' => 'Аргентина (Катамарка)',
        'America/Argentina/Catamarca' => 'Аргентина (Катамарка)',
        'America/Cayenne' => 'Французская Гвиана (Кайенна)',
        'America/Cayman' => 'Восточная Америка (Острова Кайман)',
        'America/Chicago' => 'Центральная Америка (Чикаго)',
        'America/Chihuahua' => 'Центральная Америка (Чиуауа)',
        'America/Ciudad_Juarez' => 'Горное время (Северная Америка) (Сьюдад-Хуарес)',
        'America/Coral_Harbour' => 'Восточная Америка (Корал-Харбор)',
        'America/Atikokan' => 'Восточная Америка (Корал-Харбор)',
        'America/Cordoba' => 'Аргентина (Кордова)',
        'America/Argentina/Cordoba' => 'Аргентина (Кордова)',
        'America/Costa_Rica' => 'Центральная Америка (Коста-Рика)',
        'America/Coyhaique' => 'Чили (Койайке)',
        'America/Creston' => 'Горное время (Северная Америка) (Крестон)',
        'America/Cuiaba' => 'Амазонка (Куяба)',
        'America/Curacao' => 'Атлантическое время (Кюрасао)',
        'America/Danmarkshavn' => 'Среднее время по Гринвичу (Денмарксхавн)',
        'America/Dawson' => 'Юкон (Доусон)',
        'America/Dawson_Creek' => 'Горное время (Северная Америка) (Доусон-Крик)',
        'America/Denver' => 'Горное время (Северная Америка) (Денвер)',
        'America/Detroit' => 'Восточная Америка (Детройт)',
        'America/Dominica' => 'Атлантическое время (Доминика)',
        'America/Edmonton' => 'Горное время (Северная Америка) (Эдмонтон)',
        'America/Eirunepe' => 'Акри время (Эйрунепе)',
        'America/El_Salvador' => 'Центральная Америка (Сальвадор)',
        'America/Fort_Nelson' => 'Горное время (Северная Америка) (Форт Нельсон)',
        'America/Fortaleza' => 'Бразилия (Форталеза)',
        'America/Glace_Bay' => 'Атлантическое время (Глейс-Бей)',
        'America/Godthab' => 'Гренландия (Нуук)',
        'America/Nuuk' => 'Гренландия (Нуук)',
        'America/Goose_Bay' => 'Атлантическое время (Гус-Бей)',
        'America/Grand_Turk' => 'Восточная Америка (Гранд-Терк)',
        'America/Grenada' => 'Атлантическое время (Гренада)',
        'America/Guadeloupe' => 'Атлантическое время (Гваделупа)',
        'America/Guatemala' => 'Центральная Америка (Гватемала)',
        'America/Guayaquil' => 'Эквадор (Гуаякиль)',
        'America/Guyana' => 'Гайана',
        'America/Halifax' => 'Атлантическое время (Галифакс)',
        'America/Havana' => 'Куба (Гавана)',
        'America/Hermosillo' => 'Тихоокеанское мексиканское время (Эрмосильо)',
        'America/Indiana/Knox' => 'Центральная Америка (Нокс, Индиана)',
        'America/Indiana/Marengo' => 'Восточная Америка (Маренго, Индиана)',
        'America/Indiana/Petersburg' => 'Восточная Америка (Питерсберг, Индиана)',
        'America/Indiana/Tell_City' => 'Центральная Америка (Телл-Сити)',
        'America/Indiana/Vevay' => 'Восточная Америка (Вевей, Индиана)',
        'America/Indiana/Vincennes' => 'Восточная Америка (Винсеннес)',
        'America/Indiana/Winamac' => 'Восточная Америка (Уинамак)',
        'America/Indianapolis' => 'Восточная Америка (Индианаполис)',
        'America/Indiana/Indianapolis' => 'Восточная Америка (Индианаполис)',
        'America/Inuvik' => 'Горное время (Северная Америка) (Инувик)',
        'America/Iqaluit' => 'Восточная Америка (Икалуит)',
        'America/Jamaica' => 'Восточная Америка (Ямайка)',
        'America/Jujuy' => 'Аргентина (Жужуй)',
        'America/Argentina/Jujuy' => 'Аргентина (Жужуй)',
        'America/Juneau' => 'Аляска (Джуно)',
        'America/Kentucky/Monticello' => 'Восточная Америка (Монтиселло, Кентукки)',
        'America/Kralendijk' => 'Атлантическое время (Кралендейк)',
        'America/La_Paz' => 'Боливия (Ла-Пас)',
        'America/Lima' => 'Перу (Лима)',
        'America/Los_Angeles' => 'Тихоокеанское время (Лос-Анджелес)',
        'America/Louisville' => 'Восточная Америка (Луисвилл)',
        'America/Kentucky/Louisville' => 'Восточная Америка (Луисвилл)',
        'America/Lower_Princes' => 'Атлантическое время (Лоуэр-Принс-Куотер)',
        'America/Maceio' => 'Бразилия (Масейо)',
        'America/Managua' => 'Центральная Америка (Манагуа)',
        'America/Manaus' => 'Амазонка (Манаус)',
        'America/Marigot' => 'Атлантическое время (Мариго)',
        'America/Martinique' => 'Атлантическое время (Мартиника)',
        'America/Matamoros' => 'Центральная Америка (Матаморос)',
        'America/Mazatlan' => 'Тихоокеанское мексиканское время (Масатлан)',
        'America/Mendoza' => 'Аргентина (Мендоса)',
        'America/Argentina/Mendoza' => 'Аргентина (Мендоса)',
        'America/Menominee' => 'Центральная Америка (Меномини)',
        'America/Merida' => 'Центральная Америка (Мерида)',
        'America/Metlakatla' => 'Аляска (Метлакатла)',
        'America/Mexico_City' => 'Центральная Америка (Мехико)',
        'America/Miquelon' => 'Сен-Пьер и Микелон',
        'America/Moncton' => 'Атлантическое время (Монктон)',
        'America/Monterrey' => 'Центральная Америка (Монтеррей)',
        'America/Montevideo' => 'Уругвай (Монтевидео)',
        'America/Montserrat' => 'Атлантическое время (Монтсеррат)',
        'America/Nassau' => 'Восточная Америка (Нассау)',
        'America/New_York' => 'Восточная Америка (Нью-Йорк)',
        'America/Nome' => 'Аляска (Ном)',
        'America/Noronha' => 'Фернанду-ди-Норонья',
        'America/North_Dakota/Beulah' => 'Центральная Америка (Бойла, Северная Дакота)',
        'America/North_Dakota/Center' => 'Центральная Америка (Центр, Северная Дакота)',
        'America/North_Dakota/New_Salem' => 'Центральная Америка (Нью-Сейлем, Северная Дакота)',
        'America/Ojinaga' => 'Центральная Америка (Охинага)',
        'America/Panama' => 'Восточная Америка (Панама)',
        'America/Paramaribo' => 'Суринам (Парамарибо)',
        'America/Phoenix' => 'Горное время (Северная Америка) (Финикс)',
        'America/Port-au-Prince' => 'Восточная Америка (Порт-о-Пренс)',
        'America/Port_of_Spain' => 'Атлантическое время (Порт-оф-Спейн)',
        'America/Porto_Velho' => 'Амазонка (Порту-Велью)',
        'America/Puerto_Rico' => 'Атлантическое время (Пуэрто-Рико)',
        'America/Punta_Arenas' => 'Чили (Пунта-Аренас)',
        'America/Rankin_Inlet' => 'Центральная Америка (Ранкин-Инлет)',
        'America/Recife' => 'Бразилия (Ресифи)',
        'America/Regina' => 'Центральная Америка (Реджайна)',
        'America/Resolute' => 'Центральная Америка (Резольют)',
        'America/Rio_Branco' => 'Акри время (Риу-Бранку)',
        'America/Santarem' => 'Бразилия (Сантарен)',
        'America/Santiago' => 'Чили (Сантьяго)',
        'America/Santo_Domingo' => 'Атлантическое время (Санто-Доминго)',
        'America/Sao_Paulo' => 'Бразилия (Сан-Паулу)',
        'America/Scoresbysund' => 'Гренландия (Скорсбисунн)',
        'America/Sitka' => 'Аляска (Ситка)',
        'America/St_Barthelemy' => 'Атлантическое время (Сен-Бартелеми)',
        'America/St_Johns' => 'Ньюфаундленд (Сент-Джонс)',
        'America/St_Kitts' => 'Атлантическое время (Сент-Китс)',
        'America/St_Lucia' => 'Атлантическое время (Сент-Люсия)',
        'America/St_Thomas' => 'Атлантическое время (Сент-Томас)',
        'America/St_Vincent' => 'Атлантическое время (Сент-Винсент)',
        'America/Swift_Current' => 'Центральная Америка (Свифт-Керрент)',
        'America/Tegucigalpa' => 'Центральная Америка (Тегусигальпа)',
        'America/Thule' => 'Атлантическое время (Туле)',
        'America/Tijuana' => 'Тихоокеанское время (Тихуана)',
        'America/Toronto' => 'Восточная Америка (Торонто)',
        'America/Tortola' => 'Атлантическое время (Тортола)',
        'America/Vancouver' => 'Тихоокеанское время (Ванкувер)',
        'America/Whitehorse' => 'Юкон (Уайтхорс)',
        'America/Winnipeg' => 'Центральная Америка (Виннипег)',
        'America/Yakutat' => 'Аляска (Якутат)',
        'Antarctica/Casey' => 'Западная Австралия (Кейси)',
        'Antarctica/Davis' => 'Дейвис',
        'Antarctica/DumontDUrville' => 'Дюмон-д’Юрвиль',
        'Antarctica/Macquarie' => 'Восточная Австралия (Маккуори)',
        'Antarctica/Mawson' => 'Моусон',
        'Antarctica/McMurdo' => 'Новая Зеландия (Мак-Мердо)',
        'Antarctica/Palmer' => 'Чили (Палмер)',
        'Antarctica/Rothera' => 'Ротера',
        'Antarctica/Syowa' => 'Сёва',
        'Antarctica/Troll' => 'Среднее время по Гринвичу (Тролль)',
        'Antarctica/Vostok' => 'Восток',
        'Arctic/Longyearbyen' => 'Центральная Европа (Лонгйир)',
        'Asia/Aden' => 'Саудовская Аравия (Аден)',
        'Asia/Almaty' => 'Казахстан (Алматы)',
        'Asia/Amman' => 'Восточная Европа (Амман)',
        'Asia/Anadyr' => 'Петропавловск-Камчатский (Анадырь)',
        'Asia/Aqtau' => 'Казахстан (Актау)',
        'Asia/Aqtobe' => 'Казахстан (Актобе)',
        'Asia/Ashgabat' => 'Туркменистан (Ашхабад)',
        'Asia/Atyrau' => 'Казахстан (Атырау)',
        'Asia/Baghdad' => 'Саудовская Аравия (Багдад)',
        'Asia/Bahrain' => 'Саудовская Аравия (Бахрейн)',
        'Asia/Baku' => 'Азербайджан (Баку)',
        'Asia/Bangkok' => 'Индокитай (Бангкок)',
        'Asia/Barnaul' => 'Красноярск (Барнаул)',
        'Asia/Beirut' => 'Восточная Европа (Бейрут)',
        'Asia/Bishkek' => 'Киргизия (Бишкек)',
        'Asia/Brunei' => 'Бруней-Даруссалам',
        'Asia/Calcutta' => 'Индия (Калькутта)',
        'Asia/Kolkata' => 'Индия (Калькутта)',
        'Asia/Chita' => 'Якутск (Чита)',
        'Asia/Colombo' => 'Индия (Коломбо)',
        'Asia/Damascus' => 'Восточная Европа (Дамаск)',
        'Asia/Dhaka' => 'Бангладеш (Дакка)',
        'Asia/Dili' => 'Восточный Тимор (Дили)',
        'Asia/Dubai' => 'Персидский залив (Дубай)',
        'Asia/Dushanbe' => 'Таджикистан (Душанбе)',
        'Asia/Famagusta' => 'Восточная Европа (Фамагуста)',
        'Asia/Gaza' => 'Восточная Европа (Газа)',
        'Asia/Hebron' => 'Восточная Европа (Хеврон)',
        'Asia/Hong_Kong' => 'Гонконг',
        'Asia/Hovd' => 'Ховд',
        'Asia/Irkutsk' => 'Иркутск',
        'Asia/Jakarta' => 'Западная Индонезия (Джакарта)',
        'Asia/Jayapura' => 'Восточная Индонезия (Джаяпура)',
        'Asia/Jerusalem' => 'Израиль (Иерусалим)',
        'Asia/Kabul' => 'Афганистан (Кабул)',
        'Asia/Kamchatka' => 'Петропавловск-Камчатский',
        'Asia/Karachi' => 'Пакистан (Карачи)',
        'Asia/Katmandu' => 'Непал (Катманду)',
        'Asia/Kathmandu' => 'Непал (Катманду)',
        'Asia/Khandyga' => 'Якутск (Хандыга)',
        'Asia/Krasnoyarsk' => 'Красноярск',
        'Asia/Kuala_Lumpur' => 'Малайзия (Куала-Лумпур)',
        'Asia/Kuching' => 'Малайзия (Кучинг)',
        'Asia/Kuwait' => 'Саудовская Аравия (Кувейт)',
        'Asia/Macau' => 'Китай (Макао)',
        'Asia/Magadan' => 'Магадан',
        'Asia/Makassar' => 'Центральная Индонезия (Макасар)',
        'Asia/Manila' => 'Филиппины (Манила)',
        'Asia/Muscat' => 'Персидский залив (Маскат)',
        'Asia/Nicosia' => 'Восточная Европа (Никосия)',
        'Asia/Novokuznetsk' => 'Красноярск (Новокузнецк)',
        'Asia/Novosibirsk' => 'Красноярск (Новосибирск)',
        'Asia/Omsk' => 'Омск',
        'Asia/Oral' => 'Казахстан (Уральск)',
        'Asia/Phnom_Penh' => 'Индокитай (Пномпень)',
        'Asia/Pontianak' => 'Западная Индонезия (Понтианак)',
        'Asia/Pyongyang' => 'Корея (Пхеньян)',
        'Asia/Qatar' => 'Саудовская Аравия (Катар)',
        'Asia/Qostanay' => 'Казахстан (Костанай)',
        'Asia/Qyzylorda' => 'Казахстан (Кызылорда)',
        'Asia/Rangoon' => 'Мьянма (Янгон)',
        'Asia/Yangon' => 'Мьянма (Янгон)',
        'Asia/Riyadh' => 'Саудовская Аравия (Эр-Рияд)',
        'Asia/Saigon' => 'Индокитай (Хошимин)',
        'Asia/Ho_Chi_Minh' => 'Индокитай (Хошимин)',
        'Asia/Sakhalin' => 'Магадан (о-в Сахалин)',
        'Asia/Samarkand' => 'Узбекистан (Самарканд)',
        'Asia/Seoul' => 'Корея (Сеул)',
        'Asia/Shanghai' => 'Китай (Шанхай)',
        'Asia/Singapore' => 'Сингапур',
        'Asia/Srednekolymsk' => 'Магадан (Среднеколымск)',
        'Asia/Taipei' => 'Тайвань (Тайбэй)',
        'Asia/Tashkent' => 'Узбекистан (Ташкент)',
        'Asia/Tbilisi' => 'Грузия (Тбилиси)',
        'Asia/Tehran' => 'Иран (Тегеран)',
        'Asia/Thimphu' => 'Бутан (Тхимпху)',
        'Asia/Tokyo' => 'Япония (Токио)',
        'Asia/Tomsk' => 'Красноярск (Томск)',
        'Asia/Ulaanbaatar' => 'Улан-Батор',
        'Asia/Urumqi' => 'Китай (Урумчи)',
        'Asia/Ust-Nera' => 'Владивосток (Усть-Нера)',
        'Asia/Vientiane' => 'Индокитай (Вьентьян)',
        'Asia/Vladivostok' => 'Владивосток',
        'Asia/Yakutsk' => 'Якутск',
        'Asia/Yekaterinburg' => 'Екатеринбург',
        'Asia/Yerevan' => 'Армения (Ереван)',
        'Atlantic/Azores' => 'Азорские о-ва',
        'Atlantic/Bermuda' => 'Атлантическое время (Бермудские о-ва)',
        'Atlantic/Canary' => 'Западная Европа (Канарские о-ва)',
        'Atlantic/Cape_Verde' => 'Кабо-Верде',
        'Atlantic/Faeroe' => 'Западная Европа (Фарерские о-ва)',
        'Atlantic/Faroe' => 'Западная Европа (Фарерские о-ва)',
        'Atlantic/Madeira' => 'Западная Европа (Мадейра)',
        'Atlantic/Reykjavik' => 'Среднее время по Гринвичу (Рейкьявик)',
        'Atlantic/South_Georgia' => 'Южная Георгия',
        'Atlantic/St_Helena' => 'Среднее время по Гринвичу (о-в Святой Елены)',
        'Atlantic/Stanley' => 'Фолклендские о-ва (Стэнли)',
        'Australia/Adelaide' => 'Центральная Австралия (Аделаида)',
        'Australia/Brisbane' => 'Восточная Австралия (Брисбен)',
        'Australia/Broken_Hill' => 'Центральная Австралия (Брокен-Хилл)',
        'Australia/Darwin' => 'Центральная Австралия (Дарвин)',
        'Australia/Eucla' => 'Центральная Австралия, западное время (Юкла)',
        'Australia/Hobart' => 'Восточная Австралия (Хобарт)',
        'Australia/Lindeman' => 'Восточная Австралия (Линдеман)',
        'Australia/Lord_Howe' => 'Лорд-Хау',
        'Australia/Melbourne' => 'Восточная Австралия (Мельбурн)',
        'Australia/Perth' => 'Западная Австралия (Перт)',
        'Australia/Sydney' => 'Восточная Австралия (Сидней)',
        'Etc/GMT' => 'Среднее время по Гринвичу',
        'Etc/UTC' => 'Всемирное координированное время',
        'Europe/Amsterdam' => 'Центральная Европа (Амстердам)',
        'Europe/Andorra' => 'Центральная Европа (Андорра)',
        'Europe/Astrakhan' => 'Время в Самаре (Астрахань)',
        'Europe/Athens' => 'Восточная Европа (Афины)',
        'Europe/Belgrade' => 'Центральная Европа (Белград)',
        'Europe/Berlin' => 'Центральная Европа (Берлин)',
        'Europe/Bratislava' => 'Центральная Европа (Братислава)',
        'Europe/Brussels' => 'Центральная Европа (Брюссель)',
        'Europe/Bucharest' => 'Восточная Европа (Бухарест)',
        'Europe/Budapest' => 'Центральная Европа (Будапешт)',
        'Europe/Busingen' => 'Центральная Европа (Бюзинген-на-Верхнем-Рейне)',
        'Europe/Chisinau' => 'Восточная Европа (Кишинев)',
        'Europe/Copenhagen' => 'Центральная Европа (Копенгаген)',
        'Europe/Dublin' => 'Среднее время по Гринвичу (Дублин)',
        'Europe/Gibraltar' => 'Центральная Европа (Гибралтар)',
        'Europe/Guernsey' => 'Среднее время по Гринвичу (Гернси)',
        'Europe/Helsinki' => 'Восточная Европа (Хельсинки)',
        'Europe/Isle_of_Man' => 'Среднее время по Гринвичу (о-в Мэн)',
        'Europe/Istanbul' => 'Турецкое время (Стамбул)',
        'Europe/Jersey' => 'Среднее время по Гринвичу (Джерси)',
        'Europe/Kaliningrad' => 'Восточная Европа (Калининград)',
        'Europe/Kiev' => 'Восточная Европа (Киев)',
        'Europe/Kyiv' => 'Восточная Европа (Киев)',
        'Europe/Kirov' => 'Москва (Киров)',
        'Europe/Lisbon' => 'Западная Европа (Лиссабон)',
        'Europe/Ljubljana' => 'Центральная Европа (Любляна)',
        'Europe/London' => 'Среднее время по Гринвичу (Лондон)',
        'Europe/Luxembourg' => 'Центральная Европа (Люксембург)',
        'Europe/Madrid' => 'Центральная Европа (Мадрид)',
        'Europe/Malta' => 'Центральная Европа (Мальта)',
        'Europe/Mariehamn' => 'Восточная Европа (Мариехамн)',
        'Europe/Minsk' => 'Москва (Минск)',
        'Europe/Monaco' => 'Центральная Европа (Монако)',
        'Europe/Moscow' => 'Москва',
        'Europe/Oslo' => 'Центральная Европа (Осло)',
        'Europe/Paris' => 'Центральная Европа (Париж)',
        'Europe/Podgorica' => 'Центральная Европа (Подгорица)',
        'Europe/Prague' => 'Центральная Европа (Прага)',
        'Europe/Riga' => 'Восточная Европа (Рига)',
        'Europe/Rome' => 'Центральная Европа (Рим)',
        'Europe/Samara' => 'Время в Самаре (Самара)',
        'Europe/San_Marino' => 'Центральная Европа (Сан-Марино)',
        'Europe/Sarajevo' => 'Центральная Европа (Сараево)',
        'Europe/Saratov' => 'Время в Самаре (Саратов)',
        'Europe/Simferopol' => 'Москва (Симферополь)',
        'Europe/Skopje' => 'Центральная Европа (Скопье)',
        'Europe/Sofia' => 'Восточная Европа (София)',
        'Europe/Stockholm' => 'Центральная Европа (Стокгольм)',
        'Europe/Tallinn' => 'Восточная Европа (Таллин)',
        'Europe/Tirane' => 'Центральная Европа (Тирана)',
        'Europe/Ulyanovsk' => 'Время в Самаре (Ульяновск)',
        'Europe/Vaduz' => 'Центральная Европа (Вадуц)',
        'Europe/Vatican' => 'Центральная Европа (Ватикан)',
        'Europe/Vienna' => 'Центральная Европа (Вена)',
        'Europe/Vilnius' => 'Восточная Европа (Вильнюс)',
        'Europe/Volgograd' => 'Москва (Волгоград)',
        'Europe/Warsaw' => 'Центральная Европа (Варшава)',
        'Europe/Zagreb' => 'Центральная Европа (Загреб)',
        'Europe/Zurich' => 'Центральная Европа (Цюрих)',
        'Indian/Antananarivo' => 'Восточная Африка (Антананариву)',
        'Indian/Chagos' => 'Индийский океан (Чагос)',
        'Indian/Christmas' => 'о-в Рождества',
        'Indian/Cocos' => 'Кокосовые о-ва',
        'Indian/Comoro' => 'Восточная Африка (Коморы)',
        'Indian/Kerguelen' => 'Французские Южные и Антарктические территории (Кергелен)',
        'Indian/Mahe' => 'Сейшельские Острова (Маэ)',
        'Indian/Maldives' => 'Мальдивы',
        'Indian/Mauritius' => 'Маврикий',
        'Indian/Mayotte' => 'Восточная Африка (Майотта)',
        'Indian/Reunion' => 'Реюньон',
        'Pacific/Apia' => 'Апиа',
        'Pacific/Auckland' => 'Новая Зеландия (Окленд)',
        'Pacific/Bougainville' => 'Папуа – Новая Гвинея (Бугенвиль)',
        'Pacific/Chatham' => 'Чатем',
        'Pacific/Easter' => 'О-в Пасхи',
        'Pacific/Efate' => 'Вануату (Эфате)',
        'Pacific/Enderbury' => 'о-ва Феникс (о-в Кантон)',
        'Pacific/Kanton' => 'о-ва Феникс (о-в Кантон)',
        'Pacific/Fakaofo' => 'Токелау (Факаофо)',
        'Pacific/Fiji' => 'Фиджи',
        'Pacific/Funafuti' => 'Тувалу (Фунафути)',
        'Pacific/Galapagos' => 'Галапагосские о-ва',
        'Pacific/Gambier' => 'Гамбье (о-ва Гамбье)',
        'Pacific/Guadalcanal' => 'Соломоновы Острова (Гуадалканал)',
        'Pacific/Guam' => 'Чаморро (Гуам)',
        'Pacific/Honolulu' => 'Гавайско-алеутское стандартное время (Гонолулу)',
        'Pacific/Kiritimati' => 'о-ва Лайн (Киритимати)',
        'Pacific/Kosrae' => 'Косрае',
        'Pacific/Kwajalein' => 'Маршалловы Острова (Кваджалейн)',
        'Pacific/Majuro' => 'Маршалловы Острова (Маджуро)',
        'Pacific/Marquesas' => 'Маркизские о-ва',
        'Pacific/Midway' => 'Самоа (о-ва Мидуэй)',
        'Pacific/Nauru' => 'Науру',
        'Pacific/Niue' => 'Ниуэ',
        'Pacific/Norfolk' => 'Норфолк',
        'Pacific/Noumea' => 'Новая Каледония (Нумеа)',
        'Pacific/Pago_Pago' => 'Самоа (Паго-Паго)',
        'Pacific/Palau' => 'Палау',
        'Pacific/Pitcairn' => 'Питкэрн',
        'Pacific/Ponape' => 'Понпеи',
        'Pacific/Pohnpei' => 'Понпеи',
        'Pacific/Port_Moresby' => 'Папуа – Новая Гвинея (Порт-Морсби)',
        'Pacific/Rarotonga' => 'Острова Кука (Раротонга)',
        'Pacific/Saipan' => 'Чаморро (Сайпан)',
        'Pacific/Tahiti' => 'Таити',
        'Pacific/Tarawa' => 'о-ва Гилберта (Тарава)',
        'Pacific/Tongatapu' => 'Тонга (Тонгатапу)',
        'Pacific/Truk' => 'Трук',
        'Pacific/Chuuk' => 'Трук',
        'Pacific/Wake' => 'Уэйк',
        'Pacific/Wallis' => 'Уоллис и Футуна',
    ],
    'Meta' => [],
];
