<?php

return [
    'Names' => [
        'Adlm' => 'адлам',
        'Arab' => 'арапско писмо',
        'Aran' => 'насталик',
        'Armi' => 'империјско арамејско писмо',
        'Armn' => 'јерменско писмо',
        'Avst' => 'авестанско писмо',
        'Bali' => 'балијско писмо',
        'Batk' => 'батак писмо',
        'Beng' => 'бенгалско писмо',
        'Blis' => 'блисимболично писмо',
        'Bopo' => 'бопомофо писмо',
        'Brah' => 'браманско писмо',
        'Brai' => 'брајево писмо',
        'Bugi' => 'бугинско писмо',
        'Buhd' => 'бухидско писмо',
        'Cakm' => 'чакма',
        'Cans' => 'уједињени канадски абориџински силабици',
        'Cari' => 'каријско писмо',
        'Cham' => 'чамско писмо',
        'Cher' => 'чероки',
        'Cirt' => 'цирт писмо',
        'Copt' => 'коптичко писмо',
        'Cprt' => 'кипарско писмо',
        'Cyrl' => 'ћирилица',
        'Cyrs' => 'Старословенска црквена ћирилица',
        'Deva' => 'деванагари',
        'Dsrt' => 'Дезерет',
        'Egyd' => 'египатско народно писмо',
        'Egyh' => 'египатско хијератско писмо',
        'Egyp' => 'египатски хијероглифи',
        'Ethi' => 'етиопско писмо',
        'Geok' => 'грузијско кхутсури писмо',
        'Geor' => 'грузијско писмо',
        'Glag' => 'глагољица',
        'Goth' => 'Готика',
        'Grek' => 'грчко писмо',
        'Gujr' => 'гуџаратско писмо',
        'Guru' => 'гурмуки писмо',
        'Hanb' => 'ханб',
        'Hang' => 'хангул',
        'Hani' => 'хан',
        'Hano' => 'хануно',
        'Hans' => 'поједностављено кинеско писмо',
        'Hant' => 'традиционално кинеско писмо',
        'Hebr' => 'хебрејско писмо',
        'Hira' => 'хирагана',
        'Hmng' => 'пахав хмонг писмо',
        'Hrkt' => 'јапанска слоговна писма',
        'Hung' => 'старомађарско писмо',
        'Inds' => 'индушко писмо',
        'Ital' => 'стари италик',
        'Jamo' => 'џамо',
        'Java' => 'јаванско писмо',
        'Jpan' => 'јапанско писмо',
        'Kali' => 'кајах-ли писмо',
        'Kana' => 'катакана',
        'Khar' => 'карошти писмо',
        'Khmr' => 'кмерско писмо',
        'Knda' => 'канада писмо',
        'Kore' => 'корејско писмо',
        'Kthi' => 'каити',
        'Lana' => 'ланна писмо',
        'Laoo' => 'лаошко писмо',
        'Latf' => 'латиница (фрактур варијанта)',
        'Latg' => 'галска латиница',
        'Latn' => 'латиница',
        'Lepc' => 'лепча писмо',
        'Limb' => 'лимбу писмо',
        'Lina' => 'линеарно А писмо',
        'Linb' => 'линеарно Б писмо',
        'Lyci' => 'лисијско писмо',
        'Lydi' => 'лидијско писмо',
        'Mand' => 'мандеанско писмо',
        'Mani' => 'манихејско писмо',
        'Maya' => 'мајански хијероглифи',
        'Mero' => 'мероитик писмо',
        'Mlym' => 'малајаламско писмо',
        'Mong' => 'монголско писмо',
        'Moon' => 'месечево писмо',
        'Mtei' => 'меитеи мајек',
        'Mymr' => 'мијанмарско писмо',
        'Nkoo' => 'нко',
        'Ogam' => 'огамско писмо',
        'Olck' => 'ол чики',
        'Orkh' => 'орконско писмо',
        'Orya' => 'оријанско писмо',
        'Osma' => 'осмањанско писмо',
        'Perm' => 'старо пермикско писмо',
        'Phag' => 'пагс-па писмо',
        'Phli' => 'писани пахлави',
        'Phlp' => 'псалтер пахлави',
        'Phlv' => 'пахлави писмо',
        'Phnx' => 'Феничанско писмо',
        'Plrd' => 'поралд фонетско писмо',
        'Prti' => 'писани партиан',
        'Rjng' => 'рејанг писмо',
        'Rohg' => 'ханифи',
        'Roro' => 'ронгоронго писмо',
        'Runr' => 'рунско писмо',
        'Samr' => 'самаританско писмо',
        'Sara' => 'сарати писмо',
        'Saur' => 'саураштра писмо',
        'Sgnw' => 'знаковно писмо',
        'Shaw' => 'шавијанско писмо',
        'Sinh' => 'синхалско писмо',
        'Sund' => 'сунданско писмо',
        'Sylo' => 'силоти нагри писмо',
        'Syrc' => 'сиријско писмо',
        'Syre' => 'сиријско естрангело писмо',
        'Syrj' => 'западносиријско писмо',
        'Syrn' => 'писмо источне Сирије',
        'Tagb' => 'тагбанва писмо',
        'Tale' => 'таи ле писмо',
        'Talu' => 'нови таи луе',
        'Taml' => 'тамилско писмо',
        'Tavt' => 'таи виет писмо',
        'Telu' => 'телугу писмо',
        'Teng' => 'тенгвар писмо',
        'Tfng' => 'тифинаг',
        'Tglg' => 'Тагалог',
        'Thaa' => 'тана писмо',
        'Thai' => 'тајландско писмо',
        'Tibt' => 'тибетанско писмо',
        'Ugar' => 'угаритско писмо',
        'Vaii' => 'ваи',
        'Visp' => 'видљиви говор',
        'Xpeo' => 'староперсијско писмо',
        'Xsux' => 'сумерско-акадско кунеиформ писмо',
        'Yiii' => 'ји',
        'Zinh' => 'наследно писмо',
        'Zmth' => 'математичка нотација',
        'Zsye' => 'емоџи',
        'Zsym' => 'симболи',
        'Zxxx' => 'неписани језик',
        'Zyyy' => 'заједничко писмо',
    ],
];
