<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'จูบ: คน คน โทนผิวสีขาว และ โทนผิวสีขาวเหลือง',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'จูบ: คน คน โทนผิวสีขาว และ โทนผิวสีเหลือง',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'จูบ: คน คน โทนผิวสีขาว และ โทนผิวสีแทน',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'จูบ: คน คน โทนผิวสีขาว และ โทนผิวสีเข้ม',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'จูบ: คน คน โทนผิวสีขาวเหลือง และ โทนผิวสีขาว',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'จูบ: คน คน โทนผิวสีขาวเหลือง และ โทนผิวสีเหลือง',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'จูบ: คน คน โทนผิวสีขาวเหลือง และ โทนผิวสีแทน',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'จูบ: คน คน โทนผิวสีขาวเหลือง และ โทนผิวสีเข้ม',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'จูบ: คน คน โทนผิวสีเหลือง และ โทนผิวสีขาว',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'จูบ: คน คน โทนผิวสีเหลือง และ โทนผิวสีขาวเหลือง',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'จูบ: คน คน โทนผิวสีเหลือง และ โทนผิวสีแทน',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'จูบ: คน คน โทนผิวสีเหลือง และ โทนผิวสีเข้ม',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'จูบ: คน คน โทนผิวสีแทน และ โทนผิวสีขาว',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'จูบ: คน คน โทนผิวสีแทน และ โทนผิวสีขาวเหลือง',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'จูบ: คน คน โทนผิวสีแทน และ โทนผิวสีเหลือง',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'จูบ: คน คน โทนผิวสีแทน และ โทนผิวสีเข้ม',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'จูบ: คน คน โทนผิวสีเข้ม และ โทนผิวสีขาว',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'จูบ: คน คน โทนผิวสีเข้ม และ โทนผิวสีขาวเหลือง',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'จูบ: คน คน โทนผิวสีเข้ม และ โทนผิวสีเหลือง',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'จูบ: คน คน โทนผิวสีเข้ม และ โทนผิวสีแทน',
    '👨🏻‍❤‍💋‍👨🏻' => 'จูบ: ผู้ชาย ผู้ชาย และ โทนผิวสีขาว',
    '👨🏻‍❤‍💋‍👨🏼' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีขาว และ โทนผิวสีขาวเหลือง',
    '👨🏻‍❤‍💋‍👨🏽' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีขาว และ โทนผิวสีเหลือง',
    '👨🏻‍❤‍💋‍👨🏾' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีขาว และ โทนผิวสีแทน',
    '👨🏻‍❤‍💋‍👨🏿' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีขาว และ โทนผิวสีเข้ม',
    '👨🏼‍❤‍💋‍👨🏻' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีขาว',
    '👨🏼‍❤‍💋‍👨🏼' => 'จูบ: ผู้ชาย ผู้ชาย และ โทนผิวสีขาวเหลือง',
    '👨🏼‍❤‍💋‍👨🏽' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีเหลือง',
    '👨🏼‍❤‍💋‍👨🏾' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีแทน',
    '👨🏼‍❤‍💋‍👨🏿' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีเข้ม',
    '👨🏽‍❤‍💋‍👨🏻' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีขาว',
    '👨🏽‍❤‍💋‍👨🏼' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีขาวเหลือง',
    '👨🏽‍❤‍💋‍👨🏽' => 'จูบ: ผู้ชาย ผู้ชาย และ โทนผิวสีเหลือง',
    '👨🏽‍❤‍💋‍👨🏾' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีแทน',
    '👨🏽‍❤‍💋‍👨🏿' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีเข้ม',
    '👨🏾‍❤‍💋‍👨🏻' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีแทน และ โทนผิวสีขาว',
    '👨🏾‍❤‍💋‍👨🏼' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีแทน และ โทนผิวสีขาวเหลือง',
    '👨🏾‍❤‍💋‍👨🏽' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีแทน และ โทนผิวสีเหลือง',
    '👨🏾‍❤‍💋‍👨🏾' => 'จูบ: ผู้ชาย ผู้ชาย และ โทนผิวสีแทน',
    '👨🏾‍❤‍💋‍👨🏿' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีแทน และ โทนผิวสีเข้ม',
    '👨🏿‍❤‍💋‍👨🏻' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีขาว',
    '👨🏿‍❤‍💋‍👨🏼' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีขาวเหลือง',
    '👨🏿‍❤‍💋‍👨🏽' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีเหลือง',
    '👨🏿‍❤‍💋‍👨🏾' => 'จูบ: ผู้ชาย ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีแทน',
    '👨🏿‍❤‍💋‍👨🏿' => 'จูบ: ผู้ชาย ผู้ชาย และ โทนผิวสีเข้ม',
    '👩🏻‍❤‍💋‍👨🏻' => 'จูบ: ผู้หญิง ผู้ชาย และ โทนผิวสีขาว',
    '👩🏻‍❤‍💋‍👨🏼' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีขาว และ โทนผิวสีขาวเหลือง',
    '👩🏻‍❤‍💋‍👨🏽' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีขาว และ โทนผิวสีเหลือง',
    '👩🏻‍❤‍💋‍👨🏾' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีขาว และ โทนผิวสีแทน',
    '👩🏻‍❤‍💋‍👨🏿' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีขาว และ โทนผิวสีเข้ม',
    '👩🏼‍❤‍💋‍👨🏻' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีขาว',
    '👩🏼‍❤‍💋‍👨🏼' => 'จูบ: ผู้หญิง ผู้ชาย และ โทนผิวสีขาวเหลือง',
    '👩🏼‍❤‍💋‍👨🏽' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีเหลือง',
    '👩🏼‍❤‍💋‍👨🏾' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีแทน',
    '👩🏼‍❤‍💋‍👨🏿' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีเข้ม',
    '👩🏽‍❤‍💋‍👨🏻' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีขาว',
    '👩🏽‍❤‍💋‍👨🏼' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีขาวเหลือง',
    '👩🏽‍❤‍💋‍👨🏽' => 'จูบ: ผู้หญิง ผู้ชาย และ โทนผิวสีเหลือง',
    '👩🏽‍❤‍💋‍👨🏾' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีแทน',
    '👩🏽‍❤‍💋‍👨🏿' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีเข้ม',
    '👩🏾‍❤‍💋‍👨🏻' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีแทน และ โทนผิวสีขาว',
    '👩🏾‍❤‍💋‍👨🏼' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีแทน และ โทนผิวสีขาวเหลือง',
    '👩🏾‍❤‍💋‍👨🏽' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีแทน และ โทนผิวสีเหลือง',
    '👩🏾‍❤‍💋‍👨🏾' => 'จูบ: ผู้หญิง ผู้ชาย และ โทนผิวสีแทน',
    '👩🏾‍❤‍💋‍👨🏿' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีแทน และ โทนผิวสีเข้ม',
    '👩🏿‍❤‍💋‍👨🏻' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีขาว',
    '👩🏿‍❤‍💋‍👨🏼' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีขาวเหลือง',
    '👩🏿‍❤‍💋‍👨🏽' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีเหลือง',
    '👩🏿‍❤‍💋‍👨🏾' => 'จูบ: ผู้หญิง ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีแทน',
    '👩🏿‍❤‍💋‍👨🏿' => 'จูบ: ผู้หญิง ผู้ชาย และ โทนผิวสีเข้ม',
    '👩🏻‍❤‍💋‍👩🏻' => 'จูบ: ผู้หญิง ผู้หญิง และ โทนผิวสีขาว',
    '👩🏻‍❤‍💋‍👩🏼' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีขาว และ โทนผิวสีขาวเหลือง',
    '👩🏻‍❤‍💋‍👩🏽' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีขาว และ โทนผิวสีเหลือง',
    '👩🏻‍❤‍💋‍👩🏾' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีขาว และ โทนผิวสีแทน',
    '👩🏻‍❤‍💋‍👩🏿' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีขาว และ โทนผิวสีเข้ม',
    '👩🏼‍❤‍💋‍👩🏻' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีขาวเหลือง และ โทนผิวสีขาว',
    '👩🏼‍❤‍💋‍👩🏼' => 'จูบ: ผู้หญิง ผู้หญิง และ โทนผิวสีขาวเหลือง',
    '👩🏼‍❤‍💋‍👩🏽' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีขาวเหลือง และ โทนผิวสีเหลือง',
    '👩🏼‍❤‍💋‍👩🏾' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีขาวเหลือง และ โทนผิวสีแทน',
    '👩🏼‍❤‍💋‍👩🏿' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีขาวเหลือง และ โทนผิวสีเข้ม',
    '👩🏽‍❤‍💋‍👩🏻' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีเหลือง และ โทนผิวสีขาว',
    '👩🏽‍❤‍💋‍👩🏼' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีเหลือง และ โทนผิวสีขาวเหลือง',
    '👩🏽‍❤‍💋‍👩🏽' => 'จูบ: ผู้หญิง ผู้หญิง และ โทนผิวสีเหลือง',
    '👩🏽‍❤‍💋‍👩🏾' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีเหลือง และ โทนผิวสีแทน',
    '👩🏽‍❤‍💋‍👩🏿' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีเหลือง และ โทนผิวสีเข้ม',
    '👩🏾‍❤‍💋‍👩🏻' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีแทน และ โทนผิวสีขาว',
    '👩🏾‍❤‍💋‍👩🏼' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีแทน และ โทนผิวสีขาวเหลือง',
    '👩🏾‍❤‍💋‍👩🏽' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีแทน และ โทนผิวสีเหลือง',
    '👩🏾‍❤‍💋‍👩🏾' => 'จูบ: ผู้หญิง ผู้หญิง และ โทนผิวสีแทน',
    '👩🏾‍❤‍💋‍👩🏿' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีแทน และ โทนผิวสีเข้ม',
    '👩🏿‍❤‍💋‍👩🏻' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีเข้ม และ โทนผิวสีขาว',
    '👩🏿‍❤‍💋‍👩🏼' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีเข้ม และ โทนผิวสีขาวเหลือง',
    '👩🏿‍❤‍💋‍👩🏽' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีเข้ม และ โทนผิวสีเหลือง',
    '👩🏿‍❤‍💋‍👩🏾' => 'จูบ: ผู้หญิง ผู้หญิง โทนผิวสีเข้ม และ โทนผิวสีแทน',
    '👩🏿‍❤‍💋‍👩🏿' => 'จูบ: ผู้หญิง ผู้หญิง และ โทนผิวสีเข้ม',
    '🧑🏻‍🫯‍🧑🏼' => 'นักมวยปล้ำ: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '🧑🏻‍🫯‍🧑🏽' => 'นักมวยปล้ำ: โทนผิวสีขาว โทนผิวสีเหลือง',
    '🧑🏻‍🫯‍🧑🏾' => 'นักมวยปล้ำ: โทนผิวสีขาว โทนผิวสีแทน',
    '🧑🏻‍🫯‍🧑🏿' => 'นักมวยปล้ำ: โทนผิวสีขาว โทนผิวสีเข้ม',
    '🧑🏼‍🫯‍🧑🏻' => 'นักมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '🧑🏼‍🫯‍🧑🏽' => 'นักมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '🧑🏼‍🫯‍🧑🏾' => 'นักมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '🧑🏼‍🫯‍🧑🏿' => 'นักมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '🧑🏽‍🫯‍🧑🏻' => 'นักมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีขาว',
    '🧑🏽‍🫯‍🧑🏼' => 'นักมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '🧑🏽‍🫯‍🧑🏾' => 'นักมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีแทน',
    '🧑🏽‍🫯‍🧑🏿' => 'นักมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '🧑🏾‍🫯‍🧑🏻' => 'นักมวยปล้ำ: โทนผิวสีแทน โทนผิวสีขาว',
    '🧑🏾‍🫯‍🧑🏼' => 'นักมวยปล้ำ: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '🧑🏾‍🫯‍🧑🏽' => 'นักมวยปล้ำ: โทนผิวสีแทน โทนผิวสีเหลือง',
    '🧑🏾‍🫯‍🧑🏿' => 'นักมวยปล้ำ: โทนผิวสีแทน โทนผิวสีเข้ม',
    '🧑🏿‍🫯‍🧑🏻' => 'นักมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีขาว',
    '🧑🏿‍🫯‍🧑🏼' => 'นักมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '🧑🏿‍🫯‍🧑🏽' => 'นักมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '🧑🏿‍🫯‍🧑🏾' => 'นักมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีแทน',
    '🧑🏻‍❤‍🧑🏼' => 'คู่รัก: คน คน โทนผิวสีขาว และ โทนผิวสีขาวเหลือง',
    '🧑🏻‍❤‍🧑🏽' => 'คู่รัก: คน คน โทนผิวสีขาว และ โทนผิวสีเหลือง',
    '🧑🏻‍❤‍🧑🏾' => 'คู่รัก: คน คน โทนผิวสีขาว และ โทนผิวสีแทน',
    '🧑🏻‍❤‍🧑🏿' => 'คู่รัก: คน คน โทนผิวสีขาว และ โทนผิวสีเข้ม',
    '🧑🏼‍❤‍🧑🏻' => 'คู่รัก: คน คน โทนผิวสีขาวเหลือง และ โทนผิวสีขาว',
    '🧑🏼‍❤‍🧑🏽' => 'คู่รัก: คน คน โทนผิวสีขาวเหลือง และ โทนผิวสีเหลือง',
    '🧑🏼‍❤‍🧑🏾' => 'คู่รัก: คน คน โทนผิวสีขาวเหลือง และ โทนผิวสีแทน',
    '🧑🏼‍❤‍🧑🏿' => 'คู่รัก: คน คน โทนผิวสีขาวเหลือง และ โทนผิวสีเข้ม',
    '🧑🏽‍❤‍🧑🏻' => 'คู่รัก: คน คน โทนผิวสีเหลือง และ โทนผิวสีขาว',
    '🧑🏽‍❤‍🧑🏼' => 'คู่รัก: คน คน โทนผิวสีเหลือง และ โทนผิวสีขาวเหลือง',
    '🧑🏽‍❤‍🧑🏾' => 'คู่รัก: คน คน โทนผิวสีเหลือง และ โทนผิวสีแทน',
    '🧑🏽‍❤‍🧑🏿' => 'คู่รัก: คน คน โทนผิวสีเหลือง และ โทนผิวสีเข้ม',
    '🧑🏾‍❤‍🧑🏻' => 'คู่รัก: คน คน โทนผิวสีแทน และ โทนผิวสีขาว',
    '🧑🏾‍❤‍🧑🏼' => 'คู่รัก: คน คน โทนผิวสีแทน และ โทนผิวสีขาวเหลือง',
    '🧑🏾‍❤‍🧑🏽' => 'คู่รัก: คน คน โทนผิวสีแทน และ โทนผิวสีเหลือง',
    '🧑🏾‍❤‍🧑🏿' => 'คู่รัก: คน คน โทนผิวสีแทน และ โทนผิวสีเข้ม',
    '🧑🏿‍❤‍🧑🏻' => 'คู่รัก: คน คน โทนผิวสีเข้ม และ โทนผิวสีขาว',
    '🧑🏿‍❤‍🧑🏼' => 'คู่รัก: คน คน โทนผิวสีเข้ม และ โทนผิวสีขาวเหลือง',
    '🧑🏿‍❤‍🧑🏽' => 'คู่รัก: คน คน โทนผิวสีเข้ม และ โทนผิวสีเหลือง',
    '🧑🏿‍❤‍🧑🏾' => 'คู่รัก: คน คน โทนผิวสีเข้ม และ โทนผิวสีแทน',
    '🧑🏻‍🐰‍🧑🏼' => 'คนในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '🧑🏻‍🐰‍🧑🏽' => 'คนในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีเหลือง',
    '🧑🏻‍🐰‍🧑🏾' => 'คนในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีแทน',
    '🧑🏻‍🐰‍🧑🏿' => 'คนในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีเข้ม',
    '🧑🏼‍🐰‍🧑🏻' => 'คนในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '🧑🏼‍🐰‍🧑🏽' => 'คนในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '🧑🏼‍🐰‍🧑🏾' => 'คนในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '🧑🏼‍🐰‍🧑🏿' => 'คนในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '🧑🏽‍🐰‍🧑🏻' => 'คนในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีขาว',
    '🧑🏽‍🐰‍🧑🏼' => 'คนในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '🧑🏽‍🐰‍🧑🏾' => 'คนในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีแทน',
    '🧑🏽‍🐰‍🧑🏿' => 'คนในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '🧑🏾‍🐰‍🧑🏻' => 'คนในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีขาว',
    '🧑🏾‍🐰‍🧑🏼' => 'คนในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '🧑🏾‍🐰‍🧑🏽' => 'คนในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีเหลือง',
    '🧑🏾‍🐰‍🧑🏿' => 'คนในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีเข้ม',
    '🧑🏿‍🐰‍🧑🏻' => 'คนในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีขาว',
    '🧑🏿‍🐰‍🧑🏼' => 'คนในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '🧑🏿‍🐰‍🧑🏽' => 'คนในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '🧑🏿‍🐰‍🧑🏾' => 'คนในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีแทน',
    '👨🏻‍🫯‍👨🏼' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '👨🏻‍🫯‍👨🏽' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาว โทนผิวสีเหลือง',
    '👨🏻‍🫯‍👨🏾' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาว โทนผิวสีแทน',
    '👨🏻‍🫯‍👨🏿' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาว โทนผิวสีเข้ม',
    '👨🏼‍🫯‍👨🏻' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '👨🏼‍🫯‍👨🏽' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '👨🏼‍🫯‍👨🏾' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '👨🏼‍🫯‍👨🏿' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '👨🏽‍🫯‍👨🏻' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีขาว',
    '👨🏽‍🫯‍👨🏼' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '👨🏽‍🫯‍👨🏾' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีแทน',
    '👨🏽‍🫯‍👨🏿' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '👨🏾‍🫯‍👨🏻' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีแทน โทนผิวสีขาว',
    '👨🏾‍🫯‍👨🏼' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '👨🏾‍🫯‍👨🏽' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีแทน โทนผิวสีเหลือง',
    '👨🏾‍🫯‍👨🏿' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีแทน โทนผิวสีเข้ม',
    '👨🏿‍🫯‍👨🏻' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีขาว',
    '👨🏿‍🫯‍👨🏼' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '👨🏿‍🫯‍👨🏽' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '👨🏿‍🫯‍👨🏾' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีแทน',
    '👨🏻‍❤‍👨🏻' => 'คู่รัก: ผู้ชาย ผู้ชาย และ โทนผิวสีขาว',
    '👨🏻‍❤‍👨🏼' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีขาว และ โทนผิวสีขาวเหลือง',
    '👨🏻‍❤‍👨🏽' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีขาว และ โทนผิวสีเหลือง',
    '👨🏻‍❤‍👨🏾' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีขาว และ โทนผิวสีแทน',
    '👨🏻‍❤‍👨🏿' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีขาว และ โทนผิวสีเข้ม',
    '👨🏼‍❤‍👨🏻' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีขาว',
    '👨🏼‍❤‍👨🏼' => 'คู่รัก: ผู้ชาย ผู้ชาย และ โทนผิวสีขาวเหลือง',
    '👨🏼‍❤‍👨🏽' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีเหลือง',
    '👨🏼‍❤‍👨🏾' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีแทน',
    '👨🏼‍❤‍👨🏿' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีเข้ม',
    '👨🏽‍❤‍👨🏻' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีขาว',
    '👨🏽‍❤‍👨🏼' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีขาวเหลือง',
    '👨🏽‍❤‍👨🏽' => 'คู่รัก: ผู้ชาย ผู้ชาย และ โทนผิวสีเหลือง',
    '👨🏽‍❤‍👨🏾' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีแทน',
    '👨🏽‍❤‍👨🏿' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีเข้ม',
    '👨🏾‍❤‍👨🏻' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีแทน และ โทนผิวสีขาว',
    '👨🏾‍❤‍👨🏼' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีแทน และ โทนผิวสีขาวเหลือง',
    '👨🏾‍❤‍👨🏽' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีแทน และ โทนผิวสีเหลือง',
    '👨🏾‍❤‍👨🏾' => 'คู่รัก: ผู้ชาย ผู้ชาย และ โทนผิวสีแทน',
    '👨🏾‍❤‍👨🏿' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีแทน และ โทนผิวสีเข้ม',
    '👨🏿‍❤‍👨🏻' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีขาว',
    '👨🏿‍❤‍👨🏼' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีขาวเหลือง',
    '👨🏿‍❤‍👨🏽' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีเหลือง',
    '👨🏿‍❤‍👨🏾' => 'คู่รัก: ผู้ชาย ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีแทน',
    '👨🏿‍❤‍👨🏿' => 'คู่รัก: ผู้ชาย ผู้ชาย และ โทนผิวสีเข้ม',
    '👨🏻‍🐰‍👨🏼' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '👨🏻‍🐰‍👨🏽' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีเหลือง',
    '👨🏻‍🐰‍👨🏾' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีแทน',
    '👨🏻‍🐰‍👨🏿' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีเข้ม',
    '👨🏼‍🐰‍👨🏻' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '👨🏼‍🐰‍👨🏽' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '👨🏼‍🐰‍👨🏾' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '👨🏼‍🐰‍👨🏿' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '👨🏽‍🐰‍👨🏻' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีขาว',
    '👨🏽‍🐰‍👨🏼' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '👨🏽‍🐰‍👨🏾' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีแทน',
    '👨🏽‍🐰‍👨🏿' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '👨🏾‍🐰‍👨🏻' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีขาว',
    '👨🏾‍🐰‍👨🏼' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '👨🏾‍🐰‍👨🏽' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีเหลือง',
    '👨🏾‍🐰‍👨🏿' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีเข้ม',
    '👨🏿‍🐰‍👨🏻' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีขาว',
    '👨🏿‍🐰‍👨🏼' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '👨🏿‍🐰‍👨🏽' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '👨🏿‍🐰‍👨🏾' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีแทน',
    '👩🏻‍🫯‍👩🏼' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '👩🏻‍🫯‍👩🏽' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาว โทนผิวสีเหลือง',
    '👩🏻‍🫯‍👩🏾' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาว โทนผิวสีแทน',
    '👩🏻‍🫯‍👩🏿' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาว โทนผิวสีเข้ม',
    '👩🏼‍🫯‍👩🏻' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '👩🏼‍🫯‍👩🏽' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '👩🏼‍🫯‍👩🏾' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '👩🏼‍🫯‍👩🏿' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '👩🏽‍🫯‍👩🏻' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีขาว',
    '👩🏽‍🫯‍👩🏼' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '👩🏽‍🫯‍👩🏾' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีแทน',
    '👩🏽‍🫯‍👩🏿' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '👩🏾‍🫯‍👩🏻' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีแทน โทนผิวสีขาว',
    '👩🏾‍🫯‍👩🏼' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '👩🏾‍🫯‍👩🏽' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีแทน โทนผิวสีเหลือง',
    '👩🏾‍🫯‍👩🏿' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีแทน โทนผิวสีเข้ม',
    '👩🏿‍🫯‍👩🏻' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีขาว',
    '👩🏿‍🫯‍👩🏼' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '👩🏿‍🫯‍👩🏽' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '👩🏿‍🫯‍👩🏾' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเข้ม โทนผิวสีแทน',
    '👩🏻‍❤‍👨🏻' => 'คู่รัก: ผู้หญิง ผู้ชาย และ โทนผิวสีขาว',
    '👩🏻‍❤‍👨🏼' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีขาว และ โทนผิวสีขาวเหลือง',
    '👩🏻‍❤‍👨🏽' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีขาว และ โทนผิวสีเหลือง',
    '👩🏻‍❤‍👨🏾' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีขาว และ โทนผิวสีแทน',
    '👩🏻‍❤‍👨🏿' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีขาว และ โทนผิวสีเข้ม',
    '👩🏼‍❤‍👨🏻' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีขาว',
    '👩🏼‍❤‍👨🏼' => 'คู่รัก: ผู้หญิง ผู้ชาย และ โทนผิวสีขาวเหลือง',
    '👩🏼‍❤‍👨🏽' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีเหลือง',
    '👩🏼‍❤‍👨🏾' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีแทน',
    '👩🏼‍❤‍👨🏿' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีขาวเหลือง และ โทนผิวสีเข้ม',
    '👩🏽‍❤‍👨🏻' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีขาว',
    '👩🏽‍❤‍👨🏼' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีขาวเหลือง',
    '👩🏽‍❤‍👨🏽' => 'คู่รัก: ผู้หญิง ผู้ชาย และ โทนผิวสีเหลือง',
    '👩🏽‍❤‍👨🏾' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีแทน',
    '👩🏽‍❤‍👨🏿' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีเหลือง และ โทนผิวสีเข้ม',
    '👩🏾‍❤‍👨🏻' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีแทน และ โทนผิวสีขาว',
    '👩🏾‍❤‍👨🏼' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีแทน และ โทนผิวสีขาวเหลือง',
    '👩🏾‍❤‍👨🏽' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีแทน และ โทนผิวสีเหลือง',
    '👩🏾‍❤‍👨🏾' => 'คู่รัก: ผู้หญิง ผู้ชาย และ โทนผิวสีแทน',
    '👩🏾‍❤‍👨🏿' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีแทน และ โทนผิวสีเข้ม',
    '👩🏿‍❤‍👨🏻' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีขาว',
    '👩🏿‍❤‍👨🏼' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีขาวเหลือง',
    '👩🏿‍❤‍👨🏽' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีเหลือง',
    '👩🏿‍❤‍👨🏾' => 'คู่รัก: ผู้หญิง ผู้ชาย โทนผิวสีเข้ม และ โทนผิวสีแทน',
    '👩🏿‍❤‍👨🏿' => 'คู่รัก: ผู้หญิง ผู้ชาย และ โทนผิวสีเข้ม',
    '👩🏻‍❤‍👩🏻' => 'คู่รัก: ผู้หญิง ผู้หญิง และ โทนผิวสีขาว',
    '👩🏻‍❤‍👩🏼' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีขาว และ โทนผิวสีขาวเหลือง',
    '👩🏻‍❤‍👩🏽' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีขาว และ โทนผิวสีเหลือง',
    '👩🏻‍❤‍👩🏾' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีขาว และ โทนผิวสีแทน',
    '👩🏻‍❤‍👩🏿' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีขาว และ โทนผิวสีเข้ม',
    '👩🏼‍❤‍👩🏻' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีขาวเหลือง และ โทนผิวสีขาว',
    '👩🏼‍❤‍👩🏼' => 'คู่รัก: ผู้หญิง ผู้หญิง และ โทนผิวสีขาวเหลือง',
    '👩🏼‍❤‍👩🏽' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีขาวเหลือง และ โทนผิวสีเหลือง',
    '👩🏼‍❤‍👩🏾' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีขาวเหลือง และ โทนผิวสีแทน',
    '👩🏼‍❤‍👩🏿' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีขาวเหลือง และ โทนผิวสีเข้ม',
    '👩🏽‍❤‍👩🏻' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีเหลือง และ โทนผิวสีขาว',
    '👩🏽‍❤‍👩🏼' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีเหลือง และ โทนผิวสีขาวเหลือง',
    '👩🏽‍❤‍👩🏽' => 'คู่รัก: ผู้หญิง ผู้หญิง และ โทนผิวสีเหลือง',
    '👩🏽‍❤‍👩🏾' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีเหลือง และ โทนผิวสีแทน',
    '👩🏽‍❤‍👩🏿' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีเหลือง และ โทนผิวสีเข้ม',
    '👩🏾‍❤‍👩🏻' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีแทน และ โทนผิวสีขาว',
    '👩🏾‍❤‍👩🏼' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีแทน และ โทนผิวสีขาวเหลือง',
    '👩🏾‍❤‍👩🏽' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีแทน และ โทนผิวสีเหลือง',
    '👩🏾‍❤‍👩🏾' => 'คู่รัก: ผู้หญิง ผู้หญิง และ โทนผิวสีแทน',
    '👩🏾‍❤‍👩🏿' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีแทน และ โทนผิวสีเข้ม',
    '👩🏿‍❤‍👩🏻' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีเข้ม และ โทนผิวสีขาว',
    '👩🏿‍❤‍👩🏼' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีเข้ม และ โทนผิวสีขาวเหลือง',
    '👩🏿‍❤‍👩🏽' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีเข้ม และ โทนผิวสีเหลือง',
    '👩🏿‍❤‍👩🏾' => 'คู่รัก: ผู้หญิง ผู้หญิง โทนผิวสีเข้ม และ โทนผิวสีแทน',
    '👩🏿‍❤‍👩🏿' => 'คู่รัก: ผู้หญิง ผู้หญิง และ โทนผิวสีเข้ม',
    '👩🏻‍🐰‍👩🏼' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '👩🏻‍🐰‍👩🏽' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีเหลือง',
    '👩🏻‍🐰‍👩🏾' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีแทน',
    '👩🏻‍🐰‍👩🏿' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาว โทนผิวสีเข้ม',
    '👩🏼‍🐰‍👩🏻' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '👩🏼‍🐰‍👩🏽' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '👩🏼‍🐰‍👩🏾' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '👩🏼‍🐰‍👩🏿' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '👩🏽‍🐰‍👩🏻' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีขาว',
    '👩🏽‍🐰‍👩🏼' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '👩🏽‍🐰‍👩🏾' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีแทน',
    '👩🏽‍🐰‍👩🏿' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '👩🏾‍🐰‍👩🏻' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีขาว',
    '👩🏾‍🐰‍👩🏼' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '👩🏾‍🐰‍👩🏽' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีเหลือง',
    '👩🏾‍🐰‍👩🏿' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีแทน โทนผิวสีเข้ม',
    '👩🏿‍🐰‍👩🏻' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีขาว',
    '👩🏿‍🐰‍👩🏼' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '👩🏿‍🐰‍👩🏽' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '👩🏿‍🐰‍👩🏾' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเข้ม โทนผิวสีแทน',
    '🧑🏻‍🤝‍🧑🏻' => 'คนจับมือกัน: โทนผิวสีขาว',
    '🧑🏻‍🤝‍🧑🏼' => 'คนจับมือกัน: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '🧑🏻‍🤝‍🧑🏽' => 'คนจับมือกัน: โทนผิวสีขาว โทนผิวสีเหลือง',
    '🧑🏻‍🤝‍🧑🏾' => 'คนจับมือกัน: โทนผิวสีขาว โทนผิวสีแทน',
    '🧑🏻‍🤝‍🧑🏿' => 'คนจับมือกัน: โทนผิวสีขาว โทนผิวสีเข้ม',
    '🧑🏼‍🤝‍🧑🏻' => 'คนจับมือกัน: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '🧑🏼‍🤝‍🧑🏼' => 'คนจับมือกัน: โทนผิวสีขาวเหลือง',
    '🧑🏼‍🤝‍🧑🏽' => 'คนจับมือกัน: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '🧑🏼‍🤝‍🧑🏾' => 'คนจับมือกัน: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '🧑🏼‍🤝‍🧑🏿' => 'คนจับมือกัน: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '🧑🏽‍🤝‍🧑🏻' => 'คนจับมือกัน: โทนผิวสีเหลือง โทนผิวสีขาว',
    '🧑🏽‍🤝‍🧑🏼' => 'คนจับมือกัน: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '🧑🏽‍🤝‍🧑🏽' => 'คนจับมือกัน: โทนผิวสีเหลือง',
    '🧑🏽‍🤝‍🧑🏾' => 'คนจับมือกัน: โทนผิวสีเหลือง โทนผิวสีแทน',
    '🧑🏽‍🤝‍🧑🏿' => 'คนจับมือกัน: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '🧑🏾‍🤝‍🧑🏻' => 'คนจับมือกัน: โทนผิวสีแทน โทนผิวสีขาว',
    '🧑🏾‍🤝‍🧑🏼' => 'คนจับมือกัน: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '🧑🏾‍🤝‍🧑🏽' => 'คนจับมือกัน: โทนผิวสีแทน โทนผิวสีเหลือง',
    '🧑🏾‍🤝‍🧑🏾' => 'คนจับมือกัน: โทนผิวสีแทน',
    '🧑🏾‍🤝‍🧑🏿' => 'คนจับมือกัน: โทนผิวสีแทน โทนผิวสีเข้ม',
    '🧑🏿‍🤝‍🧑🏻' => 'คนจับมือกัน: โทนผิวสีเข้ม โทนผิวสีขาว',
    '🧑🏿‍🤝‍🧑🏼' => 'คนจับมือกัน: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '🧑🏿‍🤝‍🧑🏽' => 'คนจับมือกัน: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '🧑🏿‍🤝‍🧑🏾' => 'คนจับมือกัน: โทนผิวสีเข้ม โทนผิวสีแทน',
    '🧑🏿‍🤝‍🧑🏿' => 'คนจับมือกัน: โทนผิวสีเข้ม',
    '👩🏻‍🤝‍👩🏼' => 'หญิง-หญิงจับมือ: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '👩🏻‍🤝‍👩🏽' => 'หญิง-หญิงจับมือ: โทนผิวสีขาว โทนผิวสีเหลือง',
    '👩🏻‍🤝‍👩🏾' => 'หญิง-หญิงจับมือ: โทนผิวสีขาว โทนผิวสีแทน',
    '👩🏻‍🤝‍👩🏿' => 'หญิง-หญิงจับมือ: โทนผิวสีขาว โทนผิวสีเข้ม',
    '👩🏼‍🤝‍👩🏻' => 'หญิง-หญิงจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '👩🏼‍🤝‍👩🏽' => 'หญิง-หญิงจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '👩🏼‍🤝‍👩🏾' => 'หญิง-หญิงจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '👩🏼‍🤝‍👩🏿' => 'หญิง-หญิงจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '👩🏽‍🤝‍👩🏻' => 'หญิง-หญิงจับมือ: โทนผิวสีเหลือง โทนผิวสีขาว',
    '👩🏽‍🤝‍👩🏼' => 'หญิง-หญิงจับมือ: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '👩🏽‍🤝‍👩🏾' => 'หญิง-หญิงจับมือ: โทนผิวสีเหลือง โทนผิวสีแทน',
    '👩🏽‍🤝‍👩🏿' => 'หญิง-หญิงจับมือ: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '👩🏾‍🤝‍👩🏻' => 'หญิง-หญิงจับมือ: โทนผิวสีแทน โทนผิวสีขาว',
    '👩🏾‍🤝‍👩🏼' => 'หญิง-หญิงจับมือ: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '👩🏾‍🤝‍👩🏽' => 'หญิง-หญิงจับมือ: โทนผิวสีแทน โทนผิวสีเหลือง',
    '👩🏾‍🤝‍👩🏿' => 'หญิง-หญิงจับมือ: โทนผิวสีแทน โทนผิวสีเข้ม',
    '👩🏿‍🤝‍👩🏻' => 'หญิง-หญิงจับมือ: โทนผิวสีเข้ม โทนผิวสีขาว',
    '👩🏿‍🤝‍👩🏼' => 'หญิง-หญิงจับมือ: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '👩🏿‍🤝‍👩🏽' => 'หญิง-หญิงจับมือ: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '👩🏿‍🤝‍👩🏾' => 'หญิง-หญิงจับมือ: โทนผิวสีเข้ม โทนผิวสีแทน',
    '👩🏻‍🤝‍👨🏼' => 'ชาย-หญิงจับมือ: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '👩🏻‍🤝‍👨🏽' => 'ชาย-หญิงจับมือ: โทนผิวสีขาว โทนผิวสีเหลือง',
    '👩🏻‍🤝‍👨🏾' => 'ชาย-หญิงจับมือ: โทนผิวสีขาว โทนผิวสีแทน',
    '👩🏻‍🤝‍👨🏿' => 'ชาย-หญิงจับมือ: โทนผิวสีขาว โทนผิวสีเข้ม',
    '👩🏼‍🤝‍👨🏻' => 'ชาย-หญิงจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '👩🏼‍🤝‍👨🏽' => 'ชาย-หญิงจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '👩🏼‍🤝‍👨🏾' => 'ชาย-หญิงจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '👩🏼‍🤝‍👨🏿' => 'ชาย-หญิงจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '👩🏽‍🤝‍👨🏻' => 'ชาย-หญิงจับมือ: โทนผิวสีเหลือง โทนผิวสีขาว',
    '👩🏽‍🤝‍👨🏼' => 'ชาย-หญิงจับมือ: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '👩🏽‍🤝‍👨🏾' => 'ชาย-หญิงจับมือ: โทนผิวสีเหลือง โทนผิวสีแทน',
    '👩🏽‍🤝‍👨🏿' => 'ชาย-หญิงจับมือ: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '👩🏾‍🤝‍👨🏻' => 'ชาย-หญิงจับมือ: โทนผิวสีแทน โทนผิวสีขาว',
    '👩🏾‍🤝‍👨🏼' => 'ชาย-หญิงจับมือ: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '👩🏾‍🤝‍👨🏽' => 'ชาย-หญิงจับมือ: โทนผิวสีแทน โทนผิวสีเหลือง',
    '👩🏾‍🤝‍👨🏿' => 'ชาย-หญิงจับมือ: โทนผิวสีแทน โทนผิวสีเข้ม',
    '👩🏿‍🤝‍👨🏻' => 'ชาย-หญิงจับมือ: โทนผิวสีเข้ม โทนผิวสีขาว',
    '👩🏿‍🤝‍👨🏼' => 'ชาย-หญิงจับมือ: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '👩🏿‍🤝‍👨🏽' => 'ชาย-หญิงจับมือ: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '👩🏿‍🤝‍👨🏾' => 'ชาย-หญิงจับมือ: โทนผิวสีเข้ม โทนผิวสีแทน',
    '👨🏻‍🤝‍👨🏼' => 'ชาย-ชายจับมือ: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '👨🏻‍🤝‍👨🏽' => 'ชาย-ชายจับมือ: โทนผิวสีขาว โทนผิวสีเหลือง',
    '👨🏻‍🤝‍👨🏾' => 'ชาย-ชายจับมือ: โทนผิวสีขาว โทนผิวสีแทน',
    '👨🏻‍🤝‍👨🏿' => 'ชาย-ชายจับมือ: โทนผิวสีขาว โทนผิวสีเข้ม',
    '👨🏼‍🤝‍👨🏻' => 'ชาย-ชายจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '👨🏼‍🤝‍👨🏽' => 'ชาย-ชายจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '👨🏼‍🤝‍👨🏾' => 'ชาย-ชายจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '👨🏼‍🤝‍👨🏿' => 'ชาย-ชายจับมือ: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '👨🏽‍🤝‍👨🏻' => 'ชาย-ชายจับมือ: โทนผิวสีเหลือง โทนผิวสีขาว',
    '👨🏽‍🤝‍👨🏼' => 'ชาย-ชายจับมือ: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '👨🏽‍🤝‍👨🏾' => 'ชาย-ชายจับมือ: โทนผิวสีเหลือง โทนผิวสีแทน',
    '👨🏽‍🤝‍👨🏿' => 'ชาย-ชายจับมือ: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '👨🏾‍🤝‍👨🏻' => 'ชาย-ชายจับมือ: โทนผิวสีแทน โทนผิวสีขาว',
    '👨🏾‍🤝‍👨🏼' => 'ชาย-ชายจับมือ: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '👨🏾‍🤝‍👨🏽' => 'ชาย-ชายจับมือ: โทนผิวสีแทน โทนผิวสีเหลือง',
    '👨🏾‍🤝‍👨🏿' => 'ชาย-ชายจับมือ: โทนผิวสีแทน โทนผิวสีเข้ม',
    '👨🏿‍🤝‍👨🏻' => 'ชาย-ชายจับมือ: โทนผิวสีเข้ม โทนผิวสีขาว',
    '👨🏿‍🤝‍👨🏼' => 'ชาย-ชายจับมือ: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '👨🏿‍🤝‍👨🏽' => 'ชาย-ชายจับมือ: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '👨🏿‍🤝‍👨🏾' => 'ชาย-ชายจับมือ: โทนผิวสีเข้ม โทนผิวสีแทน',
    '👩‍❤‍💋‍👨' => 'จูบ: ผู้หญิง ผู้ชาย',
    '👨‍❤‍💋‍👨' => 'จูบ: ผู้ชาย ผู้ชาย',
    '👩‍❤‍💋‍👩' => 'จูบ: ผู้หญิง ผู้หญิง',
    '👨‍👩‍👧‍👦' => 'ครอบครัว: ผู้ชาย ผู้หญิง เด็กหญิง และ เด็กชาย',
    '👨‍👩‍👦‍👦' => 'ครอบครัว: ผู้ชาย ผู้หญิง เด็กชาย และ เด็กชาย',
    '👨‍👩‍👧‍👧' => 'ครอบครัว: ผู้ชาย ผู้หญิง เด็กหญิง และ เด็กหญิง',
    '👨‍👨‍👧‍👦' => 'ครอบครัว: ผู้ชาย ผู้ชาย เด็กหญิง และ เด็กชาย',
    '👨‍👨‍👦‍👦' => 'ครอบครัว: ผู้ชาย ผู้ชาย เด็กชาย และ เด็กชาย',
    '👨‍👨‍👧‍👧' => 'ครอบครัว: ผู้ชาย ผู้ชาย เด็กหญิง และ เด็กหญิง',
    '👩‍👩‍👧‍👦' => 'ครอบครัว: ผู้หญิง ผู้หญิง เด็กหญิง และ เด็กชาย',
    '👩‍👩‍👦‍👦' => 'ครอบครัว: ผู้หญิง ผู้หญิง เด็กชาย และ เด็กชาย',
    '👩‍👩‍👧‍👧' => 'ครอบครัว: ผู้หญิง ผู้หญิง เด็กหญิง และ เด็กหญิง',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'ธง: อังกฤษ',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'ธง: สกอตแลนด์',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'ธง: เวลส์',
    '🧑‍🧑‍🧒‍🧒' => 'ครอบครัว: ผู้ใหญ่, ผู้ใหญ่, เด็ก, เด็ก',
    '🚶🏻‍♀‍➡' => 'ผู้หญิงเดิน: โทนผิวสีขาว หันขวา',
    '🚶🏼‍♀‍➡' => 'ผู้หญิงเดิน: โทนผิวสีขาวเหลือง หันขวา',
    '🚶🏽‍♀‍➡' => 'ผู้หญิงเดิน: โทนผิวสีเหลือง หันขวา',
    '🚶🏾‍♀‍➡' => 'ผู้หญิงเดิน: โทนผิวสีแทน หันขวา',
    '🚶🏿‍♀‍➡' => 'ผู้หญิงเดิน: โทนผิวสีเข้ม หันขวา',
    '🚶🏻‍♂‍➡' => 'ผู้ชายเดิน: โทนผิวสีขาว หันขวา',
    '🚶🏼‍♂‍➡' => 'ผู้ชายเดิน: โทนผิวสีขาวเหลือง หันขวา',
    '🚶🏽‍♂‍➡' => 'ผู้ชายเดิน: โทนผิวสีเหลือง หันขวา',
    '🚶🏾‍♂‍➡' => 'ผู้ชายเดิน: โทนผิวสีแทน หันขวา',
    '🚶🏿‍♂‍➡' => 'ผู้ชายเดิน: โทนผิวสีเข้ม หันขวา',
    '🧎🏻‍♀‍➡' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีขาว หันขวา',
    '🧎🏼‍♀‍➡' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีขาวเหลือง หันขวา',
    '🧎🏽‍♀‍➡' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีเหลือง หันขวา',
    '🧎🏾‍♀‍➡' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีแทน หันขวา',
    '🧎🏿‍♀‍➡' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีเข้ม หันขวา',
    '🧎🏻‍♂‍➡' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีขาว หันขวา',
    '🧎🏼‍♂‍➡' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีขาวเหลือง หันขวา',
    '🧎🏽‍♂‍➡' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีเหลือง หันขวา',
    '🧎🏾‍♂‍➡' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีแทน หันขวา',
    '🧎🏿‍♂‍➡' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีเข้ม หันขวา',
    '🧑🏻‍🦯‍➡' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีขาว หันขวา',
    '🧑🏼‍🦯‍➡' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีขาวเหลือง หันขวา',
    '🧑🏽‍🦯‍➡' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีเหลือง หันขวา',
    '🧑🏾‍🦯‍➡' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีแทน หันขวา',
    '🧑🏿‍🦯‍➡' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีเข้ม หันขวา',
    '👨🏻‍🦯‍➡' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีขาว หันขวา',
    '👨🏼‍🦯‍➡' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีขาวเหลือง หันขวา',
    '👨🏽‍🦯‍➡' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีเหลือง หันขวา',
    '👨🏾‍🦯‍➡' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีแทน หันขวา',
    '👨🏿‍🦯‍➡' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีเข้ม หันขวา',
    '👩🏻‍🦯‍➡' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีขาว หันขวา',
    '👩🏼‍🦯‍➡' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีขาวเหลือง หันขวา',
    '👩🏽‍🦯‍➡' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีเหลือง หันขวา',
    '👩🏾‍🦯‍➡' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีแทน หันขวา',
    '👩🏿‍🦯‍➡' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีเข้ม หันขวา',
    '🧑🏻‍🦼‍➡' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาว หันขวา',
    '🧑🏼‍🦼‍➡' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาวเหลือง หันขวา',
    '🧑🏽‍🦼‍➡' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเหลือง หันขวา',
    '🧑🏾‍🦼‍➡' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีแทน หันขวา',
    '🧑🏿‍🦼‍➡' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเข้ม หันขวา',
    '👨🏻‍🦼‍➡' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาว หันขวา',
    '👨🏼‍🦼‍➡' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาวเหลือง หันขวา',
    '👨🏽‍🦼‍➡' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเหลือง หันขวา',
    '👨🏾‍🦼‍➡' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีแทน หันขวา',
    '👨🏿‍🦼‍➡' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเข้ม หันขวา',
    '👩🏻‍🦼‍➡' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาว หันขวา',
    '👩🏼‍🦼‍➡' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาวเหลือง หันขวา',
    '👩🏽‍🦼‍➡' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเหลือง หันขวา',
    '👩🏾‍🦼‍➡' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีแทน หันขวา',
    '👩🏿‍🦼‍➡' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเข้ม หันขวา',
    '🧑🏻‍🦽‍➡' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีขาว หันขวา',
    '🧑🏼‍🦽‍➡' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีขาวเหลือง หันขวา',
    '🧑🏽‍🦽‍➡' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีเหลือง หันขวา',
    '🧑🏾‍🦽‍➡' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีแทน หันขวา',
    '🧑🏿‍🦽‍➡' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีเข้ม หันขวา',
    '👨🏻‍🦽‍➡' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีขาว หันขวา',
    '👨🏼‍🦽‍➡' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีขาวเหลือง หันขวา',
    '👨🏽‍🦽‍➡' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีเหลือง หันขวา',
    '👨🏾‍🦽‍➡' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีแทน หันขวา',
    '👨🏿‍🦽‍➡' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีเข้ม หันขวา',
    '👩🏻‍🦽‍➡' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีขาว หันขวา',
    '👩🏼‍🦽‍➡' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีขาวเหลือง หันขวา',
    '👩🏽‍🦽‍➡' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีเหลือง หันขวา',
    '👩🏾‍🦽‍➡' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีแทน หันขวา',
    '👩🏿‍🦽‍➡' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีเข้ม หันขวา',
    '🏃🏻‍♀‍➡' => 'ผู้หญิงวิ่ง: โทนผิวสีขาว หันขวา',
    '🏃🏼‍♀‍➡' => 'ผู้หญิงวิ่ง: โทนผิวสีขาวเหลือง หันขวา',
    '🏃🏽‍♀‍➡' => 'ผู้หญิงวิ่ง: โทนผิวสีเหลือง หันขวา',
    '🏃🏾‍♀‍➡' => 'ผู้หญิงวิ่ง: โทนผิวสีแทน หันขวา',
    '🏃🏿‍♀‍➡' => 'ผู้หญิงวิ่ง: โทนผิวสีเข้ม หันขวา',
    '🏃🏻‍♂‍➡' => 'ผู้ชายวิ่ง: โทนผิวสีขาว หันขวา',
    '🏃🏼‍♂‍➡' => 'ผู้ชายวิ่ง: โทนผิวสีขาวเหลือง หันขวา',
    '🏃🏽‍♂‍➡' => 'ผู้ชายวิ่ง: โทนผิวสีเหลือง หันขวา',
    '🏃🏾‍♂‍➡' => 'ผู้ชายวิ่ง: โทนผิวสีแทน หันขวา',
    '🏃🏿‍♂‍➡' => 'ผู้ชายวิ่ง: โทนผิวสีเข้ม หันขวา',
    '🫱🏻‍🫲🏼' => 'จับมือ: โทนผิวสีขาว โทนผิวสีขาวเหลือง',
    '🫱🏻‍🫲🏽' => 'จับมือ: โทนผิวสีขาว โทนผิวสีเหลือง',
    '🫱🏻‍🫲🏾' => 'จับมือ: โทนผิวสีขาว โทนผิวสีแทน',
    '🫱🏻‍🫲🏿' => 'จับมือ: โทนผิวสีขาว โทนผิวสีเข้ม',
    '🫱🏼‍🫲🏻' => 'จับมือ: โทนผิวสีขาวเหลือง โทนผิวสีขาว',
    '🫱🏼‍🫲🏽' => 'จับมือ: โทนผิวสีขาวเหลือง โทนผิวสีเหลือง',
    '🫱🏼‍🫲🏾' => 'จับมือ: โทนผิวสีขาวเหลือง โทนผิวสีแทน',
    '🫱🏼‍🫲🏿' => 'จับมือ: โทนผิวสีขาวเหลือง โทนผิวสีเข้ม',
    '🫱🏽‍🫲🏻' => 'จับมือ: โทนผิวสีเหลือง โทนผิวสีขาว',
    '🫱🏽‍🫲🏼' => 'จับมือ: โทนผิวสีเหลือง โทนผิวสีขาวเหลือง',
    '🫱🏽‍🫲🏾' => 'จับมือ: โทนผิวสีเหลือง โทนผิวสีแทน',
    '🫱🏽‍🫲🏿' => 'จับมือ: โทนผิวสีเหลือง โทนผิวสีเข้ม',
    '🫱🏾‍🫲🏻' => 'จับมือ: โทนผิวสีแทน โทนผิวสีขาว',
    '🫱🏾‍🫲🏼' => 'จับมือ: โทนผิวสีแทน โทนผิวสีขาวเหลือง',
    '🫱🏾‍🫲🏽' => 'จับมือ: โทนผิวสีแทน โทนผิวสีเหลือง',
    '🫱🏾‍🫲🏿' => 'จับมือ: โทนผิวสีแทน โทนผิวสีเข้ม',
    '🫱🏿‍🫲🏻' => 'จับมือ: โทนผิวสีเข้ม โทนผิวสีขาว',
    '🫱🏿‍🫲🏼' => 'จับมือ: โทนผิวสีเข้ม โทนผิวสีขาวเหลือง',
    '🫱🏿‍🫲🏽' => 'จับมือ: โทนผิวสีเข้ม โทนผิวสีเหลือง',
    '🫱🏿‍🫲🏾' => 'จับมือ: โทนผิวสีเข้ม โทนผิวสีแทน',
    '🚶‍♀‍➡' => 'ผู้หญิงเดิน: หันขวา',
    '🚶‍♂‍➡' => 'ผู้ชายเดิน: หันขวา',
    '🧎‍♀‍➡' => 'ผู้หญิงกำลังคุกเข่า: หันขวา',
    '🧎‍♂‍➡' => 'ผู้ชายกำลังคุกเข่า: หันขวา',
    '🧑‍🦯‍➡' => 'คนเดินถือไม้เท้านำทาง: หันขวา',
    '👨‍🦯‍➡' => 'ผู้ชายเดินถือไม้เท้านำทาง: หันขวา',
    '👩‍🦯‍➡' => 'ผู้หญิงเดินถือไม้เท้านำทาง: หันขวา',
    '🧑‍🦼‍➡' => 'คนนั่งวีลแชร์ไฟฟ้า: หันขวา',
    '👨‍🦼‍➡' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: หันขวา',
    '👩‍🦼‍➡' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: หันขวา',
    '🧑‍🦽‍➡' => 'คนนั่งวีลแชร์ธรรมดา: หันขวา',
    '👨‍🦽‍➡' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: หันขวา',
    '👩‍🦽‍➡' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: หันขวา',
    '🏃‍♀‍➡' => 'ผู้หญิงวิ่ง: หันขวา',
    '🏃‍♂‍➡' => 'ผู้ชายวิ่ง: หันขวา',
    '👩‍❤‍👨' => 'คู่รัก: ผู้หญิง ผู้ชาย',
    '👨‍❤‍👨' => 'คู่รัก: ผู้ชาย ผู้ชาย',
    '👩‍❤‍👩' => 'คู่รัก: ผู้หญิง ผู้หญิง',
    '👨‍👩‍👦' => 'ครอบครัว: ผู้ชาย ผู้หญิง และ เด็กชาย',
    '👨‍👩‍👧' => 'ครอบครัว: ผู้ชาย ผู้หญิง และ เด็กหญิง',
    '👨‍👨‍👦' => 'ครอบครัว: ผู้ชาย ผู้ชาย และ เด็กชาย',
    '👨‍👨‍👧' => 'ครอบครัว: ผู้ชาย ผู้ชาย และ เด็กหญิง',
    '👩‍👩‍👦' => 'ครอบครัว: ผู้หญิง ผู้หญิง และ เด็กชาย',
    '👩‍👩‍👧' => 'ครอบครัว: ผู้หญิง ผู้หญิง และ เด็กหญิง',
    '👨‍👦‍👦' => 'ครอบครัว: ผู้ชาย เด็กชาย และ เด็กชาย',
    '👨‍👧‍👦' => 'ครอบครัว: ผู้ชาย เด็กหญิง และ เด็กชาย',
    '👨‍👧‍👧' => 'ครอบครัว: ผู้ชาย เด็กหญิง และ เด็กหญิง',
    '👩‍👦‍👦' => 'ครอบครัว: ผู้หญิง เด็กชาย และ เด็กชาย',
    '👩‍👧‍👦' => 'ครอบครัว: ผู้หญิง เด็กหญิง และ เด็กชาย',
    '👩‍👧‍👧' => 'ครอบครัว: ผู้หญิง เด็กหญิง และ เด็กหญิง',
    '🧑‍🤝‍🧑' => 'คนจับมือกัน',
    '🧑‍🧑‍🧒' => 'ครอบครัว: ผู้ใหญ่, ผู้ใหญ่, เด็ก',
    '🧑‍🧒‍🧒' => 'ครอบครัว: ผู้ใหญ่, เด็ก, เด็ก',
    '🧑🏻‍🦰' => 'คน: โทนผิวสีขาว ผมแดง',
    '🧑🏼‍🦰' => 'คน: โทนผิวสีขาวเหลือง ผมแดง',
    '🧑🏽‍🦰' => 'คน: โทนผิวสีเหลือง ผมแดง',
    '🧑🏾‍🦰' => 'คน: โทนผิวสีแทน ผมแดง',
    '🧑🏿‍🦰' => 'คน: โทนผิวสีเข้ม ผมแดง',
    '🧑🏻‍🦱' => 'คน: โทนผิวสีขาว ผมหยิก',
    '🧑🏼‍🦱' => 'คน: โทนผิวสีขาวเหลือง ผมหยิก',
    '🧑🏽‍🦱' => 'คน: โทนผิวสีเหลือง ผมหยิก',
    '🧑🏾‍🦱' => 'คน: โทนผิวสีแทน ผมหยิก',
    '🧑🏿‍🦱' => 'คน: โทนผิวสีเข้ม ผมหยิก',
    '🧑🏻‍🦳' => 'คน: โทนผิวสีขาว ผมขาว',
    '🧑🏼‍🦳' => 'คน: โทนผิวสีขาวเหลือง ผมขาว',
    '🧑🏽‍🦳' => 'คน: โทนผิวสีเหลือง ผมขาว',
    '🧑🏾‍🦳' => 'คน: โทนผิวสีแทน ผมขาว',
    '🧑🏿‍🦳' => 'คน: โทนผิวสีเข้ม ผมขาว',
    '🧑🏻‍🦲' => 'คน: โทนผิวสีขาว หัวล้าน',
    '🧑🏼‍🦲' => 'คน: โทนผิวสีขาวเหลือง หัวล้าน',
    '🧑🏽‍🦲' => 'คน: โทนผิวสีเหลือง หัวล้าน',
    '🧑🏾‍🦲' => 'คน: โทนผิวสีแทน หัวล้าน',
    '🧑🏿‍🦲' => 'คน: โทนผิวสีเข้ม หัวล้าน',
    '🧑🏻‍🩰' => 'นักบัลเล่ต์: โทนผิวสีขาว',
    '🧑🏼‍🩰' => 'นักบัลเล่ต์: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🩰' => 'นักบัลเล่ต์: โทนผิวสีเหลือง',
    '🧑🏾‍🩰' => 'นักบัลเล่ต์: โทนผิวสีแทน',
    '🧑🏿‍🩰' => 'นักบัลเล่ต์: โทนผิวสีเข้ม',
    '🧔🏻‍♂' => 'ชายมีเครา: โทนผิวสีขาว',
    '🧔🏼‍♂' => 'ชายมีเครา: โทนผิวสีขาวเหลือง',
    '🧔🏽‍♂' => 'ชายมีเครา: โทนผิวสีเหลือง',
    '🧔🏾‍♂' => 'ชายมีเครา: โทนผิวสีแทน',
    '🧔🏿‍♂' => 'ชายมีเครา: โทนผิวสีเข้ม',
    '👱🏻‍♂' => 'ผู้ชายผมทอง: โทนผิวสีขาว',
    '👱🏼‍♂' => 'ผู้ชายผมทอง: โทนผิวสีขาวเหลือง',
    '👱🏽‍♂' => 'ผู้ชายผมทอง: โทนผิวสีเหลือง',
    '👱🏾‍♂' => 'ผู้ชายผมทอง: โทนผิวสีแทน',
    '👱🏿‍♂' => 'ผู้ชายผมทอง: โทนผิวสีเข้ม',
    '👨🏻‍🦰' => 'ผู้ชาย: โทนผิวสีขาว ผมแดง',
    '👨🏼‍🦰' => 'ผู้ชาย: โทนผิวสีขาวเหลือง ผมแดง',
    '👨🏽‍🦰' => 'ผู้ชาย: โทนผิวสีเหลือง ผมแดง',
    '👨🏾‍🦰' => 'ผู้ชาย: โทนผิวสีแทน ผมแดง',
    '👨🏿‍🦰' => 'ผู้ชาย: โทนผิวสีเข้ม ผมแดง',
    '👨🏻‍🦱' => 'ผู้ชาย: โทนผิวสีขาว ผมหยิก',
    '👨🏼‍🦱' => 'ผู้ชาย: โทนผิวสีขาวเหลือง ผมหยิก',
    '👨🏽‍🦱' => 'ผู้ชาย: โทนผิวสีเหลือง ผมหยิก',
    '👨🏾‍🦱' => 'ผู้ชาย: โทนผิวสีแทน ผมหยิก',
    '👨🏿‍🦱' => 'ผู้ชาย: โทนผิวสีเข้ม ผมหยิก',
    '👨🏻‍🦳' => 'ผู้ชาย: โทนผิวสีขาว ผมขาว',
    '👨🏼‍🦳' => 'ผู้ชาย: โทนผิวสีขาวเหลือง ผมขาว',
    '👨🏽‍🦳' => 'ผู้ชาย: โทนผิวสีเหลือง ผมขาว',
    '👨🏾‍🦳' => 'ผู้ชาย: โทนผิวสีแทน ผมขาว',
    '👨🏿‍🦳' => 'ผู้ชาย: โทนผิวสีเข้ม ผมขาว',
    '👨🏻‍🦲' => 'ผู้ชาย: โทนผิวสีขาว หัวล้าน',
    '👨🏼‍🦲' => 'ผู้ชาย: โทนผิวสีขาวเหลือง หัวล้าน',
    '👨🏽‍🦲' => 'ผู้ชาย: โทนผิวสีเหลือง หัวล้าน',
    '👨🏾‍🦲' => 'ผู้ชาย: โทนผิวสีแทน หัวล้าน',
    '👨🏿‍🦲' => 'ผู้ชาย: โทนผิวสีเข้ม หัวล้าน',
    '🧔🏻‍♀' => 'ผู้หญิงมีเครา: โทนผิวสีขาว',
    '🧔🏼‍♀' => 'ผู้หญิงมีเครา: โทนผิวสีขาวเหลือง',
    '🧔🏽‍♀' => 'ผู้หญิงมีเครา: โทนผิวสีเหลือง',
    '🧔🏾‍♀' => 'ผู้หญิงมีเครา: โทนผิวสีแทน',
    '🧔🏿‍♀' => 'ผู้หญิงมีเครา: โทนผิวสีเข้ม',
    '👱🏻‍♀' => 'ผู้หญิงผมทอง: โทนผิวสีขาว',
    '👱🏼‍♀' => 'ผู้หญิงผมทอง: โทนผิวสีขาวเหลือง',
    '👱🏽‍♀' => 'ผู้หญิงผมทอง: โทนผิวสีเหลือง',
    '👱🏾‍♀' => 'ผู้หญิงผมทอง: โทนผิวสีแทน',
    '👱🏿‍♀' => 'ผู้หญิงผมทอง: โทนผิวสีเข้ม',
    '👩🏻‍🦰' => 'ผู้หญิง: โทนผิวสีขาว ผมแดง',
    '👩🏼‍🦰' => 'ผู้หญิง: โทนผิวสีขาวเหลือง ผมแดง',
    '👩🏽‍🦰' => 'ผู้หญิง: โทนผิวสีเหลือง ผมแดง',
    '👩🏾‍🦰' => 'ผู้หญิง: โทนผิวสีแทน ผมแดง',
    '👩🏿‍🦰' => 'ผู้หญิง: โทนผิวสีเข้ม ผมแดง',
    '👩🏻‍🦱' => 'ผู้หญิง: โทนผิวสีขาว ผมหยิก',
    '👩🏼‍🦱' => 'ผู้หญิง: โทนผิวสีขาวเหลือง ผมหยิก',
    '👩🏽‍🦱' => 'ผู้หญิง: โทนผิวสีเหลือง ผมหยิก',
    '👩🏾‍🦱' => 'ผู้หญิง: โทนผิวสีแทน ผมหยิก',
    '👩🏿‍🦱' => 'ผู้หญิง: โทนผิวสีเข้ม ผมหยิก',
    '👩🏻‍🦳' => 'ผู้หญิง: โทนผิวสีขาว ผมขาว',
    '👩🏼‍🦳' => 'ผู้หญิง: โทนผิวสีขาวเหลือง ผมขาว',
    '👩🏽‍🦳' => 'ผู้หญิง: โทนผิวสีเหลือง ผมขาว',
    '👩🏾‍🦳' => 'ผู้หญิง: โทนผิวสีแทน ผมขาว',
    '👩🏿‍🦳' => 'ผู้หญิง: โทนผิวสีเข้ม ผมขาว',
    '👩🏻‍🦲' => 'ผู้หญิง: โทนผิวสีขาว หัวล้าน',
    '👩🏼‍🦲' => 'ผู้หญิง: โทนผิวสีขาวเหลือง หัวล้าน',
    '👩🏽‍🦲' => 'ผู้หญิง: โทนผิวสีเหลือง หัวล้าน',
    '👩🏾‍🦲' => 'ผู้หญิง: โทนผิวสีแทน หัวล้าน',
    '👩🏿‍🦲' => 'ผู้หญิง: โทนผิวสีเข้ม หัวล้าน',
    '🙍🏻‍♂' => 'ผู้ชายหน้าบึ้ง: โทนผิวสีขาว',
    '🙍🏼‍♂' => 'ผู้ชายหน้าบึ้ง: โทนผิวสีขาวเหลือง',
    '🙍🏽‍♂' => 'ผู้ชายหน้าบึ้ง: โทนผิวสีเหลือง',
    '🙍🏾‍♂' => 'ผู้ชายหน้าบึ้ง: โทนผิวสีแทน',
    '🙍🏿‍♂' => 'ผู้ชายหน้าบึ้ง: โทนผิวสีเข้ม',
    '🙍🏻‍♀' => 'ผู้หญิงหน้าบึ้ง: โทนผิวสีขาว',
    '🙍🏼‍♀' => 'ผู้หญิงหน้าบึ้ง: โทนผิวสีขาวเหลือง',
    '🙍🏽‍♀' => 'ผู้หญิงหน้าบึ้ง: โทนผิวสีเหลือง',
    '🙍🏾‍♀' => 'ผู้หญิงหน้าบึ้ง: โทนผิวสีแทน',
    '🙍🏿‍♀' => 'ผู้หญิงหน้าบึ้ง: โทนผิวสีเข้ม',
    '🙎🏻‍♂' => 'ผู้ชายโกรธ: โทนผิวสีขาว',
    '🙎🏼‍♂' => 'ผู้ชายโกรธ: โทนผิวสีขาวเหลือง',
    '🙎🏽‍♂' => 'ผู้ชายโกรธ: โทนผิวสีเหลือง',
    '🙎🏾‍♂' => 'ผู้ชายโกรธ: โทนผิวสีแทน',
    '🙎🏿‍♂' => 'ผู้ชายโกรธ: โทนผิวสีเข้ม',
    '🙎🏻‍♀' => 'ผู้หญิงโกรธ: โทนผิวสีขาว',
    '🙎🏼‍♀' => 'ผู้หญิงโกรธ: โทนผิวสีขาวเหลือง',
    '🙎🏽‍♀' => 'ผู้หญิงโกรธ: โทนผิวสีเหลือง',
    '🙎🏾‍♀' => 'ผู้หญิงโกรธ: โทนผิวสีแทน',
    '🙎🏿‍♀' => 'ผู้หญิงโกรธ: โทนผิวสีเข้ม',
    '🙅🏻‍♂' => 'ผู้ชายทำท่าไม่โอเค: โทนผิวสีขาว',
    '🙅🏼‍♂' => 'ผู้ชายทำท่าไม่โอเค: โทนผิวสีขาวเหลือง',
    '🙅🏽‍♂' => 'ผู้ชายทำท่าไม่โอเค: โทนผิวสีเหลือง',
    '🙅🏾‍♂' => 'ผู้ชายทำท่าไม่โอเค: โทนผิวสีแทน',
    '🙅🏿‍♂' => 'ผู้ชายทำท่าไม่โอเค: โทนผิวสีเข้ม',
    '🙅🏻‍♀' => 'ผู้หญิงทำท่าไม่โอเค: โทนผิวสีขาว',
    '🙅🏼‍♀' => 'ผู้หญิงทำท่าไม่โอเค: โทนผิวสีขาวเหลือง',
    '🙅🏽‍♀' => 'ผู้หญิงทำท่าไม่โอเค: โทนผิวสีเหลือง',
    '🙅🏾‍♀' => 'ผู้หญิงทำท่าไม่โอเค: โทนผิวสีแทน',
    '🙅🏿‍♀' => 'ผู้หญิงทำท่าไม่โอเค: โทนผิวสีเข้ม',
    '🙆🏻‍♂' => 'ผู้ชายทำท่าโอเค: โทนผิวสีขาว',
    '🙆🏼‍♂' => 'ผู้ชายทำท่าโอเค: โทนผิวสีขาวเหลือง',
    '🙆🏽‍♂' => 'ผู้ชายทำท่าโอเค: โทนผิวสีเหลือง',
    '🙆🏾‍♂' => 'ผู้ชายทำท่าโอเค: โทนผิวสีแทน',
    '🙆🏿‍♂' => 'ผู้ชายทำท่าโอเค: โทนผิวสีเข้ม',
    '🙆🏻‍♀' => 'ผู้หญิงทำท่าโอเค: โทนผิวสีขาว',
    '🙆🏼‍♀' => 'ผู้หญิงทำท่าโอเค: โทนผิวสีขาวเหลือง',
    '🙆🏽‍♀' => 'ผู้หญิงทำท่าโอเค: โทนผิวสีเหลือง',
    '🙆🏾‍♀' => 'ผู้หญิงทำท่าโอเค: โทนผิวสีแทน',
    '🙆🏿‍♀' => 'ผู้หญิงทำท่าโอเค: โทนผิวสีเข้ม',
    '💁🏻‍♂' => 'ผู้ชายแบมือ: โทนผิวสีขาว',
    '💁🏼‍♂' => 'ผู้ชายแบมือ: โทนผิวสีขาวเหลือง',
    '💁🏽‍♂' => 'ผู้ชายแบมือ: โทนผิวสีเหลือง',
    '💁🏾‍♂' => 'ผู้ชายแบมือ: โทนผิวสีแทน',
    '💁🏿‍♂' => 'ผู้ชายแบมือ: โทนผิวสีเข้ม',
    '💁🏻‍♀' => 'ผู้หญิงแบมือ: โทนผิวสีขาว',
    '💁🏼‍♀' => 'ผู้หญิงแบมือ: โทนผิวสีขาวเหลือง',
    '💁🏽‍♀' => 'ผู้หญิงแบมือ: โทนผิวสีเหลือง',
    '💁🏾‍♀' => 'ผู้หญิงแบมือ: โทนผิวสีแทน',
    '💁🏿‍♀' => 'ผู้หญิงแบมือ: โทนผิวสีเข้ม',
    '🙋🏻‍♂' => 'ผู้ชายยกมือ: โทนผิวสีขาว',
    '🙋🏼‍♂' => 'ผู้ชายยกมือ: โทนผิวสีขาวเหลือง',
    '🙋🏽‍♂' => 'ผู้ชายยกมือ: โทนผิวสีเหลือง',
    '🙋🏾‍♂' => 'ผู้ชายยกมือ: โทนผิวสีแทน',
    '🙋🏿‍♂' => 'ผู้ชายยกมือ: โทนผิวสีเข้ม',
    '🙋🏻‍♀' => 'ผู้หญิงยกมือ: โทนผิวสีขาว',
    '🙋🏼‍♀' => 'ผู้หญิงยกมือ: โทนผิวสีขาวเหลือง',
    '🙋🏽‍♀' => 'ผู้หญิงยกมือ: โทนผิวสีเหลือง',
    '🙋🏾‍♀' => 'ผู้หญิงยกมือ: โทนผิวสีแทน',
    '🙋🏿‍♀' => 'ผู้หญิงยกมือ: โทนผิวสีเข้ม',
    '🧏🏻‍♂' => 'ผู้ชายหูหนวก: โทนผิวสีขาว',
    '🧏🏼‍♂' => 'ผู้ชายหูหนวก: โทนผิวสีขาวเหลือง',
    '🧏🏽‍♂' => 'ผู้ชายหูหนวก: โทนผิวสีเหลือง',
    '🧏🏾‍♂' => 'ผู้ชายหูหนวก: โทนผิวสีแทน',
    '🧏🏿‍♂' => 'ผู้ชายหูหนวก: โทนผิวสีเข้ม',
    '🧏🏻‍♀' => 'ผู้หญิงหูหนวก: โทนผิวสีขาว',
    '🧏🏼‍♀' => 'ผู้หญิงหูหนวก: โทนผิวสีขาวเหลือง',
    '🧏🏽‍♀' => 'ผู้หญิงหูหนวก: โทนผิวสีเหลือง',
    '🧏🏾‍♀' => 'ผู้หญิงหูหนวก: โทนผิวสีแทน',
    '🧏🏿‍♀' => 'ผู้หญิงหูหนวก: โทนผิวสีเข้ม',
    '🙇🏻‍♂' => 'ผู้ชายหมอบคำนับ: โทนผิวสีขาว',
    '🙇🏼‍♂' => 'ผู้ชายหมอบคำนับ: โทนผิวสีขาวเหลือง',
    '🙇🏽‍♂' => 'ผู้ชายหมอบคำนับ: โทนผิวสีเหลือง',
    '🙇🏾‍♂' => 'ผู้ชายหมอบคำนับ: โทนผิวสีแทน',
    '🙇🏿‍♂' => 'ผู้ชายหมอบคำนับ: โทนผิวสีเข้ม',
    '🙇🏻‍♀' => 'ผู้หญิงหมอบคำนับ: โทนผิวสีขาว',
    '🙇🏼‍♀' => 'ผู้หญิงหมอบคำนับ: โทนผิวสีขาวเหลือง',
    '🙇🏽‍♀' => 'ผู้หญิงหมอบคำนับ: โทนผิวสีเหลือง',
    '🙇🏾‍♀' => 'ผู้หญิงหมอบคำนับ: โทนผิวสีแทน',
    '🙇🏿‍♀' => 'ผู้หญิงหมอบคำนับ: โทนผิวสีเข้ม',
    '🤦🏻‍♂' => 'ผู้ชายเอามือก่ายหน้าผาก: โทนผิวสีขาว',
    '🤦🏼‍♂' => 'ผู้ชายเอามือก่ายหน้าผาก: โทนผิวสีขาวเหลือง',
    '🤦🏽‍♂' => 'ผู้ชายเอามือก่ายหน้าผาก: โทนผิวสีเหลือง',
    '🤦🏾‍♂' => 'ผู้ชายเอามือก่ายหน้าผาก: โทนผิวสีแทน',
    '🤦🏿‍♂' => 'ผู้ชายเอามือก่ายหน้าผาก: โทนผิวสีเข้ม',
    '🤦🏻‍♀' => 'ผู้หญิงเอามือก่ายหน้าผาก: โทนผิวสีขาว',
    '🤦🏼‍♀' => 'ผู้หญิงเอามือก่ายหน้าผาก: โทนผิวสีขาวเหลือง',
    '🤦🏽‍♀' => 'ผู้หญิงเอามือก่ายหน้าผาก: โทนผิวสีเหลือง',
    '🤦🏾‍♀' => 'ผู้หญิงเอามือก่ายหน้าผาก: โทนผิวสีแทน',
    '🤦🏿‍♀' => 'ผู้หญิงเอามือก่ายหน้าผาก: โทนผิวสีเข้ม',
    '🤷🏻‍♂' => 'ผู้ชายยักไหล่: โทนผิวสีขาว',
    '🤷🏼‍♂' => 'ผู้ชายยักไหล่: โทนผิวสีขาวเหลือง',
    '🤷🏽‍♂' => 'ผู้ชายยักไหล่: โทนผิวสีเหลือง',
    '🤷🏾‍♂' => 'ผู้ชายยักไหล่: โทนผิวสีแทน',
    '🤷🏿‍♂' => 'ผู้ชายยักไหล่: โทนผิวสีเข้ม',
    '🤷🏻‍♀' => 'ผู้หญิงยักไหล่: โทนผิวสีขาว',
    '🤷🏼‍♀' => 'ผู้หญิงยักไหล่: โทนผิวสีขาวเหลือง',
    '🤷🏽‍♀' => 'ผู้หญิงยักไหล่: โทนผิวสีเหลือง',
    '🤷🏾‍♀' => 'ผู้หญิงยักไหล่: โทนผิวสีแทน',
    '🤷🏿‍♀' => 'ผู้หญิงยักไหล่: โทนผิวสีเข้ม',
    '🧑🏻‍⚕' => 'หมอ: โทนผิวสีขาว',
    '🧑🏼‍⚕' => 'หมอ: โทนผิวสีขาวเหลือง',
    '🧑🏽‍⚕' => 'หมอ: โทนผิวสีเหลือง',
    '🧑🏾‍⚕' => 'หมอ: โทนผิวสีแทน',
    '🧑🏿‍⚕' => 'หมอ: โทนผิวสีเข้ม',
    '👨🏻‍⚕' => 'หมอชาย: โทนผิวสีขาว',
    '👨🏼‍⚕' => 'หมอชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍⚕' => 'หมอชาย: โทนผิวสีเหลือง',
    '👨🏾‍⚕' => 'หมอชาย: โทนผิวสีแทน',
    '👨🏿‍⚕' => 'หมอชาย: โทนผิวสีเข้ม',
    '👩🏻‍⚕' => 'หมอหญิง: โทนผิวสีขาว',
    '👩🏼‍⚕' => 'หมอหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍⚕' => 'หมอหญิง: โทนผิวสีเหลือง',
    '👩🏾‍⚕' => 'หมอหญิง: โทนผิวสีแทน',
    '👩🏿‍⚕' => 'หมอหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🎓' => 'บัณฑิต: โทนผิวสีขาว',
    '🧑🏼‍🎓' => 'บัณฑิต: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🎓' => 'บัณฑิต: โทนผิวสีเหลือง',
    '🧑🏾‍🎓' => 'บัณฑิต: โทนผิวสีแทน',
    '🧑🏿‍🎓' => 'บัณฑิต: โทนผิวสีเข้ม',
    '👨🏻‍🎓' => 'นักเรียนชาย: โทนผิวสีขาว',
    '👨🏼‍🎓' => 'นักเรียนชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🎓' => 'นักเรียนชาย: โทนผิวสีเหลือง',
    '👨🏾‍🎓' => 'นักเรียนชาย: โทนผิวสีแทน',
    '👨🏿‍🎓' => 'นักเรียนชาย: โทนผิวสีเข้ม',
    '👩🏻‍🎓' => 'นักเรียนหญิง: โทนผิวสีขาว',
    '👩🏼‍🎓' => 'นักเรียนหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🎓' => 'นักเรียนหญิง: โทนผิวสีเหลือง',
    '👩🏾‍🎓' => 'นักเรียนหญิง: โทนผิวสีแทน',
    '👩🏿‍🎓' => 'นักเรียนหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🏫' => 'ครู: โทนผิวสีขาว',
    '🧑🏼‍🏫' => 'ครู: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🏫' => 'ครู: โทนผิวสีเหลือง',
    '🧑🏾‍🏫' => 'ครู: โทนผิวสีแทน',
    '🧑🏿‍🏫' => 'ครู: โทนผิวสีเข้ม',
    '👨🏻‍🏫' => 'ครูชาย: โทนผิวสีขาว',
    '👨🏼‍🏫' => 'ครูชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🏫' => 'ครูชาย: โทนผิวสีเหลือง',
    '👨🏾‍🏫' => 'ครูชาย: โทนผิวสีแทน',
    '👨🏿‍🏫' => 'ครูชาย: โทนผิวสีเข้ม',
    '👩🏻‍🏫' => 'ครูหญิง: โทนผิวสีขาว',
    '👩🏼‍🏫' => 'ครูหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🏫' => 'ครูหญิง: โทนผิวสีเหลือง',
    '👩🏾‍🏫' => 'ครูหญิง: โทนผิวสีแทน',
    '👩🏿‍🏫' => 'ครูหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍⚖' => 'ผู้พิพากษา: โทนผิวสีขาว',
    '🧑🏼‍⚖' => 'ผู้พิพากษา: โทนผิวสีขาวเหลือง',
    '🧑🏽‍⚖' => 'ผู้พิพากษา: โทนผิวสีเหลือง',
    '🧑🏾‍⚖' => 'ผู้พิพากษา: โทนผิวสีแทน',
    '🧑🏿‍⚖' => 'ผู้พิพากษา: โทนผิวสีเข้ม',
    '👨🏻‍⚖' => 'ผู้พิพากษาชาย: โทนผิวสีขาว',
    '👨🏼‍⚖' => 'ผู้พิพากษาชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍⚖' => 'ผู้พิพากษาชาย: โทนผิวสีเหลือง',
    '👨🏾‍⚖' => 'ผู้พิพากษาชาย: โทนผิวสีแทน',
    '👨🏿‍⚖' => 'ผู้พิพากษาชาย: โทนผิวสีเข้ม',
    '👩🏻‍⚖' => 'ผู้พิพากษาหญิง: โทนผิวสีขาว',
    '👩🏼‍⚖' => 'ผู้พิพากษาหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍⚖' => 'ผู้พิพากษาหญิง: โทนผิวสีเหลือง',
    '👩🏾‍⚖' => 'ผู้พิพากษาหญิง: โทนผิวสีแทน',
    '👩🏿‍⚖' => 'ผู้พิพากษาหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🌾' => 'ชาวนา: โทนผิวสีขาว',
    '🧑🏼‍🌾' => 'ชาวนา: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🌾' => 'ชาวนา: โทนผิวสีเหลือง',
    '🧑🏾‍🌾' => 'ชาวนา: โทนผิวสีแทน',
    '🧑🏿‍🌾' => 'ชาวนา: โทนผิวสีเข้ม',
    '👨🏻‍🌾' => 'ชาวนาชาย: โทนผิวสีขาว',
    '👨🏼‍🌾' => 'ชาวนาชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🌾' => 'ชาวนาชาย: โทนผิวสีเหลือง',
    '👨🏾‍🌾' => 'ชาวนาชาย: โทนผิวสีแทน',
    '👨🏿‍🌾' => 'ชาวนาชาย: โทนผิวสีเข้ม',
    '👩🏻‍🌾' => 'ชาวนาหญิง: โทนผิวสีขาว',
    '👩🏼‍🌾' => 'ชาวนาหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🌾' => 'ชาวนาหญิง: โทนผิวสีเหลือง',
    '👩🏾‍🌾' => 'ชาวนาหญิง: โทนผิวสีแทน',
    '👩🏿‍🌾' => 'ชาวนาหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🍳' => 'กุ๊ก: โทนผิวสีขาว',
    '🧑🏼‍🍳' => 'กุ๊ก: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🍳' => 'กุ๊ก: โทนผิวสีเหลือง',
    '🧑🏾‍🍳' => 'กุ๊ก: โทนผิวสีแทน',
    '🧑🏿‍🍳' => 'กุ๊ก: โทนผิวสีเข้ม',
    '👨🏻‍🍳' => 'พ่อครัว: โทนผิวสีขาว',
    '👨🏼‍🍳' => 'พ่อครัว: โทนผิวสีขาวเหลือง',
    '👨🏽‍🍳' => 'พ่อครัว: โทนผิวสีเหลือง',
    '👨🏾‍🍳' => 'พ่อครัว: โทนผิวสีแทน',
    '👨🏿‍🍳' => 'พ่อครัว: โทนผิวสีเข้ม',
    '👩🏻‍🍳' => 'แม่ครัว: โทนผิวสีขาว',
    '👩🏼‍🍳' => 'แม่ครัว: โทนผิวสีขาวเหลือง',
    '👩🏽‍🍳' => 'แม่ครัว: โทนผิวสีเหลือง',
    '👩🏾‍🍳' => 'แม่ครัว: โทนผิวสีแทน',
    '👩🏿‍🍳' => 'แม่ครัว: โทนผิวสีเข้ม',
    '🧑🏻‍🔧' => 'ช่างกล: โทนผิวสีขาว',
    '🧑🏼‍🔧' => 'ช่างกล: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🔧' => 'ช่างกล: โทนผิวสีเหลือง',
    '🧑🏾‍🔧' => 'ช่างกล: โทนผิวสีแทน',
    '🧑🏿‍🔧' => 'ช่างกล: โทนผิวสีเข้ม',
    '👨🏻‍🔧' => 'ช่างซ่อมชาย: โทนผิวสีขาว',
    '👨🏼‍🔧' => 'ช่างซ่อมชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🔧' => 'ช่างซ่อมชาย: โทนผิวสีเหลือง',
    '👨🏾‍🔧' => 'ช่างซ่อมชาย: โทนผิวสีแทน',
    '👨🏿‍🔧' => 'ช่างซ่อมชาย: โทนผิวสีเข้ม',
    '👩🏻‍🔧' => 'ช่างซ่อมหญิง: โทนผิวสีขาว',
    '👩🏼‍🔧' => 'ช่างซ่อมหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🔧' => 'ช่างซ่อมหญิง: โทนผิวสีเหลือง',
    '👩🏾‍🔧' => 'ช่างซ่อมหญิง: โทนผิวสีแทน',
    '👩🏿‍🔧' => 'ช่างซ่อมหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🏭' => 'พนักงานโรงงาน: โทนผิวสีขาว',
    '🧑🏼‍🏭' => 'พนักงานโรงงาน: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🏭' => 'พนักงานโรงงาน: โทนผิวสีเหลือง',
    '🧑🏾‍🏭' => 'พนักงานโรงงาน: โทนผิวสีแทน',
    '🧑🏿‍🏭' => 'พนักงานโรงงาน: โทนผิวสีเข้ม',
    '👨🏻‍🏭' => 'พนักงานโรงงานชาย: โทนผิวสีขาว',
    '👨🏼‍🏭' => 'พนักงานโรงงานชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🏭' => 'พนักงานโรงงานชาย: โทนผิวสีเหลือง',
    '👨🏾‍🏭' => 'พนักงานโรงงานชาย: โทนผิวสีแทน',
    '👨🏿‍🏭' => 'พนักงานโรงงานชาย: โทนผิวสีเข้ม',
    '👩🏻‍🏭' => 'พนักงานโรงงานหญิง: โทนผิวสีขาว',
    '👩🏼‍🏭' => 'พนักงานโรงงานหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🏭' => 'พนักงานโรงงานหญิง: โทนผิวสีเหลือง',
    '👩🏾‍🏭' => 'พนักงานโรงงานหญิง: โทนผิวสีแทน',
    '👩🏿‍🏭' => 'พนักงานโรงงานหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍💼' => 'พนักงานออฟฟิศ: โทนผิวสีขาว',
    '🧑🏼‍💼' => 'พนักงานออฟฟิศ: โทนผิวสีขาวเหลือง',
    '🧑🏽‍💼' => 'พนักงานออฟฟิศ: โทนผิวสีเหลือง',
    '🧑🏾‍💼' => 'พนักงานออฟฟิศ: โทนผิวสีแทน',
    '🧑🏿‍💼' => 'พนักงานออฟฟิศ: โทนผิวสีเข้ม',
    '👨🏻‍💼' => 'พนักงานบริษัทชาย: โทนผิวสีขาว',
    '👨🏼‍💼' => 'พนักงานบริษัทชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍💼' => 'พนักงานบริษัทชาย: โทนผิวสีเหลือง',
    '👨🏾‍💼' => 'พนักงานบริษัทชาย: โทนผิวสีแทน',
    '👨🏿‍💼' => 'พนักงานบริษัทชาย: โทนผิวสีเข้ม',
    '👩🏻‍💼' => 'พนักงานบริษัทหญิง: โทนผิวสีขาว',
    '👩🏼‍💼' => 'พนักงานบริษัทหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍💼' => 'พนักงานบริษัทหญิง: โทนผิวสีเหลือง',
    '👩🏾‍💼' => 'พนักงานบริษัทหญิง: โทนผิวสีแทน',
    '👩🏿‍💼' => 'พนักงานบริษัทหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🔬' => 'นักวิทยาศาสตร์: โทนผิวสีขาว',
    '🧑🏼‍🔬' => 'นักวิทยาศาสตร์: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🔬' => 'นักวิทยาศาสตร์: โทนผิวสีเหลือง',
    '🧑🏾‍🔬' => 'นักวิทยาศาสตร์: โทนผิวสีแทน',
    '🧑🏿‍🔬' => 'นักวิทยาศาสตร์: โทนผิวสีเข้ม',
    '👨🏻‍🔬' => 'นักวิทยาศาสตร์ชาย: โทนผิวสีขาว',
    '👨🏼‍🔬' => 'นักวิทยาศาสตร์ชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🔬' => 'นักวิทยาศาสตร์ชาย: โทนผิวสีเหลือง',
    '👨🏾‍🔬' => 'นักวิทยาศาสตร์ชาย: โทนผิวสีแทน',
    '👨🏿‍🔬' => 'นักวิทยาศาสตร์ชาย: โทนผิวสีเข้ม',
    '👩🏻‍🔬' => 'นักวิทยาศาสตร์หญิง: โทนผิวสีขาว',
    '👩🏼‍🔬' => 'นักวิทยาศาสตร์หญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🔬' => 'นักวิทยาศาสตร์หญิง: โทนผิวสีเหลือง',
    '👩🏾‍🔬' => 'นักวิทยาศาสตร์หญิง: โทนผิวสีแทน',
    '👩🏿‍🔬' => 'นักวิทยาศาสตร์หญิง: โทนผิวสีเข้ม',
    '🧑🏻‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยี: โทนผิวสีขาว',
    '🧑🏼‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยี: โทนผิวสีขาวเหลือง',
    '🧑🏽‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยี: โทนผิวสีเหลือง',
    '🧑🏾‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยี: โทนผิวสีแทน',
    '🧑🏿‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยี: โทนผิวสีเข้ม',
    '👨🏻‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีชาย: โทนผิวสีขาว',
    '👨🏼‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีชาย: โทนผิวสีเหลือง',
    '👨🏾‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีชาย: โทนผิวสีแทน',
    '👨🏿‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีชาย: โทนผิวสีเข้ม',
    '👩🏻‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีหญิง: โทนผิวสีขาว',
    '👩🏼‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีหญิง: โทนผิวสีเหลือง',
    '👩🏾‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีหญิง: โทนผิวสีแทน',
    '👩🏿‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🎤' => 'นักร้อง: โทนผิวสีขาว',
    '🧑🏼‍🎤' => 'นักร้อง: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🎤' => 'นักร้อง: โทนผิวสีเหลือง',
    '🧑🏾‍🎤' => 'นักร้อง: โทนผิวสีแทน',
    '🧑🏿‍🎤' => 'นักร้อง: โทนผิวสีเข้ม',
    '👨🏻‍🎤' => 'นักร้องชาย: โทนผิวสีขาว',
    '👨🏼‍🎤' => 'นักร้องชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🎤' => 'นักร้องชาย: โทนผิวสีเหลือง',
    '👨🏾‍🎤' => 'นักร้องชาย: โทนผิวสีแทน',
    '👨🏿‍🎤' => 'นักร้องชาย: โทนผิวสีเข้ม',
    '👩🏻‍🎤' => 'นักร้องหญิง: โทนผิวสีขาว',
    '👩🏼‍🎤' => 'นักร้องหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🎤' => 'นักร้องหญิง: โทนผิวสีเหลือง',
    '👩🏾‍🎤' => 'นักร้องหญิง: โทนผิวสีแทน',
    '👩🏿‍🎤' => 'นักร้องหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🎨' => 'ศิลปิน: โทนผิวสีขาว',
    '🧑🏼‍🎨' => 'ศิลปิน: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🎨' => 'ศิลปิน: โทนผิวสีเหลือง',
    '🧑🏾‍🎨' => 'ศิลปิน: โทนผิวสีแทน',
    '🧑🏿‍🎨' => 'ศิลปิน: โทนผิวสีเข้ม',
    '👨🏻‍🎨' => 'ศิลปินชาย: โทนผิวสีขาว',
    '👨🏼‍🎨' => 'ศิลปินชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🎨' => 'ศิลปินชาย: โทนผิวสีเหลือง',
    '👨🏾‍🎨' => 'ศิลปินชาย: โทนผิวสีแทน',
    '👨🏿‍🎨' => 'ศิลปินชาย: โทนผิวสีเข้ม',
    '👩🏻‍🎨' => 'ศิลปินหญิง: โทนผิวสีขาว',
    '👩🏼‍🎨' => 'ศิลปินหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🎨' => 'ศิลปินหญิง: โทนผิวสีเหลือง',
    '👩🏾‍🎨' => 'ศิลปินหญิง: โทนผิวสีแทน',
    '👩🏿‍🎨' => 'ศิลปินหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍✈' => 'นักบิน: โทนผิวสีขาว',
    '🧑🏼‍✈' => 'นักบิน: โทนผิวสีขาวเหลือง',
    '🧑🏽‍✈' => 'นักบิน: โทนผิวสีเหลือง',
    '🧑🏾‍✈' => 'นักบิน: โทนผิวสีแทน',
    '🧑🏿‍✈' => 'นักบิน: โทนผิวสีเข้ม',
    '👨🏻‍✈' => 'นักบินชาย: โทนผิวสีขาว',
    '👨🏼‍✈' => 'นักบินชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍✈' => 'นักบินชาย: โทนผิวสีเหลือง',
    '👨🏾‍✈' => 'นักบินชาย: โทนผิวสีแทน',
    '👨🏿‍✈' => 'นักบินชาย: โทนผิวสีเข้ม',
    '👩🏻‍✈' => 'นักบินหญิง: โทนผิวสีขาว',
    '👩🏼‍✈' => 'นักบินหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍✈' => 'นักบินหญิง: โทนผิวสีเหลือง',
    '👩🏾‍✈' => 'นักบินหญิง: โทนผิวสีแทน',
    '👩🏿‍✈' => 'นักบินหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🚀' => 'นักบินอวกาศ: โทนผิวสีขาว',
    '🧑🏼‍🚀' => 'นักบินอวกาศ: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🚀' => 'นักบินอวกาศ: โทนผิวสีเหลือง',
    '🧑🏾‍🚀' => 'นักบินอวกาศ: โทนผิวสีแทน',
    '🧑🏿‍🚀' => 'นักบินอวกาศ: โทนผิวสีเข้ม',
    '👨🏻‍🚀' => 'นักบินอวกาศชาย: โทนผิวสีขาว',
    '👨🏼‍🚀' => 'นักบินอวกาศชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🚀' => 'นักบินอวกาศชาย: โทนผิวสีเหลือง',
    '👨🏾‍🚀' => 'นักบินอวกาศชาย: โทนผิวสีแทน',
    '👨🏿‍🚀' => 'นักบินอวกาศชาย: โทนผิวสีเข้ม',
    '👩🏻‍🚀' => 'นักบินอวกาศหญิง: โทนผิวสีขาว',
    '👩🏼‍🚀' => 'นักบินอวกาศหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🚀' => 'นักบินอวกาศหญิง: โทนผิวสีเหลือง',
    '👩🏾‍🚀' => 'นักบินอวกาศหญิง: โทนผิวสีแทน',
    '👩🏿‍🚀' => 'นักบินอวกาศหญิง: โทนผิวสีเข้ม',
    '🧑🏻‍🚒' => 'พนักงานดับเพลิง: โทนผิวสีขาว',
    '🧑🏼‍🚒' => 'พนักงานดับเพลิง: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🚒' => 'พนักงานดับเพลิง: โทนผิวสีเหลือง',
    '🧑🏾‍🚒' => 'พนักงานดับเพลิง: โทนผิวสีแทน',
    '🧑🏿‍🚒' => 'พนักงานดับเพลิง: โทนผิวสีเข้ม',
    '👨🏻‍🚒' => 'พนักงานดับเพลิงชาย: โทนผิวสีขาว',
    '👨🏼‍🚒' => 'พนักงานดับเพลิงชาย: โทนผิวสีขาวเหลือง',
    '👨🏽‍🚒' => 'พนักงานดับเพลิงชาย: โทนผิวสีเหลือง',
    '👨🏾‍🚒' => 'พนักงานดับเพลิงชาย: โทนผิวสีแทน',
    '👨🏿‍🚒' => 'พนักงานดับเพลิงชาย: โทนผิวสีเข้ม',
    '👩🏻‍🚒' => 'พนักงานดับเพลิงหญิง: โทนผิวสีขาว',
    '👩🏼‍🚒' => 'พนักงานดับเพลิงหญิง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🚒' => 'พนักงานดับเพลิงหญิง: โทนผิวสีเหลือง',
    '👩🏾‍🚒' => 'พนักงานดับเพลิงหญิง: โทนผิวสีแทน',
    '👩🏿‍🚒' => 'พนักงานดับเพลิงหญิง: โทนผิวสีเข้ม',
    '👮🏻‍♂' => 'ตำรวจชาย: โทนผิวสีขาว',
    '👮🏼‍♂' => 'ตำรวจชาย: โทนผิวสีขาวเหลือง',
    '👮🏽‍♂' => 'ตำรวจชาย: โทนผิวสีเหลือง',
    '👮🏾‍♂' => 'ตำรวจชาย: โทนผิวสีแทน',
    '👮🏿‍♂' => 'ตำรวจชาย: โทนผิวสีเข้ม',
    '👮🏻‍♀' => 'ตำรวจหญิง: โทนผิวสีขาว',
    '👮🏼‍♀' => 'ตำรวจหญิง: โทนผิวสีขาวเหลือง',
    '👮🏽‍♀' => 'ตำรวจหญิง: โทนผิวสีเหลือง',
    '👮🏾‍♀' => 'ตำรวจหญิง: โทนผิวสีแทน',
    '👮🏿‍♀' => 'ตำรวจหญิง: โทนผิวสีเข้ม',
    '🕵🏻‍♂' => 'นักสืบชาย: โทนผิวสีขาว',
    '🕵🏼‍♂' => 'นักสืบชาย: โทนผิวสีขาวเหลือง',
    '🕵🏽‍♂' => 'นักสืบชาย: โทนผิวสีเหลือง',
    '🕵🏾‍♂' => 'นักสืบชาย: โทนผิวสีแทน',
    '🕵🏿‍♂' => 'นักสืบชาย: โทนผิวสีเข้ม',
    '🕵🏻‍♀' => 'นักสืบหญิง: โทนผิวสีขาว',
    '🕵🏼‍♀' => 'นักสืบหญิง: โทนผิวสีขาวเหลือง',
    '🕵🏽‍♀' => 'นักสืบหญิง: โทนผิวสีเหลือง',
    '🕵🏾‍♀' => 'นักสืบหญิง: โทนผิวสีแทน',
    '🕵🏿‍♀' => 'นักสืบหญิง: โทนผิวสีเข้ม',
    '💂🏻‍♂' => 'องครักษ์ชาย: โทนผิวสีขาว',
    '💂🏼‍♂' => 'องครักษ์ชาย: โทนผิวสีขาวเหลือง',
    '💂🏽‍♂' => 'องครักษ์ชาย: โทนผิวสีเหลือง',
    '💂🏾‍♂' => 'องครักษ์ชาย: โทนผิวสีแทน',
    '💂🏿‍♂' => 'องครักษ์ชาย: โทนผิวสีเข้ม',
    '💂🏻‍♀' => 'องครักษ์หญิง: โทนผิวสีขาว',
    '💂🏼‍♀' => 'องครักษ์หญิง: โทนผิวสีขาวเหลือง',
    '💂🏽‍♀' => 'องครักษ์หญิง: โทนผิวสีเหลือง',
    '💂🏾‍♀' => 'องครักษ์หญิง: โทนผิวสีแทน',
    '💂🏿‍♀' => 'องครักษ์หญิง: โทนผิวสีเข้ม',
    '👷🏻‍♂' => 'พนักงานก่อสร้างชาย: โทนผิวสีขาว',
    '👷🏼‍♂' => 'พนักงานก่อสร้างชาย: โทนผิวสีขาวเหลือง',
    '👷🏽‍♂' => 'พนักงานก่อสร้างชาย: โทนผิวสีเหลือง',
    '👷🏾‍♂' => 'พนักงานก่อสร้างชาย: โทนผิวสีแทน',
    '👷🏿‍♂' => 'พนักงานก่อสร้างชาย: โทนผิวสีเข้ม',
    '👷🏻‍♀' => 'พนักงานก่อสร้างหญิง: โทนผิวสีขาว',
    '👷🏼‍♀' => 'พนักงานก่อสร้างหญิง: โทนผิวสีขาวเหลือง',
    '👷🏽‍♀' => 'พนักงานก่อสร้างหญิง: โทนผิวสีเหลือง',
    '👷🏾‍♀' => 'พนักงานก่อสร้างหญิง: โทนผิวสีแทน',
    '👷🏿‍♀' => 'พนักงานก่อสร้างหญิง: โทนผิวสีเข้ม',
    '👳🏻‍♂' => 'ผู้ชายโพกหัว: โทนผิวสีขาว',
    '👳🏼‍♂' => 'ผู้ชายโพกหัว: โทนผิวสีขาวเหลือง',
    '👳🏽‍♂' => 'ผู้ชายโพกหัว: โทนผิวสีเหลือง',
    '👳🏾‍♂' => 'ผู้ชายโพกหัว: โทนผิวสีแทน',
    '👳🏿‍♂' => 'ผู้ชายโพกหัว: โทนผิวสีเข้ม',
    '👳🏻‍♀' => 'ผู้หญิงโพกหัว: โทนผิวสีขาว',
    '👳🏼‍♀' => 'ผู้หญิงโพกหัว: โทนผิวสีขาวเหลือง',
    '👳🏽‍♀' => 'ผู้หญิงโพกหัว: โทนผิวสีเหลือง',
    '👳🏾‍♀' => 'ผู้หญิงโพกหัว: โทนผิวสีแทน',
    '👳🏿‍♀' => 'ผู้หญิงโพกหัว: โทนผิวสีเข้ม',
    '🤵🏻‍♂' => 'ผู้ชายใส่ทักซิโด้: โทนผิวสีขาว',
    '🤵🏼‍♂' => 'ผู้ชายใส่ทักซิโด้: โทนผิวสีขาวเหลือง',
    '🤵🏽‍♂' => 'ผู้ชายใส่ทักซิโด้: โทนผิวสีเหลือง',
    '🤵🏾‍♂' => 'ผู้ชายใส่ทักซิโด้: โทนผิวสีแทน',
    '🤵🏿‍♂' => 'ผู้ชายใส่ทักซิโด้: โทนผิวสีเข้ม',
    '🤵🏻‍♀' => 'ผู้หญิงใส่ทักซิโด้: โทนผิวสีขาว',
    '🤵🏼‍♀' => 'ผู้หญิงใส่ทักซิโด้: โทนผิวสีขาวเหลือง',
    '🤵🏽‍♀' => 'ผู้หญิงใส่ทักซิโด้: โทนผิวสีเหลือง',
    '🤵🏾‍♀' => 'ผู้หญิงใส่ทักซิโด้: โทนผิวสีแทน',
    '🤵🏿‍♀' => 'ผู้หญิงใส่ทักซิโด้: โทนผิวสีเข้ม',
    '👰🏻‍♂' => 'ผู้ชายที่มีผ้าคลุมหน้า: โทนผิวสีขาว',
    '👰🏼‍♂' => 'ผู้ชายที่มีผ้าคลุมหน้า: โทนผิวสีขาวเหลือง',
    '👰🏽‍♂' => 'ผู้ชายที่มีผ้าคลุมหน้า: โทนผิวสีเหลือง',
    '👰🏾‍♂' => 'ผู้ชายที่มีผ้าคลุมหน้า: โทนผิวสีแทน',
    '👰🏿‍♂' => 'ผู้ชายที่มีผ้าคลุมหน้า: โทนผิวสีเข้ม',
    '👰🏻‍♀' => 'ผู้หญิงที่มีผ้าคลุมหน้า: โทนผิวสีขาว',
    '👰🏼‍♀' => 'ผู้หญิงที่มีผ้าคลุมหน้า: โทนผิวสีขาวเหลือง',
    '👰🏽‍♀' => 'ผู้หญิงที่มีผ้าคลุมหน้า: โทนผิวสีเหลือง',
    '👰🏾‍♀' => 'ผู้หญิงที่มีผ้าคลุมหน้า: โทนผิวสีแทน',
    '👰🏿‍♀' => 'ผู้หญิงที่มีผ้าคลุมหน้า: โทนผิวสีเข้ม',
    '👩🏻‍🍼' => 'ผู้หญิงให้นมลูก: โทนผิวสีขาว',
    '👩🏼‍🍼' => 'ผู้หญิงให้นมลูก: โทนผิวสีขาวเหลือง',
    '👩🏽‍🍼' => 'ผู้หญิงให้นมลูก: โทนผิวสีเหลือง',
    '👩🏾‍🍼' => 'ผู้หญิงให้นมลูก: โทนผิวสีแทน',
    '👩🏿‍🍼' => 'ผู้หญิงให้นมลูก: โทนผิวสีเข้ม',
    '👨🏻‍🍼' => 'ผู้ชายให้นมลูก: โทนผิวสีขาว',
    '👨🏼‍🍼' => 'ผู้ชายให้นมลูก: โทนผิวสีขาวเหลือง',
    '👨🏽‍🍼' => 'ผู้ชายให้นมลูก: โทนผิวสีเหลือง',
    '👨🏾‍🍼' => 'ผู้ชายให้นมลูก: โทนผิวสีแทน',
    '👨🏿‍🍼' => 'ผู้ชายให้นมลูก: โทนผิวสีเข้ม',
    '🧑🏻‍🍼' => 'คนให้นมลูก: โทนผิวสีขาว',
    '🧑🏼‍🍼' => 'คนให้นมลูก: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🍼' => 'คนให้นมลูก: โทนผิวสีเหลือง',
    '🧑🏾‍🍼' => 'คนให้นมลูก: โทนผิวสีแทน',
    '🧑🏿‍🍼' => 'คนให้นมลูก: โทนผิวสีเข้ม',
    '🧑🏻‍🎄' => 'ซานตาคลอส: โทนผิวสีขาว',
    '🧑🏼‍🎄' => 'ซานตาคลอส: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🎄' => 'ซานตาคลอส: โทนผิวสีเหลือง',
    '🧑🏾‍🎄' => 'ซานตาคลอส: โทนผิวสีแทน',
    '🧑🏿‍🎄' => 'ซานตาคลอส: โทนผิวสีเข้ม',
    '🦸🏻‍♂' => 'พระเอก: โทนผิวสีขาว',
    '🦸🏼‍♂' => 'พระเอก: โทนผิวสีขาวเหลือง',
    '🦸🏽‍♂' => 'พระเอก: โทนผิวสีเหลือง',
    '🦸🏾‍♂' => 'พระเอก: โทนผิวสีแทน',
    '🦸🏿‍♂' => 'พระเอก: โทนผิวสีเข้ม',
    '🦸🏻‍♀' => 'ยอดหญิง: โทนผิวสีขาว',
    '🦸🏼‍♀' => 'ยอดหญิง: โทนผิวสีขาวเหลือง',
    '🦸🏽‍♀' => 'ยอดหญิง: โทนผิวสีเหลือง',
    '🦸🏾‍♀' => 'ยอดหญิง: โทนผิวสีแทน',
    '🦸🏿‍♀' => 'ยอดหญิง: โทนผิวสีเข้ม',
    '🦹🏻‍♂' => 'ตัวโกง: โทนผิวสีขาว',
    '🦹🏼‍♂' => 'ตัวโกง: โทนผิวสีขาวเหลือง',
    '🦹🏽‍♂' => 'ตัวโกง: โทนผิวสีเหลือง',
    '🦹🏾‍♂' => 'ตัวโกง: โทนผิวสีแทน',
    '🦹🏿‍♂' => 'ตัวโกง: โทนผิวสีเข้ม',
    '🦹🏻‍♀' => 'นางร้าย: โทนผิวสีขาว',
    '🦹🏼‍♀' => 'นางร้าย: โทนผิวสีขาวเหลือง',
    '🦹🏽‍♀' => 'นางร้าย: โทนผิวสีเหลือง',
    '🦹🏾‍♀' => 'นางร้าย: โทนผิวสีแทน',
    '🦹🏿‍♀' => 'นางร้าย: โทนผิวสีเข้ม',
    '🧙🏻‍♂' => 'พ่อมด: โทนผิวสีขาว',
    '🧙🏼‍♂' => 'พ่อมด: โทนผิวสีขาวเหลือง',
    '🧙🏽‍♂' => 'พ่อมด: โทนผิวสีเหลือง',
    '🧙🏾‍♂' => 'พ่อมด: โทนผิวสีแทน',
    '🧙🏿‍♂' => 'พ่อมด: โทนผิวสีเข้ม',
    '🧙🏻‍♀' => 'แม่มด: โทนผิวสีขาว',
    '🧙🏼‍♀' => 'แม่มด: โทนผิวสีขาวเหลือง',
    '🧙🏽‍♀' => 'แม่มด: โทนผิวสีเหลือง',
    '🧙🏾‍♀' => 'แม่มด: โทนผิวสีแทน',
    '🧙🏿‍♀' => 'แม่มด: โทนผิวสีเข้ม',
    '🧚🏻‍♂' => 'เทพบุตร: โทนผิวสีขาว',
    '🧚🏼‍♂' => 'เทพบุตร: โทนผิวสีขาวเหลือง',
    '🧚🏽‍♂' => 'เทพบุตร: โทนผิวสีเหลือง',
    '🧚🏾‍♂' => 'เทพบุตร: โทนผิวสีแทน',
    '🧚🏿‍♂' => 'เทพบุตร: โทนผิวสีเข้ม',
    '🧚🏻‍♀' => 'เทพธิดา: โทนผิวสีขาว',
    '🧚🏼‍♀' => 'เทพธิดา: โทนผิวสีขาวเหลือง',
    '🧚🏽‍♀' => 'เทพธิดา: โทนผิวสีเหลือง',
    '🧚🏾‍♀' => 'เทพธิดา: โทนผิวสีแทน',
    '🧚🏿‍♀' => 'เทพธิดา: โทนผิวสีเข้ม',
    '🧛🏻‍♂' => 'แวมไพร์ผู้ชาย: โทนผิวสีขาว',
    '🧛🏼‍♂' => 'แวมไพร์ผู้ชาย: โทนผิวสีขาวเหลือง',
    '🧛🏽‍♂' => 'แวมไพร์ผู้ชาย: โทนผิวสีเหลือง',
    '🧛🏾‍♂' => 'แวมไพร์ผู้ชาย: โทนผิวสีแทน',
    '🧛🏿‍♂' => 'แวมไพร์ผู้ชาย: โทนผิวสีเข้ม',
    '🧛🏻‍♀' => 'แวมไพร์ผู้หญิง: โทนผิวสีขาว',
    '🧛🏼‍♀' => 'แวมไพร์ผู้หญิง: โทนผิวสีขาวเหลือง',
    '🧛🏽‍♀' => 'แวมไพร์ผู้หญิง: โทนผิวสีเหลือง',
    '🧛🏾‍♀' => 'แวมไพร์ผู้หญิง: โทนผิวสีแทน',
    '🧛🏿‍♀' => 'แวมไพร์ผู้หญิง: โทนผิวสีเข้ม',
    '🧜🏻‍♂' => 'เงือกชาย: โทนผิวสีขาว',
    '🧜🏼‍♂' => 'เงือกชาย: โทนผิวสีขาวเหลือง',
    '🧜🏽‍♂' => 'เงือกชาย: โทนผิวสีเหลือง',
    '🧜🏾‍♂' => 'เงือกชาย: โทนผิวสีแทน',
    '🧜🏿‍♂' => 'เงือกชาย: โทนผิวสีเข้ม',
    '🧜🏻‍♀' => 'เงือก: โทนผิวสีขาว',
    '🧜🏼‍♀' => 'เงือก: โทนผิวสีขาวเหลือง',
    '🧜🏽‍♀' => 'เงือก: โทนผิวสีเหลือง',
    '🧜🏾‍♀' => 'เงือก: โทนผิวสีแทน',
    '🧜🏿‍♀' => 'เงือก: โทนผิวสีเข้ม',
    '🧝🏻‍♂' => 'เอลฟ์ผู้ชาย: โทนผิวสีขาว',
    '🧝🏼‍♂' => 'เอลฟ์ผู้ชาย: โทนผิวสีขาวเหลือง',
    '🧝🏽‍♂' => 'เอลฟ์ผู้ชาย: โทนผิวสีเหลือง',
    '🧝🏾‍♂' => 'เอลฟ์ผู้ชาย: โทนผิวสีแทน',
    '🧝🏿‍♂' => 'เอลฟ์ผู้ชาย: โทนผิวสีเข้ม',
    '🧝🏻‍♀' => 'เอลฟ์ผู้หญิง: โทนผิวสีขาว',
    '🧝🏼‍♀' => 'เอลฟ์ผู้หญิง: โทนผิวสีขาวเหลือง',
    '🧝🏽‍♀' => 'เอลฟ์ผู้หญิง: โทนผิวสีเหลือง',
    '🧝🏾‍♀' => 'เอลฟ์ผู้หญิง: โทนผิวสีแทน',
    '🧝🏿‍♀' => 'เอลฟ์ผู้หญิง: โทนผิวสีเข้ม',
    '💆🏻‍♂' => 'ผู้ชายกำลังนวดหน้า: โทนผิวสีขาว',
    '💆🏼‍♂' => 'ผู้ชายกำลังนวดหน้า: โทนผิวสีขาวเหลือง',
    '💆🏽‍♂' => 'ผู้ชายกำลังนวดหน้า: โทนผิวสีเหลือง',
    '💆🏾‍♂' => 'ผู้ชายกำลังนวดหน้า: โทนผิวสีแทน',
    '💆🏿‍♂' => 'ผู้ชายกำลังนวดหน้า: โทนผิวสีเข้ม',
    '💆🏻‍♀' => 'ผู้หญิงกำลังนวดหน้า: โทนผิวสีขาว',
    '💆🏼‍♀' => 'ผู้หญิงกำลังนวดหน้า: โทนผิวสีขาวเหลือง',
    '💆🏽‍♀' => 'ผู้หญิงกำลังนวดหน้า: โทนผิวสีเหลือง',
    '💆🏾‍♀' => 'ผู้หญิงกำลังนวดหน้า: โทนผิวสีแทน',
    '💆🏿‍♀' => 'ผู้หญิงกำลังนวดหน้า: โทนผิวสีเข้ม',
    '💇🏻‍♂' => 'ผู้ชายกำลังตัดผม: โทนผิวสีขาว',
    '💇🏼‍♂' => 'ผู้ชายกำลังตัดผม: โทนผิวสีขาวเหลือง',
    '💇🏽‍♂' => 'ผู้ชายกำลังตัดผม: โทนผิวสีเหลือง',
    '💇🏾‍♂' => 'ผู้ชายกำลังตัดผม: โทนผิวสีแทน',
    '💇🏿‍♂' => 'ผู้ชายกำลังตัดผม: โทนผิวสีเข้ม',
    '💇🏻‍♀' => 'ผู้หญิงกำลังตัดผม: โทนผิวสีขาว',
    '💇🏼‍♀' => 'ผู้หญิงกำลังตัดผม: โทนผิวสีขาวเหลือง',
    '💇🏽‍♀' => 'ผู้หญิงกำลังตัดผม: โทนผิวสีเหลือง',
    '💇🏾‍♀' => 'ผู้หญิงกำลังตัดผม: โทนผิวสีแทน',
    '💇🏿‍♀' => 'ผู้หญิงกำลังตัดผม: โทนผิวสีเข้ม',
    '🚶🏻‍♂' => 'ผู้ชายเดิน: โทนผิวสีขาว',
    '🚶🏼‍♂' => 'ผู้ชายเดิน: โทนผิวสีขาวเหลือง',
    '🚶🏽‍♂' => 'ผู้ชายเดิน: โทนผิวสีเหลือง',
    '🚶🏾‍♂' => 'ผู้ชายเดิน: โทนผิวสีแทน',
    '🚶🏿‍♂' => 'ผู้ชายเดิน: โทนผิวสีเข้ม',
    '🚶🏻‍♀' => 'ผู้หญิงเดิน: โทนผิวสีขาว',
    '🚶🏼‍♀' => 'ผู้หญิงเดิน: โทนผิวสีขาวเหลือง',
    '🚶🏽‍♀' => 'ผู้หญิงเดิน: โทนผิวสีเหลือง',
    '🚶🏾‍♀' => 'ผู้หญิงเดิน: โทนผิวสีแทน',
    '🚶🏿‍♀' => 'ผู้หญิงเดิน: โทนผิวสีเข้ม',
    '🚶🏻‍➡' => 'คนเดิน: โทนผิวสีขาว หันขวา',
    '🚶🏼‍➡' => 'คนเดิน: โทนผิวสีขาวเหลือง หันขวา',
    '🚶🏽‍➡' => 'คนเดิน: โทนผิวสีเหลือง หันขวา',
    '🚶🏾‍➡' => 'คนเดิน: โทนผิวสีแทน หันขวา',
    '🚶🏿‍➡' => 'คนเดิน: โทนผิวสีเข้ม หันขวา',
    '🧍🏻‍♂' => 'ผู้ชายกำลังยืน: โทนผิวสีขาว',
    '🧍🏼‍♂' => 'ผู้ชายกำลังยืน: โทนผิวสีขาวเหลือง',
    '🧍🏽‍♂' => 'ผู้ชายกำลังยืน: โทนผิวสีเหลือง',
    '🧍🏾‍♂' => 'ผู้ชายกำลังยืน: โทนผิวสีแทน',
    '🧍🏿‍♂' => 'ผู้ชายกำลังยืน: โทนผิวสีเข้ม',
    '🧍🏻‍♀' => 'ผู้หญิงกำลังยืน: โทนผิวสีขาว',
    '🧍🏼‍♀' => 'ผู้หญิงกำลังยืน: โทนผิวสีขาวเหลือง',
    '🧍🏽‍♀' => 'ผู้หญิงกำลังยืน: โทนผิวสีเหลือง',
    '🧍🏾‍♀' => 'ผู้หญิงกำลังยืน: โทนผิวสีแทน',
    '🧍🏿‍♀' => 'ผู้หญิงกำลังยืน: โทนผิวสีเข้ม',
    '🧎🏻‍♂' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีขาว',
    '🧎🏼‍♂' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีขาวเหลือง',
    '🧎🏽‍♂' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีเหลือง',
    '🧎🏾‍♂' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีแทน',
    '🧎🏿‍♂' => 'ผู้ชายกำลังคุกเข่า: โทนผิวสีเข้ม',
    '🧎🏻‍♀' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีขาว',
    '🧎🏼‍♀' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีขาวเหลือง',
    '🧎🏽‍♀' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีเหลือง',
    '🧎🏾‍♀' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีแทน',
    '🧎🏿‍♀' => 'ผู้หญิงกำลังคุกเข่า: โทนผิวสีเข้ม',
    '🧎🏻‍➡' => 'คนกำลังคุกเข่า: โทนผิวสีขาว หันขวา',
    '🧎🏼‍➡' => 'คนกำลังคุกเข่า: โทนผิวสีขาวเหลือง หันขวา',
    '🧎🏽‍➡' => 'คนกำลังคุกเข่า: โทนผิวสีเหลือง หันขวา',
    '🧎🏾‍➡' => 'คนกำลังคุกเข่า: โทนผิวสีแทน หันขวา',
    '🧎🏿‍➡' => 'คนกำลังคุกเข่า: โทนผิวสีเข้ม หันขวา',
    '🧑🏻‍🦯' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีขาว',
    '🧑🏼‍🦯' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🦯' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีเหลือง',
    '🧑🏾‍🦯' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีแทน',
    '🧑🏿‍🦯' => 'คนเดินถือไม้เท้านำทาง: โทนผิวสีเข้ม',
    '👨🏻‍🦯' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีขาว',
    '👨🏼‍🦯' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีขาวเหลือง',
    '👨🏽‍🦯' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีเหลือง',
    '👨🏾‍🦯' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีแทน',
    '👨🏿‍🦯' => 'ผู้ชายเดินถือไม้เท้านำทาง: โทนผิวสีเข้ม',
    '👩🏻‍🦯' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีขาว',
    '👩🏼‍🦯' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีขาวเหลือง',
    '👩🏽‍🦯' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีเหลือง',
    '👩🏾‍🦯' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีแทน',
    '👩🏿‍🦯' => 'ผู้หญิงเดินถือไม้เท้านำทาง: โทนผิวสีเข้ม',
    '🧑🏻‍🦼' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาว',
    '🧑🏼‍🦼' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🦼' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเหลือง',
    '🧑🏾‍🦼' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีแทน',
    '🧑🏿‍🦼' => 'คนนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเข้ม',
    '👨🏻‍🦼' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาว',
    '👨🏼‍🦼' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาวเหลือง',
    '👨🏽‍🦼' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเหลือง',
    '👨🏾‍🦼' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีแทน',
    '👨🏿‍🦼' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเข้ม',
    '👩🏻‍🦼' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาว',
    '👩🏼‍🦼' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีขาวเหลือง',
    '👩🏽‍🦼' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเหลือง',
    '👩🏾‍🦼' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีแทน',
    '👩🏿‍🦼' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า: โทนผิวสีเข้ม',
    '🧑🏻‍🦽' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีขาว',
    '🧑🏼‍🦽' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีขาวเหลือง',
    '🧑🏽‍🦽' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีเหลือง',
    '🧑🏾‍🦽' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีแทน',
    '🧑🏿‍🦽' => 'คนนั่งวีลแชร์ธรรมดา: โทนผิวสีเข้ม',
    '👨🏻‍🦽' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีขาว',
    '👨🏼‍🦽' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีขาวเหลือง',
    '👨🏽‍🦽' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีเหลือง',
    '👨🏾‍🦽' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีแทน',
    '👨🏿‍🦽' => 'ผู้ชายนั่งวีลแชร์ธรรมดา: โทนผิวสีเข้ม',
    '👩🏻‍🦽' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีขาว',
    '👩🏼‍🦽' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีขาวเหลือง',
    '👩🏽‍🦽' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีเหลือง',
    '👩🏾‍🦽' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีแทน',
    '👩🏿‍🦽' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา: โทนผิวสีเข้ม',
    '🏃🏻‍♂' => 'ผู้ชายวิ่ง: โทนผิวสีขาว',
    '🏃🏼‍♂' => 'ผู้ชายวิ่ง: โทนผิวสีขาวเหลือง',
    '🏃🏽‍♂' => 'ผู้ชายวิ่ง: โทนผิวสีเหลือง',
    '🏃🏾‍♂' => 'ผู้ชายวิ่ง: โทนผิวสีแทน',
    '🏃🏿‍♂' => 'ผู้ชายวิ่ง: โทนผิวสีเข้ม',
    '🏃🏻‍♀' => 'ผู้หญิงวิ่ง: โทนผิวสีขาว',
    '🏃🏼‍♀' => 'ผู้หญิงวิ่ง: โทนผิวสีขาวเหลือง',
    '🏃🏽‍♀' => 'ผู้หญิงวิ่ง: โทนผิวสีเหลือง',
    '🏃🏾‍♀' => 'ผู้หญิงวิ่ง: โทนผิวสีแทน',
    '🏃🏿‍♀' => 'ผู้หญิงวิ่ง: โทนผิวสีเข้ม',
    '🏃🏻‍➡' => 'คนวิ่ง: โทนผิวสีขาว หันขวา',
    '🏃🏼‍➡' => 'คนวิ่ง: โทนผิวสีขาวเหลือง หันขวา',
    '🏃🏽‍➡' => 'คนวิ่ง: โทนผิวสีเหลือง หันขวา',
    '🏃🏾‍➡' => 'คนวิ่ง: โทนผิวสีแทน หันขวา',
    '🏃🏿‍➡' => 'คนวิ่ง: โทนผิวสีเข้ม หันขวา',
    '👯🏻‍♀' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาว',
    '👯🏼‍♀' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีขาวเหลือง',
    '👯🏽‍♀' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเหลือง',
    '👯🏾‍♀' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีแทน',
    '👯🏿‍♀' => 'ผู้หญิงในชุดหูกระต่าย: โทนผิวสีเข้ม',
    '👯🏻‍♂' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาว',
    '👯🏼‍♂' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีขาวเหลือง',
    '👯🏽‍♂' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเหลือง',
    '👯🏾‍♂' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีแทน',
    '👯🏿‍♂' => 'ผู้ชายในชุดหูกระต่าย: โทนผิวสีเข้ม',
    '🧖🏻‍♂' => 'ผู้ชายในห้องอบไอน้ำ: โทนผิวสีขาว',
    '🧖🏼‍♂' => 'ผู้ชายในห้องอบไอน้ำ: โทนผิวสีขาวเหลือง',
    '🧖🏽‍♂' => 'ผู้ชายในห้องอบไอน้ำ: โทนผิวสีเหลือง',
    '🧖🏾‍♂' => 'ผู้ชายในห้องอบไอน้ำ: โทนผิวสีแทน',
    '🧖🏿‍♂' => 'ผู้ชายในห้องอบไอน้ำ: โทนผิวสีเข้ม',
    '🧖🏻‍♀' => 'ผู้หญิงในห้องอบไอน้ำ: โทนผิวสีขาว',
    '🧖🏼‍♀' => 'ผู้หญิงในห้องอบไอน้ำ: โทนผิวสีขาวเหลือง',
    '🧖🏽‍♀' => 'ผู้หญิงในห้องอบไอน้ำ: โทนผิวสีเหลือง',
    '🧖🏾‍♀' => 'ผู้หญิงในห้องอบไอน้ำ: โทนผิวสีแทน',
    '🧖🏿‍♀' => 'ผู้หญิงในห้องอบไอน้ำ: โทนผิวสีเข้ม',
    '🧗🏻‍♂' => 'ผู้ชายไต่เขา: โทนผิวสีขาว',
    '🧗🏼‍♂' => 'ผู้ชายไต่เขา: โทนผิวสีขาวเหลือง',
    '🧗🏽‍♂' => 'ผู้ชายไต่เขา: โทนผิวสีเหลือง',
    '🧗🏾‍♂' => 'ผู้ชายไต่เขา: โทนผิวสีแทน',
    '🧗🏿‍♂' => 'ผู้ชายไต่เขา: โทนผิวสีเข้ม',
    '🧗🏻‍♀' => 'ผู้หญิงไต่เขา: โทนผิวสีขาว',
    '🧗🏼‍♀' => 'ผู้หญิงไต่เขา: โทนผิวสีขาวเหลือง',
    '🧗🏽‍♀' => 'ผู้หญิงไต่เขา: โทนผิวสีเหลือง',
    '🧗🏾‍♀' => 'ผู้หญิงไต่เขา: โทนผิวสีแทน',
    '🧗🏿‍♀' => 'ผู้หญิงไต่เขา: โทนผิวสีเข้ม',
    '🏌🏻‍♂' => 'ผู้ชายตีกอล์ฟ: โทนผิวสีขาว',
    '🏌🏼‍♂' => 'ผู้ชายตีกอล์ฟ: โทนผิวสีขาวเหลือง',
    '🏌🏽‍♂' => 'ผู้ชายตีกอล์ฟ: โทนผิวสีเหลือง',
    '🏌🏾‍♂' => 'ผู้ชายตีกอล์ฟ: โทนผิวสีแทน',
    '🏌🏿‍♂' => 'ผู้ชายตีกอล์ฟ: โทนผิวสีเข้ม',
    '🏌🏻‍♀' => 'ผู้หญิงตีกอล์ฟ: โทนผิวสีขาว',
    '🏌🏼‍♀' => 'ผู้หญิงตีกอล์ฟ: โทนผิวสีขาวเหลือง',
    '🏌🏽‍♀' => 'ผู้หญิงตีกอล์ฟ: โทนผิวสีเหลือง',
    '🏌🏾‍♀' => 'ผู้หญิงตีกอล์ฟ: โทนผิวสีแทน',
    '🏌🏿‍♀' => 'ผู้หญิงตีกอล์ฟ: โทนผิวสีเข้ม',
    '🏄🏻‍♂' => 'ผู้ชายโต้คลื่น: โทนผิวสีขาว',
    '🏄🏼‍♂' => 'ผู้ชายโต้คลื่น: โทนผิวสีขาวเหลือง',
    '🏄🏽‍♂' => 'ผู้ชายโต้คลื่น: โทนผิวสีเหลือง',
    '🏄🏾‍♂' => 'ผู้ชายโต้คลื่น: โทนผิวสีแทน',
    '🏄🏿‍♂' => 'ผู้ชายโต้คลื่น: โทนผิวสีเข้ม',
    '🏄🏻‍♀' => 'ผู้หญิงโต้คลื่น: โทนผิวสีขาว',
    '🏄🏼‍♀' => 'ผู้หญิงโต้คลื่น: โทนผิวสีขาวเหลือง',
    '🏄🏽‍♀' => 'ผู้หญิงโต้คลื่น: โทนผิวสีเหลือง',
    '🏄🏾‍♀' => 'ผู้หญิงโต้คลื่น: โทนผิวสีแทน',
    '🏄🏿‍♀' => 'ผู้หญิงโต้คลื่น: โทนผิวสีเข้ม',
    '🚣🏻‍♂' => 'ผู้ชายพายเรือ: โทนผิวสีขาว',
    '🚣🏼‍♂' => 'ผู้ชายพายเรือ: โทนผิวสีขาวเหลือง',
    '🚣🏽‍♂' => 'ผู้ชายพายเรือ: โทนผิวสีเหลือง',
    '🚣🏾‍♂' => 'ผู้ชายพายเรือ: โทนผิวสีแทน',
    '🚣🏿‍♂' => 'ผู้ชายพายเรือ: โทนผิวสีเข้ม',
    '🚣🏻‍♀' => 'ผู้หญิงพายเรือ: โทนผิวสีขาว',
    '🚣🏼‍♀' => 'ผู้หญิงพายเรือ: โทนผิวสีขาวเหลือง',
    '🚣🏽‍♀' => 'ผู้หญิงพายเรือ: โทนผิวสีเหลือง',
    '🚣🏾‍♀' => 'ผู้หญิงพายเรือ: โทนผิวสีแทน',
    '🚣🏿‍♀' => 'ผู้หญิงพายเรือ: โทนผิวสีเข้ม',
    '🏊🏻‍♂' => 'ผู้ชายว่ายน้ำ: โทนผิวสีขาว',
    '🏊🏼‍♂' => 'ผู้ชายว่ายน้ำ: โทนผิวสีขาวเหลือง',
    '🏊🏽‍♂' => 'ผู้ชายว่ายน้ำ: โทนผิวสีเหลือง',
    '🏊🏾‍♂' => 'ผู้ชายว่ายน้ำ: โทนผิวสีแทน',
    '🏊🏿‍♂' => 'ผู้ชายว่ายน้ำ: โทนผิวสีเข้ม',
    '🏊🏻‍♀' => 'ผู้หญิงว่ายน้ำ: โทนผิวสีขาว',
    '🏊🏼‍♀' => 'ผู้หญิงว่ายน้ำ: โทนผิวสีขาวเหลือง',
    '🏊🏽‍♀' => 'ผู้หญิงว่ายน้ำ: โทนผิวสีเหลือง',
    '🏊🏾‍♀' => 'ผู้หญิงว่ายน้ำ: โทนผิวสีแทน',
    '🏊🏿‍♀' => 'ผู้หญิงว่ายน้ำ: โทนผิวสีเข้ม',
    '⛹🏻‍♂' => 'ผู้ชายเล่นบอล: โทนผิวสีขาว',
    '⛹🏼‍♂' => 'ผู้ชายเล่นบอล: โทนผิวสีขาวเหลือง',
    '⛹🏽‍♂' => 'ผู้ชายเล่นบอล: โทนผิวสีเหลือง',
    '⛹🏾‍♂' => 'ผู้ชายเล่นบอล: โทนผิวสีแทน',
    '⛹🏿‍♂' => 'ผู้ชายเล่นบอล: โทนผิวสีเข้ม',
    '⛹🏻‍♀' => 'ผู้หญิงเล่นบอล: โทนผิวสีขาว',
    '⛹🏼‍♀' => 'ผู้หญิงเล่นบอล: โทนผิวสีขาวเหลือง',
    '⛹🏽‍♀' => 'ผู้หญิงเล่นบอล: โทนผิวสีเหลือง',
    '⛹🏾‍♀' => 'ผู้หญิงเล่นบอล: โทนผิวสีแทน',
    '⛹🏿‍♀' => 'ผู้หญิงเล่นบอล: โทนผิวสีเข้ม',
    '🏋🏻‍♂' => 'ผู้ชายยกน้ำหนัก: โทนผิวสีขาว',
    '🏋🏼‍♂' => 'ผู้ชายยกน้ำหนัก: โทนผิวสีขาวเหลือง',
    '🏋🏽‍♂' => 'ผู้ชายยกน้ำหนัก: โทนผิวสีเหลือง',
    '🏋🏾‍♂' => 'ผู้ชายยกน้ำหนัก: โทนผิวสีแทน',
    '🏋🏿‍♂' => 'ผู้ชายยกน้ำหนัก: โทนผิวสีเข้ม',
    '🏋🏻‍♀' => 'ผู้หญิงยกน้ำหนัก: โทนผิวสีขาว',
    '🏋🏼‍♀' => 'ผู้หญิงยกน้ำหนัก: โทนผิวสีขาวเหลือง',
    '🏋🏽‍♀' => 'ผู้หญิงยกน้ำหนัก: โทนผิวสีเหลือง',
    '🏋🏾‍♀' => 'ผู้หญิงยกน้ำหนัก: โทนผิวสีแทน',
    '🏋🏿‍♀' => 'ผู้หญิงยกน้ำหนัก: โทนผิวสีเข้ม',
    '🚴🏻‍♂' => 'ผู้ชายปั่นจักรยาน: โทนผิวสีขาว',
    '🚴🏼‍♂' => 'ผู้ชายปั่นจักรยาน: โทนผิวสีขาวเหลือง',
    '🚴🏽‍♂' => 'ผู้ชายปั่นจักรยาน: โทนผิวสีเหลือง',
    '🚴🏾‍♂' => 'ผู้ชายปั่นจักรยาน: โทนผิวสีแทน',
    '🚴🏿‍♂' => 'ผู้ชายปั่นจักรยาน: โทนผิวสีเข้ม',
    '🚴🏻‍♀' => 'ผู้หญิงปั่นจักรยาน: โทนผิวสีขาว',
    '🚴🏼‍♀' => 'ผู้หญิงปั่นจักรยาน: โทนผิวสีขาวเหลือง',
    '🚴🏽‍♀' => 'ผู้หญิงปั่นจักรยาน: โทนผิวสีเหลือง',
    '🚴🏾‍♀' => 'ผู้หญิงปั่นจักรยาน: โทนผิวสีแทน',
    '🚴🏿‍♀' => 'ผู้หญิงปั่นจักรยาน: โทนผิวสีเข้ม',
    '🚵🏻‍♂' => 'ผู้ชายปั่นจักรยานเสือภูเขา: โทนผิวสีขาว',
    '🚵🏼‍♂' => 'ผู้ชายปั่นจักรยานเสือภูเขา: โทนผิวสีขาวเหลือง',
    '🚵🏽‍♂' => 'ผู้ชายปั่นจักรยานเสือภูเขา: โทนผิวสีเหลือง',
    '🚵🏾‍♂' => 'ผู้ชายปั่นจักรยานเสือภูเขา: โทนผิวสีแทน',
    '🚵🏿‍♂' => 'ผู้ชายปั่นจักรยานเสือภูเขา: โทนผิวสีเข้ม',
    '🚵🏻‍♀' => 'ผู้หญิงปั่นจักรยานเสือภูเขา: โทนผิวสีขาว',
    '🚵🏼‍♀' => 'ผู้หญิงปั่นจักรยานเสือภูเขา: โทนผิวสีขาวเหลือง',
    '🚵🏽‍♀' => 'ผู้หญิงปั่นจักรยานเสือภูเขา: โทนผิวสีเหลือง',
    '🚵🏾‍♀' => 'ผู้หญิงปั่นจักรยานเสือภูเขา: โทนผิวสีแทน',
    '🚵🏿‍♀' => 'ผู้หญิงปั่นจักรยานเสือภูเขา: โทนผิวสีเข้ม',
    '🤸🏻‍♂' => 'ผู้ชายตีลังกา: โทนผิวสีขาว',
    '🤸🏼‍♂' => 'ผู้ชายตีลังกา: โทนผิวสีขาวเหลือง',
    '🤸🏽‍♂' => 'ผู้ชายตีลังกา: โทนผิวสีเหลือง',
    '🤸🏾‍♂' => 'ผู้ชายตีลังกา: โทนผิวสีแทน',
    '🤸🏿‍♂' => 'ผู้ชายตีลังกา: โทนผิวสีเข้ม',
    '🤸🏻‍♀' => 'ผู้หญิงตีลังกา: โทนผิวสีขาว',
    '🤸🏼‍♀' => 'ผู้หญิงตีลังกา: โทนผิวสีขาวเหลือง',
    '🤸🏽‍♀' => 'ผู้หญิงตีลังกา: โทนผิวสีเหลือง',
    '🤸🏾‍♀' => 'ผู้หญิงตีลังกา: โทนผิวสีแทน',
    '🤸🏿‍♀' => 'ผู้หญิงตีลังกา: โทนผิวสีเข้ม',
    '🤼🏻‍♀' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาว',
    '🤼🏼‍♀' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง',
    '🤼🏽‍♀' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเหลือง',
    '🤼🏾‍♀' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีแทน',
    '🤼🏿‍♀' => 'ผู้หญิงเล่นมวยปล้ำ: โทนผิวสีเข้ม',
    '🤼🏻‍♂' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาว',
    '🤼🏼‍♂' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีขาวเหลือง',
    '🤼🏽‍♂' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเหลือง',
    '🤼🏾‍♂' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีแทน',
    '🤼🏿‍♂' => 'ผู้ชายเล่นมวยปล้ำ: โทนผิวสีเข้ม',
    '🤽🏻‍♂' => 'ผู้ชายเล่นโปโลน้ำ: โทนผิวสีขาว',
    '🤽🏼‍♂' => 'ผู้ชายเล่นโปโลน้ำ: โทนผิวสีขาวเหลือง',
    '🤽🏽‍♂' => 'ผู้ชายเล่นโปโลน้ำ: โทนผิวสีเหลือง',
    '🤽🏾‍♂' => 'ผู้ชายเล่นโปโลน้ำ: โทนผิวสีแทน',
    '🤽🏿‍♂' => 'ผู้ชายเล่นโปโลน้ำ: โทนผิวสีเข้ม',
    '🤽🏻‍♀' => 'ผู้หญิงเล่นโปโลน้ำ: โทนผิวสีขาว',
    '🤽🏼‍♀' => 'ผู้หญิงเล่นโปโลน้ำ: โทนผิวสีขาวเหลือง',
    '🤽🏽‍♀' => 'ผู้หญิงเล่นโปโลน้ำ: โทนผิวสีเหลือง',
    '🤽🏾‍♀' => 'ผู้หญิงเล่นโปโลน้ำ: โทนผิวสีแทน',
    '🤽🏿‍♀' => 'ผู้หญิงเล่นโปโลน้ำ: โทนผิวสีเข้ม',
    '🤾🏻‍♂' => 'ผู้ชายเล่นแฮนด์บอล: โทนผิวสีขาว',
    '🤾🏼‍♂' => 'ผู้ชายเล่นแฮนด์บอล: โทนผิวสีขาวเหลือง',
    '🤾🏽‍♂' => 'ผู้ชายเล่นแฮนด์บอล: โทนผิวสีเหลือง',
    '🤾🏾‍♂' => 'ผู้ชายเล่นแฮนด์บอล: โทนผิวสีแทน',
    '🤾🏿‍♂' => 'ผู้ชายเล่นแฮนด์บอล: โทนผิวสีเข้ม',
    '🤾🏻‍♀' => 'ผู้หญิงเล่นแฮนด์บอล: โทนผิวสีขาว',
    '🤾🏼‍♀' => 'ผู้หญิงเล่นแฮนด์บอล: โทนผิวสีขาวเหลือง',
    '🤾🏽‍♀' => 'ผู้หญิงเล่นแฮนด์บอล: โทนผิวสีเหลือง',
    '🤾🏾‍♀' => 'ผู้หญิงเล่นแฮนด์บอล: โทนผิวสีแทน',
    '🤾🏿‍♀' => 'ผู้หญิงเล่นแฮนด์บอล: โทนผิวสีเข้ม',
    '🤹🏻‍♂' => 'ผู้ชายเล่นจั๊กกลิ้ง: โทนผิวสีขาว',
    '🤹🏼‍♂' => 'ผู้ชายเล่นจั๊กกลิ้ง: โทนผิวสีขาวเหลือง',
    '🤹🏽‍♂' => 'ผู้ชายเล่นจั๊กกลิ้ง: โทนผิวสีเหลือง',
    '🤹🏾‍♂' => 'ผู้ชายเล่นจั๊กกลิ้ง: โทนผิวสีแทน',
    '🤹🏿‍♂' => 'ผู้ชายเล่นจั๊กกลิ้ง: โทนผิวสีเข้ม',
    '🤹🏻‍♀' => 'ผู้หญิงเล่นจั๊กกลิ้ง: โทนผิวสีขาว',
    '🤹🏼‍♀' => 'ผู้หญิงเล่นจั๊กกลิ้ง: โทนผิวสีขาวเหลือง',
    '🤹🏽‍♀' => 'ผู้หญิงเล่นจั๊กกลิ้ง: โทนผิวสีเหลือง',
    '🤹🏾‍♀' => 'ผู้หญิงเล่นจั๊กกลิ้ง: โทนผิวสีแทน',
    '🤹🏿‍♀' => 'ผู้หญิงเล่นจั๊กกลิ้ง: โทนผิวสีเข้ม',
    '🧘🏻‍♂' => 'ผู้ชายนั่งสมาธิ: โทนผิวสีขาว',
    '🧘🏼‍♂' => 'ผู้ชายนั่งสมาธิ: โทนผิวสีขาวเหลือง',
    '🧘🏽‍♂' => 'ผู้ชายนั่งสมาธิ: โทนผิวสีเหลือง',
    '🧘🏾‍♂' => 'ผู้ชายนั่งสมาธิ: โทนผิวสีแทน',
    '🧘🏿‍♂' => 'ผู้ชายนั่งสมาธิ: โทนผิวสีเข้ม',
    '🧘🏻‍♀' => 'ผู้หญิงนั่งสมาธิ: โทนผิวสีขาว',
    '🧘🏼‍♀' => 'ผู้หญิงนั่งสมาธิ: โทนผิวสีขาวเหลือง',
    '🧘🏽‍♀' => 'ผู้หญิงนั่งสมาธิ: โทนผิวสีเหลือง',
    '🧘🏾‍♀' => 'ผู้หญิงนั่งสมาธิ: โทนผิวสีแทน',
    '🧘🏿‍♀' => 'ผู้หญิงนั่งสมาธิ: โทนผิวสีเข้ม',
    '🧑‍🦰' => 'คน: ผมแดง',
    '🧑‍🦱' => 'คน: ผมหยิก',
    '🧑‍🦳' => 'คน: ผมขาว',
    '🧑‍🦲' => 'คน: หัวล้าน',
    '👨‍🦰' => 'ผู้ชาย: ผมแดง',
    '👨‍🦱' => 'ผู้ชาย: ผมหยิก',
    '👨‍🦳' => 'ผู้ชาย: ผมขาว',
    '👨‍🦲' => 'ผู้ชาย: หัวล้าน',
    '👩‍🦰' => 'ผู้หญิง: ผมแดง',
    '👩‍🦱' => 'ผู้หญิง: ผมหยิก',
    '👩‍🦳' => 'ผู้หญิง: ผมขาว',
    '👩‍🦲' => 'ผู้หญิง: หัวล้าน',
    '🚶‍➡' => 'คนเดิน: หันขวา',
    '🧎‍➡' => 'คนกำลังคุกเข่า: หันขวา',
    '🏃‍➡' => 'คนวิ่ง: หันขวา',
    '👨‍👦' => 'ครอบครัว: ผู้ชาย เด็กชาย',
    '👨‍👧' => 'ครอบครัว: ผู้ชาย เด็กหญิง',
    '👩‍👦' => 'ครอบครัว: ผู้หญิง เด็กชาย',
    '👩‍👧' => 'ครอบครัว: ผู้หญิง เด็กหญิง',
    '😶‍🌫' => 'หน้าในหมู่เมฆ',
    '😮‍💨' => 'หน้าหายใจออก',
    '🙂‍↕' => 'พยักหน้า',
    '😵‍💫' => 'หน้าตาลาย',
    '❤‍🔥' => 'ไฟไหม้หัวใจ',
    '❤‍🩹' => 'หัวใจที่มีการซ่อมแซม',
    '👁‍🗨' => 'ตาในลูกโป่งคำพูด',
    '🧔‍♂' => 'ชายมีเครา',
    '👱‍♂' => 'ผู้ชายผมทอง',
    '🧔‍♀' => 'ผู้หญิงมีเครา',
    '👱‍♀' => 'ผู้หญิงผมทอง',
    '🙍‍♂' => 'ผู้ชายหน้าบึ้ง',
    '🙍‍♀' => 'ผู้หญิงหน้าบึ้ง',
    '🙎‍♂' => 'ผู้ชายโกรธ',
    '🙎‍♀' => 'ผู้หญิงโกรธ',
    '🙅‍♂' => 'ผู้ชายทำท่าไม่โอเค',
    '🙅‍♀' => 'ผู้หญิงทำท่าไม่โอเค',
    '🙆‍♂' => 'ผู้ชายทำท่าโอเค',
    '🙆‍♀' => 'ผู้หญิงทำท่าโอเค',
    '💁‍♂' => 'ผู้ชายแบมือ',
    '💁‍♀' => 'ผู้หญิงแบมือ',
    '🙋‍♂' => 'ผู้ชายยกมือ',
    '🙋‍♀' => 'ผู้หญิงยกมือ',
    '🧏‍♂' => 'ผู้ชายหูหนวก',
    '🧏‍♀' => 'ผู้หญิงหูหนวก',
    '🙇‍♂' => 'ผู้ชายหมอบคำนับ',
    '🙇‍♀' => 'ผู้หญิงหมอบคำนับ',
    '🤦‍♂' => 'ผู้ชายเอามือก่ายหน้าผาก',
    '🤦‍♀' => 'ผู้หญิงเอามือก่ายหน้าผาก',
    '🤷‍♂' => 'ผู้ชายยักไหล่',
    '🤷‍♀' => 'ผู้หญิงยักไหล่',
    '🧑‍⚕' => 'หมอ',
    '👨‍⚕' => 'หมอชาย',
    '👩‍⚕' => 'หมอหญิง',
    '🧑‍🎓' => 'บัณฑิต',
    '👨‍🎓' => 'นักเรียนชาย',
    '👩‍🎓' => 'นักเรียนหญิง',
    '🧑‍🏫' => 'ครู',
    '👨‍🏫' => 'ครูชาย',
    '👩‍🏫' => 'ครูหญิง',
    '🧑‍⚖' => 'ผู้พิพากษา',
    '👨‍⚖' => 'ผู้พิพากษาชาย',
    '👩‍⚖' => 'ผู้พิพากษาหญิง',
    '🧑‍🌾' => 'ชาวนา',
    '👨‍🌾' => 'ชาวนาชาย',
    '👩‍🌾' => 'ชาวนาหญิง',
    '🧑‍🍳' => 'กุ๊ก',
    '👨‍🍳' => 'พ่อครัว',
    '👩‍🍳' => 'แม่ครัว',
    '🧑‍🔧' => 'ช่างกล',
    '👨‍🔧' => 'ช่างซ่อมชาย',
    '👩‍🔧' => 'ช่างซ่อมหญิง',
    '🧑‍🏭' => 'พนักงานโรงงาน',
    '👨‍🏭' => 'พนักงานโรงงานชาย',
    '👩‍🏭' => 'พนักงานโรงงานหญิง',
    '🧑‍💼' => 'พนักงานออฟฟิศ',
    '👨‍💼' => 'พนักงานบริษัทชาย',
    '👩‍💼' => 'พนักงานบริษัทหญิง',
    '🧑‍🔬' => 'นักวิทยาศาสตร์',
    '👨‍🔬' => 'นักวิทยาศาสตร์ชาย',
    '👩‍🔬' => 'นักวิทยาศาสตร์หญิง',
    '🧑‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยี',
    '👨‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีชาย',
    '👩‍💻' => 'ผู้เชี่ยวชาญด้านเทคโนโลยีหญิง',
    '🧑‍🎤' => 'นักร้อง',
    '👨‍🎤' => 'นักร้องชาย',
    '👩‍🎤' => 'นักร้องหญิง',
    '🧑‍🎨' => 'ศิลปิน',
    '👨‍🎨' => 'ศิลปินชาย',
    '👩‍🎨' => 'ศิลปินหญิง',
    '🧑‍✈' => 'นักบิน',
    '👨‍✈' => 'นักบินชาย',
    '👩‍✈' => 'นักบินหญิง',
    '🧑‍🚀' => 'นักบินอวกาศ',
    '👨‍🚀' => 'นักบินอวกาศชาย',
    '👩‍🚀' => 'นักบินอวกาศหญิง',
    '🧑‍🚒' => 'พนักงานดับเพลิง',
    '👨‍🚒' => 'พนักงานดับเพลิงชาย',
    '👩‍🚒' => 'พนักงานดับเพลิงหญิง',
    '👮‍♂' => 'ตำรวจชาย',
    '👮‍♀' => 'ตำรวจหญิง',
    '🕵‍♂' => 'นักสืบชาย',
    '🕵‍♀' => 'นักสืบหญิง',
    '💂‍♂' => 'องครักษ์ชาย',
    '💂‍♀' => 'องครักษ์หญิง',
    '👷‍♂' => 'พนักงานก่อสร้างชาย',
    '👷‍♀' => 'พนักงานก่อสร้างหญิง',
    '👳‍♂' => 'ผู้ชายโพกหัว',
    '👳‍♀' => 'ผู้หญิงโพกหัว',
    '🤵‍♂' => 'ผู้ชายใส่ทักซิโด้',
    '🤵‍♀' => 'ผู้หญิงใส่ทักซิโด้',
    '👰‍♂' => 'ผู้ชายที่มีผ้าคลุมหน้า',
    '👰‍♀' => 'ผู้หญิงที่มีผ้าคลุมหน้า',
    '👩‍🍼' => 'ผู้หญิงให้นมลูก',
    '👨‍🍼' => 'ผู้ชายให้นมลูก',
    '🧑‍🍼' => 'คนให้นมลูก',
    '🧑‍🎄' => 'ซานตาคลอส',
    '🦸‍♂' => 'พระเอก',
    '🦸‍♀' => 'ยอดหญิง',
    '🦹‍♂' => 'ตัวโกง',
    '🦹‍♀' => 'นางร้าย',
    '🧙‍♂' => 'พ่อมด',
    '🧙‍♀' => 'แม่มด',
    '🧚‍♂' => 'เทพบุตร',
    '🧚‍♀' => 'เทพธิดา',
    '🧛‍♂' => 'แวมไพร์ผู้ชาย',
    '🧛‍♀' => 'แวมไพร์ผู้หญิง',
    '🧜‍♂' => 'เงือกชาย',
    '🧜‍♀' => 'เงือก',
    '🧝‍♂' => 'เอลฟ์ผู้ชาย',
    '🧝‍♀' => 'เอลฟ์ผู้หญิง',
    '🧞‍♂' => 'ยักษ์จีนี่ชาย',
    '🧞‍♀' => 'ยักษ์จีนี่หญิง',
    '🧟‍♂' => 'ซอมบี้ผู้ชาย',
    '🧟‍♀' => 'ซอมบี้ผู้หญิง',
    '💆‍♂' => 'ผู้ชายกำลังนวดหน้า',
    '💆‍♀' => 'ผู้หญิงกำลังนวดหน้า',
    '💇‍♂' => 'ผู้ชายกำลังตัดผม',
    '💇‍♀' => 'ผู้หญิงกำลังตัดผม',
    '🚶‍♂' => 'ผู้ชายเดิน',
    '🚶‍♀' => 'ผู้หญิงเดิน',
    '🧍‍♂' => 'ผู้ชายกำลังยืน',
    '🧍‍♀' => 'ผู้หญิงกำลังยืน',
    '🧎‍♂' => 'ผู้ชายกำลังคุกเข่า',
    '🧎‍♀' => 'ผู้หญิงกำลังคุกเข่า',
    '🧑‍🦯' => 'คนเดินถือไม้เท้านำทาง',
    '👨‍🦯' => 'ผู้ชายเดินถือไม้เท้านำทาง',
    '👩‍🦯' => 'ผู้หญิงเดินถือไม้เท้านำทาง',
    '🧑‍🦼' => 'คนนั่งวีลแชร์ไฟฟ้า',
    '👨‍🦼' => 'ผู้ชายนั่งวีลแชร์ไฟฟ้า',
    '👩‍🦼' => 'ผู้หญิงนั่งวีลแชร์ไฟฟ้า',
    '🧑‍🦽' => 'คนนั่งวีลแชร์ธรรมดา',
    '👨‍🦽' => 'ผู้ชายนั่งวีลแชร์ธรรมดา',
    '👩‍🦽' => 'ผู้หญิงนั่งวีลแชร์ธรรมดา',
    '🏃‍♂' => 'ผู้ชายวิ่ง',
    '🏃‍♀' => 'ผู้หญิงวิ่ง',
    '🧑‍🩰' => 'นักบัลเล่ต์',
    '👯‍♂' => 'ผู้ชายในชุดหูกระต่าย',
    '👯‍♀' => 'ผู้หญิงในชุดหูกระต่าย',
    '🧖‍♂' => 'ผู้ชายในห้องอบไอน้ำ',
    '🧖‍♀' => 'ผู้หญิงในห้องอบไอน้ำ',
    '🧗‍♂' => 'ผู้ชายไต่เขา',
    '🧗‍♀' => 'ผู้หญิงไต่เขา',
    '🏌‍♂' => 'ผู้ชายตีกอล์ฟ',
    '🏌‍♀' => 'ผู้หญิงตีกอล์ฟ',
    '🏄‍♂' => 'ผู้ชายโต้คลื่น',
    '🏄‍♀' => 'ผู้หญิงโต้คลื่น',
    '🚣‍♂' => 'ผู้ชายพายเรือ',
    '🚣‍♀' => 'ผู้หญิงพายเรือ',
    '🏊‍♂' => 'ผู้ชายว่ายน้ำ',
    '🏊‍♀' => 'ผู้หญิงว่ายน้ำ',
    '⛹‍♂' => 'ผู้ชายเล่นบอล',
    '⛹‍♀' => 'ผู้หญิงเล่นบอล',
    '🏋‍♂' => 'ผู้ชายยกน้ำหนัก',
    '🏋‍♀' => 'ผู้หญิงยกน้ำหนัก',
    '🚴‍♂' => 'ผู้ชายปั่นจักรยาน',
    '🚴‍♀' => 'ผู้หญิงปั่นจักรยาน',
    '🚵‍♂' => 'ผู้ชายปั่นจักรยานเสือภูเขา',
    '🚵‍♀' => 'ผู้หญิงปั่นจักรยานเสือภูเขา',
    '🤸‍♂' => 'ผู้ชายตีลังกา',
    '🤸‍♀' => 'ผู้หญิงตีลังกา',
    '🤼‍♂' => 'ผู้ชายเล่นมวยปล้ำ',
    '🤼‍♀' => 'ผู้หญิงเล่นมวยปล้ำ',
    '🤽‍♂' => 'ผู้ชายเล่นโปโลน้ำ',
    '🤽‍♀' => 'ผู้หญิงเล่นโปโลน้ำ',
    '🤾‍♂' => 'ผู้ชายเล่นแฮนด์บอล',
    '🤾‍♀' => 'ผู้หญิงเล่นแฮนด์บอล',
    '🤹‍♂' => 'ผู้ชายเล่นจั๊กกลิ้ง',
    '🤹‍♀' => 'ผู้หญิงเล่นจั๊กกลิ้ง',
    '🧘‍♂' => 'ผู้ชายนั่งสมาธิ',
    '🧘‍♀' => 'ผู้หญิงนั่งสมาธิ',
    '🧑‍🧒' => 'ครอบครัว: ผู้ใหญ่, เด็ก',
    '🐕‍🦺' => 'สุนัขบริการ',
    '🐈‍⬛' => 'แมวดำ',
    '🐻‍❄' => 'หมีขั้วโลก',
    '🐦‍⬛' => 'นกสีดำ',
    '🐦‍🔥' => 'นกฟินิกซ์',
    '🍋‍🟩' => 'มะนาว',
    '🍄‍🟫' => 'เห็ดสีน้ำตาล',
    '⛓‍💥' => 'โซ่ขาด',
    '🏳‍🌈' => 'ธงสีรุ้ง',
    '🏳‍⚧' => 'ธงคนข้ามเพศ',
    '🏴‍☠' => 'ธงโจรสลัด',
    '👋🏻' => 'โบกมือ: โทนผิวสีขาว',
    '👋🏼' => 'โบกมือ: โทนผิวสีขาวเหลือง',
    '👋🏽' => 'โบกมือ: โทนผิวสีเหลือง',
    '👋🏾' => 'โบกมือ: โทนผิวสีแทน',
    '👋🏿' => 'โบกมือ: โทนผิวสีเข้ม',
    '🤚🏻' => 'ยกมือ: โทนผิวสีขาว',
    '🤚🏼' => 'ยกมือ: โทนผิวสีขาวเหลือง',
    '🤚🏽' => 'ยกมือ: โทนผิวสีเหลือง',
    '🤚🏾' => 'ยกมือ: โทนผิวสีแทน',
    '🤚🏿' => 'ยกมือ: โทนผิวสีเข้ม',
    '🖐🏻' => 'ชูมือกางนิ้ว: โทนผิวสีขาว',
    '🖐🏼' => 'ชูมือกางนิ้ว: โทนผิวสีขาวเหลือง',
    '🖐🏽' => 'ชูมือกางนิ้ว: โทนผิวสีเหลือง',
    '🖐🏾' => 'ชูมือกางนิ้ว: โทนผิวสีแทน',
    '🖐🏿' => 'ชูมือกางนิ้ว: โทนผิวสีเข้ม',
    '✋🏻' => 'ตั้งฝ่ามือ: โทนผิวสีขาว',
    '✋🏼' => 'ตั้งฝ่ามือ: โทนผิวสีขาวเหลือง',
    '✋🏽' => 'ตั้งฝ่ามือ: โทนผิวสีเหลือง',
    '✋🏾' => 'ตั้งฝ่ามือ: โทนผิวสีแทน',
    '✋🏿' => 'ตั้งฝ่ามือ: โทนผิวสีเข้ม',
    '🖖🏻' => 'ชูนิ้วแบบวัลแคน: โทนผิวสีขาว',
    '🖖🏼' => 'ชูนิ้วแบบวัลแคน: โทนผิวสีขาวเหลือง',
    '🖖🏽' => 'ชูนิ้วแบบวัลแคน: โทนผิวสีเหลือง',
    '🖖🏾' => 'ชูนิ้วแบบวัลแคน: โทนผิวสีแทน',
    '🖖🏿' => 'ชูนิ้วแบบวัลแคน: โทนผิวสีเข้ม',
    '🫱🏻' => 'มือหันไปทางขวา: โทนผิวสีขาว',
    '🫱🏼' => 'มือหันไปทางขวา: โทนผิวสีขาวเหลือง',
    '🫱🏽' => 'มือหันไปทางขวา: โทนผิวสีเหลือง',
    '🫱🏾' => 'มือหันไปทางขวา: โทนผิวสีแทน',
    '🫱🏿' => 'มือหันไปทางขวา: โทนผิวสีเข้ม',
    '🫲🏻' => 'มือหันไปทางซ้าย: โทนผิวสีขาว',
    '🫲🏼' => 'มือหันไปทางซ้าย: โทนผิวสีขาวเหลือง',
    '🫲🏽' => 'มือหันไปทางซ้าย: โทนผิวสีเหลือง',
    '🫲🏾' => 'มือหันไปทางซ้าย: โทนผิวสีแทน',
    '🫲🏿' => 'มือหันไปทางซ้าย: โทนผิวสีเข้ม',
    '🫳🏻' => 'มือคว่ำฝ่ามือ: โทนผิวสีขาว',
    '🫳🏼' => 'มือคว่ำฝ่ามือ: โทนผิวสีขาวเหลือง',
    '🫳🏽' => 'มือคว่ำฝ่ามือ: โทนผิวสีเหลือง',
    '🫳🏾' => 'มือคว่ำฝ่ามือ: โทนผิวสีแทน',
    '🫳🏿' => 'มือคว่ำฝ่ามือ: โทนผิวสีเข้ม',
    '🫴🏻' => 'มือหงายฝ่ามือ: โทนผิวสีขาว',
    '🫴🏼' => 'มือหงายฝ่ามือ: โทนผิวสีขาวเหลือง',
    '🫴🏽' => 'มือหงายฝ่ามือ: โทนผิวสีเหลือง',
    '🫴🏾' => 'มือหงายฝ่ามือ: โทนผิวสีแทน',
    '🫴🏿' => 'มือหงายฝ่ามือ: โทนผิวสีเข้ม',
    '🫷🏻' => 'มือผลักไปทางซ้าย: โทนผิวสีขาว',
    '🫷🏼' => 'มือผลักไปทางซ้าย: โทนผิวสีขาวเหลือง',
    '🫷🏽' => 'มือผลักไปทางซ้าย: โทนผิวสีเหลือง',
    '🫷🏾' => 'มือผลักไปทางซ้าย: โทนผิวสีแทน',
    '🫷🏿' => 'มือผลักไปทางซ้าย: โทนผิวสีเข้ม',
    '🫸🏻' => 'มือผลักไปทางขวา: โทนผิวสีขาว',
    '🫸🏼' => 'มือผลักไปทางขวา: โทนผิวสีขาวเหลือง',
    '🫸🏽' => 'มือผลักไปทางขวา: โทนผิวสีเหลือง',
    '🫸🏾' => 'มือผลักไปทางขวา: โทนผิวสีแทน',
    '🫸🏿' => 'มือผลักไปทางขวา: โทนผิวสีเข้ม',
    '👌🏻' => 'ทำมือโอเค: โทนผิวสีขาว',
    '👌🏼' => 'ทำมือโอเค: โทนผิวสีขาวเหลือง',
    '👌🏽' => 'ทำมือโอเค: โทนผิวสีเหลือง',
    '👌🏾' => 'ทำมือโอเค: โทนผิวสีแทน',
    '👌🏿' => 'ทำมือโอเค: โทนผิวสีเข้ม',
    '🤌🏻' => 'หุบนิ้ว: โทนผิวสีขาว',
    '🤌🏼' => 'หุบนิ้ว: โทนผิวสีขาวเหลือง',
    '🤌🏽' => 'หุบนิ้ว: โทนผิวสีเหลือง',
    '🤌🏾' => 'หุบนิ้ว: โทนผิวสีแทน',
    '🤌🏿' => 'หุบนิ้ว: โทนผิวสีเข้ม',
    '🤏🏻' => 'ทำมือบีบนิ้วเข้าหากัน: โทนผิวสีขาว',
    '🤏🏼' => 'ทำมือบีบนิ้วเข้าหากัน: โทนผิวสีขาวเหลือง',
    '🤏🏽' => 'ทำมือบีบนิ้วเข้าหากัน: โทนผิวสีเหลือง',
    '🤏🏾' => 'ทำมือบีบนิ้วเข้าหากัน: โทนผิวสีแทน',
    '🤏🏿' => 'ทำมือบีบนิ้วเข้าหากัน: โทนผิวสีเข้ม',
    '✌🏻' => 'ชู 2 นิ้ว: โทนผิวสีขาว',
    '✌🏼' => 'ชู 2 นิ้ว: โทนผิวสีขาวเหลือง',
    '✌🏽' => 'ชู 2 นิ้ว: โทนผิวสีเหลือง',
    '✌🏾' => 'ชู 2 นิ้ว: โทนผิวสีแทน',
    '✌🏿' => 'ชู 2 นิ้ว: โทนผิวสีเข้ม',
    '🤞🏻' => 'นิ้วไขว้: โทนผิวสีขาว',
    '🤞🏼' => 'นิ้วไขว้: โทนผิวสีขาวเหลือง',
    '🤞🏽' => 'นิ้วไขว้: โทนผิวสีเหลือง',
    '🤞🏾' => 'นิ้วไขว้: โทนผิวสีแทน',
    '🤞🏿' => 'นิ้วไขว้: โทนผิวสีเข้ม',
    '🫰🏻' => 'นิ้วชี้ไขว้นิ้วโป้ง: โทนผิวสีขาว',
    '🫰🏼' => 'นิ้วชี้ไขว้นิ้วโป้ง: โทนผิวสีขาวเหลือง',
    '🫰🏽' => 'นิ้วชี้ไขว้นิ้วโป้ง: โทนผิวสีเหลือง',
    '🫰🏾' => 'นิ้วชี้ไขว้นิ้วโป้ง: โทนผิวสีแทน',
    '🫰🏿' => 'นิ้วชี้ไขว้นิ้วโป้ง: โทนผิวสีเข้ม',
    '🤟🏻' => 'ทำมือ ‘ฉันรักเธอ’: โทนผิวสีขาว',
    '🤟🏼' => 'ทำมือ ‘ฉันรักเธอ’: โทนผิวสีขาวเหลือง',
    '🤟🏽' => 'ทำมือ ‘ฉันรักเธอ’: โทนผิวสีเหลือง',
    '🤟🏾' => 'ทำมือ ‘ฉันรักเธอ’: โทนผิวสีแทน',
    '🤟🏿' => 'ทำมือ ‘ฉันรักเธอ’: โทนผิวสีเข้ม',
    '🤘🏻' => 'ชูนิ้วชาวร็อก: โทนผิวสีขาว',
    '🤘🏼' => 'ชูนิ้วชาวร็อก: โทนผิวสีขาวเหลือง',
    '🤘🏽' => 'ชูนิ้วชาวร็อก: โทนผิวสีเหลือง',
    '🤘🏾' => 'ชูนิ้วชาวร็อก: โทนผิวสีแทน',
    '🤘🏿' => 'ชูนิ้วชาวร็อก: โทนผิวสีเข้ม',
    '🤙🏻' => 'มือโทร: โทนผิวสีขาว',
    '🤙🏼' => 'มือโทร: โทนผิวสีขาวเหลือง',
    '🤙🏽' => 'มือโทร: โทนผิวสีเหลือง',
    '🤙🏾' => 'มือโทร: โทนผิวสีแทน',
    '🤙🏿' => 'มือโทร: โทนผิวสีเข้ม',
    '👈🏻' => 'นิ้วชี้ทางซ้าย: โทนผิวสีขาว',
    '👈🏼' => 'นิ้วชี้ทางซ้าย: โทนผิวสีขาวเหลือง',
    '👈🏽' => 'นิ้วชี้ทางซ้าย: โทนผิวสีเหลือง',
    '👈🏾' => 'นิ้วชี้ทางซ้าย: โทนผิวสีแทน',
    '👈🏿' => 'นิ้วชี้ทางซ้าย: โทนผิวสีเข้ม',
    '👉🏻' => 'นิ้วชี้ทางขวา: โทนผิวสีขาว',
    '👉🏼' => 'นิ้วชี้ทางขวา: โทนผิวสีขาวเหลือง',
    '👉🏽' => 'นิ้วชี้ทางขวา: โทนผิวสีเหลือง',
    '👉🏾' => 'นิ้วชี้ทางขวา: โทนผิวสีแทน',
    '👉🏿' => 'นิ้วชี้ทางขวา: โทนผิวสีเข้ม',
    '👆🏻' => 'หลังมือนิ้วชี้ขึ้น: โทนผิวสีขาว',
    '👆🏼' => 'หลังมือนิ้วชี้ขึ้น: โทนผิวสีขาวเหลือง',
    '👆🏽' => 'หลังมือนิ้วชี้ขึ้น: โทนผิวสีเหลือง',
    '👆🏾' => 'หลังมือนิ้วชี้ขึ้น: โทนผิวสีแทน',
    '👆🏿' => 'หลังมือนิ้วชี้ขึ้น: โทนผิวสีเข้ม',
    '🖕🏻' => 'ชูนิ้วกลาง: โทนผิวสีขาว',
    '🖕🏼' => 'ชูนิ้วกลาง: โทนผิวสีขาวเหลือง',
    '🖕🏽' => 'ชูนิ้วกลาง: โทนผิวสีเหลือง',
    '🖕🏾' => 'ชูนิ้วกลาง: โทนผิวสีแทน',
    '🖕🏿' => 'ชูนิ้วกลาง: โทนผิวสีเข้ม',
    '👇🏻' => 'นิ้วชี้ลง: โทนผิวสีขาว',
    '👇🏼' => 'นิ้วชี้ลง: โทนผิวสีขาวเหลือง',
    '👇🏽' => 'นิ้วชี้ลง: โทนผิวสีเหลือง',
    '👇🏾' => 'นิ้วชี้ลง: โทนผิวสีแทน',
    '👇🏿' => 'นิ้วชี้ลง: โทนผิวสีเข้ม',
    '☝🏻' => 'นิ้วชี้ขึ้น: โทนผิวสีขาว',
    '☝🏼' => 'นิ้วชี้ขึ้น: โทนผิวสีขาวเหลือง',
    '☝🏽' => 'นิ้วชี้ขึ้น: โทนผิวสีเหลือง',
    '☝🏾' => 'นิ้วชี้ขึ้น: โทนผิวสีแทน',
    '☝🏿' => 'นิ้วชี้ขึ้น: โทนผิวสีเข้ม',
    '🫵🏻' => 'นิ้วชี้ไปที่ผู้ดู: โทนผิวสีขาว',
    '🫵🏼' => 'นิ้วชี้ไปที่ผู้ดู: โทนผิวสีขาวเหลือง',
    '🫵🏽' => 'นิ้วชี้ไปที่ผู้ดู: โทนผิวสีเหลือง',
    '🫵🏾' => 'นิ้วชี้ไปที่ผู้ดู: โทนผิวสีแทน',
    '🫵🏿' => 'นิ้วชี้ไปที่ผู้ดู: โทนผิวสีเข้ม',
    '👍🏻' => 'ชูนิ้วโป้งขึ้น: โทนผิวสีขาว',
    '👍🏼' => 'ชูนิ้วโป้งขึ้น: โทนผิวสีขาวเหลือง',
    '👍🏽' => 'ชูนิ้วโป้งขึ้น: โทนผิวสีเหลือง',
    '👍🏾' => 'ชูนิ้วโป้งขึ้น: โทนผิวสีแทน',
    '👍🏿' => 'ชูนิ้วโป้งขึ้น: โทนผิวสีเข้ม',
    '👎🏻' => 'คว่ำนิ้วโป้งลง: โทนผิวสีขาว',
    '👎🏼' => 'คว่ำนิ้วโป้งลง: โทนผิวสีขาวเหลือง',
    '👎🏽' => 'คว่ำนิ้วโป้งลง: โทนผิวสีเหลือง',
    '👎🏾' => 'คว่ำนิ้วโป้งลง: โทนผิวสีแทน',
    '👎🏿' => 'คว่ำนิ้วโป้งลง: โทนผิวสีเข้ม',
    '✊🏻' => 'กำมือ: โทนผิวสีขาว',
    '✊🏼' => 'กำมือ: โทนผิวสีขาวเหลือง',
    '✊🏽' => 'กำมือ: โทนผิวสีเหลือง',
    '✊🏾' => 'กำมือ: โทนผิวสีแทน',
    '✊🏿' => 'กำมือ: โทนผิวสีเข้ม',
    '👊🏻' => 'กำปั้น: โทนผิวสีขาว',
    '👊🏼' => 'กำปั้น: โทนผิวสีขาวเหลือง',
    '👊🏽' => 'กำปั้น: โทนผิวสีเหลือง',
    '👊🏾' => 'กำปั้น: โทนผิวสีแทน',
    '👊🏿' => 'กำปั้น: โทนผิวสีเข้ม',
    '🤛🏻' => 'กำปั้นขวา: โทนผิวสีขาว',
    '🤛🏼' => 'กำปั้นขวา: โทนผิวสีขาวเหลือง',
    '🤛🏽' => 'กำปั้นขวา: โทนผิวสีเหลือง',
    '🤛🏾' => 'กำปั้นขวา: โทนผิวสีแทน',
    '🤛🏿' => 'กำปั้นขวา: โทนผิวสีเข้ม',
    '🤜🏻' => 'กำปั้นซ้าย: โทนผิวสีขาว',
    '🤜🏼' => 'กำปั้นซ้าย: โทนผิวสีขาวเหลือง',
    '🤜🏽' => 'กำปั้นซ้าย: โทนผิวสีเหลือง',
    '🤜🏾' => 'กำปั้นซ้าย: โทนผิวสีแทน',
    '🤜🏿' => 'กำปั้นซ้าย: โทนผิวสีเข้ม',
    '👏🏻' => 'ตบมือ: โทนผิวสีขาว',
    '👏🏼' => 'ตบมือ: โทนผิวสีขาวเหลือง',
    '👏🏽' => 'ตบมือ: โทนผิวสีเหลือง',
    '👏🏾' => 'ตบมือ: โทนผิวสีแทน',
    '👏🏿' => 'ตบมือ: โทนผิวสีเข้ม',
    '🙌🏻' => 'ชู 2 มือ: โทนผิวสีขาว',
    '🙌🏼' => 'ชู 2 มือ: โทนผิวสีขาวเหลือง',
    '🙌🏽' => 'ชู 2 มือ: โทนผิวสีเหลือง',
    '🙌🏾' => 'ชู 2 มือ: โทนผิวสีแทน',
    '🙌🏿' => 'ชู 2 มือ: โทนผิวสีเข้ม',
    '🫶🏻' => 'มือรูปหัวใจ: โทนผิวสีขาว',
    '🫶🏼' => 'มือรูปหัวใจ: โทนผิวสีขาวเหลือง',
    '🫶🏽' => 'มือรูปหัวใจ: โทนผิวสีเหลือง',
    '🫶🏾' => 'มือรูปหัวใจ: โทนผิวสีแทน',
    '🫶🏿' => 'มือรูปหัวใจ: โทนผิวสีเข้ม',
    '👐🏻' => 'แบมือ: โทนผิวสีขาว',
    '👐🏼' => 'แบมือ: โทนผิวสีขาวเหลือง',
    '👐🏽' => 'แบมือ: โทนผิวสีเหลือง',
    '👐🏾' => 'แบมือ: โทนผิวสีแทน',
    '👐🏿' => 'แบมือ: โทนผิวสีเข้ม',
    '🤲🏻' => 'แบสองมือ: โทนผิวสีขาว',
    '🤲🏼' => 'แบสองมือ: โทนผิวสีขาวเหลือง',
    '🤲🏽' => 'แบสองมือ: โทนผิวสีเหลือง',
    '🤲🏾' => 'แบสองมือ: โทนผิวสีแทน',
    '🤲🏿' => 'แบสองมือ: โทนผิวสีเข้ม',
    '🤝🏻' => 'จับมือ: โทนผิวสีขาว',
    '🤝🏼' => 'จับมือ: โทนผิวสีขาวเหลือง',
    '🤝🏽' => 'จับมือ: โทนผิวสีเหลือง',
    '🤝🏾' => 'จับมือ: โทนผิวสีแทน',
    '🤝🏿' => 'จับมือ: โทนผิวสีเข้ม',
    '🙏🏻' => 'พนมมือ: โทนผิวสีขาว',
    '🙏🏼' => 'พนมมือ: โทนผิวสีขาวเหลือง',
    '🙏🏽' => 'พนมมือ: โทนผิวสีเหลือง',
    '🙏🏾' => 'พนมมือ: โทนผิวสีแทน',
    '🙏🏿' => 'พนมมือ: โทนผิวสีเข้ม',
    '✍🏻' => 'เขียนหนังสือ: โทนผิวสีขาว',
    '✍🏼' => 'เขียนหนังสือ: โทนผิวสีขาวเหลือง',
    '✍🏽' => 'เขียนหนังสือ: โทนผิวสีเหลือง',
    '✍🏾' => 'เขียนหนังสือ: โทนผิวสีแทน',
    '✍🏿' => 'เขียนหนังสือ: โทนผิวสีเข้ม',
    '💅🏻' => 'สีทาเล็บ: โทนผิวสีขาว',
    '💅🏼' => 'สีทาเล็บ: โทนผิวสีขาวเหลือง',
    '💅🏽' => 'สีทาเล็บ: โทนผิวสีเหลือง',
    '💅🏾' => 'สีทาเล็บ: โทนผิวสีแทน',
    '💅🏿' => 'สีทาเล็บ: โทนผิวสีเข้ม',
    '🤳🏻' => 'เซลฟี่: โทนผิวสีขาว',
    '🤳🏼' => 'เซลฟี่: โทนผิวสีขาวเหลือง',
    '🤳🏽' => 'เซลฟี่: โทนผิวสีเหลือง',
    '🤳🏾' => 'เซลฟี่: โทนผิวสีแทน',
    '🤳🏿' => 'เซลฟี่: โทนผิวสีเข้ม',
    '💪🏻' => 'เบ่งกล้าม: โทนผิวสีขาว',
    '💪🏼' => 'เบ่งกล้าม: โทนผิวสีขาวเหลือง',
    '💪🏽' => 'เบ่งกล้าม: โทนผิวสีเหลือง',
    '💪🏾' => 'เบ่งกล้าม: โทนผิวสีแทน',
    '💪🏿' => 'เบ่งกล้าม: โทนผิวสีเข้ม',
    '🦵🏻' => 'ขา: โทนผิวสีขาว',
    '🦵🏼' => 'ขา: โทนผิวสีขาวเหลือง',
    '🦵🏽' => 'ขา: โทนผิวสีเหลือง',
    '🦵🏾' => 'ขา: โทนผิวสีแทน',
    '🦵🏿' => 'ขา: โทนผิวสีเข้ม',
    '🦶🏻' => 'เท้า: โทนผิวสีขาว',
    '🦶🏼' => 'เท้า: โทนผิวสีขาวเหลือง',
    '🦶🏽' => 'เท้า: โทนผิวสีเหลือง',
    '🦶🏾' => 'เท้า: โทนผิวสีแทน',
    '🦶🏿' => 'เท้า: โทนผิวสีเข้ม',
    '👂🏻' => 'หู: โทนผิวสีขาว',
    '👂🏼' => 'หู: โทนผิวสีขาวเหลือง',
    '👂🏽' => 'หู: โทนผิวสีเหลือง',
    '👂🏾' => 'หู: โทนผิวสีแทน',
    '👂🏿' => 'หู: โทนผิวสีเข้ม',
    '🦻🏻' => 'หูใส่อุปกรณ์ช่วยฟัง: โทนผิวสีขาว',
    '🦻🏼' => 'หูใส่อุปกรณ์ช่วยฟัง: โทนผิวสีขาวเหลือง',
    '🦻🏽' => 'หูใส่อุปกรณ์ช่วยฟัง: โทนผิวสีเหลือง',
    '🦻🏾' => 'หูใส่อุปกรณ์ช่วยฟัง: โทนผิวสีแทน',
    '🦻🏿' => 'หูใส่อุปกรณ์ช่วยฟัง: โทนผิวสีเข้ม',
    '👃🏻' => 'จมูก: โทนผิวสีขาว',
    '👃🏼' => 'จมูก: โทนผิวสีขาวเหลือง',
    '👃🏽' => 'จมูก: โทนผิวสีเหลือง',
    '👃🏾' => 'จมูก: โทนผิวสีแทน',
    '👃🏿' => 'จมูก: โทนผิวสีเข้ม',
    '👶🏻' => 'ทารก: โทนผิวสีขาว',
    '👶🏼' => 'ทารก: โทนผิวสีขาวเหลือง',
    '👶🏽' => 'ทารก: โทนผิวสีเหลือง',
    '👶🏾' => 'ทารก: โทนผิวสีแทน',
    '👶🏿' => 'ทารก: โทนผิวสีเข้ม',
    '🧒🏻' => 'เด็ก: โทนผิวสีขาว',
    '🧒🏼' => 'เด็ก: โทนผิวสีขาวเหลือง',
    '🧒🏽' => 'เด็ก: โทนผิวสีเหลือง',
    '🧒🏾' => 'เด็ก: โทนผิวสีแทน',
    '🧒🏿' => 'เด็ก: โทนผิวสีเข้ม',
    '👦🏻' => 'เด็กชาย: โทนผิวสีขาว',
    '👦🏼' => 'เด็กชาย: โทนผิวสีขาวเหลือง',
    '👦🏽' => 'เด็กชาย: โทนผิวสีเหลือง',
    '👦🏾' => 'เด็กชาย: โทนผิวสีแทน',
    '👦🏿' => 'เด็กชาย: โทนผิวสีเข้ม',
    '👧🏻' => 'เด็กหญิง: โทนผิวสีขาว',
    '👧🏼' => 'เด็กหญิง: โทนผิวสีขาวเหลือง',
    '👧🏽' => 'เด็กหญิง: โทนผิวสีเหลือง',
    '👧🏾' => 'เด็กหญิง: โทนผิวสีแทน',
    '👧🏿' => 'เด็กหญิง: โทนผิวสีเข้ม',
    '🧑🏻' => 'คน: โทนผิวสีขาว',
    '🧑🏼' => 'คน: โทนผิวสีขาวเหลือง',
    '🧑🏽' => 'คน: โทนผิวสีเหลือง',
    '🧑🏾' => 'คน: โทนผิวสีแทน',
    '🧑🏿' => 'คน: โทนผิวสีเข้ม',
    '👱🏻' => 'คนผมทอง: โทนผิวสีขาว',
    '👱🏼' => 'คนผมทอง: โทนผิวสีขาวเหลือง',
    '👱🏽' => 'คนผมทอง: โทนผิวสีเหลือง',
    '👱🏾' => 'คนผมทอง: โทนผิวสีแทน',
    '👱🏿' => 'คนผมทอง: โทนผิวสีเข้ม',
    '👨🏻' => 'ผู้ชาย: โทนผิวสีขาว',
    '👨🏼' => 'ผู้ชาย: โทนผิวสีขาวเหลือง',
    '👨🏽' => 'ผู้ชาย: โทนผิวสีเหลือง',
    '👨🏾' => 'ผู้ชาย: โทนผิวสีแทน',
    '👨🏿' => 'ผู้ชาย: โทนผิวสีเข้ม',
    '🧔🏻' => 'ผู้ชายมีเครา: โทนผิวสีขาว',
    '🧔🏼' => 'ผู้ชายมีเครา: โทนผิวสีขาวเหลือง',
    '🧔🏽' => 'ผู้ชายมีเครา: โทนผิวสีเหลือง',
    '🧔🏾' => 'ผู้ชายมีเครา: โทนผิวสีแทน',
    '🧔🏿' => 'ผู้ชายมีเครา: โทนผิวสีเข้ม',
    '👩🏻' => 'ผู้หญิง: โทนผิวสีขาว',
    '👩🏼' => 'ผู้หญิง: โทนผิวสีขาวเหลือง',
    '👩🏽' => 'ผู้หญิง: โทนผิวสีเหลือง',
    '👩🏾' => 'ผู้หญิง: โทนผิวสีแทน',
    '👩🏿' => 'ผู้หญิง: โทนผิวสีเข้ม',
    '🧓🏻' => 'คนชรา: โทนผิวสีขาว',
    '🧓🏼' => 'คนชรา: โทนผิวสีขาวเหลือง',
    '🧓🏽' => 'คนชรา: โทนผิวสีเหลือง',
    '🧓🏾' => 'คนชรา: โทนผิวสีแทน',
    '🧓🏿' => 'คนชรา: โทนผิวสีเข้ม',
    '👴🏻' => 'ชายแก่: โทนผิวสีขาว',
    '👴🏼' => 'ชายแก่: โทนผิวสีขาวเหลือง',
    '👴🏽' => 'ชายแก่: โทนผิวสีเหลือง',
    '👴🏾' => 'ชายแก่: โทนผิวสีแทน',
    '👴🏿' => 'ชายแก่: โทนผิวสีเข้ม',
    '👵🏻' => 'หญิงแก่: โทนผิวสีขาว',
    '👵🏼' => 'หญิงแก่: โทนผิวสีขาวเหลือง',
    '👵🏽' => 'หญิงแก่: โทนผิวสีเหลือง',
    '👵🏾' => 'หญิงแก่: โทนผิวสีแทน',
    '👵🏿' => 'หญิงแก่: โทนผิวสีเข้ม',
    '🙍🏻' => 'ขมวดคิ้ว: โทนผิวสีขาว',
    '🙍🏼' => 'ขมวดคิ้ว: โทนผิวสีขาวเหลือง',
    '🙍🏽' => 'ขมวดคิ้ว: โทนผิวสีเหลือง',
    '🙍🏾' => 'ขมวดคิ้ว: โทนผิวสีแทน',
    '🙍🏿' => 'ขมวดคิ้ว: โทนผิวสีเข้ม',
    '🙎🏻' => 'ปากยื่น: โทนผิวสีขาว',
    '🙎🏼' => 'ปากยื่น: โทนผิวสีขาวเหลือง',
    '🙎🏽' => 'ปากยื่น: โทนผิวสีเหลือง',
    '🙎🏾' => 'ปากยื่น: โทนผิวสีแทน',
    '🙎🏿' => 'ปากยื่น: โทนผิวสีเข้ม',
    '🙅🏻' => 'มือทำท่าไม่โอเค: โทนผิวสีขาว',
    '🙅🏼' => 'มือทำท่าไม่โอเค: โทนผิวสีขาวเหลือง',
    '🙅🏽' => 'มือทำท่าไม่โอเค: โทนผิวสีเหลือง',
    '🙅🏾' => 'มือทำท่าไม่โอเค: โทนผิวสีแทน',
    '🙅🏿' => 'มือทำท่าไม่โอเค: โทนผิวสีเข้ม',
    '🙆🏻' => 'ทำท่าโอเค: โทนผิวสีขาว',
    '🙆🏼' => 'ทำท่าโอเค: โทนผิวสีขาวเหลือง',
    '🙆🏽' => 'ทำท่าโอเค: โทนผิวสีเหลือง',
    '🙆🏾' => 'ทำท่าโอเค: โทนผิวสีแทน',
    '🙆🏿' => 'ทำท่าโอเค: โทนผิวสีเข้ม',
    '💁🏻' => 'โต๊ะสอบถาม: โทนผิวสีขาว',
    '💁🏼' => 'โต๊ะสอบถาม: โทนผิวสีขาวเหลือง',
    '💁🏽' => 'โต๊ะสอบถาม: โทนผิวสีเหลือง',
    '💁🏾' => 'โต๊ะสอบถาม: โทนผิวสีแทน',
    '💁🏿' => 'โต๊ะสอบถาม: โทนผิวสีเข้ม',
    '🙋🏻' => 'ยกมือขึ้น: โทนผิวสีขาว',
    '🙋🏼' => 'ยกมือขึ้น: โทนผิวสีขาวเหลือง',
    '🙋🏽' => 'ยกมือขึ้น: โทนผิวสีเหลือง',
    '🙋🏾' => 'ยกมือขึ้น: โทนผิวสีแทน',
    '🙋🏿' => 'ยกมือขึ้น: โทนผิวสีเข้ม',
    '🧏🏻' => 'คนหูหนวก: โทนผิวสีขาว',
    '🧏🏼' => 'คนหูหนวก: โทนผิวสีขาวเหลือง',
    '🧏🏽' => 'คนหูหนวก: โทนผิวสีเหลือง',
    '🧏🏾' => 'คนหูหนวก: โทนผิวสีแทน',
    '🧏🏿' => 'คนหูหนวก: โทนผิวสีเข้ม',
    '🙇🏻' => 'ท่าขอโทษ: โทนผิวสีขาว',
    '🙇🏼' => 'ท่าขอโทษ: โทนผิวสีขาวเหลือง',
    '🙇🏽' => 'ท่าขอโทษ: โทนผิวสีเหลือง',
    '🙇🏾' => 'ท่าขอโทษ: โทนผิวสีแทน',
    '🙇🏿' => 'ท่าขอโทษ: โทนผิวสีเข้ม',
    '🤦🏻' => 'หมดกัน: โทนผิวสีขาว',
    '🤦🏼' => 'หมดกัน: โทนผิวสีขาวเหลือง',
    '🤦🏽' => 'หมดกัน: โทนผิวสีเหลือง',
    '🤦🏾' => 'หมดกัน: โทนผิวสีแทน',
    '🤦🏿' => 'หมดกัน: โทนผิวสีเข้ม',
    '🤷🏻' => 'ยักไหล่: โทนผิวสีขาว',
    '🤷🏼' => 'ยักไหล่: โทนผิวสีขาวเหลือง',
    '🤷🏽' => 'ยักไหล่: โทนผิวสีเหลือง',
    '🤷🏾' => 'ยักไหล่: โทนผิวสีแทน',
    '🤷🏿' => 'ยักไหล่: โทนผิวสีเข้ม',
    '👮🏻' => 'เจ้าหน้าที่ตำรวจ: โทนผิวสีขาว',
    '👮🏼' => 'เจ้าหน้าที่ตำรวจ: โทนผิวสีขาวเหลือง',
    '👮🏽' => 'เจ้าหน้าที่ตำรวจ: โทนผิวสีเหลือง',
    '👮🏾' => 'เจ้าหน้าที่ตำรวจ: โทนผิวสีแทน',
    '👮🏿' => 'เจ้าหน้าที่ตำรวจ: โทนผิวสีเข้ม',
    '🕵🏻' => 'นักสืบ: โทนผิวสีขาว',
    '🕵🏼' => 'นักสืบ: โทนผิวสีขาวเหลือง',
    '🕵🏽' => 'นักสืบ: โทนผิวสีเหลือง',
    '🕵🏾' => 'นักสืบ: โทนผิวสีแทน',
    '🕵🏿' => 'นักสืบ: โทนผิวสีเข้ม',
    '💂🏻' => 'การ์ดคุ้มกัน: โทนผิวสีขาว',
    '💂🏼' => 'การ์ดคุ้มกัน: โทนผิวสีขาวเหลือง',
    '💂🏽' => 'การ์ดคุ้มกัน: โทนผิวสีเหลือง',
    '💂🏾' => 'การ์ดคุ้มกัน: โทนผิวสีแทน',
    '💂🏿' => 'การ์ดคุ้มกัน: โทนผิวสีเข้ม',
    '🥷🏻' => 'นินจา: โทนผิวสีขาว',
    '🥷🏼' => 'นินจา: โทนผิวสีขาวเหลือง',
    '🥷🏽' => 'นินจา: โทนผิวสีเหลือง',
    '🥷🏾' => 'นินจา: โทนผิวสีแทน',
    '🥷🏿' => 'นินจา: โทนผิวสีเข้ม',
    '👷🏻' => 'คนงานก่อสร้าง: โทนผิวสีขาว',
    '👷🏼' => 'คนงานก่อสร้าง: โทนผิวสีขาวเหลือง',
    '👷🏽' => 'คนงานก่อสร้าง: โทนผิวสีเหลือง',
    '👷🏾' => 'คนงานก่อสร้าง: โทนผิวสีแทน',
    '👷🏿' => 'คนงานก่อสร้าง: โทนผิวสีเข้ม',
    '🫅🏻' => 'คนสวมมงกุฎ: โทนผิวสีขาว',
    '🫅🏼' => 'คนสวมมงกุฎ: โทนผิวสีขาวเหลือง',
    '🫅🏽' => 'คนสวมมงกุฎ: โทนผิวสีเหลือง',
    '🫅🏾' => 'คนสวมมงกุฎ: โทนผิวสีแทน',
    '🫅🏿' => 'คนสวมมงกุฎ: โทนผิวสีเข้ม',
    '🤴🏻' => 'เจ้าชาย: โทนผิวสีขาว',
    '🤴🏼' => 'เจ้าชาย: โทนผิวสีขาวเหลือง',
    '🤴🏽' => 'เจ้าชาย: โทนผิวสีเหลือง',
    '🤴🏾' => 'เจ้าชาย: โทนผิวสีแทน',
    '🤴🏿' => 'เจ้าชาย: โทนผิวสีเข้ม',
    '👸🏻' => 'เจ้าหญิง: โทนผิวสีขาว',
    '👸🏼' => 'เจ้าหญิง: โทนผิวสีขาวเหลือง',
    '👸🏽' => 'เจ้าหญิง: โทนผิวสีเหลือง',
    '👸🏾' => 'เจ้าหญิง: โทนผิวสีแทน',
    '👸🏿' => 'เจ้าหญิง: โทนผิวสีเข้ม',
    '👳🏻' => 'ชายโพกหัว: โทนผิวสีขาว',
    '👳🏼' => 'ชายโพกหัว: โทนผิวสีขาวเหลือง',
    '👳🏽' => 'ชายโพกหัว: โทนผิวสีเหลือง',
    '👳🏾' => 'ชายโพกหัว: โทนผิวสีแทน',
    '👳🏿' => 'ชายโพกหัว: โทนผิวสีเข้ม',
    '👲🏻' => 'ชายจีน: โทนผิวสีขาว',
    '👲🏼' => 'ชายจีน: โทนผิวสีขาวเหลือง',
    '👲🏽' => 'ชายจีน: โทนผิวสีเหลือง',
    '👲🏾' => 'ชายจีน: โทนผิวสีแทน',
    '👲🏿' => 'ชายจีน: โทนผิวสีเข้ม',
    '🧕🏻' => 'ผู้หญิงโพกศีรษะ: โทนผิวสีขาว',
    '🧕🏼' => 'ผู้หญิงโพกศีรษะ: โทนผิวสีขาวเหลือง',
    '🧕🏽' => 'ผู้หญิงโพกศีรษะ: โทนผิวสีเหลือง',
    '🧕🏾' => 'ผู้หญิงโพกศีรษะ: โทนผิวสีแทน',
    '🧕🏿' => 'ผู้หญิงโพกศีรษะ: โทนผิวสีเข้ม',
    '🤵🏻' => 'คนหล่อ: โทนผิวสีขาว',
    '🤵🏼' => 'คนหล่อ: โทนผิวสีขาวเหลือง',
    '🤵🏽' => 'คนหล่อ: โทนผิวสีเหลือง',
    '🤵🏾' => 'คนหล่อ: โทนผิวสีแทน',
    '🤵🏿' => 'คนหล่อ: โทนผิวสีเข้ม',
    '👰🏻' => 'เจ้าสาว: โทนผิวสีขาว',
    '👰🏼' => 'เจ้าสาว: โทนผิวสีขาวเหลือง',
    '👰🏽' => 'เจ้าสาว: โทนผิวสีเหลือง',
    '👰🏾' => 'เจ้าสาว: โทนผิวสีแทน',
    '👰🏿' => 'เจ้าสาว: โทนผิวสีเข้ม',
    '🤰🏻' => 'คนท้อง: โทนผิวสีขาว',
    '🤰🏼' => 'คนท้อง: โทนผิวสีขาวเหลือง',
    '🤰🏽' => 'คนท้อง: โทนผิวสีเหลือง',
    '🤰🏾' => 'คนท้อง: โทนผิวสีแทน',
    '🤰🏿' => 'คนท้อง: โทนผิวสีเข้ม',
    '🫃🏻' => 'ผู้ชายตั้งครรภ์: โทนผิวสีขาว',
    '🫃🏼' => 'ผู้ชายตั้งครรภ์: โทนผิวสีขาวเหลือง',
    '🫃🏽' => 'ผู้ชายตั้งครรภ์: โทนผิวสีเหลือง',
    '🫃🏾' => 'ผู้ชายตั้งครรภ์: โทนผิวสีแทน',
    '🫃🏿' => 'ผู้ชายตั้งครรภ์: โทนผิวสีเข้ม',
    '🫄🏻' => 'คนตั้งครรภ์: โทนผิวสีขาว',
    '🫄🏼' => 'คนตั้งครรภ์: โทนผิวสีขาวเหลือง',
    '🫄🏽' => 'คนตั้งครรภ์: โทนผิวสีเหลือง',
    '🫄🏾' => 'คนตั้งครรภ์: โทนผิวสีแทน',
    '🫄🏿' => 'คนตั้งครรภ์: โทนผิวสีเข้ม',
    '🤱🏻' => 'ให้นม: โทนผิวสีขาว',
    '🤱🏼' => 'ให้นม: โทนผิวสีขาวเหลือง',
    '🤱🏽' => 'ให้นม: โทนผิวสีเหลือง',
    '🤱🏾' => 'ให้นม: โทนผิวสีแทน',
    '🤱🏿' => 'ให้นม: โทนผิวสีเข้ม',
    '👼🏻' => 'นางฟ้าเด็ก: โทนผิวสีขาว',
    '👼🏼' => 'นางฟ้าเด็ก: โทนผิวสีขาวเหลือง',
    '👼🏽' => 'นางฟ้าเด็ก: โทนผิวสีเหลือง',
    '👼🏾' => 'นางฟ้าเด็ก: โทนผิวสีแทน',
    '👼🏿' => 'นางฟ้าเด็ก: โทนผิวสีเข้ม',
    '🎅🏻' => 'ซานต้า: โทนผิวสีขาว',
    '🎅🏼' => 'ซานต้า: โทนผิวสีขาวเหลือง',
    '🎅🏽' => 'ซานต้า: โทนผิวสีเหลือง',
    '🎅🏾' => 'ซานต้า: โทนผิวสีแทน',
    '🎅🏿' => 'ซานต้า: โทนผิวสีเข้ม',
    '🤶🏻' => 'นางซานต้า: โทนผิวสีขาว',
    '🤶🏼' => 'นางซานต้า: โทนผิวสีขาวเหลือง',
    '🤶🏽' => 'นางซานต้า: โทนผิวสีเหลือง',
    '🤶🏾' => 'นางซานต้า: โทนผิวสีแทน',
    '🤶🏿' => 'นางซานต้า: โทนผิวสีเข้ม',
    '🦸🏻' => 'ซุปเปอร์ฮีโร่: โทนผิวสีขาว',
    '🦸🏼' => 'ซุปเปอร์ฮีโร่: โทนผิวสีขาวเหลือง',
    '🦸🏽' => 'ซุปเปอร์ฮีโร่: โทนผิวสีเหลือง',
    '🦸🏾' => 'ซุปเปอร์ฮีโร่: โทนผิวสีแทน',
    '🦸🏿' => 'ซุปเปอร์ฮีโร่: โทนผิวสีเข้ม',
    '🦹🏻' => 'ยอดมนุษย์: โทนผิวสีขาว',
    '🦹🏼' => 'ยอดมนุษย์: โทนผิวสีขาวเหลือง',
    '🦹🏽' => 'ยอดมนุษย์: โทนผิวสีเหลือง',
    '🦹🏾' => 'ยอดมนุษย์: โทนผิวสีแทน',
    '🦹🏿' => 'ยอดมนุษย์: โทนผิวสีเข้ม',
    '🧙🏻' => 'นักเวทย์: โทนผิวสีขาว',
    '🧙🏼' => 'นักเวทย์: โทนผิวสีขาวเหลือง',
    '🧙🏽' => 'นักเวทย์: โทนผิวสีเหลือง',
    '🧙🏾' => 'นักเวทย์: โทนผิวสีแทน',
    '🧙🏿' => 'นักเวทย์: โทนผิวสีเข้ม',
    '🧚🏻' => 'นางฟ้า: โทนผิวสีขาว',
    '🧚🏼' => 'นางฟ้า: โทนผิวสีขาวเหลือง',
    '🧚🏽' => 'นางฟ้า: โทนผิวสีเหลือง',
    '🧚🏾' => 'นางฟ้า: โทนผิวสีแทน',
    '🧚🏿' => 'นางฟ้า: โทนผิวสีเข้ม',
    '🧛🏻' => 'แวมไพร์: โทนผิวสีขาว',
    '🧛🏼' => 'แวมไพร์: โทนผิวสีขาวเหลือง',
    '🧛🏽' => 'แวมไพร์: โทนผิวสีเหลือง',
    '🧛🏾' => 'แวมไพร์: โทนผิวสีแทน',
    '🧛🏿' => 'แวมไพร์: โทนผิวสีเข้ม',
    '🧜🏻' => 'ครึ่งคนครึ่งปลา: โทนผิวสีขาว',
    '🧜🏼' => 'ครึ่งคนครึ่งปลา: โทนผิวสีขาวเหลือง',
    '🧜🏽' => 'ครึ่งคนครึ่งปลา: โทนผิวสีเหลือง',
    '🧜🏾' => 'ครึ่งคนครึ่งปลา: โทนผิวสีแทน',
    '🧜🏿' => 'ครึ่งคนครึ่งปลา: โทนผิวสีเข้ม',
    '🧝🏻' => 'เอลฟ์: โทนผิวสีขาว',
    '🧝🏼' => 'เอลฟ์: โทนผิวสีขาวเหลือง',
    '🧝🏽' => 'เอลฟ์: โทนผิวสีเหลือง',
    '🧝🏾' => 'เอลฟ์: โทนผิวสีแทน',
    '🧝🏿' => 'เอลฟ์: โทนผิวสีเข้ม',
    '💆🏻' => 'นวดหน้า: โทนผิวสีขาว',
    '💆🏼' => 'นวดหน้า: โทนผิวสีขาวเหลือง',
    '💆🏽' => 'นวดหน้า: โทนผิวสีเหลือง',
    '💆🏾' => 'นวดหน้า: โทนผิวสีแทน',
    '💆🏿' => 'นวดหน้า: โทนผิวสีเข้ม',
    '💇🏻' => 'ตัดผม: โทนผิวสีขาว',
    '💇🏼' => 'ตัดผม: โทนผิวสีขาวเหลือง',
    '💇🏽' => 'ตัดผม: โทนผิวสีเหลือง',
    '💇🏾' => 'ตัดผม: โทนผิวสีแทน',
    '💇🏿' => 'ตัดผม: โทนผิวสีเข้ม',
    '🚶🏻' => 'คนเดิน: โทนผิวสีขาว',
    '🚶🏼' => 'คนเดิน: โทนผิวสีขาวเหลือง',
    '🚶🏽' => 'คนเดิน: โทนผิวสีเหลือง',
    '🚶🏾' => 'คนเดิน: โทนผิวสีแทน',
    '🚶🏿' => 'คนเดิน: โทนผิวสีเข้ม',
    '🧍🏻' => 'คนกำลังยืน: โทนผิวสีขาว',
    '🧍🏼' => 'คนกำลังยืน: โทนผิวสีขาวเหลือง',
    '🧍🏽' => 'คนกำลังยืน: โทนผิวสีเหลือง',
    '🧍🏾' => 'คนกำลังยืน: โทนผิวสีแทน',
    '🧍🏿' => 'คนกำลังยืน: โทนผิวสีเข้ม',
    '🧎🏻' => 'คนกำลังคุกเข่า: โทนผิวสีขาว',
    '🧎🏼' => 'คนกำลังคุกเข่า: โทนผิวสีขาวเหลือง',
    '🧎🏽' => 'คนกำลังคุกเข่า: โทนผิวสีเหลือง',
    '🧎🏾' => 'คนกำลังคุกเข่า: โทนผิวสีแทน',
    '🧎🏿' => 'คนกำลังคุกเข่า: โทนผิวสีเข้ม',
    '🏃🏻' => 'คนวิ่ง: โทนผิวสีขาว',
    '🏃🏼' => 'คนวิ่ง: โทนผิวสีขาวเหลือง',
    '🏃🏽' => 'คนวิ่ง: โทนผิวสีเหลือง',
    '🏃🏾' => 'คนวิ่ง: โทนผิวสีแทน',
    '🏃🏿' => 'คนวิ่ง: โทนผิวสีเข้ม',
    '💃🏻' => 'นักเต้น: โทนผิวสีขาว',
    '💃🏼' => 'นักเต้น: โทนผิวสีขาวเหลือง',
    '💃🏽' => 'นักเต้น: โทนผิวสีเหลือง',
    '💃🏾' => 'นักเต้น: โทนผิวสีแทน',
    '💃🏿' => 'นักเต้น: โทนผิวสีเข้ม',
    '🕺🏻' => 'คนเต้น: โทนผิวสีขาว',
    '🕺🏼' => 'คนเต้น: โทนผิวสีขาวเหลือง',
    '🕺🏽' => 'คนเต้น: โทนผิวสีเหลือง',
    '🕺🏾' => 'คนเต้น: โทนผิวสีแทน',
    '🕺🏿' => 'คนเต้น: โทนผิวสีเข้ม',
    '🕴🏻' => 'คนใส่สูทลอยได้: โทนผิวสีขาว',
    '🕴🏼' => 'คนใส่สูทลอยได้: โทนผิวสีขาวเหลือง',
    '🕴🏽' => 'คนใส่สูทลอยได้: โทนผิวสีเหลือง',
    '🕴🏾' => 'คนใส่สูทลอยได้: โทนผิวสีแทน',
    '🕴🏿' => 'คนใส่สูทลอยได้: โทนผิวสีเข้ม',
    '👯🏻' => 'คนในชุดหูกระต่าย: โทนผิวสีขาว',
    '👯🏼' => 'คนในชุดหูกระต่าย: โทนผิวสีขาวเหลือง',
    '👯🏽' => 'คนในชุดหูกระต่าย: โทนผิวสีเหลือง',
    '👯🏾' => 'คนในชุดหูกระต่าย: โทนผิวสีแทน',
    '👯🏿' => 'คนในชุดหูกระต่าย: โทนผิวสีเข้ม',
    '🧖🏻' => 'คนในห้องอบไอน้ำ: โทนผิวสีขาว',
    '🧖🏼' => 'คนในห้องอบไอน้ำ: โทนผิวสีขาวเหลือง',
    '🧖🏽' => 'คนในห้องอบไอน้ำ: โทนผิวสีเหลือง',
    '🧖🏾' => 'คนในห้องอบไอน้ำ: โทนผิวสีแทน',
    '🧖🏿' => 'คนในห้องอบไอน้ำ: โทนผิวสีเข้ม',
    '🧗🏻' => 'นักไต่เขา: โทนผิวสีขาว',
    '🧗🏼' => 'นักไต่เขา: โทนผิวสีขาวเหลือง',
    '🧗🏽' => 'นักไต่เขา: โทนผิวสีเหลือง',
    '🧗🏾' => 'นักไต่เขา: โทนผิวสีแทน',
    '🧗🏿' => 'นักไต่เขา: โทนผิวสีเข้ม',
    '🏇🏻' => 'แข่งม้า: โทนผิวสีขาว',
    '🏇🏼' => 'แข่งม้า: โทนผิวสีขาวเหลือง',
    '🏇🏽' => 'แข่งม้า: โทนผิวสีเหลือง',
    '🏇🏾' => 'แข่งม้า: โทนผิวสีแทน',
    '🏇🏿' => 'แข่งม้า: โทนผิวสีเข้ม',
    '🏂🏻' => 'นักสโนว์บอร์ด: โทนผิวสีขาว',
    '🏂🏼' => 'นักสโนว์บอร์ด: โทนผิวสีขาวเหลือง',
    '🏂🏽' => 'นักสโนว์บอร์ด: โทนผิวสีเหลือง',
    '🏂🏾' => 'นักสโนว์บอร์ด: โทนผิวสีแทน',
    '🏂🏿' => 'นักสโนว์บอร์ด: โทนผิวสีเข้ม',
    '🏌🏻' => 'นักกอล์ฟ: โทนผิวสีขาว',
    '🏌🏼' => 'นักกอล์ฟ: โทนผิวสีขาวเหลือง',
    '🏌🏽' => 'นักกอล์ฟ: โทนผิวสีเหลือง',
    '🏌🏾' => 'นักกอล์ฟ: โทนผิวสีแทน',
    '🏌🏿' => 'นักกอล์ฟ: โทนผิวสีเข้ม',
    '🏄🏻' => 'นักโต้คลื่น: โทนผิวสีขาว',
    '🏄🏼' => 'นักโต้คลื่น: โทนผิวสีขาวเหลือง',
    '🏄🏽' => 'นักโต้คลื่น: โทนผิวสีเหลือง',
    '🏄🏾' => 'นักโต้คลื่น: โทนผิวสีแทน',
    '🏄🏿' => 'นักโต้คลื่น: โทนผิวสีเข้ม',
    '🚣🏻' => 'นักพายเรือ: โทนผิวสีขาว',
    '🚣🏼' => 'นักพายเรือ: โทนผิวสีขาวเหลือง',
    '🚣🏽' => 'นักพายเรือ: โทนผิวสีเหลือง',
    '🚣🏾' => 'นักพายเรือ: โทนผิวสีแทน',
    '🚣🏿' => 'นักพายเรือ: โทนผิวสีเข้ม',
    '🏊🏻' => 'นักว่ายน้ำ: โทนผิวสีขาว',
    '🏊🏼' => 'นักว่ายน้ำ: โทนผิวสีขาวเหลือง',
    '🏊🏽' => 'นักว่ายน้ำ: โทนผิวสีเหลือง',
    '🏊🏾' => 'นักว่ายน้ำ: โทนผิวสีแทน',
    '🏊🏿' => 'นักว่ายน้ำ: โทนผิวสีเข้ม',
    '⛹🏻' => 'คนเล่นบอล: โทนผิวสีขาว',
    '⛹🏼' => 'คนเล่นบอล: โทนผิวสีขาวเหลือง',
    '⛹🏽' => 'คนเล่นบอล: โทนผิวสีเหลือง',
    '⛹🏾' => 'คนเล่นบอล: โทนผิวสีแทน',
    '⛹🏿' => 'คนเล่นบอล: โทนผิวสีเข้ม',
    '🏋🏻' => 'นักยกน้ำหนัก: โทนผิวสีขาว',
    '🏋🏼' => 'นักยกน้ำหนัก: โทนผิวสีขาวเหลือง',
    '🏋🏽' => 'นักยกน้ำหนัก: โทนผิวสีเหลือง',
    '🏋🏾' => 'นักยกน้ำหนัก: โทนผิวสีแทน',
    '🏋🏿' => 'นักยกน้ำหนัก: โทนผิวสีเข้ม',
    '🚴🏻' => 'นักปั่นจักรยาน: โทนผิวสีขาว',
    '🚴🏼' => 'นักปั่นจักรยาน: โทนผิวสีขาวเหลือง',
    '🚴🏽' => 'นักปั่นจักรยาน: โทนผิวสีเหลือง',
    '🚴🏾' => 'นักปั่นจักรยาน: โทนผิวสีแทน',
    '🚴🏿' => 'นักปั่นจักรยาน: โทนผิวสีเข้ม',
    '🚵🏻' => 'นักปั่นจักรยานเสือภูเขา: โทนผิวสีขาว',
    '🚵🏼' => 'นักปั่นจักรยานเสือภูเขา: โทนผิวสีขาวเหลือง',
    '🚵🏽' => 'นักปั่นจักรยานเสือภูเขา: โทนผิวสีเหลือง',
    '🚵🏾' => 'นักปั่นจักรยานเสือภูเขา: โทนผิวสีแทน',
    '🚵🏿' => 'นักปั่นจักรยานเสือภูเขา: โทนผิวสีเข้ม',
    '🤸🏻' => 'คนตีลังกา: โทนผิวสีขาว',
    '🤸🏼' => 'คนตีลังกา: โทนผิวสีขาวเหลือง',
    '🤸🏽' => 'คนตีลังกา: โทนผิวสีเหลือง',
    '🤸🏾' => 'คนตีลังกา: โทนผิวสีแทน',
    '🤸🏿' => 'คนตีลังกา: โทนผิวสีเข้ม',
    '🤼🏻' => 'นักมวยปล้ำ: โทนผิวสีขาว',
    '🤼🏼' => 'นักมวยปล้ำ: โทนผิวสีขาวเหลือง',
    '🤼🏽' => 'นักมวยปล้ำ: โทนผิวสีเหลือง',
    '🤼🏾' => 'นักมวยปล้ำ: โทนผิวสีแทน',
    '🤼🏿' => 'นักมวยปล้ำ: โทนผิวสีเข้ม',
    '🤽🏻' => 'นักโปโลน้ำ: โทนผิวสีขาว',
    '🤽🏼' => 'นักโปโลน้ำ: โทนผิวสีขาวเหลือง',
    '🤽🏽' => 'นักโปโลน้ำ: โทนผิวสีเหลือง',
    '🤽🏾' => 'นักโปโลน้ำ: โทนผิวสีแทน',
    '🤽🏿' => 'นักโปโลน้ำ: โทนผิวสีเข้ม',
    '🤾🏻' => 'นักแฮนด์บอล: โทนผิวสีขาว',
    '🤾🏼' => 'นักแฮนด์บอล: โทนผิวสีขาวเหลือง',
    '🤾🏽' => 'นักแฮนด์บอล: โทนผิวสีเหลือง',
    '🤾🏾' => 'นักแฮนด์บอล: โทนผิวสีแทน',
    '🤾🏿' => 'นักแฮนด์บอล: โทนผิวสีเข้ม',
    '🤹🏻' => 'คนเล่นจั๊กกลิ้ง: โทนผิวสีขาว',
    '🤹🏼' => 'คนเล่นจั๊กกลิ้ง: โทนผิวสีขาวเหลือง',
    '🤹🏽' => 'คนเล่นจั๊กกลิ้ง: โทนผิวสีเหลือง',
    '🤹🏾' => 'คนเล่นจั๊กกลิ้ง: โทนผิวสีแทน',
    '🤹🏿' => 'คนเล่นจั๊กกลิ้ง: โทนผิวสีเข้ม',
    '🧘🏻' => 'คนนั่งสมาธิ: โทนผิวสีขาว',
    '🧘🏼' => 'คนนั่งสมาธิ: โทนผิวสีขาวเหลือง',
    '🧘🏽' => 'คนนั่งสมาธิ: โทนผิวสีเหลือง',
    '🧘🏾' => 'คนนั่งสมาธิ: โทนผิวสีแทน',
    '🧘🏿' => 'คนนั่งสมาธิ: โทนผิวสีเข้ม',
    '🛀🏻' => 'คนนอนแช่น้ำในอ่าง: โทนผิวสีขาว',
    '🛀🏼' => 'คนนอนแช่น้ำในอ่าง: โทนผิวสีขาวเหลือง',
    '🛀🏽' => 'คนนอนแช่น้ำในอ่าง: โทนผิวสีเหลือง',
    '🛀🏾' => 'คนนอนแช่น้ำในอ่าง: โทนผิวสีแทน',
    '🛀🏿' => 'คนนอนแช่น้ำในอ่าง: โทนผิวสีเข้ม',
    '🛌🏻' => 'คนนอนหลับ: โทนผิวสีขาว',
    '🛌🏼' => 'คนนอนหลับ: โทนผิวสีขาวเหลือง',
    '🛌🏽' => 'คนนอนหลับ: โทนผิวสีเหลือง',
    '🛌🏾' => 'คนนอนหลับ: โทนผิวสีแทน',
    '🛌🏿' => 'คนนอนหลับ: โทนผิวสีเข้ม',
    '👭🏻' => 'หญิง-หญิงจับมือ: โทนผิวสีขาว',
    '👭🏼' => 'หญิง-หญิงจับมือ: โทนผิวสีขาวเหลือง',
    '👭🏽' => 'หญิง-หญิงจับมือ: โทนผิวสีเหลือง',
    '👭🏾' => 'หญิง-หญิงจับมือ: โทนผิวสีแทน',
    '👭🏿' => 'หญิง-หญิงจับมือ: โทนผิวสีเข้ม',
    '👫🏻' => 'ชาย-หญิงจับมือ: โทนผิวสีขาว',
    '👫🏼' => 'ชาย-หญิงจับมือ: โทนผิวสีขาวเหลือง',
    '👫🏽' => 'ชาย-หญิงจับมือ: โทนผิวสีเหลือง',
    '👫🏾' => 'ชาย-หญิงจับมือ: โทนผิวสีแทน',
    '👫🏿' => 'ชาย-หญิงจับมือ: โทนผิวสีเข้ม',
    '👬🏻' => 'ชาย-ชายจับมือ: โทนผิวสีขาว',
    '👬🏼' => 'ชาย-ชายจับมือ: โทนผิวสีขาวเหลือง',
    '👬🏽' => 'ชาย-ชายจับมือ: โทนผิวสีเหลือง',
    '👬🏾' => 'ชาย-ชายจับมือ: โทนผิวสีแทน',
    '👬🏿' => 'ชาย-ชายจับมือ: โทนผิวสีเข้ม',
    '💏🏻' => 'จูบ: โทนผิวสีขาว',
    '💏🏼' => 'จูบ: โทนผิวสีขาวเหลือง',
    '💏🏽' => 'จูบ: โทนผิวสีเหลือง',
    '💏🏾' => 'จูบ: โทนผิวสีแทน',
    '💏🏿' => 'จูบ: โทนผิวสีเข้ม',
    '💑🏻' => 'คู่รัก: โทนผิวสีขาว',
    '💑🏼' => 'คู่รัก: โทนผิวสีขาวเหลือง',
    '💑🏽' => 'คู่รัก: โทนผิวสีเหลือง',
    '💑🏾' => 'คู่รัก: โทนผิวสีแทน',
    '💑🏿' => 'คู่รัก: โทนผิวสีเข้ม',
    '🇦🇨' => 'ธง: เกาะแอสเซนชัน',
    '🇦🇩' => 'ธง: อันดอร์รา',
    '🇦🇪' => 'ธง: สหรัฐอาหรับเอมิเรตส์',
    '🇦🇫' => 'ธง: อัฟกานิสถาน',
    '🇦🇬' => 'ธง: แอนติกาและบาร์บูดา',
    '🇦🇮' => 'ธง: แองกวิลลา',
    '🇦🇱' => 'ธง: แอลเบเนีย',
    '🇦🇲' => 'ธง: อาร์เมเนีย',
    '🇦🇴' => 'ธง: แองโกลา',
    '🇦🇶' => 'ธง: แอนตาร์กติกา',
    '🇦🇷' => 'ธง: อาร์เจนตินา',
    '🇦🇸' => 'ธง: อเมริกันซามัว',
    '🇦🇹' => 'ธง: ออสเตรีย',
    '🇦🇺' => 'ธง: ออสเตรเลีย',
    '🇦🇼' => 'ธง: อารูบา',
    '🇦🇽' => 'ธง: หมู่เกาะโอลันด์',
    '🇦🇿' => 'ธง: อาเซอร์ไบจาน',
    '🇧🇦' => 'ธง: บอสเนียและเฮอร์เซโกวีนา',
    '🇧🇧' => 'ธง: บาร์เบโดส',
    '🇧🇩' => 'ธง: บังกลาเทศ',
    '🇧🇪' => 'ธง: เบลเยียม',
    '🇧🇫' => 'ธง: บูร์กินาฟาโซ',
    '🇧🇬' => 'ธง: บัลแกเรีย',
    '🇧🇭' => 'ธง: บาห์เรน',
    '🇧🇮' => 'ธง: บุรุนดี',
    '🇧🇯' => 'ธง: เบนิน',
    '🇧🇱' => 'ธง: เซนต์บาร์เธเลมี',
    '🇧🇲' => 'ธง: เบอร์มิวดา',
    '🇧🇳' => 'ธง: บรูไน',
    '🇧🇴' => 'ธง: โบลิเวีย',
    '🇧🇶' => 'ธง: เนเธอร์แลนด์แคริบเบียน',
    '🇧🇷' => 'ธง: บราซิล',
    '🇧🇸' => 'ธง: บาฮามาส',
    '🇧🇹' => 'ธง: ภูฏาน',
    '🇧🇻' => 'ธง: เกาะบูเว',
    '🇧🇼' => 'ธง: บอตสวานา',
    '🇧🇾' => 'ธง: เบลารุส',
    '🇧🇿' => 'ธง: เบลีซ',
    '🇨🇦' => 'ธง: แคนาดา',
    '🇨🇨' => 'ธง: หมู่เกาะโคโคส (คีลิง)',
    '🇨🇩' => 'ธง: คองโก - กินชาซา',
    '🇨🇫' => 'ธง: สาธารณรัฐแอฟริกากลาง',
    '🇨🇬' => 'ธง: คองโก - บราซซาวิล',
    '🇨🇭' => 'ธง: สวิตเซอร์แลนด์',
    '🇨🇮' => 'ธง: โกตดิวัวร์',
    '🇨🇰' => 'ธง: หมู่เกาะคุก',
    '🇨🇱' => 'ธง: ชิลี',
    '🇨🇲' => 'ธง: แคเมอรูน',
    '🇨🇳' => 'ธง: จีน',
    '🇨🇴' => 'ธง: โคลอมเบีย',
    '🇨🇵' => 'ธง: เกาะคลิปเปอร์ตัน',
    '🇨🇶' => 'ธง: ซาร์ก',
    '🇨🇷' => 'ธง: คอสตาริกา',
    '🇨🇺' => 'ธง: คิวบา',
    '🇨🇻' => 'ธง: เคปเวิร์ด',
    '🇨🇼' => 'ธง: คูราเซา',
    '🇨🇽' => 'ธง: เกาะคริสต์มาส',
    '🇨🇾' => 'ธง: ไซปรัส',
    '🇨🇿' => 'ธง: เช็ก',
    '🇩🇪' => 'ธง: เยอรมนี',
    '🇩🇬' => 'ธง: ดิเอโกการ์เซีย',
    '🇩🇯' => 'ธง: จิบูตี',
    '🇩🇰' => 'ธง: เดนมาร์ก',
    '🇩🇲' => 'ธง: โดมินิกา',
    '🇩🇴' => 'ธง: สาธารณรัฐโดมินิกัน',
    '🇩🇿' => 'ธง: แอลจีเรีย',
    '🇪🇦' => 'ธง: เซวตาและเมลียา',
    '🇪🇨' => 'ธง: เอกวาดอร์',
    '🇪🇪' => 'ธง: เอสโตเนีย',
    '🇪🇬' => 'ธง: อียิปต์',
    '🇪🇭' => 'ธง: ซาฮาราตะวันตก',
    '🇪🇷' => 'ธง: เอริเทรีย',
    '🇪🇸' => 'ธง: สเปน',
    '🇪🇹' => 'ธง: เอธิโอเปีย',
    '🇪🇺' => 'ธง: สหภาพยุโรป',
    '🇫🇮' => 'ธง: ฟินแลนด์',
    '🇫🇯' => 'ธง: ฟิจิ',
    '🇫🇰' => 'ธง: หมู่เกาะฟอล์กแลนด์',
    '🇫🇲' => 'ธง: ไมโครนีเซีย',
    '🇫🇴' => 'ธง: หมู่เกาะแฟโร',
    '🇫🇷' => 'ธง: ฝรั่งเศส',
    '🇬🇦' => 'ธง: กาบอง',
    '🇬🇧' => 'ธง: สหราชอาณาจักร',
    '🇬🇩' => 'ธง: เกรเนดา',
    '🇬🇪' => 'ธง: จอร์เจีย',
    '🇬🇫' => 'ธง: เฟรนช์เกียนา',
    '🇬🇬' => 'ธง: เกิร์นซีย์',
    '🇬🇭' => 'ธง: กานา',
    '🇬🇮' => 'ธง: ยิบรอลตาร์',
    '🇬🇱' => 'ธง: กรีนแลนด์',
    '🇬🇲' => 'ธง: แกมเบีย',
    '🇬🇳' => 'ธง: กินี',
    '🇬🇵' => 'ธง: กวาเดอลูป',
    '🇬🇶' => 'ธง: อิเควทอเรียลกินี',
    '🇬🇷' => 'ธง: กรีซ',
    '🇬🇸' => 'ธง: เกาะเซาท์จอร์เจียและหมู่เกาะเซาท์แซนด์วิช',
    '🇬🇹' => 'ธง: กัวเตมาลา',
    '🇬🇺' => 'ธง: กวม',
    '🇬🇼' => 'ธง: กินี-บิสเซา',
    '🇬🇾' => 'ธง: กายอานา',
    '🇭🇰' => 'ธง: เขตปกครองพิเศษฮ่องกงแห่งสาธารณรัฐประชาชนจีน',
    '🇭🇲' => 'ธง: เกาะเฮิร์ดและหมู่เกาะแมกดอนัลด์',
    '🇭🇳' => 'ธง: ฮอนดูรัส',
    '🇭🇷' => 'ธง: โครเอเชีย',
    '🇭🇹' => 'ธง: เฮติ',
    '🇭🇺' => 'ธง: ฮังการี',
    '🇮🇨' => 'ธง: หมู่เกาะคานารี',
    '🇮🇩' => 'ธง: อินโดนีเซีย',
    '🇮🇪' => 'ธง: ไอร์แลนด์',
    '🇮🇱' => 'ธง: อิสราเอล',
    '🇮🇲' => 'ธง: เกาะแมน',
    '🇮🇳' => 'ธง: อินเดีย',
    '🇮🇴' => 'ธง: บริติชอินเดียนโอเชียนเทร์ริทอรี',
    '🇮🇶' => 'ธง: อิรัก',
    '🇮🇷' => 'ธง: อิหร่าน',
    '🇮🇸' => 'ธง: ไอซ์แลนด์',
    '🇮🇹' => 'ธง: อิตาลี',
    '🇯🇪' => 'ธง: เจอร์ซีย์',
    '🇯🇲' => 'ธง: จาเมกา',
    '🇯🇴' => 'ธง: จอร์แดน',
    '🇯🇵' => 'ธง: ญี่ปุ่น',
    '🇰🇪' => 'ธง: เคนยา',
    '🇰🇬' => 'ธง: คีร์กีซสถาน',
    '🇰🇭' => 'ธง: กัมพูชา',
    '🇰🇮' => 'ธง: คิริบาส',
    '🇰🇲' => 'ธง: คอโมโรส',
    '🇰🇳' => 'ธง: เซนต์คิตส์และเนวิส',
    '🇰🇵' => 'ธง: เกาหลีเหนือ',
    '🇰🇷' => 'ธง: เกาหลีใต้',
    '🇰🇼' => 'ธง: คูเวต',
    '🇰🇾' => 'ธง: หมู่เกาะเคย์แมน',
    '🇰🇿' => 'ธง: คาซัคสถาน',
    '🇱🇦' => 'ธง: ลาว',
    '🇱🇧' => 'ธง: เลบานอน',
    '🇱🇨' => 'ธง: เซนต์ลูเซีย',
    '🇱🇮' => 'ธง: ลิกเตนสไตน์',
    '🇱🇰' => 'ธง: ศรีลังกา',
    '🇱🇷' => 'ธง: ไลบีเรีย',
    '🇱🇸' => 'ธง: เลโซโท',
    '🇱🇹' => 'ธง: ลิทัวเนีย',
    '🇱🇺' => 'ธง: ลักเซมเบิร์ก',
    '🇱🇻' => 'ธง: ลัตเวีย',
    '🇱🇾' => 'ธง: ลิเบีย',
    '🇲🇦' => 'ธง: โมร็อกโก',
    '🇲🇨' => 'ธง: โมนาโก',
    '🇲🇩' => 'ธง: มอลโดวา',
    '🇲🇪' => 'ธง: มอนเตเนโกร',
    '🇲🇫' => 'ธง: เซนต์มาร์ติน',
    '🇲🇬' => 'ธง: มาดากัสการ์',
    '🇲🇭' => 'ธง: หมู่เกาะมาร์แชลล์',
    '🇲🇰' => 'ธง: มาซิโดเนียเหนือ',
    '🇲🇱' => 'ธง: มาลี',
    '🇲🇲' => 'ธง: เมียนมา (พม่า)',
    '🇲🇳' => 'ธง: มองโกเลีย',
    '🇲🇴' => 'ธง: เขตปกครองพิเศษมาเก๊าแห่งสาธารณรัฐประชาชนจีน',
    '🇲🇵' => 'ธง: หมู่เกาะนอร์เทิร์นมาเรียนา',
    '🇲🇶' => 'ธง: มาร์ตินีก',
    '🇲🇷' => 'ธง: มอริเตเนีย',
    '🇲🇸' => 'ธง: มอนต์เซอร์รัต',
    '🇲🇹' => 'ธง: มอลตา',
    '🇲🇺' => 'ธง: มอริเชียส',
    '🇲🇻' => 'ธง: มัลดีฟส์',
    '🇲🇼' => 'ธง: มาลาวี',
    '🇲🇽' => 'ธง: เม็กซิโก',
    '🇲🇾' => 'ธง: มาเลเซีย',
    '🇲🇿' => 'ธง: โมซัมบิก',
    '🇳🇦' => 'ธง: นามิเบีย',
    '🇳🇨' => 'ธง: นิวแคลิโดเนีย',
    '🇳🇪' => 'ธง: ไนเจอร์',
    '🇳🇫' => 'ธง: เกาะนอร์ฟอล์ก',
    '🇳🇬' => 'ธง: ไนจีเรีย',
    '🇳🇮' => 'ธง: นิการากัว',
    '🇳🇱' => 'ธง: เนเธอร์แลนด์',
    '🇳🇴' => 'ธง: นอร์เวย์',
    '🇳🇵' => 'ธง: เนปาล',
    '🇳🇷' => 'ธง: นาอูรู',
    '🇳🇺' => 'ธง: นีอูเอ',
    '🇳🇿' => 'ธง: นิวซีแลนด์',
    '🇴🇲' => 'ธง: โอมาน',
    '🇵🇦' => 'ธง: ปานามา',
    '🇵🇪' => 'ธง: เปรู',
    '🇵🇫' => 'ธง: เฟรนช์โปลินีเซีย',
    '🇵🇬' => 'ธง: ปาปัวนิวกินี',
    '🇵🇭' => 'ธง: ฟิลิปปินส์',
    '🇵🇰' => 'ธง: ปากีสถาน',
    '🇵🇱' => 'ธง: โปแลนด์',
    '🇵🇲' => 'ธง: แซงปีแยร์และมีเกอลง',
    '🇵🇳' => 'ธง: หมู่เกาะพิตแคร์น',
    '🇵🇷' => 'ธง: เปอร์โตริโก',
    '🇵🇸' => 'ธง: ดินแดนปาเลสไตน์',
    '🇵🇹' => 'ธง: โปรตุเกส',
    '🇵🇼' => 'ธง: ปาเลา',
    '🇵🇾' => 'ธง: ปารากวัย',
    '🇶🇦' => 'ธง: กาตาร์',
    '🇷🇪' => 'ธง: เรอูนียง',
    '🇷🇴' => 'ธง: โรมาเนีย',
    '🇷🇸' => 'ธง: เซอร์เบีย',
    '🇷🇺' => 'ธง: รัสเซีย',
    '🇷🇼' => 'ธง: รวันดา',
    '🇸🇦' => 'ธง: ซาอุดีอาระเบีย',
    '🇸🇧' => 'ธง: หมู่เกาะโซโลมอน',
    '🇸🇨' => 'ธง: เซเชลส์',
    '🇸🇩' => 'ธง: ซูดาน',
    '🇸🇪' => 'ธง: สวีเดน',
    '🇸🇬' => 'ธง: สิงคโปร์',
    '🇸🇭' => 'ธง: เซนต์เฮเลนา',
    '🇸🇮' => 'ธง: สโลวีเนีย',
    '🇸🇯' => 'ธง: สฟาลบาร์และยานไมเอน',
    '🇸🇰' => 'ธง: สโลวะเกีย',
    '🇸🇱' => 'ธง: เซียร์ราลีโอน',
    '🇸🇲' => 'ธง: ซานมาริโน',
    '🇸🇳' => 'ธง: เซเนกัล',
    '🇸🇴' => 'ธง: โซมาเลีย',
    '🇸🇷' => 'ธง: ซูรินาเม',
    '🇸🇸' => 'ธง: ซูดานใต้',
    '🇸🇹' => 'ธง: เซาตูเมและปรินซิปี',
    '🇸🇻' => 'ธง: เอลซัลวาดอร์',
    '🇸🇽' => 'ธง: ซินต์มาร์เทน',
    '🇸🇾' => 'ธง: ซีเรีย',
    '🇸🇿' => 'ธง: เอสวาตีนี',
    '🇹🇦' => 'ธง: ทริสตันดาคูนา',
    '🇹🇨' => 'ธง: หมู่เกาะเติกส์และหมู่เกาะเคคอส',
    '🇹🇩' => 'ธง: ชาด',
    '🇹🇫' => 'ธง: เฟรนช์เซาเทิร์นเทร์ริทอรีส์',
    '🇹🇬' => 'ธง: โตโก',
    '🇹🇭' => 'ธง: ไทย',
    '🇹🇯' => 'ธง: ทาจิกิสถาน',
    '🇹🇰' => 'ธง: โตเกเลา',
    '🇹🇱' => 'ธง: ติมอร์-เลสเต',
    '🇹🇲' => 'ธง: เติร์กเมนิสถาน',
    '🇹🇳' => 'ธง: ตูนิเซีย',
    '🇹🇴' => 'ธง: ตองกา',
    '🇹🇷' => 'ธง: ตุรกี',
    '🇹🇹' => 'ธง: ตรินิแดดและโตเบโก',
    '🇹🇻' => 'ธง: ตูวาลู',
    '🇹🇼' => 'ธง: ไต้หวัน',
    '🇹🇿' => 'ธง: แทนซาเนีย',
    '🇺🇦' => 'ธง: ยูเครน',
    '🇺🇬' => 'ธง: ยูกันดา',
    '🇺🇲' => 'ธง: หมู่เกาะรอบนอกของสหรัฐอเมริกา',
    '🇺🇳' => 'ธง: สหประชาชาติ',
    '🇺🇸' => 'ธง: สหรัฐอเมริกา',
    '🇺🇾' => 'ธง: อุรุกวัย',
    '🇺🇿' => 'ธง: อุซเบกิสถาน',
    '🇻🇦' => 'ธง: นครวาติกัน',
    '🇻🇨' => 'ธง: เซนต์วินเซนต์และเกรนาดีนส์',
    '🇻🇪' => 'ธง: เวเนซุเอลา',
    '🇻🇬' => 'ธง: หมู่เกาะบริติชเวอร์จิน',
    '🇻🇮' => 'ธง: หมู่เกาะเวอร์จินของสหรัฐอเมริกา',
    '🇻🇳' => 'ธง: เวียดนาม',
    '🇻🇺' => 'ธง: วานูอาตู',
    '🇼🇫' => 'ธง: วาลลิสและฟุตูนา',
    '🇼🇸' => 'ธง: ซามัว',
    '🇽🇰' => 'ธง: โคโซโว',
    '🇾🇪' => 'ธง: เยเมน',
    '🇾🇹' => 'ธง: มายอต',
    '🇿🇦' => 'ธง: แอฟริกาใต้',
    '🇿🇲' => 'ธง: แซมเบีย',
    '🇿🇼' => 'ธง: ซิมบับเว',
    '🔟' => 'ปุ่มกดเลข: 10',
    '🏻' => 'โทนผิวสีขาว',
    '🏼' => 'โทนผิวสีขาวเหลือง',
    '🏽' => 'โทนผิวสีเหลือง',
    '🏾' => 'โทนผิวสีแทน',
    '🏿' => 'โทนผิวสีเข้ม',
    '😀' => 'หน้ายิ้มยิงฟัน',
    '😃' => 'หน้ายิ้มอ้าปาก',
    '😄' => 'หน้ายิ้มตายิ้ม และอ้าปาก',
    '😁' => 'ยิ้มยิงฟันตายิ้ม',
    '😆' => 'ยิ้มตาหยี',
    '😅' => 'ยิ้มเหงื่อตก',
    '🤣' => 'ขำกลิ้ง',
    '😂' => 'ร้องไห้ดีใจ',
    '🙂' => 'หน้ายิ้มบางๆ',
    '🙃' => 'หน้ากลับหัว',
    '🫠' => 'ใบหน้าละลาย',
    '😉' => 'ขยิบตา',
    '😊' => 'หน้ายิ้มตายิ้ม',
    '😇' => 'ยิ้มเทวดา',
    '🥰' => 'หน้ายิ้มพร้อมกับหัวใจหลายดวง',
    '😍' => 'ตาหัวใจ',
    '🤩' => 'หน้าตาเป็นประกาย',
    '😘' => 'หน้าส่งจุ๊บ',
    '😗' => 'หน้าจุ๊บ',
    '☺' => 'หน้ายิ้ม',
    '😚' => 'หยีตาส่งจุ๊บ',
    '😙' => 'หน้ายิ้มส่งจุ๊บ',
    '🥲' => 'ใบหน้ายิ้มทั้งน้ำตา',
    '😋' => 'แลบลิ้นมุมปาก',
    '😛' => 'แลบลิ้น',
    '😜' => 'แลบลิ้นหน้าทะเล้น',
    '🤪' => 'หน้าเพี้ยน',
    '😝' => 'แลบลิ้นตาหยี',
    '🤑' => 'หน้าเห็นแก่เงิน',
    '🤗' => 'ยิ้มกอด',
    '🤭' => 'เอามือปิดปาก',
    '🫢' => 'หน้าเบิกตากว้างและเอามือปิดปาก',
    '🫣' => 'หน้าแอบมอง',
    '🤫' => 'หน้าบอกให้เงียบ',
    '🤔' => 'หน้าครุ่นคิด',
    '🫡' => 'หน้าทำท่าวันทยาหัตถ์',
    '🤐' => 'รูดซิปปาก',
    '🤨' => 'หน้าประหลาดใจกับยักคิ้ว',
    '😐' => 'หน้าเฉยๆ',
    '😑' => 'หน้าเย็นชา',
    '😶' => 'หน้าไม่มีปาก',
    '🫥' => 'หน้าเป็นเส้นประ',
    '😏' => 'แสยะยิ้ม',
    '😒' => 'หน้าหน่าย',
    '🙄' => 'กลอกตา',
    '😬' => 'เบะปาก',
    '🤥' => 'ขี้โกหก',
    '🫨' => 'ใบหน้าสั่น',
    '😌' => 'โล่งใจ',
    '😔' => 'คิดไม่ตก',
    '😪' => 'ง่วง',
    '🤤' => 'น้ำลายไหล',
    '😴' => 'หลับ',
    '🫩' => 'ถุงใต้ตาบวม',
    '😷' => 'ผ้าคาดปาก',
    '🤒' => 'อมปรอท',
    '🤕' => 'หัวแตก',
    '🤢' => 'หน้าเขียว',
    '🤮' => 'หน้าอาเจียน',
    '🤧' => 'จาม',
    '🥵' => 'ร้อนมาก',
    '🥶' => 'หนาวสั่น',
    '🥴' => 'หน้างงงวย',
    '😵' => 'หน้ามึน',
    '🤯' => 'ช็อค',
    '🤠' => 'คาวบอยสวมหมวก',
    '🥳' => 'ไปปาร์ตี้',
    '🥸' => 'ปลอมตัว',
    '😎' => 'หน้ายิ้มใส่แว่น',
    '🤓' => 'เด็กเนิร์ด',
    '🧐' => 'หน้ากับแว่นเลนส์เดียว',
    '😕' => 'หน้าสับสน',
    '🫤' => 'หน้าสงสัย',
    '😟' => 'หน้ากังวล',
    '🙁' => 'หน้าบึ้งเล็กน้อย',
    '☹' => 'หน้าบึ้ง',
    '😮' => 'อ้าปาก',
    '😯' => 'หน้าจุ๊ๆ',
    '😲' => 'หน้าประหลาดใจ',
    '😳' => 'อายหน้าแดง',
    '🫪' => 'หน้าบิดเบี้ยว',
    '🥺' => 'หน้าอ้อนวอน',
    '🥹' => 'หน้ากลั้นน้ำตา',
    '😦' => 'หน้าบึ้งอ้าปาก',
    '😧' => 'หน้าเจ็บปวด',
    '😨' => 'หวาดกลัว',
    '😰' => 'กังวลเหงื่อตก',
    '😥' => 'โล่งอก',
    '😢' => 'ร้องไห้',
    '😭' => 'ร้องไห้โฮ',
    '😱' => 'กลัวกรีดร้อง',
    '😖' => 'หน้ารำคาญ',
    '😣' => 'อดทน',
    '😞' => 'หน้าผิดหวัง',
    '😓' => 'เหงื่อตก',
    '😩' => 'หน้าอิดโรย',
    '😫' => 'เหนื่อย',
    '🥱' => 'หน้ากำลังหาว',
    '😤' => 'หน้าข่มอารมณ์',
    '😡' => 'โกรธมาก',
    '😠' => 'หน้าโกรธ',
    '🤬' => 'หน้ากำลังด่า',
    '😈' => 'ยิ้มมีเขา',
    '👿' => 'หน้าบึ้งมีเขา',
    '💀' => 'หัวกระโหลก',
    '☠' => 'กะโหลกไขว้',
    '💩' => 'อุนจิ',
    '🤡' => 'หน้าตลก',
    '👹' => 'ยักษ์ญี่ปุ่น',
    '👺' => 'ปีศาจญี่ปุ่น',
    '👻' => 'ผี',
    '👽' => 'เอเลี่ยน',
    '👾' => 'สัตว์ประหลาดเอเลี่ยน',
    '🤖' => 'หุ่นยนต์',
    '😺' => 'แมวยิ้มอ้าปาก',
    '😸' => 'แมวยิ้มอ้าปากและยิ้มออกตา',
    '😹' => 'แมวร้องไห้ดีใจ',
    '😻' => 'แมวยิ้มมีตารูปหัวใจ',
    '😼' => 'แมวยิ้มเจ้าเล่ห์',
    '😽' => 'แมวส่งจุ๊บ',
    '🙀' => 'แมวตกใจ',
    '😿' => 'แมวร้องไห้',
    '😾' => 'แมวโกรธ',
    '🙈' => 'ลิงปิดตา',
    '🙉' => 'ลิงปิดหู',
    '🙊' => 'ลิงปิดปาก',
    '💌' => 'จดหมายรัก',
    '💘' => 'ศรปักใจ',
    '💝' => 'หัวใจผูกริบบิ้น',
    '💖' => 'หัวใจวิบวับ',
    '💗' => 'ใจพองโต',
    '💓' => 'หัวใจเต้น',
    '💞' => 'หัวใจโคจร',
    '💕' => 'ใจ 2 ดวง',
    '💟' => 'หัวใจประดับ',
    '❣' => 'เครื่องหมายอัศเจรีย์รูปหัวใจ',
    '💔' => 'อกหัก',
    '❤' => 'หัวใจสีแดง',
    '🩷' => 'หัวใจสีชมพู',
    '🧡' => 'หัวใจสีส้ม',
    '💛' => 'หัวใจสีเหลือง',
    '💚' => 'หัวใจสีเขียว',
    '💙' => 'หัวใจสีน้ำเงิน',
    '🩵' => 'หัวใจสีฟ้า',
    '💜' => 'หัวใจสีม่วง',
    '🤎' => 'หัวใจสีน้ำตาล',
    '🖤' => 'ใจดำ',
    '🩶' => 'หัวใจสีเทา',
    '🤍' => 'หัวใจสีขาว',
    '💋' => 'รอยจูบ',
    '💯' => 'คะแนนเต็ม',
    '💢' => 'สัญลักษณ์ความโกรธ',
    '🫯' => 'ก้อนเมฆต่อสู้',
    '💥' => 'การปะทะ',
    '💫' => 'มึนหัว',
    '💦' => 'เหงื่อหยด',
    '💨' => 'วิ่งฉิว',
    '🕳' => 'หลุม',
    '💬' => 'พูดไม่ออก',
    '🗨' => 'ฟองคำพูด',
    '🗯' => 'ฟองคำพูดรุนแรง',
    '💭' => 'ลูกโป่งความคิด',
    '💤' => 'หลับปุ๋ย',
    '👋' => 'โบกมือ',
    '🤚' => 'ยกมือ',
    '🖐' => 'ชูมือกางนิ้ว',
    '✋' => 'ตั้งฝ่ามือ',
    '🖖' => 'ชูนิ้วแบบวัลแคน',
    '🫱' => 'มือหันไปทางขวา',
    '🫲' => 'มือหันไปทางซ้าย',
    '🫳' => 'มือคว่ำฝ่ามือ',
    '🫴' => 'มือหงายฝ่ามือ',
    '🫷' => 'มือผลักไปทางซ้าย',
    '🫸' => 'มือผลักไปทางขวา',
    '👌' => 'ทำมือโอเค',
    '🤌' => 'หุบนิ้ว',
    '🤏' => 'ทำมือบีบนิ้วเข้าหากัน',
    '✌' => 'ชู 2 นิ้ว',
    '🤞' => 'นิ้วไขว้',
    '🫰' => 'นิ้วชี้ไขว้นิ้วโป้ง',
    '🤟' => 'ทำมือ ‘ฉันรักเธอ’',
    '🤘' => 'ชูนิ้วชาวร็อก',
    '🤙' => 'มือโทร',
    '👈' => 'นิ้วชี้ทางซ้าย',
    '👉' => 'นิ้วชี้ทางขวา',
    '👆' => 'หลังมือนิ้วชี้ขึ้น',
    '🖕' => 'ชูนิ้วกลาง',
    '👇' => 'นิ้วชี้ลง',
    '☝' => 'นิ้วชี้ขึ้น',
    '🫵' => 'นิ้วชี้ไปที่ผู้ดู',
    '👍' => 'ชูนิ้วโป้งขึ้น',
    '👎' => 'คว่ำนิ้วโป้งลง',
    '✊' => 'กำมือ',
    '👊' => 'กำปั้น',
    '🤛' => 'กำปั้นขวา',
    '🤜' => 'กำปั้นซ้าย',
    '👏' => 'ตบมือ',
    '🙌' => 'ชู 2 มือ',
    '🫶' => 'มือรูปหัวใจ',
    '👐' => 'แบมือ',
    '🤲' => 'แบสองมือ',
    '🤝' => 'จับมือ',
    '🙏' => 'พนมมือ',
    '✍' => 'เขียนหนังสือ',
    '💅' => 'สีทาเล็บ',
    '🤳' => 'เซลฟี่',
    '💪' => 'เบ่งกล้าม',
    '🦾' => 'แขนกล',
    '🦿' => 'ขากล',
    '🦵' => 'ขา',
    '🦶' => 'เท้า',
    '👂' => 'หู',
    '🦻' => 'หูใส่อุปกรณ์ช่วยฟัง',
    '👃' => 'จมูก',
    '🧠' => 'สมอง',
    '🫀' => 'หัวใจ',
    '🫁' => 'ปอด',
    '🦷' => 'ฟัน',
    '🦴' => 'กระดูก',
    '👀' => 'ตา 2 ข้าง',
    '👁' => 'ตาข้างเดียว',
    '👅' => 'ลิ้น',
    '👄' => 'ปาก',
    '🫦' => 'ขบริมฝีปาก',
    '👶' => 'ทารก',
    '🧒' => 'เด็ก',
    '👦' => 'เด็กชาย',
    '👧' => 'เด็กหญิง',
    '🧑' => 'คน',
    '👱' => 'คนผมทอง',
    '👨' => 'ผู้ชาย',
    '🧔' => 'ผู้ชายมีเครา',
    '👩' => 'ผู้หญิง',
    '🧓' => 'คนชรา',
    '👴' => 'ชายแก่',
    '👵' => 'หญิงแก่',
    '🙍' => 'ขมวดคิ้ว',
    '🙎' => 'ปากยื่น',
    '🙅' => 'มือทำท่าไม่โอเค',
    '🙆' => 'ทำท่าโอเค',
    '💁' => 'โต๊ะสอบถาม',
    '🙋' => 'ยกมือขึ้น',
    '🧏' => 'คนหูหนวก',
    '🙇' => 'ท่าขอโทษ',
    '🤦' => 'หมดกัน',
    '🤷' => 'ยักไหล่',
    '👮' => 'เจ้าหน้าที่ตำรวจ',
    '🕵' => 'นักสืบ',
    '💂' => 'การ์ดคุ้มกัน',
    '🥷' => 'นินจา',
    '👷' => 'คนงานก่อสร้าง',
    '🫅' => 'คนสวมมงกุฎ',
    '🤴' => 'เจ้าชาย',
    '👸' => 'เจ้าหญิง',
    '👳' => 'ชายโพกหัว',
    '👲' => 'ชายจีน',
    '🧕' => 'ผู้หญิงโพกศีรษะ',
    '🤵' => 'คนหล่อ',
    '👰' => 'เจ้าสาว',
    '🤰' => 'คนท้อง',
    '🫃' => 'ผู้ชายตั้งครรภ์',
    '🫄' => 'คนตั้งครรภ์',
    '🤱' => 'ให้นม',
    '👼' => 'นางฟ้าเด็ก',
    '🎅' => 'ซานต้า',
    '🤶' => 'นางซานต้า',
    '🦸' => 'ซุปเปอร์ฮีโร่',
    '🦹' => 'ยอดมนุษย์',
    '🧙' => 'นักเวทย์',
    '🧚' => 'นางฟ้า',
    '🧛' => 'แวมไพร์',
    '🧜' => 'ครึ่งคนครึ่งปลา',
    '🧝' => 'เอลฟ์',
    '🧞' => 'ยักษ์จีนี่',
    '🧟' => 'ซอมบี้',
    '🧌' => 'โทรลล์',
    '🫈' => 'สิ่งมีชีวิตขนยาว',
    '💆' => 'นวดหน้า',
    '💇' => 'ตัดผม',
    '🚶' => 'คนเดิน',
    '🧍' => 'คนกำลังยืน',
    '🧎' => 'คนกำลังคุกเข่า',
    '🏃' => 'คนวิ่ง',
    '💃' => 'นักเต้น',
    '🕺' => 'คนเต้น',
    '🕴' => 'คนใส่สูทลอยได้',
    '👯' => 'คนในชุดหูกระต่าย',
    '🧖' => 'คนในห้องอบไอน้ำ',
    '🧗' => 'นักไต่เขา',
    '🤺' => 'นักฟันดาบ',
    '🏇' => 'แข่งม้า',
    '⛷' => 'นักสกี',
    '🏂' => 'นักสโนว์บอร์ด',
    '🏌' => 'นักกอล์ฟ',
    '🏄' => 'นักโต้คลื่น',
    '🚣' => 'นักพายเรือ',
    '🏊' => 'นักว่ายน้ำ',
    '⛹' => 'คนเล่นบอล',
    '🏋' => 'นักยกน้ำหนัก',
    '🚴' => 'นักปั่นจักรยาน',
    '🚵' => 'นักปั่นจักรยานเสือภูเขา',
    '🤸' => 'คนตีลังกา',
    '🤼' => 'นักมวยปล้ำ',
    '🤽' => 'นักโปโลน้ำ',
    '🤾' => 'นักแฮนด์บอล',
    '🤹' => 'คนเล่นจั๊กกลิ้ง',
    '🧘' => 'คนนั่งสมาธิ',
    '🛀' => 'คนนอนแช่น้ำในอ่าง',
    '🛌' => 'คนนอนหลับ',
    '👭' => 'หญิง-หญิงจับมือ',
    '👫' => 'ชาย-หญิงจับมือ',
    '👬' => 'ชาย-ชายจับมือ',
    '💏' => 'จูบ',
    '💑' => 'คู่รัก',
    '🗣' => 'เงาคนกำลังพูด',
    '👤' => 'เงาครึ่งตัวคนเดียว',
    '👥' => 'เงาครึ่งตัว 2 คน',
    '🫂' => 'คนกอดกัน',
    '👪' => 'ครอบครัว',
    '👣' => 'รอยเท้า',
    '🫆' => 'ลายนิ้วมือ',
    '🦰' => 'ผมแดง',
    '🦱' => 'ผมหยิก',
    '🦳' => 'ผมขาว',
    '🦲' => 'หัวล้าน',
    '🐵' => 'หน้าลิง',
    '🐒' => 'ลิง',
    '🦍' => 'กอริลล่า',
    '🦧' => 'อุรังอุตัง',
    '🐶' => 'หน้าสุนัข',
    '🐕' => 'สุนัข',
    '🦮' => 'สุนัขนำทาง',
    '🐩' => 'พุดเดิ้ล',
    '🐺' => 'หมาป่า',
    '🦊' => 'จิ้งจอก',
    '🦝' => 'แรคคูน',
    '🐱' => 'หน้าแมว',
    '🐈' => 'แมว',
    '🦁' => 'สิงโต',
    '🐯' => 'หน้าเสือ',
    '🐅' => 'เสือ',
    '🐆' => 'เสือดาว',
    '🐴' => 'หน้าม้า',
    '🫎' => 'มูส',
    '🫏' => 'ลา',
    '🐎' => 'ม้า',
    '🦄' => 'ยูนิคอร์น',
    '🦓' => 'ม้าลาย',
    '🦌' => 'กวาง',
    '🦬' => 'ควายไบซัน',
    '🐮' => 'หน้าวัว',
    '🐂' => 'วัวตัวผู้',
    '🐃' => 'ควาย',
    '🐄' => 'วัว',
    '🐷' => 'หน้าหมู',
    '🐖' => 'หมู',
    '🐗' => 'หมูป่าตัวผู้',
    '🐽' => 'จมูกหมู',
    '🐏' => 'แกะตัวผู้',
    '🐑' => 'แกะ',
    '🐐' => 'แพะ',
    '🐪' => 'อูฐโหนกเดียว',
    '🐫' => 'อูฐสองโหนก',
    '🦙' => 'ลามะ',
    '🦒' => 'ยีราฟ',
    '🐘' => 'ช้าง',
    '🦣' => 'ช้างแมมมอธ',
    '🦏' => 'แรด',
    '🦛' => 'ฮิปโปโปเตมัส',
    '🐭' => 'หน้าหนู',
    '🐁' => 'หนูตัวเล็ก',
    '🐀' => 'หนูตัวใหญ่',
    '🐹' => 'หนูแฮมสเตอร์',
    '🐰' => 'หน้ากระต่าย',
    '🐇' => 'กระต่าย',
    '🐿' => 'ชิปมังก์',
    '🦫' => 'บีเวอร์',
    '🦔' => 'เฮดจ์ฮ็อก',
    '🦇' => 'ค้างคาว',
    '🐻' => 'หมี',
    '🐨' => 'โคอาล่า',
    '🐼' => 'แพนด้า',
    '🦥' => 'สลอธ',
    '🦦' => 'ตัวนาก',
    '🦨' => 'สกังก์',
    '🦘' => 'จิงโจ้',
    '🦡' => 'แบดเจอร์',
    '🐾' => 'รอยเท้าสัตว์',
    '🦃' => 'ไก่งวง',
    '🐔' => 'ไก่',
    '🐓' => 'ไก่ตัวผู้',
    '🐣' => 'ลูกเจี๊ยบออกจากไข่',
    '🐤' => 'ลูกเจี๊ยบ',
    '🐥' => 'ลูกเจี๊ยบยืนหันหน้า',
    '🐦' => 'นก',
    '🐧' => 'เพนกวิน',
    '🕊' => 'นกพิราบขาว',
    '🦅' => 'อินทรี',
    '🦆' => 'เป็ด',
    '🦢' => 'หงส์',
    '🦉' => 'นกฮูก',
    '🦤' => 'นกโดโด',
    '🪶' => 'ขนนก',
    '🦩' => 'นกฟลามิงโก',
    '🦚' => 'นกยูง',
    '🦜' => 'นกแก้ว',
    '🪽' => 'ปีก',
    '🪿' => 'ห่าน',
    '🐸' => 'กบ',
    '🐊' => 'จระเข้',
    '🐢' => 'เต่า',
    '🦎' => 'จิ้งจก',
    '🐍' => 'งู',
    '🐲' => 'หน้ามังกร',
    '🐉' => 'มังกร',
    '🦕' => 'ไดโนเสาร์',
    '🦖' => 'ทีเร็กซ์',
    '🐳' => 'ปลาวาฬพ่นน้ำ',
    '🐋' => 'ปลาวาฬ',
    '🐬' => 'ปลาโลมา',
    '🫍' => 'วาฬออร์กา',
    '🦭' => 'แมวน้ำ',
    '🐟' => 'ปลา',
    '🐠' => 'ปลาเขตร้อน',
    '🐡' => 'ปลาปักเป้า',
    '🦈' => 'ฉลาม',
    '🐙' => 'ปลาหมึกยักษ์',
    '🐚' => 'หอย',
    '🪸' => 'ปะการัง',
    '🪼' => 'แมงกะพรุน',
    '🦀' => 'ปู',
    '🦞' => 'กุ้งมังกร',
    '🦐' => 'กุ้ง',
    '🦑' => 'หมึก',
    '🦪' => 'หอยนางรม',
    '🐌' => 'หอยทาก',
    '🦋' => 'ผีเสื้อ',
    '🐛' => 'แมลง',
    '🐜' => 'มด',
    '🐝' => 'ผึ้ง',
    '🪲' => 'ด้วง',
    '🐞' => 'เต่าทอง',
    '🦗' => 'จิ้งหรีด',
    '🪳' => 'แมลงสาบ',
    '🕷' => 'แมงมุม',
    '🕸' => 'ใยแมงมุม',
    '🦂' => 'แมงป่อง',
    '🦟' => 'ยุง',
    '🪰' => 'แมลงวัน',
    '🪱' => 'หนอน',
    '🦠' => 'จุลินทรีย์',
    '💐' => 'ช่อดอกไม้',
    '🌸' => 'ดอกซากุระ',
    '💮' => 'ตราดอกไม้',
    '🪷' => 'ดอกบัว',
    '🏵' => 'ลายดอกกุหลาบ',
    '🌹' => 'ดอกกุหลาบ',
    '🥀' => 'ดอกไม้เหี่ยว',
    '🌺' => 'ดอกชบา',
    '🌻' => 'ดอกทานตะวัน',
    '🌼' => 'ดอกไม้บาน',
    '🌷' => 'ทิวลิป',
    '🪻' => 'ไฮยาซินธ์',
    '🌱' => 'ต้นอ่อน',
    '🪴' => 'ไม้กระถาง',
    '🌲' => 'ต้นสน',
    '🌳' => 'ต้นไม้ร่มรื่น',
    '🌴' => 'ต้นมะพร้าว',
    '🌵' => 'ตะบองเพชร',
    '🌾' => 'รวงข้าว',
    '🌿' => 'สมุนไพร',
    '☘' => 'ใบโคลเวอร์',
    '🍀' => 'ใบโคลเวอร์ 4 แฉก',
    '🍁' => 'ใบเมเปิ้ล',
    '🍂' => 'ใบไม้ร่วง',
    '🍃' => 'ใบไม้ปลิว',
    '🪹' => 'รังนกเปล่า',
    '🪺' => 'รังนกที่มีไข่',
    '🍄' => 'เห็ด',
    '🪾' => 'ต้นไม้ไร้ใบ',
    '🍇' => 'องุ่น',
    '🍈' => 'เมลอน',
    '🍉' => 'แตงโม',
    '🍊' => 'ส้ม',
    '🍋' => 'เลมอน',
    '🍌' => 'กล้วย',
    '🍍' => 'สับปะรด',
    '🥭' => 'มะม่วง',
    '🍎' => 'แอปเปิ้ลแดง',
    '🍏' => 'แอปเปิ้ลเขียว',
    '🍐' => 'ลูกแพร์',
    '🍑' => 'ลูกพีช',
    '🍒' => 'เชอร์รี่',
    '🍓' => 'สตรอว์เบอร์รี่',
    '🫐' => 'บลูเบอร์รี่',
    '🥝' => 'กีวี',
    '🍅' => 'มะเขือเทศ',
    '🫒' => 'มะกอก',
    '🥥' => 'มะพร้าว',
    '🥑' => 'อาโวคาโด',
    '🍆' => 'มะเขือยาว',
    '🥔' => 'มันฝรั่ง',
    '🥕' => 'แครอท',
    '🌽' => 'ข้าวโพด',
    '🌶' => 'พริก',
    '🫑' => 'พริกหยวก',
    '🥒' => 'แตงกวา',
    '🥬' => 'ผักใบเขียว',
    '🥦' => 'บรอกโคลี',
    '🧄' => 'กระเทียม',
    '🧅' => 'หอมหัวใหญ่',
    '🥜' => 'ถั่ว',
    '🫘' => 'เมล็ดถั่ว',
    '🌰' => 'เกาลัด',
    '🫚' => 'ขิง',
    '🫛' => 'ฝักถั่ว',
    '🫜' => 'พืชหัว',
    '🍞' => 'ขนมปัง',
    '🥐' => 'ครัวซอง',
    '🥖' => 'ขนมปังฝรั่งเศส',
    '🫓' => 'แฟลตเบรด',
    '🥨' => 'เพรตเซล',
    '🥯' => 'เบเกิล',
    '🥞' => 'แพนเค้ก',
    '🧇' => 'วาฟเฟิล',
    '🧀' => 'เนยแข็ง',
    '🍖' => 'เนื้อ',
    '🍗' => 'น่องไก่',
    '🥩' => 'เนื้อหั่นชิ้น',
    '🥓' => 'เบคอน',
    '🍔' => 'แฮมเบอร์เกอร์',
    '🍟' => 'เฟรนช์ฟราย',
    '🍕' => 'พิซซ่า 1 ชิ้น',
    '🌭' => 'ฮอทด็อก',
    '🥪' => 'แซนด์วิช',
    '🌮' => 'ทาโก้',
    '🌯' => 'เบอร์ริโต',
    '🫔' => 'ทามาเล่',
    '🥙' => 'เคบับ',
    '🧆' => 'ฟาลาเฟล',
    '🥚' => 'ไข่',
    '🍳' => 'ทำอาหาร',
    '🥘' => 'กระทะ',
    '🍲' => 'สตูว์',
    '🫕' => 'ฟองดูว์',
    '🥣' => 'ชามพร้อมช้อน',
    '🥗' => 'สลัด',
    '🍿' => 'ป๊อปคอร์น',
    '🧈' => 'เนย',
    '🧂' => 'เกลือ',
    '🥫' => 'อาหารกระป๋อง',
    '🍱' => 'กล่องเบนโตะ',
    '🍘' => 'ข้าวอบกรอบ',
    '🍙' => 'ข้าวปั้น',
    '🍚' => 'ข้าวสวย',
    '🍛' => 'ข้าวแกงกะหรี่',
    '🍜' => 'ราเมน',
    '🍝' => 'สปาเก็ตตี้',
    '🍠' => 'มันเผา',
    '🍢' => 'โอเด้ง',
    '🍣' => 'ซูชิ',
    '🍤' => 'กุ้งทอด',
    '🍥' => 'ลูกชิ้นปลา',
    '🥮' => 'ขนมไหว้พระจันทร์',
    '🍡' => 'ดังโงะ',
    '🥟' => 'เกี๊ยว',
    '🥠' => 'คุกกี้เสี่ยงทาย',
    '🥡' => 'อาหารกล่องซื้อกลับบ้าน',
    '🍦' => 'ซอฟต์ครีม',
    '🍧' => 'น้ำแข็งไส',
    '🍨' => 'ไอศกรีม',
    '🍩' => 'โดนัท',
    '🍪' => 'คุกกี้',
    '🎂' => 'เค้กวันเกิด',
    '🍰' => 'เค้ก',
    '🧁' => 'คัพเค้ก',
    '🥧' => 'พาย',
    '🍫' => 'ช็อกโกแลต',
    '🍬' => 'ลูกอม',
    '🍭' => 'อมยิ้ม',
    '🍮' => 'คัสตาร์ด',
    '🍯' => 'โถน้ำผึ้ง',
    '🍼' => 'ขวดนม',
    '🥛' => 'แก้วนม',
    '☕' => 'เครื่องดื่มร้อน',
    '🫖' => 'กาน้ำชา',
    '🍵' => 'ถ้วยชา',
    '🍶' => 'สาเก',
    '🍾' => 'แชมเปญ',
    '🍷' => 'ไวน์',
    '🍸' => 'ค็อกเทล',
    '🍹' => 'เครื่องดื่มผสมน้ำผลไม้',
    '🍺' => 'เบียร์',
    '🍻' => 'เหยือกเบียร์ชนกัน',
    '🥂' => 'ชนแก้ว',
    '🥃' => 'แก้วเหล้า',
    '🫗' => 'เทน้ำ',
    '🥤' => 'แก้วพร้อมหลอด',
    '🧋' => 'ชาไข่มุก',
    '🧃' => 'เครื่องดื่มแบบกล่อง',
    '🧉' => 'ชามาเต',
    '🧊' => 'ก้อนน้ำแข็ง',
    '🥢' => 'ตะเกียบ',
    '🍽' => 'จานพร้อมส้อมและมีด',
    '🍴' => 'ส้อมและมีด',
    '🥄' => 'ช้อน',
    '🔪' => 'มีดทำครัว',
    '🫙' => 'ขวดโหล',
    '🏺' => 'โถโบราณ',
    '🌍' => 'ลูกโลกแสดงทวีปยุโรปและแอฟริกา',
    '🌎' => 'ลูกโลกแสดงทวีปอเมริกา',
    '🌏' => 'ลูกโลกแสดงทวีปเอเชียและออสเตรเลีย',
    '🌐' => 'ลูกโลกแสดงเส้นเมริเดียน',
    '🗺' => 'แผนที่โลก',
    '🗾' => 'แผนที่ญี่ปุ่น',
    '🧭' => 'เข็มทิศ',
    '🏔' => 'ภูเขามีหิมะ',
    '⛰' => 'ภูเขา',
    '🛘' => 'ดินถล่ม',
    '🌋' => 'ภูเขาไฟ',
    '🗻' => 'ภูเขาไฟฟูจิ',
    '🏕' => 'ตั้งแคมป์',
    '🏖' => 'ร่มชายหาด',
    '🏜' => 'ทะเลทราย',
    '🏝' => 'เกาะ',
    '🏞' => 'อุทยาน',
    '🏟' => 'สนามกีฬา',
    '🏛' => 'อาคารสไตล์คลาสสิก',
    '🏗' => 'ก่อสร้างอาคาร',
    '🧱' => 'ก้อนอิฐ',
    '🪨' => 'หิน',
    '🪵' => 'ไม้',
    '🛖' => 'กระท่อม',
    '🏘' => 'บ้านหลายหลัง',
    '🏚' => 'บ้านร้าง',
    '🏠' => 'บ้านเดี่ยว',
    '🏡' => 'บ้านพร้อมสวน',
    '🏢' => 'ตึกสำนักงาน',
    '🏣' => 'ไปรษณีย์ญี่ปุ่น',
    '🏤' => 'ไปรษณีย์ยุโรป',
    '🏥' => 'โรงพยาบาล',
    '🏦' => 'ธนาคาร',
    '🏨' => 'โรงแรม',
    '🏩' => 'ม่านรูด',
    '🏪' => 'ร้านสะดวกซื้อ',
    '🏫' => 'โรงเรียน',
    '🏬' => 'ห้างสรรพสินค้า',
    '🏭' => 'โรงงาน',
    '🏯' => 'ปราสาทญี่ปุ่น',
    '🏰' => 'ปราสาทยุโรป',
    '💒' => 'งานแต่งงาน',
    '🗼' => 'โตเกียวทาวเวอร์',
    '🗽' => 'เทพีเสรีภาพ',
    '⛪' => 'โบสถ์',
    '🕌' => 'มัสยิด',
    '🛕' => 'วัดฮินดู',
    '🕍' => 'โบสถ์ยิว',
    '⛩' => 'ศาลเจ้าชินโต',
    '🕋' => 'วิหารกะอ์บะฮ์',
    '⛲' => 'น้ำพุ',
    '⛺' => 'เต็นท์',
    '🌁' => 'หมอกลง',
    '🌃' => 'ดาว',
    '🏙' => 'หมู่ตึกสูง',
    '🌄' => 'ดวงอาทิตย์โผล่พ้นเขา',
    '🌅' => 'ดวงอาทิตย์ขึ้น',
    '🌆' => 'เมืองยามโพล้เพล้',
    '🌇' => 'ดวงอาทิตย์ตก',
    '🌉' => 'สะพานกลางคืน',
    '♨' => 'น้ำพุร้อน',
    '🎠' => 'ม้าหมุน',
    '🛝' => 'กระดานลื่นของเล่น',
    '🎡' => 'ชิงช้าสวรรค์',
    '🎢' => 'รถไฟเหาะ',
    '💈' => 'ร้านตัดผม',
    '🎪' => 'ละครสัตว์',
    '🚂' => 'หัวรถจักรไอน้ำ',
    '🚃' => 'ตู้รถไฟ',
    '🚄' => 'ชินคันเซ็น',
    '🚅' => 'รถไฟความเร็วสูง',
    '🚆' => 'รถไฟ',
    '🚇' => 'รถไฟใต้ดิน',
    '🚈' => 'รถไฟรางเบา',
    '🚉' => 'สถานีรถไฟ',
    '🚊' => 'รถรางบนราง',
    '🚝' => 'รถไฟรางเดี่ยว',
    '🚞' => 'รางรถไฟภูเขา',
    '🚋' => 'ตู้รถราง',
    '🚌' => 'รถบัส',
    '🚍' => 'รถบัสกำลังมา',
    '🚎' => 'รถราง',
    '🚐' => 'มินิบัส',
    '🚑' => 'รถพยาบาล',
    '🚒' => 'รถดับเพลิง',
    '🚓' => 'รถตำรวจ',
    '🚔' => 'รถตำรวจกำลังมา',
    '🚕' => 'แท็กซี่',
    '🚖' => 'แท็กซี่กำลังมา',
    '🚗' => 'รถ',
    '🚘' => 'รถกำลังมา',
    '🚙' => 'รถบ้าน',
    '🛻' => 'รถกระบะ',
    '🚚' => 'รถขนส่ง',
    '🚛' => 'รถบรรทุก',
    '🚜' => 'แทร็กเตอร์',
    '🏎' => 'รถแข่ง',
    '🏍' => 'มอเตอร์ไซค์',
    '🛵' => 'รถสกู๊ตเตอร์',
    '🦽' => 'วีลแชร์ธรรมดา',
    '🦼' => 'วีลแชร์ไฟฟ้า',
    '🛺' => 'รถสามล้อ',
    '🚲' => 'จักรยาน',
    '🛴' => 'สกู๊ตเตอร์',
    '🛹' => 'สเก็ตบอร์ด',
    '🛼' => 'รองเท้าสเก็ต',
    '🚏' => 'ป้ายรถบัส',
    '🛣' => 'ทางด่วน',
    '🛤' => 'รางรถไฟ',
    '🛢' => 'ถังน้ำมัน',
    '⛽' => 'ปั๊มน้ำมัน',
    '🛞' => 'ล้อรถ',
    '🚨' => 'สัญญาณไฟตำรวจ',
    '🚥' => 'ไฟจราจรแนวนอน',
    '🚦' => 'ไฟจราจรแนวตั้ง',
    '🛑' => 'เครื่องหมายหยุด',
    '🚧' => 'ป้ายไซต์ก่อสร้าง',
    '⚓' => 'สมอเรือ',
    '🛟' => 'ห่วงชูชีพ',
    '⛵' => 'เรือใบ',
    '🛶' => 'แคนู',
    '🚤' => 'เรือด่วน',
    '🛳' => 'เรือโดยสาร',
    '⛴' => 'เรือเฟอร์รี',
    '🛥' => 'เรือยนต์',
    '🚢' => 'เรือ',
    '✈' => 'เครื่องบิน',
    '🛩' => 'เครื่องบินเล็ก',
    '🛫' => 'เครื่องบินขึ้น',
    '🛬' => 'เครื่องบินลง',
    '🪂' => 'ร่มชูชีพ',
    '💺' => 'ที่นั่ง',
    '🚁' => 'เฮลิคอปเตอร์',
    '🚟' => 'รถไฟสะพานแขวน',
    '🚠' => 'เคเบิลคาร์',
    '🚡' => 'รถกระเช้าลอยฟ้า',
    '🛰' => 'ดาวเทียม',
    '🚀' => 'จรวด',
    '🛸' => 'จานบิน',
    '🛎' => 'กระดิ่งโรงแรม',
    '🧳' => 'กระเป๋าเดินทาง',
    '⌛' => 'นาฬิกาทราย',
    '⏳' => 'นาฬิกาทรายจับเวลา',
    '⌚' => 'นาฬิกาข้อมือ',
    '⏰' => 'นาฬิกาปลุก',
    '⏱' => 'นาฬิกาจับเวลา',
    '⏲' => 'นาฬิกานับถอยหลัง',
    '🕰' => 'นาฬิกาบนหิ้ง',
    '🕛' => 'สิบสองนาฬิกา',
    '🕧' => 'สิบสองนาฬิกาครึ่ง',
    '🕐' => 'หนึ่งนาฬิกา',
    '🕜' => 'หนึ่งนาฬิกาครึ่ง',
    '🕑' => 'สองนาฬิกา',
    '🕝' => 'สองนาฬิกาครึ่ง',
    '🕒' => 'สามนาฬิกา',
    '🕞' => 'สามนาฬิกาครึ่ง',
    '🕓' => 'สี่นาฬิกา',
    '🕟' => 'สี่นาฬิกาครึ่ง',
    '🕔' => 'ห้านาฬิกา',
    '🕠' => 'ห้านาฬิกาครึ่ง',
    '🕕' => 'หกนาฬิกา',
    '🕡' => 'หกนาฬิกาครึ่ง',
    '🕖' => 'เจ็ดนาฬิกา',
    '🕢' => 'เจ็ดนาฬิกาครึ่ง',
    '🕗' => 'แปดนาฬิกา',
    '🕣' => 'แปดนาฬิกาครึ่ง',
    '🕘' => 'เก้านาฬิกา',
    '🕤' => 'เก้านาฬิกาครึ่ง',
    '🕙' => 'สิบนาฬิกา',
    '🕥' => 'สิบนาฬิกาครึ่ง',
    '🕚' => 'สิบเอ็ดนาฬิกา',
    '🕦' => 'สิบเอ็ดนาฬิกาครึ่ง',
    '🌑' => 'จันทร์ดับ',
    '🌒' => 'พระจันทร์เสี้ยวข้างขึ้น',
    '🌓' => 'พระจันทร์ครึ่งซีกขวา',
    '🌔' => 'ข้างขึ้น',
    '🌕' => 'พระจันทร์เต็มดวง',
    '🌖' => 'ข้างแรม',
    '🌗' => 'พระจันทร์ครึ่งซีกซ้าย',
    '🌘' => 'พระจันทร์เสี้ยวข้างแรม',
    '🌙' => 'พระจันทร์เสี้ยว',
    '🌚' => 'หน้าพระจันทร์ดับ',
    '🌛' => 'หน้าพระจันทร์เสี้ยวขวา',
    '🌜' => 'หน้าพระจันทร์เสี้ยวซ้าย',
    '🌡' => 'เครื่องวัดอุณหภูมิ',
    '☀' => 'พระอาทิตย์',
    '🌝' => 'หน้าพระจันทร์เต็มดวง',
    '🌞' => 'หน้าพระอาทิตย์',
    '🪐' => 'ดาวเคราะห์ที่มีวงแหวน',
    '⭐' => 'ดาวสีขาวขนาดกลาง',
    '🌟' => 'ดาวส่องแสง',
    '🌠' => 'ดาวตก',
    '🌌' => 'ทางช้างเผือก',
    '☁' => 'เมฆ',
    '⛅' => 'ดวงอาทิตย์หลังเมฆ',
    '⛈' => 'ฝนฟ้าคะนอง',
    '🌤' => 'เมฆน้อยบดบังพระอาทิตย์',
    '🌥' => 'เมฆก้อนใหญ่บังพระอาทิตย์',
    '🌦' => 'เมฆฝนบดบังพระอาทิตย์',
    '🌧' => 'เมฆฝน',
    '🌨' => 'เมฆและหิมะ',
    '🌩' => 'เมฆและฟ้าแลบ',
    '🌪' => 'พายุทอร์นาโด',
    '🌫' => 'หมอก',
    '🌬' => 'พ่นลม',
    '🌀' => 'ไซโคลน',
    '🌈' => 'รุ้ง',
    '🌂' => 'ร่มหุบ',
    '☂' => 'ร่ม',
    '☔' => 'ร่มและหยดน้ำฝน',
    '⛱' => 'ร่มปักดิน',
    '⚡' => 'ไฟฟ้าแรงสูง',
    '❄' => 'เกล็ดหิมะ',
    '☃' => 'สโนว์แมนและหิมะ',
    '⛄' => 'สโนว์แมน',
    '☄' => 'ดาวหาง',
    '🔥' => 'ไฟ',
    '💧' => 'หยดน้ำ',
    '🌊' => 'คลื่น',
    '🎃' => 'ฟักทองฮาโลวีน',
    '🎄' => 'ต้นคริสต์มาส',
    '🎆' => 'พลุ',
    '🎇' => 'ดอกไม้ไฟ',
    '🧨' => 'ประทัด',
    '✨' => 'ประกายวิบวับ',
    '🎈' => 'ลูกโป่ง',
    '🎉' => 'ปาร์ตี้',
    '🎊' => 'ลูกบอลใส่เศษกระดาษงานปาร์ตี้',
    '🎋' => 'ต้นไม้ประดับคำอวยพร',
    '🎍' => 'ต้นสนประดับ',
    '🎎' => 'ตุ๊กตาญี่ปุ่น',
    '🎏' => 'ธงปลาคาร์พ',
    '🎐' => 'โมบายล์กระดิ่ง',
    '🎑' => 'ไหว้พระจันทร์',
    '🧧' => 'อั่งเปา',
    '🎀' => 'ริบบิ้น',
    '🎁' => 'ของขวัญ',
    '🎗' => 'ริบบิ้นรำลึก',
    '🎟' => 'ตั๋วเข้าชม',
    '🎫' => 'ตั๋ว',
    '🎖' => 'เหรียญกล้าหาญ',
    '🏆' => 'ถ้วยรางวัล',
    '🏅' => 'เหรียญรางวัล',
    '🥇' => 'เหรียญทอง',
    '🥈' => 'เหรียญเงิน',
    '🥉' => 'เหรียญทองแดง',
    '⚽' => 'ลูกฟุตบอล',
    '⚾' => 'เบสบอล',
    '🥎' => 'ซอฟต์บอล',
    '🏀' => 'บาสเกตบอล',
    '🏐' => 'วอลเลย์บอล',
    '🏈' => 'อเมริกันฟุตบอล',
    '🏉' => 'รักบี้',
    '🎾' => 'เทนนิส',
    '🥏' => 'จานร่อน',
    '🎳' => 'โบว์ลิ่ง',
    '🏏' => 'คริกเก็ต',
    '🏑' => 'ฮอกกี้',
    '🏒' => 'ไม้ฮอกกี้',
    '🥍' => 'ลาครอส',
    '🏓' => 'ปิงปอง',
    '🏸' => 'แบดมินตัน',
    '🥊' => 'นวม',
    '🥋' => 'ชุดยูโด',
    '🥅' => 'โกล',
    '⛳' => 'ธงในหลุม',
    '⛸' => 'สเก็ตน้ำแข็ง',
    '🎣' => 'ตกปลา',
    '🤿' => 'หน้ากากดำน้ำ',
    '🎽' => 'เสื้อวิ่ง',
    '🎿' => 'สกี',
    '🛷' => 'เลื่อนหิมะ',
    '🥌' => 'ลูกกลิ้งหิน',
    '🎯' => 'กลางเป้า',
    '🪀' => 'โยโย่',
    '🪁' => 'ว่าว',
    '🔫' => 'ปืนฉีดน้ำ',
    '🎱' => 'บิลเลียด',
    '🔮' => 'ลูกแก้ววิเศษ',
    '🪄' => 'ไม้กายสิทธิ์',
    '🎮' => 'วิดีโอเกม',
    '🕹' => 'จอยสติ๊ก',
    '🎰' => 'สล็อตแมชชีน',
    '🎲' => 'ลูกเต๋า',
    '🧩' => 'จิ๊กซอว์',
    '🧸' => 'ตุ๊กตาหมี',
    '🪅' => 'ปิญญาตา',
    '🪩' => 'ลูกบอลกระจก',
    '🪆' => 'ตุ๊กตาแม่ลูกดก',
    '♠' => 'โพดำ',
    '♥' => 'โพแดง',
    '♦' => 'ข้าวหลามตัด',
    '♣' => 'ดอกจิก',
    '♟' => 'หมากรุก',
    '🃏' => 'ไพ่โจ๊กเกอร์',
    '🀄' => 'ไพ่นกกระจอกมังกรแดง',
    '🎴' => 'ไพ่ดอกไม้',
    '🎭' => 'หน้ากาก',
    '🖼' => 'รูปใส่กรอบ',
    '🎨' => 'จานสีวาดรูป',
    '🧵' => 'ด้าย',
    '🪡' => 'เข็มเย็บผ้า',
    '🧶' => 'ไหมพรม',
    '🪢' => 'เงื่อน',
    '👓' => 'แว่นตา',
    '🕶' => 'แว่นกันแดด',
    '🥽' => 'แว่นตากันลม',
    '🥼' => 'เสื้อกาวน์',
    '🦺' => 'เสื้อนิรภัย',
    '👔' => 'เนคไท',
    '👕' => 'เสื้อยืด',
    '👖' => 'ยีนส์',
    '🧣' => 'ผ้าพันคอ',
    '🧤' => 'ถุงมือ',
    '🧥' => 'เสื้อโค้ต',
    '🧦' => 'ถุงเท้า',
    '👗' => 'ชุดกระโปรง',
    '👘' => 'กิโมโน',
    '🥻' => 'ชุดส่าหรี',
    '🩱' => 'ชุดว่ายน้ำวันพีซ',
    '🩲' => 'กางเกงชั้นในชาย',
    '🩳' => 'กางเกงขาสั้น',
    '👙' => 'บิกินี',
    '👚' => 'เสื้อผู้หญิง',
    '🪭' => 'พัดแบบพับได้',
    '👛' => 'กระเป๋าใส่เงิน',
    '👜' => 'กระเป๋าถือ',
    '👝' => 'กระเป๋าใบเล็ก',
    '🛍' => 'ถุงช็อปปิ้ง',
    '🎒' => 'เป้นักเรียน',
    '🩴' => 'รองเท้าลำลอง',
    '👞' => 'รองเท้าชาย',
    '👟' => 'รองเท้ากีฬา',
    '🥾' => 'รองเท้าปีนเขา',
    '🥿' => 'รองเท้าส้นเตี้ย',
    '👠' => 'รองเท้าส้นสูง',
    '👡' => 'รองเท้าแตะผู้หญิง',
    '🩰' => 'รองเท้าบัลเล่ต์',
    '👢' => 'รองเท้าบู๊ตผู้หญิง',
    '🪮' => 'หวีส้อม',
    '👑' => 'มงกุฎ',
    '👒' => 'หมวกผู้หญิง',
    '🎩' => 'หมวกสูง',
    '🎓' => 'หมวกรับปริญญา',
    '🧢' => 'หมวกแก๊ป',
    '🪖' => 'หมวกทหาร',
    '⛑' => 'หมวกนิรภัยมีกากบาทขาว',
    '📿' => 'ลูกประคำ',
    '💄' => 'ลิปสติก',
    '💍' => 'แหวน',
    '💎' => 'อัญมณี',
    '🔇' => 'ไม่ใช้เสียง',
    '🔈' => 'ลำโพงเสียงเบา',
    '🔉' => 'ลำโพงเสียงปานกลาง',
    '🔊' => 'ลำโพงเสียงดัง',
    '📢' => 'เครื่องขยายเสียง',
    '📣' => 'โทรโข่ง',
    '📯' => 'แตรส่งสาร',
    '🔔' => 'กระดิ่ง',
    '🔕' => 'ไม่มีกระดิ่ง',
    '🎼' => 'บรรทัดห้าเส้น',
    '🎵' => 'โน้ตดนตรี',
    '🎶' => 'โน้ตดนตรีหลายตัว',
    '🎙' => 'ไมค์สตูดิโอ',
    '🎚' => 'ที่ปรับระดับเสียง',
    '🎛' => 'ปุ่มควบคุมเสียง',
    '🎤' => 'ไมโครโฟน',
    '🎧' => 'หูฟัง',
    '📻' => 'วิทยุ',
    '🎷' => 'แซ็กโซโฟน',
    '🎺' => 'ทรัมเป็ต',
    '🪊' => 'ทรอมโบน',
    '🪗' => 'แอคคอร์เดียน',
    '🎸' => 'กีต้าร์',
    '🎹' => 'เปียโน',
    '🎻' => 'ไวโอลิน',
    '🪕' => 'แบนโจ',
    '🥁' => 'กลอง',
    '🪘' => 'กลองยาว',
    '🪇' => 'มาราคัส',
    '🪈' => 'ขลุ่ย',
    '🪉' => 'ฮาร์ป',
    '📱' => 'โทรศัพท์มือถือ',
    '📲' => 'โทรศัพท์มือถือพร้อมลูกศรชี้',
    '☎' => 'โทรศัพท์',
    '📞' => 'หูโทรศัพท์',
    '📟' => 'เพจเจอร์',
    '📠' => 'แฟกซ์',
    '🔋' => 'แบตเตอรี่',
    '🪫' => 'แบตเตอรี่ต่ำ',
    '🔌' => 'ปลั๊กไฟ',
    '💻' => 'แล็ปท็อป',
    '🖥' => 'คอมพิวเตอร์เดสก์ท็อป',
    '🖨' => 'เครื่องพิมพ์',
    '⌨' => 'แป้นพิมพ์',
    '🖱' => 'เมาส์',
    '🖲' => 'แทร็กบอล',
    '💽' => 'แผ่นดิสก์',
    '💾' => 'ฟลอปปี้ดิสก์',
    '💿' => 'บลูเรย์',
    '📀' => 'ดีวีดี',
    '🧮' => 'ลูกคิด',
    '🎥' => 'กล้องถ่ายภาพยนตร์',
    '🎞' => 'เฟรมภาพยนตร์',
    '📽' => 'เครื่องฉายหนัง',
    '🎬' => 'สเลท',
    '📺' => 'ทีวี',
    '📷' => 'กล้อง',
    '📸' => 'กล้องเปิดแฟลช',
    '📹' => 'กล้องวิดีโอ',
    '📼' => 'วิดีโอเทป',
    '🔍' => 'แว่นขยายเอียงซ้าย',
    '🔎' => 'แว่นขยายเอียงขวา',
    '🕯' => 'เทียน',
    '💡' => 'หลอดไฟ',
    '🔦' => 'ไฟฉาย',
    '🏮' => 'โคมไฟแดง',
    '🪔' => 'ตะเกียงดิยา',
    '📔' => 'สมุดโน้ตมีลาย',
    '📕' => 'หนังสือปิด',
    '📖' => 'หนังสือเปิด',
    '📗' => 'หนังสือสีเขียว',
    '📘' => 'หนังสือสีน้ำเงิน',
    '📙' => 'หนังสือสีส้ม',
    '📚' => 'หนังสือ',
    '📓' => 'สมุดโน้ต',
    '📒' => 'สมุดโน้ตเจาะรูข้าง',
    '📃' => 'เอกสารม้วนปลาย',
    '📜' => 'ม้วนกระดาษ',
    '📄' => 'เอกสาร',
    '📰' => 'หนังสือพิมพ์',
    '🗞' => 'ม้วนหนังสือพิมพ์',
    '📑' => 'แถบคั่นหน้า',
    '🔖' => 'ที่คั่นหนังสือ',
    '🏷' => 'ป้าย',
    '🪙' => 'เหรียญ',
    '💰' => 'ถุงเงิน',
    '🪎' => 'หีบสมบัติ',
    '💴' => 'ธนบัตรเยน',
    '💵' => 'ธนบัตรดอลลาร์',
    '💶' => 'ธนบัตรยูโร',
    '💷' => 'ธนบัตรปอนด์',
    '💸' => 'เงินบิน',
    '💳' => 'บัตรเครดิต',
    '🧾' => 'ใบเสร็จ',
    '💹' => 'ตลาดขึ้น',
    '✉' => 'ซองจดหมาย',
    '📧' => 'อีเมล',
    '📨' => 'จดหมายเข้า',
    '📩' => 'จดหมายออก',
    '📤' => 'กล่องขาออก',
    '📥' => 'กล่องขาเข้า',
    '📦' => 'พัสดุ',
    '📫' => 'กล่องจดหมายปิดยกธง',
    '📪' => 'กล่องจดหมายปิดคว่ำธง',
    '📬' => 'กล่องจดหมายมีจดหมาย',
    '📭' => 'กล่องจดหมายว่าง',
    '📮' => 'ตู้ไปรษณีย์',
    '🗳' => 'หีบบัตรลงคะแนน',
    '✏' => 'ดินสอ',
    '✒' => 'ปลายปากกาสีดำ',
    '🖋' => 'ปากกาหมึกซึม',
    '🖊' => 'ปากกา',
    '🖌' => 'แปรงทาสี',
    '🖍' => 'ดินสอสี',
    '📝' => 'จดบันทึก',
    '💼' => 'กระเป๋าเอกสาร',
    '📁' => 'แฟ้มเอกสาร',
    '📂' => 'เปิดเอกสาร',
    '🗂' => 'ที่คั่นบัตรรายการ',
    '📅' => 'ปฏิทิน',
    '📆' => 'ปฏิทินแบบฉีกออก',
    '🗒' => 'สมุดโน้ตสันห่วง',
    '🗓' => 'ปฏิทินสันห่วง',
    '📇' => 'ที่ใส่บัตร',
    '📈' => 'แนวโน้มขึ้น',
    '📉' => 'แนวโน้มลง',
    '📊' => 'กราฟแท่ง',
    '📋' => 'คลิปบอร์ด',
    '📌' => 'หมุดปัก',
    '📍' => 'หมุดหัวกลม',
    '📎' => 'คลิปหนีบกระดาษ',
    '🖇' => 'คลิปหนีบกระดาษคู่',
    '📏' => 'ไม้บรรทัดตรง',
    '📐' => 'ไม้บรรทัดสามเหลี่ยม',
    '✂' => 'กรรไกร',
    '🗃' => 'กล่องใส่แฟ้ม',
    '🗄' => 'ตู้เอกสาร',
    '🗑' => 'ตะกร้าขยะ',
    '🔒' => 'ล็อคปิด',
    '🔓' => 'ล็อคเปิด',
    '🔏' => 'ล็อคด้วยปากกา',
    '🔐' => 'ล็อคด้วยกุญแจ',
    '🔑' => 'กุญแจ',
    '🗝' => 'กุญแจเก่า',
    '🔨' => 'ค้อน',
    '🪓' => 'ขวาน',
    '⛏' => 'จอบ',
    '⚒' => 'ค้อนและจอบ',
    '🛠' => 'ค้อนและประแจ',
    '🗡' => 'ดาบสั้น',
    '⚔' => 'ดาบไขว้',
    '💣' => 'ระเบิด',
    '🪃' => 'บูมเมอแรง',
    '🏹' => 'ธนูและลูกศร',
    '🛡' => 'โล่',
    '🪚' => 'เลื่อย',
    '🔧' => 'ประแจ',
    '🪛' => 'ไขควง',
    '🔩' => 'สลักและน็อต',
    '⚙' => 'เฟือง',
    '🗜' => 'เครื่องบีบอัด',
    '⚖' => 'ตราชั่ง',
    '🦯' => 'ไม้เท้านำทาง',
    '🔗' => 'สัญลักษณ์การลิงก์',
    '⛓' => 'โซ่',
    '🪝' => 'ตะขอ',
    '🧰' => 'กล่องเครื่องมือ',
    '🧲' => 'แม่เหล็ก',
    '🪜' => 'บันไดปีน',
    '🪏' => 'พลั่ว',
    '⚗' => 'อุปกรณ์กลั่น',
    '🧪' => 'หลอดทดลอง',
    '🧫' => 'จานเพาะเชื้อ',
    '🧬' => 'ดีเอ็นเอ',
    '🔬' => 'กล้องจุลทรรศน์',
    '🔭' => 'กล้องโทรทรรศน์',
    '📡' => 'จานดาวเทียม',
    '💉' => 'กระบอกฉีดยา',
    '🩸' => 'หยดเลือด',
    '💊' => 'ยาเม็ด',
    '🩹' => 'พลาสเตอร์ปิดแผล',
    '🩼' => 'ไม้เท้าค้ำยัน',
    '🩺' => 'เครื่องฟังตรวจ',
    '🩻' => 'เอ็กซ์เรย์',
    '🚪' => 'ประตู',
    '🛗' => 'ลิฟต์',
    '🪞' => 'กระจก',
    '🪟' => 'หน้าต่าง',
    '🛏' => 'เตียง',
    '🛋' => 'โซฟากับโคมไฟ',
    '🪑' => 'เก้าอี้',
    '🚽' => 'โถส้วม',
    '🪠' => 'ที่ปั๊มชักโครก',
    '🚿' => 'ฝักบัว',
    '🛁' => 'อ่างอาบน้ำ',
    '🪤' => 'กับดักหนู',
    '🪒' => 'ใบมีดโกน',
    '🧴' => 'ขวดโลชั่น',
    '🧷' => 'เข็มกลัดซ่อนปลาย',
    '🧹' => 'ไม้กวาด',
    '🧺' => 'ตะกร้า',
    '🧻' => 'กระดาษชำระ',
    '🪣' => 'ถัง',
    '🧼' => 'สบู่',
    '🫧' => 'ฟอง',
    '🪥' => 'แปรงสีฟัน',
    '🧽' => 'ฟองน้ำ',
    '🧯' => 'ที่ดับเพลิง',
    '🛒' => 'รถเข็น',
    '🚬' => 'ป้ายสูบบุหรี่',
    '⚰' => 'โลงศพ',
    '🪦' => 'แผ่นหินจารึก',
    '⚱' => 'โกศกระดูก',
    '🧿' => 'เครื่องราง',
    '🪬' => 'มือฮัมซา',
    '🗿' => 'รูปปั้นโมไอ',
    '🪧' => 'ป้ายประกาศ',
    '🪪' => 'บัตรประชาชน',
    '🏧' => 'เอทีเอ็ม',
    '🚮' => 'ทิ้งขยะให้ลงถัง',
    '🚰' => 'น้ำดื่ม',
    '♿' => 'รถเข็นผู้ป่วย',
    '🚹' => 'ห้องน้ำชาย',
    '🚺' => 'ห้องน้ำหญิง',
    '🚻' => 'ห้องน้ำ',
    '🚼' => 'ป้ายทารก',
    '🚾' => 'ป้ายห้องน้ำ',
    '🛂' => 'ตรวจพาสปอร์ต',
    '🛃' => 'ศุลกากร',
    '🛄' => 'รับสัมภาระ',
    '🛅' => 'บริการฝากกระเป๋า',
    '⚠' => 'ป้ายระวัง',
    '🚸' => 'เด็กๆ ข้ามถนน',
    '⛔' => 'ป้ายห้ามเข้า',
    '🚫' => 'ป้ายหวงห้าม',
    '🚳' => 'ห้ามจักรยาน',
    '🚭' => 'ป้ายห้ามสูบบุหรี่',
    '🚯' => 'ห้ามทิ้งขยะ',
    '🚱' => 'ห้ามดื่มน้ำ',
    '🚷' => 'ห้ามคนเดินเท้า',
    '📵' => 'ห้ามใช้โทรศัพท์',
    '🔞' => 'ห้ามอายุต่ำกว่า 18 ปี',
    '☢' => 'กัมมันตรังสี',
    '☣' => 'เชื้อโรคอันตราย',
    '⬆' => 'ลูกศรชี้ขึ้น',
    '↗' => 'ลูกศรชี้มุมขวาบน',
    '➡' => 'ลูกศรชี้ไปทางขวา',
    '↘' => 'ลูกศรชี้มุมขวาล่าง',
    '⬇' => 'ลูกศรชี้ลง',
    '↙' => 'ลูกศรชี้มุุมซ้ายล่าง',
    '⬅' => 'ลูกศรชี้ไปทางซ้าย',
    '↖' => 'ลูกศรชี้มุมซ้ายบน',
    '↕' => 'ลูกศรชี้ขึ้นลง',
    '↔' => 'ลูกศรชี้ซ้ายขวา',
    '↩' => 'ลูกศรวนซ้าย',
    '↪' => 'ลูกศรวนขวา',
    '⤴' => 'ลูกศรโค้งขึ้น',
    '⤵' => 'ลูกศรโค้งลง',
    '🔃' => 'สัญลักษณ์โหลดซ้ำ',
    '🔄' => 'ลูกศรทวนเข็มนาฬิกา',
    '🔙' => 'กลับ',
    '🔚' => 'สิ้นสุด',
    '🔛' => 'เปิด',
    '🔜' => 'สัญลักษณ์เร็วๆ นี้',
    '🔝' => 'สัญลักษณ์บน',
    '🛐' => 'ที่บูชา',
    '⚛' => 'อะตอม',
    '🕉' => 'เครื่องหมายโอม',
    '✡' => 'สตาร์ออฟเดวิด',
    '☸' => 'ธรรมจักร',
    '☯' => 'หยินหยาง',
    '✝' => 'ไม้กางเขนละติน',
    '☦' => 'ไม้กางเขนออร์โธดอกซ์',
    '☪' => 'พระจันทร์เสี้ยวและดาว',
    '☮' => 'เครื่องหมายสันติภาพ',
    '🕎' => 'เชิงเทียน 7 กิ่ง',
    '🔯' => 'ดาว 6 แฉก',
    '🪯' => 'ขัณฑา',
    '♈' => 'ราศีเมษ',
    '♉' => 'ราศีพฤษภ',
    '♊' => 'ราศีเมถุน',
    '♋' => 'ราศีกรกฎ',
    '♌' => 'ราศีสิงห์',
    '♍' => 'ราศีกันย์',
    '♎' => 'ราศีตุลย์',
    '♏' => 'ราศีพิจิก',
    '♐' => 'ราศีธนู',
    '♑' => 'ราศีมังกร',
    '♒' => 'ราศีกุมภ์',
    '♓' => 'ราศีมีน',
    '⛎' => 'กลุ่มดาวคนแบกงู',
    '🔀' => 'ลูกศรไขว้',
    '🔁' => 'เล่นซ้ำ',
    '🔂' => 'เล่นซ้ำเพลงเดียว',
    '▶' => 'เล่น',
    '⏩' => 'เร่งไปข้างหน้า',
    '⏭' => 'เล่นแทร็กถัดไป',
    '⏯' => 'เล่นหรือหยุดชั่วคราว',
    '◀' => 'ย้อนกลับ',
    '⏪' => 'ถอยกลับ',
    '⏮' => 'ปุ่มแทร็กก่อนหน้า',
    '🔼' => 'ปุ่มสามเหลี่ยมขึ้น',
    '⏫' => 'ลูกศรขึ้น',
    '🔽' => 'ปุ่มสามเหลี่ยมลง',
    '⏬' => 'ลูกศรลง',
    '⏸' => 'ปุ่มหยุุดชั่วคราว',
    '⏹' => 'ปุ่มหยุด',
    '⏺' => 'ปุ่มอัด',
    '⏏' => 'ปุ่มดีดออก',
    '🎦' => 'โรงภาพยนตร์',
    '🔅' => 'แสงสว่างน้อย',
    '🔆' => 'แสงสว่างมาก',
    '📶' => 'สัญญาณมือถือ',
    '🛜' => 'ไร้สาย',
    '📳' => 'โหมดสั่น',
    '📴' => 'ปิดมือถือ',
    '♀' => 'สัญลักษณ์เพศหญิง',
    '♂' => 'สัญลักษณ์เพศชาย',
    '⚧' => 'สัญลักษณ์คนข้ามเพศ',
    '✖' => 'คูณ',
    '➕' => 'บวก',
    '➖' => 'ลบ',
    '➗' => 'หาร',
    '🟰' => 'เครื่องหมายเท่ากับตัวหนา',
    '♾' => 'ไม่มีที่สิ้นสุด',
    '‼' => 'เครื่องหมายอัศเจรีย์คู่',
    '⁉' => 'เครื่องหมายอัศเจรีย์และคำถาม',
    '❓' => 'เครื่องหมายคำถาม',
    '❔' => 'เครื่องหมายคำถามสีขาว',
    '❕' => 'เครื่องหมายอัศเจรีย์สีขาว',
    '❗' => 'เครื่องหมายอัศเจรีย์สีแดง',
    '〰' => 'เส้นคลื่น',
    '💱' => 'การแลกเปลี่ยนเงิน',
    '💲' => 'สัญลักษณ์ดอลลาร์',
    '⚕' => 'เครื่องหมายการแพทย์',
    '♻' => 'สัญลักษณ์รีไซเคิล',
    '⚜' => 'สัญลักษณ์ดอกลิลลี่',
    '🔱' => 'ฉมวก',
    '📛' => 'ป้ายชื่อ',
    '🔰' => 'สัญลักษณ์มือใหม่หัดขับ',
    '⭕' => 'วงกลมกลวงสีแดง',
    '✅' => 'ปุ่มเครื่องหมายถูก',
    '☑' => 'กล่องกาเครื่องหมายมีเครื่องหมายถูก',
    '✔' => 'เครื่องหมายถูก',
    '❌' => 'เครื่องหมายกากบาท',
    '❎' => 'ปุ่มเครื่องหมายกากบาท',
    '➰' => 'ห่วง',
    '➿' => 'ห่วง 2 รู',
    '〽' => 'เครื่องหมายเปลี่ยนท่อน',
    '✳' => 'ดอกจัน 8 ซี่',
    '✴' => 'ดาว 8 แฉก',
    '❇' => 'เปล่งประกาย',
    '™' => 'เครื่องหมายการค้า',
    '🫟' => 'กระเด็น',
    '🔠' => 'อักษรตัวพิมพ์ใหญ่',
    '🔡' => 'อักษรตัวพิมพ์เล็ก',
    '🔢' => 'หมายเลข',
    '🔣' => 'สัญลักษณ์',
    '🔤' => 'ตัวอักษรภาษาอังกฤษ',
    '🅰' => 'เลือดกรุ๊ปเอ',
    '🆎' => 'เลือดกรุ๊ปเอบี',
    '🅱' => 'เลือดกรุ๊ปบี',
    '🆑' => 'ลบข้อมูล',
    '🆒' => 'เย็น',
    '🆓' => 'ฟรี',
    'ℹ' => 'แหล่งข้อมูล',
    '🆔' => 'หมายเลขประจำตัว',
    'Ⓜ' => 'ตัวเอ็มในวงกลม',
    '🆕' => 'ใหม่',
    '🆖' => 'ปุ่มเอ็นจี',
    '🅾' => 'เลือดกรุ๊ปโอ',
    '🆗' => 'โอเค',
    '🅿' => 'ที่จอดรถ',
    '🆘' => 'ช่วยด้วย',
    '🆙' => 'ขึ้น',
    '🆚' => 'ต่อสู้กับ',
    '🈁' => 'ภาษาญี่ปุ่นคำว่า “ที่นี่”',
    '🈂' => 'ภาษาญี่ปุ่นคำว่า “ค่าบริการ”',
    '🈷' => 'ภาษาญี่ปุ่นคำว่า “จำนวนต่อเดือน”',
    '🈶' => 'ภาษาญี่ปุ่นคำว่า “คิดค่าใช้จ่าย”',
    '🈯' => 'ภาษาญี่ปุ่นคำว่า “จองแล้ว”',
    '🉐' => 'ภาษาญี่ปุ่นคำว่า “ราคาถูก”',
    '🈹' => 'ภาษาญี่ปุ่นคำว่า “ส่วนลด”',
    '🈚' => 'ภาษาญี่ปุ่นคำว่า “ไม่มี”',
    '🈲' => 'ภาษาญี่ปุ่นคำว่า “ห้าม”',
    '🉑' => 'ภาษาญี่ปุ่นคำว่า “ยอมรับได้”',
    '🈸' => 'ภาษาญี่ปุ่นคำว่า “ใบสมัคร”',
    '🈴' => 'ภาษาญี่ปุ่นคำว่า “ผ่าน”',
    '🈳' => 'ภาษาจีนว่างเปล่า',
    '㊗' => 'ภาษาญี่ปุ่นคำว่า “แสดงความยินดี”',
    '㊙' => 'ภาษาญี่ปุ่นคำว่า “ความลับ”',
    '🈺' => 'ภาษาญี่ปุ่นคำว่า “เปิดทำการ”',
    '🈵' => 'ภาษาญี่ปุ่นคำว่า “เต็ม”',
    '🔴' => 'วงกลมสีแดง',
    '🟠' => 'วงกลมสีส้ม',
    '🟡' => 'วงกลมสีเหลือง',
    '🟢' => 'วงกลมสีเขียว',
    '🔵' => 'วงกลมสีน้ำเงิน',
    '🟣' => 'วงกลมสีม่วง',
    '🟤' => 'วงกลมสีน้ำตาล',
    '⚫' => 'วงกลมสีดำ',
    '⚪' => 'วงกลมสีขาว',
    '🟥' => 'สี่เหลี่ยมสีแดง',
    '🟧' => 'สี่เหลี่ยมสีส้ม',
    '🟨' => 'สี่เหลี่ยมสีเหลือง',
    '🟩' => 'สี่เหลี่ยมสีเขียว',
    '🟦' => 'สี่เหลี่ยมสีน้ำเงิน',
    '🟪' => 'สี่เหลี่ยมสีม่วง',
    '🟫' => 'สี่เหลี่ยมสีน้ำตาล',
    '⬛' => 'สี่เหลี่ยมใหญ่สีดำ',
    '⬜' => 'สี่เหลี่ยมใหญ่สีขาว',
    '◼' => 'สี่เหลี่ยมขนาดกลางสีดำ',
    '◻' => 'สี่เหลี่ยมขนาดกลางสีขาว',
    '◾' => 'สี่เหลี่ยมเล็กปานกลางสีดำ',
    '◽' => 'สี่เหลี่ยมเล็กปานกลางสีขาว',
    '▪' => 'สี่เหลี่ยมเล็กสีดำ',
    '▫' => 'สี่เหลี่ยมเล็กสีขาว',
    '🔶' => 'เพชรใหญ่สีส้ม',
    '🔷' => 'เพชรใหญ่สีน้ำเงิน',
    '🔸' => 'เพชรเล็กสีส้ม',
    '🔹' => 'เพชรเล็กสีน้ำเงิน',
    '🔺' => 'สามเหลี่ยมหงายสีแดง',
    '🔻' => 'สามเหลี่ยมคว่ำสีแดง',
    '💠' => 'ข้าวหลามตัดมีจุดตรงกลาง',
    '🔘' => 'ปุ่มวิทยุ',
    '🔳' => 'ปุ่มสี่เหลี่ยมขอบขาว',
    '🔲' => 'ปุ่มสี่เหลี่ยมขอบดำ',
    '🏁' => 'ธงตราหมากรุก',
    '🚩' => 'ธงปักตำแหน่ง',
    '🎌' => 'ธงไขว้',
    '🏴' => 'ธงดำ',
    '🏳' => 'ธงขาว',
];
