<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'поцелуй: взрослый взрослый очень светлый тон кожи светлый тон кожи',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'поцелуй: взрослый взрослый очень светлый тон кожи средний тон кожи',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'поцелуй: взрослый взрослый очень светлый тон кожи темный тон кожи',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'поцелуй: взрослый взрослый очень светлый тон кожи очень темный тон кожи',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'поцелуй: взрослый взрослый светлый тон кожи очень светлый тон кожи',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'поцелуй: взрослый взрослый светлый тон кожи средний тон кожи',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'поцелуй: взрослый взрослый светлый тон кожи темный тон кожи',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'поцелуй: взрослый взрослый светлый тон кожи очень темный тон кожи',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'поцелуй: взрослый взрослый средний тон кожи очень светлый тон кожи',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'поцелуй: взрослый взрослый средний тон кожи светлый тон кожи',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'поцелуй: взрослый взрослый средний тон кожи темный тон кожи',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'поцелуй: взрослый взрослый средний тон кожи очень темный тон кожи',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'поцелуй: взрослый взрослый темный тон кожи очень светлый тон кожи',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'поцелуй: взрослый взрослый темный тон кожи светлый тон кожи',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'поцелуй: взрослый взрослый темный тон кожи средний тон кожи',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'поцелуй: взрослый взрослый темный тон кожи очень темный тон кожи',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'поцелуй: взрослый взрослый очень темный тон кожи очень светлый тон кожи',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'поцелуй: взрослый взрослый очень темный тон кожи светлый тон кожи',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'поцелуй: взрослый взрослый очень темный тон кожи средний тон кожи',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'поцелуй: взрослый взрослый очень темный тон кожи темный тон кожи',
    '👨🏻‍❤‍💋‍👨🏻' => 'поцелуй: мужчина мужчина очень светлый тон кожи',
    '👨🏻‍❤‍💋‍👨🏼' => 'поцелуй: мужчина мужчина очень светлый тон кожи светлый тон кожи',
    '👨🏻‍❤‍💋‍👨🏽' => 'поцелуй: мужчина мужчина очень светлый тон кожи средний тон кожи',
    '👨🏻‍❤‍💋‍👨🏾' => 'поцелуй: мужчина мужчина очень светлый тон кожи темный тон кожи',
    '👨🏻‍❤‍💋‍👨🏿' => 'поцелуй: мужчина мужчина очень светлый тон кожи очень темный тон кожи',
    '👨🏼‍❤‍💋‍👨🏻' => 'поцелуй: мужчина мужчина светлый тон кожи очень светлый тон кожи',
    '👨🏼‍❤‍💋‍👨🏼' => 'поцелуй: мужчина мужчина светлый тон кожи',
    '👨🏼‍❤‍💋‍👨🏽' => 'поцелуй: мужчина мужчина светлый тон кожи средний тон кожи',
    '👨🏼‍❤‍💋‍👨🏾' => 'поцелуй: мужчина мужчина светлый тон кожи темный тон кожи',
    '👨🏼‍❤‍💋‍👨🏿' => 'поцелуй: мужчина мужчина светлый тон кожи очень темный тон кожи',
    '👨🏽‍❤‍💋‍👨🏻' => 'поцелуй: мужчина мужчина средний тон кожи очень светлый тон кожи',
    '👨🏽‍❤‍💋‍👨🏼' => 'поцелуй: мужчина мужчина средний тон кожи светлый тон кожи',
    '👨🏽‍❤‍💋‍👨🏽' => 'поцелуй: мужчина мужчина средний тон кожи',
    '👨🏽‍❤‍💋‍👨🏾' => 'поцелуй: мужчина мужчина средний тон кожи темный тон кожи',
    '👨🏽‍❤‍💋‍👨🏿' => 'поцелуй: мужчина мужчина средний тон кожи очень темный тон кожи',
    '👨🏾‍❤‍💋‍👨🏻' => 'поцелуй: мужчина мужчина темный тон кожи очень светлый тон кожи',
    '👨🏾‍❤‍💋‍👨🏼' => 'поцелуй: мужчина мужчина темный тон кожи светлый тон кожи',
    '👨🏾‍❤‍💋‍👨🏽' => 'поцелуй: мужчина мужчина темный тон кожи средний тон кожи',
    '👨🏾‍❤‍💋‍👨🏾' => 'поцелуй: мужчина мужчина темный тон кожи',
    '👨🏾‍❤‍💋‍👨🏿' => 'поцелуй: мужчина мужчина темный тон кожи очень темный тон кожи',
    '👨🏿‍❤‍💋‍👨🏻' => 'поцелуй: мужчина мужчина очень темный тон кожи очень светлый тон кожи',
    '👨🏿‍❤‍💋‍👨🏼' => 'поцелуй: мужчина мужчина очень темный тон кожи светлый тон кожи',
    '👨🏿‍❤‍💋‍👨🏽' => 'поцелуй: мужчина мужчина очень темный тон кожи средний тон кожи',
    '👨🏿‍❤‍💋‍👨🏾' => 'поцелуй: мужчина мужчина очень темный тон кожи темный тон кожи',
    '👨🏿‍❤‍💋‍👨🏿' => 'поцелуй: мужчина мужчина очень темный тон кожи',
    '👩🏻‍❤‍💋‍👨🏻' => 'поцелуй: женщина мужчина очень светлый тон кожи',
    '👩🏻‍❤‍💋‍👨🏼' => 'поцелуй: женщина мужчина очень светлый тон кожи светлый тон кожи',
    '👩🏻‍❤‍💋‍👨🏽' => 'поцелуй: женщина мужчина очень светлый тон кожи средний тон кожи',
    '👩🏻‍❤‍💋‍👨🏾' => 'поцелуй: женщина мужчина очень светлый тон кожи темный тон кожи',
    '👩🏻‍❤‍💋‍👨🏿' => 'поцелуй: женщина мужчина очень светлый тон кожи очень темный тон кожи',
    '👩🏼‍❤‍💋‍👨🏻' => 'поцелуй: женщина мужчина светлый тон кожи очень светлый тон кожи',
    '👩🏼‍❤‍💋‍👨🏼' => 'поцелуй: женщина мужчина светлый тон кожи',
    '👩🏼‍❤‍💋‍👨🏽' => 'поцелуй: женщина мужчина светлый тон кожи средний тон кожи',
    '👩🏼‍❤‍💋‍👨🏾' => 'поцелуй: женщина мужчина светлый тон кожи темный тон кожи',
    '👩🏼‍❤‍💋‍👨🏿' => 'поцелуй: женщина мужчина светлый тон кожи очень темный тон кожи',
    '👩🏽‍❤‍💋‍👨🏻' => 'поцелуй: женщина мужчина средний тон кожи очень светлый тон кожи',
    '👩🏽‍❤‍💋‍👨🏼' => 'поцелуй: женщина мужчина средний тон кожи светлый тон кожи',
    '👩🏽‍❤‍💋‍👨🏽' => 'поцелуй: женщина мужчина средний тон кожи',
    '👩🏽‍❤‍💋‍👨🏾' => 'поцелуй: женщина мужчина средний тон кожи темный тон кожи',
    '👩🏽‍❤‍💋‍👨🏿' => 'поцелуй: женщина мужчина средний тон кожи очень темный тон кожи',
    '👩🏾‍❤‍💋‍👨🏻' => 'поцелуй: женщина мужчина темный тон кожи очень светлый тон кожи',
    '👩🏾‍❤‍💋‍👨🏼' => 'поцелуй: женщина мужчина темный тон кожи светлый тон кожи',
    '👩🏾‍❤‍💋‍👨🏽' => 'поцелуй: женщина мужчина темный тон кожи средний тон кожи',
    '👩🏾‍❤‍💋‍👨🏾' => 'поцелуй: женщина мужчина темный тон кожи',
    '👩🏾‍❤‍💋‍👨🏿' => 'поцелуй: женщина мужчина темный тон кожи очень темный тон кожи',
    '👩🏿‍❤‍💋‍👨🏻' => 'поцелуй: женщина мужчина очень темный тон кожи очень светлый тон кожи',
    '👩🏿‍❤‍💋‍👨🏼' => 'поцелуй: женщина мужчина очень темный тон кожи светлый тон кожи',
    '👩🏿‍❤‍💋‍👨🏽' => 'поцелуй: женщина мужчина очень темный тон кожи средний тон кожи',
    '👩🏿‍❤‍💋‍👨🏾' => 'поцелуй: женщина мужчина очень темный тон кожи темный тон кожи',
    '👩🏿‍❤‍💋‍👨🏿' => 'поцелуй: женщина мужчина очень темный тон кожи',
    '👩🏻‍❤‍💋‍👩🏻' => 'поцелуй: женщина женщина очень светлый тон кожи',
    '👩🏻‍❤‍💋‍👩🏼' => 'поцелуй: женщина женщина очень светлый тон кожи светлый тон кожи',
    '👩🏻‍❤‍💋‍👩🏽' => 'поцелуй: женщина женщина очень светлый тон кожи средний тон кожи',
    '👩🏻‍❤‍💋‍👩🏾' => 'поцелуй: женщина женщина очень светлый тон кожи темный тон кожи',
    '👩🏻‍❤‍💋‍👩🏿' => 'поцелуй: женщина женщина очень светлый тон кожи очень темный тон кожи',
    '👩🏼‍❤‍💋‍👩🏻' => 'поцелуй: женщина женщина светлый тон кожи очень светлый тон кожи',
    '👩🏼‍❤‍💋‍👩🏼' => 'поцелуй: женщина женщина светлый тон кожи',
    '👩🏼‍❤‍💋‍👩🏽' => 'поцелуй: женщина женщина светлый тон кожи средний тон кожи',
    '👩🏼‍❤‍💋‍👩🏾' => 'поцелуй: женщина женщина светлый тон кожи темный тон кожи',
    '👩🏼‍❤‍💋‍👩🏿' => 'поцелуй: женщина женщина светлый тон кожи очень темный тон кожи',
    '👩🏽‍❤‍💋‍👩🏻' => 'поцелуй: женщина женщина средний тон кожи очень светлый тон кожи',
    '👩🏽‍❤‍💋‍👩🏼' => 'поцелуй: женщина женщина средний тон кожи светлый тон кожи',
    '👩🏽‍❤‍💋‍👩🏽' => 'поцелуй: женщина женщина средний тон кожи',
    '👩🏽‍❤‍💋‍👩🏾' => 'поцелуй: женщина женщина средний тон кожи темный тон кожи',
    '👩🏽‍❤‍💋‍👩🏿' => 'поцелуй: женщина женщина средний тон кожи очень темный тон кожи',
    '👩🏾‍❤‍💋‍👩🏻' => 'поцелуй: женщина женщина темный тон кожи очень светлый тон кожи',
    '👩🏾‍❤‍💋‍👩🏼' => 'поцелуй: женщина женщина темный тон кожи светлый тон кожи',
    '👩🏾‍❤‍💋‍👩🏽' => 'поцелуй: женщина женщина темный тон кожи средний тон кожи',
    '👩🏾‍❤‍💋‍👩🏾' => 'поцелуй: женщина женщина темный тон кожи',
    '👩🏾‍❤‍💋‍👩🏿' => 'поцелуй: женщина женщина темный тон кожи очень темный тон кожи',
    '👩🏿‍❤‍💋‍👩🏻' => 'поцелуй: женщина женщина очень темный тон кожи очень светлый тон кожи',
    '👩🏿‍❤‍💋‍👩🏼' => 'поцелуй: женщина женщина очень темный тон кожи светлый тон кожи',
    '👩🏿‍❤‍💋‍👩🏽' => 'поцелуй: женщина женщина очень темный тон кожи средний тон кожи',
    '👩🏿‍❤‍💋‍👩🏾' => 'поцелуй: женщина женщина очень темный тон кожи темный тон кожи',
    '👩🏿‍❤‍💋‍👩🏿' => 'поцелуй: женщина женщина очень темный тон кожи',
    '🧑🏻‍🫯‍🧑🏼' => 'борцы: очень светлый тон кожи светлый тон кожи',
    '🧑🏻‍🫯‍🧑🏽' => 'борцы: очень светлый тон кожи средний тон кожи',
    '🧑🏻‍🫯‍🧑🏾' => 'борцы: очень светлый тон кожи темный тон кожи',
    '🧑🏻‍🫯‍🧑🏿' => 'борцы: очень светлый тон кожи очень темный тон кожи',
    '🧑🏼‍🫯‍🧑🏻' => 'борцы: светлый тон кожи очень светлый тон кожи',
    '🧑🏼‍🫯‍🧑🏽' => 'борцы: светлый тон кожи средний тон кожи',
    '🧑🏼‍🫯‍🧑🏾' => 'борцы: светлый тон кожи темный тон кожи',
    '🧑🏼‍🫯‍🧑🏿' => 'борцы: светлый тон кожи очень темный тон кожи',
    '🧑🏽‍🫯‍🧑🏻' => 'борцы: средний тон кожи очень светлый тон кожи',
    '🧑🏽‍🫯‍🧑🏼' => 'борцы: средний тон кожи светлый тон кожи',
    '🧑🏽‍🫯‍🧑🏾' => 'борцы: средний тон кожи темный тон кожи',
    '🧑🏽‍🫯‍🧑🏿' => 'борцы: средний тон кожи очень темный тон кожи',
    '🧑🏾‍🫯‍🧑🏻' => 'борцы: темный тон кожи очень светлый тон кожи',
    '🧑🏾‍🫯‍🧑🏼' => 'борцы: темный тон кожи светлый тон кожи',
    '🧑🏾‍🫯‍🧑🏽' => 'борцы: темный тон кожи средний тон кожи',
    '🧑🏾‍🫯‍🧑🏿' => 'борцы: темный тон кожи очень темный тон кожи',
    '🧑🏿‍🫯‍🧑🏻' => 'борцы: очень темный тон кожи очень светлый тон кожи',
    '🧑🏿‍🫯‍🧑🏼' => 'борцы: очень темный тон кожи светлый тон кожи',
    '🧑🏿‍🫯‍🧑🏽' => 'борцы: очень темный тон кожи средний тон кожи',
    '🧑🏿‍🫯‍🧑🏾' => 'борцы: очень темный тон кожи темный тон кожи',
    '🧑🏻‍❤‍🧑🏼' => 'влюбленная пара: взрослый взрослый очень светлый тон кожи светлый тон кожи',
    '🧑🏻‍❤‍🧑🏽' => 'влюбленная пара: взрослый взрослый очень светлый тон кожи средний тон кожи',
    '🧑🏻‍❤‍🧑🏾' => 'влюбленная пара: взрослый взрослый очень светлый тон кожи темный тон кожи',
    '🧑🏻‍❤‍🧑🏿' => 'влюбленная пара: взрослый взрослый очень светлый тон кожи очень темный тон кожи',
    '🧑🏼‍❤‍🧑🏻' => 'влюбленная пара: взрослый взрослый светлый тон кожи очень светлый тон кожи',
    '🧑🏼‍❤‍🧑🏽' => 'влюбленная пара: взрослый взрослый светлый тон кожи средний тон кожи',
    '🧑🏼‍❤‍🧑🏾' => 'влюбленная пара: взрослый взрослый светлый тон кожи темный тон кожи',
    '🧑🏼‍❤‍🧑🏿' => 'влюбленная пара: взрослый взрослый светлый тон кожи очень темный тон кожи',
    '🧑🏽‍❤‍🧑🏻' => 'влюбленная пара: взрослый взрослый средний тон кожи очень светлый тон кожи',
    '🧑🏽‍❤‍🧑🏼' => 'влюбленная пара: взрослый взрослый средний тон кожи светлый тон кожи',
    '🧑🏽‍❤‍🧑🏾' => 'влюбленная пара: взрослый взрослый средний тон кожи темный тон кожи',
    '🧑🏽‍❤‍🧑🏿' => 'влюбленная пара: взрослый взрослый средний тон кожи очень темный тон кожи',
    '🧑🏾‍❤‍🧑🏻' => 'влюбленная пара: взрослый взрослый темный тон кожи очень светлый тон кожи',
    '🧑🏾‍❤‍🧑🏼' => 'влюбленная пара: взрослый взрослый темный тон кожи светлый тон кожи',
    '🧑🏾‍❤‍🧑🏽' => 'влюбленная пара: взрослый взрослый темный тон кожи средний тон кожи',
    '🧑🏾‍❤‍🧑🏿' => 'влюбленная пара: взрослый взрослый темный тон кожи очень темный тон кожи',
    '🧑🏿‍❤‍🧑🏻' => 'влюбленная пара: взрослый взрослый очень темный тон кожи очень светлый тон кожи',
    '🧑🏿‍❤‍🧑🏼' => 'влюбленная пара: взрослый взрослый очень темный тон кожи светлый тон кожи',
    '🧑🏿‍❤‍🧑🏽' => 'влюбленная пара: взрослый взрослый очень темный тон кожи средний тон кожи',
    '🧑🏿‍❤‍🧑🏾' => 'влюбленная пара: взрослый взрослый очень темный тон кожи темный тон кожи',
    '🧑🏻‍🐰‍🧑🏼' => 'люди с ушами кролика: очень светлый тон кожи светлый тон кожи',
    '🧑🏻‍🐰‍🧑🏽' => 'люди с ушами кролика: очень светлый тон кожи средний тон кожи',
    '🧑🏻‍🐰‍🧑🏾' => 'люди с ушами кролика: очень светлый тон кожи темный тон кожи',
    '🧑🏻‍🐰‍🧑🏿' => 'люди с ушами кролика: очень светлый тон кожи очень темный тон кожи',
    '🧑🏼‍🐰‍🧑🏻' => 'люди с ушами кролика: светлый тон кожи очень светлый тон кожи',
    '🧑🏼‍🐰‍🧑🏽' => 'люди с ушами кролика: светлый тон кожи средний тон кожи',
    '🧑🏼‍🐰‍🧑🏾' => 'люди с ушами кролика: светлый тон кожи темный тон кожи',
    '🧑🏼‍🐰‍🧑🏿' => 'люди с ушами кролика: светлый тон кожи очень темный тон кожи',
    '🧑🏽‍🐰‍🧑🏻' => 'люди с ушами кролика: средний тон кожи очень светлый тон кожи',
    '🧑🏽‍🐰‍🧑🏼' => 'люди с ушами кролика: средний тон кожи светлый тон кожи',
    '🧑🏽‍🐰‍🧑🏾' => 'люди с ушами кролика: средний тон кожи темный тон кожи',
    '🧑🏽‍🐰‍🧑🏿' => 'люди с ушами кролика: средний тон кожи очень темный тон кожи',
    '🧑🏾‍🐰‍🧑🏻' => 'люди с ушами кролика: темный тон кожи очень светлый тон кожи',
    '🧑🏾‍🐰‍🧑🏼' => 'люди с ушами кролика: темный тон кожи светлый тон кожи',
    '🧑🏾‍🐰‍🧑🏽' => 'люди с ушами кролика: темный тон кожи средний тон кожи',
    '🧑🏾‍🐰‍🧑🏿' => 'люди с ушами кролика: темный тон кожи очень темный тон кожи',
    '🧑🏿‍🐰‍🧑🏻' => 'люди с ушами кролика: очень темный тон кожи очень светлый тон кожи',
    '🧑🏿‍🐰‍🧑🏼' => 'люди с ушами кролика: очень темный тон кожи светлый тон кожи',
    '🧑🏿‍🐰‍🧑🏽' => 'люди с ушами кролика: очень темный тон кожи средний тон кожи',
    '🧑🏿‍🐰‍🧑🏾' => 'люди с ушами кролика: очень темный тон кожи темный тон кожи',
    '👨🏻‍🫯‍👨🏼' => 'мужчины-борцы: очень светлый тон кожи светлый тон кожи',
    '👨🏻‍🫯‍👨🏽' => 'мужчины-борцы: очень светлый тон кожи средний тон кожи',
    '👨🏻‍🫯‍👨🏾' => 'мужчины-борцы: очень светлый тон кожи темный тон кожи',
    '👨🏻‍🫯‍👨🏿' => 'мужчины-борцы: очень светлый тон кожи очень темный тон кожи',
    '👨🏼‍🫯‍👨🏻' => 'мужчины-борцы: светлый тон кожи очень светлый тон кожи',
    '👨🏼‍🫯‍👨🏽' => 'мужчины-борцы: светлый тон кожи средний тон кожи',
    '👨🏼‍🫯‍👨🏾' => 'мужчины-борцы: светлый тон кожи темный тон кожи',
    '👨🏼‍🫯‍👨🏿' => 'мужчины-борцы: светлый тон кожи очень темный тон кожи',
    '👨🏽‍🫯‍👨🏻' => 'мужчины-борцы: средний тон кожи очень светлый тон кожи',
    '👨🏽‍🫯‍👨🏼' => 'мужчины-борцы: средний тон кожи светлый тон кожи',
    '👨🏽‍🫯‍👨🏾' => 'мужчины-борцы: средний тон кожи темный тон кожи',
    '👨🏽‍🫯‍👨🏿' => 'мужчины-борцы: средний тон кожи очень темный тон кожи',
    '👨🏾‍🫯‍👨🏻' => 'мужчины-борцы: темный тон кожи очень светлый тон кожи',
    '👨🏾‍🫯‍👨🏼' => 'мужчины-борцы: темный тон кожи светлый тон кожи',
    '👨🏾‍🫯‍👨🏽' => 'мужчины-борцы: темный тон кожи средний тон кожи',
    '👨🏾‍🫯‍👨🏿' => 'мужчины-борцы: темный тон кожи очень темный тон кожи',
    '👨🏿‍🫯‍👨🏻' => 'мужчины-борцы: очень темный тон кожи очень светлый тон кожи',
    '👨🏿‍🫯‍👨🏼' => 'мужчины-борцы: очень темный тон кожи светлый тон кожи',
    '👨🏿‍🫯‍👨🏽' => 'мужчины-борцы: очень темный тон кожи средний тон кожи',
    '👨🏿‍🫯‍👨🏾' => 'мужчины-борцы: очень темный тон кожи темный тон кожи',
    '👨🏻‍❤‍👨🏻' => 'влюбленная пара: мужчина мужчина очень светлый тон кожи',
    '👨🏻‍❤‍👨🏼' => 'влюбленная пара: мужчина мужчина очень светлый тон кожи светлый тон кожи',
    '👨🏻‍❤‍👨🏽' => 'влюбленная пара: мужчина мужчина очень светлый тон кожи средний тон кожи',
    '👨🏻‍❤‍👨🏾' => 'влюбленная пара: мужчина мужчина очень светлый тон кожи темный тон кожи',
    '👨🏻‍❤‍👨🏿' => 'влюбленная пара: мужчина мужчина очень светлый тон кожи очень темный тон кожи',
    '👨🏼‍❤‍👨🏻' => 'влюбленная пара: мужчина мужчина светлый тон кожи очень светлый тон кожи',
    '👨🏼‍❤‍👨🏼' => 'влюбленная пара: мужчина мужчина светлый тон кожи',
    '👨🏼‍❤‍👨🏽' => 'влюбленная пара: мужчина мужчина светлый тон кожи средний тон кожи',
    '👨🏼‍❤‍👨🏾' => 'влюбленная пара: мужчина мужчина светлый тон кожи темный тон кожи',
    '👨🏼‍❤‍👨🏿' => 'влюбленная пара: мужчина мужчина светлый тон кожи очень темный тон кожи',
    '👨🏽‍❤‍👨🏻' => 'влюбленная пара: мужчина мужчина средний тон кожи очень светлый тон кожи',
    '👨🏽‍❤‍👨🏼' => 'влюбленная пара: мужчина мужчина средний тон кожи светлый тон кожи',
    '👨🏽‍❤‍👨🏽' => 'влюбленная пара: мужчина мужчина средний тон кожи',
    '👨🏽‍❤‍👨🏾' => 'влюбленная пара: мужчина мужчина средний тон кожи темный тон кожи',
    '👨🏽‍❤‍👨🏿' => 'влюбленная пара: мужчина мужчина средний тон кожи очень темный тон кожи',
    '👨🏾‍❤‍👨🏻' => 'влюбленная пара: мужчина мужчина темный тон кожи очень светлый тон кожи',
    '👨🏾‍❤‍👨🏼' => 'влюбленная пара: мужчина мужчина темный тон кожи светлый тон кожи',
    '👨🏾‍❤‍👨🏽' => 'влюбленная пара: мужчина мужчина темный тон кожи средний тон кожи',
    '👨🏾‍❤‍👨🏾' => 'влюбленная пара: мужчина мужчина темный тон кожи',
    '👨🏾‍❤‍👨🏿' => 'влюбленная пара: мужчина мужчина темный тон кожи очень темный тон кожи',
    '👨🏿‍❤‍👨🏻' => 'влюбленная пара: мужчина мужчина очень темный тон кожи очень светлый тон кожи',
    '👨🏿‍❤‍👨🏼' => 'влюбленная пара: мужчина мужчина очень темный тон кожи светлый тон кожи',
    '👨🏿‍❤‍👨🏽' => 'влюбленная пара: мужчина мужчина очень темный тон кожи средний тон кожи',
    '👨🏿‍❤‍👨🏾' => 'влюбленная пара: мужчина мужчина очень темный тон кожи темный тон кожи',
    '👨🏿‍❤‍👨🏿' => 'влюбленная пара: мужчина мужчина очень темный тон кожи',
    '👨🏻‍🐰‍👨🏼' => 'мужчины с ушами кролика: очень светлый тон кожи светлый тон кожи',
    '👨🏻‍🐰‍👨🏽' => 'мужчины с ушами кролика: очень светлый тон кожи средний тон кожи',
    '👨🏻‍🐰‍👨🏾' => 'мужчины с ушами кролика: очень светлый тон кожи темный тон кожи',
    '👨🏻‍🐰‍👨🏿' => 'мужчины с ушами кролика: очень светлый тон кожи очень темный тон кожи',
    '👨🏼‍🐰‍👨🏻' => 'мужчины с ушами кролика: светлый тон кожи очень светлый тон кожи',
    '👨🏼‍🐰‍👨🏽' => 'мужчины с ушами кролика: светлый тон кожи средний тон кожи',
    '👨🏼‍🐰‍👨🏾' => 'мужчины с ушами кролика: светлый тон кожи темный тон кожи',
    '👨🏼‍🐰‍👨🏿' => 'мужчины с ушами кролика: светлый тон кожи очень темный тон кожи',
    '👨🏽‍🐰‍👨🏻' => 'мужчины с ушами кролика: средний тон кожи очень светлый тон кожи',
    '👨🏽‍🐰‍👨🏼' => 'мужчины с ушами кролика: средний тон кожи светлый тон кожи',
    '👨🏽‍🐰‍👨🏾' => 'мужчины с ушами кролика: средний тон кожи темный тон кожи',
    '👨🏽‍🐰‍👨🏿' => 'мужчины с ушами кролика: средний тон кожи очень темный тон кожи',
    '👨🏾‍🐰‍👨🏻' => 'мужчины с ушами кролика: темный тон кожи очень светлый тон кожи',
    '👨🏾‍🐰‍👨🏼' => 'мужчины с ушами кролика: темный тон кожи светлый тон кожи',
    '👨🏾‍🐰‍👨🏽' => 'мужчины с ушами кролика: темный тон кожи средний тон кожи',
    '👨🏾‍🐰‍👨🏿' => 'мужчины с ушами кролика: темный тон кожи очень темный тон кожи',
    '👨🏿‍🐰‍👨🏻' => 'мужчины с ушами кролика: очень темный тон кожи очень светлый тон кожи',
    '👨🏿‍🐰‍👨🏼' => 'мужчины с ушами кролика: очень темный тон кожи светлый тон кожи',
    '👨🏿‍🐰‍👨🏽' => 'мужчины с ушами кролика: очень темный тон кожи средний тон кожи',
    '👨🏿‍🐰‍👨🏾' => 'мужчины с ушами кролика: очень темный тон кожи темный тон кожи',
    '👩🏻‍🫯‍👩🏼' => 'женщины-борцы: очень светлый тон кожи светлый тон кожи',
    '👩🏻‍🫯‍👩🏽' => 'женщины-борцы: очень светлый тон кожи средний тон кожи',
    '👩🏻‍🫯‍👩🏾' => 'женщины-борцы: очень светлый тон кожи темный тон кожи',
    '👩🏻‍🫯‍👩🏿' => 'женщины-борцы: очень светлый тон кожи очень темный тон кожи',
    '👩🏼‍🫯‍👩🏻' => 'женщины-борцы: светлый тон кожи очень светлый тон кожи',
    '👩🏼‍🫯‍👩🏽' => 'женщины-борцы: светлый тон кожи средний тон кожи',
    '👩🏼‍🫯‍👩🏾' => 'женщины-борцы: светлый тон кожи темный тон кожи',
    '👩🏼‍🫯‍👩🏿' => 'женщины-борцы: светлый тон кожи очень темный тон кожи',
    '👩🏽‍🫯‍👩🏻' => 'женщины-борцы: средний тон кожи очень светлый тон кожи',
    '👩🏽‍🫯‍👩🏼' => 'женщины-борцы: средний тон кожи светлый тон кожи',
    '👩🏽‍🫯‍👩🏾' => 'женщины-борцы: средний тон кожи темный тон кожи',
    '👩🏽‍🫯‍👩🏿' => 'женщины-борцы: средний тон кожи очень темный тон кожи',
    '👩🏾‍🫯‍👩🏻' => 'женщины-борцы: темный тон кожи очень светлый тон кожи',
    '👩🏾‍🫯‍👩🏼' => 'женщины-борцы: темный тон кожи светлый тон кожи',
    '👩🏾‍🫯‍👩🏽' => 'женщины-борцы: темный тон кожи средний тон кожи',
    '👩🏾‍🫯‍👩🏿' => 'женщины-борцы: темный тон кожи очень темный тон кожи',
    '👩🏿‍🫯‍👩🏻' => 'женщины-борцы: очень темный тон кожи очень светлый тон кожи',
    '👩🏿‍🫯‍👩🏼' => 'женщины-борцы: очень темный тон кожи светлый тон кожи',
    '👩🏿‍🫯‍👩🏽' => 'женщины-борцы: очень темный тон кожи средний тон кожи',
    '👩🏿‍🫯‍👩🏾' => 'женщины-борцы: очень темный тон кожи темный тон кожи',
    '👩🏻‍❤‍👨🏻' => 'влюбленная пара: женщина мужчина очень светлый тон кожи',
    '👩🏻‍❤‍👨🏼' => 'влюбленная пара: женщина мужчина очень светлый тон кожи светлый тон кожи',
    '👩🏻‍❤‍👨🏽' => 'влюбленная пара: женщина мужчина очень светлый тон кожи средний тон кожи',
    '👩🏻‍❤‍👨🏾' => 'влюбленная пара: женщина мужчина очень светлый тон кожи темный тон кожи',
    '👩🏻‍❤‍👨🏿' => 'влюбленная пара: женщина мужчина очень светлый тон кожи очень темный тон кожи',
    '👩🏼‍❤‍👨🏻' => 'влюбленная пара: женщина мужчина светлый тон кожи очень светлый тон кожи',
    '👩🏼‍❤‍👨🏼' => 'влюбленная пара: женщина мужчина светлый тон кожи',
    '👩🏼‍❤‍👨🏽' => 'влюбленная пара: женщина мужчина светлый тон кожи средний тон кожи',
    '👩🏼‍❤‍👨🏾' => 'влюбленная пара: женщина мужчина светлый тон кожи темный тон кожи',
    '👩🏼‍❤‍👨🏿' => 'влюбленная пара: женщина мужчина светлый тон кожи очень темный тон кожи',
    '👩🏽‍❤‍👨🏻' => 'влюбленная пара: женщина мужчина средний тон кожи очень светлый тон кожи',
    '👩🏽‍❤‍👨🏼' => 'влюбленная пара: женщина мужчина средний тон кожи светлый тон кожи',
    '👩🏽‍❤‍👨🏽' => 'влюбленная пара: женщина мужчина средний тон кожи',
    '👩🏽‍❤‍👨🏾' => 'влюбленная пара: женщина мужчина средний тон кожи темный тон кожи',
    '👩🏽‍❤‍👨🏿' => 'влюбленная пара: женщина мужчина средний тон кожи очень темный тон кожи',
    '👩🏾‍❤‍👨🏻' => 'влюбленная пара: женщина мужчина темный тон кожи очень светлый тон кожи',
    '👩🏾‍❤‍👨🏼' => 'влюбленная пара: женщина мужчина темный тон кожи светлый тон кожи',
    '👩🏾‍❤‍👨🏽' => 'влюбленная пара: женщина мужчина темный тон кожи средний тон кожи',
    '👩🏾‍❤‍👨🏾' => 'влюбленная пара: женщина мужчина темный тон кожи',
    '👩🏾‍❤‍👨🏿' => 'влюбленная пара: женщина мужчина темный тон кожи очень темный тон кожи',
    '👩🏿‍❤‍👨🏻' => 'влюбленная пара: женщина мужчина очень темный тон кожи очень светлый тон кожи',
    '👩🏿‍❤‍👨🏼' => 'влюбленная пара: женщина мужчина очень темный тон кожи светлый тон кожи',
    '👩🏿‍❤‍👨🏽' => 'влюбленная пара: женщина мужчина очень темный тон кожи средний тон кожи',
    '👩🏿‍❤‍👨🏾' => 'влюбленная пара: женщина мужчина очень темный тон кожи темный тон кожи',
    '👩🏿‍❤‍👨🏿' => 'влюбленная пара: женщина мужчина очень темный тон кожи',
    '👩🏻‍❤‍👩🏻' => 'влюбленная пара: женщина женщина очень светлый тон кожи',
    '👩🏻‍❤‍👩🏼' => 'влюбленная пара: женщина женщина очень светлый тон кожи светлый тон кожи',
    '👩🏻‍❤‍👩🏽' => 'влюбленная пара: женщина женщина очень светлый тон кожи средний тон кожи',
    '👩🏻‍❤‍👩🏾' => 'влюбленная пара: женщина женщина очень светлый тон кожи темный тон кожи',
    '👩🏻‍❤‍👩🏿' => 'влюбленная пара: женщина женщина очень светлый тон кожи очень темный тон кожи',
    '👩🏼‍❤‍👩🏻' => 'влюбленная пара: женщина женщина светлый тон кожи очень светлый тон кожи',
    '👩🏼‍❤‍👩🏼' => 'влюбленная пара: женщина женщина светлый тон кожи',
    '👩🏼‍❤‍👩🏽' => 'влюбленная пара: женщина женщина светлый тон кожи средний тон кожи',
    '👩🏼‍❤‍👩🏾' => 'влюбленная пара: женщина женщина светлый тон кожи темный тон кожи',
    '👩🏼‍❤‍👩🏿' => 'влюбленная пара: женщина женщина светлый тон кожи очень темный тон кожи',
    '👩🏽‍❤‍👩🏻' => 'влюбленная пара: женщина женщина средний тон кожи очень светлый тон кожи',
    '👩🏽‍❤‍👩🏼' => 'влюбленная пара: женщина женщина средний тон кожи светлый тон кожи',
    '👩🏽‍❤‍👩🏽' => 'влюбленная пара: женщина женщина средний тон кожи',
    '👩🏽‍❤‍👩🏾' => 'влюбленная пара: женщина женщина средний тон кожи темный тон кожи',
    '👩🏽‍❤‍👩🏿' => 'влюбленная пара: женщина женщина средний тон кожи очень темный тон кожи',
    '👩🏾‍❤‍👩🏻' => 'влюбленная пара: женщина женщина темный тон кожи очень светлый тон кожи',
    '👩🏾‍❤‍👩🏼' => 'влюбленная пара: женщина женщина темный тон кожи светлый тон кожи',
    '👩🏾‍❤‍👩🏽' => 'влюбленная пара: женщина женщина темный тон кожи средний тон кожи',
    '👩🏾‍❤‍👩🏾' => 'влюбленная пара: женщина женщина темный тон кожи',
    '👩🏾‍❤‍👩🏿' => 'влюбленная пара: женщина женщина темный тон кожи очень темный тон кожи',
    '👩🏿‍❤‍👩🏻' => 'влюбленная пара: женщина женщина очень темный тон кожи очень светлый тон кожи',
    '👩🏿‍❤‍👩🏼' => 'влюбленная пара: женщина женщина очень темный тон кожи светлый тон кожи',
    '👩🏿‍❤‍👩🏽' => 'влюбленная пара: женщина женщина очень темный тон кожи средний тон кожи',
    '👩🏿‍❤‍👩🏾' => 'влюбленная пара: женщина женщина очень темный тон кожи темный тон кожи',
    '👩🏿‍❤‍👩🏿' => 'влюбленная пара: женщина женщина очень темный тон кожи',
    '👩🏻‍🐰‍👩🏼' => 'женщины с ушами кролика: очень светлый тон кожи светлый тон кожи',
    '👩🏻‍🐰‍👩🏽' => 'женщины с ушами кролика: очень светлый тон кожи средний тон кожи',
    '👩🏻‍🐰‍👩🏾' => 'женщины с ушами кролика: очень светлый тон кожи темный тон кожи',
    '👩🏻‍🐰‍👩🏿' => 'женщины с ушами кролика: очень светлый тон кожи очень темный тон кожи',
    '👩🏼‍🐰‍👩🏻' => 'женщины с ушами кролика: светлый тон кожи очень светлый тон кожи',
    '👩🏼‍🐰‍👩🏽' => 'женщины с ушами кролика: светлый тон кожи средний тон кожи',
    '👩🏼‍🐰‍👩🏾' => 'женщины с ушами кролика: светлый тон кожи темный тон кожи',
    '👩🏼‍🐰‍👩🏿' => 'женщины с ушами кролика: светлый тон кожи очень темный тон кожи',
    '👩🏽‍🐰‍👩🏻' => 'женщины с ушами кролика: средний тон кожи очень светлый тон кожи',
    '👩🏽‍🐰‍👩🏼' => 'женщины с ушами кролика: средний тон кожи светлый тон кожи',
    '👩🏽‍🐰‍👩🏾' => 'женщины с ушами кролика: средний тон кожи темный тон кожи',
    '👩🏽‍🐰‍👩🏿' => 'женщины с ушами кролика: средний тон кожи очень темный тон кожи',
    '👩🏾‍🐰‍👩🏻' => 'женщины с ушами кролика: темный тон кожи очень светлый тон кожи',
    '👩🏾‍🐰‍👩🏼' => 'женщины с ушами кролика: темный тон кожи светлый тон кожи',
    '👩🏾‍🐰‍👩🏽' => 'женщины с ушами кролика: темный тон кожи средний тон кожи',
    '👩🏾‍🐰‍👩🏿' => 'женщины с ушами кролика: темный тон кожи очень темный тон кожи',
    '👩🏿‍🐰‍👩🏻' => 'женщины с ушами кролика: очень темный тон кожи очень светлый тон кожи',
    '👩🏿‍🐰‍👩🏼' => 'женщины с ушами кролика: очень темный тон кожи светлый тон кожи',
    '👩🏿‍🐰‍👩🏽' => 'женщины с ушами кролика: очень темный тон кожи средний тон кожи',
    '👩🏿‍🐰‍👩🏾' => 'женщины с ушами кролика: очень темный тон кожи темный тон кожи',
    '🧑🏻‍🤝‍🧑🏻' => 'люди, держащиеся за руки: очень светлый тон кожи',
    '🧑🏻‍🤝‍🧑🏼' => 'люди, держащиеся за руки: очень светлый тон кожи светлый тон кожи',
    '🧑🏻‍🤝‍🧑🏽' => 'люди, держащиеся за руки: очень светлый тон кожи средний тон кожи',
    '🧑🏻‍🤝‍🧑🏾' => 'люди, держащиеся за руки: очень светлый тон кожи темный тон кожи',
    '🧑🏻‍🤝‍🧑🏿' => 'люди, держащиеся за руки: очень светлый тон кожи очень темный тон кожи',
    '🧑🏼‍🤝‍🧑🏻' => 'люди, держащиеся за руки: светлый тон кожи очень светлый тон кожи',
    '🧑🏼‍🤝‍🧑🏼' => 'люди, держащиеся за руки: светлый тон кожи',
    '🧑🏼‍🤝‍🧑🏽' => 'люди, держащиеся за руки: светлый тон кожи средний тон кожи',
    '🧑🏼‍🤝‍🧑🏾' => 'люди, держащиеся за руки: светлый тон кожи темный тон кожи',
    '🧑🏼‍🤝‍🧑🏿' => 'люди, держащиеся за руки: светлый тон кожи очень темный тон кожи',
    '🧑🏽‍🤝‍🧑🏻' => 'люди, держащиеся за руки: средний тон кожи очень светлый тон кожи',
    '🧑🏽‍🤝‍🧑🏼' => 'люди, держащиеся за руки: средний тон кожи светлый тон кожи',
    '🧑🏽‍🤝‍🧑🏽' => 'люди, держащиеся за руки: средний тон кожи',
    '🧑🏽‍🤝‍🧑🏾' => 'люди, держащиеся за руки: средний тон кожи темный тон кожи',
    '🧑🏽‍🤝‍🧑🏿' => 'люди, держащиеся за руки: средний тон кожи очень темный тон кожи',
    '🧑🏾‍🤝‍🧑🏻' => 'люди, держащиеся за руки: темный тон кожи очень светлый тон кожи',
    '🧑🏾‍🤝‍🧑🏼' => 'люди, держащиеся за руки: темный тон кожи светлый тон кожи',
    '🧑🏾‍🤝‍🧑🏽' => 'люди, держащиеся за руки: темный тон кожи средний тон кожи',
    '🧑🏾‍🤝‍🧑🏾' => 'люди, держащиеся за руки: темный тон кожи',
    '🧑🏾‍🤝‍🧑🏿' => 'люди, держащиеся за руки: темный тон кожи очень темный тон кожи',
    '🧑🏿‍🤝‍🧑🏻' => 'люди, держащиеся за руки: очень темный тон кожи очень светлый тон кожи',
    '🧑🏿‍🤝‍🧑🏼' => 'люди, держащиеся за руки: очень темный тон кожи светлый тон кожи',
    '🧑🏿‍🤝‍🧑🏽' => 'люди, держащиеся за руки: очень темный тон кожи средний тон кожи',
    '🧑🏿‍🤝‍🧑🏾' => 'люди, держащиеся за руки: очень темный тон кожи темный тон кожи',
    '🧑🏿‍🤝‍🧑🏿' => 'люди, держащиеся за руки: очень темный тон кожи',
    '👩🏻‍🤝‍👩🏼' => 'две женщины: очень светлый тон кожи светлый тон кожи',
    '👩🏻‍🤝‍👩🏽' => 'две женщины: очень светлый тон кожи средний тон кожи',
    '👩🏻‍🤝‍👩🏾' => 'две женщины: очень светлый тон кожи темный тон кожи',
    '👩🏻‍🤝‍👩🏿' => 'две женщины: очень светлый тон кожи очень темный тон кожи',
    '👩🏼‍🤝‍👩🏻' => 'две женщины: светлый тон кожи очень светлый тон кожи',
    '👩🏼‍🤝‍👩🏽' => 'две женщины: светлый тон кожи средний тон кожи',
    '👩🏼‍🤝‍👩🏾' => 'две женщины: светлый тон кожи темный тон кожи',
    '👩🏼‍🤝‍👩🏿' => 'две женщины: светлый тон кожи очень темный тон кожи',
    '👩🏽‍🤝‍👩🏻' => 'две женщины: средний тон кожи очень светлый тон кожи',
    '👩🏽‍🤝‍👩🏼' => 'две женщины: средний тон кожи светлый тон кожи',
    '👩🏽‍🤝‍👩🏾' => 'две женщины: средний тон кожи темный тон кожи',
    '👩🏽‍🤝‍👩🏿' => 'две женщины: средний тон кожи очень темный тон кожи',
    '👩🏾‍🤝‍👩🏻' => 'две женщины: темный тон кожи очень светлый тон кожи',
    '👩🏾‍🤝‍👩🏼' => 'две женщины: темный тон кожи светлый тон кожи',
    '👩🏾‍🤝‍👩🏽' => 'две женщины: темный тон кожи средний тон кожи',
    '👩🏾‍🤝‍👩🏿' => 'две женщины: темный тон кожи очень темный тон кожи',
    '👩🏿‍🤝‍👩🏻' => 'две женщины: очень темный тон кожи очень светлый тон кожи',
    '👩🏿‍🤝‍👩🏼' => 'две женщины: очень темный тон кожи светлый тон кожи',
    '👩🏿‍🤝‍👩🏽' => 'две женщины: очень темный тон кожи средний тон кожи',
    '👩🏿‍🤝‍👩🏾' => 'две женщины: очень темный тон кожи темный тон кожи',
    '👩🏻‍🤝‍👨🏼' => 'мужчина и женщина: очень светлый тон кожи светлый тон кожи',
    '👩🏻‍🤝‍👨🏽' => 'мужчина и женщина: очень светлый тон кожи средний тон кожи',
    '👩🏻‍🤝‍👨🏾' => 'мужчина и женщина: очень светлый тон кожи темный тон кожи',
    '👩🏻‍🤝‍👨🏿' => 'мужчина и женщина: очень светлый тон кожи очень темный тон кожи',
    '👩🏼‍🤝‍👨🏻' => 'мужчина и женщина: светлый тон кожи очень светлый тон кожи',
    '👩🏼‍🤝‍👨🏽' => 'мужчина и женщина: светлый тон кожи средний тон кожи',
    '👩🏼‍🤝‍👨🏾' => 'мужчина и женщина: светлый тон кожи темный тон кожи',
    '👩🏼‍🤝‍👨🏿' => 'мужчина и женщина: светлый тон кожи очень темный тон кожи',
    '👩🏽‍🤝‍👨🏻' => 'мужчина и женщина: средний тон кожи очень светлый тон кожи',
    '👩🏽‍🤝‍👨🏼' => 'мужчина и женщина: средний тон кожи светлый тон кожи',
    '👩🏽‍🤝‍👨🏾' => 'мужчина и женщина: средний тон кожи темный тон кожи',
    '👩🏽‍🤝‍👨🏿' => 'мужчина и женщина: средний тон кожи очень темный тон кожи',
    '👩🏾‍🤝‍👨🏻' => 'мужчина и женщина: темный тон кожи очень светлый тон кожи',
    '👩🏾‍🤝‍👨🏼' => 'мужчина и женщина: темный тон кожи светлый тон кожи',
    '👩🏾‍🤝‍👨🏽' => 'мужчина и женщина: темный тон кожи средний тон кожи',
    '👩🏾‍🤝‍👨🏿' => 'мужчина и женщина: темный тон кожи очень темный тон кожи',
    '👩🏿‍🤝‍👨🏻' => 'мужчина и женщина: очень темный тон кожи очень светлый тон кожи',
    '👩🏿‍🤝‍👨🏼' => 'мужчина и женщина: очень темный тон кожи светлый тон кожи',
    '👩🏿‍🤝‍👨🏽' => 'мужчина и женщина: очень темный тон кожи средний тон кожи',
    '👩🏿‍🤝‍👨🏾' => 'мужчина и женщина: очень темный тон кожи темный тон кожи',
    '👨🏻‍🤝‍👨🏼' => 'двое мужчин: очень светлый тон кожи светлый тон кожи',
    '👨🏻‍🤝‍👨🏽' => 'двое мужчин: очень светлый тон кожи средний тон кожи',
    '👨🏻‍🤝‍👨🏾' => 'двое мужчин: очень светлый тон кожи темный тон кожи',
    '👨🏻‍🤝‍👨🏿' => 'двое мужчин: очень светлый тон кожи очень темный тон кожи',
    '👨🏼‍🤝‍👨🏻' => 'двое мужчин: светлый тон кожи очень светлый тон кожи',
    '👨🏼‍🤝‍👨🏽' => 'двое мужчин: светлый тон кожи средний тон кожи',
    '👨🏼‍🤝‍👨🏾' => 'двое мужчин: светлый тон кожи темный тон кожи',
    '👨🏼‍🤝‍👨🏿' => 'двое мужчин: светлый тон кожи очень темный тон кожи',
    '👨🏽‍🤝‍👨🏻' => 'двое мужчин: средний тон кожи очень светлый тон кожи',
    '👨🏽‍🤝‍👨🏼' => 'двое мужчин: средний тон кожи светлый тон кожи',
    '👨🏽‍🤝‍👨🏾' => 'двое мужчин: средний тон кожи темный тон кожи',
    '👨🏽‍🤝‍👨🏿' => 'двое мужчин: средний тон кожи очень темный тон кожи',
    '👨🏾‍🤝‍👨🏻' => 'двое мужчин: темный тон кожи очень светлый тон кожи',
    '👨🏾‍🤝‍👨🏼' => 'двое мужчин: темный тон кожи светлый тон кожи',
    '👨🏾‍🤝‍👨🏽' => 'двое мужчин: темный тон кожи средний тон кожи',
    '👨🏾‍🤝‍👨🏿' => 'двое мужчин: темный тон кожи очень темный тон кожи',
    '👨🏿‍🤝‍👨🏻' => 'двое мужчин: очень темный тон кожи очень светлый тон кожи',
    '👨🏿‍🤝‍👨🏼' => 'двое мужчин: очень темный тон кожи светлый тон кожи',
    '👨🏿‍🤝‍👨🏽' => 'двое мужчин: очень темный тон кожи средний тон кожи',
    '👨🏿‍🤝‍👨🏾' => 'двое мужчин: очень темный тон кожи темный тон кожи',
    '👩‍❤‍💋‍👨' => 'поцелуй: женщина мужчина',
    '👨‍❤‍💋‍👨' => 'поцелуй: мужчина мужчина',
    '👩‍❤‍💋‍👩' => 'поцелуй: женщина женщина',
    '👨‍👩‍👧‍👦' => 'семья: мужчина женщина девочка мальчик',
    '👨‍👩‍👦‍👦' => 'семья: мужчина женщина мальчик мальчик',
    '👨‍👩‍👧‍👧' => 'семья: мужчина женщина девочка девочка',
    '👨‍👨‍👧‍👦' => 'семья: мужчина мужчина девочка мальчик',
    '👨‍👨‍👦‍👦' => 'семья: мужчина мужчина мальчик мальчик',
    '👨‍👨‍👧‍👧' => 'семья: мужчина мужчина девочка девочка',
    '👩‍👩‍👧‍👦' => 'семья: женщина женщина девочка мальчик',
    '👩‍👩‍👦‍👦' => 'семья: женщина женщина мальчик мальчик',
    '👩‍👩‍👧‍👧' => 'семья: женщина женщина девочка девочка',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'флаг: Англия',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'флаг: Шотландия',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'флаг: Уэльс',
    '🧑‍🧑‍🧒‍🧒' => 'семья: двое взрослых и двое детей',
    '🚶🏻‍♀‍➡' => 'женщина идет: очень светлый тон кожи , направленные вправо',
    '🚶🏼‍♀‍➡' => 'женщина идет: светлый тон кожи , направленные вправо',
    '🚶🏽‍♀‍➡' => 'женщина идет: средний тон кожи , направленные вправо',
    '🚶🏾‍♀‍➡' => 'женщина идет: темный тон кожи , направленные вправо',
    '🚶🏿‍♀‍➡' => 'женщина идет: очень темный тон кожи , направленные вправо',
    '🚶🏻‍♂‍➡' => 'мужчина идет: очень светлый тон кожи , направленные вправо',
    '🚶🏼‍♂‍➡' => 'мужчина идет: светлый тон кожи , направленные вправо',
    '🚶🏽‍♂‍➡' => 'мужчина идет: средний тон кожи , направленные вправо',
    '🚶🏾‍♂‍➡' => 'мужчина идет: темный тон кожи , направленные вправо',
    '🚶🏿‍♂‍➡' => 'мужчина идет: очень темный тон кожи , направленные вправо',
    '🧎🏻‍♀‍➡' => 'женщина на коленях: очень светлый тон кожи , направленные вправо',
    '🧎🏼‍♀‍➡' => 'женщина на коленях: светлый тон кожи , направленные вправо',
    '🧎🏽‍♀‍➡' => 'женщина на коленях: средний тон кожи , направленные вправо',
    '🧎🏾‍♀‍➡' => 'женщина на коленях: темный тон кожи , направленные вправо',
    '🧎🏿‍♀‍➡' => 'женщина на коленях: очень темный тон кожи , направленные вправо',
    '🧎🏻‍♂‍➡' => 'мужчина на коленях: очень светлый тон кожи , направленные вправо',
    '🧎🏼‍♂‍➡' => 'мужчина на коленях: светлый тон кожи , направленные вправо',
    '🧎🏽‍♂‍➡' => 'мужчина на коленях: средний тон кожи , направленные вправо',
    '🧎🏾‍♂‍➡' => 'мужчина на коленях: темный тон кожи , направленные вправо',
    '🧎🏿‍♂‍➡' => 'мужчина на коленях: очень темный тон кожи , направленные вправо',
    '🧑🏻‍🦯‍➡' => 'человек с белой тростью: очень светлый тон кожи , направленные вправо',
    '🧑🏼‍🦯‍➡' => 'человек с белой тростью: светлый тон кожи , направленные вправо',
    '🧑🏽‍🦯‍➡' => 'человек с белой тростью: средний тон кожи , направленные вправо',
    '🧑🏾‍🦯‍➡' => 'человек с белой тростью: темный тон кожи , направленные вправо',
    '🧑🏿‍🦯‍➡' => 'человек с белой тростью: очень темный тон кожи , направленные вправо',
    '👨🏻‍🦯‍➡' => 'мужчина с тростью для ходьбы: очень светлый тон кожи , направленные вправо',
    '👨🏼‍🦯‍➡' => 'мужчина с тростью для ходьбы: светлый тон кожи , направленные вправо',
    '👨🏽‍🦯‍➡' => 'мужчина с тростью для ходьбы: средний тон кожи , направленные вправо',
    '👨🏾‍🦯‍➡' => 'мужчина с тростью для ходьбы: темный тон кожи , направленные вправо',
    '👨🏿‍🦯‍➡' => 'мужчина с тростью для ходьбы: очень темный тон кожи , направленные вправо',
    '👩🏻‍🦯‍➡' => 'женщина с тростью для ходьбы: очень светлый тон кожи , направленные вправо',
    '👩🏼‍🦯‍➡' => 'женщина с тростью для ходьбы: светлый тон кожи , направленные вправо',
    '👩🏽‍🦯‍➡' => 'женщина с тростью для ходьбы: средний тон кожи , направленные вправо',
    '👩🏾‍🦯‍➡' => 'женщина с тростью для ходьбы: темный тон кожи , направленные вправо',
    '👩🏿‍🦯‍➡' => 'женщина с тростью для ходьбы: очень темный тон кожи , направленные вправо',
    '🧑🏻‍🦼‍➡' => 'человек в кресле-коляске с мотором: очень светлый тон кожи , направленные вправо',
    '🧑🏼‍🦼‍➡' => 'человек в кресле-коляске с мотором: светлый тон кожи , направленные вправо',
    '🧑🏽‍🦼‍➡' => 'человек в кресле-коляске с мотором: средний тон кожи , направленные вправо',
    '🧑🏾‍🦼‍➡' => 'человек в кресле-коляске с мотором: темный тон кожи , направленные вправо',
    '🧑🏿‍🦼‍➡' => 'человек в кресле-коляске с мотором: очень темный тон кожи , направленные вправо',
    '👨🏻‍🦼‍➡' => 'мужчина в электрическом кресле-коляске: очень светлый тон кожи , направленные вправо',
    '👨🏼‍🦼‍➡' => 'мужчина в электрическом кресле-коляске: светлый тон кожи , направленные вправо',
    '👨🏽‍🦼‍➡' => 'мужчина в электрическом кресле-коляске: средний тон кожи , направленные вправо',
    '👨🏾‍🦼‍➡' => 'мужчина в электрическом кресле-коляске: темный тон кожи , направленные вправо',
    '👨🏿‍🦼‍➡' => 'мужчина в электрическом кресле-коляске: очень темный тон кожи , направленные вправо',
    '👩🏻‍🦼‍➡' => 'женщина в электрическом кресле-коляске: очень светлый тон кожи , направленные вправо',
    '👩🏼‍🦼‍➡' => 'женщина в электрическом кресле-коляске: светлый тон кожи , направленные вправо',
    '👩🏽‍🦼‍➡' => 'женщина в электрическом кресле-коляске: средний тон кожи , направленные вправо',
    '👩🏾‍🦼‍➡' => 'женщина в электрическом кресле-коляске: темный тон кожи , направленные вправо',
    '👩🏿‍🦼‍➡' => 'женщина в электрическом кресле-коляске: очень темный тон кожи , направленные вправо',
    '🧑🏻‍🦽‍➡' => 'человек в кресле-коляске с ручным приводом: очень светлый тон кожи , направленные вправо',
    '🧑🏼‍🦽‍➡' => 'человек в кресле-коляске с ручным приводом: светлый тон кожи , направленные вправо',
    '🧑🏽‍🦽‍➡' => 'человек в кресле-коляске с ручным приводом: средний тон кожи , направленные вправо',
    '🧑🏾‍🦽‍➡' => 'человек в кресле-коляске с ручным приводом: темный тон кожи , направленные вправо',
    '🧑🏿‍🦽‍➡' => 'человек в кресле-коляске с ручным приводом: очень темный тон кожи , направленные вправо',
    '👨🏻‍🦽‍➡' => 'мужчина в ручном кресле-коляске: очень светлый тон кожи , направленные вправо',
    '👨🏼‍🦽‍➡' => 'мужчина в ручном кресле-коляске: светлый тон кожи , направленные вправо',
    '👨🏽‍🦽‍➡' => 'мужчина в ручном кресле-коляске: средний тон кожи , направленные вправо',
    '👨🏾‍🦽‍➡' => 'мужчина в ручном кресле-коляске: темный тон кожи , направленные вправо',
    '👨🏿‍🦽‍➡' => 'мужчина в ручном кресле-коляске: очень темный тон кожи , направленные вправо',
    '👩🏻‍🦽‍➡' => 'женщина в ручном кресле-коляске: очень светлый тон кожи , направленные вправо',
    '👩🏼‍🦽‍➡' => 'женщина в ручном кресле-коляске: светлый тон кожи , направленные вправо',
    '👩🏽‍🦽‍➡' => 'женщина в ручном кресле-коляске: средний тон кожи , направленные вправо',
    '👩🏾‍🦽‍➡' => 'женщина в ручном кресле-коляске: темный тон кожи , направленные вправо',
    '👩🏿‍🦽‍➡' => 'женщина в ручном кресле-коляске: очень темный тон кожи , направленные вправо',
    '🏃🏻‍♀‍➡' => 'женщина бежит: очень светлый тон кожи , направленные вправо',
    '🏃🏼‍♀‍➡' => 'женщина бежит: светлый тон кожи , направленные вправо',
    '🏃🏽‍♀‍➡' => 'женщина бежит: средний тон кожи , направленные вправо',
    '🏃🏾‍♀‍➡' => 'женщина бежит: темный тон кожи , направленные вправо',
    '🏃🏿‍♀‍➡' => 'женщина бежит: очень темный тон кожи , направленные вправо',
    '🏃🏻‍♂‍➡' => 'мужчина бежит: очень светлый тон кожи , направленные вправо',
    '🏃🏼‍♂‍➡' => 'мужчина бежит: светлый тон кожи , направленные вправо',
    '🏃🏽‍♂‍➡' => 'мужчина бежит: средний тон кожи , направленные вправо',
    '🏃🏾‍♂‍➡' => 'мужчина бежит: темный тон кожи , направленные вправо',
    '🏃🏿‍♂‍➡' => 'мужчина бежит: очень темный тон кожи , направленные вправо',
    '🫱🏻‍🫲🏼' => 'рукопожатие: очень светлый тон кожи светлый тон кожи',
    '🫱🏻‍🫲🏽' => 'рукопожатие: очень светлый тон кожи средний тон кожи',
    '🫱🏻‍🫲🏾' => 'рукопожатие: очень светлый тон кожи темный тон кожи',
    '🫱🏻‍🫲🏿' => 'рукопожатие: очень светлый тон кожи очень темный тон кожи',
    '🫱🏼‍🫲🏻' => 'рукопожатие: светлый тон кожи очень светлый тон кожи',
    '🫱🏼‍🫲🏽' => 'рукопожатие: светлый тон кожи средний тон кожи',
    '🫱🏼‍🫲🏾' => 'рукопожатие: светлый тон кожи темный тон кожи',
    '🫱🏼‍🫲🏿' => 'рукопожатие: светлый тон кожи очень темный тон кожи',
    '🫱🏽‍🫲🏻' => 'рукопожатие: средний тон кожи очень светлый тон кожи',
    '🫱🏽‍🫲🏼' => 'рукопожатие: средний тон кожи светлый тон кожи',
    '🫱🏽‍🫲🏾' => 'рукопожатие: средний тон кожи темный тон кожи',
    '🫱🏽‍🫲🏿' => 'рукопожатие: средний тон кожи очень темный тон кожи',
    '🫱🏾‍🫲🏻' => 'рукопожатие: темный тон кожи очень светлый тон кожи',
    '🫱🏾‍🫲🏼' => 'рукопожатие: темный тон кожи светлый тон кожи',
    '🫱🏾‍🫲🏽' => 'рукопожатие: темный тон кожи средний тон кожи',
    '🫱🏾‍🫲🏿' => 'рукопожатие: темный тон кожи очень темный тон кожи',
    '🫱🏿‍🫲🏻' => 'рукопожатие: очень темный тон кожи очень светлый тон кожи',
    '🫱🏿‍🫲🏼' => 'рукопожатие: очень темный тон кожи светлый тон кожи',
    '🫱🏿‍🫲🏽' => 'рукопожатие: очень темный тон кожи средний тон кожи',
    '🫱🏿‍🫲🏾' => 'рукопожатие: очень темный тон кожи темный тон кожи',
    '🚶‍♀‍➡' => 'женщина идет: , направленные вправо',
    '🚶‍♂‍➡' => 'мужчина идет: , направленные вправо',
    '🧎‍♀‍➡' => 'женщина на коленях: , направленные вправо',
    '🧎‍♂‍➡' => 'мужчина на коленях: , направленные вправо',
    '🧑‍🦯‍➡' => 'человек с белой тростью: , направленные вправо',
    '👨‍🦯‍➡' => 'мужчина с тростью для ходьбы: , направленные вправо',
    '👩‍🦯‍➡' => 'женщина с тростью для ходьбы: , направленные вправо',
    '🧑‍🦼‍➡' => 'человек в кресле-коляске с мотором: , направленные вправо',
    '👨‍🦼‍➡' => 'мужчина в электрическом кресле-коляске: , направленные вправо',
    '👩‍🦼‍➡' => 'женщина в электрическом кресле-коляске: , направленные вправо',
    '🧑‍🦽‍➡' => 'человек в кресле-коляске с ручным приводом: , направленные вправо',
    '👨‍🦽‍➡' => 'мужчина в ручном кресле-коляске: , направленные вправо',
    '👩‍🦽‍➡' => 'женщина в ручном кресле-коляске: , направленные вправо',
    '🏃‍♀‍➡' => 'женщина бежит: , направленные вправо',
    '🏃‍♂‍➡' => 'мужчина бежит: , направленные вправо',
    '👩‍❤‍👨' => 'влюбленная пара: женщина мужчина',
    '👨‍❤‍👨' => 'влюбленная пара: мужчина мужчина',
    '👩‍❤‍👩' => 'влюбленная пара: женщина женщина',
    '👨‍👩‍👦' => 'семья: мужчина женщина мальчик',
    '👨‍👩‍👧' => 'семья: мужчина женщина девочка',
    '👨‍👨‍👦' => 'семья: мужчина мужчина мальчик',
    '👨‍👨‍👧' => 'семья: мужчина мужчина девочка',
    '👩‍👩‍👦' => 'семья: женщина женщина мальчик',
    '👩‍👩‍👧' => 'семья: женщина женщина девочка',
    '👨‍👦‍👦' => 'семья: мужчина мальчик мальчик',
    '👨‍👧‍👦' => 'семья: мужчина девочка мальчик',
    '👨‍👧‍👧' => 'семья: мужчина девочка девочка',
    '👩‍👦‍👦' => 'семья: женщина мальчик мальчик',
    '👩‍👧‍👦' => 'семья: женщина девочка мальчик',
    '👩‍👧‍👧' => 'семья: женщина девочка девочка',
    '🧑‍🤝‍🧑' => 'люди, держащиеся за руки',
    '🧑‍🧑‍🧒' => 'семья: двое взрослых и ребенок',
    '🧑‍🧒‍🧒' => 'семья: взрослый и двое детей',
    '🧑🏻‍🦰' => 'взрослый: очень светлый тон кожи рыжие волосы',
    '🧑🏼‍🦰' => 'взрослый: светлый тон кожи рыжие волосы',
    '🧑🏽‍🦰' => 'взрослый: средний тон кожи рыжие волосы',
    '🧑🏾‍🦰' => 'взрослый: темный тон кожи рыжие волосы',
    '🧑🏿‍🦰' => 'взрослый: очень темный тон кожи рыжие волосы',
    '🧑🏻‍🦱' => 'взрослый: очень светлый тон кожи кудрявые волосы',
    '🧑🏼‍🦱' => 'взрослый: светлый тон кожи кудрявые волосы',
    '🧑🏽‍🦱' => 'взрослый: средний тон кожи кудрявые волосы',
    '🧑🏾‍🦱' => 'взрослый: темный тон кожи кудрявые волосы',
    '🧑🏿‍🦱' => 'взрослый: очень темный тон кожи кудрявые волосы',
    '🧑🏻‍🦳' => 'взрослый: очень светлый тон кожи седые волосы',
    '🧑🏼‍🦳' => 'взрослый: светлый тон кожи седые волосы',
    '🧑🏽‍🦳' => 'взрослый: средний тон кожи седые волосы',
    '🧑🏾‍🦳' => 'взрослый: темный тон кожи седые волосы',
    '🧑🏿‍🦳' => 'взрослый: очень темный тон кожи седые волосы',
    '🧑🏻‍🦲' => 'взрослый: очень светлый тон кожи без волос',
    '🧑🏼‍🦲' => 'взрослый: светлый тон кожи без волос',
    '🧑🏽‍🦲' => 'взрослый: средний тон кожи без волос',
    '🧑🏾‍🦲' => 'взрослый: темный тон кожи без волос',
    '🧑🏿‍🦲' => 'взрослый: очень темный тон кожи без волос',
    '🧑🏻‍🩰' => 'артист балета: очень светлый тон кожи',
    '🧑🏼‍🩰' => 'артист балета: светлый тон кожи',
    '🧑🏽‍🩰' => 'артист балета: средний тон кожи',
    '🧑🏾‍🩰' => 'артист балета: темный тон кожи',
    '🧑🏿‍🩰' => 'артист балета: очень темный тон кожи',
    '🧔🏻‍♂' => 'бородатый мужчина: очень светлый тон кожи',
    '🧔🏼‍♂' => 'бородатый мужчина: светлый тон кожи',
    '🧔🏽‍♂' => 'бородатый мужчина: средний тон кожи',
    '🧔🏾‍♂' => 'бородатый мужчина: темный тон кожи',
    '🧔🏿‍♂' => 'бородатый мужчина: очень темный тон кожи',
    '👱🏻‍♂' => 'блондин: очень светлый тон кожи',
    '👱🏼‍♂' => 'блондин: светлый тон кожи',
    '👱🏽‍♂' => 'блондин: средний тон кожи',
    '👱🏾‍♂' => 'блондин: темный тон кожи',
    '👱🏿‍♂' => 'блондин: очень темный тон кожи',
    '👨🏻‍🦰' => 'мужчина: очень светлый тон кожи рыжие волосы',
    '👨🏼‍🦰' => 'мужчина: светлый тон кожи рыжие волосы',
    '👨🏽‍🦰' => 'мужчина: средний тон кожи рыжие волосы',
    '👨🏾‍🦰' => 'мужчина: темный тон кожи рыжие волосы',
    '👨🏿‍🦰' => 'мужчина: очень темный тон кожи рыжие волосы',
    '👨🏻‍🦱' => 'мужчина: очень светлый тон кожи кудрявые волосы',
    '👨🏼‍🦱' => 'мужчина: светлый тон кожи кудрявые волосы',
    '👨🏽‍🦱' => 'мужчина: средний тон кожи кудрявые волосы',
    '👨🏾‍🦱' => 'мужчина: темный тон кожи кудрявые волосы',
    '👨🏿‍🦱' => 'мужчина: очень темный тон кожи кудрявые волосы',
    '👨🏻‍🦳' => 'мужчина: очень светлый тон кожи седые волосы',
    '👨🏼‍🦳' => 'мужчина: светлый тон кожи седые волосы',
    '👨🏽‍🦳' => 'мужчина: средний тон кожи седые волосы',
    '👨🏾‍🦳' => 'мужчина: темный тон кожи седые волосы',
    '👨🏿‍🦳' => 'мужчина: очень темный тон кожи седые волосы',
    '👨🏻‍🦲' => 'мужчина: очень светлый тон кожи без волос',
    '👨🏼‍🦲' => 'мужчина: светлый тон кожи без волос',
    '👨🏽‍🦲' => 'мужчина: средний тон кожи без волос',
    '👨🏾‍🦲' => 'мужчина: темный тон кожи без волос',
    '👨🏿‍🦲' => 'мужчина: очень темный тон кожи без волос',
    '🧔🏻‍♀' => 'бородатая женщина: очень светлый тон кожи',
    '🧔🏼‍♀' => 'бородатая женщина: светлый тон кожи',
    '🧔🏽‍♀' => 'бородатая женщина: средний тон кожи',
    '🧔🏾‍♀' => 'бородатая женщина: темный тон кожи',
    '🧔🏿‍♀' => 'бородатая женщина: очень темный тон кожи',
    '👱🏻‍♀' => 'блондинка: очень светлый тон кожи',
    '👱🏼‍♀' => 'блондинка: светлый тон кожи',
    '👱🏽‍♀' => 'блондинка: средний тон кожи',
    '👱🏾‍♀' => 'блондинка: темный тон кожи',
    '👱🏿‍♀' => 'блондинка: очень темный тон кожи',
    '👩🏻‍🦰' => 'женщина: очень светлый тон кожи рыжие волосы',
    '👩🏼‍🦰' => 'женщина: светлый тон кожи рыжие волосы',
    '👩🏽‍🦰' => 'женщина: средний тон кожи рыжие волосы',
    '👩🏾‍🦰' => 'женщина: темный тон кожи рыжие волосы',
    '👩🏿‍🦰' => 'женщина: очень темный тон кожи рыжие волосы',
    '👩🏻‍🦱' => 'женщина: очень светлый тон кожи кудрявые волосы',
    '👩🏼‍🦱' => 'женщина: светлый тон кожи кудрявые волосы',
    '👩🏽‍🦱' => 'женщина: средний тон кожи кудрявые волосы',
    '👩🏾‍🦱' => 'женщина: темный тон кожи кудрявые волосы',
    '👩🏿‍🦱' => 'женщина: очень темный тон кожи кудрявые волосы',
    '👩🏻‍🦳' => 'женщина: очень светлый тон кожи седые волосы',
    '👩🏼‍🦳' => 'женщина: светлый тон кожи седые волосы',
    '👩🏽‍🦳' => 'женщина: средний тон кожи седые волосы',
    '👩🏾‍🦳' => 'женщина: темный тон кожи седые волосы',
    '👩🏿‍🦳' => 'женщина: очень темный тон кожи седые волосы',
    '👩🏻‍🦲' => 'женщина: очень светлый тон кожи без волос',
    '👩🏼‍🦲' => 'женщина: светлый тон кожи без волос',
    '👩🏽‍🦲' => 'женщина: средний тон кожи без волос',
    '👩🏾‍🦲' => 'женщина: темный тон кожи без волос',
    '👩🏿‍🦲' => 'женщина: очень темный тон кожи без волос',
    '🙍🏻‍♂' => 'нахмурившийся мужчина: очень светлый тон кожи',
    '🙍🏼‍♂' => 'нахмурившийся мужчина: светлый тон кожи',
    '🙍🏽‍♂' => 'нахмурившийся мужчина: средний тон кожи',
    '🙍🏾‍♂' => 'нахмурившийся мужчина: темный тон кожи',
    '🙍🏿‍♂' => 'нахмурившийся мужчина: очень темный тон кожи',
    '🙍🏻‍♀' => 'нахмурившаяся женщина: очень светлый тон кожи',
    '🙍🏼‍♀' => 'нахмурившаяся женщина: светлый тон кожи',
    '🙍🏽‍♀' => 'нахмурившаяся женщина: средний тон кожи',
    '🙍🏾‍♀' => 'нахмурившаяся женщина: темный тон кожи',
    '🙍🏿‍♀' => 'нахмурившаяся женщина: очень темный тон кожи',
    '🙎🏻‍♂' => 'обиженный мужчина: очень светлый тон кожи',
    '🙎🏼‍♂' => 'обиженный мужчина: светлый тон кожи',
    '🙎🏽‍♂' => 'обиженный мужчина: средний тон кожи',
    '🙎🏾‍♂' => 'обиженный мужчина: темный тон кожи',
    '🙎🏿‍♂' => 'обиженный мужчина: очень темный тон кожи',
    '🙎🏻‍♀' => 'обиженная женщина: очень светлый тон кожи',
    '🙎🏼‍♀' => 'обиженная женщина: светлый тон кожи',
    '🙎🏽‍♀' => 'обиженная женщина: средний тон кожи',
    '🙎🏾‍♀' => 'обиженная женщина: темный тон кожи',
    '🙎🏿‍♀' => 'обиженная женщина: очень темный тон кожи',
    '🙅🏻‍♂' => 'мужчина против: очень светлый тон кожи',
    '🙅🏼‍♂' => 'мужчина против: светлый тон кожи',
    '🙅🏽‍♂' => 'мужчина против: средний тон кожи',
    '🙅🏾‍♂' => 'мужчина против: темный тон кожи',
    '🙅🏿‍♂' => 'мужчина против: очень темный тон кожи',
    '🙅🏻‍♀' => 'женщина против: очень светлый тон кожи',
    '🙅🏼‍♀' => 'женщина против: светлый тон кожи',
    '🙅🏽‍♀' => 'женщина против: средний тон кожи',
    '🙅🏾‍♀' => 'женщина против: темный тон кожи',
    '🙅🏿‍♀' => 'женщина против: очень темный тон кожи',
    '🙆🏻‍♂' => 'мужчина за: очень светлый тон кожи',
    '🙆🏼‍♂' => 'мужчина за: светлый тон кожи',
    '🙆🏽‍♂' => 'мужчина за: средний тон кожи',
    '🙆🏾‍♂' => 'мужчина за: темный тон кожи',
    '🙆🏿‍♂' => 'мужчина за: очень темный тон кожи',
    '🙆🏻‍♀' => 'женщина за: очень светлый тон кожи',
    '🙆🏼‍♀' => 'женщина за: светлый тон кожи',
    '🙆🏽‍♀' => 'женщина за: средний тон кожи',
    '🙆🏾‍♀' => 'женщина за: темный тон кожи',
    '🙆🏿‍♀' => 'женщина за: очень темный тон кожи',
    '💁🏻‍♂' => 'мужчина тянет руку: очень светлый тон кожи',
    '💁🏼‍♂' => 'мужчина тянет руку: светлый тон кожи',
    '💁🏽‍♂' => 'мужчина тянет руку: средний тон кожи',
    '💁🏾‍♂' => 'мужчина тянет руку: темный тон кожи',
    '💁🏿‍♂' => 'мужчина тянет руку: очень темный тон кожи',
    '💁🏻‍♀' => 'женщина тянет руку: очень светлый тон кожи',
    '💁🏼‍♀' => 'женщина тянет руку: светлый тон кожи',
    '💁🏽‍♀' => 'женщина тянет руку: средний тон кожи',
    '💁🏾‍♀' => 'женщина тянет руку: темный тон кожи',
    '💁🏿‍♀' => 'женщина тянет руку: очень темный тон кожи',
    '🙋🏻‍♂' => 'мужчина с поднятой рукой: очень светлый тон кожи',
    '🙋🏼‍♂' => 'мужчина с поднятой рукой: светлый тон кожи',
    '🙋🏽‍♂' => 'мужчина с поднятой рукой: средний тон кожи',
    '🙋🏾‍♂' => 'мужчина с поднятой рукой: темный тон кожи',
    '🙋🏿‍♂' => 'мужчина с поднятой рукой: очень темный тон кожи',
    '🙋🏻‍♀' => 'женщина с поднятой рукой: очень светлый тон кожи',
    '🙋🏼‍♀' => 'женщина с поднятой рукой: светлый тон кожи',
    '🙋🏽‍♀' => 'женщина с поднятой рукой: средний тон кожи',
    '🙋🏾‍♀' => 'женщина с поднятой рукой: темный тон кожи',
    '🙋🏿‍♀' => 'женщина с поднятой рукой: очень темный тон кожи',
    '🧏🏻‍♂' => 'глухой мужчина: очень светлый тон кожи',
    '🧏🏼‍♂' => 'глухой мужчина: светлый тон кожи',
    '🧏🏽‍♂' => 'глухой мужчина: средний тон кожи',
    '🧏🏾‍♂' => 'глухой мужчина: темный тон кожи',
    '🧏🏿‍♂' => 'глухой мужчина: очень темный тон кожи',
    '🧏🏻‍♀' => 'глухая женщина: очень светлый тон кожи',
    '🧏🏼‍♀' => 'глухая женщина: светлый тон кожи',
    '🧏🏽‍♀' => 'глухая женщина: средний тон кожи',
    '🧏🏾‍♀' => 'глухая женщина: темный тон кожи',
    '🧏🏿‍♀' => 'глухая женщина: очень темный тон кожи',
    '🙇🏻‍♂' => 'мужчина кланяется: очень светлый тон кожи',
    '🙇🏼‍♂' => 'мужчина кланяется: светлый тон кожи',
    '🙇🏽‍♂' => 'мужчина кланяется: средний тон кожи',
    '🙇🏾‍♂' => 'мужчина кланяется: темный тон кожи',
    '🙇🏿‍♂' => 'мужчина кланяется: очень темный тон кожи',
    '🙇🏻‍♀' => 'женщина кланяется: очень светлый тон кожи',
    '🙇🏼‍♀' => 'женщина кланяется: светлый тон кожи',
    '🙇🏽‍♀' => 'женщина кланяется: средний тон кожи',
    '🙇🏾‍♀' => 'женщина кланяется: темный тон кожи',
    '🙇🏿‍♀' => 'женщина кланяется: очень темный тон кожи',
    '🤦🏻‍♂' => 'мужчина потерял дар речи: очень светлый тон кожи',
    '🤦🏼‍♂' => 'мужчина потерял дар речи: светлый тон кожи',
    '🤦🏽‍♂' => 'мужчина потерял дар речи: средний тон кожи',
    '🤦🏾‍♂' => 'мужчина потерял дар речи: темный тон кожи',
    '🤦🏿‍♂' => 'мужчина потерял дар речи: очень темный тон кожи',
    '🤦🏻‍♀' => 'женщина потеряла дар речи: очень светлый тон кожи',
    '🤦🏼‍♀' => 'женщина потеряла дар речи: светлый тон кожи',
    '🤦🏽‍♀' => 'женщина потеряла дар речи: средний тон кожи',
    '🤦🏾‍♀' => 'женщина потеряла дар речи: темный тон кожи',
    '🤦🏿‍♀' => 'женщина потеряла дар речи: очень темный тон кожи',
    '🤷🏻‍♂' => 'мужчина пожимает плечами: очень светлый тон кожи',
    '🤷🏼‍♂' => 'мужчина пожимает плечами: светлый тон кожи',
    '🤷🏽‍♂' => 'мужчина пожимает плечами: средний тон кожи',
    '🤷🏾‍♂' => 'мужчина пожимает плечами: темный тон кожи',
    '🤷🏿‍♂' => 'мужчина пожимает плечами: очень темный тон кожи',
    '🤷🏻‍♀' => 'женщина пожимает плечами: очень светлый тон кожи',
    '🤷🏼‍♀' => 'женщина пожимает плечами: светлый тон кожи',
    '🤷🏽‍♀' => 'женщина пожимает плечами: средний тон кожи',
    '🤷🏾‍♀' => 'женщина пожимает плечами: темный тон кожи',
    '🤷🏿‍♀' => 'женщина пожимает плечами: очень темный тон кожи',
    '🧑🏻‍⚕' => 'медицинский работник: очень светлый тон кожи',
    '🧑🏼‍⚕' => 'медицинский работник: светлый тон кожи',
    '🧑🏽‍⚕' => 'медицинский работник: средний тон кожи',
    '🧑🏾‍⚕' => 'медицинский работник: темный тон кожи',
    '🧑🏿‍⚕' => 'медицинский работник: очень темный тон кожи',
    '👨🏻‍⚕' => 'врач: очень светлый тон кожи',
    '👨🏼‍⚕' => 'врач: светлый тон кожи',
    '👨🏽‍⚕' => 'врач: средний тон кожи',
    '👨🏾‍⚕' => 'врач: темный тон кожи',
    '👨🏿‍⚕' => 'врач: очень темный тон кожи',
    '👩🏻‍⚕' => 'женщина-врач: очень светлый тон кожи',
    '👩🏼‍⚕' => 'женщина-врач: светлый тон кожи',
    '👩🏽‍⚕' => 'женщина-врач: средний тон кожи',
    '👩🏾‍⚕' => 'женщина-врач: темный тон кожи',
    '👩🏿‍⚕' => 'женщина-врач: очень темный тон кожи',
    '🧑🏻‍🎓' => 'учащийся: очень светлый тон кожи',
    '🧑🏼‍🎓' => 'учащийся: светлый тон кожи',
    '🧑🏽‍🎓' => 'учащийся: средний тон кожи',
    '🧑🏾‍🎓' => 'учащийся: темный тон кожи',
    '🧑🏿‍🎓' => 'учащийся: очень темный тон кожи',
    '👨🏻‍🎓' => 'студент: очень светлый тон кожи',
    '👨🏼‍🎓' => 'студент: светлый тон кожи',
    '👨🏽‍🎓' => 'студент: средний тон кожи',
    '👨🏾‍🎓' => 'студент: темный тон кожи',
    '👨🏿‍🎓' => 'студент: очень темный тон кожи',
    '👩🏻‍🎓' => 'студентка: очень светлый тон кожи',
    '👩🏼‍🎓' => 'студентка: светлый тон кожи',
    '👩🏽‍🎓' => 'студентка: средний тон кожи',
    '👩🏾‍🎓' => 'студентка: темный тон кожи',
    '👩🏿‍🎓' => 'студентка: очень темный тон кожи',
    '🧑🏻‍🏫' => 'педагог: очень светлый тон кожи',
    '🧑🏼‍🏫' => 'педагог: светлый тон кожи',
    '🧑🏽‍🏫' => 'педагог: средний тон кожи',
    '🧑🏾‍🏫' => 'педагог: темный тон кожи',
    '🧑🏿‍🏫' => 'педагог: очень темный тон кожи',
    '👨🏻‍🏫' => 'учитель: очень светлый тон кожи',
    '👨🏼‍🏫' => 'учитель: светлый тон кожи',
    '👨🏽‍🏫' => 'учитель: средний тон кожи',
    '👨🏾‍🏫' => 'учитель: темный тон кожи',
    '👨🏿‍🏫' => 'учитель: очень темный тон кожи',
    '👩🏻‍🏫' => 'учительница: очень светлый тон кожи',
    '👩🏼‍🏫' => 'учительница: светлый тон кожи',
    '👩🏽‍🏫' => 'учительница: средний тон кожи',
    '👩🏾‍🏫' => 'учительница: темный тон кожи',
    '👩🏿‍🏫' => 'учительница: очень темный тон кожи',
    '🧑🏻‍⚖' => 'судья: очень светлый тон кожи',
    '🧑🏼‍⚖' => 'судья: светлый тон кожи',
    '🧑🏽‍⚖' => 'судья: средний тон кожи',
    '🧑🏾‍⚖' => 'судья: темный тон кожи',
    '🧑🏿‍⚖' => 'судья: очень темный тон кожи',
    '👨🏻‍⚖' => 'мужчина-судья: очень светлый тон кожи',
    '👨🏼‍⚖' => 'мужчина-судья: светлый тон кожи',
    '👨🏽‍⚖' => 'мужчина-судья: средний тон кожи',
    '👨🏾‍⚖' => 'мужчина-судья: темный тон кожи',
    '👨🏿‍⚖' => 'мужчина-судья: очень темный тон кожи',
    '👩🏻‍⚖' => 'женщина-судья: очень светлый тон кожи',
    '👩🏼‍⚖' => 'женщина-судья: светлый тон кожи',
    '👩🏽‍⚖' => 'женщина-судья: средний тон кожи',
    '👩🏾‍⚖' => 'женщина-судья: темный тон кожи',
    '👩🏿‍⚖' => 'женщина-судья: очень темный тон кожи',
    '🧑🏻‍🌾' => 'фермер: очень светлый тон кожи',
    '🧑🏼‍🌾' => 'фермер: светлый тон кожи',
    '🧑🏽‍🌾' => 'фермер: средний тон кожи',
    '🧑🏾‍🌾' => 'фермер: темный тон кожи',
    '🧑🏿‍🌾' => 'фермер: очень темный тон кожи',
    '👨🏻‍🌾' => 'мужчина-фермер: очень светлый тон кожи',
    '👨🏼‍🌾' => 'мужчина-фермер: светлый тон кожи',
    '👨🏽‍🌾' => 'мужчина-фермер: средний тон кожи',
    '👨🏾‍🌾' => 'мужчина-фермер: темный тон кожи',
    '👨🏿‍🌾' => 'мужчина-фермер: очень темный тон кожи',
    '👩🏻‍🌾' => 'женщина-фермер: очень светлый тон кожи',
    '👩🏼‍🌾' => 'женщина-фермер: светлый тон кожи',
    '👩🏽‍🌾' => 'женщина-фермер: средний тон кожи',
    '👩🏾‍🌾' => 'женщина-фермер: темный тон кожи',
    '👩🏿‍🌾' => 'женщина-фермер: очень темный тон кожи',
    '🧑🏻‍🍳' => 'повар: очень светлый тон кожи',
    '🧑🏼‍🍳' => 'повар: светлый тон кожи',
    '🧑🏽‍🍳' => 'повар: средний тон кожи',
    '🧑🏾‍🍳' => 'повар: темный тон кожи',
    '🧑🏿‍🍳' => 'повар: очень темный тон кожи',
    '👨🏻‍🍳' => 'мужчина-повар: очень светлый тон кожи',
    '👨🏼‍🍳' => 'мужчина-повар: светлый тон кожи',
    '👨🏽‍🍳' => 'мужчина-повар: средний тон кожи',
    '👨🏾‍🍳' => 'мужчина-повар: темный тон кожи',
    '👨🏿‍🍳' => 'мужчина-повар: очень темный тон кожи',
    '👩🏻‍🍳' => 'повариха: очень светлый тон кожи',
    '👩🏼‍🍳' => 'повариха: светлый тон кожи',
    '👩🏽‍🍳' => 'повариха: средний тон кожи',
    '👩🏾‍🍳' => 'повариха: темный тон кожи',
    '👩🏿‍🍳' => 'повариха: очень темный тон кожи',
    '🧑🏻‍🔧' => 'механик: очень светлый тон кожи',
    '🧑🏼‍🔧' => 'механик: светлый тон кожи',
    '🧑🏽‍🔧' => 'механик: средний тон кожи',
    '🧑🏾‍🔧' => 'механик: темный тон кожи',
    '🧑🏿‍🔧' => 'механик: очень темный тон кожи',
    '👨🏻‍🔧' => 'мужчина-механик: очень светлый тон кожи',
    '👨🏼‍🔧' => 'мужчина-механик: светлый тон кожи',
    '👨🏽‍🔧' => 'мужчина-механик: средний тон кожи',
    '👨🏾‍🔧' => 'мужчина-механик: темный тон кожи',
    '👨🏿‍🔧' => 'мужчина-механик: очень темный тон кожи',
    '👩🏻‍🔧' => 'женщина-механик: очень светлый тон кожи',
    '👩🏼‍🔧' => 'женщина-механик: светлый тон кожи',
    '👩🏽‍🔧' => 'женщина-механик: средний тон кожи',
    '👩🏾‍🔧' => 'женщина-механик: темный тон кожи',
    '👩🏿‍🔧' => 'женщина-механик: очень темный тон кожи',
    '🧑🏻‍🏭' => 'рабочий: очень светлый тон кожи',
    '🧑🏼‍🏭' => 'рабочий: светлый тон кожи',
    '🧑🏽‍🏭' => 'рабочий: средний тон кожи',
    '🧑🏾‍🏭' => 'рабочий: темный тон кожи',
    '🧑🏿‍🏭' => 'рабочий: очень темный тон кожи',
    '👨🏻‍🏭' => 'мужчина-рабочий: очень светлый тон кожи',
    '👨🏼‍🏭' => 'мужчина-рабочий: светлый тон кожи',
    '👨🏽‍🏭' => 'мужчина-рабочий: средний тон кожи',
    '👨🏾‍🏭' => 'мужчина-рабочий: темный тон кожи',
    '👨🏿‍🏭' => 'мужчина-рабочий: очень темный тон кожи',
    '👩🏻‍🏭' => 'работница: очень светлый тон кожи',
    '👩🏼‍🏭' => 'работница: светлый тон кожи',
    '👩🏽‍🏭' => 'работница: средний тон кожи',
    '👩🏾‍🏭' => 'работница: темный тон кожи',
    '👩🏿‍🏭' => 'работница: очень темный тон кожи',
    '🧑🏻‍💼' => 'офисный работник: очень светлый тон кожи',
    '🧑🏼‍💼' => 'офисный работник: светлый тон кожи',
    '🧑🏽‍💼' => 'офисный работник: средний тон кожи',
    '🧑🏾‍💼' => 'офисный работник: темный тон кожи',
    '🧑🏿‍💼' => 'офисный работник: очень темный тон кожи',
    '👨🏻‍💼' => 'офисный работник - мужчина: очень светлый тон кожи',
    '👨🏼‍💼' => 'офисный работник - мужчина: светлый тон кожи',
    '👨🏽‍💼' => 'офисный работник - мужчина: средний тон кожи',
    '👨🏾‍💼' => 'офисный работник - мужчина: темный тон кожи',
    '👨🏿‍💼' => 'офисный работник - мужчина: очень темный тон кожи',
    '👩🏻‍💼' => 'офисная работница: очень светлый тон кожи',
    '👩🏼‍💼' => 'офисная работница: светлый тон кожи',
    '👩🏽‍💼' => 'офисная работница: средний тон кожи',
    '👩🏾‍💼' => 'офисная работница: темный тон кожи',
    '👩🏿‍💼' => 'офисная работница: очень темный тон кожи',
    '🧑🏻‍🔬' => 'ученый: очень светлый тон кожи',
    '🧑🏼‍🔬' => 'ученый: светлый тон кожи',
    '🧑🏽‍🔬' => 'ученый: средний тон кожи',
    '🧑🏾‍🔬' => 'ученый: темный тон кожи',
    '🧑🏿‍🔬' => 'ученый: очень темный тон кожи',
    '👨🏻‍🔬' => 'мужчина-ученый: очень светлый тон кожи',
    '👨🏼‍🔬' => 'мужчина-ученый: светлый тон кожи',
    '👨🏽‍🔬' => 'мужчина-ученый: средний тон кожи',
    '👨🏾‍🔬' => 'мужчина-ученый: темный тон кожи',
    '👨🏿‍🔬' => 'мужчина-ученый: очень темный тон кожи',
    '👩🏻‍🔬' => 'ученая: очень светлый тон кожи',
    '👩🏼‍🔬' => 'ученая: светлый тон кожи',
    '👩🏽‍🔬' => 'ученая: средний тон кожи',
    '👩🏾‍🔬' => 'ученая: темный тон кожи',
    '👩🏿‍🔬' => 'ученая: очень темный тон кожи',
    '🧑🏻‍💻' => 'инженер: очень светлый тон кожи',
    '🧑🏼‍💻' => 'инженер: светлый тон кожи',
    '🧑🏽‍💻' => 'инженер: средний тон кожи',
    '🧑🏾‍💻' => 'инженер: темный тон кожи',
    '🧑🏿‍💻' => 'инженер: очень темный тон кожи',
    '👨🏻‍💻' => 'мужчина-инженер: очень светлый тон кожи',
    '👨🏼‍💻' => 'мужчина-инженер: светлый тон кожи',
    '👨🏽‍💻' => 'мужчина-инженер: средний тон кожи',
    '👨🏾‍💻' => 'мужчина-инженер: темный тон кожи',
    '👨🏿‍💻' => 'мужчина-инженер: очень темный тон кожи',
    '👩🏻‍💻' => 'женщина-инженер: очень светлый тон кожи',
    '👩🏼‍💻' => 'женщина-инженер: светлый тон кожи',
    '👩🏽‍💻' => 'женщина-инженер: средний тон кожи',
    '👩🏾‍💻' => 'женщина-инженер: темный тон кожи',
    '👩🏿‍💻' => 'женщина-инженер: очень темный тон кожи',
    '🧑🏻‍🎤' => 'певец: очень светлый тон кожи',
    '🧑🏼‍🎤' => 'певец: светлый тон кожи',
    '🧑🏽‍🎤' => 'певец: средний тон кожи',
    '🧑🏾‍🎤' => 'певец: темный тон кожи',
    '🧑🏿‍🎤' => 'певец: очень темный тон кожи',
    '👨🏻‍🎤' => 'мужчина-певец: очень светлый тон кожи',
    '👨🏼‍🎤' => 'мужчина-певец: светлый тон кожи',
    '👨🏽‍🎤' => 'мужчина-певец: средний тон кожи',
    '👨🏾‍🎤' => 'мужчина-певец: темный тон кожи',
    '👨🏿‍🎤' => 'мужчина-певец: очень темный тон кожи',
    '👩🏻‍🎤' => 'певица: очень светлый тон кожи',
    '👩🏼‍🎤' => 'певица: светлый тон кожи',
    '👩🏽‍🎤' => 'певица: средний тон кожи',
    '👩🏾‍🎤' => 'певица: темный тон кожи',
    '👩🏿‍🎤' => 'певица: очень темный тон кожи',
    '🧑🏻‍🎨' => 'художник: очень светлый тон кожи',
    '🧑🏼‍🎨' => 'художник: светлый тон кожи',
    '🧑🏽‍🎨' => 'художник: средний тон кожи',
    '🧑🏾‍🎨' => 'художник: темный тон кожи',
    '🧑🏿‍🎨' => 'художник: очень темный тон кожи',
    '👨🏻‍🎨' => 'мужчина-художник: очень светлый тон кожи',
    '👨🏼‍🎨' => 'мужчина-художник: светлый тон кожи',
    '👨🏽‍🎨' => 'мужчина-художник: средний тон кожи',
    '👨🏾‍🎨' => 'мужчина-художник: темный тон кожи',
    '👨🏿‍🎨' => 'мужчина-художник: очень темный тон кожи',
    '👩🏻‍🎨' => 'художница: очень светлый тон кожи',
    '👩🏼‍🎨' => 'художница: светлый тон кожи',
    '👩🏽‍🎨' => 'художница: средний тон кожи',
    '👩🏾‍🎨' => 'художница: темный тон кожи',
    '👩🏿‍🎨' => 'художница: очень темный тон кожи',
    '🧑🏻‍✈' => 'пилот: очень светлый тон кожи',
    '🧑🏼‍✈' => 'пилот: светлый тон кожи',
    '🧑🏽‍✈' => 'пилот: средний тон кожи',
    '🧑🏾‍✈' => 'пилот: темный тон кожи',
    '🧑🏿‍✈' => 'пилот: очень темный тон кожи',
    '👨🏻‍✈' => 'мужчина-пилот: очень светлый тон кожи',
    '👨🏼‍✈' => 'мужчина-пилот: светлый тон кожи',
    '👨🏽‍✈' => 'мужчина-пилот: средний тон кожи',
    '👨🏾‍✈' => 'мужчина-пилот: темный тон кожи',
    '👨🏿‍✈' => 'мужчина-пилот: очень темный тон кожи',
    '👩🏻‍✈' => 'женщина-пилот: очень светлый тон кожи',
    '👩🏼‍✈' => 'женщина-пилот: светлый тон кожи',
    '👩🏽‍✈' => 'женщина-пилот: средний тон кожи',
    '👩🏾‍✈' => 'женщина-пилот: темный тон кожи',
    '👩🏿‍✈' => 'женщина-пилот: очень темный тон кожи',
    '🧑🏻‍🚀' => 'космонавт: очень светлый тон кожи',
    '🧑🏼‍🚀' => 'космонавт: светлый тон кожи',
    '🧑🏽‍🚀' => 'космонавт: средний тон кожи',
    '🧑🏾‍🚀' => 'космонавт: темный тон кожи',
    '🧑🏿‍🚀' => 'космонавт: очень темный тон кожи',
    '👨🏻‍🚀' => 'мужчина-космонавт: очень светлый тон кожи',
    '👨🏼‍🚀' => 'мужчина-космонавт: светлый тон кожи',
    '👨🏽‍🚀' => 'мужчина-космонавт: средний тон кожи',
    '👨🏾‍🚀' => 'мужчина-космонавт: темный тон кожи',
    '👨🏿‍🚀' => 'мужчина-космонавт: очень темный тон кожи',
    '👩🏻‍🚀' => 'женщина-космонавт: очень светлый тон кожи',
    '👩🏼‍🚀' => 'женщина-космонавт: светлый тон кожи',
    '👩🏽‍🚀' => 'женщина-космонавт: средний тон кожи',
    '👩🏾‍🚀' => 'женщина-космонавт: темный тон кожи',
    '👩🏿‍🚀' => 'женщина-космонавт: очень темный тон кожи',
    '🧑🏻‍🚒' => 'пожарный: очень светлый тон кожи',
    '🧑🏼‍🚒' => 'пожарный: светлый тон кожи',
    '🧑🏽‍🚒' => 'пожарный: средний тон кожи',
    '🧑🏾‍🚒' => 'пожарный: темный тон кожи',
    '🧑🏿‍🚒' => 'пожарный: очень темный тон кожи',
    '👨🏻‍🚒' => 'мужчина-пожарный: очень светлый тон кожи',
    '👨🏼‍🚒' => 'мужчина-пожарный: светлый тон кожи',
    '👨🏽‍🚒' => 'мужчина-пожарный: средний тон кожи',
    '👨🏾‍🚒' => 'мужчина-пожарный: темный тон кожи',
    '👨🏿‍🚒' => 'мужчина-пожарный: очень темный тон кожи',
    '👩🏻‍🚒' => 'женщина-пожарный: очень светлый тон кожи',
    '👩🏼‍🚒' => 'женщина-пожарный: светлый тон кожи',
    '👩🏽‍🚒' => 'женщина-пожарный: средний тон кожи',
    '👩🏾‍🚒' => 'женщина-пожарный: темный тон кожи',
    '👩🏿‍🚒' => 'женщина-пожарный: очень темный тон кожи',
    '👮🏻‍♂' => 'мужчина-полицейский: очень светлый тон кожи',
    '👮🏼‍♂' => 'мужчина-полицейский: светлый тон кожи',
    '👮🏽‍♂' => 'мужчина-полицейский: средний тон кожи',
    '👮🏾‍♂' => 'мужчина-полицейский: темный тон кожи',
    '👮🏿‍♂' => 'мужчина-полицейский: очень темный тон кожи',
    '👮🏻‍♀' => 'женщина-полицейский: очень светлый тон кожи',
    '👮🏼‍♀' => 'женщина-полицейский: светлый тон кожи',
    '👮🏽‍♀' => 'женщина-полицейский: средний тон кожи',
    '👮🏾‍♀' => 'женщина-полицейский: темный тон кожи',
    '👮🏿‍♀' => 'женщина-полицейский: очень темный тон кожи',
    '🕵🏻‍♂' => 'мужчина-детектив: очень светлый тон кожи',
    '🕵🏼‍♂' => 'мужчина-детектив: светлый тон кожи',
    '🕵🏽‍♂' => 'мужчина-детектив: средний тон кожи',
    '🕵🏾‍♂' => 'мужчина-детектив: темный тон кожи',
    '🕵🏿‍♂' => 'мужчина-детектив: очень темный тон кожи',
    '🕵🏻‍♀' => 'женщина-детектив: очень светлый тон кожи',
    '🕵🏼‍♀' => 'женщина-детектив: светлый тон кожи',
    '🕵🏽‍♀' => 'женщина-детектив: средний тон кожи',
    '🕵🏾‍♀' => 'женщина-детектив: темный тон кожи',
    '🕵🏿‍♀' => 'женщина-детектив: очень темный тон кожи',
    '💂🏻‍♂' => 'мужчина-гвардеец: очень светлый тон кожи',
    '💂🏼‍♂' => 'мужчина-гвардеец: светлый тон кожи',
    '💂🏽‍♂' => 'мужчина-гвардеец: средний тон кожи',
    '💂🏾‍♂' => 'мужчина-гвардеец: темный тон кожи',
    '💂🏿‍♂' => 'мужчина-гвардеец: очень темный тон кожи',
    '💂🏻‍♀' => 'женщина-гвардеец: очень светлый тон кожи',
    '💂🏼‍♀' => 'женщина-гвардеец: светлый тон кожи',
    '💂🏽‍♀' => 'женщина-гвардеец: средний тон кожи',
    '💂🏾‍♀' => 'женщина-гвардеец: темный тон кожи',
    '💂🏿‍♀' => 'женщина-гвардеец: очень темный тон кожи',
    '👷🏻‍♂' => 'мужчина-строитель: очень светлый тон кожи',
    '👷🏼‍♂' => 'мужчина-строитель: светлый тон кожи',
    '👷🏽‍♂' => 'мужчина-строитель: средний тон кожи',
    '👷🏾‍♂' => 'мужчина-строитель: темный тон кожи',
    '👷🏿‍♂' => 'мужчина-строитель: очень темный тон кожи',
    '👷🏻‍♀' => 'женщина-строитель: очень светлый тон кожи',
    '👷🏼‍♀' => 'женщина-строитель: светлый тон кожи',
    '👷🏽‍♀' => 'женщина-строитель: средний тон кожи',
    '👷🏾‍♀' => 'женщина-строитель: темный тон кожи',
    '👷🏿‍♀' => 'женщина-строитель: очень темный тон кожи',
    '👳🏻‍♂' => 'мужчина в тюрбане: очень светлый тон кожи',
    '👳🏼‍♂' => 'мужчина в тюрбане: светлый тон кожи',
    '👳🏽‍♂' => 'мужчина в тюрбане: средний тон кожи',
    '👳🏾‍♂' => 'мужчина в тюрбане: темный тон кожи',
    '👳🏿‍♂' => 'мужчина в тюрбане: очень темный тон кожи',
    '👳🏻‍♀' => 'женщина в тюрбане: очень светлый тон кожи',
    '👳🏼‍♀' => 'женщина в тюрбане: светлый тон кожи',
    '👳🏽‍♀' => 'женщина в тюрбане: средний тон кожи',
    '👳🏾‍♀' => 'женщина в тюрбане: темный тон кожи',
    '👳🏿‍♀' => 'женщина в тюрбане: очень темный тон кожи',
    '🤵🏻‍♂' => 'мужчина в смокинге: очень светлый тон кожи',
    '🤵🏼‍♂' => 'мужчина в смокинге: светлый тон кожи',
    '🤵🏽‍♂' => 'мужчина в смокинге: средний тон кожи',
    '🤵🏾‍♂' => 'мужчина в смокинге: темный тон кожи',
    '🤵🏿‍♂' => 'мужчина в смокинге: очень темный тон кожи',
    '🤵🏻‍♀' => 'женщина в смокинге: очень светлый тон кожи',
    '🤵🏼‍♀' => 'женщина в смокинге: светлый тон кожи',
    '🤵🏽‍♀' => 'женщина в смокинге: средний тон кожи',
    '🤵🏾‍♀' => 'женщина в смокинге: темный тон кожи',
    '🤵🏿‍♀' => 'женщина в смокинге: очень темный тон кожи',
    '👰🏻‍♂' => 'мужчина в фате: очень светлый тон кожи',
    '👰🏼‍♂' => 'мужчина в фате: светлый тон кожи',
    '👰🏽‍♂' => 'мужчина в фате: средний тон кожи',
    '👰🏾‍♂' => 'мужчина в фате: темный тон кожи',
    '👰🏿‍♂' => 'мужчина в фате: очень темный тон кожи',
    '👰🏻‍♀' => 'женщина в фате: очень светлый тон кожи',
    '👰🏼‍♀' => 'женщина в фате: светлый тон кожи',
    '👰🏽‍♀' => 'женщина в фате: средний тон кожи',
    '👰🏾‍♀' => 'женщина в фате: темный тон кожи',
    '👰🏿‍♀' => 'женщина в фате: очень темный тон кожи',
    '👩🏻‍🍼' => 'кормящая женщина: очень светлый тон кожи',
    '👩🏼‍🍼' => 'кормящая женщина: светлый тон кожи',
    '👩🏽‍🍼' => 'кормящая женщина: средний тон кожи',
    '👩🏾‍🍼' => 'кормящая женщина: темный тон кожи',
    '👩🏿‍🍼' => 'кормящая женщина: очень темный тон кожи',
    '👨🏻‍🍼' => 'кормящий мужчина: очень светлый тон кожи',
    '👨🏼‍🍼' => 'кормящий мужчина: светлый тон кожи',
    '👨🏽‍🍼' => 'кормящий мужчина: средний тон кожи',
    '👨🏾‍🍼' => 'кормящий мужчина: темный тон кожи',
    '👨🏿‍🍼' => 'кормящий мужчина: очень темный тон кожи',
    '🧑🏻‍🍼' => 'кормящий человек: очень светлый тон кожи',
    '🧑🏼‍🍼' => 'кормящий человек: светлый тон кожи',
    '🧑🏽‍🍼' => 'кормящий человек: средний тон кожи',
    '🧑🏾‍🍼' => 'кормящий человек: темный тон кожи',
    '🧑🏿‍🍼' => 'кормящий человек: очень темный тон кожи',
    '🧑🏻‍🎄' => 'Санта: очень светлый тон кожи',
    '🧑🏼‍🎄' => 'Санта: светлый тон кожи',
    '🧑🏽‍🎄' => 'Санта: средний тон кожи',
    '🧑🏾‍🎄' => 'Санта: темный тон кожи',
    '🧑🏿‍🎄' => 'Санта: очень темный тон кожи',
    '🦸🏻‍♂' => 'мужчина-супергерой: очень светлый тон кожи',
    '🦸🏼‍♂' => 'мужчина-супергерой: светлый тон кожи',
    '🦸🏽‍♂' => 'мужчина-супергерой: средний тон кожи',
    '🦸🏾‍♂' => 'мужчина-супергерой: темный тон кожи',
    '🦸🏿‍♂' => 'мужчина-супергерой: очень темный тон кожи',
    '🦸🏻‍♀' => 'женщина-супергерой: очень светлый тон кожи',
    '🦸🏼‍♀' => 'женщина-супергерой: светлый тон кожи',
    '🦸🏽‍♀' => 'женщина-супергерой: средний тон кожи',
    '🦸🏾‍♀' => 'женщина-супергерой: темный тон кожи',
    '🦸🏿‍♀' => 'женщина-супергерой: очень темный тон кожи',
    '🦹🏻‍♂' => 'мужчина-суперзлодей: очень светлый тон кожи',
    '🦹🏼‍♂' => 'мужчина-суперзлодей: светлый тон кожи',
    '🦹🏽‍♂' => 'мужчина-суперзлодей: средний тон кожи',
    '🦹🏾‍♂' => 'мужчина-суперзлодей: темный тон кожи',
    '🦹🏿‍♂' => 'мужчина-суперзлодей: очень темный тон кожи',
    '🦹🏻‍♀' => 'женщина-суперзлодей: очень светлый тон кожи',
    '🦹🏼‍♀' => 'женщина-суперзлодей: светлый тон кожи',
    '🦹🏽‍♀' => 'женщина-суперзлодей: средний тон кожи',
    '🦹🏾‍♀' => 'женщина-суперзлодей: темный тон кожи',
    '🦹🏿‍♀' => 'женщина-суперзлодей: очень темный тон кожи',
    '🧙🏻‍♂' => 'волшебник: очень светлый тон кожи',
    '🧙🏼‍♂' => 'волшебник: светлый тон кожи',
    '🧙🏽‍♂' => 'волшебник: средний тон кожи',
    '🧙🏾‍♂' => 'волшебник: темный тон кожи',
    '🧙🏿‍♂' => 'волшебник: очень темный тон кожи',
    '🧙🏻‍♀' => 'волшебница: очень светлый тон кожи',
    '🧙🏼‍♀' => 'волшебница: светлый тон кожи',
    '🧙🏽‍♀' => 'волшебница: средний тон кожи',
    '🧙🏾‍♀' => 'волшебница: темный тон кожи',
    '🧙🏿‍♀' => 'волшебница: очень темный тон кожи',
    '🧚🏻‍♂' => 'мужчина-фея: очень светлый тон кожи',
    '🧚🏼‍♂' => 'мужчина-фея: светлый тон кожи',
    '🧚🏽‍♂' => 'мужчина-фея: средний тон кожи',
    '🧚🏾‍♂' => 'мужчина-фея: темный тон кожи',
    '🧚🏿‍♂' => 'мужчина-фея: очень темный тон кожи',
    '🧚🏻‍♀' => 'женщина-фея: очень светлый тон кожи',
    '🧚🏼‍♀' => 'женщина-фея: светлый тон кожи',
    '🧚🏽‍♀' => 'женщина-фея: средний тон кожи',
    '🧚🏾‍♀' => 'женщина-фея: темный тон кожи',
    '🧚🏿‍♀' => 'женщина-фея: очень темный тон кожи',
    '🧛🏻‍♂' => 'мужчина-вампир: очень светлый тон кожи',
    '🧛🏼‍♂' => 'мужчина-вампир: светлый тон кожи',
    '🧛🏽‍♂' => 'мужчина-вампир: средний тон кожи',
    '🧛🏾‍♂' => 'мужчина-вампир: темный тон кожи',
    '🧛🏿‍♂' => 'мужчина-вампир: очень темный тон кожи',
    '🧛🏻‍♀' => 'женщина-вампир: очень светлый тон кожи',
    '🧛🏼‍♀' => 'женщина-вампир: светлый тон кожи',
    '🧛🏽‍♀' => 'женщина-вампир: средний тон кожи',
    '🧛🏾‍♀' => 'женщина-вампир: темный тон кожи',
    '🧛🏿‍♀' => 'женщина-вампир: очень темный тон кожи',
    '🧜🏻‍♂' => 'тритон: очень светлый тон кожи',
    '🧜🏼‍♂' => 'тритон: светлый тон кожи',
    '🧜🏽‍♂' => 'тритон: средний тон кожи',
    '🧜🏾‍♂' => 'тритон: темный тон кожи',
    '🧜🏿‍♂' => 'тритон: очень темный тон кожи',
    '🧜🏻‍♀' => 'женщина-русалка: очень светлый тон кожи',
    '🧜🏼‍♀' => 'женщина-русалка: светлый тон кожи',
    '🧜🏽‍♀' => 'женщина-русалка: средний тон кожи',
    '🧜🏾‍♀' => 'женщина-русалка: темный тон кожи',
    '🧜🏿‍♀' => 'женщина-русалка: очень темный тон кожи',
    '🧝🏻‍♂' => 'мужчина-эльф: очень светлый тон кожи',
    '🧝🏼‍♂' => 'мужчина-эльф: светлый тон кожи',
    '🧝🏽‍♂' => 'мужчина-эльф: средний тон кожи',
    '🧝🏾‍♂' => 'мужчина-эльф: темный тон кожи',
    '🧝🏿‍♂' => 'мужчина-эльф: очень темный тон кожи',
    '🧝🏻‍♀' => 'женщина-эльф: очень светлый тон кожи',
    '🧝🏼‍♀' => 'женщина-эльф: светлый тон кожи',
    '🧝🏽‍♀' => 'женщина-эльф: средний тон кожи',
    '🧝🏾‍♀' => 'женщина-эльф: темный тон кожи',
    '🧝🏿‍♀' => 'женщина-эльф: очень темный тон кожи',
    '💆🏻‍♂' => 'мужчине массируют лицо: очень светлый тон кожи',
    '💆🏼‍♂' => 'мужчине массируют лицо: светлый тон кожи',
    '💆🏽‍♂' => 'мужчине массируют лицо: средний тон кожи',
    '💆🏾‍♂' => 'мужчине массируют лицо: темный тон кожи',
    '💆🏿‍♂' => 'мужчине массируют лицо: очень темный тон кожи',
    '💆🏻‍♀' => 'женщине массируют лицо: очень светлый тон кожи',
    '💆🏼‍♀' => 'женщине массируют лицо: светлый тон кожи',
    '💆🏽‍♀' => 'женщине массируют лицо: средний тон кожи',
    '💆🏾‍♀' => 'женщине массируют лицо: темный тон кожи',
    '💆🏿‍♀' => 'женщине массируют лицо: очень темный тон кожи',
    '💇🏻‍♂' => 'мужчина у парикмахера: очень светлый тон кожи',
    '💇🏼‍♂' => 'мужчина у парикмахера: светлый тон кожи',
    '💇🏽‍♂' => 'мужчина у парикмахера: средний тон кожи',
    '💇🏾‍♂' => 'мужчина у парикмахера: темный тон кожи',
    '💇🏿‍♂' => 'мужчина у парикмахера: очень темный тон кожи',
    '💇🏻‍♀' => 'женщина у парикмахера: очень светлый тон кожи',
    '💇🏼‍♀' => 'женщина у парикмахера: светлый тон кожи',
    '💇🏽‍♀' => 'женщина у парикмахера: средний тон кожи',
    '💇🏾‍♀' => 'женщина у парикмахера: темный тон кожи',
    '💇🏿‍♀' => 'женщина у парикмахера: очень темный тон кожи',
    '🚶🏻‍♂' => 'мужчина идет: очень светлый тон кожи',
    '🚶🏼‍♂' => 'мужчина идет: светлый тон кожи',
    '🚶🏽‍♂' => 'мужчина идет: средний тон кожи',
    '🚶🏾‍♂' => 'мужчина идет: темный тон кожи',
    '🚶🏿‍♂' => 'мужчина идет: очень темный тон кожи',
    '🚶🏻‍♀' => 'женщина идет: очень светлый тон кожи',
    '🚶🏼‍♀' => 'женщина идет: светлый тон кожи',
    '🚶🏽‍♀' => 'женщина идет: средний тон кожи',
    '🚶🏾‍♀' => 'женщина идет: темный тон кожи',
    '🚶🏿‍♀' => 'женщина идет: очень темный тон кожи',
    '🚶🏻‍➡' => 'человек идет: очень светлый тон кожи , направленные вправо',
    '🚶🏼‍➡' => 'человек идет: светлый тон кожи , направленные вправо',
    '🚶🏽‍➡' => 'человек идет: средний тон кожи , направленные вправо',
    '🚶🏾‍➡' => 'человек идет: темный тон кожи , направленные вправо',
    '🚶🏿‍➡' => 'человек идет: очень темный тон кожи , направленные вправо',
    '🧍🏻‍♂' => 'мужчина стоит: очень светлый тон кожи',
    '🧍🏼‍♂' => 'мужчина стоит: светлый тон кожи',
    '🧍🏽‍♂' => 'мужчина стоит: средний тон кожи',
    '🧍🏾‍♂' => 'мужчина стоит: темный тон кожи',
    '🧍🏿‍♂' => 'мужчина стоит: очень темный тон кожи',
    '🧍🏻‍♀' => 'женщина стоит: очень светлый тон кожи',
    '🧍🏼‍♀' => 'женщина стоит: светлый тон кожи',
    '🧍🏽‍♀' => 'женщина стоит: средний тон кожи',
    '🧍🏾‍♀' => 'женщина стоит: темный тон кожи',
    '🧍🏿‍♀' => 'женщина стоит: очень темный тон кожи',
    '🧎🏻‍♂' => 'мужчина на коленях: очень светлый тон кожи',
    '🧎🏼‍♂' => 'мужчина на коленях: светлый тон кожи',
    '🧎🏽‍♂' => 'мужчина на коленях: средний тон кожи',
    '🧎🏾‍♂' => 'мужчина на коленях: темный тон кожи',
    '🧎🏿‍♂' => 'мужчина на коленях: очень темный тон кожи',
    '🧎🏻‍♀' => 'женщина на коленях: очень светлый тон кожи',
    '🧎🏼‍♀' => 'женщина на коленях: светлый тон кожи',
    '🧎🏽‍♀' => 'женщина на коленях: средний тон кожи',
    '🧎🏾‍♀' => 'женщина на коленях: темный тон кожи',
    '🧎🏿‍♀' => 'женщина на коленях: очень темный тон кожи',
    '🧎🏻‍➡' => 'человек на коленях: очень светлый тон кожи , направленные вправо',
    '🧎🏼‍➡' => 'человек на коленях: светлый тон кожи , направленные вправо',
    '🧎🏽‍➡' => 'человек на коленях: средний тон кожи , направленные вправо',
    '🧎🏾‍➡' => 'человек на коленях: темный тон кожи , направленные вправо',
    '🧎🏿‍➡' => 'человек на коленях: очень темный тон кожи , направленные вправо',
    '🧑🏻‍🦯' => 'человек с белой тростью: очень светлый тон кожи',
    '🧑🏼‍🦯' => 'человек с белой тростью: светлый тон кожи',
    '🧑🏽‍🦯' => 'человек с белой тростью: средний тон кожи',
    '🧑🏾‍🦯' => 'человек с белой тростью: темный тон кожи',
    '🧑🏿‍🦯' => 'человек с белой тростью: очень темный тон кожи',
    '👨🏻‍🦯' => 'мужчина с тростью для ходьбы: очень светлый тон кожи',
    '👨🏼‍🦯' => 'мужчина с тростью для ходьбы: светлый тон кожи',
    '👨🏽‍🦯' => 'мужчина с тростью для ходьбы: средний тон кожи',
    '👨🏾‍🦯' => 'мужчина с тростью для ходьбы: темный тон кожи',
    '👨🏿‍🦯' => 'мужчина с тростью для ходьбы: очень темный тон кожи',
    '👩🏻‍🦯' => 'женщина с тростью для ходьбы: очень светлый тон кожи',
    '👩🏼‍🦯' => 'женщина с тростью для ходьбы: светлый тон кожи',
    '👩🏽‍🦯' => 'женщина с тростью для ходьбы: средний тон кожи',
    '👩🏾‍🦯' => 'женщина с тростью для ходьбы: темный тон кожи',
    '👩🏿‍🦯' => 'женщина с тростью для ходьбы: очень темный тон кожи',
    '🧑🏻‍🦼' => 'человек в кресле-коляске с мотором: очень светлый тон кожи',
    '🧑🏼‍🦼' => 'человек в кресле-коляске с мотором: светлый тон кожи',
    '🧑🏽‍🦼' => 'человек в кресле-коляске с мотором: средний тон кожи',
    '🧑🏾‍🦼' => 'человек в кресле-коляске с мотором: темный тон кожи',
    '🧑🏿‍🦼' => 'человек в кресле-коляске с мотором: очень темный тон кожи',
    '👨🏻‍🦼' => 'мужчина в электрическом кресле-коляске: очень светлый тон кожи',
    '👨🏼‍🦼' => 'мужчина в электрическом кресле-коляске: светлый тон кожи',
    '👨🏽‍🦼' => 'мужчина в электрическом кресле-коляске: средний тон кожи',
    '👨🏾‍🦼' => 'мужчина в электрическом кресле-коляске: темный тон кожи',
    '👨🏿‍🦼' => 'мужчина в электрическом кресле-коляске: очень темный тон кожи',
    '👩🏻‍🦼' => 'женщина в электрическом кресле-коляске: очень светлый тон кожи',
    '👩🏼‍🦼' => 'женщина в электрическом кресле-коляске: светлый тон кожи',
    '👩🏽‍🦼' => 'женщина в электрическом кресле-коляске: средний тон кожи',
    '👩🏾‍🦼' => 'женщина в электрическом кресле-коляске: темный тон кожи',
    '👩🏿‍🦼' => 'женщина в электрическом кресле-коляске: очень темный тон кожи',
    '🧑🏻‍🦽' => 'человек в кресле-коляске с ручным приводом: очень светлый тон кожи',
    '🧑🏼‍🦽' => 'человек в кресле-коляске с ручным приводом: светлый тон кожи',
    '🧑🏽‍🦽' => 'человек в кресле-коляске с ручным приводом: средний тон кожи',
    '🧑🏾‍🦽' => 'человек в кресле-коляске с ручным приводом: темный тон кожи',
    '🧑🏿‍🦽' => 'человек в кресле-коляске с ручным приводом: очень темный тон кожи',
    '👨🏻‍🦽' => 'мужчина в ручном кресле-коляске: очень светлый тон кожи',
    '👨🏼‍🦽' => 'мужчина в ручном кресле-коляске: светлый тон кожи',
    '👨🏽‍🦽' => 'мужчина в ручном кресле-коляске: средний тон кожи',
    '👨🏾‍🦽' => 'мужчина в ручном кресле-коляске: темный тон кожи',
    '👨🏿‍🦽' => 'мужчина в ручном кресле-коляске: очень темный тон кожи',
    '👩🏻‍🦽' => 'женщина в ручном кресле-коляске: очень светлый тон кожи',
    '👩🏼‍🦽' => 'женщина в ручном кресле-коляске: светлый тон кожи',
    '👩🏽‍🦽' => 'женщина в ручном кресле-коляске: средний тон кожи',
    '👩🏾‍🦽' => 'женщина в ручном кресле-коляске: темный тон кожи',
    '👩🏿‍🦽' => 'женщина в ручном кресле-коляске: очень темный тон кожи',
    '🏃🏻‍♂' => 'мужчина бежит: очень светлый тон кожи',
    '🏃🏼‍♂' => 'мужчина бежит: светлый тон кожи',
    '🏃🏽‍♂' => 'мужчина бежит: средний тон кожи',
    '🏃🏾‍♂' => 'мужчина бежит: темный тон кожи',
    '🏃🏿‍♂' => 'мужчина бежит: очень темный тон кожи',
    '🏃🏻‍♀' => 'женщина бежит: очень светлый тон кожи',
    '🏃🏼‍♀' => 'женщина бежит: светлый тон кожи',
    '🏃🏽‍♀' => 'женщина бежит: средний тон кожи',
    '🏃🏾‍♀' => 'женщина бежит: темный тон кожи',
    '🏃🏿‍♀' => 'женщина бежит: очень темный тон кожи',
    '🏃🏻‍➡' => 'человек бежит: очень светлый тон кожи , направленные вправо',
    '🏃🏼‍➡' => 'человек бежит: светлый тон кожи , направленные вправо',
    '🏃🏽‍➡' => 'человек бежит: средний тон кожи , направленные вправо',
    '🏃🏾‍➡' => 'человек бежит: темный тон кожи , направленные вправо',
    '🏃🏿‍➡' => 'человек бежит: очень темный тон кожи , направленные вправо',
    '👯🏻‍♀' => 'женщины с ушами кролика: очень светлый тон кожи',
    '👯🏼‍♀' => 'женщины с ушами кролика: светлый тон кожи',
    '👯🏽‍♀' => 'женщины с ушами кролика: средний тон кожи',
    '👯🏾‍♀' => 'женщины с ушами кролика: темный тон кожи',
    '👯🏿‍♀' => 'женщины с ушами кролика: очень темный тон кожи',
    '👯🏻‍♂' => 'мужчины с ушами кролика: очень светлый тон кожи',
    '👯🏼‍♂' => 'мужчины с ушами кролика: светлый тон кожи',
    '👯🏽‍♂' => 'мужчины с ушами кролика: средний тон кожи',
    '👯🏾‍♂' => 'мужчины с ушами кролика: темный тон кожи',
    '👯🏿‍♂' => 'мужчины с ушами кролика: очень темный тон кожи',
    '🧖🏻‍♂' => 'мужчина в бане: очень светлый тон кожи',
    '🧖🏼‍♂' => 'мужчина в бане: светлый тон кожи',
    '🧖🏽‍♂' => 'мужчина в бане: средний тон кожи',
    '🧖🏾‍♂' => 'мужчина в бане: темный тон кожи',
    '🧖🏿‍♂' => 'мужчина в бане: очень темный тон кожи',
    '🧖🏻‍♀' => 'женщина в бане: очень светлый тон кожи',
    '🧖🏼‍♀' => 'женщина в бане: светлый тон кожи',
    '🧖🏽‍♀' => 'женщина в бане: средний тон кожи',
    '🧖🏾‍♀' => 'женщина в бане: темный тон кожи',
    '🧖🏿‍♀' => 'женщина в бане: очень темный тон кожи',
    '🧗🏻‍♂' => 'мужчина взбирается по скале: очень светлый тон кожи',
    '🧗🏼‍♂' => 'мужчина взбирается по скале: светлый тон кожи',
    '🧗🏽‍♂' => 'мужчина взбирается по скале: средний тон кожи',
    '🧗🏾‍♂' => 'мужчина взбирается по скале: темный тон кожи',
    '🧗🏿‍♂' => 'мужчина взбирается по скале: очень темный тон кожи',
    '🧗🏻‍♀' => 'женщина взбирается по скале: очень светлый тон кожи',
    '🧗🏼‍♀' => 'женщина взбирается по скале: светлый тон кожи',
    '🧗🏽‍♀' => 'женщина взбирается по скале: средний тон кожи',
    '🧗🏾‍♀' => 'женщина взбирается по скале: темный тон кожи',
    '🧗🏿‍♀' => 'женщина взбирается по скале: очень темный тон кожи',
    '🏌🏻‍♂' => 'мужчина играет в гольф: очень светлый тон кожи',
    '🏌🏼‍♂' => 'мужчина играет в гольф: светлый тон кожи',
    '🏌🏽‍♂' => 'мужчина играет в гольф: средний тон кожи',
    '🏌🏾‍♂' => 'мужчина играет в гольф: темный тон кожи',
    '🏌🏿‍♂' => 'мужчина играет в гольф: очень темный тон кожи',
    '🏌🏻‍♀' => 'женщина играет в гольф: очень светлый тон кожи',
    '🏌🏼‍♀' => 'женщина играет в гольф: светлый тон кожи',
    '🏌🏽‍♀' => 'женщина играет в гольф: средний тон кожи',
    '🏌🏾‍♀' => 'женщина играет в гольф: темный тон кожи',
    '🏌🏿‍♀' => 'женщина играет в гольф: очень темный тон кожи',
    '🏄🏻‍♂' => 'серфингист: очень светлый тон кожи',
    '🏄🏼‍♂' => 'серфингист: светлый тон кожи',
    '🏄🏽‍♂' => 'серфингист: средний тон кожи',
    '🏄🏾‍♂' => 'серфингист: темный тон кожи',
    '🏄🏿‍♂' => 'серфингист: очень темный тон кожи',
    '🏄🏻‍♀' => 'серфингистка: очень светлый тон кожи',
    '🏄🏼‍♀' => 'серфингистка: светлый тон кожи',
    '🏄🏽‍♀' => 'серфингистка: средний тон кожи',
    '🏄🏾‍♀' => 'серфингистка: темный тон кожи',
    '🏄🏿‍♀' => 'серфингистка: очень темный тон кожи',
    '🚣🏻‍♂' => 'гребец: очень светлый тон кожи',
    '🚣🏼‍♂' => 'гребец: светлый тон кожи',
    '🚣🏽‍♂' => 'гребец: средний тон кожи',
    '🚣🏾‍♂' => 'гребец: темный тон кожи',
    '🚣🏿‍♂' => 'гребец: очень темный тон кожи',
    '🚣🏻‍♀' => 'гребчиха: очень светлый тон кожи',
    '🚣🏼‍♀' => 'гребчиха: светлый тон кожи',
    '🚣🏽‍♀' => 'гребчиха: средний тон кожи',
    '🚣🏾‍♀' => 'гребчиха: темный тон кожи',
    '🚣🏿‍♀' => 'гребчиха: очень темный тон кожи',
    '🏊🏻‍♂' => 'пловец: очень светлый тон кожи',
    '🏊🏼‍♂' => 'пловец: светлый тон кожи',
    '🏊🏽‍♂' => 'пловец: средний тон кожи',
    '🏊🏾‍♂' => 'пловец: темный тон кожи',
    '🏊🏿‍♂' => 'пловец: очень темный тон кожи',
    '🏊🏻‍♀' => 'пловчиха: очень светлый тон кожи',
    '🏊🏼‍♀' => 'пловчиха: светлый тон кожи',
    '🏊🏽‍♀' => 'пловчиха: средний тон кожи',
    '🏊🏾‍♀' => 'пловчиха: темный тон кожи',
    '🏊🏿‍♀' => 'пловчиха: очень темный тон кожи',
    '⛹🏻‍♂' => 'мужчина с мячом: очень светлый тон кожи',
    '⛹🏼‍♂' => 'мужчина с мячом: светлый тон кожи',
    '⛹🏽‍♂' => 'мужчина с мячом: средний тон кожи',
    '⛹🏾‍♂' => 'мужчина с мячом: темный тон кожи',
    '⛹🏿‍♂' => 'мужчина с мячом: очень темный тон кожи',
    '⛹🏻‍♀' => 'женщина с мячом: очень светлый тон кожи',
    '⛹🏼‍♀' => 'женщина с мячом: светлый тон кожи',
    '⛹🏽‍♀' => 'женщина с мячом: средний тон кожи',
    '⛹🏾‍♀' => 'женщина с мячом: темный тон кожи',
    '⛹🏿‍♀' => 'женщина с мячом: очень темный тон кожи',
    '🏋🏻‍♂' => 'мужчина со штангой: очень светлый тон кожи',
    '🏋🏼‍♂' => 'мужчина со штангой: светлый тон кожи',
    '🏋🏽‍♂' => 'мужчина со штангой: средний тон кожи',
    '🏋🏾‍♂' => 'мужчина со штангой: темный тон кожи',
    '🏋🏿‍♂' => 'мужчина со штангой: очень темный тон кожи',
    '🏋🏻‍♀' => 'женщина со штангой: очень светлый тон кожи',
    '🏋🏼‍♀' => 'женщина со штангой: светлый тон кожи',
    '🏋🏽‍♀' => 'женщина со штангой: средний тон кожи',
    '🏋🏾‍♀' => 'женщина со штангой: темный тон кожи',
    '🏋🏿‍♀' => 'женщина со штангой: очень темный тон кожи',
    '🚴🏻‍♂' => 'мужчина на велосипеде: очень светлый тон кожи',
    '🚴🏼‍♂' => 'мужчина на велосипеде: светлый тон кожи',
    '🚴🏽‍♂' => 'мужчина на велосипеде: средний тон кожи',
    '🚴🏾‍♂' => 'мужчина на велосипеде: темный тон кожи',
    '🚴🏿‍♂' => 'мужчина на велосипеде: очень темный тон кожи',
    '🚴🏻‍♀' => 'женщина на велосипеде: очень светлый тон кожи',
    '🚴🏼‍♀' => 'женщина на велосипеде: светлый тон кожи',
    '🚴🏽‍♀' => 'женщина на велосипеде: средний тон кожи',
    '🚴🏾‍♀' => 'женщина на велосипеде: темный тон кожи',
    '🚴🏿‍♀' => 'женщина на велосипеде: очень темный тон кожи',
    '🚵🏻‍♂' => 'мужчина на горном велосипеде: очень светлый тон кожи',
    '🚵🏼‍♂' => 'мужчина на горном велосипеде: светлый тон кожи',
    '🚵🏽‍♂' => 'мужчина на горном велосипеде: средний тон кожи',
    '🚵🏾‍♂' => 'мужчина на горном велосипеде: темный тон кожи',
    '🚵🏿‍♂' => 'мужчина на горном велосипеде: очень темный тон кожи',
    '🚵🏻‍♀' => 'женщина на горном велосипеде: очень светлый тон кожи',
    '🚵🏼‍♀' => 'женщина на горном велосипеде: светлый тон кожи',
    '🚵🏽‍♀' => 'женщина на горном велосипеде: средний тон кожи',
    '🚵🏾‍♀' => 'женщина на горном велосипеде: темный тон кожи',
    '🚵🏿‍♀' => 'женщина на горном велосипеде: очень темный тон кожи',
    '🤸🏻‍♂' => 'акробат: очень светлый тон кожи',
    '🤸🏼‍♂' => 'акробат: светлый тон кожи',
    '🤸🏽‍♂' => 'акробат: средний тон кожи',
    '🤸🏾‍♂' => 'акробат: темный тон кожи',
    '🤸🏿‍♂' => 'акробат: очень темный тон кожи',
    '🤸🏻‍♀' => 'женщина-акробат: очень светлый тон кожи',
    '🤸🏼‍♀' => 'женщина-акробат: светлый тон кожи',
    '🤸🏽‍♀' => 'женщина-акробат: средний тон кожи',
    '🤸🏾‍♀' => 'женщина-акробат: темный тон кожи',
    '🤸🏿‍♀' => 'женщина-акробат: очень темный тон кожи',
    '🤼🏻‍♀' => 'женщины-борцы: очень светлый тон кожи',
    '🤼🏼‍♀' => 'женщины-борцы: светлый тон кожи',
    '🤼🏽‍♀' => 'женщины-борцы: средний тон кожи',
    '🤼🏾‍♀' => 'женщины-борцы: темный тон кожи',
    '🤼🏿‍♀' => 'женщины-борцы: очень темный тон кожи',
    '🤼🏻‍♂' => 'мужчины-борцы: очень светлый тон кожи',
    '🤼🏼‍♂' => 'мужчины-борцы: светлый тон кожи',
    '🤼🏽‍♂' => 'мужчины-борцы: средний тон кожи',
    '🤼🏾‍♂' => 'мужчины-борцы: темный тон кожи',
    '🤼🏿‍♂' => 'мужчины-борцы: очень темный тон кожи',
    '🤽🏻‍♂' => 'мужчина играет в водное поло: очень светлый тон кожи',
    '🤽🏼‍♂' => 'мужчина играет в водное поло: светлый тон кожи',
    '🤽🏽‍♂' => 'мужчина играет в водное поло: средний тон кожи',
    '🤽🏾‍♂' => 'мужчина играет в водное поло: темный тон кожи',
    '🤽🏿‍♂' => 'мужчина играет в водное поло: очень темный тон кожи',
    '🤽🏻‍♀' => 'женщина играет в водное поло: очень светлый тон кожи',
    '🤽🏼‍♀' => 'женщина играет в водное поло: светлый тон кожи',
    '🤽🏽‍♀' => 'женщина играет в водное поло: средний тон кожи',
    '🤽🏾‍♀' => 'женщина играет в водное поло: темный тон кожи',
    '🤽🏿‍♀' => 'женщина играет в водное поло: очень темный тон кожи',
    '🤾🏻‍♂' => 'гандболист: очень светлый тон кожи',
    '🤾🏼‍♂' => 'гандболист: светлый тон кожи',
    '🤾🏽‍♂' => 'гандболист: средний тон кожи',
    '🤾🏾‍♂' => 'гандболист: темный тон кожи',
    '🤾🏿‍♂' => 'гандболист: очень темный тон кожи',
    '🤾🏻‍♀' => 'гандболистка: очень светлый тон кожи',
    '🤾🏼‍♀' => 'гандболистка: светлый тон кожи',
    '🤾🏽‍♀' => 'гандболистка: средний тон кожи',
    '🤾🏾‍♀' => 'гандболистка: темный тон кожи',
    '🤾🏿‍♀' => 'гандболистка: очень темный тон кожи',
    '🤹🏻‍♂' => 'мужчина-жонглер: очень светлый тон кожи',
    '🤹🏼‍♂' => 'мужчина-жонглер: светлый тон кожи',
    '🤹🏽‍♂' => 'мужчина-жонглер: средний тон кожи',
    '🤹🏾‍♂' => 'мужчина-жонглер: темный тон кожи',
    '🤹🏿‍♂' => 'мужчина-жонглер: очень темный тон кожи',
    '🤹🏻‍♀' => 'женщина-жонглер: очень светлый тон кожи',
    '🤹🏼‍♀' => 'женщина-жонглер: светлый тон кожи',
    '🤹🏽‍♀' => 'женщина-жонглер: средний тон кожи',
    '🤹🏾‍♀' => 'женщина-жонглер: темный тон кожи',
    '🤹🏿‍♀' => 'женщина-жонглер: очень темный тон кожи',
    '🧘🏻‍♂' => 'мужчина в позе лотоса: очень светлый тон кожи',
    '🧘🏼‍♂' => 'мужчина в позе лотоса: светлый тон кожи',
    '🧘🏽‍♂' => 'мужчина в позе лотоса: средний тон кожи',
    '🧘🏾‍♂' => 'мужчина в позе лотоса: темный тон кожи',
    '🧘🏿‍♂' => 'мужчина в позе лотоса: очень темный тон кожи',
    '🧘🏻‍♀' => 'женщина в позе лотоса: очень светлый тон кожи',
    '🧘🏼‍♀' => 'женщина в позе лотоса: светлый тон кожи',
    '🧘🏽‍♀' => 'женщина в позе лотоса: средний тон кожи',
    '🧘🏾‍♀' => 'женщина в позе лотоса: темный тон кожи',
    '🧘🏿‍♀' => 'женщина в позе лотоса: очень темный тон кожи',
    '🧑‍🦰' => 'взрослый: рыжие волосы',
    '🧑‍🦱' => 'взрослый: кудрявые волосы',
    '🧑‍🦳' => 'взрослый: седые волосы',
    '🧑‍🦲' => 'взрослый: без волос',
    '👨‍🦰' => 'мужчина: рыжие волосы',
    '👨‍🦱' => 'мужчина: кудрявые волосы',
    '👨‍🦳' => 'мужчина: седые волосы',
    '👨‍🦲' => 'мужчина: без волос',
    '👩‍🦰' => 'женщина: рыжие волосы',
    '👩‍🦱' => 'женщина: кудрявые волосы',
    '👩‍🦳' => 'женщина: седые волосы',
    '👩‍🦲' => 'женщина: без волос',
    '🚶‍➡' => 'человек идет: , направленные вправо',
    '🧎‍➡' => 'человек на коленях: , направленные вправо',
    '🏃‍➡' => 'человек бежит: , направленные вправо',
    '👨‍👦' => 'семья: мужчина мальчик',
    '👨‍👧' => 'семья: мужчина девочка',
    '👩‍👦' => 'семья: женщина мальчик',
    '👩‍👧' => 'семья: женщина девочка',
    '😶‍🌫' => 'лицо в облаках',
    '😮‍💨' => 'выдыхает',
    '🙂‍↕' => 'положительно качает головой',
    '😵‍💫' => 'ошеломление',
    '❤‍🔥' => 'горящее сердце',
    '❤‍🩹' => 'заживающее сердце',
    '👁‍🗨' => 'значок свидетеля',
    '🧔‍♂' => 'бородатый мужчина',
    '👱‍♂' => 'блондин',
    '🧔‍♀' => 'бородатая женщина',
    '👱‍♀' => 'блондинка',
    '🙍‍♂' => 'нахмурившийся мужчина',
    '🙍‍♀' => 'нахмурившаяся женщина',
    '🙎‍♂' => 'обиженный мужчина',
    '🙎‍♀' => 'обиженная женщина',
    '🙅‍♂' => 'мужчина против',
    '🙅‍♀' => 'женщина против',
    '🙆‍♂' => 'мужчина за',
    '🙆‍♀' => 'женщина за',
    '💁‍♂' => 'мужчина тянет руку',
    '💁‍♀' => 'женщина тянет руку',
    '🙋‍♂' => 'мужчина с поднятой рукой',
    '🙋‍♀' => 'женщина с поднятой рукой',
    '🧏‍♂' => 'глухой мужчина',
    '🧏‍♀' => 'глухая женщина',
    '🙇‍♂' => 'мужчина кланяется',
    '🙇‍♀' => 'женщина кланяется',
    '🤦‍♂' => 'мужчина потерял дар речи',
    '🤦‍♀' => 'женщина потеряла дар речи',
    '🤷‍♂' => 'мужчина пожимает плечами',
    '🤷‍♀' => 'женщина пожимает плечами',
    '🧑‍⚕' => 'медицинский работник',
    '👨‍⚕' => 'врач',
    '👩‍⚕' => 'женщина-врач',
    '🧑‍🎓' => 'учащийся',
    '👨‍🎓' => 'студент',
    '👩‍🎓' => 'студентка',
    '🧑‍🏫' => 'педагог',
    '👨‍🏫' => 'учитель',
    '👩‍🏫' => 'учительница',
    '🧑‍⚖' => 'судья',
    '👨‍⚖' => 'мужчина-судья',
    '👩‍⚖' => 'женщина-судья',
    '🧑‍🌾' => 'фермер',
    '👨‍🌾' => 'мужчина-фермер',
    '👩‍🌾' => 'женщина-фермер',
    '🧑‍🍳' => 'повар',
    '👨‍🍳' => 'мужчина-повар',
    '👩‍🍳' => 'повариха',
    '🧑‍🔧' => 'механик',
    '👨‍🔧' => 'мужчина-механик',
    '👩‍🔧' => 'женщина-механик',
    '🧑‍🏭' => 'рабочий',
    '👨‍🏭' => 'мужчина-рабочий',
    '👩‍🏭' => 'работница',
    '🧑‍💼' => 'офисный работник',
    '👨‍💼' => 'офисный работник - мужчина',
    '👩‍💼' => 'офисная работница',
    '🧑‍🔬' => 'ученый',
    '👨‍🔬' => 'мужчина-ученый',
    '👩‍🔬' => 'ученая',
    '🧑‍💻' => 'инженер',
    '👨‍💻' => 'мужчина-инженер',
    '👩‍💻' => 'женщина-инженер',
    '🧑‍🎤' => 'певец',
    '👨‍🎤' => 'мужчина-певец',
    '👩‍🎤' => 'певица',
    '🧑‍🎨' => 'художник',
    '👨‍🎨' => 'мужчина-художник',
    '👩‍🎨' => 'художница',
    '🧑‍✈' => 'пилот',
    '👨‍✈' => 'мужчина-пилот',
    '👩‍✈' => 'женщина-пилот',
    '🧑‍🚀' => 'космонавт',
    '👨‍🚀' => 'мужчина-космонавт',
    '👩‍🚀' => 'женщина-космонавт',
    '🧑‍🚒' => 'пожарный',
    '👨‍🚒' => 'мужчина-пожарный',
    '👩‍🚒' => 'женщина-пожарный',
    '👮‍♂' => 'мужчина-полицейский',
    '👮‍♀' => 'женщина-полицейский',
    '🕵‍♂' => 'мужчина-детектив',
    '🕵‍♀' => 'женщина-детектив',
    '💂‍♂' => 'мужчина-гвардеец',
    '💂‍♀' => 'женщина-гвардеец',
    '👷‍♂' => 'мужчина-строитель',
    '👷‍♀' => 'женщина-строитель',
    '👳‍♂' => 'мужчина в тюрбане',
    '👳‍♀' => 'женщина в тюрбане',
    '🤵‍♂' => 'мужчина в смокинге',
    '🤵‍♀' => 'женщина в смокинге',
    '👰‍♂' => 'мужчина в фате',
    '👰‍♀' => 'женщина в фате',
    '👩‍🍼' => 'кормящая женщина',
    '👨‍🍼' => 'кормящий мужчина',
    '🧑‍🍼' => 'кормящий человек',
    '🧑‍🎄' => 'Санта',
    '🦸‍♂' => 'мужчина-супергерой',
    '🦸‍♀' => 'женщина-супергерой',
    '🦹‍♂' => 'мужчина-суперзлодей',
    '🦹‍♀' => 'женщина-суперзлодей',
    '🧙‍♂' => 'волшебник',
    '🧙‍♀' => 'волшебница',
    '🧚‍♂' => 'мужчина-фея',
    '🧚‍♀' => 'женщина-фея',
    '🧛‍♂' => 'мужчина-вампир',
    '🧛‍♀' => 'женщина-вампир',
    '🧜‍♂' => 'тритон',
    '🧜‍♀' => 'женщина-русалка',
    '🧝‍♂' => 'мужчина-эльф',
    '🧝‍♀' => 'женщина-эльф',
    '🧞‍♂' => 'мужчина-джинн',
    '🧞‍♀' => 'женщина-джинн',
    '🧟‍♂' => 'мужчина-зомби',
    '🧟‍♀' => 'женщина-зомби',
    '💆‍♂' => 'мужчине массируют лицо',
    '💆‍♀' => 'женщине массируют лицо',
    '💇‍♂' => 'мужчина у парикмахера',
    '💇‍♀' => 'женщина у парикмахера',
    '🚶‍♂' => 'мужчина идет',
    '🚶‍♀' => 'женщина идет',
    '🧍‍♂' => 'мужчина стоит',
    '🧍‍♀' => 'женщина стоит',
    '🧎‍♂' => 'мужчина на коленях',
    '🧎‍♀' => 'женщина на коленях',
    '🧑‍🦯' => 'человек с белой тростью',
    '👨‍🦯' => 'мужчина с тростью для ходьбы',
    '👩‍🦯' => 'женщина с тростью для ходьбы',
    '🧑‍🦼' => 'человек в кресле-коляске с мотором',
    '👨‍🦼' => 'мужчина в электрическом кресле-коляске',
    '👩‍🦼' => 'женщина в электрическом кресле-коляске',
    '🧑‍🦽' => 'человек в кресле-коляске с ручным приводом',
    '👨‍🦽' => 'мужчина в ручном кресле-коляске',
    '👩‍🦽' => 'женщина в ручном кресле-коляске',
    '🏃‍♂' => 'мужчина бежит',
    '🏃‍♀' => 'женщина бежит',
    '🧑‍🩰' => 'артист балета',
    '👯‍♂' => 'мужчины с ушами кролика',
    '👯‍♀' => 'женщины с ушами кролика',
    '🧖‍♂' => 'мужчина в бане',
    '🧖‍♀' => 'женщина в бане',
    '🧗‍♂' => 'мужчина взбирается по скале',
    '🧗‍♀' => 'женщина взбирается по скале',
    '🏌‍♂' => 'мужчина играет в гольф',
    '🏌‍♀' => 'женщина играет в гольф',
    '🏄‍♂' => 'серфингист',
    '🏄‍♀' => 'серфингистка',
    '🚣‍♂' => 'гребец',
    '🚣‍♀' => 'гребчиха',
    '🏊‍♂' => 'пловец',
    '🏊‍♀' => 'пловчиха',
    '⛹‍♂' => 'мужчина с мячом',
    '⛹‍♀' => 'женщина с мячом',
    '🏋‍♂' => 'мужчина со штангой',
    '🏋‍♀' => 'женщина со штангой',
    '🚴‍♂' => 'мужчина на велосипеде',
    '🚴‍♀' => 'женщина на велосипеде',
    '🚵‍♂' => 'мужчина на горном велосипеде',
    '🚵‍♀' => 'женщина на горном велосипеде',
    '🤸‍♂' => 'акробат',
    '🤸‍♀' => 'женщина-акробат',
    '🤼‍♂' => 'мужчины-борцы',
    '🤼‍♀' => 'женщины-борцы',
    '🤽‍♂' => 'мужчина играет в водное поло',
    '🤽‍♀' => 'женщина играет в водное поло',
    '🤾‍♂' => 'гандболист',
    '🤾‍♀' => 'гандболистка',
    '🤹‍♂' => 'мужчина-жонглер',
    '🤹‍♀' => 'женщина-жонглер',
    '🧘‍♂' => 'мужчина в позе лотоса',
    '🧘‍♀' => 'женщина в позе лотоса',
    '🧑‍🧒' => 'семья: взрослый и ребенок',
    '🐕‍🦺' => 'служебная собака',
    '🐈‍⬛' => 'черная кошка',
    '🐻‍❄' => 'морда белого медведя',
    '🐦‍⬛' => 'черная птица',
    '🐦‍🔥' => 'феникс',
    '🍋‍🟩' => 'лайм',
    '🍄‍🟫' => 'бурый гриб',
    '⛓‍💥' => 'разорванная цепь',
    '🏳‍🌈' => 'радужный флаг',
    '🏳‍⚧' => 'флаг трансгендерного сообщества',
    '🏴‍☠' => 'пиратский флаг',
    '👋🏻' => 'машет рукой: очень светлый тон кожи',
    '👋🏼' => 'машет рукой: светлый тон кожи',
    '👋🏽' => 'машет рукой: средний тон кожи',
    '👋🏾' => 'машет рукой: темный тон кожи',
    '👋🏿' => 'машет рукой: очень темный тон кожи',
    '🤚🏻' => 'поднятая рука: очень светлый тон кожи',
    '🤚🏼' => 'поднятая рука: светлый тон кожи',
    '🤚🏽' => 'поднятая рука: средний тон кожи',
    '🤚🏾' => 'поднятая рука: темный тон кожи',
    '🤚🏿' => 'поднятая рука: очень темный тон кожи',
    '🖐🏻' => 'раскрытая ладонь: очень светлый тон кожи',
    '🖐🏼' => 'раскрытая ладонь: светлый тон кожи',
    '🖐🏽' => 'раскрытая ладонь: средний тон кожи',
    '🖐🏾' => 'раскрытая ладонь: темный тон кожи',
    '🖐🏿' => 'раскрытая ладонь: очень темный тон кожи',
    '✋🏻' => 'поднятая ладонь: очень светлый тон кожи',
    '✋🏼' => 'поднятая ладонь: светлый тон кожи',
    '✋🏽' => 'поднятая ладонь: средний тон кожи',
    '✋🏾' => 'поднятая ладонь: темный тон кожи',
    '✋🏿' => 'поднятая ладонь: очень темный тон кожи',
    '🖖🏻' => 'вулканский салют: очень светлый тон кожи',
    '🖖🏼' => 'вулканский салют: светлый тон кожи',
    '🖖🏽' => 'вулканский салют: средний тон кожи',
    '🖖🏾' => 'вулканский салют: темный тон кожи',
    '🖖🏿' => 'вулканский салют: очень темный тон кожи',
    '🫱🏻' => 'рука вправо: очень светлый тон кожи',
    '🫱🏼' => 'рука вправо: светлый тон кожи',
    '🫱🏽' => 'рука вправо: средний тон кожи',
    '🫱🏾' => 'рука вправо: темный тон кожи',
    '🫱🏿' => 'рука вправо: очень темный тон кожи',
    '🫲🏻' => 'рука влево: очень светлый тон кожи',
    '🫲🏼' => 'рука влево: светлый тон кожи',
    '🫲🏽' => 'рука влево: средний тон кожи',
    '🫲🏾' => 'рука влево: темный тон кожи',
    '🫲🏿' => 'рука влево: очень темный тон кожи',
    '🫳🏻' => 'рука ладонью вниз: очень светлый тон кожи',
    '🫳🏼' => 'рука ладонью вниз: светлый тон кожи',
    '🫳🏽' => 'рука ладонью вниз: средний тон кожи',
    '🫳🏾' => 'рука ладонью вниз: темный тон кожи',
    '🫳🏿' => 'рука ладонью вниз: очень темный тон кожи',
    '🫴🏻' => 'рука ладонью вверх: очень светлый тон кожи',
    '🫴🏼' => 'рука ладонью вверх: светлый тон кожи',
    '🫴🏽' => 'рука ладонью вверх: средний тон кожи',
    '🫴🏾' => 'рука ладонью вверх: темный тон кожи',
    '🫴🏿' => 'рука ладонью вверх: очень темный тон кожи',
    '🫷🏻' => 'рука ладонью влево: очень светлый тон кожи',
    '🫷🏼' => 'рука ладонью влево: светлый тон кожи',
    '🫷🏽' => 'рука ладонью влево: средний тон кожи',
    '🫷🏾' => 'рука ладонью влево: темный тон кожи',
    '🫷🏿' => 'рука ладонью влево: очень темный тон кожи',
    '🫸🏻' => 'рука ладонью вправо: очень светлый тон кожи',
    '🫸🏼' => 'рука ладонью вправо: светлый тон кожи',
    '🫸🏽' => 'рука ладонью вправо: средний тон кожи',
    '🫸🏾' => 'рука ладонью вправо: темный тон кожи',
    '🫸🏿' => 'рука ладонью вправо: очень темный тон кожи',
    '👌🏻' => 'жест «все хорошо»: очень светлый тон кожи',
    '👌🏼' => 'жест «все хорошо»: светлый тон кожи',
    '👌🏽' => 'жест «все хорошо»: средний тон кожи',
    '👌🏾' => 'жест «все хорошо»: темный тон кожи',
    '👌🏿' => 'жест «все хорошо»: очень темный тон кожи',
    '🤌🏻' => 'щепоть: очень светлый тон кожи',
    '🤌🏼' => 'щепоть: светлый тон кожи',
    '🤌🏽' => 'щепоть: средний тон кожи',
    '🤌🏾' => 'щепоть: темный тон кожи',
    '🤌🏿' => 'щепоть: очень темный тон кожи',
    '🤏🏻' => 'жест «мало»: очень светлый тон кожи',
    '🤏🏼' => 'жест «мало»: светлый тон кожи',
    '🤏🏽' => 'жест «мало»: средний тон кожи',
    '🤏🏾' => 'жест «мало»: темный тон кожи',
    '🤏🏿' => 'жест «мало»: очень темный тон кожи',
    '✌🏻' => 'жест V: очень светлый тон кожи',
    '✌🏼' => 'жест V: светлый тон кожи',
    '✌🏽' => 'жест V: средний тон кожи',
    '✌🏾' => 'жест V: темный тон кожи',
    '✌🏿' => 'жест V: очень темный тон кожи',
    '🤞🏻' => 'скрещенные пальцы: очень светлый тон кожи',
    '🤞🏼' => 'скрещенные пальцы: светлый тон кожи',
    '🤞🏽' => 'скрещенные пальцы: средний тон кожи',
    '🤞🏾' => 'скрещенные пальцы: темный тон кожи',
    '🤞🏿' => 'скрещенные пальцы: очень темный тон кожи',
    '🫰🏻' => 'жест «деньги»: очень светлый тон кожи',
    '🫰🏼' => 'жест «деньги»: светлый тон кожи',
    '🫰🏽' => 'жест «деньги»: средний тон кожи',
    '🫰🏾' => 'жест «деньги»: темный тон кожи',
    '🫰🏿' => 'жест «деньги»: очень темный тон кожи',
    '🤟🏻' => 'я-тебя-люблю: очень светлый тон кожи',
    '🤟🏼' => 'я-тебя-люблю: светлый тон кожи',
    '🤟🏽' => 'я-тебя-люблю: средний тон кожи',
    '🤟🏾' => 'я-тебя-люблю: темный тон кожи',
    '🤟🏿' => 'я-тебя-люблю: очень темный тон кожи',
    '🤘🏻' => 'рокерский жест: очень светлый тон кожи',
    '🤘🏼' => 'рокерский жест: светлый тон кожи',
    '🤘🏽' => 'рокерский жест: средний тон кожи',
    '🤘🏾' => 'рокерский жест: темный тон кожи',
    '🤘🏿' => 'рокерский жест: очень темный тон кожи',
    '🤙🏻' => 'жест «позвони мне»: очень светлый тон кожи',
    '🤙🏼' => 'жест «позвони мне»: светлый тон кожи',
    '🤙🏽' => 'жест «позвони мне»: средний тон кожи',
    '🤙🏾' => 'жест «позвони мне»: темный тон кожи',
    '🤙🏿' => 'жест «позвони мне»: очень темный тон кожи',
    '👈🏻' => 'указывающий налево палец: очень светлый тон кожи',
    '👈🏼' => 'указывающий налево палец: светлый тон кожи',
    '👈🏽' => 'указывающий налево палец: средний тон кожи',
    '👈🏾' => 'указывающий налево палец: темный тон кожи',
    '👈🏿' => 'указывающий налево палец: очень темный тон кожи',
    '👉🏻' => 'указывающий направо палец: очень светлый тон кожи',
    '👉🏼' => 'указывающий направо палец: светлый тон кожи',
    '👉🏽' => 'указывающий направо палец: средний тон кожи',
    '👉🏾' => 'указывающий направо палец: темный тон кожи',
    '👉🏿' => 'указывающий направо палец: очень темный тон кожи',
    '👆🏻' => 'указывающий вверх палец: очень светлый тон кожи',
    '👆🏼' => 'указывающий вверх палец: светлый тон кожи',
    '👆🏽' => 'указывающий вверх палец: средний тон кожи',
    '👆🏾' => 'указывающий вверх палец: темный тон кожи',
    '👆🏿' => 'указывающий вверх палец: очень темный тон кожи',
    '🖕🏻' => 'средний палец: очень светлый тон кожи',
    '🖕🏼' => 'средний палец: светлый тон кожи',
    '🖕🏽' => 'средний палец: средний тон кожи',
    '🖕🏾' => 'средний палец: темный тон кожи',
    '🖕🏿' => 'средний палец: очень темный тон кожи',
    '👇🏻' => 'указывающий вниз палец: очень светлый тон кожи',
    '👇🏼' => 'указывающий вниз палец: светлый тон кожи',
    '👇🏽' => 'указывающий вниз палец: средний тон кожи',
    '👇🏾' => 'указывающий вниз палец: темный тон кожи',
    '👇🏿' => 'указывающий вниз палец: очень темный тон кожи',
    '☝🏻' => 'указательный палец вверх: очень светлый тон кожи',
    '☝🏼' => 'указательный палец вверх: светлый тон кожи',
    '☝🏽' => 'указательный палец вверх: средний тон кожи',
    '☝🏾' => 'указательный палец вверх: темный тон кожи',
    '☝🏿' => 'указательный палец вверх: очень темный тон кожи',
    '🫵🏻' => 'указательный палец на себя: очень светлый тон кожи',
    '🫵🏼' => 'указательный палец на себя: светлый тон кожи',
    '🫵🏽' => 'указательный палец на себя: средний тон кожи',
    '🫵🏾' => 'указательный палец на себя: темный тон кожи',
    '🫵🏿' => 'указательный палец на себя: очень темный тон кожи',
    '👍🏻' => 'большой палец вверх: очень светлый тон кожи',
    '👍🏼' => 'большой палец вверх: светлый тон кожи',
    '👍🏽' => 'большой палец вверх: средний тон кожи',
    '👍🏾' => 'большой палец вверх: темный тон кожи',
    '👍🏿' => 'большой палец вверх: очень темный тон кожи',
    '👎🏻' => 'большой палец вниз: очень светлый тон кожи',
    '👎🏼' => 'большой палец вниз: светлый тон кожи',
    '👎🏽' => 'большой палец вниз: средний тон кожи',
    '👎🏾' => 'большой палец вниз: темный тон кожи',
    '👎🏿' => 'большой палец вниз: очень темный тон кожи',
    '✊🏻' => 'поднятый кулак: очень светлый тон кожи',
    '✊🏼' => 'поднятый кулак: светлый тон кожи',
    '✊🏽' => 'поднятый кулак: средний тон кожи',
    '✊🏾' => 'поднятый кулак: темный тон кожи',
    '✊🏿' => 'поднятый кулак: очень темный тон кожи',
    '👊🏻' => 'кулак: очень светлый тон кожи',
    '👊🏼' => 'кулак: светлый тон кожи',
    '👊🏽' => 'кулак: средний тон кожи',
    '👊🏾' => 'кулак: темный тон кожи',
    '👊🏿' => 'кулак: очень темный тон кожи',
    '🤛🏻' => 'кулак влево: очень светлый тон кожи',
    '🤛🏼' => 'кулак влево: светлый тон кожи',
    '🤛🏽' => 'кулак влево: средний тон кожи',
    '🤛🏾' => 'кулак влево: темный тон кожи',
    '🤛🏿' => 'кулак влево: очень темный тон кожи',
    '🤜🏻' => 'кулак вправо: очень светлый тон кожи',
    '🤜🏼' => 'кулак вправо: светлый тон кожи',
    '🤜🏽' => 'кулак вправо: средний тон кожи',
    '🤜🏾' => 'кулак вправо: темный тон кожи',
    '🤜🏿' => 'кулак вправо: очень темный тон кожи',
    '👏🏻' => 'аплодисменты: очень светлый тон кожи',
    '👏🏼' => 'аплодисменты: светлый тон кожи',
    '👏🏽' => 'аплодисменты: средний тон кожи',
    '👏🏾' => 'аплодисменты: темный тон кожи',
    '👏🏿' => 'аплодисменты: очень темный тон кожи',
    '🙌🏻' => 'ура: очень светлый тон кожи',
    '🙌🏼' => 'ура: светлый тон кожи',
    '🙌🏽' => 'ура: средний тон кожи',
    '🙌🏾' => 'ура: темный тон кожи',
    '🙌🏿' => 'ура: очень темный тон кожи',
    '🫶🏻' => 'жест «сердце»: очень светлый тон кожи',
    '🫶🏼' => 'жест «сердце»: светлый тон кожи',
    '🫶🏽' => 'жест «сердце»: средний тон кожи',
    '🫶🏾' => 'жест «сердце»: темный тон кожи',
    '🫶🏿' => 'жест «сердце»: очень темный тон кожи',
    '👐🏻' => 'ладони в стороны: очень светлый тон кожи',
    '👐🏼' => 'ладони в стороны: светлый тон кожи',
    '👐🏽' => 'ладони в стороны: средний тон кожи',
    '👐🏾' => 'ладони в стороны: темный тон кожи',
    '👐🏿' => 'ладони в стороны: очень темный тон кожи',
    '🤲🏻' => 'ладони лодочкой: очень светлый тон кожи',
    '🤲🏼' => 'ладони лодочкой: светлый тон кожи',
    '🤲🏽' => 'ладони лодочкой: средний тон кожи',
    '🤲🏾' => 'ладони лодочкой: темный тон кожи',
    '🤲🏿' => 'ладони лодочкой: очень темный тон кожи',
    '🤝🏻' => 'рукопожатие: очень светлый тон кожи',
    '🤝🏼' => 'рукопожатие: светлый тон кожи',
    '🤝🏽' => 'рукопожатие: средний тон кожи',
    '🤝🏾' => 'рукопожатие: темный тон кожи',
    '🤝🏿' => 'рукопожатие: очень темный тон кожи',
    '🙏🏻' => 'сложенные руки: очень светлый тон кожи',
    '🙏🏼' => 'сложенные руки: светлый тон кожи',
    '🙏🏽' => 'сложенные руки: средний тон кожи',
    '🙏🏾' => 'сложенные руки: темный тон кожи',
    '🙏🏿' => 'сложенные руки: очень темный тон кожи',
    '✍🏻' => 'пишущая рука: очень светлый тон кожи',
    '✍🏼' => 'пишущая рука: светлый тон кожи',
    '✍🏽' => 'пишущая рука: средний тон кожи',
    '✍🏾' => 'пишущая рука: темный тон кожи',
    '✍🏿' => 'пишущая рука: очень темный тон кожи',
    '💅🏻' => 'маникюр: очень светлый тон кожи',
    '💅🏼' => 'маникюр: светлый тон кожи',
    '💅🏽' => 'маникюр: средний тон кожи',
    '💅🏾' => 'маникюр: темный тон кожи',
    '💅🏿' => 'маникюр: очень темный тон кожи',
    '🤳🏻' => 'селфи: очень светлый тон кожи',
    '🤳🏼' => 'селфи: светлый тон кожи',
    '🤳🏽' => 'селфи: средний тон кожи',
    '🤳🏾' => 'селфи: темный тон кожи',
    '🤳🏿' => 'селфи: очень темный тон кожи',
    '💪🏻' => 'бицепс: очень светлый тон кожи',
    '💪🏼' => 'бицепс: светлый тон кожи',
    '💪🏽' => 'бицепс: средний тон кожи',
    '💪🏾' => 'бицепс: темный тон кожи',
    '💪🏿' => 'бицепс: очень темный тон кожи',
    '🦵🏻' => 'нога: очень светлый тон кожи',
    '🦵🏼' => 'нога: светлый тон кожи',
    '🦵🏽' => 'нога: средний тон кожи',
    '🦵🏾' => 'нога: темный тон кожи',
    '🦵🏿' => 'нога: очень темный тон кожи',
    '🦶🏻' => 'щиколотка: очень светлый тон кожи',
    '🦶🏼' => 'щиколотка: светлый тон кожи',
    '🦶🏽' => 'щиколотка: средний тон кожи',
    '🦶🏾' => 'щиколотка: темный тон кожи',
    '🦶🏿' => 'щиколотка: очень темный тон кожи',
    '👂🏻' => 'ухо: очень светлый тон кожи',
    '👂🏼' => 'ухо: светлый тон кожи',
    '👂🏽' => 'ухо: средний тон кожи',
    '👂🏾' => 'ухо: темный тон кожи',
    '👂🏿' => 'ухо: очень темный тон кожи',
    '🦻🏻' => 'ухо со слуховым аппаратом: очень светлый тон кожи',
    '🦻🏼' => 'ухо со слуховым аппаратом: светлый тон кожи',
    '🦻🏽' => 'ухо со слуховым аппаратом: средний тон кожи',
    '🦻🏾' => 'ухо со слуховым аппаратом: темный тон кожи',
    '🦻🏿' => 'ухо со слуховым аппаратом: очень темный тон кожи',
    '👃🏻' => 'нос: очень светлый тон кожи',
    '👃🏼' => 'нос: светлый тон кожи',
    '👃🏽' => 'нос: средний тон кожи',
    '👃🏾' => 'нос: темный тон кожи',
    '👃🏿' => 'нос: очень темный тон кожи',
    '👶🏻' => 'младенец: очень светлый тон кожи',
    '👶🏼' => 'младенец: светлый тон кожи',
    '👶🏽' => 'младенец: средний тон кожи',
    '👶🏾' => 'младенец: темный тон кожи',
    '👶🏿' => 'младенец: очень темный тон кожи',
    '🧒🏻' => 'ребенок: очень светлый тон кожи',
    '🧒🏼' => 'ребенок: светлый тон кожи',
    '🧒🏽' => 'ребенок: средний тон кожи',
    '🧒🏾' => 'ребенок: темный тон кожи',
    '🧒🏿' => 'ребенок: очень темный тон кожи',
    '👦🏻' => 'мальчик: очень светлый тон кожи',
    '👦🏼' => 'мальчик: светлый тон кожи',
    '👦🏽' => 'мальчик: средний тон кожи',
    '👦🏾' => 'мальчик: темный тон кожи',
    '👦🏿' => 'мальчик: очень темный тон кожи',
    '👧🏻' => 'девочка: очень светлый тон кожи',
    '👧🏼' => 'девочка: светлый тон кожи',
    '👧🏽' => 'девочка: средний тон кожи',
    '👧🏾' => 'девочка: темный тон кожи',
    '👧🏿' => 'девочка: очень темный тон кожи',
    '🧑🏻' => 'взрослый: очень светлый тон кожи',
    '🧑🏼' => 'взрослый: светлый тон кожи',
    '🧑🏽' => 'взрослый: средний тон кожи',
    '🧑🏾' => 'взрослый: темный тон кожи',
    '🧑🏿' => 'взрослый: очень темный тон кожи',
    '👱🏻' => 'человек со светлыми волосами: очень светлый тон кожи',
    '👱🏼' => 'человек со светлыми волосами: светлый тон кожи',
    '👱🏽' => 'человек со светлыми волосами: средний тон кожи',
    '👱🏾' => 'человек со светлыми волосами: темный тон кожи',
    '👱🏿' => 'человек со светлыми волосами: очень темный тон кожи',
    '👨🏻' => 'мужчина: очень светлый тон кожи',
    '👨🏼' => 'мужчина: светлый тон кожи',
    '👨🏽' => 'мужчина: средний тон кожи',
    '👨🏾' => 'мужчина: темный тон кожи',
    '👨🏿' => 'мужчина: очень темный тон кожи',
    '🧔🏻' => 'бородатый человек: очень светлый тон кожи',
    '🧔🏼' => 'бородатый человек: светлый тон кожи',
    '🧔🏽' => 'бородатый человек: средний тон кожи',
    '🧔🏾' => 'бородатый человек: темный тон кожи',
    '🧔🏿' => 'бородатый человек: очень темный тон кожи',
    '👩🏻' => 'женщина: очень светлый тон кожи',
    '👩🏼' => 'женщина: светлый тон кожи',
    '👩🏽' => 'женщина: средний тон кожи',
    '👩🏾' => 'женщина: темный тон кожи',
    '👩🏿' => 'женщина: очень темный тон кожи',
    '🧓🏻' => 'пожилой человек: очень светлый тон кожи',
    '🧓🏼' => 'пожилой человек: светлый тон кожи',
    '🧓🏽' => 'пожилой человек: средний тон кожи',
    '🧓🏾' => 'пожилой человек: темный тон кожи',
    '🧓🏿' => 'пожилой человек: очень темный тон кожи',
    '👴🏻' => 'пожилой мужчина: очень светлый тон кожи',
    '👴🏼' => 'пожилой мужчина: светлый тон кожи',
    '👴🏽' => 'пожилой мужчина: средний тон кожи',
    '👴🏾' => 'пожилой мужчина: темный тон кожи',
    '👴🏿' => 'пожилой мужчина: очень темный тон кожи',
    '👵🏻' => 'пожилая женщина: очень светлый тон кожи',
    '👵🏼' => 'пожилая женщина: светлый тон кожи',
    '👵🏽' => 'пожилая женщина: средний тон кожи',
    '👵🏾' => 'пожилая женщина: темный тон кожи',
    '👵🏿' => 'пожилая женщина: очень темный тон кожи',
    '🙍🏻' => 'нахмурившийся человек: очень светлый тон кожи',
    '🙍🏼' => 'нахмурившийся человек: светлый тон кожи',
    '🙍🏽' => 'нахмурившийся человек: средний тон кожи',
    '🙍🏾' => 'нахмурившийся человек: темный тон кожи',
    '🙍🏿' => 'нахмурившийся человек: очень темный тон кожи',
    '🙎🏻' => 'обиженный человек: очень светлый тон кожи',
    '🙎🏼' => 'обиженный человек: светлый тон кожи',
    '🙎🏽' => 'обиженный человек: средний тон кожи',
    '🙎🏾' => 'обиженный человек: темный тон кожи',
    '🙎🏿' => 'обиженный человек: очень темный тон кожи',
    '🙅🏻' => 'человек против: очень светлый тон кожи',
    '🙅🏼' => 'человек против: светлый тон кожи',
    '🙅🏽' => 'человек против: средний тон кожи',
    '🙅🏾' => 'человек против: темный тон кожи',
    '🙅🏿' => 'человек против: очень темный тон кожи',
    '🙆🏻' => 'человек за: очень светлый тон кожи',
    '🙆🏼' => 'человек за: светлый тон кожи',
    '🙆🏽' => 'человек за: средний тон кожи',
    '🙆🏾' => 'человек за: темный тон кожи',
    '🙆🏿' => 'человек за: очень темный тон кожи',
    '💁🏻' => 'человек тянет руку: очень светлый тон кожи',
    '💁🏼' => 'человек тянет руку: светлый тон кожи',
    '💁🏽' => 'человек тянет руку: средний тон кожи',
    '💁🏾' => 'человек тянет руку: темный тон кожи',
    '💁🏿' => 'человек тянет руку: очень темный тон кожи',
    '🙋🏻' => 'человек с поднятой рукой: очень светлый тон кожи',
    '🙋🏼' => 'человек с поднятой рукой: светлый тон кожи',
    '🙋🏽' => 'человек с поднятой рукой: средний тон кожи',
    '🙋🏾' => 'человек с поднятой рукой: темный тон кожи',
    '🙋🏿' => 'человек с поднятой рукой: очень темный тон кожи',
    '🧏🏻' => 'глухой человек: очень светлый тон кожи',
    '🧏🏼' => 'глухой человек: светлый тон кожи',
    '🧏🏽' => 'глухой человек: средний тон кожи',
    '🧏🏾' => 'глухой человек: темный тон кожи',
    '🧏🏿' => 'глухой человек: очень темный тон кожи',
    '🙇🏻' => 'человек кланяется: очень светлый тон кожи',
    '🙇🏼' => 'человек кланяется: светлый тон кожи',
    '🙇🏽' => 'человек кланяется: средний тон кожи',
    '🙇🏾' => 'человек кланяется: темный тон кожи',
    '🙇🏿' => 'человек кланяется: очень темный тон кожи',
    '🤦🏻' => 'человек потерял дар речи: очень светлый тон кожи',
    '🤦🏼' => 'человек потерял дар речи: светлый тон кожи',
    '🤦🏽' => 'человек потерял дар речи: средний тон кожи',
    '🤦🏾' => 'человек потерял дар речи: темный тон кожи',
    '🤦🏿' => 'человек потерял дар речи: очень темный тон кожи',
    '🤷🏻' => 'человек пожимает плечами: очень светлый тон кожи',
    '🤷🏼' => 'человек пожимает плечами: светлый тон кожи',
    '🤷🏽' => 'человек пожимает плечами: средний тон кожи',
    '🤷🏾' => 'человек пожимает плечами: темный тон кожи',
    '🤷🏿' => 'человек пожимает плечами: очень темный тон кожи',
    '👮🏻' => 'полицейский: очень светлый тон кожи',
    '👮🏼' => 'полицейский: светлый тон кожи',
    '👮🏽' => 'полицейский: средний тон кожи',
    '👮🏾' => 'полицейский: темный тон кожи',
    '👮🏿' => 'полицейский: очень темный тон кожи',
    '🕵🏻' => 'детектив: очень светлый тон кожи',
    '🕵🏼' => 'детектив: светлый тон кожи',
    '🕵🏽' => 'детектив: средний тон кожи',
    '🕵🏾' => 'детектив: темный тон кожи',
    '🕵🏿' => 'детектив: очень темный тон кожи',
    '💂🏻' => 'гвардеец: очень светлый тон кожи',
    '💂🏼' => 'гвардеец: светлый тон кожи',
    '💂🏽' => 'гвардеец: средний тон кожи',
    '💂🏾' => 'гвардеец: темный тон кожи',
    '💂🏿' => 'гвардеец: очень темный тон кожи',
    '🥷🏻' => 'ниндзя: очень светлый тон кожи',
    '🥷🏼' => 'ниндзя: светлый тон кожи',
    '🥷🏽' => 'ниндзя: средний тон кожи',
    '🥷🏾' => 'ниндзя: темный тон кожи',
    '🥷🏿' => 'ниндзя: очень темный тон кожи',
    '👷🏻' => 'строитель: очень светлый тон кожи',
    '👷🏼' => 'строитель: светлый тон кожи',
    '👷🏽' => 'строитель: средний тон кожи',
    '👷🏾' => 'строитель: темный тон кожи',
    '👷🏿' => 'строитель: очень темный тон кожи',
    '🫅🏻' => 'человек с короной: очень светлый тон кожи',
    '🫅🏼' => 'человек с короной: светлый тон кожи',
    '🫅🏽' => 'человек с короной: средний тон кожи',
    '🫅🏾' => 'человек с короной: темный тон кожи',
    '🫅🏿' => 'человек с короной: очень темный тон кожи',
    '🤴🏻' => 'принц: очень светлый тон кожи',
    '🤴🏼' => 'принц: светлый тон кожи',
    '🤴🏽' => 'принц: средний тон кожи',
    '🤴🏾' => 'принц: темный тон кожи',
    '🤴🏿' => 'принц: очень темный тон кожи',
    '👸🏻' => 'принцесса: очень светлый тон кожи',
    '👸🏼' => 'принцесса: светлый тон кожи',
    '👸🏽' => 'принцесса: средний тон кожи',
    '👸🏾' => 'принцесса: темный тон кожи',
    '👸🏿' => 'принцесса: очень темный тон кожи',
    '👳🏻' => 'человек в тюрбане: очень светлый тон кожи',
    '👳🏼' => 'человек в тюрбане: светлый тон кожи',
    '👳🏽' => 'человек в тюрбане: средний тон кожи',
    '👳🏾' => 'человек в тюрбане: темный тон кожи',
    '👳🏿' => 'человек в тюрбане: очень темный тон кожи',
    '👲🏻' => 'мужчина в китайской шапке: очень светлый тон кожи',
    '👲🏼' => 'мужчина в китайской шапке: светлый тон кожи',
    '👲🏽' => 'мужчина в китайской шапке: средний тон кожи',
    '👲🏾' => 'мужчина в китайской шапке: темный тон кожи',
    '👲🏿' => 'мужчина в китайской шапке: очень темный тон кожи',
    '🧕🏻' => 'женщина в платке: очень светлый тон кожи',
    '🧕🏼' => 'женщина в платке: светлый тон кожи',
    '🧕🏽' => 'женщина в платке: средний тон кожи',
    '🧕🏾' => 'женщина в платке: темный тон кожи',
    '🧕🏿' => 'женщина в платке: очень темный тон кожи',
    '🤵🏻' => 'жених: очень светлый тон кожи',
    '🤵🏼' => 'жених: светлый тон кожи',
    '🤵🏽' => 'жених: средний тон кожи',
    '🤵🏾' => 'жених: темный тон кожи',
    '🤵🏿' => 'жених: очень темный тон кожи',
    '👰🏻' => 'невеста: очень светлый тон кожи',
    '👰🏼' => 'невеста: светлый тон кожи',
    '👰🏽' => 'невеста: средний тон кожи',
    '👰🏾' => 'невеста: темный тон кожи',
    '👰🏿' => 'невеста: очень темный тон кожи',
    '🤰🏻' => 'беременная женщина: очень светлый тон кожи',
    '🤰🏼' => 'беременная женщина: светлый тон кожи',
    '🤰🏽' => 'беременная женщина: средний тон кожи',
    '🤰🏾' => 'беременная женщина: темный тон кожи',
    '🤰🏿' => 'беременная женщина: очень темный тон кожи',
    '🫃🏻' => 'беременный мужчина: очень светлый тон кожи',
    '🫃🏼' => 'беременный мужчина: светлый тон кожи',
    '🫃🏽' => 'беременный мужчина: средний тон кожи',
    '🫃🏾' => 'беременный мужчина: темный тон кожи',
    '🫃🏿' => 'беременный мужчина: очень темный тон кожи',
    '🫄🏻' => 'беременный человек: очень светлый тон кожи',
    '🫄🏼' => 'беременный человек: светлый тон кожи',
    '🫄🏽' => 'беременный человек: средний тон кожи',
    '🫄🏾' => 'беременный человек: темный тон кожи',
    '🫄🏿' => 'беременный человек: очень темный тон кожи',
    '🤱🏻' => 'кормление грудью: очень светлый тон кожи',
    '🤱🏼' => 'кормление грудью: светлый тон кожи',
    '🤱🏽' => 'кормление грудью: средний тон кожи',
    '🤱🏾' => 'кормление грудью: темный тон кожи',
    '🤱🏿' => 'кормление грудью: очень темный тон кожи',
    '👼🏻' => 'ангелочек: очень светлый тон кожи',
    '👼🏼' => 'ангелочек: светлый тон кожи',
    '👼🏽' => 'ангелочек: средний тон кожи',
    '👼🏾' => 'ангелочек: темный тон кожи',
    '👼🏿' => 'ангелочек: очень темный тон кожи',
    '🎅🏻' => 'Санта-Клаус: очень светлый тон кожи',
    '🎅🏼' => 'Санта-Клаус: светлый тон кожи',
    '🎅🏽' => 'Санта-Клаус: средний тон кожи',
    '🎅🏾' => 'Санта-Клаус: темный тон кожи',
    '🎅🏿' => 'Санта-Клаус: очень темный тон кожи',
    '🤶🏻' => 'миссис Клаус: очень светлый тон кожи',
    '🤶🏼' => 'миссис Клаус: светлый тон кожи',
    '🤶🏽' => 'миссис Клаус: средний тон кожи',
    '🤶🏾' => 'миссис Клаус: темный тон кожи',
    '🤶🏿' => 'миссис Клаус: очень темный тон кожи',
    '🦸🏻' => 'супергерой: очень светлый тон кожи',
    '🦸🏼' => 'супергерой: светлый тон кожи',
    '🦸🏽' => 'супергерой: средний тон кожи',
    '🦸🏾' => 'супергерой: темный тон кожи',
    '🦸🏿' => 'супергерой: очень темный тон кожи',
    '🦹🏻' => 'суперзлодей: очень светлый тон кожи',
    '🦹🏼' => 'суперзлодей: светлый тон кожи',
    '🦹🏽' => 'суперзлодей: средний тон кожи',
    '🦹🏾' => 'суперзлодей: темный тон кожи',
    '🦹🏿' => 'суперзлодей: очень темный тон кожи',
    '🧙🏻' => 'маг: очень светлый тон кожи',
    '🧙🏼' => 'маг: светлый тон кожи',
    '🧙🏽' => 'маг: средний тон кожи',
    '🧙🏾' => 'маг: темный тон кожи',
    '🧙🏿' => 'маг: очень темный тон кожи',
    '🧚🏻' => 'фея: очень светлый тон кожи',
    '🧚🏼' => 'фея: светлый тон кожи',
    '🧚🏽' => 'фея: средний тон кожи',
    '🧚🏾' => 'фея: темный тон кожи',
    '🧚🏿' => 'фея: очень темный тон кожи',
    '🧛🏻' => 'вампир: очень светлый тон кожи',
    '🧛🏼' => 'вампир: светлый тон кожи',
    '🧛🏽' => 'вампир: средний тон кожи',
    '🧛🏾' => 'вампир: темный тон кожи',
    '🧛🏿' => 'вампир: очень темный тон кожи',
    '🧜🏻' => 'русалка: очень светлый тон кожи',
    '🧜🏼' => 'русалка: светлый тон кожи',
    '🧜🏽' => 'русалка: средний тон кожи',
    '🧜🏾' => 'русалка: темный тон кожи',
    '🧜🏿' => 'русалка: очень темный тон кожи',
    '🧝🏻' => 'эльф: очень светлый тон кожи',
    '🧝🏼' => 'эльф: светлый тон кожи',
    '🧝🏽' => 'эльф: средний тон кожи',
    '🧝🏾' => 'эльф: темный тон кожи',
    '🧝🏿' => 'эльф: очень темный тон кожи',
    '💆🏻' => 'человеку массируют лицо: очень светлый тон кожи',
    '💆🏼' => 'человеку массируют лицо: светлый тон кожи',
    '💆🏽' => 'человеку массируют лицо: средний тон кожи',
    '💆🏾' => 'человеку массируют лицо: темный тон кожи',
    '💆🏿' => 'человеку массируют лицо: очень темный тон кожи',
    '💇🏻' => 'человек у парикмахера: очень светлый тон кожи',
    '💇🏼' => 'человек у парикмахера: светлый тон кожи',
    '💇🏽' => 'человек у парикмахера: средний тон кожи',
    '💇🏾' => 'человек у парикмахера: темный тон кожи',
    '💇🏿' => 'человек у парикмахера: очень темный тон кожи',
    '🚶🏻' => 'человек идет: очень светлый тон кожи',
    '🚶🏼' => 'человек идет: светлый тон кожи',
    '🚶🏽' => 'человек идет: средний тон кожи',
    '🚶🏾' => 'человек идет: темный тон кожи',
    '🚶🏿' => 'человек идет: очень темный тон кожи',
    '🧍🏻' => 'человек стоит: очень светлый тон кожи',
    '🧍🏼' => 'человек стоит: светлый тон кожи',
    '🧍🏽' => 'человек стоит: средний тон кожи',
    '🧍🏾' => 'человек стоит: темный тон кожи',
    '🧍🏿' => 'человек стоит: очень темный тон кожи',
    '🧎🏻' => 'человек на коленях: очень светлый тон кожи',
    '🧎🏼' => 'человек на коленях: светлый тон кожи',
    '🧎🏽' => 'человек на коленях: средний тон кожи',
    '🧎🏾' => 'человек на коленях: темный тон кожи',
    '🧎🏿' => 'человек на коленях: очень темный тон кожи',
    '🏃🏻' => 'человек бежит: очень светлый тон кожи',
    '🏃🏼' => 'человек бежит: светлый тон кожи',
    '🏃🏽' => 'человек бежит: средний тон кожи',
    '🏃🏾' => 'человек бежит: темный тон кожи',
    '🏃🏿' => 'человек бежит: очень темный тон кожи',
    '💃🏻' => 'танцующая женщина: очень светлый тон кожи',
    '💃🏼' => 'танцующая женщина: светлый тон кожи',
    '💃🏽' => 'танцующая женщина: средний тон кожи',
    '💃🏾' => 'танцующая женщина: темный тон кожи',
    '💃🏿' => 'танцующая женщина: очень темный тон кожи',
    '🕺🏻' => 'танцующий мужчина: очень светлый тон кожи',
    '🕺🏼' => 'танцующий мужчина: светлый тон кожи',
    '🕺🏽' => 'танцующий мужчина: средний тон кожи',
    '🕺🏾' => 'танцующий мужчина: темный тон кожи',
    '🕺🏿' => 'танцующий мужчина: очень темный тон кожи',
    '🕴🏻' => 'бизнесмен в воздухе: очень светлый тон кожи',
    '🕴🏼' => 'бизнесмен в воздухе: светлый тон кожи',
    '🕴🏽' => 'бизнесмен в воздухе: средний тон кожи',
    '🕴🏾' => 'бизнесмен в воздухе: темный тон кожи',
    '🕴🏿' => 'бизнесмен в воздухе: очень темный тон кожи',
    '👯🏻' => 'люди с ушами кролика: очень светлый тон кожи',
    '👯🏼' => 'люди с ушами кролика: светлый тон кожи',
    '👯🏽' => 'люди с ушами кролика: средний тон кожи',
    '👯🏾' => 'люди с ушами кролика: темный тон кожи',
    '👯🏿' => 'люди с ушами кролика: очень темный тон кожи',
    '🧖🏻' => 'человек в бане: очень светлый тон кожи',
    '🧖🏼' => 'человек в бане: светлый тон кожи',
    '🧖🏽' => 'человек в бане: средний тон кожи',
    '🧖🏾' => 'человек в бане: темный тон кожи',
    '🧖🏿' => 'человек в бане: очень темный тон кожи',
    '🧗🏻' => 'человек взбирается по скале: очень светлый тон кожи',
    '🧗🏼' => 'человек взбирается по скале: светлый тон кожи',
    '🧗🏽' => 'человек взбирается по скале: средний тон кожи',
    '🧗🏾' => 'человек взбирается по скале: темный тон кожи',
    '🧗🏿' => 'человек взбирается по скале: очень темный тон кожи',
    '🏇🏻' => 'скачки: очень светлый тон кожи',
    '🏇🏼' => 'скачки: светлый тон кожи',
    '🏇🏽' => 'скачки: средний тон кожи',
    '🏇🏾' => 'скачки: темный тон кожи',
    '🏇🏿' => 'скачки: очень темный тон кожи',
    '🏂🏻' => 'сноубордист: очень светлый тон кожи',
    '🏂🏼' => 'сноубордист: светлый тон кожи',
    '🏂🏽' => 'сноубордист: средний тон кожи',
    '🏂🏾' => 'сноубордист: темный тон кожи',
    '🏂🏿' => 'сноубордист: очень темный тон кожи',
    '🏌🏻' => 'гольфист: очень светлый тон кожи',
    '🏌🏼' => 'гольфист: светлый тон кожи',
    '🏌🏽' => 'гольфист: средний тон кожи',
    '🏌🏾' => 'гольфист: темный тон кожи',
    '🏌🏿' => 'гольфист: очень темный тон кожи',
    '🏄🏻' => 'серфинг: очень светлый тон кожи',
    '🏄🏼' => 'серфинг: светлый тон кожи',
    '🏄🏽' => 'серфинг: средний тон кожи',
    '🏄🏾' => 'серфинг: темный тон кожи',
    '🏄🏿' => 'серфинг: очень темный тон кожи',
    '🚣🏻' => 'гребля: очень светлый тон кожи',
    '🚣🏼' => 'гребля: светлый тон кожи',
    '🚣🏽' => 'гребля: средний тон кожи',
    '🚣🏾' => 'гребля: темный тон кожи',
    '🚣🏿' => 'гребля: очень темный тон кожи',
    '🏊🏻' => 'плавание: очень светлый тон кожи',
    '🏊🏼' => 'плавание: светлый тон кожи',
    '🏊🏽' => 'плавание: средний тон кожи',
    '🏊🏾' => 'плавание: темный тон кожи',
    '🏊🏿' => 'плавание: очень темный тон кожи',
    '⛹🏻' => 'баскетболист: очень светлый тон кожи',
    '⛹🏼' => 'баскетболист: светлый тон кожи',
    '⛹🏽' => 'баскетболист: средний тон кожи',
    '⛹🏾' => 'баскетболист: темный тон кожи',
    '⛹🏿' => 'баскетболист: очень темный тон кожи',
    '🏋🏻' => 'тяжелоатлет: очень светлый тон кожи',
    '🏋🏼' => 'тяжелоатлет: светлый тон кожи',
    '🏋🏽' => 'тяжелоатлет: средний тон кожи',
    '🏋🏾' => 'тяжелоатлет: темный тон кожи',
    '🏋🏿' => 'тяжелоатлет: очень темный тон кожи',
    '🚴🏻' => 'велосипедист: очень светлый тон кожи',
    '🚴🏼' => 'велосипедист: светлый тон кожи',
    '🚴🏽' => 'велосипедист: средний тон кожи',
    '🚴🏾' => 'велосипедист: темный тон кожи',
    '🚴🏿' => 'велосипедист: очень темный тон кожи',
    '🚵🏻' => 'человек на горном велосипеде: очень светлый тон кожи',
    '🚵🏼' => 'человек на горном велосипеде: светлый тон кожи',
    '🚵🏽' => 'человек на горном велосипеде: средний тон кожи',
    '🚵🏾' => 'человек на горном велосипеде: темный тон кожи',
    '🚵🏿' => 'человек на горном велосипеде: очень темный тон кожи',
    '🤸🏻' => 'акробатический трюк: очень светлый тон кожи',
    '🤸🏼' => 'акробатический трюк: светлый тон кожи',
    '🤸🏽' => 'акробатический трюк: средний тон кожи',
    '🤸🏾' => 'акробатический трюк: темный тон кожи',
    '🤸🏿' => 'акробатический трюк: очень темный тон кожи',
    '🤼🏻' => 'борцы: очень светлый тон кожи',
    '🤼🏼' => 'борцы: светлый тон кожи',
    '🤼🏽' => 'борцы: средний тон кожи',
    '🤼🏾' => 'борцы: темный тон кожи',
    '🤼🏿' => 'борцы: очень темный тон кожи',
    '🤽🏻' => 'водное поло: очень светлый тон кожи',
    '🤽🏼' => 'водное поло: светлый тон кожи',
    '🤽🏽' => 'водное поло: средний тон кожи',
    '🤽🏾' => 'водное поло: темный тон кожи',
    '🤽🏿' => 'водное поло: очень темный тон кожи',
    '🤾🏻' => 'гандбол: очень светлый тон кожи',
    '🤾🏼' => 'гандбол: светлый тон кожи',
    '🤾🏽' => 'гандбол: средний тон кожи',
    '🤾🏾' => 'гандбол: темный тон кожи',
    '🤾🏿' => 'гандбол: очень темный тон кожи',
    '🤹🏻' => 'жонглер: очень светлый тон кожи',
    '🤹🏼' => 'жонглер: светлый тон кожи',
    '🤹🏽' => 'жонглер: средний тон кожи',
    '🤹🏾' => 'жонглер: темный тон кожи',
    '🤹🏿' => 'жонглер: очень темный тон кожи',
    '🧘🏻' => 'человек в позе лотоса: очень светлый тон кожи',
    '🧘🏼' => 'человек в позе лотоса: светлый тон кожи',
    '🧘🏽' => 'человек в позе лотоса: средний тон кожи',
    '🧘🏾' => 'человек в позе лотоса: темный тон кожи',
    '🧘🏿' => 'человек в позе лотоса: очень темный тон кожи',
    '🛀🏻' => 'человек в ванне: очень светлый тон кожи',
    '🛀🏼' => 'человек в ванне: светлый тон кожи',
    '🛀🏽' => 'человек в ванне: средний тон кожи',
    '🛀🏾' => 'человек в ванне: темный тон кожи',
    '🛀🏿' => 'человек в ванне: очень темный тон кожи',
    '🛌🏻' => 'человек в кровати: очень светлый тон кожи',
    '🛌🏼' => 'человек в кровати: светлый тон кожи',
    '🛌🏽' => 'человек в кровати: средний тон кожи',
    '🛌🏾' => 'человек в кровати: темный тон кожи',
    '🛌🏿' => 'человек в кровати: очень темный тон кожи',
    '👭🏻' => 'две женщины: очень светлый тон кожи',
    '👭🏼' => 'две женщины: светлый тон кожи',
    '👭🏽' => 'две женщины: средний тон кожи',
    '👭🏾' => 'две женщины: темный тон кожи',
    '👭🏿' => 'две женщины: очень темный тон кожи',
    '👫🏻' => 'мужчина и женщина: очень светлый тон кожи',
    '👫🏼' => 'мужчина и женщина: светлый тон кожи',
    '👫🏽' => 'мужчина и женщина: средний тон кожи',
    '👫🏾' => 'мужчина и женщина: темный тон кожи',
    '👫🏿' => 'мужчина и женщина: очень темный тон кожи',
    '👬🏻' => 'двое мужчин: очень светлый тон кожи',
    '👬🏼' => 'двое мужчин: светлый тон кожи',
    '👬🏽' => 'двое мужчин: средний тон кожи',
    '👬🏾' => 'двое мужчин: темный тон кожи',
    '👬🏿' => 'двое мужчин: очень темный тон кожи',
    '💏🏻' => 'поцелуй: очень светлый тон кожи',
    '💏🏼' => 'поцелуй: светлый тон кожи',
    '💏🏽' => 'поцелуй: средний тон кожи',
    '💏🏾' => 'поцелуй: темный тон кожи',
    '💏🏿' => 'поцелуй: очень темный тон кожи',
    '💑🏻' => 'влюбленная пара: очень светлый тон кожи',
    '💑🏼' => 'влюбленная пара: светлый тон кожи',
    '💑🏽' => 'влюбленная пара: средний тон кожи',
    '💑🏾' => 'влюбленная пара: темный тон кожи',
    '💑🏿' => 'влюбленная пара: очень темный тон кожи',
    '🇦🇨' => 'флаг: о-в Вознесения',
    '🇦🇩' => 'флаг: Андорра',
    '🇦🇪' => 'флаг: ОАЭ',
    '🇦🇫' => 'флаг: Афганистан',
    '🇦🇬' => 'флаг: Антигуа и Барбуда',
    '🇦🇮' => 'флаг: Ангилья',
    '🇦🇱' => 'флаг: Албания',
    '🇦🇲' => 'флаг: Армения',
    '🇦🇴' => 'флаг: Ангола',
    '🇦🇶' => 'флаг: Антарктида',
    '🇦🇷' => 'флаг: Аргентина',
    '🇦🇸' => 'флаг: Американское Самоа',
    '🇦🇹' => 'флаг: Австрия',
    '🇦🇺' => 'флаг: Австралия',
    '🇦🇼' => 'флаг: Аруба',
    '🇦🇽' => 'флаг: Аландские о-ва',
    '🇦🇿' => 'флаг: Азербайджан',
    '🇧🇦' => 'флаг: Босния и Герцеговина',
    '🇧🇧' => 'флаг: Барбадос',
    '🇧🇩' => 'флаг: Бангладеш',
    '🇧🇪' => 'флаг: Бельгия',
    '🇧🇫' => 'флаг: Буркина-Фасо',
    '🇧🇬' => 'флаг: Болгария',
    '🇧🇭' => 'флаг: Бахрейн',
    '🇧🇮' => 'флаг: Бурунди',
    '🇧🇯' => 'флаг: Бенин',
    '🇧🇱' => 'флаг: Сен-Бартелеми',
    '🇧🇲' => 'флаг: Бермудские о-ва',
    '🇧🇳' => 'флаг: Бруней',
    '🇧🇴' => 'флаг: Боливия',
    '🇧🇶' => 'флаг: Бонэйр, Синт-Эстатиус и Саба',
    '🇧🇷' => 'флаг: Бразилия',
    '🇧🇸' => 'флаг: Багамы',
    '🇧🇹' => 'флаг: Бутан',
    '🇧🇻' => 'флаг: о-в Буве',
    '🇧🇼' => 'флаг: Ботсвана',
    '🇧🇾' => 'флаг: Беларусь',
    '🇧🇿' => 'флаг: Белиз',
    '🇨🇦' => 'флаг: Канада',
    '🇨🇨' => 'флаг: Кокосовые о-ва',
    '🇨🇩' => 'флаг: Конго - Киншаса',
    '🇨🇫' => 'флаг: Центрально-Африканская Республика',
    '🇨🇬' => 'флаг: Конго - Браззавиль',
    '🇨🇭' => 'флаг: Швейцария',
    '🇨🇮' => 'флаг: Кот-д’Ивуар',
    '🇨🇰' => 'флаг: о-ва Кука',
    '🇨🇱' => 'флаг: Чили',
    '🇨🇲' => 'флаг: Камерун',
    '🇨🇳' => 'флаг: Китай',
    '🇨🇴' => 'флаг: Колумбия',
    '🇨🇵' => 'флаг: о-в Клиппертон',
    '🇨🇶' => 'флаг: Сарк',
    '🇨🇷' => 'флаг: Коста-Рика',
    '🇨🇺' => 'флаг: Куба',
    '🇨🇻' => 'флаг: Кабо-Верде',
    '🇨🇼' => 'флаг: Кюрасао',
    '🇨🇽' => 'флаг: о-в Рождества',
    '🇨🇾' => 'флаг: Кипр',
    '🇨🇿' => 'флаг: Чехия',
    '🇩🇪' => 'флаг: Германия',
    '🇩🇬' => 'флаг: Диего-Гарсия',
    '🇩🇯' => 'флаг: Джибути',
    '🇩🇰' => 'флаг: Дания',
    '🇩🇲' => 'флаг: Доминика',
    '🇩🇴' => 'флаг: Доминиканская Республика',
    '🇩🇿' => 'флаг: Алжир',
    '🇪🇦' => 'флаг: Сеута и Мелилья',
    '🇪🇨' => 'флаг: Эквадор',
    '🇪🇪' => 'флаг: Эстония',
    '🇪🇬' => 'флаг: Египет',
    '🇪🇭' => 'флаг: Западная Сахара',
    '🇪🇷' => 'флаг: Эритрея',
    '🇪🇸' => 'флаг: Испания',
    '🇪🇹' => 'флаг: Эфиопия',
    '🇪🇺' => 'флаг: Европейский союз',
    '🇫🇮' => 'флаг: Финляндия',
    '🇫🇯' => 'флаг: Фиджи',
    '🇫🇰' => 'флаг: Фолклендские о-ва',
    '🇫🇲' => 'флаг: Федеративные Штаты Микронезии',
    '🇫🇴' => 'флаг: Фарерские о-ва',
    '🇫🇷' => 'флаг: Франция',
    '🇬🇦' => 'флаг: Габон',
    '🇬🇧' => 'флаг: Великобритания',
    '🇬🇩' => 'флаг: Гренада',
    '🇬🇪' => 'флаг: Грузия',
    '🇬🇫' => 'флаг: Французская Гвиана',
    '🇬🇬' => 'флаг: Гернси',
    '🇬🇭' => 'флаг: Гана',
    '🇬🇮' => 'флаг: Гибралтар',
    '🇬🇱' => 'флаг: Гренландия',
    '🇬🇲' => 'флаг: Гамбия',
    '🇬🇳' => 'флаг: Гвинея',
    '🇬🇵' => 'флаг: Гваделупа',
    '🇬🇶' => 'флаг: Экваториальная Гвинея',
    '🇬🇷' => 'флаг: Греция',
    '🇬🇸' => 'флаг: Южная Георгия и Южные Сандвичевы о-ва',
    '🇬🇹' => 'флаг: Гватемала',
    '🇬🇺' => 'флаг: Гуам',
    '🇬🇼' => 'флаг: Гвинея-Бисау',
    '🇬🇾' => 'флаг: Гайана',
    '🇭🇰' => 'флаг: Гонконг (САР)',
    '🇭🇲' => 'флаг: о-ва Херд и Макдональд',
    '🇭🇳' => 'флаг: Гондурас',
    '🇭🇷' => 'флаг: Хорватия',
    '🇭🇹' => 'флаг: Гаити',
    '🇭🇺' => 'флаг: Венгрия',
    '🇮🇨' => 'флаг: Канарские о-ва',
    '🇮🇩' => 'флаг: Индонезия',
    '🇮🇪' => 'флаг: Ирландия',
    '🇮🇱' => 'флаг: Израиль',
    '🇮🇲' => 'флаг: о-в Мэн',
    '🇮🇳' => 'флаг: Индия',
    '🇮🇴' => 'флаг: Британская территория в Индийском океане',
    '🇮🇶' => 'флаг: Ирак',
    '🇮🇷' => 'флаг: Иран',
    '🇮🇸' => 'флаг: Исландия',
    '🇮🇹' => 'флаг: Италия',
    '🇯🇪' => 'флаг: Джерси',
    '🇯🇲' => 'флаг: Ямайка',
    '🇯🇴' => 'флаг: Иордания',
    '🇯🇵' => 'флаг: Япония',
    '🇰🇪' => 'флаг: Кения',
    '🇰🇬' => 'флаг: Киргизия',
    '🇰🇭' => 'флаг: Камбоджа',
    '🇰🇮' => 'флаг: Кирибати',
    '🇰🇲' => 'флаг: Коморы',
    '🇰🇳' => 'флаг: Сент-Китс и Невис',
    '🇰🇵' => 'флаг: КНДР',
    '🇰🇷' => 'флаг: Республика Корея',
    '🇰🇼' => 'флаг: Кувейт',
    '🇰🇾' => 'флаг: о-ва Кайман',
    '🇰🇿' => 'флаг: Казахстан',
    '🇱🇦' => 'флаг: Лаос',
    '🇱🇧' => 'флаг: Ливан',
    '🇱🇨' => 'флаг: Сент-Люсия',
    '🇱🇮' => 'флаг: Лихтенштейн',
    '🇱🇰' => 'флаг: Шри-Ланка',
    '🇱🇷' => 'флаг: Либерия',
    '🇱🇸' => 'флаг: Лесото',
    '🇱🇹' => 'флаг: Литва',
    '🇱🇺' => 'флаг: Люксембург',
    '🇱🇻' => 'флаг: Латвия',
    '🇱🇾' => 'флаг: Ливия',
    '🇲🇦' => 'флаг: Марокко',
    '🇲🇨' => 'флаг: Монако',
    '🇲🇩' => 'флаг: Молдова',
    '🇲🇪' => 'флаг: Черногория',
    '🇲🇫' => 'флаг: Сен-Мартен',
    '🇲🇬' => 'флаг: Мадагаскар',
    '🇲🇭' => 'флаг: Маршалловы о-ва',
    '🇲🇰' => 'флаг: Северная Македония',
    '🇲🇱' => 'флаг: Мали',
    '🇲🇲' => 'флаг: Мьянма (Бирма)',
    '🇲🇳' => 'флаг: Монголия',
    '🇲🇴' => 'флаг: Макао (САР)',
    '🇲🇵' => 'флаг: Северные Марианские о-ва',
    '🇲🇶' => 'флаг: Мартиника',
    '🇲🇷' => 'флаг: Мавритания',
    '🇲🇸' => 'флаг: Монтсеррат',
    '🇲🇹' => 'флаг: Мальта',
    '🇲🇺' => 'флаг: Маврикий',
    '🇲🇻' => 'флаг: Мальдивы',
    '🇲🇼' => 'флаг: Малави',
    '🇲🇽' => 'флаг: Мексика',
    '🇲🇾' => 'флаг: Малайзия',
    '🇲🇿' => 'флаг: Мозамбик',
    '🇳🇦' => 'флаг: Намибия',
    '🇳🇨' => 'флаг: Новая Каледония',
    '🇳🇪' => 'флаг: Нигер',
    '🇳🇫' => 'флаг: о-в Норфолк',
    '🇳🇬' => 'флаг: Нигерия',
    '🇳🇮' => 'флаг: Никарагуа',
    '🇳🇱' => 'флаг: Нидерланды',
    '🇳🇴' => 'флаг: Норвегия',
    '🇳🇵' => 'флаг: Непал',
    '🇳🇷' => 'флаг: Науру',
    '🇳🇺' => 'флаг: Ниуэ',
    '🇳🇿' => 'флаг: Новая Зеландия',
    '🇴🇲' => 'флаг: Оман',
    '🇵🇦' => 'флаг: Панама',
    '🇵🇪' => 'флаг: Перу',
    '🇵🇫' => 'флаг: Французская Полинезия',
    '🇵🇬' => 'флаг: Папуа — Новая Гвинея',
    '🇵🇭' => 'флаг: Филиппины',
    '🇵🇰' => 'флаг: Пакистан',
    '🇵🇱' => 'флаг: Польша',
    '🇵🇲' => 'флаг: Сен-Пьер и Микелон',
    '🇵🇳' => 'флаг: о-ва Питкэрн',
    '🇵🇷' => 'флаг: Пуэрто-Рико',
    '🇵🇸' => 'флаг: Палестинские территории',
    '🇵🇹' => 'флаг: Португалия',
    '🇵🇼' => 'флаг: Палау',
    '🇵🇾' => 'флаг: Парагвай',
    '🇶🇦' => 'флаг: Катар',
    '🇷🇪' => 'флаг: Реюньон',
    '🇷🇴' => 'флаг: Румыния',
    '🇷🇸' => 'флаг: Сербия',
    '🇷🇺' => 'флаг: Россия',
    '🇷🇼' => 'флаг: Руанда',
    '🇸🇦' => 'флаг: Саудовская Аравия',
    '🇸🇧' => 'флаг: Соломоновы о-ва',
    '🇸🇨' => 'флаг: Сейшельские о-ва',
    '🇸🇩' => 'флаг: Судан',
    '🇸🇪' => 'флаг: Швеция',
    '🇸🇬' => 'флаг: Сингапур',
    '🇸🇭' => 'флаг: о-в Св. Елены',
    '🇸🇮' => 'флаг: Словения',
    '🇸🇯' => 'флаг: Шпицберген и Ян-Майен',
    '🇸🇰' => 'флаг: Словакия',
    '🇸🇱' => 'флаг: Сьерра-Леоне',
    '🇸🇲' => 'флаг: Сан-Марино',
    '🇸🇳' => 'флаг: Сенегал',
    '🇸🇴' => 'флаг: Сомали',
    '🇸🇷' => 'флаг: Суринам',
    '🇸🇸' => 'флаг: Южный Судан',
    '🇸🇹' => 'флаг: Сан-Томе и Принсипи',
    '🇸🇻' => 'флаг: Сальвадор',
    '🇸🇽' => 'флаг: Синт-Мартен',
    '🇸🇾' => 'флаг: Сирия',
    '🇸🇿' => 'флаг: Эсватини',
    '🇹🇦' => 'флаг: Тристан-да-Кунья',
    '🇹🇨' => 'флаг: Тёркс и Кайкос',
    '🇹🇩' => 'флаг: Чад',
    '🇹🇫' => 'флаг: Французские Южные территории',
    '🇹🇬' => 'флаг: Того',
    '🇹🇭' => 'флаг: Таиланд',
    '🇹🇯' => 'флаг: Таджикистан',
    '🇹🇰' => 'флаг: Токелау',
    '🇹🇱' => 'флаг: Восточный Тимор',
    '🇹🇲' => 'флаг: Туркменистан',
    '🇹🇳' => 'флаг: Тунис',
    '🇹🇴' => 'флаг: Тонга',
    '🇹🇷' => 'флаг: Турция',
    '🇹🇹' => 'флаг: Тринидад и Тобаго',
    '🇹🇻' => 'флаг: Тувалу',
    '🇹🇼' => 'флаг: Тайвань',
    '🇹🇿' => 'флаг: Танзания',
    '🇺🇦' => 'флаг: Украина',
    '🇺🇬' => 'флаг: Уганда',
    '🇺🇲' => 'флаг: Внешние малые о-ва (США)',
    '🇺🇳' => 'флаг: Организация Объединенных Наций',
    '🇺🇸' => 'флаг: Соединенные Штаты',
    '🇺🇾' => 'флаг: Уругвай',
    '🇺🇿' => 'флаг: Узбекистан',
    '🇻🇦' => 'флаг: Ватикан',
    '🇻🇨' => 'флаг: Сент-Винсент и Гренадины',
    '🇻🇪' => 'флаг: Венесуэла',
    '🇻🇬' => 'флаг: Виргинские о-ва (Великобритания)',
    '🇻🇮' => 'флаг: Виргинские о-ва (США)',
    '🇻🇳' => 'флаг: Вьетнам',
    '🇻🇺' => 'флаг: Вануату',
    '🇼🇫' => 'флаг: Уоллис и Футуна',
    '🇼🇸' => 'флаг: Самоа',
    '🇽🇰' => 'флаг: Косово',
    '🇾🇪' => 'флаг: Йемен',
    '🇾🇹' => 'флаг: Майотта',
    '🇿🇦' => 'флаг: Южно-Африканская Республика',
    '🇿🇲' => 'флаг: Замбия',
    '🇿🇼' => 'флаг: Зимбабве',
    '🔟' => 'клавиши: 10',
    '🏻' => 'очень светлый тон кожи',
    '🏼' => 'светлый тон кожи',
    '🏽' => 'средний тон кожи',
    '🏾' => 'темный тон кожи',
    '🏿' => 'очень темный тон кожи',
    '😀' => 'широко улыбается',
    '😃' => 'смеется',
    '😄' => 'смеется с закрытыми глазами',
    '😁' => 'светится от счастья',
    '😆' => 'смеется с прищуренными глазами',
    '😅' => 'нервно смеется',
    '🤣' => 'катается со смеху',
    '😂' => 'смеется до слез',
    '🙂' => 'слегка улыбается',
    '🙃' => 'вверх тормашками',
    '🫠' => 'тает',
    '😉' => 'подмигивает',
    '😊' => 'довольно улыбается',
    '😇' => 'с нимбом',
    '🥰' => 'улыбающееся лицо с сердечками',
    '😍' => 'влюбленное лицо',
    '🤩' => 'звезды в глазах',
    '😘' => 'воздушный поцелуй',
    '😗' => 'целует',
    '☺' => 'улыбается',
    '😚' => 'целует с закрытыми глазами',
    '😙' => 'счастливый поцелуй',
    '🥲' => 'улыбающееся лицо со слезой',
    '😋' => 'вкусно',
    '😛' => 'показывает язык',
    '😜' => 'показывает язык и подмигивает',
    '🤪' => 'сумасшедшее лицо',
    '😝' => 'морщится и показывает язык',
    '🤑' => 'деньги в глазах',
    '🤗' => 'обнимает',
    '🤭' => 'прикрывает рот рукой',
    '🫢' => 'прикрывает рот рукой с открытыми глазами',
    '🫣' => 'подсматривает',
    '🤫' => 'тс-с-с',
    '🤔' => 'думает',
    '🫡' => 'воинское приветствие',
    '🤐' => 'рот на замке',
    '🤨' => 'не верит',
    '😐' => 'все равно',
    '😑' => 'без эмоций',
    '😶' => 'лицо без рта',
    '🫥' => 'лицо пунктиром',
    '😏' => 'ухмыляется',
    '😒' => 'скучает',
    '🙄' => 'закатывает глаза',
    '😬' => 'гримаса',
    '🤥' => 'лжец',
    '🫨' => 'трясущееся лицо',
    '😌' => 'испытывает облегчение',
    '😔' => 'размышляет',
    '😪' => 'хочет спать',
    '🤤' => 'пускает слюни',
    '😴' => 'спит',
    '🫩' => 'лицо с мешками под глазами',
    '😷' => 'в медицинской маске',
    '🤒' => 'с градусником во рту',
    '🤕' => 'с перевязанной головой',
    '🤢' => 'тошнит',
    '🤮' => 'рвота',
    '🤧' => 'чихает',
    '🥵' => 'жар',
    '🥶' => 'мерзнет',
    '🥴' => 'чувствует головокружение',
    '😵' => 'головокружение',
    '🤯' => 'взрыв мозга',
    '🤠' => 'в ковбойской шляпе',
    '🥳' => 'на вечеринке',
    '🥸' => 'маскировка',
    '😎' => 'лицо в темных очках',
    '🤓' => 'очкарик',
    '🧐' => 'с моноклем',
    '😕' => 'в замешательстве',
    '🫤' => 'с перекошенным ртом',
    '😟' => 'беспокоится',
    '🙁' => 'немного грустит',
    '☹' => 'грустит',
    '😮' => 'удивление',
    '😯' => 'неприятный сюрприз',
    '😲' => 'в шоке',
    '😳' => 'краснеет',
    '🫪' => 'лицо перекосило',
    '🥺' => 'умоляет',
    '🥹' => 'еле сдерживает слезы',
    '😦' => 'в изумлении',
    '😧' => 'страдает',
    '😨' => 'боится',
    '😰' => 'сильно беспокоится',
    '😥' => 'обошлось',
    '😢' => 'плачет',
    '😭' => 'слезы рекой',
    '😱' => 'в ужасе',
    '😖' => 'в растерянности',
    '😣' => 'упорство',
    '😞' => 'разочарование',
    '😓' => 'в холодном поту',
    '😩' => 'усталость',
    '😫' => 'сильная усталость',
    '🥱' => 'зевает',
    '😤' => 'в ожидании успеха',
    '😡' => 'злится',
    '😠' => 'сердится',
    '🤬' => 'цензура',
    '😈' => 'улыбающийся чертенок',
    '👿' => 'злой чертенок',
    '💀' => 'череп',
    '☠' => 'череп и кости',
    '💩' => 'какашка',
    '🤡' => 'клоун',
    '👹' => 'чудовище',
    '👺' => 'японский гоблин',
    '👻' => 'привидение',
    '👽' => 'инопланетянин',
    '👾' => 'космический монстр',
    '🤖' => 'робот',
    '😺' => 'улыбающийся кот',
    '😸' => 'смеющийся кот',
    '😹' => 'смеющийся до слез кот',
    '😻' => 'влюбленный кот',
    '😼' => 'ухмыляющийся кот',
    '😽' => 'целующий кот',
    '🙀' => 'кот в шоке',
    '😿' => 'плачущий кот',
    '😾' => 'злой кот',
    '🙈' => 'ничего не вижу',
    '🙉' => 'ничего не слышу',
    '🙊' => 'ничего никому не скажу',
    '💌' => 'любовное письмо',
    '💘' => 'сердце, пронзенное стрелой',
    '💝' => 'сердце с лентой',
    '💖' => 'сверкающее сердце',
    '💗' => 'растущее сердце',
    '💓' => 'пульсирующее сердце',
    '💞' => 'вращающиеся сердца',
    '💕' => 'два сердца',
    '💟' => 'значок «сердце»',
    '❣' => 'восклицательный знак в виде сердца',
    '💔' => 'разбитое сердце',
    '❤' => 'алое сердце',
    '🩷' => 'розовое сердце',
    '🧡' => 'оранжевое сердце',
    '💛' => 'желтое сердце',
    '💚' => 'зеленое сердце',
    '💙' => 'синее сердце',
    '🩵' => 'голубое сердце',
    '💜' => 'фиолетовое сердце',
    '🤎' => 'коричневое сердце',
    '🖤' => 'черное сердце',
    '🩶' => 'серое сердце',
    '🤍' => 'белое сердце',
    '💋' => 'след от поцелуя',
    '💯' => 'сто баллов',
    '💢' => 'значок «гнев»',
    '🫯' => 'драка',
    '💥' => 'взрыв',
    '💫' => 'кружащаяся звезда',
    '💦' => 'капли пота',
    '💨' => 'исчезновение',
    '🕳' => 'дыра',
    '💬' => 'облачко с многоточием',
    '🗨' => 'пустое облачко',
    '🗯' => 'гневное облачко',
    '💭' => 'облачко с мыслями',
    '💤' => 'сон',
    '👋' => 'машет рукой',
    '🤚' => 'поднятая рука',
    '🖐' => 'раскрытая ладонь',
    '✋' => 'поднятая ладонь',
    '🖖' => 'вулканский салют',
    '🫱' => 'рука вправо',
    '🫲' => 'рука влево',
    '🫳' => 'рука ладонью вниз',
    '🫴' => 'рука ладонью вверх',
    '🫷' => 'рука ладонью влево',
    '🫸' => 'рука ладонью вправо',
    '👌' => 'жест «все хорошо»',
    '🤌' => 'щепоть',
    '🤏' => 'жест «мало»',
    '✌' => 'жест V',
    '🤞' => 'скрещенные пальцы',
    '🫰' => 'жест «деньги»',
    '🤟' => 'я-тебя-люблю',
    '🤘' => 'рокерский жест',
    '🤙' => 'жест «позвони мне»',
    '👈' => 'указывающий налево палец',
    '👉' => 'указывающий направо палец',
    '👆' => 'указывающий вверх палец',
    '🖕' => 'средний палец',
    '👇' => 'указывающий вниз палец',
    '☝' => 'указательный палец вверх',
    '🫵' => 'указательный палец на себя',
    '👍' => 'большой палец вверх',
    '👎' => 'большой палец вниз',
    '✊' => 'поднятый кулак',
    '👊' => 'кулак',
    '🤛' => 'кулак влево',
    '🤜' => 'кулак вправо',
    '👏' => 'аплодисменты',
    '🙌' => 'ура',
    '🫶' => 'жест «сердце»',
    '👐' => 'ладони в стороны',
    '🤲' => 'ладони лодочкой',
    '🤝' => 'рукопожатие',
    '🙏' => 'сложенные руки',
    '✍' => 'пишущая рука',
    '💅' => 'маникюр',
    '🤳' => 'селфи',
    '💪' => 'бицепс',
    '🦾' => 'механическая рука',
    '🦿' => 'механическая нога',
    '🦵' => 'нога',
    '🦶' => 'щиколотка',
    '👂' => 'ухо',
    '🦻' => 'ухо со слуховым аппаратом',
    '👃' => 'нос',
    '🧠' => 'мозг',
    '🫀' => 'сердце человека',
    '🫁' => 'легкие',
    '🦷' => 'зуб',
    '🦴' => 'кость',
    '👀' => 'глаза',
    '👁' => 'глаз',
    '👅' => 'язык',
    '👄' => 'рот',
    '🫦' => 'кусать губы',
    '👶' => 'младенец',
    '🧒' => 'ребенок',
    '👦' => 'мальчик',
    '👧' => 'девочка',
    '🧑' => 'взрослый',
    '👱' => 'человек со светлыми волосами',
    '👨' => 'мужчина',
    '🧔' => 'бородатый человек',
    '👩' => 'женщина',
    '🧓' => 'пожилой человек',
    '👴' => 'пожилой мужчина',
    '👵' => 'пожилая женщина',
    '🙍' => 'нахмурившийся человек',
    '🙎' => 'обиженный человек',
    '🙅' => 'человек против',
    '🙆' => 'человек за',
    '💁' => 'человек тянет руку',
    '🙋' => 'человек с поднятой рукой',
    '🧏' => 'глухой человек',
    '🙇' => 'человек кланяется',
    '🤦' => 'человек потерял дар речи',
    '🤷' => 'человек пожимает плечами',
    '👮' => 'полицейский',
    '🕵' => 'детектив',
    '💂' => 'гвардеец',
    '🥷' => 'ниндзя',
    '👷' => 'строитель',
    '🫅' => 'человек с короной',
    '🤴' => 'принц',
    '👸' => 'принцесса',
    '👳' => 'человек в тюрбане',
    '👲' => 'мужчина в китайской шапке',
    '🧕' => 'женщина в платке',
    '🤵' => 'жених',
    '👰' => 'невеста',
    '🤰' => 'беременная женщина',
    '🫃' => 'беременный мужчина',
    '🫄' => 'беременный человек',
    '🤱' => 'кормление грудью',
    '👼' => 'ангелочек',
    '🎅' => 'Санта-Клаус',
    '🤶' => 'миссис Клаус',
    '🦸' => 'супергерой',
    '🦹' => 'суперзлодей',
    '🧙' => 'маг',
    '🧚' => 'фея',
    '🧛' => 'вампир',
    '🧜' => 'русалка',
    '🧝' => 'эльф',
    '🧞' => 'джинн',
    '🧟' => 'зомби',
    '🧌' => 'тролль',
    '🫈' => 'снежный человек',
    '💆' => 'человеку массируют лицо',
    '💇' => 'человек у парикмахера',
    '🚶' => 'человек идет',
    '🧍' => 'человек стоит',
    '🧎' => 'человек на коленях',
    '🏃' => 'человек бежит',
    '💃' => 'танцующая женщина',
    '🕺' => 'танцующий мужчина',
    '🕴' => 'бизнесмен в воздухе',
    '👯' => 'люди с ушами кролика',
    '🧖' => 'человек в бане',
    '🧗' => 'человек взбирается по скале',
    '🤺' => 'фехтовальщик',
    '🏇' => 'скачки',
    '⛷' => 'горные лыжи',
    '🏂' => 'сноубордист',
    '🏌' => 'гольфист',
    '🏄' => 'серфинг',
    '🚣' => 'гребля',
    '🏊' => 'плавание',
    '⛹' => 'баскетболист',
    '🏋' => 'тяжелоатлет',
    '🚴' => 'велосипедист',
    '🚵' => 'человек на горном велосипеде',
    '🤸' => 'акробатический трюк',
    '🤼' => 'борцы',
    '🤽' => 'водное поло',
    '🤾' => 'гандбол',
    '🤹' => 'жонглер',
    '🧘' => 'человек в позе лотоса',
    '🛀' => 'человек в ванне',
    '🛌' => 'человек в кровати',
    '👭' => 'две женщины',
    '👫' => 'мужчина и женщина',
    '👬' => 'двое мужчин',
    '💏' => 'поцелуй',
    '💑' => 'влюбленная пара',
    '🗣' => 'говорящая голова',
    '👤' => 'силуэт человека',
    '👥' => 'два силуэта',
    '🫂' => 'обнимающиеся люди',
    '👪' => 'семья',
    '👣' => 'следы',
    '🫆' => 'отпечаток пальца',
    '🦰' => 'рыжие волосы',
    '🦱' => 'кудрявые волосы',
    '🦳' => 'седые волосы',
    '🦲' => 'без волос',
    '🐵' => 'морда обезьяны',
    '🐒' => 'обезьяна',
    '🦍' => 'горилла',
    '🦧' => 'орангутан',
    '🐶' => 'морда собаки',
    '🐕' => 'собака',
    '🦮' => 'собака-поводырь',
    '🐩' => 'пудель',
    '🐺' => 'морда волка',
    '🦊' => 'морда лисицы',
    '🦝' => 'морда енота',
    '🐱' => 'морда кошки',
    '🐈' => 'кошка',
    '🦁' => 'морда льва',
    '🐯' => 'морда тигра',
    '🐅' => 'тигр',
    '🐆' => 'леопард',
    '🐴' => 'морда лошади',
    '🫎' => 'лось',
    '🫏' => 'осел',
    '🐎' => 'лошадь',
    '🦄' => 'голова единорога',
    '🦓' => 'зебра',
    '🦌' => 'олень',
    '🦬' => 'бизон',
    '🐮' => 'морда коровы',
    '🐂' => 'бык',
    '🐃' => 'буйвол',
    '🐄' => 'корова',
    '🐷' => 'морда свиньи',
    '🐖' => 'свинья',
    '🐗' => 'кабан',
    '🐽' => 'свиной пятачок',
    '🐏' => 'баран',
    '🐑' => 'овца',
    '🐐' => 'коза',
    '🐪' => 'одногорбый верблюд',
    '🐫' => 'двугорбый верблюд',
    '🦙' => 'лама',
    '🦒' => 'жираф',
    '🐘' => 'слон',
    '🦣' => 'мамонт',
    '🦏' => 'носорог',
    '🦛' => 'гиппопотам',
    '🐭' => 'морда мыши',
    '🐁' => 'мышь',
    '🐀' => 'крыса',
    '🐹' => 'морда хомяка',
    '🐰' => 'морда кролика',
    '🐇' => 'кролик',
    '🐿' => 'бурундук',
    '🦫' => 'бобр',
    '🦔' => 'еж',
    '🦇' => 'летучая мышь',
    '🐻' => 'морда медведя',
    '🐨' => 'морда коалы',
    '🐼' => 'морда панды',
    '🦥' => 'ленивец',
    '🦦' => 'выдра',
    '🦨' => 'скунс',
    '🦘' => 'кенгуру',
    '🦡' => 'барсук',
    '🐾' => 'следы животного',
    '🦃' => 'индейка',
    '🐔' => 'курица',
    '🐓' => 'петух',
    '🐣' => 'цыпленок в яйце',
    '🐤' => 'цыпленок боком',
    '🐥' => 'цыпленок',
    '🐦' => 'птица',
    '🐧' => 'пингвин',
    '🕊' => 'голубь',
    '🦅' => 'орел',
    '🦆' => 'утка',
    '🦢' => 'лебедь',
    '🦉' => 'сова',
    '🦤' => 'дронт',
    '🪶' => 'перо',
    '🦩' => 'фламинго',
    '🦚' => 'павлин',
    '🦜' => 'попугай',
    '🪽' => 'крыло',
    '🪿' => 'гусь',
    '🐸' => 'голова лягушки',
    '🐊' => 'крокодил',
    '🐢' => 'черепаха',
    '🦎' => 'ящерица',
    '🐍' => 'змея',
    '🐲' => 'голова дракона',
    '🐉' => 'дракон',
    '🦕' => 'зауропод',
    '🦖' => 'Ти-Рекс',
    '🐳' => 'кит с фонтанчиком',
    '🐋' => 'кит',
    '🐬' => 'дельфин',
    '🫍' => 'косатка',
    '🦭' => 'тюлень',
    '🐟' => 'рыба',
    '🐠' => 'тропическая рыба',
    '🐡' => 'рыба-еж',
    '🦈' => 'акула',
    '🐙' => 'осьминог',
    '🐚' => 'раковина',
    '🪸' => 'коралл',
    '🪼' => 'медуза',
    '🦀' => 'краб',
    '🦞' => 'омар',
    '🦐' => 'креветка',
    '🦑' => 'кальмар',
    '🦪' => 'устрица',
    '🐌' => 'улитка',
    '🦋' => 'бабочка',
    '🐛' => 'гусеница',
    '🐜' => 'муравей',
    '🐝' => 'пчела',
    '🪲' => 'жук',
    '🐞' => 'божья коровка',
    '🦗' => 'сверчок',
    '🪳' => 'таракан',
    '🕷' => 'паук',
    '🕸' => 'паутина',
    '🦂' => 'скорпион',
    '🦟' => 'комар',
    '🪰' => 'муха',
    '🪱' => 'червяк',
    '🦠' => 'микроб',
    '💐' => 'букет',
    '🌸' => 'цветок вишни',
    '💮' => 'белый цветок',
    '🪷' => 'лотос',
    '🏵' => 'розетка',
    '🌹' => 'роза',
    '🥀' => 'увядший цветок',
    '🌺' => 'гибискус',
    '🌻' => 'подсолнух',
    '🌼' => 'цветок',
    '🌷' => 'тюльпан',
    '🪻' => 'гиацинт',
    '🌱' => 'росток',
    '🪴' => 'растение в горшке',
    '🌲' => 'елка',
    '🌳' => 'дерево',
    '🌴' => 'пальма',
    '🌵' => 'кактус',
    '🌾' => 'колос',
    '🌿' => 'веточка',
    '☘' => 'трилистник',
    '🍀' => 'четырехлистный клевер',
    '🍁' => 'кленовый лист',
    '🍂' => 'падающие листья',
    '🍃' => 'листья на ветру',
    '🪹' => 'пустое гнездо',
    '🪺' => 'гнездо с яйцами',
    '🍄' => 'гриб',
    '🪾' => 'дерево без листвы',
    '🍇' => 'виноград',
    '🍈' => 'дыня',
    '🍉' => 'арбуз',
    '🍊' => 'мандарин',
    '🍋' => 'лимон',
    '🍌' => 'банан',
    '🍍' => 'ананас',
    '🥭' => 'манго',
    '🍎' => 'красное яблоко',
    '🍏' => 'зеленое яблоко',
    '🍐' => 'груша',
    '🍑' => 'персик',
    '🍒' => 'вишня',
    '🍓' => 'клубника',
    '🫐' => 'голубика',
    '🥝' => 'киви',
    '🍅' => 'помидор',
    '🫒' => 'оливка',
    '🥥' => 'кокос',
    '🥑' => 'авокадо',
    '🍆' => 'баклажан',
    '🥔' => 'картофель',
    '🥕' => 'морковь',
    '🌽' => 'кукурузный початок',
    '🌶' => 'острый перец',
    '🫑' => 'болгарский перец',
    '🥒' => 'огурец',
    '🥬' => 'зеленый салат',
    '🥦' => 'брокколи',
    '🧄' => 'чеснок',
    '🧅' => 'лук',
    '🥜' => 'арахис',
    '🫘' => 'фасоль',
    '🌰' => 'каштан',
    '🫚' => 'корень имбиря',
    '🫛' => 'стручок гороха',
    '🫜' => 'корнеплод',
    '🍞' => 'хлеб',
    '🥐' => 'круассан',
    '🥖' => 'багет',
    '🫓' => 'лепешка',
    '🥨' => 'крендель',
    '🥯' => 'бублик',
    '🥞' => 'блины',
    '🧇' => 'вафля',
    '🧀' => 'сыр',
    '🍖' => 'мясо на косточке',
    '🍗' => 'куриная ножка',
    '🥩' => 'кусок мяса',
    '🥓' => 'бекон',
    '🍔' => 'гамбургер',
    '🍟' => 'картофель фри',
    '🍕' => 'пицца',
    '🌭' => 'хот-дог',
    '🥪' => 'сэндвич',
    '🌮' => 'тако',
    '🌯' => 'буррито',
    '🫔' => 'тамале',
    '🥙' => 'шаурма',
    '🧆' => 'фалафель',
    '🥚' => 'яйцо',
    '🍳' => 'яичница на сковороде',
    '🥘' => 'рагу в сковороде',
    '🍲' => 'кастрюля с горячей едой',
    '🫕' => 'фондю',
    '🥣' => 'миска с ложкой',
    '🥗' => 'овощной салат',
    '🍿' => 'попкорн',
    '🧈' => 'масло',
    '🧂' => 'солонка',
    '🥫' => 'консервы',
    '🍱' => 'бэнто',
    '🍘' => 'рисовый крекер',
    '🍙' => 'онигири',
    '🍚' => 'рис',
    '🍛' => 'рис с карри',
    '🍜' => 'лапша',
    '🍝' => 'спагетти',
    '🍠' => 'печеный сладкий картофель',
    '🍢' => 'одэн',
    '🍣' => 'суши',
    '🍤' => 'жареная креветка',
    '🍥' => 'камабоко',
    '🥮' => 'лунный пирог',
    '🍡' => 'данго',
    '🥟' => 'вареник',
    '🥠' => 'печенье с предсказанием',
    '🥡' => 'коробка для еды на вынос',
    '🍦' => 'мороженое в стаканчике',
    '🍧' => 'мороженое в креманке',
    '🍨' => 'мороженое',
    '🍩' => 'пончик',
    '🍪' => 'печенье',
    '🎂' => 'торт ко дню рождения',
    '🍰' => 'кусочек торта',
    '🧁' => 'капкейк',
    '🥧' => 'пирог',
    '🍫' => 'шоколад',
    '🍬' => 'конфета',
    '🍭' => 'леденец',
    '🍮' => 'пудинг',
    '🍯' => 'мед',
    '🍼' => 'бутылочка с соской',
    '🥛' => 'стакан молока',
    '☕' => 'горячий напиток',
    '🫖' => 'чайник',
    '🍵' => 'чашка без ручки',
    '🍶' => 'бутылка саке',
    '🍾' => 'шампанское',
    '🍷' => 'бокал вина',
    '🍸' => 'коктейль',
    '🍹' => 'тропический коктейль',
    '🍺' => 'кружка пива',
    '🍻' => 'чокающиеся кружки',
    '🥂' => 'чокающиеся бокалы',
    '🥃' => 'стакан с виски',
    '🫗' => 'стакан с жидкостью',
    '🥤' => 'стакан с соломинкой',
    '🧋' => 'чай с шариками',
    '🧃' => 'пакетик сока',
    '🧉' => 'мате',
    '🧊' => 'кубик льда',
    '🥢' => 'палочки для еды',
    '🍽' => 'тарелка с приборами',
    '🍴' => 'вилка и нож',
    '🥄' => 'ложка',
    '🔪' => 'нож',
    '🫙' => 'банка',
    '🏺' => 'амфора',
    '🌍' => 'Европа и Африка на земном шаре',
    '🌎' => 'Америка на земном шаре',
    '🌏' => 'Азия и Австралия на земном шаре',
    '🌐' => 'меридианы',
    '🗺' => 'карта мира',
    '🗾' => 'карта Японии',
    '🧭' => 'компас',
    '🏔' => 'гора со снежной шапкой',
    '⛰' => 'гора',
    '🛘' => 'оползень',
    '🌋' => 'вулкан',
    '🗻' => 'Фудзияма',
    '🏕' => 'кемпинг',
    '🏖' => 'пляж',
    '🏜' => 'пустыня',
    '🏝' => 'остров',
    '🏞' => 'национальный парк',
    '🏟' => 'стадион',
    '🏛' => 'античное здание',
    '🏗' => 'стройка',
    '🧱' => 'кирпичи',
    '🪨' => 'камень',
    '🪵' => 'древесина',
    '🛖' => 'хижина',
    '🏘' => 'дома',
    '🏚' => 'заброшенный дом',
    '🏠' => 'дом',
    '🏡' => 'дом с садом',
    '🏢' => 'офисное здание',
    '🏣' => 'японская почта',
    '🏤' => 'почта',
    '🏥' => 'больница',
    '🏦' => 'банк',
    '🏨' => 'гостиница',
    '🏩' => 'гостиница для свиданий',
    '🏪' => 'круглосуточный магазин',
    '🏫' => 'школа',
    '🏬' => 'универмаг',
    '🏭' => 'завод',
    '🏯' => 'японский замок',
    '🏰' => 'замок',
    '💒' => 'свадьба',
    '🗼' => 'Токийская башня',
    '🗽' => 'статуя Свободы',
    '⛪' => 'церковь',
    '🕌' => 'мечеть',
    '🛕' => 'индуистский храм',
    '🕍' => 'синагога',
    '⛩' => 'синтоистский храм',
    '🕋' => 'Кааба',
    '⛲' => 'фонтан',
    '⛺' => 'палатка',
    '🌁' => 'туман',
    '🌃' => 'звездная ночь',
    '🏙' => 'вид на город',
    '🌄' => 'восход солнца над горами',
    '🌅' => 'восход',
    '🌆' => 'закат в городе',
    '🌇' => 'закат',
    '🌉' => 'мост ночью',
    '♨' => 'горячие источники',
    '🎠' => 'лошадь на карусели',
    '🛝' => 'детская горка',
    '🎡' => 'колесо обозрения',
    '🎢' => 'американские горки',
    '💈' => 'парикмахерская',
    '🎪' => 'цирковой шатер',
    '🚂' => 'паровоз',
    '🚃' => 'вагон',
    '🚄' => 'скоростной поезд',
    '🚅' => 'поезд-пуля',
    '🚆' => 'поезд',
    '🚇' => 'метро',
    '🚈' => 'легкий рельсовый транспорт',
    '🚉' => 'железнодорожный вокзал',
    '🚊' => 'трамвай',
    '🚝' => 'монорельс',
    '🚞' => 'поезд в горах',
    '🚋' => 'трамвайный вагон',
    '🚌' => 'автобус',
    '🚍' => 'автобус спереди',
    '🚎' => 'троллейбус',
    '🚐' => 'микроавтобус',
    '🚑' => 'машина скорой помощи',
    '🚒' => 'пожарная машина',
    '🚓' => 'полицейская машина',
    '🚔' => 'полицейская машина спереди',
    '🚕' => 'такси',
    '🚖' => 'такси спереди',
    '🚗' => 'автомобиль',
    '🚘' => 'автомобиль спереди',
    '🚙' => 'джип',
    '🛻' => 'пикап',
    '🚚' => 'грузовик',
    '🚛' => 'фура',
    '🚜' => 'трактор',
    '🏎' => 'гоночный автомобиль',
    '🏍' => 'мотоцикл',
    '🛵' => 'скутер',
    '🦽' => 'кресло-коляска с ручным приводом',
    '🦼' => 'кресло-коляска с мотором',
    '🛺' => 'авторикша',
    '🚲' => 'велосипед',
    '🛴' => 'самокат',
    '🛹' => 'скейтборд',
    '🛼' => 'роликовые коньки',
    '🚏' => 'автобусная остановка',
    '🛣' => 'шоссе',
    '🛤' => 'железная дорога',
    '🛢' => 'бочка',
    '⛽' => 'заправка',
    '🛞' => 'автомобильное колесо',
    '🚨' => 'мигалка',
    '🚥' => 'горизонтальный светофор',
    '🚦' => 'вертикальный светофор',
    '🛑' => 'знак «стоп»',
    '🚧' => 'строительные работы',
    '⚓' => 'якорь',
    '🛟' => 'спасательный круг',
    '⛵' => 'парусник',
    '🛶' => 'каноэ',
    '🚤' => 'катер',
    '🛳' => 'пассажирский лайнер',
    '⛴' => 'паром',
    '🛥' => 'моторная лодка',
    '🚢' => 'корабль',
    '✈' => 'самолет',
    '🛩' => 'маленький самолет',
    '🛫' => 'взлет',
    '🛬' => 'посадка',
    '🪂' => 'парашют',
    '💺' => 'кресло',
    '🚁' => 'вертолет',
    '🚟' => 'подвесная железная дорога',
    '🚠' => 'вагон фуникулера',
    '🚡' => 'канатная дорога',
    '🛰' => 'спутник',
    '🚀' => 'ракета',
    '🛸' => 'летающая тарелка',
    '🛎' => 'гостиничный звонок',
    '🧳' => 'багаж',
    '⌛' => 'песочные часы',
    '⏳' => 'время пошло',
    '⌚' => 'наручные часы',
    '⏰' => 'будильник',
    '⏱' => 'секундомер',
    '⏲' => 'таймер',
    '🕰' => 'каминные часы',
    '🕛' => 'двенадцать часов',
    '🕧' => 'полпервого',
    '🕐' => 'час',
    '🕜' => 'полвторого',
    '🕑' => 'два часа',
    '🕝' => 'полтретьего',
    '🕒' => 'три часа',
    '🕞' => 'полчетвертого',
    '🕓' => 'четыре часа',
    '🕟' => 'полпятого',
    '🕔' => 'пять часов',
    '🕠' => 'полшестого',
    '🕕' => 'шесть часов',
    '🕡' => 'полседьмого',
    '🕖' => 'семь часов',
    '🕢' => 'полвосьмого',
    '🕗' => 'восемь часов',
    '🕣' => 'полдевятого',
    '🕘' => 'девять часов',
    '🕤' => 'полдесятого',
    '🕙' => 'десять часов',
    '🕥' => 'пол-одиннадцатого',
    '🕚' => 'одиннадцать часов',
    '🕦' => 'полдвенадцатого',
    '🌑' => 'новолуние',
    '🌒' => 'молодая луна',
    '🌓' => 'луна в первой четверти',
    '🌔' => 'прибывающая луна',
    '🌕' => 'полнолуние',
    '🌖' => 'убывающая луна',
    '🌗' => 'луна в последней четверти',
    '🌘' => 'старая луна',
    '🌙' => 'полумесяц',
    '🌚' => 'новая луна с лицом',
    '🌛' => 'луна в первой четверти с лицом',
    '🌜' => 'луна в последней четверти с лицом',
    '🌡' => 'термометр',
    '☀' => 'солнце',
    '🌝' => 'полная луна с лицом',
    '🌞' => 'солнце с лицом',
    '🪐' => 'планета с кольцом',
    '⭐' => 'желтая звезда',
    '🌟' => 'сияющая звезда',
    '🌠' => 'падающая звезда',
    '🌌' => 'Млечный Путь',
    '☁' => 'облако',
    '⛅' => 'солнце за облаками',
    '⛈' => 'гроза',
    '🌤' => 'солнце за облачком',
    '🌥' => 'солнце за облаком',
    '🌦' => 'слепой дождь',
    '🌧' => 'дождь',
    '🌨' => 'снег',
    '🌩' => 'молния',
    '🌪' => 'торнадо',
    '🌫' => 'густой туман',
    '🌬' => 'дует ветер',
    '🌀' => 'циклон',
    '🌈' => 'радуга',
    '🌂' => 'закрытый зонт',
    '☂' => 'зонт',
    '☔' => 'зонт под дождем',
    '⛱' => 'пляжный зонт',
    '⚡' => 'высокое напряжение',
    '❄' => 'снежинка',
    '☃' => 'снеговик под снегом',
    '⛄' => 'снеговик',
    '☄' => 'комета',
    '🔥' => 'огонь',
    '💧' => 'капля',
    '🌊' => 'волна',
    '🎃' => 'тыква-фонарь',
    '🎄' => 'новогодняя елка',
    '🎆' => 'фейерверк',
    '🎇' => 'бенгальский огонь',
    '🧨' => 'динамитная шашка',
    '✨' => 'блестки',
    '🎈' => 'воздушный шарик',
    '🎉' => 'хлопушка',
    '🎊' => 'конфетти',
    '🎋' => 'бамбук с бумажными лентами',
    '🎍' => 'украшенный бамбук',
    '🎎' => 'японские куклы',
    '🎏' => 'вымпелы в виде карпов',
    '🎐' => 'музыка ветра',
    '🎑' => 'праздник Луны',
    '🧧' => 'красный конверт',
    '🎀' => 'бантик',
    '🎁' => 'подарок',
    '🎗' => 'памятная лента',
    '🎟' => 'билеты',
    '🎫' => 'билет',
    '🎖' => 'военная медаль',
    '🏆' => 'кубок',
    '🏅' => 'спортивная медаль',
    '🥇' => 'золотая медаль',
    '🥈' => 'серебряная медаль',
    '🥉' => 'бронзовая медаль',
    '⚽' => 'футбол',
    '⚾' => 'бейсбол',
    '🥎' => 'софтбол',
    '🏀' => 'баскетбол',
    '🏐' => 'волейбол',
    '🏈' => 'американский футбол',
    '🏉' => 'регби',
    '🎾' => 'теннис',
    '🥏' => 'летающий диск',
    '🎳' => 'боулинг',
    '🏏' => 'крикет',
    '🏑' => 'хоккей на траве',
    '🏒' => 'хоккей',
    '🥍' => 'лакросс',
    '🏓' => 'настольный теннис',
    '🏸' => 'бадминтон',
    '🥊' => 'боксерская перчатка',
    '🥋' => 'спортивное кимоно',
    '🥅' => 'спортивные ворота',
    '⛳' => 'гольф',
    '⛸' => 'коньки',
    '🎣' => 'удочка с рыбой',
    '🤿' => 'маска с трубкой',
    '🎽' => 'футболка для бега',
    '🎿' => 'лыжи',
    '🛷' => 'санки',
    '🥌' => 'керлинг',
    '🎯' => 'мишень',
    '🪀' => 'йо-йо',
    '🪁' => 'воздушный змей',
    '🔫' => 'водяной пистолет',
    '🎱' => 'бильярд',
    '🔮' => 'хрустальный шар',
    '🪄' => 'волшебная палочка',
    '🎮' => 'видеоигры',
    '🕹' => 'джойстик',
    '🎰' => 'игровой автомат',
    '🎲' => 'игральная кость',
    '🧩' => 'пазл',
    '🧸' => 'плюшевый мишка',
    '🪅' => 'пиньята',
    '🪩' => 'диско-шар',
    '🪆' => 'матрешка',
    '♠' => 'пики',
    '♥' => 'червы',
    '♦' => 'бубны',
    '♣' => 'трефы',
    '♟' => 'пешка',
    '🃏' => 'джокер',
    '🀄' => 'маджонг',
    '🎴' => 'цветочная карта',
    '🎭' => 'маски',
    '🖼' => 'картина',
    '🎨' => 'палитра с красками',
    '🧵' => 'катушка ниток',
    '🪡' => 'швейная игла',
    '🧶' => 'клубок',
    '🪢' => 'узел',
    '👓' => 'очки',
    '🕶' => 'солнечные очки',
    '🥽' => 'защитные очки',
    '🥼' => 'лабораторный халат',
    '🦺' => 'спасательный жилет',
    '👔' => 'галстук',
    '👕' => 'футболка',
    '👖' => 'джинсы',
    '🧣' => 'шарф',
    '🧤' => 'перчатки',
    '🧥' => 'пальто',
    '🧦' => 'носки',
    '👗' => 'платье',
    '👘' => 'кимоно',
    '🥻' => 'сари',
    '🩱' => 'цельный купальник',
    '🩲' => 'плавки',
    '🩳' => 'шорты',
    '👙' => 'бикини',
    '👚' => 'блузка',
    '🪭' => 'веер',
    '👛' => 'кошелек',
    '👜' => 'сумка',
    '👝' => 'клатч',
    '🛍' => 'пакеты',
    '🎒' => 'ранец',
    '🩴' => 'вьетнамки',
    '👞' => 'ботинок',
    '👟' => 'кроссовки',
    '🥾' => 'треккинговый ботинок',
    '🥿' => 'балетки',
    '👠' => 'туфли на каблуке',
    '👡' => 'босоножки',
    '🩰' => 'пуанты',
    '👢' => 'сапог',
    '🪮' => 'афро-гребень',
    '👑' => 'корона',
    '👒' => 'шляпка',
    '🎩' => 'цилиндр',
    '🎓' => 'шапочка выпускника',
    '🧢' => 'бейсболка',
    '🪖' => 'армейская каска',
    '⛑' => 'каска с белым крестом',
    '📿' => 'четки',
    '💄' => 'помада',
    '💍' => 'кольцо',
    '💎' => 'драгоценный камень',
    '🔇' => 'без звука',
    '🔈' => 'низкая громкость',
    '🔉' => 'средняя громкость',
    '🔊' => 'высокая громкость',
    '📢' => 'громкоговоритель',
    '📣' => 'мегафон',
    '📯' => 'почтовый рожок',
    '🔔' => 'колокольчик',
    '🔕' => 'перечеркнутый колокольчик',
    '🎼' => 'нотный стан',
    '🎵' => 'нота',
    '🎶' => 'ноты',
    '🎙' => 'студийный микрофон',
    '🎚' => 'слайдер',
    '🎛' => 'регуляторы',
    '🎤' => 'микрофон',
    '🎧' => 'наушники',
    '📻' => 'радио',
    '🎷' => 'саксофон',
    '🎺' => 'труба',
    '🪊' => 'тромбон',
    '🪗' => 'аккордеон',
    '🎸' => 'гитара',
    '🎹' => 'клавишные',
    '🎻' => 'скрипка',
    '🪕' => 'банджо',
    '🥁' => 'барабан',
    '🪘' => 'конга',
    '🪇' => 'маракасы',
    '🪈' => 'флейта',
    '🪉' => 'арфа',
    '📱' => 'мобильный телефон',
    '📲' => 'входящий вызов',
    '☎' => 'телефон',
    '📞' => 'телефонная трубка',
    '📟' => 'пейджер',
    '📠' => 'факс',
    '🔋' => 'батарейка',
    '🪫' => 'низкий уровень заряда',
    '🔌' => 'вилка',
    '💻' => 'ноутбук',
    '🖥' => 'компьютер',
    '🖨' => 'принтер',
    '⌨' => 'клавиатура',
    '🖱' => 'мышка',
    '🖲' => 'трекбол',
    '💽' => 'диск',
    '💾' => 'дискета',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🧮' => 'счеты',
    '🎥' => 'кинокамера',
    '🎞' => 'кинопленка',
    '📽' => 'кинопроектор',
    '🎬' => 'хлопушка-нумератор',
    '📺' => 'телевизор',
    '📷' => 'фотоаппарат',
    '📸' => 'фотоаппарат со вспышкой',
    '📹' => 'видеокамера',
    '📼' => 'видеокассета',
    '🔍' => 'лупа, наклоненная влево',
    '🔎' => 'лупа, наклоненная вправо',
    '🕯' => 'свеча',
    '💡' => 'лампочка',
    '🔦' => 'фонарик',
    '🏮' => 'красный бумажный фонарик',
    '🪔' => 'масляная лампа',
    '📔' => 'записная книжка',
    '📕' => 'закрытая книга',
    '📖' => 'открытая книга',
    '📗' => 'зеленая книга',
    '📘' => 'синяя книга',
    '📙' => 'оранжевая книга',
    '📚' => 'книги',
    '📓' => 'тетрадь',
    '📒' => 'блокнот',
    '📃' => 'страница с загибом',
    '📜' => 'свиток',
    '📄' => 'страница',
    '📰' => 'газета',
    '🗞' => 'свернутая газета',
    '📑' => 'стикеры-закладки',
    '🔖' => 'закладка',
    '🏷' => 'бирка',
    '🪙' => 'монета',
    '💰' => 'мешок денег',
    '🪎' => 'сундук с сокровищами',
    '💴' => 'банкнота иены',
    '💵' => 'банкнота доллара',
    '💶' => 'банкнота евро',
    '💷' => 'банкнота фунта',
    '💸' => 'банкнота с крылышками',
    '💳' => 'кредитная карта',
    '🧾' => 'чек',
    '💹' => 'биржа',
    '✉' => 'конверт',
    '📧' => 'электронная почта',
    '📨' => 'входящее письмо',
    '📩' => 'исходящее письмо',
    '📤' => 'исходящие',
    '📥' => 'входящие',
    '📦' => 'посылка',
    '📫' => 'закрытый почтовый ящик с поднятым флажком',
    '📪' => 'закрытый почтовый ящик с опущенным флажком',
    '📬' => 'открытый почтовый ящик с поднятым флажком',
    '📭' => 'открытый почтовый ящик с опущенным флажком',
    '📮' => 'почтовый ящик',
    '🗳' => 'избирательная урна',
    '✏' => 'карандаш',
    '✒' => 'перьевой наконечник',
    '🖋' => 'перьевая ручка',
    '🖊' => 'шариковая ручка',
    '🖌' => 'кисточка',
    '🖍' => 'восковой мелок',
    '📝' => 'заметка',
    '💼' => 'портфель',
    '📁' => 'папка',
    '📂' => 'открытая папка',
    '🗂' => 'маркированные папки',
    '📅' => 'календарь',
    '📆' => 'отрывной календарь',
    '🗒' => 'перекидной блокнот',
    '🗓' => 'перекидной календарь',
    '📇' => 'органайзер',
    '📈' => 'диаграмма роста',
    '📉' => 'диаграмма падения',
    '📊' => 'гистограмма',
    '📋' => 'планшет с зажимом',
    '📌' => 'канцелярская кнопка',
    '📍' => 'канцелярская кнопка с шариком',
    '📎' => 'скрепка',
    '🖇' => 'скрепки',
    '📏' => 'линейка',
    '📐' => 'линейка-треугольник',
    '✂' => 'ножницы',
    '🗃' => 'картотека',
    '🗄' => 'архивный шкаф',
    '🗑' => 'корзина для мусора',
    '🔒' => 'закрытый замок',
    '🔓' => 'открытый замок',
    '🔏' => 'закрытый замок с перьевой ручкой',
    '🔐' => 'закрытый замок с ключом',
    '🔑' => 'ключ',
    '🗝' => 'старинный ключ',
    '🔨' => 'молоток',
    '🪓' => 'топор',
    '⛏' => 'кирка',
    '⚒' => 'кирка и молот',
    '🛠' => 'молот и гаечный ключ',
    '🗡' => 'кинжал',
    '⚔' => 'скрещенные мечи',
    '💣' => 'бомба',
    '🪃' => 'бумеранг',
    '🏹' => 'лук со стрелой',
    '🛡' => 'щит',
    '🪚' => 'пила по дереву',
    '🔧' => 'гаечный ключ',
    '🪛' => 'отвертка',
    '🔩' => 'болт и гайка',
    '⚙' => 'шестеренка',
    '🗜' => 'компрессор',
    '⚖' => 'весы',
    '🦯' => 'белая трость',
    '🔗' => 'гиперссылка',
    '⛓' => 'цепь',
    '🪝' => 'крюк',
    '🧰' => 'ящик для инструментов',
    '🧲' => 'магнит',
    '🪜' => 'лестница',
    '🪏' => 'лопата',
    '⚗' => 'перегонный сосуд',
    '🧪' => 'пробирка',
    '🧫' => 'чашка Петри',
    '🧬' => 'ДНК',
    '🔬' => 'микроскоп',
    '🔭' => 'телескоп',
    '📡' => 'спутниковая антенна',
    '💉' => 'шприц',
    '🩸' => 'капля крови',
    '💊' => 'пилюля',
    '🩹' => 'пластырь',
    '🩼' => 'костыль',
    '🩺' => 'стетоскоп',
    '🩻' => 'рентген',
    '🚪' => 'дверь',
    '🛗' => 'лифт',
    '🪞' => 'зеркало',
    '🪟' => 'окно',
    '🛏' => 'кровать',
    '🛋' => 'диван и торшер',
    '🪑' => 'стул',
    '🚽' => 'унитаз',
    '🪠' => 'вантуз',
    '🚿' => 'душ',
    '🛁' => 'ванна',
    '🪤' => 'мышеловка',
    '🪒' => 'бритва',
    '🧴' => 'бутылка лосьона',
    '🧷' => 'английская булавка',
    '🧹' => 'метла',
    '🧺' => 'корзина',
    '🧻' => 'рулон бумаги',
    '🪣' => 'ведро',
    '🧼' => 'мыло',
    '🫧' => 'пузыри',
    '🪥' => 'зубная щетка',
    '🧽' => 'губка',
    '🧯' => 'огнетушитель',
    '🛒' => 'тележка для покупок',
    '🚬' => 'сигарета',
    '⚰' => 'гроб',
    '🪦' => 'надгробие',
    '⚱' => 'урна с прахом',
    '🧿' => 'назар бонджук',
    '🪬' => 'хамса',
    '🗿' => 'истукан',
    '🪧' => 'плакат',
    '🪪' => 'удостоверение личности',
    '🏧' => 'значок банкомата',
    '🚮' => 'бросайте мусор в урну',
    '🚰' => 'питьевая вода',
    '♿' => 'значок «для инвалидов»',
    '🚹' => 'мужской туалет',
    '🚺' => 'женский туалет',
    '🚻' => 'уборная',
    '🚼' => 'пеленальная',
    '🚾' => 'туалет',
    '🛂' => 'паспортный контроль',
    '🛃' => 'таможня',
    '🛄' => 'получение багажа',
    '🛅' => 'забытый багаж',
    '⚠' => 'значок предупреждения',
    '🚸' => 'знак «дети»',
    '⛔' => 'въезд запрещен',
    '🚫' => 'запрещено',
    '🚳' => 'перечеркнутый велосипед',
    '🚭' => 'курение запрещено',
    '🚯' => 'не мусорьте',
    '🚱' => 'непитьевая вода',
    '🚷' => 'переход запрещен',
    '📵' => 'мобильные телефоны запрещены',
    '🔞' => 'для людей старше восемнадцати лет',
    '☢' => 'радиация',
    '☣' => 'биологическая угроза',
    '⬆' => 'стрелка вверх',
    '↗' => 'стрелка вправо-вверх',
    '➡' => 'стрелка вправо',
    '↘' => 'стрелка вправо-вниз',
    '⬇' => 'стрелка вниз',
    '↙' => 'стрелка влево-вниз',
    '⬅' => 'стрелка влево',
    '↖' => 'стрелка влево-вверх',
    '↕' => 'стрелка вверх-вниз',
    '↔' => 'стрелка влево-вправо',
    '↩' => 'стрелка вправо с поворотом влево',
    '↪' => 'стрелка влево с поворотом вправо',
    '⤴' => 'стрелка вправо с поворотом вверх',
    '⤵' => 'стрелка вправо с поворотом вниз',
    '🔃' => 'по часовой стрелке',
    '🔄' => 'против часовой стрелки',
    '🔙' => 'стрелка «назад»',
    '🔚' => 'стрелка «конец»',
    '🔛' => 'стрелка «активно»',
    '🔜' => 'стрелка «скоро»',
    '🔝' => 'стрелка «верх»',
    '🛐' => 'религия',
    '⚛' => 'символ атома',
    '🕉' => 'ом',
    '✡' => 'звезда Давида',
    '☸' => 'колесо дхармы',
    '☯' => 'инь-ян',
    '✝' => 'латинский крест',
    '☦' => 'православный крест',
    '☪' => 'звезда и полумесяц',
    '☮' => 'пацифик',
    '🕎' => 'менора',
    '🔯' => 'шестиконечная звезда',
    '🪯' => 'кханда',
    '♈' => 'знак зодиака Овен',
    '♉' => 'знак зодиака Телец',
    '♊' => 'знак зодиака Близнецы',
    '♋' => 'знак зодиака Рак',
    '♌' => 'знак зодиака Лев',
    '♍' => 'знак зодиака Дева',
    '♎' => 'знак зодиака Весы',
    '♏' => 'знак зодиака Скорпион',
    '♐' => 'знак зодиака Стрелец',
    '♑' => 'знак зодиака Козерог',
    '♒' => 'знак зодиака Водолей',
    '♓' => 'знак зодиака Рыбы',
    '⛎' => 'знак зодиака Змееносец',
    '🔀' => 'случайный выбор',
    '🔁' => 'повтор',
    '🔂' => 'повтор одной песни',
    '▶' => 'воспроизведение',
    '⏩' => 'перемотка вперед',
    '⏭' => 'следующий трек',
    '⏯' => 'воспроизведение/пауза',
    '◀' => 'реверс',
    '⏪' => 'перемотка назад',
    '⏮' => 'предыдущий трек',
    '🔼' => 'треугольник острием вверх',
    '⏫' => 'два треугольника острием вверх',
    '🔽' => 'треугольник острием вниз',
    '⏬' => 'два треугольника острием вниз',
    '⏸' => 'пауза',
    '⏹' => 'стоп',
    '⏺' => 'запись',
    '⏏' => 'выброс',
    '🎦' => 'видеозапись',
    '🔅' => 'низкая яркость',
    '🔆' => 'высокая яркость',
    '📶' => 'сигнал сети',
    '🛜' => 'беспроводная сеть',
    '📳' => 'режим вибрации',
    '📴' => 'выключенный телефон',
    '♀' => 'женский символ',
    '♂' => 'мужской символ',
    '⚧' => 'трансгендер',
    '✖' => 'знак умножения',
    '➕' => 'знак сложения',
    '➖' => 'знак вычитания',
    '➗' => 'знак деления',
    '🟰' => 'жирный знак равенства',
    '♾' => 'бесконечность',
    '‼' => 'два восклицательных знака',
    '⁉' => 'восклицательный и вопросительный знаки',
    '❓' => 'красный вопросительный знак',
    '❔' => 'белый вопросительный знак',
    '❕' => 'белый восклицательный знак',
    '❗' => 'красный восклицательный знак',
    '〰' => 'волнистая линия',
    '💱' => 'обмен валюты',
    '💲' => 'жирный знак доллара',
    '⚕' => 'медицинский символ',
    '♻' => 'утилизация',
    '⚜' => 'геральдическая лилия',
    '🔱' => 'трезубец',
    '📛' => 'бейдж',
    '🔰' => 'символ новичка',
    '⭕' => 'красное кольцо',
    '✅' => 'белая галочка',
    '☑' => 'галочка в квадрате',
    '✔' => 'галочка',
    '❌' => 'крестик',
    '❎' => 'кнопка «крестик»',
    '➰' => 'петля',
    '➿' => 'двойная петля',
    '〽' => 'вступает другой голос',
    '✳' => 'восьмиконечная звездочка',
    '✴' => 'восьмиконечная звезда',
    '❇' => 'искра',
    '™' => 'товарный знак',
    '🫟' => 'клякса',
    '🔠' => 'ввод прописными',
    '🔡' => 'ввод строчными',
    '🔢' => 'ввод цифр',
    '🔣' => 'ввод символов',
    '🔤' => 'ввод латиницей',
    '🅰' => 'II группа крови',
    '🆎' => 'IV группа крови',
    '🅱' => 'III группа крови',
    '🆑' => 'кнопка «очистить»',
    '🆒' => 'значок «круто»',
    '🆓' => 'значок «бесплатно»',
    'ℹ' => 'значок информации',
    '🆔' => 'значок «идентификация»',
    'Ⓜ' => 'буква «м» в кружке',
    '🆕' => 'значок «новинка»',
    '🆖' => 'значок «не годится»',
    '🅾' => 'I группа крови',
    '🆗' => 'значок «ОК»',
    '🅿' => 'парковка',
    '🆘' => 'значок SOS',
    '🆙' => 'значок «обновление»',
    '🆚' => 'значок «против»',
    '🈁' => 'значок «здесь»',
    '🈂' => 'цена услуги',
    '🈷' => 'месяц',
    '🈶' => 'платно',
    '🈯' => 'забронировано',
    '🉐' => 'удачная сделка',
    '🈹' => 'скидка',
    '🈚' => 'бесплатно',
    '🈲' => 'запрет',
    '🉑' => 'допустимость',
    '🈸' => 'заявка',
    '🈴' => 'проходной балл',
    '🈳' => 'есть места',
    '㊗' => 'поздравление',
    '㊙' => 'секрет',
    '🈺' => 'открыто',
    '🈵' => 'нет мест',
    '🔴' => 'красный круг',
    '🟠' => 'оранжевый круг',
    '🟡' => 'желтый круг',
    '🟢' => 'зеленый круг',
    '🔵' => 'голубой круг',
    '🟣' => 'фиолетовый круг',
    '🟤' => 'коричневый круг',
    '⚫' => 'черный круг',
    '⚪' => 'белый круг',
    '🟥' => 'красный квадрат',
    '🟧' => 'оранжевый квадрат',
    '🟨' => 'желтый квадрат',
    '🟩' => 'зеленый квадрат',
    '🟦' => 'синий квадрат',
    '🟪' => 'фиолетовый квадрат',
    '🟫' => 'коричневый квадрат',
    '⬛' => 'большой черный квадрат',
    '⬜' => 'большой белый квадрат',
    '◼' => 'черный квадрат',
    '◻' => 'белый квадрат',
    '◾' => 'небольшой черный квадрат',
    '◽' => 'небольшой белый квадрат',
    '▪' => 'черный квадратик',
    '▫' => 'белый квадратик',
    '🔶' => 'большой оранжевый ромб',
    '🔷' => 'большой голубой ромб',
    '🔸' => 'небольшой оранжевый ромб',
    '🔹' => 'небольшой голубой ромб',
    '🔺' => 'треугольник вершиной вверх',
    '🔻' => 'треугольник вершиной вниз',
    '💠' => 'ромб с точкой',
    '🔘' => 'круглая кнопка',
    '🔳' => 'кнопка с белой рамкой',
    '🔲' => 'кнопка с черной рамкой',
    '🏁' => 'клетчатый флаг',
    '🚩' => 'треугольный флаг',
    '🎌' => 'скрещенные флаги',
    '🏴' => 'черный флаг',
    '🏳' => 'белый флаг',
];
