<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'shumis: qof, qof, jidh fudud, jidh fudud oo dhexe',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'shumis: qof, qof, jidh fudud, jidh nooc dhexe',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'shumis: qof, qof, jidh fudud, jidh nooc madaw oo dhexe',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'shumis: qof, qof, jidh fudud, jidh madaw',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'shumis: qof, qof, jidh fudud oo dhexe, jidh fudud',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'shumis: qof, qof, jidh fudud oo dhexe, jidh nooc dhexe',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'shumis: qof, qof, jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'shumis: qof, qof, jidh fudud oo dhexe, jidh madaw',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'shumis: qof, qof, jidh nooc dhexe, jidh fudud',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'shumis: qof, qof, jidh nooc dhexe, jidh fudud oo dhexe',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'shumis: qof, qof, jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'shumis: qof, qof, jidh nooc dhexe, jidh madaw',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'shumis: qof, qof, jidh nooc madaw oo dhexe, jidh fudud',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'shumis: qof, qof, jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'shumis: qof, qof, jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'shumis: qof, qof, jidh nooc madaw oo dhexe, jidh madaw',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'shumis: qof, qof, jidh madaw, jidh fudud',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'shumis: qof, qof, jidh madaw, jidh fudud oo dhexe',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'shumis: qof, qof, jidh madaw, jidh nooc dhexe',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'shumis: qof, qof, jidh madaw, jidh nooc madaw oo dhexe',
    '👨🏻‍❤‍💋‍👨🏻' => 'shumis: ninka, ninka, jidh fudud',
    '👨🏻‍❤‍💋‍👨🏼' => 'shumis: ninka, ninka, jidh fudud, jidh fudud oo dhexe',
    '👨🏻‍❤‍💋‍👨🏽' => 'shumis: ninka, ninka, jidh fudud, jidh nooc dhexe',
    '👨🏻‍❤‍💋‍👨🏾' => 'shumis: ninka, ninka, jidh fudud, jidh nooc madaw oo dhexe',
    '👨🏻‍❤‍💋‍👨🏿' => 'shumis: ninka, ninka, jidh fudud, jidh madaw',
    '👨🏼‍❤‍💋‍👨🏻' => 'shumis: ninka, ninka, jidh fudud oo dhexe, jidh fudud',
    '👨🏼‍❤‍💋‍👨🏼' => 'shumis: ninka, ninka, jidh fudud oo dhexe',
    '👨🏼‍❤‍💋‍👨🏽' => 'shumis: ninka, ninka, jidh fudud oo dhexe, jidh nooc dhexe',
    '👨🏼‍❤‍💋‍👨🏾' => 'shumis: ninka, ninka, jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👨🏼‍❤‍💋‍👨🏿' => 'shumis: ninka, ninka, jidh fudud oo dhexe, jidh madaw',
    '👨🏽‍❤‍💋‍👨🏻' => 'shumis: ninka, ninka, jidh nooc dhexe, jidh fudud',
    '👨🏽‍❤‍💋‍👨🏼' => 'shumis: ninka, ninka, jidh nooc dhexe, jidh fudud oo dhexe',
    '👨🏽‍❤‍💋‍👨🏽' => 'shumis: ninka, ninka, jidh nooc dhexe',
    '👨🏽‍❤‍💋‍👨🏾' => 'shumis: ninka, ninka, jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👨🏽‍❤‍💋‍👨🏿' => 'shumis: ninka, ninka, jidh nooc dhexe, jidh madaw',
    '👨🏾‍❤‍💋‍👨🏻' => 'shumis: ninka, ninka, jidh nooc madaw oo dhexe, jidh fudud',
    '👨🏾‍❤‍💋‍👨🏼' => 'shumis: ninka, ninka, jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👨🏾‍❤‍💋‍👨🏽' => 'shumis: ninka, ninka, jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👨🏾‍❤‍💋‍👨🏾' => 'shumis: ninka, ninka, jidh nooc madaw oo dhexe',
    '👨🏾‍❤‍💋‍👨🏿' => 'shumis: ninka, ninka, jidh nooc madaw oo dhexe, jidh madaw',
    '👨🏿‍❤‍💋‍👨🏻' => 'shumis: ninka, ninka, jidh madaw, jidh fudud',
    '👨🏿‍❤‍💋‍👨🏼' => 'shumis: ninka, ninka, jidh madaw, jidh fudud oo dhexe',
    '👨🏿‍❤‍💋‍👨🏽' => 'shumis: ninka, ninka, jidh madaw, jidh nooc dhexe',
    '👨🏿‍❤‍💋‍👨🏾' => 'shumis: ninka, ninka, jidh madaw, jidh nooc madaw oo dhexe',
    '👨🏿‍❤‍💋‍👨🏿' => 'shumis: ninka, ninka, jidh madaw',
    '👩🏻‍❤‍💋‍👨🏻' => 'shumis: naag, ninka, jidh fudud',
    '👩🏻‍❤‍💋‍👨🏼' => 'shumis: naag, ninka, jidh fudud, jidh fudud oo dhexe',
    '👩🏻‍❤‍💋‍👨🏽' => 'shumis: naag, ninka, jidh fudud, jidh nooc dhexe',
    '👩🏻‍❤‍💋‍👨🏾' => 'shumis: naag, ninka, jidh fudud, jidh nooc madaw oo dhexe',
    '👩🏻‍❤‍💋‍👨🏿' => 'shumis: naag, ninka, jidh fudud, jidh madaw',
    '👩🏼‍❤‍💋‍👨🏻' => 'shumis: naag, ninka, jidh fudud oo dhexe, jidh fudud',
    '👩🏼‍❤‍💋‍👨🏼' => 'shumis: naag, ninka, jidh fudud oo dhexe',
    '👩🏼‍❤‍💋‍👨🏽' => 'shumis: naag, ninka, jidh fudud oo dhexe, jidh nooc dhexe',
    '👩🏼‍❤‍💋‍👨🏾' => 'shumis: naag, ninka, jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👩🏼‍❤‍💋‍👨🏿' => 'shumis: naag, ninka, jidh fudud oo dhexe, jidh madaw',
    '👩🏽‍❤‍💋‍👨🏻' => 'shumis: naag, ninka, jidh nooc dhexe, jidh fudud',
    '👩🏽‍❤‍💋‍👨🏼' => 'shumis: naag, ninka, jidh nooc dhexe, jidh fudud oo dhexe',
    '👩🏽‍❤‍💋‍👨🏽' => 'shumis: naag, ninka, jidh nooc dhexe',
    '👩🏽‍❤‍💋‍👨🏾' => 'shumis: naag, ninka, jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👩🏽‍❤‍💋‍👨🏿' => 'shumis: naag, ninka, jidh nooc dhexe, jidh madaw',
    '👩🏾‍❤‍💋‍👨🏻' => 'shumis: naag, ninka, jidh nooc madaw oo dhexe, jidh fudud',
    '👩🏾‍❤‍💋‍👨🏼' => 'shumis: naag, ninka, jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👩🏾‍❤‍💋‍👨🏽' => 'shumis: naag, ninka, jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👩🏾‍❤‍💋‍👨🏾' => 'shumis: naag, ninka, jidh nooc madaw oo dhexe',
    '👩🏾‍❤‍💋‍👨🏿' => 'shumis: naag, ninka, jidh nooc madaw oo dhexe, jidh madaw',
    '👩🏿‍❤‍💋‍👨🏻' => 'shumis: naag, ninka, jidh madaw, jidh fudud',
    '👩🏿‍❤‍💋‍👨🏼' => 'shumis: naag, ninka, jidh madaw, jidh fudud oo dhexe',
    '👩🏿‍❤‍💋‍👨🏽' => 'shumis: naag, ninka, jidh madaw, jidh nooc dhexe',
    '👩🏿‍❤‍💋‍👨🏾' => 'shumis: naag, ninka, jidh madaw, jidh nooc madaw oo dhexe',
    '👩🏿‍❤‍💋‍👨🏿' => 'shumis: naag, ninka, jidh madaw',
    '👩🏻‍❤‍💋‍👩🏻' => 'shumis: naag, naag, jidh fudud',
    '👩🏻‍❤‍💋‍👩🏼' => 'shumis: naag, naag, jidh fudud, jidh fudud oo dhexe',
    '👩🏻‍❤‍💋‍👩🏽' => 'shumis: naag, naag, jidh fudud, jidh nooc dhexe',
    '👩🏻‍❤‍💋‍👩🏾' => 'shumis: naag, naag, jidh fudud, jidh nooc madaw oo dhexe',
    '👩🏻‍❤‍💋‍👩🏿' => 'shumis: naag, naag, jidh fudud, jidh madaw',
    '👩🏼‍❤‍💋‍👩🏻' => 'shumis: naag, naag, jidh fudud oo dhexe, jidh fudud',
    '👩🏼‍❤‍💋‍👩🏼' => 'shumis: naag, naag, jidh fudud oo dhexe',
    '👩🏼‍❤‍💋‍👩🏽' => 'shumis: naag, naag, jidh fudud oo dhexe, jidh nooc dhexe',
    '👩🏼‍❤‍💋‍👩🏾' => 'shumis: naag, naag, jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👩🏼‍❤‍💋‍👩🏿' => 'shumis: naag, naag, jidh fudud oo dhexe, jidh madaw',
    '👩🏽‍❤‍💋‍👩🏻' => 'shumis: naag, naag, jidh nooc dhexe, jidh fudud',
    '👩🏽‍❤‍💋‍👩🏼' => 'shumis: naag, naag, jidh nooc dhexe, jidh fudud oo dhexe',
    '👩🏽‍❤‍💋‍👩🏽' => 'shumis: naag, naag, jidh nooc dhexe',
    '👩🏽‍❤‍💋‍👩🏾' => 'shumis: naag, naag, jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👩🏽‍❤‍💋‍👩🏿' => 'shumis: naag, naag, jidh nooc dhexe, jidh madaw',
    '👩🏾‍❤‍💋‍👩🏻' => 'shumis: naag, naag, jidh nooc madaw oo dhexe, jidh fudud',
    '👩🏾‍❤‍💋‍👩🏼' => 'shumis: naag, naag, jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👩🏾‍❤‍💋‍👩🏽' => 'shumis: naag, naag, jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👩🏾‍❤‍💋‍👩🏾' => 'shumis: naag, naag, jidh nooc madaw oo dhexe',
    '👩🏾‍❤‍💋‍👩🏿' => 'shumis: naag, naag, jidh nooc madaw oo dhexe, jidh madaw',
    '👩🏿‍❤‍💋‍👩🏻' => 'shumis: naag, naag, jidh madaw, jidh fudud',
    '👩🏿‍❤‍💋‍👩🏼' => 'shumis: naag, naag, jidh madaw, jidh fudud oo dhexe',
    '👩🏿‍❤‍💋‍👩🏽' => 'shumis: naag, naag, jidh madaw, jidh nooc dhexe',
    '👩🏿‍❤‍💋‍👩🏾' => 'shumis: naag, naag, jidh madaw, jidh nooc madaw oo dhexe',
    '👩🏿‍❤‍💋‍👩🏿' => 'shumis: naag, naag, jidh madaw',
    '🧑🏻‍🫯‍🧑🏼' => 'dad lagdamaya: jidh fudud, jidh fudud oo dhexe',
    '🧑🏻‍🫯‍🧑🏽' => 'dad lagdamaya: jidh fudud, jidh nooc dhexe',
    '🧑🏻‍🫯‍🧑🏾' => 'dad lagdamaya: jidh fudud, jidh nooc madaw oo dhexe',
    '🧑🏻‍🫯‍🧑🏿' => 'dad lagdamaya: jidh fudud, jidh madaw',
    '🧑🏼‍🫯‍🧑🏻' => 'dad lagdamaya: jidh fudud oo dhexe, jidh fudud',
    '🧑🏼‍🫯‍🧑🏽' => 'dad lagdamaya: jidh fudud oo dhexe, jidh nooc dhexe',
    '🧑🏼‍🫯‍🧑🏾' => 'dad lagdamaya: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '🧑🏼‍🫯‍🧑🏿' => 'dad lagdamaya: jidh fudud oo dhexe, jidh madaw',
    '🧑🏽‍🫯‍🧑🏻' => 'dad lagdamaya: jidh nooc dhexe, jidh fudud',
    '🧑🏽‍🫯‍🧑🏼' => 'dad lagdamaya: jidh nooc dhexe, jidh fudud oo dhexe',
    '🧑🏽‍🫯‍🧑🏾' => 'dad lagdamaya: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '🧑🏽‍🫯‍🧑🏿' => 'dad lagdamaya: jidh nooc dhexe, jidh madaw',
    '🧑🏾‍🫯‍🧑🏻' => 'dad lagdamaya: jidh nooc madaw oo dhexe, jidh fudud',
    '🧑🏾‍🫯‍🧑🏼' => 'dad lagdamaya: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '🧑🏾‍🫯‍🧑🏽' => 'dad lagdamaya: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '🧑🏾‍🫯‍🧑🏿' => 'dad lagdamaya: jidh nooc madaw oo dhexe, jidh madaw',
    '🧑🏿‍🫯‍🧑🏻' => 'dad lagdamaya: jidh madaw, jidh fudud',
    '🧑🏿‍🫯‍🧑🏼' => 'dad lagdamaya: jidh madaw, jidh fudud oo dhexe',
    '🧑🏿‍🫯‍🧑🏽' => 'dad lagdamaya: jidh madaw, jidh nooc dhexe',
    '🧑🏿‍🫯‍🧑🏾' => 'dad lagdamaya: jidh madaw, jidh nooc madaw oo dhexe',
    '🧑🏻‍❤‍🧑🏼' => 'lammaane is jecel: qof, qof, jidh fudud, jidh fudud oo dhexe',
    '🧑🏻‍❤‍🧑🏽' => 'lammaane is jecel: qof, qof, jidh fudud, jidh nooc dhexe',
    '🧑🏻‍❤‍🧑🏾' => 'lammaane is jecel: qof, qof, jidh fudud, jidh nooc madaw oo dhexe',
    '🧑🏻‍❤‍🧑🏿' => 'lammaane is jecel: qof, qof, jidh fudud, jidh madaw',
    '🧑🏼‍❤‍🧑🏻' => 'lammaane is jecel: qof, qof, jidh fudud oo dhexe, jidh fudud',
    '🧑🏼‍❤‍🧑🏽' => 'lammaane is jecel: qof, qof, jidh fudud oo dhexe, jidh nooc dhexe',
    '🧑🏼‍❤‍🧑🏾' => 'lammaane is jecel: qof, qof, jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '🧑🏼‍❤‍🧑🏿' => 'lammaane is jecel: qof, qof, jidh fudud oo dhexe, jidh madaw',
    '🧑🏽‍❤‍🧑🏻' => 'lammaane is jecel: qof, qof, jidh nooc dhexe, jidh fudud',
    '🧑🏽‍❤‍🧑🏼' => 'lammaane is jecel: qof, qof, jidh nooc dhexe, jidh fudud oo dhexe',
    '🧑🏽‍❤‍🧑🏾' => 'lammaane is jecel: qof, qof, jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '🧑🏽‍❤‍🧑🏿' => 'lammaane is jecel: qof, qof, jidh nooc dhexe, jidh madaw',
    '🧑🏾‍❤‍🧑🏻' => 'lammaane is jecel: qof, qof, jidh nooc madaw oo dhexe, jidh fudud',
    '🧑🏾‍❤‍🧑🏼' => 'lammaane is jecel: qof, qof, jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '🧑🏾‍❤‍🧑🏽' => 'lammaane is jecel: qof, qof, jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '🧑🏾‍❤‍🧑🏿' => 'lammaane is jecel: qof, qof, jidh nooc madaw oo dhexe, jidh madaw',
    '🧑🏿‍❤‍🧑🏻' => 'lammaane is jecel: qof, qof, jidh madaw, jidh fudud',
    '🧑🏿‍❤‍🧑🏼' => 'lammaane is jecel: qof, qof, jidh madaw, jidh fudud oo dhexe',
    '🧑🏿‍❤‍🧑🏽' => 'lammaane is jecel: qof, qof, jidh madaw, jidh nooc dhexe',
    '🧑🏿‍❤‍🧑🏾' => 'lammaane is jecel: qof, qof, jidh madaw, jidh nooc madaw oo dhexe',
    '🧑🏻‍🐰‍🧑🏼' => 'dad leh dhaggo bakayle: jidh fudud, jidh fudud oo dhexe',
    '🧑🏻‍🐰‍🧑🏽' => 'dad leh dhaggo bakayle: jidh fudud, jidh nooc dhexe',
    '🧑🏻‍🐰‍🧑🏾' => 'dad leh dhaggo bakayle: jidh fudud, jidh nooc madaw oo dhexe',
    '🧑🏻‍🐰‍🧑🏿' => 'dad leh dhaggo bakayle: jidh fudud, jidh madaw',
    '🧑🏼‍🐰‍🧑🏻' => 'dad leh dhaggo bakayle: jidh fudud oo dhexe, jidh fudud',
    '🧑🏼‍🐰‍🧑🏽' => 'dad leh dhaggo bakayle: jidh fudud oo dhexe, jidh nooc dhexe',
    '🧑🏼‍🐰‍🧑🏾' => 'dad leh dhaggo bakayle: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '🧑🏼‍🐰‍🧑🏿' => 'dad leh dhaggo bakayle: jidh fudud oo dhexe, jidh madaw',
    '🧑🏽‍🐰‍🧑🏻' => 'dad leh dhaggo bakayle: jidh nooc dhexe, jidh fudud',
    '🧑🏽‍🐰‍🧑🏼' => 'dad leh dhaggo bakayle: jidh nooc dhexe, jidh fudud oo dhexe',
    '🧑🏽‍🐰‍🧑🏾' => 'dad leh dhaggo bakayle: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '🧑🏽‍🐰‍🧑🏿' => 'dad leh dhaggo bakayle: jidh nooc dhexe, jidh madaw',
    '🧑🏾‍🐰‍🧑🏻' => 'dad leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh fudud',
    '🧑🏾‍🐰‍🧑🏼' => 'dad leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '🧑🏾‍🐰‍🧑🏽' => 'dad leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '🧑🏾‍🐰‍🧑🏿' => 'dad leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh madaw',
    '🧑🏿‍🐰‍🧑🏻' => 'dad leh dhaggo bakayle: jidh madaw, jidh fudud',
    '🧑🏿‍🐰‍🧑🏼' => 'dad leh dhaggo bakayle: jidh madaw, jidh fudud oo dhexe',
    '🧑🏿‍🐰‍🧑🏽' => 'dad leh dhaggo bakayle: jidh madaw, jidh nooc dhexe',
    '🧑🏿‍🐰‍🧑🏾' => 'dad leh dhaggo bakayle: jidh madaw, jidh nooc madaw oo dhexe',
    '👨🏻‍🫯‍👨🏼' => 'rag lagdamaya: jidh fudud, jidh fudud oo dhexe',
    '👨🏻‍🫯‍👨🏽' => 'rag lagdamaya: jidh fudud, jidh nooc dhexe',
    '👨🏻‍🫯‍👨🏾' => 'rag lagdamaya: jidh fudud, jidh nooc madaw oo dhexe',
    '👨🏻‍🫯‍👨🏿' => 'rag lagdamaya: jidh fudud, jidh madaw',
    '👨🏼‍🫯‍👨🏻' => 'rag lagdamaya: jidh fudud oo dhexe, jidh fudud',
    '👨🏼‍🫯‍👨🏽' => 'rag lagdamaya: jidh fudud oo dhexe, jidh nooc dhexe',
    '👨🏼‍🫯‍👨🏾' => 'rag lagdamaya: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👨🏼‍🫯‍👨🏿' => 'rag lagdamaya: jidh fudud oo dhexe, jidh madaw',
    '👨🏽‍🫯‍👨🏻' => 'rag lagdamaya: jidh nooc dhexe, jidh fudud',
    '👨🏽‍🫯‍👨🏼' => 'rag lagdamaya: jidh nooc dhexe, jidh fudud oo dhexe',
    '👨🏽‍🫯‍👨🏾' => 'rag lagdamaya: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👨🏽‍🫯‍👨🏿' => 'rag lagdamaya: jidh nooc dhexe, jidh madaw',
    '👨🏾‍🫯‍👨🏻' => 'rag lagdamaya: jidh nooc madaw oo dhexe, jidh fudud',
    '👨🏾‍🫯‍👨🏼' => 'rag lagdamaya: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👨🏾‍🫯‍👨🏽' => 'rag lagdamaya: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👨🏾‍🫯‍👨🏿' => 'rag lagdamaya: jidh nooc madaw oo dhexe, jidh madaw',
    '👨🏿‍🫯‍👨🏻' => 'rag lagdamaya: jidh madaw, jidh fudud',
    '👨🏿‍🫯‍👨🏼' => 'rag lagdamaya: jidh madaw, jidh fudud oo dhexe',
    '👨🏿‍🫯‍👨🏽' => 'rag lagdamaya: jidh madaw, jidh nooc dhexe',
    '👨🏿‍🫯‍👨🏾' => 'rag lagdamaya: jidh madaw, jidh nooc madaw oo dhexe',
    '👨🏻‍❤‍👨🏻' => 'lammaane is jecel: ninka, ninka, jidh fudud',
    '👨🏻‍❤‍👨🏼' => 'lammaane is jecel: ninka, ninka, jidh fudud, jidh fudud oo dhexe',
    '👨🏻‍❤‍👨🏽' => 'lammaane is jecel: ninka, ninka, jidh fudud, jidh nooc dhexe',
    '👨🏻‍❤‍👨🏾' => 'lammaane is jecel: ninka, ninka, jidh fudud, jidh nooc madaw oo dhexe',
    '👨🏻‍❤‍👨🏿' => 'lammaane is jecel: ninka, ninka, jidh fudud, jidh madaw',
    '👨🏼‍❤‍👨🏻' => 'lammaane is jecel: ninka, ninka, jidh fudud oo dhexe, jidh fudud',
    '👨🏼‍❤‍👨🏼' => 'lammaane is jecel: ninka, ninka, jidh fudud oo dhexe',
    '👨🏼‍❤‍👨🏽' => 'lammaane is jecel: ninka, ninka, jidh fudud oo dhexe, jidh nooc dhexe',
    '👨🏼‍❤‍👨🏾' => 'lammaane is jecel: ninka, ninka, jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👨🏼‍❤‍👨🏿' => 'lammaane is jecel: ninka, ninka, jidh fudud oo dhexe, jidh madaw',
    '👨🏽‍❤‍👨🏻' => 'lammaane is jecel: ninka, ninka, jidh nooc dhexe, jidh fudud',
    '👨🏽‍❤‍👨🏼' => 'lammaane is jecel: ninka, ninka, jidh nooc dhexe, jidh fudud oo dhexe',
    '👨🏽‍❤‍👨🏽' => 'lammaane is jecel: ninka, ninka, jidh nooc dhexe',
    '👨🏽‍❤‍👨🏾' => 'lammaane is jecel: ninka, ninka, jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👨🏽‍❤‍👨🏿' => 'lammaane is jecel: ninka, ninka, jidh nooc dhexe, jidh madaw',
    '👨🏾‍❤‍👨🏻' => 'lammaane is jecel: ninka, ninka, jidh nooc madaw oo dhexe, jidh fudud',
    '👨🏾‍❤‍👨🏼' => 'lammaane is jecel: ninka, ninka, jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👨🏾‍❤‍👨🏽' => 'lammaane is jecel: ninka, ninka, jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👨🏾‍❤‍👨🏾' => 'lammaane is jecel: ninka, ninka, jidh nooc madaw oo dhexe',
    '👨🏾‍❤‍👨🏿' => 'lammaane is jecel: ninka, ninka, jidh nooc madaw oo dhexe, jidh madaw',
    '👨🏿‍❤‍👨🏻' => 'lammaane is jecel: ninka, ninka, jidh madaw, jidh fudud',
    '👨🏿‍❤‍👨🏼' => 'lammaane is jecel: ninka, ninka, jidh madaw, jidh fudud oo dhexe',
    '👨🏿‍❤‍👨🏽' => 'lammaane is jecel: ninka, ninka, jidh madaw, jidh nooc dhexe',
    '👨🏿‍❤‍👨🏾' => 'lammaane is jecel: ninka, ninka, jidh madaw, jidh nooc madaw oo dhexe',
    '👨🏿‍❤‍👨🏿' => 'lammaane is jecel: ninka, ninka, jidh madaw',
    '👨🏻‍🐰‍👨🏼' => 'rag leh dhaggo bakayle: jidh fudud, jidh fudud oo dhexe',
    '👨🏻‍🐰‍👨🏽' => 'rag leh dhaggo bakayle: jidh fudud, jidh nooc dhexe',
    '👨🏻‍🐰‍👨🏾' => 'rag leh dhaggo bakayle: jidh fudud, jidh nooc madaw oo dhexe',
    '👨🏻‍🐰‍👨🏿' => 'rag leh dhaggo bakayle: jidh fudud, jidh madaw',
    '👨🏼‍🐰‍👨🏻' => 'rag leh dhaggo bakayle: jidh fudud oo dhexe, jidh fudud',
    '👨🏼‍🐰‍👨🏽' => 'rag leh dhaggo bakayle: jidh fudud oo dhexe, jidh nooc dhexe',
    '👨🏼‍🐰‍👨🏾' => 'rag leh dhaggo bakayle: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👨🏼‍🐰‍👨🏿' => 'rag leh dhaggo bakayle: jidh fudud oo dhexe, jidh madaw',
    '👨🏽‍🐰‍👨🏻' => 'rag leh dhaggo bakayle: jidh nooc dhexe, jidh fudud',
    '👨🏽‍🐰‍👨🏼' => 'rag leh dhaggo bakayle: jidh nooc dhexe, jidh fudud oo dhexe',
    '👨🏽‍🐰‍👨🏾' => 'rag leh dhaggo bakayle: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👨🏽‍🐰‍👨🏿' => 'rag leh dhaggo bakayle: jidh nooc dhexe, jidh madaw',
    '👨🏾‍🐰‍👨🏻' => 'rag leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh fudud',
    '👨🏾‍🐰‍👨🏼' => 'rag leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👨🏾‍🐰‍👨🏽' => 'rag leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👨🏾‍🐰‍👨🏿' => 'rag leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh madaw',
    '👨🏿‍🐰‍👨🏻' => 'rag leh dhaggo bakayle: jidh madaw, jidh fudud',
    '👨🏿‍🐰‍👨🏼' => 'rag leh dhaggo bakayle: jidh madaw, jidh fudud oo dhexe',
    '👨🏿‍🐰‍👨🏽' => 'rag leh dhaggo bakayle: jidh madaw, jidh nooc dhexe',
    '👨🏿‍🐰‍👨🏾' => 'rag leh dhaggo bakayle: jidh madaw, jidh nooc madaw oo dhexe',
    '👩🏻‍🫯‍👩🏼' => 'naaga lagdamaya: jidh fudud, jidh fudud oo dhexe',
    '👩🏻‍🫯‍👩🏽' => 'naaga lagdamaya: jidh fudud, jidh nooc dhexe',
    '👩🏻‍🫯‍👩🏾' => 'naaga lagdamaya: jidh fudud, jidh nooc madaw oo dhexe',
    '👩🏻‍🫯‍👩🏿' => 'naaga lagdamaya: jidh fudud, jidh madaw',
    '👩🏼‍🫯‍👩🏻' => 'naaga lagdamaya: jidh fudud oo dhexe, jidh fudud',
    '👩🏼‍🫯‍👩🏽' => 'naaga lagdamaya: jidh fudud oo dhexe, jidh nooc dhexe',
    '👩🏼‍🫯‍👩🏾' => 'naaga lagdamaya: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👩🏼‍🫯‍👩🏿' => 'naaga lagdamaya: jidh fudud oo dhexe, jidh madaw',
    '👩🏽‍🫯‍👩🏻' => 'naaga lagdamaya: jidh nooc dhexe, jidh fudud',
    '👩🏽‍🫯‍👩🏼' => 'naaga lagdamaya: jidh nooc dhexe, jidh fudud oo dhexe',
    '👩🏽‍🫯‍👩🏾' => 'naaga lagdamaya: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👩🏽‍🫯‍👩🏿' => 'naaga lagdamaya: jidh nooc dhexe, jidh madaw',
    '👩🏾‍🫯‍👩🏻' => 'naaga lagdamaya: jidh nooc madaw oo dhexe, jidh fudud',
    '👩🏾‍🫯‍👩🏼' => 'naaga lagdamaya: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👩🏾‍🫯‍👩🏽' => 'naaga lagdamaya: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👩🏾‍🫯‍👩🏿' => 'naaga lagdamaya: jidh nooc madaw oo dhexe, jidh madaw',
    '👩🏿‍🫯‍👩🏻' => 'naaga lagdamaya: jidh madaw, jidh fudud',
    '👩🏿‍🫯‍👩🏼' => 'naaga lagdamaya: jidh madaw, jidh fudud oo dhexe',
    '👩🏿‍🫯‍👩🏽' => 'naaga lagdamaya: jidh madaw, jidh nooc dhexe',
    '👩🏿‍🫯‍👩🏾' => 'naaga lagdamaya: jidh madaw, jidh nooc madaw oo dhexe',
    '👩🏻‍❤‍👨🏻' => 'lammaane is jecel: naag, ninka, jidh fudud',
    '👩🏻‍❤‍👨🏼' => 'lammaane is jecel: naag, ninka, jidh fudud, jidh fudud oo dhexe',
    '👩🏻‍❤‍👨🏽' => 'lammaane is jecel: naag, ninka, jidh fudud, jidh nooc dhexe',
    '👩🏻‍❤‍👨🏾' => 'lammaane is jecel: naag, ninka, jidh fudud, jidh nooc madaw oo dhexe',
    '👩🏻‍❤‍👨🏿' => 'lammaane is jecel: naag, ninka, jidh fudud, jidh madaw',
    '👩🏼‍❤‍👨🏻' => 'lammaane is jecel: naag, ninka, jidh fudud oo dhexe, jidh fudud',
    '👩🏼‍❤‍👨🏼' => 'lammaane is jecel: naag, ninka, jidh fudud oo dhexe',
    '👩🏼‍❤‍👨🏽' => 'lammaane is jecel: naag, ninka, jidh fudud oo dhexe, jidh nooc dhexe',
    '👩🏼‍❤‍👨🏾' => 'lammaane is jecel: naag, ninka, jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👩🏼‍❤‍👨🏿' => 'lammaane is jecel: naag, ninka, jidh fudud oo dhexe, jidh madaw',
    '👩🏽‍❤‍👨🏻' => 'lammaane is jecel: naag, ninka, jidh nooc dhexe, jidh fudud',
    '👩🏽‍❤‍👨🏼' => 'lammaane is jecel: naag, ninka, jidh nooc dhexe, jidh fudud oo dhexe',
    '👩🏽‍❤‍👨🏽' => 'lammaane is jecel: naag, ninka, jidh nooc dhexe',
    '👩🏽‍❤‍👨🏾' => 'lammaane is jecel: naag, ninka, jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👩🏽‍❤‍👨🏿' => 'lammaane is jecel: naag, ninka, jidh nooc dhexe, jidh madaw',
    '👩🏾‍❤‍👨🏻' => 'lammaane is jecel: naag, ninka, jidh nooc madaw oo dhexe, jidh fudud',
    '👩🏾‍❤‍👨🏼' => 'lammaane is jecel: naag, ninka, jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👩🏾‍❤‍👨🏽' => 'lammaane is jecel: naag, ninka, jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👩🏾‍❤‍👨🏾' => 'lammaane is jecel: naag, ninka, jidh nooc madaw oo dhexe',
    '👩🏾‍❤‍👨🏿' => 'lammaane is jecel: naag, ninka, jidh nooc madaw oo dhexe, jidh madaw',
    '👩🏿‍❤‍👨🏻' => 'lammaane is jecel: naag, ninka, jidh madaw, jidh fudud',
    '👩🏿‍❤‍👨🏼' => 'lammaane is jecel: naag, ninka, jidh madaw, jidh fudud oo dhexe',
    '👩🏿‍❤‍👨🏽' => 'lammaane is jecel: naag, ninka, jidh madaw, jidh nooc dhexe',
    '👩🏿‍❤‍👨🏾' => 'lammaane is jecel: naag, ninka, jidh madaw, jidh nooc madaw oo dhexe',
    '👩🏿‍❤‍👨🏿' => 'lammaane is jecel: naag, ninka, jidh madaw',
    '👩🏻‍❤‍👩🏻' => 'lammaane is jecel: naag, naag, jidh fudud',
    '👩🏻‍❤‍👩🏼' => 'lammaane is jecel: naag, naag, jidh fudud, jidh fudud oo dhexe',
    '👩🏻‍❤‍👩🏽' => 'lammaane is jecel: naag, naag, jidh fudud, jidh nooc dhexe',
    '👩🏻‍❤‍👩🏾' => 'lammaane is jecel: naag, naag, jidh fudud, jidh nooc madaw oo dhexe',
    '👩🏻‍❤‍👩🏿' => 'lammaane is jecel: naag, naag, jidh fudud, jidh madaw',
    '👩🏼‍❤‍👩🏻' => 'lammaane is jecel: naag, naag, jidh fudud oo dhexe, jidh fudud',
    '👩🏼‍❤‍👩🏼' => 'lammaane is jecel: naag, naag, jidh fudud oo dhexe',
    '👩🏼‍❤‍👩🏽' => 'lammaane is jecel: naag, naag, jidh fudud oo dhexe, jidh nooc dhexe',
    '👩🏼‍❤‍👩🏾' => 'lammaane is jecel: naag, naag, jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👩🏼‍❤‍👩🏿' => 'lammaane is jecel: naag, naag, jidh fudud oo dhexe, jidh madaw',
    '👩🏽‍❤‍👩🏻' => 'lammaane is jecel: naag, naag, jidh nooc dhexe, jidh fudud',
    '👩🏽‍❤‍👩🏼' => 'lammaane is jecel: naag, naag, jidh nooc dhexe, jidh fudud oo dhexe',
    '👩🏽‍❤‍👩🏽' => 'lammaane is jecel: naag, naag, jidh nooc dhexe',
    '👩🏽‍❤‍👩🏾' => 'lammaane is jecel: naag, naag, jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👩🏽‍❤‍👩🏿' => 'lammaane is jecel: naag, naag, jidh nooc dhexe, jidh madaw',
    '👩🏾‍❤‍👩🏻' => 'lammaane is jecel: naag, naag, jidh nooc madaw oo dhexe, jidh fudud',
    '👩🏾‍❤‍👩🏼' => 'lammaane is jecel: naag, naag, jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👩🏾‍❤‍👩🏽' => 'lammaane is jecel: naag, naag, jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👩🏾‍❤‍👩🏾' => 'lammaane is jecel: naag, naag, jidh nooc madaw oo dhexe',
    '👩🏾‍❤‍👩🏿' => 'lammaane is jecel: naag, naag, jidh nooc madaw oo dhexe, jidh madaw',
    '👩🏿‍❤‍👩🏻' => 'lammaane is jecel: naag, naag, jidh madaw, jidh fudud',
    '👩🏿‍❤‍👩🏼' => 'lammaane is jecel: naag, naag, jidh madaw, jidh fudud oo dhexe',
    '👩🏿‍❤‍👩🏽' => 'lammaane is jecel: naag, naag, jidh madaw, jidh nooc dhexe',
    '👩🏿‍❤‍👩🏾' => 'lammaane is jecel: naag, naag, jidh madaw, jidh nooc madaw oo dhexe',
    '👩🏿‍❤‍👩🏿' => 'lammaane is jecel: naag, naag, jidh madaw',
    '👩🏻‍🐰‍👩🏼' => 'naag leh dhaggo bakayle: jidh fudud, jidh fudud oo dhexe',
    '👩🏻‍🐰‍👩🏽' => 'naag leh dhaggo bakayle: jidh fudud, jidh nooc dhexe',
    '👩🏻‍🐰‍👩🏾' => 'naag leh dhaggo bakayle: jidh fudud, jidh nooc madaw oo dhexe',
    '👩🏻‍🐰‍👩🏿' => 'naag leh dhaggo bakayle: jidh fudud, jidh madaw',
    '👩🏼‍🐰‍👩🏻' => 'naag leh dhaggo bakayle: jidh fudud oo dhexe, jidh fudud',
    '👩🏼‍🐰‍👩🏽' => 'naag leh dhaggo bakayle: jidh fudud oo dhexe, jidh nooc dhexe',
    '👩🏼‍🐰‍👩🏾' => 'naag leh dhaggo bakayle: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👩🏼‍🐰‍👩🏿' => 'naag leh dhaggo bakayle: jidh fudud oo dhexe, jidh madaw',
    '👩🏽‍🐰‍👩🏻' => 'naag leh dhaggo bakayle: jidh nooc dhexe, jidh fudud',
    '👩🏽‍🐰‍👩🏼' => 'naag leh dhaggo bakayle: jidh nooc dhexe, jidh fudud oo dhexe',
    '👩🏽‍🐰‍👩🏾' => 'naag leh dhaggo bakayle: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👩🏽‍🐰‍👩🏿' => 'naag leh dhaggo bakayle: jidh nooc dhexe, jidh madaw',
    '👩🏾‍🐰‍👩🏻' => 'naag leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh fudud',
    '👩🏾‍🐰‍👩🏼' => 'naag leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👩🏾‍🐰‍👩🏽' => 'naag leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👩🏾‍🐰‍👩🏿' => 'naag leh dhaggo bakayle: jidh nooc madaw oo dhexe, jidh madaw',
    '👩🏿‍🐰‍👩🏻' => 'naag leh dhaggo bakayle: jidh madaw, jidh fudud',
    '👩🏿‍🐰‍👩🏼' => 'naag leh dhaggo bakayle: jidh madaw, jidh fudud oo dhexe',
    '👩🏿‍🐰‍👩🏽' => 'naag leh dhaggo bakayle: jidh madaw, jidh nooc dhexe',
    '👩🏿‍🐰‍👩🏾' => 'naag leh dhaggo bakayle: jidh madaw, jidh nooc madaw oo dhexe',
    '🧑🏻‍🤝‍🧑🏻' => 'dad gacmaha is haysta: jidh fudud',
    '🧑🏻‍🤝‍🧑🏼' => 'dad gacmaha is haysta: jidh fudud, jidh fudud oo dhexe',
    '🧑🏻‍🤝‍🧑🏽' => 'dad gacmaha is haysta: jidh fudud, jidh nooc dhexe',
    '🧑🏻‍🤝‍🧑🏾' => 'dad gacmaha is haysta: jidh fudud, jidh nooc madaw oo dhexe',
    '🧑🏻‍🤝‍🧑🏿' => 'dad gacmaha is haysta: jidh fudud, jidh madaw',
    '🧑🏼‍🤝‍🧑🏻' => 'dad gacmaha is haysta: jidh fudud oo dhexe, jidh fudud',
    '🧑🏼‍🤝‍🧑🏼' => 'dad gacmaha is haysta: jidh fudud oo dhexe',
    '🧑🏼‍🤝‍🧑🏽' => 'dad gacmaha is haysta: jidh fudud oo dhexe, jidh nooc dhexe',
    '🧑🏼‍🤝‍🧑🏾' => 'dad gacmaha is haysta: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '🧑🏼‍🤝‍🧑🏿' => 'dad gacmaha is haysta: jidh fudud oo dhexe, jidh madaw',
    '🧑🏽‍🤝‍🧑🏻' => 'dad gacmaha is haysta: jidh nooc dhexe, jidh fudud',
    '🧑🏽‍🤝‍🧑🏼' => 'dad gacmaha is haysta: jidh nooc dhexe, jidh fudud oo dhexe',
    '🧑🏽‍🤝‍🧑🏽' => 'dad gacmaha is haysta: jidh nooc dhexe',
    '🧑🏽‍🤝‍🧑🏾' => 'dad gacmaha is haysta: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '🧑🏽‍🤝‍🧑🏿' => 'dad gacmaha is haysta: jidh nooc dhexe, jidh madaw',
    '🧑🏾‍🤝‍🧑🏻' => 'dad gacmaha is haysta: jidh nooc madaw oo dhexe, jidh fudud',
    '🧑🏾‍🤝‍🧑🏼' => 'dad gacmaha is haysta: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '🧑🏾‍🤝‍🧑🏽' => 'dad gacmaha is haysta: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '🧑🏾‍🤝‍🧑🏾' => 'dad gacmaha is haysta: jidh nooc madaw oo dhexe',
    '🧑🏾‍🤝‍🧑🏿' => 'dad gacmaha is haysta: jidh nooc madaw oo dhexe, jidh madaw',
    '🧑🏿‍🤝‍🧑🏻' => 'dad gacmaha is haysta: jidh madaw, jidh fudud',
    '🧑🏿‍🤝‍🧑🏼' => 'dad gacmaha is haysta: jidh madaw, jidh fudud oo dhexe',
    '🧑🏿‍🤝‍🧑🏽' => 'dad gacmaha is haysta: jidh madaw, jidh nooc dhexe',
    '🧑🏿‍🤝‍🧑🏾' => 'dad gacmaha is haysta: jidh madaw, jidh nooc madaw oo dhexe',
    '🧑🏿‍🤝‍🧑🏿' => 'dad gacmaha is haysta: jidh madaw',
    '👩🏻‍🤝‍👩🏼' => 'haween haysta is gacmaha: jidh fudud, jidh fudud oo dhexe',
    '👩🏻‍🤝‍👩🏽' => 'haween haysta is gacmaha: jidh fudud, jidh nooc dhexe',
    '👩🏻‍🤝‍👩🏾' => 'haween haysta is gacmaha: jidh fudud, jidh nooc madaw oo dhexe',
    '👩🏻‍🤝‍👩🏿' => 'haween haysta is gacmaha: jidh fudud, jidh madaw',
    '👩🏼‍🤝‍👩🏻' => 'haween haysta is gacmaha: jidh fudud oo dhexe, jidh fudud',
    '👩🏼‍🤝‍👩🏽' => 'haween haysta is gacmaha: jidh fudud oo dhexe, jidh nooc dhexe',
    '👩🏼‍🤝‍👩🏾' => 'haween haysta is gacmaha: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👩🏼‍🤝‍👩🏿' => 'haween haysta is gacmaha: jidh fudud oo dhexe, jidh madaw',
    '👩🏽‍🤝‍👩🏻' => 'haween haysta is gacmaha: jidh nooc dhexe, jidh fudud',
    '👩🏽‍🤝‍👩🏼' => 'haween haysta is gacmaha: jidh nooc dhexe, jidh fudud oo dhexe',
    '👩🏽‍🤝‍👩🏾' => 'haween haysta is gacmaha: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👩🏽‍🤝‍👩🏿' => 'haween haysta is gacmaha: jidh nooc dhexe, jidh madaw',
    '👩🏾‍🤝‍👩🏻' => 'haween haysta is gacmaha: jidh nooc madaw oo dhexe, jidh fudud',
    '👩🏾‍🤝‍👩🏼' => 'haween haysta is gacmaha: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👩🏾‍🤝‍👩🏽' => 'haween haysta is gacmaha: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👩🏾‍🤝‍👩🏿' => 'haween haysta is gacmaha: jidh nooc madaw oo dhexe, jidh madaw',
    '👩🏿‍🤝‍👩🏻' => 'haween haysta is gacmaha: jidh madaw, jidh fudud',
    '👩🏿‍🤝‍👩🏼' => 'haween haysta is gacmaha: jidh madaw, jidh fudud oo dhexe',
    '👩🏿‍🤝‍👩🏽' => 'haween haysta is gacmaha: jidh madaw, jidh nooc dhexe',
    '👩🏿‍🤝‍👩🏾' => 'haween haysta is gacmaha: jidh madaw, jidh nooc madaw oo dhexe',
    '👩🏻‍🤝‍👨🏼' => 'naag iyo nin gacmaha is haysta: jidh fudud, jidh fudud oo dhexe',
    '👩🏻‍🤝‍👨🏽' => 'naag iyo nin gacmaha is haysta: jidh fudud, jidh nooc dhexe',
    '👩🏻‍🤝‍👨🏾' => 'naag iyo nin gacmaha is haysta: jidh fudud, jidh nooc madaw oo dhexe',
    '👩🏻‍🤝‍👨🏿' => 'naag iyo nin gacmaha is haysta: jidh fudud, jidh madaw',
    '👩🏼‍🤝‍👨🏻' => 'naag iyo nin gacmaha is haysta: jidh fudud oo dhexe, jidh fudud',
    '👩🏼‍🤝‍👨🏽' => 'naag iyo nin gacmaha is haysta: jidh fudud oo dhexe, jidh nooc dhexe',
    '👩🏼‍🤝‍👨🏾' => 'naag iyo nin gacmaha is haysta: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👩🏼‍🤝‍👨🏿' => 'naag iyo nin gacmaha is haysta: jidh fudud oo dhexe, jidh madaw',
    '👩🏽‍🤝‍👨🏻' => 'naag iyo nin gacmaha is haysta: jidh nooc dhexe, jidh fudud',
    '👩🏽‍🤝‍👨🏼' => 'naag iyo nin gacmaha is haysta: jidh nooc dhexe, jidh fudud oo dhexe',
    '👩🏽‍🤝‍👨🏾' => 'naag iyo nin gacmaha is haysta: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👩🏽‍🤝‍👨🏿' => 'naag iyo nin gacmaha is haysta: jidh nooc dhexe, jidh madaw',
    '👩🏾‍🤝‍👨🏻' => 'naag iyo nin gacmaha is haysta: jidh nooc madaw oo dhexe, jidh fudud',
    '👩🏾‍🤝‍👨🏼' => 'naag iyo nin gacmaha is haysta: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👩🏾‍🤝‍👨🏽' => 'naag iyo nin gacmaha is haysta: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👩🏾‍🤝‍👨🏿' => 'naag iyo nin gacmaha is haysta: jidh nooc madaw oo dhexe, jidh madaw',
    '👩🏿‍🤝‍👨🏻' => 'naag iyo nin gacmaha is haysta: jidh madaw, jidh fudud',
    '👩🏿‍🤝‍👨🏼' => 'naag iyo nin gacmaha is haysta: jidh madaw, jidh fudud oo dhexe',
    '👩🏿‍🤝‍👨🏽' => 'naag iyo nin gacmaha is haysta: jidh madaw, jidh nooc dhexe',
    '👩🏿‍🤝‍👨🏾' => 'naag iyo nin gacmaha is haysta: jidh madaw, jidh nooc madaw oo dhexe',
    '👨🏻‍🤝‍👨🏼' => 'laba nin oo gacmaha is haysta: jidh fudud, jidh fudud oo dhexe',
    '👨🏻‍🤝‍👨🏽' => 'laba nin oo gacmaha is haysta: jidh fudud, jidh nooc dhexe',
    '👨🏻‍🤝‍👨🏾' => 'laba nin oo gacmaha is haysta: jidh fudud, jidh nooc madaw oo dhexe',
    '👨🏻‍🤝‍👨🏿' => 'laba nin oo gacmaha is haysta: jidh fudud, jidh madaw',
    '👨🏼‍🤝‍👨🏻' => 'laba nin oo gacmaha is haysta: jidh fudud oo dhexe, jidh fudud',
    '👨🏼‍🤝‍👨🏽' => 'laba nin oo gacmaha is haysta: jidh fudud oo dhexe, jidh nooc dhexe',
    '👨🏼‍🤝‍👨🏾' => 'laba nin oo gacmaha is haysta: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '👨🏼‍🤝‍👨🏿' => 'laba nin oo gacmaha is haysta: jidh fudud oo dhexe, jidh madaw',
    '👨🏽‍🤝‍👨🏻' => 'laba nin oo gacmaha is haysta: jidh nooc dhexe, jidh fudud',
    '👨🏽‍🤝‍👨🏼' => 'laba nin oo gacmaha is haysta: jidh nooc dhexe, jidh fudud oo dhexe',
    '👨🏽‍🤝‍👨🏾' => 'laba nin oo gacmaha is haysta: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '👨🏽‍🤝‍👨🏿' => 'laba nin oo gacmaha is haysta: jidh nooc dhexe, jidh madaw',
    '👨🏾‍🤝‍👨🏻' => 'laba nin oo gacmaha is haysta: jidh nooc madaw oo dhexe, jidh fudud',
    '👨🏾‍🤝‍👨🏼' => 'laba nin oo gacmaha is haysta: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '👨🏾‍🤝‍👨🏽' => 'laba nin oo gacmaha is haysta: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '👨🏾‍🤝‍👨🏿' => 'laba nin oo gacmaha is haysta: jidh nooc madaw oo dhexe, jidh madaw',
    '👨🏿‍🤝‍👨🏻' => 'laba nin oo gacmaha is haysta: jidh madaw, jidh fudud',
    '👨🏿‍🤝‍👨🏼' => 'laba nin oo gacmaha is haysta: jidh madaw, jidh fudud oo dhexe',
    '👨🏿‍🤝‍👨🏽' => 'laba nin oo gacmaha is haysta: jidh madaw, jidh nooc dhexe',
    '👨🏿‍🤝‍👨🏾' => 'laba nin oo gacmaha is haysta: jidh madaw, jidh nooc madaw oo dhexe',
    '👩‍❤‍💋‍👨' => 'shumis: naag, ninka',
    '👨‍❤‍💋‍👨' => 'shumis: ninka, ninka',
    '👩‍❤‍💋‍👩' => 'shumis: naag, naag',
    '👨‍👩‍👧‍👦' => 'Qooys caruur ah: ninka, naag, gabar, wiil',
    '👨‍👩‍👦‍👦' => 'Qooys caruur ah: ninka, naag, wiil, wiil',
    '👨‍👩‍👧‍👧' => 'Qooys caruur ah: ninka, naag, gabar, gabar',
    '👨‍👨‍👧‍👦' => 'Qooys caruur ah: ninka, ninka, gabar, wiil',
    '👨‍👨‍👦‍👦' => 'Qooys caruur ah: ninka, ninka, wiil, wiil',
    '👨‍👨‍👧‍👧' => 'Qooys caruur ah: ninka, ninka, gabar, gabar',
    '👩‍👩‍👧‍👦' => 'Qooys caruur ah: naag, naag, gabar, wiil',
    '👩‍👩‍👦‍👦' => 'Qooys caruur ah: naag, naag, wiil, wiil',
    '👩‍👩‍👧‍👧' => 'Qooys caruur ah: naag, naag, gabar, gabar',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'calan: Ingiriiska',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'calan: Skotland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'calan: Waalis',
    '🧑‍🧑‍🧒‍🧒' => 'qoys: qof weyn, qof weyn, ilmo, ilmo',
    '🚶🏻‍♀‍➡' => 'haweeney soconaysa: jidh fudud, midig u jeeda',
    '🚶🏼‍♀‍➡' => 'haweeney soconaysa: jidh fudud oo dhexe, midig u jeeda',
    '🚶🏽‍♀‍➡' => 'haweeney soconaysa: jidh nooc dhexe, midig u jeeda',
    '🚶🏾‍♀‍➡' => 'haweeney soconaysa: jidh nooc madaw oo dhexe, midig u jeeda',
    '🚶🏿‍♀‍➡' => 'haweeney soconaysa: jidh madaw, midig u jeeda',
    '🚶🏻‍♂‍➡' => 'nin soconaya: jidh fudud, midig u jeeda',
    '🚶🏼‍♂‍➡' => 'nin soconaya: jidh fudud oo dhexe, midig u jeeda',
    '🚶🏽‍♂‍➡' => 'nin soconaya: jidh nooc dhexe, midig u jeeda',
    '🚶🏾‍♂‍➡' => 'nin soconaya: jidh nooc madaw oo dhexe, midig u jeeda',
    '🚶🏿‍♂‍➡' => 'nin soconaya: jidh madaw, midig u jeeda',
    '🧎🏻‍♀‍➡' => 'naag jilba dhiganaysa: jidh fudud, midig u jeeda',
    '🧎🏼‍♀‍➡' => 'naag jilba dhiganaysa: jidh fudud oo dhexe, midig u jeeda',
    '🧎🏽‍♀‍➡' => 'naag jilba dhiganaysa: jidh nooc dhexe, midig u jeeda',
    '🧎🏾‍♀‍➡' => 'naag jilba dhiganaysa: jidh nooc madaw oo dhexe, midig u jeeda',
    '🧎🏿‍♀‍➡' => 'naag jilba dhiganaysa: jidh madaw, midig u jeeda',
    '🧎🏻‍♂‍➡' => 'nin jilba dhiganaya: jidh fudud, midig u jeeda',
    '🧎🏼‍♂‍➡' => 'nin jilba dhiganaya: jidh fudud oo dhexe, midig u jeeda',
    '🧎🏽‍♂‍➡' => 'nin jilba dhiganaya: jidh nooc dhexe, midig u jeeda',
    '🧎🏾‍♂‍➡' => 'nin jilba dhiganaya: jidh nooc madaw oo dhexe, midig u jeeda',
    '🧎🏿‍♂‍➡' => 'nin jilba dhiganaya: jidh madaw, midig u jeeda',
    '🧑🏻‍🦯‍➡' => 'qof wata bakoorad cas: jidh fudud, midig u jeeda',
    '🧑🏼‍🦯‍➡' => 'qof wata bakoorad cas: jidh fudud oo dhexe, midig u jeeda',
    '🧑🏽‍🦯‍➡' => 'qof wata bakoorad cas: jidh nooc dhexe, midig u jeeda',
    '🧑🏾‍🦯‍➡' => 'qof wata bakoorad cas: jidh nooc madaw oo dhexe, midig u jeeda',
    '🧑🏿‍🦯‍➡' => 'qof wata bakoorad cas: jidh madaw, midig u jeeda',
    '👨🏻‍🦯‍➡' => 'nin sita usha cad indhoolaha: jidh fudud, midig u jeeda',
    '👨🏼‍🦯‍➡' => 'nin sita usha cad indhoolaha: jidh fudud oo dhexe, midig u jeeda',
    '👨🏽‍🦯‍➡' => 'nin sita usha cad indhoolaha: jidh nooc dhexe, midig u jeeda',
    '👨🏾‍🦯‍➡' => 'nin sita usha cad indhoolaha: jidh nooc madaw oo dhexe, midig u jeeda',
    '👨🏿‍🦯‍➡' => 'nin sita usha cad indhoolaha: jidh madaw, midig u jeeda',
    '👩🏻‍🦯‍➡' => 'naag sidata usha cad indhoolaha: jidh fudud, midig u jeeda',
    '👩🏼‍🦯‍➡' => 'naag sidata usha cad indhoolaha: jidh fudud oo dhexe, midig u jeeda',
    '👩🏽‍🦯‍➡' => 'naag sidata usha cad indhoolaha: jidh nooc dhexe, midig u jeeda',
    '👩🏾‍🦯‍➡' => 'naag sidata usha cad indhoolaha: jidh nooc madaw oo dhexe, midig u jeeda',
    '👩🏿‍🦯‍➡' => 'naag sidata usha cad indhoolaha: jidh madaw, midig u jeeda',
    '🧑🏻‍🦼‍➡' => 'qof kufadhiya gaari matoor leh: jidh fudud, midig u jeeda',
    '🧑🏼‍🦼‍➡' => 'qof kufadhiya gaari matoor leh: jidh fudud oo dhexe, midig u jeeda',
    '🧑🏽‍🦼‍➡' => 'qof kufadhiya gaari matoor leh: jidh nooc dhexe, midig u jeeda',
    '🧑🏾‍🦼‍➡' => 'qof kufadhiya gaari matoor leh: jidh nooc madaw oo dhexe, midig u jeeda',
    '🧑🏿‍🦼‍➡' => 'qof kufadhiya gaari matoor leh: jidh madaw, midig u jeeda',
    '👨🏻‍🦼‍➡' => 'nin saaran kursi curyaan matoor leh: jidh fudud, midig u jeeda',
    '👨🏼‍🦼‍➡' => 'nin saaran kursi curyaan matoor leh: jidh fudud oo dhexe, midig u jeeda',
    '👨🏽‍🦼‍➡' => 'nin saaran kursi curyaan matoor leh: jidh nooc dhexe, midig u jeeda',
    '👨🏾‍🦼‍➡' => 'nin saaran kursi curyaan matoor leh: jidh nooc madaw oo dhexe, midig u jeeda',
    '👨🏿‍🦼‍➡' => 'nin saaran kursi curyaan matoor leh: jidh madaw, midig u jeeda',
    '👩🏻‍🦼‍➡' => 'gabadh saaran kursi curyaan matoor leh: jidh fudud, midig u jeeda',
    '👩🏼‍🦼‍➡' => 'gabadh saaran kursi curyaan matoor leh: jidh fudud oo dhexe, midig u jeeda',
    '👩🏽‍🦼‍➡' => 'gabadh saaran kursi curyaan matoor leh: jidh nooc dhexe, midig u jeeda',
    '👩🏾‍🦼‍➡' => 'gabadh saaran kursi curyaan matoor leh: jidh nooc madaw oo dhexe, midig u jeeda',
    '👩🏿‍🦼‍➡' => 'gabadh saaran kursi curyaan matoor leh: jidh madaw, midig u jeeda',
    '🧑🏻‍🦽‍➡' => 'qof ku fadhiya gaari curyaanka gacanta: jidh fudud, midig u jeeda',
    '🧑🏼‍🦽‍➡' => 'qof ku fadhiya gaari curyaanka gacanta: jidh fudud oo dhexe, midig u jeeda',
    '🧑🏽‍🦽‍➡' => 'qof ku fadhiya gaari curyaanka gacanta: jidh nooc dhexe, midig u jeeda',
    '🧑🏾‍🦽‍➡' => 'qof ku fadhiya gaari curyaanka gacanta: jidh nooc madaw oo dhexe, midig u jeeda',
    '🧑🏿‍🦽‍➡' => 'qof ku fadhiya gaari curyaanka gacanta: jidh madaw, midig u jeeda',
    '👨🏻‍🦽‍➡' => 'nin saaran kursiga curyaanka macmac ah: jidh fudud, midig u jeeda',
    '👨🏼‍🦽‍➡' => 'nin saaran kursiga curyaanka macmac ah: jidh fudud oo dhexe, midig u jeeda',
    '👨🏽‍🦽‍➡' => 'nin saaran kursiga curyaanka macmac ah: jidh nooc dhexe, midig u jeeda',
    '👨🏾‍🦽‍➡' => 'nin saaran kursiga curyaanka macmac ah: jidh nooc madaw oo dhexe, midig u jeeda',
    '👨🏿‍🦽‍➡' => 'nin saaran kursiga curyaanka macmac ah: jidh madaw, midig u jeeda',
    '👩🏻‍🦽‍➡' => 'naag fadhida kursiga curyaanka macmal ah: jidh fudud, midig u jeeda',
    '👩🏼‍🦽‍➡' => 'naag fadhida kursiga curyaanka macmal ah: jidh fudud oo dhexe, midig u jeeda',
    '👩🏽‍🦽‍➡' => 'naag fadhida kursiga curyaanka macmal ah: jidh nooc dhexe, midig u jeeda',
    '👩🏾‍🦽‍➡' => 'naag fadhida kursiga curyaanka macmal ah: jidh nooc madaw oo dhexe, midig u jeeda',
    '👩🏿‍🦽‍➡' => 'naag fadhida kursiga curyaanka macmal ah: jidh madaw, midig u jeeda',
    '🏃🏻‍♀‍➡' => 'naag ordaysa: jidh fudud, midig u jeeda',
    '🏃🏼‍♀‍➡' => 'naag ordaysa: jidh fudud oo dhexe, midig u jeeda',
    '🏃🏽‍♀‍➡' => 'naag ordaysa: jidh nooc dhexe, midig u jeeda',
    '🏃🏾‍♀‍➡' => 'naag ordaysa: jidh nooc madaw oo dhexe, midig u jeeda',
    '🏃🏿‍♀‍➡' => 'naag ordaysa: jidh madaw, midig u jeeda',
    '🏃🏻‍♂‍➡' => 'nin ordaya: jidh fudud, midig u jeeda',
    '🏃🏼‍♂‍➡' => 'nin ordaya: jidh fudud oo dhexe, midig u jeeda',
    '🏃🏽‍♂‍➡' => 'nin ordaya: jidh nooc dhexe, midig u jeeda',
    '🏃🏾‍♂‍➡' => 'nin ordaya: jidh nooc madaw oo dhexe, midig u jeeda',
    '🏃🏿‍♂‍➡' => 'nin ordaya: jidh madaw, midig u jeeda',
    '🫱🏻‍🫲🏼' => 'gacan-qaadka salaanta: jidh fudud, jidh fudud oo dhexe',
    '🫱🏻‍🫲🏽' => 'gacan-qaadka salaanta: jidh fudud, jidh nooc dhexe',
    '🫱🏻‍🫲🏾' => 'gacan-qaadka salaanta: jidh fudud, jidh nooc madaw oo dhexe',
    '🫱🏻‍🫲🏿' => 'gacan-qaadka salaanta: jidh fudud, jidh madaw',
    '🫱🏼‍🫲🏻' => 'gacan-qaadka salaanta: jidh fudud oo dhexe, jidh fudud',
    '🫱🏼‍🫲🏽' => 'gacan-qaadka salaanta: jidh fudud oo dhexe, jidh nooc dhexe',
    '🫱🏼‍🫲🏾' => 'gacan-qaadka salaanta: jidh fudud oo dhexe, jidh nooc madaw oo dhexe',
    '🫱🏼‍🫲🏿' => 'gacan-qaadka salaanta: jidh fudud oo dhexe, jidh madaw',
    '🫱🏽‍🫲🏻' => 'gacan-qaadka salaanta: jidh nooc dhexe, jidh fudud',
    '🫱🏽‍🫲🏼' => 'gacan-qaadka salaanta: jidh nooc dhexe, jidh fudud oo dhexe',
    '🫱🏽‍🫲🏾' => 'gacan-qaadka salaanta: jidh nooc dhexe, jidh nooc madaw oo dhexe',
    '🫱🏽‍🫲🏿' => 'gacan-qaadka salaanta: jidh nooc dhexe, jidh madaw',
    '🫱🏾‍🫲🏻' => 'gacan-qaadka salaanta: jidh nooc madaw oo dhexe, jidh fudud',
    '🫱🏾‍🫲🏼' => 'gacan-qaadka salaanta: jidh nooc madaw oo dhexe, jidh fudud oo dhexe',
    '🫱🏾‍🫲🏽' => 'gacan-qaadka salaanta: jidh nooc madaw oo dhexe, jidh nooc dhexe',
    '🫱🏾‍🫲🏿' => 'gacan-qaadka salaanta: jidh nooc madaw oo dhexe, jidh madaw',
    '🫱🏿‍🫲🏻' => 'gacan-qaadka salaanta: jidh madaw, jidh fudud',
    '🫱🏿‍🫲🏼' => 'gacan-qaadka salaanta: jidh madaw, jidh fudud oo dhexe',
    '🫱🏿‍🫲🏽' => 'gacan-qaadka salaanta: jidh madaw, jidh nooc dhexe',
    '🫱🏿‍🫲🏾' => 'gacan-qaadka salaanta: jidh madaw, jidh nooc madaw oo dhexe',
    '🚶‍♀‍➡' => 'haweeney soconaysa: midig u jeeda',
    '🚶‍♂‍➡' => 'nin soconaya: midig u jeeda',
    '🧎‍♀‍➡' => 'naag jilba dhiganaysa: midig u jeeda',
    '🧎‍♂‍➡' => 'nin jilba dhiganaya: midig u jeeda',
    '🧑‍🦯‍➡' => 'qof wata bakoorad cas: midig u jeeda',
    '👨‍🦯‍➡' => 'nin sita usha cad indhoolaha: midig u jeeda',
    '👩‍🦯‍➡' => 'naag sidata usha cad indhoolaha: midig u jeeda',
    '🧑‍🦼‍➡' => 'qof kufadhiya gaari matoor leh: midig u jeeda',
    '👨‍🦼‍➡' => 'nin saaran kursi curyaan matoor leh: midig u jeeda',
    '👩‍🦼‍➡' => 'gabadh saaran kursi curyaan matoor leh: midig u jeeda',
    '🧑‍🦽‍➡' => 'qof ku fadhiya gaari curyaanka gacanta: midig u jeeda',
    '👨‍🦽‍➡' => 'nin saaran kursiga curyaanka macmac ah: midig u jeeda',
    '👩‍🦽‍➡' => 'naag fadhida kursiga curyaanka macmal ah: midig u jeeda',
    '🏃‍♀‍➡' => 'naag ordaysa: midig u jeeda',
    '🏃‍♂‍➡' => 'nin ordaya: midig u jeeda',
    '👩‍❤‍👨' => 'lammaane is jecel: naag, ninka',
    '👨‍❤‍👨' => 'lammaane is jecel: ninka, ninka',
    '👩‍❤‍👩' => 'lammaane is jecel: naag, naag',
    '👨‍👩‍👦' => 'Qooys caruur ah: ninka, naag, wiil',
    '👨‍👩‍👧' => 'Qooys caruur ah: ninka, naag, gabar',
    '👨‍👨‍👦' => 'Qooys caruur ah: ninka, ninka, wiil',
    '👨‍👨‍👧' => 'Qooys caruur ah: ninka, ninka, gabar',
    '👩‍👩‍👦' => 'Qooys caruur ah: naag, naag, wiil',
    '👩‍👩‍👧' => 'Qooys caruur ah: naag, naag, gabar',
    '👨‍👦‍👦' => 'Qooys caruur ah: ninka, wiil, wiil',
    '👨‍👧‍👦' => 'Qooys caruur ah: ninka, gabar, wiil',
    '👨‍👧‍👧' => 'Qooys caruur ah: ninka, gabar, gabar',
    '👩‍👦‍👦' => 'Qooys caruur ah: naag, wiil, wiil',
    '👩‍👧‍👦' => 'Qooys caruur ah: naag, gabar, wiil',
    '👩‍👧‍👧' => 'Qooys caruur ah: naag, gabar, gabar',
    '🧑‍🤝‍🧑' => 'dad gacmaha is haysta',
    '🧑‍🧑‍🧒' => 'qoys: qof weyn, qof weyn, ilmo',
    '🧑‍🧒‍🧒' => 'qoys: qof weyn, ilmo, ilmo',
    '🧑🏻‍🦰' => 'qof: jidh fudud, timo cas',
    '🧑🏼‍🦰' => 'qof: jidh fudud oo dhexe, timo cas',
    '🧑🏽‍🦰' => 'qof: jidh nooc dhexe, timo cas',
    '🧑🏾‍🦰' => 'qof: jidh nooc madaw oo dhexe, timo cas',
    '🧑🏿‍🦰' => 'qof: jidh madaw, timo cas',
    '🧑🏻‍🦱' => 'qof: jidh fudud, timo walaaqan',
    '🧑🏼‍🦱' => 'qof: jidh fudud oo dhexe, timo walaaqan',
    '🧑🏽‍🦱' => 'qof: jidh nooc dhexe, timo walaaqan',
    '🧑🏾‍🦱' => 'qof: jidh nooc madaw oo dhexe, timo walaaqan',
    '🧑🏿‍🦱' => 'qof: jidh madaw, timo walaaqan',
    '🧑🏻‍🦳' => 'qof: jidh fudud, caddaan',
    '🧑🏼‍🦳' => 'qof: jidh fudud oo dhexe, caddaan',
    '🧑🏽‍🦳' => 'qof: jidh nooc dhexe, caddaan',
    '🧑🏾‍🦳' => 'qof: jidh nooc madaw oo dhexe, caddaan',
    '🧑🏿‍🦳' => 'qof: jidh madaw, caddaan',
    '🧑🏻‍🦲' => 'qof: jidh fudud, bidaar',
    '🧑🏼‍🦲' => 'qof: jidh fudud oo dhexe, bidaar',
    '🧑🏽‍🦲' => 'qof: jidh nooc dhexe, bidaar',
    '🧑🏾‍🦲' => 'qof: jidh nooc madaw oo dhexe, bidaar',
    '🧑🏿‍🦲' => 'qof: jidh madaw, bidaar',
    '🧑🏻‍🩰' => 'qoob ka ciyaare faneed: jidh fudud',
    '🧑🏼‍🩰' => 'qoob ka ciyaare faneed: jidh fudud oo dhexe',
    '🧑🏽‍🩰' => 'qoob ka ciyaare faneed: jidh nooc dhexe',
    '🧑🏾‍🩰' => 'qoob ka ciyaare faneed: jidh nooc madaw oo dhexe',
    '🧑🏿‍🩰' => 'qoob ka ciyaare faneed: jidh madaw',
    '🧔🏻‍♂' => 'nin: jidh fudud, gadh',
    '🧔🏼‍♂' => 'nin: jidh fudud oo dhexe, gadh',
    '🧔🏽‍♂' => 'nin: jidh nooc dhexe, gadh',
    '🧔🏾‍♂' => 'nin: jidh nooc madaw oo dhexe, gadh',
    '🧔🏿‍♂' => 'nin: jidh madaw, gadh',
    '👱🏻‍♂' => 'nin: jidh fudud, timo cad',
    '👱🏼‍♂' => 'nin: jidh fudud oo dhexe, timo cad',
    '👱🏽‍♂' => 'nin: jidh nooc dhexe, timo cad',
    '👱🏾‍♂' => 'nin: jidh nooc madaw oo dhexe, timo cad',
    '👱🏿‍♂' => 'nin: jidh madaw, timo cad',
    '👨🏻‍🦰' => 'ninka: jidh fudud, timo cas',
    '👨🏼‍🦰' => 'ninka: jidh fudud oo dhexe, timo cas',
    '👨🏽‍🦰' => 'ninka: jidh nooc dhexe, timo cas',
    '👨🏾‍🦰' => 'ninka: jidh nooc madaw oo dhexe, timo cas',
    '👨🏿‍🦰' => 'ninka: jidh madaw, timo cas',
    '👨🏻‍🦱' => 'ninka: jidh fudud, timo walaaqan',
    '👨🏼‍🦱' => 'ninka: jidh fudud oo dhexe, timo walaaqan',
    '👨🏽‍🦱' => 'ninka: jidh nooc dhexe, timo walaaqan',
    '👨🏾‍🦱' => 'ninka: jidh nooc madaw oo dhexe, timo walaaqan',
    '👨🏿‍🦱' => 'ninka: jidh madaw, timo walaaqan',
    '👨🏻‍🦳' => 'ninka: jidh fudud, caddaan',
    '👨🏼‍🦳' => 'ninka: jidh fudud oo dhexe, caddaan',
    '👨🏽‍🦳' => 'ninka: jidh nooc dhexe, caddaan',
    '👨🏾‍🦳' => 'ninka: jidh nooc madaw oo dhexe, caddaan',
    '👨🏿‍🦳' => 'ninka: jidh madaw, caddaan',
    '👨🏻‍🦲' => 'ninka: jidh fudud, bidaar',
    '👨🏼‍🦲' => 'ninka: jidh fudud oo dhexe, bidaar',
    '👨🏽‍🦲' => 'ninka: jidh nooc dhexe, bidaar',
    '👨🏾‍🦲' => 'ninka: jidh nooc madaw oo dhexe, bidaar',
    '👨🏿‍🦲' => 'ninka: jidh madaw, bidaar',
    '🧔🏻‍♀' => 'gabadh: jidh fudud, gadh',
    '🧔🏼‍♀' => 'gabadh: jidh fudud oo dhexe, gadh',
    '🧔🏽‍♀' => 'gabadh: jidh nooc dhexe, gadh',
    '🧔🏾‍♀' => 'gabadh: jidh nooc madaw oo dhexe, gadh',
    '🧔🏿‍♀' => 'gabadh: jidh madaw, gadh',
    '👱🏻‍♀' => 'naag: jidh fudud, timo cad',
    '👱🏼‍♀' => 'naag: jidh fudud oo dhexe, timo cad',
    '👱🏽‍♀' => 'naag: jidh nooc dhexe, timo cad',
    '👱🏾‍♀' => 'naag: jidh nooc madaw oo dhexe, timo cad',
    '👱🏿‍♀' => 'naag: jidh madaw, timo cad',
    '👩🏻‍🦰' => 'naag: jidh fudud, timo cas',
    '👩🏼‍🦰' => 'naag: jidh fudud oo dhexe, timo cas',
    '👩🏽‍🦰' => 'naag: jidh nooc dhexe, timo cas',
    '👩🏾‍🦰' => 'naag: jidh nooc madaw oo dhexe, timo cas',
    '👩🏿‍🦰' => 'naag: jidh madaw, timo cas',
    '👩🏻‍🦱' => 'naag: jidh fudud, timo walaaqan',
    '👩🏼‍🦱' => 'naag: jidh fudud oo dhexe, timo walaaqan',
    '👩🏽‍🦱' => 'naag: jidh nooc dhexe, timo walaaqan',
    '👩🏾‍🦱' => 'naag: jidh nooc madaw oo dhexe, timo walaaqan',
    '👩🏿‍🦱' => 'naag: jidh madaw, timo walaaqan',
    '👩🏻‍🦳' => 'naag: jidh fudud, caddaan',
    '👩🏼‍🦳' => 'naag: jidh fudud oo dhexe, caddaan',
    '👩🏽‍🦳' => 'naag: jidh nooc dhexe, caddaan',
    '👩🏾‍🦳' => 'naag: jidh nooc madaw oo dhexe, caddaan',
    '👩🏿‍🦳' => 'naag: jidh madaw, caddaan',
    '👩🏻‍🦲' => 'naag: jidh fudud, bidaar',
    '👩🏼‍🦲' => 'naag: jidh fudud oo dhexe, bidaar',
    '👩🏽‍🦲' => 'naag: jidh nooc dhexe, bidaar',
    '👩🏾‍🦲' => 'naag: jidh nooc madaw oo dhexe, bidaar',
    '👩🏿‍🦲' => 'naag: jidh madaw, bidaar',
    '🙍🏻‍♂' => 'nin wajiga kaduudaya: jidh fudud',
    '🙍🏼‍♂' => 'nin wajiga kaduudaya: jidh fudud oo dhexe',
    '🙍🏽‍♂' => 'nin wajiga kaduudaya: jidh nooc dhexe',
    '🙍🏾‍♂' => 'nin wajiga kaduudaya: jidh nooc madaw oo dhexe',
    '🙍🏿‍♂' => 'nin wajiga kaduudaya: jidh madaw',
    '🙍🏻‍♀' => 'naag wajiga kaduudaya: jidh fudud',
    '🙍🏼‍♀' => 'naag wajiga kaduudaya: jidh fudud oo dhexe',
    '🙍🏽‍♀' => 'naag wajiga kaduudaya: jidh nooc dhexe',
    '🙍🏾‍♀' => 'naag wajiga kaduudaya: jidh nooc madaw oo dhexe',
    '🙍🏿‍♀' => 'naag wajiga kaduudaya: jidh madaw',
    '🙎🏻‍♂' => 'nin bushinta qaniinaya: jidh fudud',
    '🙎🏼‍♂' => 'nin bushinta qaniinaya: jidh fudud oo dhexe',
    '🙎🏽‍♂' => 'nin bushinta qaniinaya: jidh nooc dhexe',
    '🙎🏾‍♂' => 'nin bushinta qaniinaya: jidh nooc madaw oo dhexe',
    '🙎🏿‍♂' => 'nin bushinta qaniinaya: jidh madaw',
    '🙎🏻‍♀' => 'naag bushinta qaniinaysa: jidh fudud',
    '🙎🏼‍♀' => 'naag bushinta qaniinaysa: jidh fudud oo dhexe',
    '🙎🏽‍♀' => 'naag bushinta qaniinaysa: jidh nooc dhexe',
    '🙎🏾‍♀' => 'naag bushinta qaniinaysa: jidh nooc madaw oo dhexe',
    '🙎🏿‍♀' => 'naag bushinta qaniinaysa: jidh madaw',
    '🙅🏻‍♂' => 'nin ku meedaaraya MAYA: jidh fudud',
    '🙅🏼‍♂' => 'nin ku meedaaraya MAYA: jidh fudud oo dhexe',
    '🙅🏽‍♂' => 'nin ku meedaaraya MAYA: jidh nooc dhexe',
    '🙅🏾‍♂' => 'nin ku meedaaraya MAYA: jidh nooc madaw oo dhexe',
    '🙅🏿‍♂' => 'nin ku meedaaraya MAYA: jidh madaw',
    '🙅🏻‍♀' => 'naag ku meedaaraysa MAYA: jidh fudud',
    '🙅🏼‍♀' => 'naag ku meedaaraysa MAYA: jidh fudud oo dhexe',
    '🙅🏽‍♀' => 'naag ku meedaaraysa MAYA: jidh nooc dhexe',
    '🙅🏾‍♀' => 'naag ku meedaaraysa MAYA: jidh nooc madaw oo dhexe',
    '🙅🏿‍♀' => 'naag ku meedaaraysa MAYA: jidh madaw',
    '🙆🏻‍♂' => 'nin ku meedaaraya HAA: jidh fudud',
    '🙆🏼‍♂' => 'nin ku meedaaraya HAA: jidh fudud oo dhexe',
    '🙆🏽‍♂' => 'nin ku meedaaraya HAA: jidh nooc dhexe',
    '🙆🏾‍♂' => 'nin ku meedaaraya HAA: jidh nooc madaw oo dhexe',
    '🙆🏿‍♂' => 'nin ku meedaaraya HAA: jidh madaw',
    '🙆🏻‍♀' => 'haweeney ku meedaaraysa MAYA: jidh fudud',
    '🙆🏼‍♀' => 'haweeney ku meedaaraysa MAYA: jidh fudud oo dhexe',
    '🙆🏽‍♀' => 'haweeney ku meedaaraysa MAYA: jidh nooc dhexe',
    '🙆🏾‍♀' => 'haweeney ku meedaaraysa MAYA: jidh nooc madaw oo dhexe',
    '🙆🏿‍♀' => 'haweeney ku meedaaraysa MAYA: jidh madaw',
    '💁🏻‍♂' => 'nin war bixinaya: jidh fudud',
    '💁🏼‍♂' => 'nin war bixinaya: jidh fudud oo dhexe',
    '💁🏽‍♂' => 'nin war bixinaya: jidh nooc dhexe',
    '💁🏾‍♂' => 'nin war bixinaya: jidh nooc madaw oo dhexe',
    '💁🏿‍♂' => 'nin war bixinaya: jidh madaw',
    '💁🏻‍♀' => 'naag warbixin bixinaysa: jidh fudud',
    '💁🏼‍♀' => 'naag warbixin bixinaysa: jidh fudud oo dhexe',
    '💁🏽‍♀' => 'naag warbixin bixinaysa: jidh nooc dhexe',
    '💁🏾‍♀' => 'naag warbixin bixinaysa: jidh nooc madaw oo dhexe',
    '💁🏿‍♀' => 'naag warbixin bixinaysa: jidh madaw',
    '🙋🏻‍♂' => 'nin gcan taagaya: jidh fudud',
    '🙋🏼‍♂' => 'nin gcan taagaya: jidh fudud oo dhexe',
    '🙋🏽‍♂' => 'nin gcan taagaya: jidh nooc dhexe',
    '🙋🏾‍♂' => 'nin gcan taagaya: jidh nooc madaw oo dhexe',
    '🙋🏿‍♂' => 'nin gcan taagaya: jidh madaw',
    '🙋🏻‍♀' => 'naag gacan taagaysa: jidh fudud',
    '🙋🏼‍♀' => 'naag gacan taagaysa: jidh fudud oo dhexe',
    '🙋🏽‍♀' => 'naag gacan taagaysa: jidh nooc dhexe',
    '🙋🏾‍♀' => 'naag gacan taagaysa: jidh nooc madaw oo dhexe',
    '🙋🏿‍♀' => 'naag gacan taagaysa: jidh madaw',
    '🧏🏻‍♂' => 'nin dhagoole ah: jidh fudud',
    '🧏🏼‍♂' => 'nin dhagoole ah: jidh fudud oo dhexe',
    '🧏🏽‍♂' => 'nin dhagoole ah: jidh nooc dhexe',
    '🧏🏾‍♂' => 'nin dhagoole ah: jidh nooc madaw oo dhexe',
    '🧏🏿‍♂' => 'nin dhagoole ah: jidh madaw',
    '🧏🏻‍♀' => 'naag dhagoole ah: jidh fudud',
    '🧏🏼‍♀' => 'naag dhagoole ah: jidh fudud oo dhexe',
    '🧏🏽‍♀' => 'naag dhagoole ah: jidh nooc dhexe',
    '🧏🏾‍♀' => 'naag dhagoole ah: jidh nooc madaw oo dhexe',
    '🧏🏿‍♀' => 'naag dhagoole ah: jidh madaw',
    '🙇🏻‍♂' => 'nin fooraraya: jidh fudud',
    '🙇🏼‍♂' => 'nin fooraraya: jidh fudud oo dhexe',
    '🙇🏽‍♂' => 'nin fooraraya: jidh nooc dhexe',
    '🙇🏾‍♂' => 'nin fooraraya: jidh nooc madaw oo dhexe',
    '🙇🏿‍♂' => 'nin fooraraya: jidh madaw',
    '🙇🏻‍♀' => 'naag fooraraysa: jidh fudud',
    '🙇🏼‍♀' => 'naag fooraraysa: jidh fudud oo dhexe',
    '🙇🏽‍♀' => 'naag fooraraysa: jidh nooc dhexe',
    '🙇🏾‍♀' => 'naag fooraraysa: jidh nooc madaw oo dhexe',
    '🙇🏿‍♀' => 'naag fooraraysa: jidh madaw',
    '🤦🏻‍♂' => 'nin calaacal waji saaranaya: jidh fudud',
    '🤦🏼‍♂' => 'nin calaacal waji saaranaya: jidh fudud oo dhexe',
    '🤦🏽‍♂' => 'nin calaacal waji saaranaya: jidh nooc dhexe',
    '🤦🏾‍♂' => 'nin calaacal waji saaranaya: jidh nooc madaw oo dhexe',
    '🤦🏿‍♂' => 'nin calaacal waji saaranaya: jidh madaw',
    '🤦🏻‍♀' => 'naag calaacal waji saaranaysa: jidh fudud',
    '🤦🏼‍♀' => 'naag calaacal waji saaranaysa: jidh fudud oo dhexe',
    '🤦🏽‍♀' => 'naag calaacal waji saaranaysa: jidh nooc dhexe',
    '🤦🏾‍♀' => 'naag calaacal waji saaranaysa: jidh nooc madaw oo dhexe',
    '🤦🏿‍♀' => 'naag calaacal waji saaranaysa: jidh madaw',
    '🤷🏻‍♂' => 'nin garba-ruxaya: jidh fudud',
    '🤷🏼‍♂' => 'nin garba-ruxaya: jidh fudud oo dhexe',
    '🤷🏽‍♂' => 'nin garba-ruxaya: jidh nooc dhexe',
    '🤷🏾‍♂' => 'nin garba-ruxaya: jidh nooc madaw oo dhexe',
    '🤷🏿‍♂' => 'nin garba-ruxaya: jidh madaw',
    '🤷🏻‍♀' => 'naag garba-ruxaysa: jidh fudud',
    '🤷🏼‍♀' => 'naag garba-ruxaysa: jidh fudud oo dhexe',
    '🤷🏽‍♀' => 'naag garba-ruxaysa: jidh nooc dhexe',
    '🤷🏾‍♀' => 'naag garba-ruxaysa: jidh nooc madaw oo dhexe',
    '🤷🏿‍♀' => 'naag garba-ruxaysa: jidh madaw',
    '🧑🏻‍⚕' => 'shaqaale caafimaad: jidh fudud',
    '🧑🏼‍⚕' => 'shaqaale caafimaad: jidh fudud oo dhexe',
    '🧑🏽‍⚕' => 'shaqaale caafimaad: jidh nooc dhexe',
    '🧑🏾‍⚕' => 'shaqaale caafimaad: jidh nooc madaw oo dhexe',
    '🧑🏿‍⚕' => 'shaqaale caafimaad: jidh madaw',
    '👨🏻‍⚕' => 'nin shaqaale caafimaad ah: jidh fudud',
    '👨🏼‍⚕' => 'nin shaqaale caafimaad ah: jidh fudud oo dhexe',
    '👨🏽‍⚕' => 'nin shaqaale caafimaad ah: jidh nooc dhexe',
    '👨🏾‍⚕' => 'nin shaqaale caafimaad ah: jidh nooc madaw oo dhexe',
    '👨🏿‍⚕' => 'nin shaqaale caafimaad ah: jidh madaw',
    '👩🏻‍⚕' => 'naag shaqaale caafimaad ah: jidh fudud',
    '👩🏼‍⚕' => 'naag shaqaale caafimaad ah: jidh fudud oo dhexe',
    '👩🏽‍⚕' => 'naag shaqaale caafimaad ah: jidh nooc dhexe',
    '👩🏾‍⚕' => 'naag shaqaale caafimaad ah: jidh nooc madaw oo dhexe',
    '👩🏿‍⚕' => 'naag shaqaale caafimaad ah: jidh madaw',
    '🧑🏻‍🎓' => 'arday: jidh fudud',
    '🧑🏼‍🎓' => 'arday: jidh fudud oo dhexe',
    '🧑🏽‍🎓' => 'arday: jidh nooc dhexe',
    '🧑🏾‍🎓' => 'arday: jidh nooc madaw oo dhexe',
    '🧑🏿‍🎓' => 'arday: jidh madaw',
    '👨🏻‍🎓' => 'nin arday ah: jidh fudud',
    '👨🏼‍🎓' => 'nin arday ah: jidh fudud oo dhexe',
    '👨🏽‍🎓' => 'nin arday ah: jidh nooc dhexe',
    '👨🏾‍🎓' => 'nin arday ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🎓' => 'nin arday ah: jidh madaw',
    '👩🏻‍🎓' => 'naag ardayad ah: jidh fudud',
    '👩🏼‍🎓' => 'naag ardayad ah: jidh fudud oo dhexe',
    '👩🏽‍🎓' => 'naag ardayad ah: jidh nooc dhexe',
    '👩🏾‍🎓' => 'naag ardayad ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🎓' => 'naag ardayad ah: jidh madaw',
    '🧑🏻‍🏫' => 'bare: jidh fudud',
    '🧑🏼‍🏫' => 'bare: jidh fudud oo dhexe',
    '🧑🏽‍🏫' => 'bare: jidh nooc dhexe',
    '🧑🏾‍🏫' => 'bare: jidh nooc madaw oo dhexe',
    '🧑🏿‍🏫' => 'bare: jidh madaw',
    '👨🏻‍🏫' => 'nin macallin ah: jidh fudud',
    '👨🏼‍🏫' => 'nin macallin ah: jidh fudud oo dhexe',
    '👨🏽‍🏫' => 'nin macallin ah: jidh nooc dhexe',
    '👨🏾‍🏫' => 'nin macallin ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🏫' => 'nin macallin ah: jidh madaw',
    '👩🏻‍🏫' => 'naag macallimad ah: jidh fudud',
    '👩🏼‍🏫' => 'naag macallimad ah: jidh fudud oo dhexe',
    '👩🏽‍🏫' => 'naag macallimad ah: jidh nooc dhexe',
    '👩🏾‍🏫' => 'naag macallimad ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🏫' => 'naag macallimad ah: jidh madaw',
    '🧑🏻‍⚖' => 'qaalli: jidh fudud',
    '🧑🏼‍⚖' => 'qaalli: jidh fudud oo dhexe',
    '🧑🏽‍⚖' => 'qaalli: jidh nooc dhexe',
    '🧑🏾‍⚖' => 'qaalli: jidh nooc madaw oo dhexe',
    '🧑🏿‍⚖' => 'qaalli: jidh madaw',
    '👨🏻‍⚖' => 'nin garsoore ah: jidh fudud',
    '👨🏼‍⚖' => 'nin garsoore ah: jidh fudud oo dhexe',
    '👨🏽‍⚖' => 'nin garsoore ah: jidh nooc dhexe',
    '👨🏾‍⚖' => 'nin garsoore ah: jidh nooc madaw oo dhexe',
    '👨🏿‍⚖' => 'nin garsoore ah: jidh madaw',
    '👩🏻‍⚖' => 'naag garsoore ah: jidh fudud',
    '👩🏼‍⚖' => 'naag garsoore ah: jidh fudud oo dhexe',
    '👩🏽‍⚖' => 'naag garsoore ah: jidh nooc dhexe',
    '👩🏾‍⚖' => 'naag garsoore ah: jidh nooc madaw oo dhexe',
    '👩🏿‍⚖' => 'naag garsoore ah: jidh madaw',
    '🧑🏻‍🌾' => 'Beeraley: jidh fudud',
    '🧑🏼‍🌾' => 'Beeraley: jidh fudud oo dhexe',
    '🧑🏽‍🌾' => 'Beeraley: jidh nooc dhexe',
    '🧑🏾‍🌾' => 'Beeraley: jidh nooc madaw oo dhexe',
    '🧑🏿‍🌾' => 'Beeraley: jidh madaw',
    '👨🏻‍🌾' => 'nin beeraleey ah: jidh fudud',
    '👨🏼‍🌾' => 'nin beeraleey ah: jidh fudud oo dhexe',
    '👨🏽‍🌾' => 'nin beeraleey ah: jidh nooc dhexe',
    '👨🏾‍🌾' => 'nin beeraleey ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🌾' => 'nin beeraleey ah: jidh madaw',
    '👩🏻‍🌾' => 'naag beeraleeyad ah: jidh fudud',
    '👩🏼‍🌾' => 'naag beeraleeyad ah: jidh fudud oo dhexe',
    '👩🏽‍🌾' => 'naag beeraleeyad ah: jidh nooc dhexe',
    '👩🏾‍🌾' => 'naag beeraleeyad ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🌾' => 'naag beeraleeyad ah: jidh madaw',
    '🧑🏻‍🍳' => 'cunno kariye: jidh fudud',
    '🧑🏼‍🍳' => 'cunno kariye: jidh fudud oo dhexe',
    '🧑🏽‍🍳' => 'cunno kariye: jidh nooc dhexe',
    '🧑🏾‍🍳' => 'cunno kariye: jidh nooc madaw oo dhexe',
    '🧑🏿‍🍳' => 'cunno kariye: jidh madaw',
    '👨🏻‍🍳' => 'nin kariye ah: jidh fudud',
    '👨🏼‍🍳' => 'nin kariye ah: jidh fudud oo dhexe',
    '👨🏽‍🍳' => 'nin kariye ah: jidh nooc dhexe',
    '👨🏾‍🍳' => 'nin kariye ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🍳' => 'nin kariye ah: jidh madaw',
    '👩🏻‍🍳' => 'naag kariso ah: jidh fudud',
    '👩🏼‍🍳' => 'naag kariso ah: jidh fudud oo dhexe',
    '👩🏽‍🍳' => 'naag kariso ah: jidh nooc dhexe',
    '👩🏾‍🍳' => 'naag kariso ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🍳' => 'naag kariso ah: jidh madaw',
    '🧑🏻‍🔧' => 'makaanik: jidh fudud',
    '🧑🏼‍🔧' => 'makaanik: jidh fudud oo dhexe',
    '🧑🏽‍🔧' => 'makaanik: jidh nooc dhexe',
    '🧑🏾‍🔧' => 'makaanik: jidh nooc madaw oo dhexe',
    '🧑🏿‍🔧' => 'makaanik: jidh madaw',
    '👨🏻‍🔧' => 'nin makaanik ah: jidh fudud',
    '👨🏼‍🔧' => 'nin makaanik ah: jidh fudud oo dhexe',
    '👨🏽‍🔧' => 'nin makaanik ah: jidh nooc dhexe',
    '👨🏾‍🔧' => 'nin makaanik ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🔧' => 'nin makaanik ah: jidh madaw',
    '👩🏻‍🔧' => 'naag makaanikad ah: jidh fudud',
    '👩🏼‍🔧' => 'naag makaanikad ah: jidh fudud oo dhexe',
    '👩🏽‍🔧' => 'naag makaanikad ah: jidh nooc dhexe',
    '👩🏾‍🔧' => 'naag makaanikad ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🔧' => 'naag makaanikad ah: jidh madaw',
    '🧑🏻‍🏭' => 'shaqaale warshadeed: jidh fudud',
    '🧑🏼‍🏭' => 'shaqaale warshadeed: jidh fudud oo dhexe',
    '🧑🏽‍🏭' => 'shaqaale warshadeed: jidh nooc dhexe',
    '🧑🏾‍🏭' => 'shaqaale warshadeed: jidh nooc madaw oo dhexe',
    '🧑🏿‍🏭' => 'shaqaale warshadeed: jidh madaw',
    '👨🏻‍🏭' => 'nin shaqaale warshad ah: jidh fudud',
    '👨🏼‍🏭' => 'nin shaqaale warshad ah: jidh fudud oo dhexe',
    '👨🏽‍🏭' => 'nin shaqaale warshad ah: jidh nooc dhexe',
    '👨🏾‍🏭' => 'nin shaqaale warshad ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🏭' => 'nin shaqaale warshad ah: jidh madaw',
    '👩🏻‍🏭' => 'naag shaqaale warshad ah: jidh fudud',
    '👩🏼‍🏭' => 'naag shaqaale warshad ah: jidh fudud oo dhexe',
    '👩🏽‍🏭' => 'naag shaqaale warshad ah: jidh nooc dhexe',
    '👩🏾‍🏭' => 'naag shaqaale warshad ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🏭' => 'naag shaqaale warshad ah: jidh madaw',
    '🧑🏻‍💼' => 'shaqaale xafiis: jidh fudud',
    '🧑🏼‍💼' => 'shaqaale xafiis: jidh fudud oo dhexe',
    '🧑🏽‍💼' => 'shaqaale xafiis: jidh nooc dhexe',
    '🧑🏾‍💼' => 'shaqaale xafiis: jidh nooc madaw oo dhexe',
    '🧑🏿‍💼' => 'shaqaale xafiis: jidh madaw',
    '👨🏻‍💼' => 'nin shaqaale xafiis ah: jidh fudud',
    '👨🏼‍💼' => 'nin shaqaale xafiis ah: jidh fudud oo dhexe',
    '👨🏽‍💼' => 'nin shaqaale xafiis ah: jidh nooc dhexe',
    '👨🏾‍💼' => 'nin shaqaale xafiis ah: jidh nooc madaw oo dhexe',
    '👨🏿‍💼' => 'nin shaqaale xafiis ah: jidh madaw',
    '👩🏻‍💼' => 'naag shaqaale xafiis ah: jidh fudud',
    '👩🏼‍💼' => 'naag shaqaale xafiis ah: jidh fudud oo dhexe',
    '👩🏽‍💼' => 'naag shaqaale xafiis ah: jidh nooc dhexe',
    '👩🏾‍💼' => 'naag shaqaale xafiis ah: jidh nooc madaw oo dhexe',
    '👩🏿‍💼' => 'naag shaqaale xafiis ah: jidh madaw',
    '🧑🏻‍🔬' => 'saynisyahan: jidh fudud',
    '🧑🏼‍🔬' => 'saynisyahan: jidh fudud oo dhexe',
    '🧑🏽‍🔬' => 'saynisyahan: jidh nooc dhexe',
    '🧑🏾‍🔬' => 'saynisyahan: jidh nooc madaw oo dhexe',
    '🧑🏿‍🔬' => 'saynisyahan: jidh madaw',
    '👨🏻‍🔬' => 'qabiir saynisyahan ah: jidh fudud',
    '👨🏼‍🔬' => 'qabiir saynisyahan ah: jidh fudud oo dhexe',
    '👨🏽‍🔬' => 'qabiir saynisyahan ah: jidh nooc dhexe',
    '👨🏾‍🔬' => 'qabiir saynisyahan ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🔬' => 'qabiir saynisyahan ah: jidh madaw',
    '👩🏻‍🔬' => 'haweeney cilmi sayniska taqaan: jidh fudud',
    '👩🏼‍🔬' => 'haweeney cilmi sayniska taqaan: jidh fudud oo dhexe',
    '👩🏽‍🔬' => 'haweeney cilmi sayniska taqaan: jidh nooc dhexe',
    '👩🏾‍🔬' => 'haweeney cilmi sayniska taqaan: jidh nooc madaw oo dhexe',
    '👩🏿‍🔬' => 'haweeney cilmi sayniska taqaan: jidh madaw',
    '🧑🏻‍💻' => 'Tiknoolajiste: jidh fudud',
    '🧑🏼‍💻' => 'Tiknoolajiste: jidh fudud oo dhexe',
    '🧑🏽‍💻' => 'Tiknoolajiste: jidh nooc dhexe',
    '🧑🏾‍💻' => 'Tiknoolajiste: jidh nooc madaw oo dhexe',
    '🧑🏿‍💻' => 'Tiknoolajiste: jidh madaw',
    '👨🏻‍💻' => 'nin tiknoolijiste ah: jidh fudud',
    '👨🏼‍💻' => 'nin tiknoolijiste ah: jidh fudud oo dhexe',
    '👨🏽‍💻' => 'nin tiknoolijiste ah: jidh nooc dhexe',
    '👨🏾‍💻' => 'nin tiknoolijiste ah: jidh nooc madaw oo dhexe',
    '👨🏿‍💻' => 'nin tiknoolijiste ah: jidh madaw',
    '👩🏻‍💻' => 'naag tiknoolijisate ah: jidh fudud',
    '👩🏼‍💻' => 'naag tiknoolijisate ah: jidh fudud oo dhexe',
    '👩🏽‍💻' => 'naag tiknoolijisate ah: jidh nooc dhexe',
    '👩🏾‍💻' => 'naag tiknoolijisate ah: jidh nooc madaw oo dhexe',
    '👩🏿‍💻' => 'naag tiknoolijisate ah: jidh madaw',
    '🧑🏻‍🎤' => 'heesaa: jidh fudud',
    '🧑🏼‍🎤' => 'heesaa: jidh fudud oo dhexe',
    '🧑🏽‍🎤' => 'heesaa: jidh nooc dhexe',
    '🧑🏾‍🎤' => 'heesaa: jidh nooc madaw oo dhexe',
    '🧑🏿‍🎤' => 'heesaa: jidh madaw',
    '👨🏻‍🎤' => 'nin fannaan ah: jidh fudud',
    '👨🏼‍🎤' => 'nin fannaan ah: jidh fudud oo dhexe',
    '👨🏽‍🎤' => 'nin fannaan ah: jidh nooc dhexe',
    '👨🏾‍🎤' => 'nin fannaan ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🎤' => 'nin fannaan ah: jidh madaw',
    '👩🏻‍🎤' => 'naag fannaanad ah: jidh fudud',
    '👩🏼‍🎤' => 'naag fannaanad ah: jidh fudud oo dhexe',
    '👩🏽‍🎤' => 'naag fannaanad ah: jidh nooc dhexe',
    '👩🏾‍🎤' => 'naag fannaanad ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🎤' => 'naag fannaanad ah: jidh madaw',
    '🧑🏻‍🎨' => 'fanaan: jidh fudud',
    '🧑🏼‍🎨' => 'fanaan: jidh fudud oo dhexe',
    '🧑🏽‍🎨' => 'fanaan: jidh nooc dhexe',
    '🧑🏾‍🎨' => 'fanaan: jidh nooc madaw oo dhexe',
    '🧑🏿‍🎨' => 'fanaan: jidh madaw',
    '👨🏻‍🎨' => 'nin farsama yaqaan ah: jidh fudud',
    '👨🏼‍🎨' => 'nin farsama yaqaan ah: jidh fudud oo dhexe',
    '👨🏽‍🎨' => 'nin farsama yaqaan ah: jidh nooc dhexe',
    '👨🏾‍🎨' => 'nin farsama yaqaan ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🎨' => 'nin farsama yaqaan ah: jidh madaw',
    '👩🏻‍🎨' => 'naag farsama yaqaan ah: jidh fudud',
    '👩🏼‍🎨' => 'naag farsama yaqaan ah: jidh fudud oo dhexe',
    '👩🏽‍🎨' => 'naag farsama yaqaan ah: jidh nooc dhexe',
    '👩🏾‍🎨' => 'naag farsama yaqaan ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🎨' => 'naag farsama yaqaan ah: jidh madaw',
    '🧑🏻‍✈' => 'darawal dayuurad: jidh fudud',
    '🧑🏼‍✈' => 'darawal dayuurad: jidh fudud oo dhexe',
    '🧑🏽‍✈' => 'darawal dayuurad: jidh nooc dhexe',
    '🧑🏾‍✈' => 'darawal dayuurad: jidh nooc madaw oo dhexe',
    '🧑🏿‍✈' => 'darawal dayuurad: jidh madaw',
    '👨🏻‍✈' => 'nin duuliye ah: jidh fudud',
    '👨🏼‍✈' => 'nin duuliye ah: jidh fudud oo dhexe',
    '👨🏽‍✈' => 'nin duuliye ah: jidh nooc dhexe',
    '👨🏾‍✈' => 'nin duuliye ah: jidh nooc madaw oo dhexe',
    '👨🏿‍✈' => 'nin duuliye ah: jidh madaw',
    '👩🏻‍✈' => 'naag duuliye ah: jidh fudud',
    '👩🏼‍✈' => 'naag duuliye ah: jidh fudud oo dhexe',
    '👩🏽‍✈' => 'naag duuliye ah: jidh nooc dhexe',
    '👩🏾‍✈' => 'naag duuliye ah: jidh nooc madaw oo dhexe',
    '👩🏿‍✈' => 'naag duuliye ah: jidh madaw',
    '🧑🏻‍🚀' => 'dayax u safre: jidh fudud',
    '🧑🏼‍🚀' => 'dayax u safre: jidh fudud oo dhexe',
    '🧑🏽‍🚀' => 'dayax u safre: jidh nooc dhexe',
    '🧑🏾‍🚀' => 'dayax u safre: jidh nooc madaw oo dhexe',
    '🧑🏿‍🚀' => 'dayax u safre: jidh madaw',
    '👨🏻‍🚀' => 'nin cirbixiyeen ah: jidh fudud',
    '👨🏼‍🚀' => 'nin cirbixiyeen ah: jidh fudud oo dhexe',
    '👨🏽‍🚀' => 'nin cirbixiyeen ah: jidh nooc dhexe',
    '👨🏾‍🚀' => 'nin cirbixiyeen ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🚀' => 'nin cirbixiyeen ah: jidh madaw',
    '👩🏻‍🚀' => 'naag cir bixiyeenad ah: jidh fudud',
    '👩🏼‍🚀' => 'naag cir bixiyeenad ah: jidh fudud oo dhexe',
    '👩🏽‍🚀' => 'naag cir bixiyeenad ah: jidh nooc dhexe',
    '👩🏾‍🚀' => 'naag cir bixiyeenad ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🚀' => 'naag cir bixiyeenad ah: jidh madaw',
    '🧑🏻‍🚒' => 'dab damis: jidh fudud',
    '🧑🏼‍🚒' => 'dab damis: jidh fudud oo dhexe',
    '🧑🏽‍🚒' => 'dab damis: jidh nooc dhexe',
    '🧑🏾‍🚒' => 'dab damis: jidh nooc madaw oo dhexe',
    '🧑🏿‍🚒' => 'dab damis: jidh madaw',
    '👨🏻‍🚒' => 'ninka dab-demiska ah: jidh fudud',
    '👨🏼‍🚒' => 'ninka dab-demiska ah: jidh fudud oo dhexe',
    '👨🏽‍🚒' => 'ninka dab-demiska ah: jidh nooc dhexe',
    '👨🏾‍🚒' => 'ninka dab-demiska ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🚒' => 'ninka dab-demiska ah: jidh madaw',
    '👩🏻‍🚒' => 'naag dab-demis ah: jidh fudud',
    '👩🏼‍🚒' => 'naag dab-demis ah: jidh fudud oo dhexe',
    '👩🏽‍🚒' => 'naag dab-demis ah: jidh nooc dhexe',
    '👩🏾‍🚒' => 'naag dab-demis ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🚒' => 'naag dab-demis ah: jidh madaw',
    '👮🏻‍♂' => 'nin sarkaal boolis ah: jidh fudud',
    '👮🏼‍♂' => 'nin sarkaal boolis ah: jidh fudud oo dhexe',
    '👮🏽‍♂' => 'nin sarkaal boolis ah: jidh nooc dhexe',
    '👮🏾‍♂' => 'nin sarkaal boolis ah: jidh nooc madaw oo dhexe',
    '👮🏿‍♂' => 'nin sarkaal boolis ah: jidh madaw',
    '👮🏻‍♀' => 'haweeney sarkaal boolis ah: jidh fudud',
    '👮🏼‍♀' => 'haweeney sarkaal boolis ah: jidh fudud oo dhexe',
    '👮🏽‍♀' => 'haweeney sarkaal boolis ah: jidh nooc dhexe',
    '👮🏾‍♀' => 'haweeney sarkaal boolis ah: jidh nooc madaw oo dhexe',
    '👮🏿‍♀' => 'haweeney sarkaal boolis ah: jidh madaw',
    '🕵🏻‍♂' => 'nin dambi-baare ah: jidh fudud',
    '🕵🏼‍♂' => 'nin dambi-baare ah: jidh fudud oo dhexe',
    '🕵🏽‍♂' => 'nin dambi-baare ah: jidh nooc dhexe',
    '🕵🏾‍♂' => 'nin dambi-baare ah: jidh nooc madaw oo dhexe',
    '🕵🏿‍♂' => 'nin dambi-baare ah: jidh madaw',
    '🕵🏻‍♀' => 'naag dambi-baarto ah: jidh fudud',
    '🕵🏼‍♀' => 'naag dambi-baarto ah: jidh fudud oo dhexe',
    '🕵🏽‍♀' => 'naag dambi-baarto ah: jidh nooc dhexe',
    '🕵🏾‍♀' => 'naag dambi-baarto ah: jidh nooc madaw oo dhexe',
    '🕵🏿‍♀' => 'naag dambi-baarto ah: jidh madaw',
    '💂🏻‍♂' => 'nin illaaliye ah: jidh fudud',
    '💂🏼‍♂' => 'nin illaaliye ah: jidh fudud oo dhexe',
    '💂🏽‍♂' => 'nin illaaliye ah: jidh nooc dhexe',
    '💂🏾‍♂' => 'nin illaaliye ah: jidh nooc madaw oo dhexe',
    '💂🏿‍♂' => 'nin illaaliye ah: jidh madaw',
    '💂🏻‍♀' => 'haweeney ilaaliye ah: jidh fudud',
    '💂🏼‍♀' => 'haweeney ilaaliye ah: jidh fudud oo dhexe',
    '💂🏽‍♀' => 'haweeney ilaaliye ah: jidh nooc dhexe',
    '💂🏾‍♀' => 'haweeney ilaaliye ah: jidh nooc madaw oo dhexe',
    '💂🏿‍♀' => 'haweeney ilaaliye ah: jidh madaw',
    '👷🏻‍♂' => 'nin shaqaale dhismo ah: jidh fudud',
    '👷🏼‍♂' => 'nin shaqaale dhismo ah: jidh fudud oo dhexe',
    '👷🏽‍♂' => 'nin shaqaale dhismo ah: jidh nooc dhexe',
    '👷🏾‍♂' => 'nin shaqaale dhismo ah: jidh nooc madaw oo dhexe',
    '👷🏿‍♂' => 'nin shaqaale dhismo ah: jidh madaw',
    '👷🏻‍♀' => 'naag shaqaale dhismo ah: jidh fudud',
    '👷🏼‍♀' => 'naag shaqaale dhismo ah: jidh fudud oo dhexe',
    '👷🏽‍♀' => 'naag shaqaale dhismo ah: jidh nooc dhexe',
    '👷🏾‍♀' => 'naag shaqaale dhismo ah: jidh nooc madaw oo dhexe',
    '👷🏿‍♀' => 'naag shaqaale dhismo ah: jidh madaw',
    '👳🏻‍♂' => 'nin cammaamad xiran: jidh fudud',
    '👳🏼‍♂' => 'nin cammaamad xiran: jidh fudud oo dhexe',
    '👳🏽‍♂' => 'nin cammaamad xiran: jidh nooc dhexe',
    '👳🏾‍♂' => 'nin cammaamad xiran: jidh nooc madaw oo dhexe',
    '👳🏿‍♂' => 'nin cammaamad xiran: jidh madaw',
    '👳🏻‍♀' => 'naag cammaamad xiran: jidh fudud',
    '👳🏼‍♀' => 'naag cammaamad xiran: jidh fudud oo dhexe',
    '👳🏽‍♀' => 'naag cammaamad xiran: jidh nooc dhexe',
    '👳🏾‍♀' => 'naag cammaamad xiran: jidh nooc madaw oo dhexe',
    '👳🏿‍♀' => 'naag cammaamad xiran: jidh madaw',
    '🤵🏻‍♂' => 'nin xidhan suut ka rasmiga ah: jidh fudud',
    '🤵🏼‍♂' => 'nin xidhan suut ka rasmiga ah: jidh fudud oo dhexe',
    '🤵🏽‍♂' => 'nin xidhan suut ka rasmiga ah: jidh nooc dhexe',
    '🤵🏾‍♂' => 'nin xidhan suut ka rasmiga ah: jidh nooc madaw oo dhexe',
    '🤵🏿‍♂' => 'nin xidhan suut ka rasmiga ah: jidh madaw',
    '🤵🏻‍♀' => 'gabadh xidhan suut: jidh fudud',
    '🤵🏼‍♀' => 'gabadh xidhan suut: jidh fudud oo dhexe',
    '🤵🏽‍♀' => 'gabadh xidhan suut: jidh nooc dhexe',
    '🤵🏾‍♀' => 'gabadh xidhan suut: jidh nooc madaw oo dhexe',
    '🤵🏿‍♀' => 'gabadh xidhan suut: jidh madaw',
    '👰🏻‍♂' => 'nin niqaamaban: jidh fudud',
    '👰🏼‍♂' => 'nin niqaamaban: jidh fudud oo dhexe',
    '👰🏽‍♂' => 'nin niqaamaban: jidh nooc dhexe',
    '👰🏾‍♂' => 'nin niqaamaban: jidh nooc madaw oo dhexe',
    '👰🏿‍♂' => 'nin niqaamaban: jidh madaw',
    '👰🏻‍♀' => 'naag niqaaban: jidh fudud',
    '👰🏼‍♀' => 'naag niqaaban: jidh fudud oo dhexe',
    '👰🏽‍♀' => 'naag niqaaban: jidh nooc dhexe',
    '👰🏾‍♀' => 'naag niqaaban: jidh nooc madaw oo dhexe',
    '👰🏿‍♀' => 'naag niqaaban: jidh madaw',
    '👩🏻‍🍼' => 'naag canug quudineeysa: jidh fudud',
    '👩🏼‍🍼' => 'naag canug quudineeysa: jidh fudud oo dhexe',
    '👩🏽‍🍼' => 'naag canug quudineeysa: jidh nooc dhexe',
    '👩🏾‍🍼' => 'naag canug quudineeysa: jidh nooc madaw oo dhexe',
    '👩🏿‍🍼' => 'naag canug quudineeysa: jidh madaw',
    '👨🏻‍🍼' => 'nin canug quudinaya: jidh fudud',
    '👨🏼‍🍼' => 'nin canug quudinaya: jidh fudud oo dhexe',
    '👨🏽‍🍼' => 'nin canug quudinaya: jidh nooc dhexe',
    '👨🏾‍🍼' => 'nin canug quudinaya: jidh nooc madaw oo dhexe',
    '👨🏿‍🍼' => 'nin canug quudinaya: jidh madaw',
    '🧑🏻‍🍼' => 'qof canug quudinaya: jidh fudud',
    '🧑🏼‍🍼' => 'qof canug quudinaya: jidh fudud oo dhexe',
    '🧑🏽‍🍼' => 'qof canug quudinaya: jidh nooc dhexe',
    '🧑🏾‍🍼' => 'qof canug quudinaya: jidh nooc madaw oo dhexe',
    '🧑🏿‍🍼' => 'qof canug quudinaya: jidh madaw',
    '🧑🏻‍🎄' => 'mx claus: jidh fudud',
    '🧑🏼‍🎄' => 'mx claus: jidh fudud oo dhexe',
    '🧑🏽‍🎄' => 'mx claus: jidh nooc dhexe',
    '🧑🏾‍🎄' => 'mx claus: jidh nooc madaw oo dhexe',
    '🧑🏿‍🎄' => 'mx claus: jidh madaw',
    '🦸🏻‍♂' => 'nin halyeey ah: jidh fudud',
    '🦸🏼‍♂' => 'nin halyeey ah: jidh fudud oo dhexe',
    '🦸🏽‍♂' => 'nin halyeey ah: jidh nooc dhexe',
    '🦸🏾‍♂' => 'nin halyeey ah: jidh nooc madaw oo dhexe',
    '🦸🏿‍♂' => 'nin halyeey ah: jidh madaw',
    '🦸🏻‍♀' => 'haweeney geesinnimadeedu sareeyso: jidh fudud',
    '🦸🏼‍♀' => 'haweeney geesinnimadeedu sareeyso: jidh fudud oo dhexe',
    '🦸🏽‍♀' => 'haweeney geesinnimadeedu sareeyso: jidh nooc dhexe',
    '🦸🏾‍♀' => 'haweeney geesinnimadeedu sareeyso: jidh nooc madaw oo dhexe',
    '🦸🏿‍♀' => 'haweeney geesinnimadeedu sareeyso: jidh madaw',
    '🦹🏻‍♂' => 'nin sheyddaannimadiisu sareeyso: jidh fudud',
    '🦹🏼‍♂' => 'nin sheyddaannimadiisu sareeyso: jidh fudud oo dhexe',
    '🦹🏽‍♂' => 'nin sheyddaannimadiisu sareeyso: jidh nooc dhexe',
    '🦹🏾‍♂' => 'nin sheyddaannimadiisu sareeyso: jidh nooc madaw oo dhexe',
    '🦹🏿‍♂' => 'nin sheyddaannimadiisu sareeyso: jidh madaw',
    '🦹🏻‍♀' => 'haweeney shayddaannimadeedu sareeyso: jidh fudud',
    '🦹🏼‍♀' => 'haweeney shayddaannimadeedu sareeyso: jidh fudud oo dhexe',
    '🦹🏽‍♀' => 'haweeney shayddaannimadeedu sareeyso: jidh nooc dhexe',
    '🦹🏾‍♀' => 'haweeney shayddaannimadeedu sareeyso: jidh nooc madaw oo dhexe',
    '🦹🏿‍♀' => 'haweeney shayddaannimadeedu sareeyso: jidh madaw',
    '🧙🏻‍♂' => 'nin xirfad u leh sixirka: jidh fudud',
    '🧙🏼‍♂' => 'nin xirfad u leh sixirka: jidh fudud oo dhexe',
    '🧙🏽‍♂' => 'nin xirfad u leh sixirka: jidh nooc dhexe',
    '🧙🏾‍♂' => 'nin xirfad u leh sixirka: jidh nooc madaw oo dhexe',
    '🧙🏿‍♂' => 'nin xirfad u leh sixirka: jidh madaw',
    '🧙🏻‍♀' => 'naag xirfad u leh sixirka: jidh fudud',
    '🧙🏼‍♀' => 'naag xirfad u leh sixirka: jidh fudud oo dhexe',
    '🧙🏽‍♀' => 'naag xirfad u leh sixirka: jidh nooc dhexe',
    '🧙🏾‍♀' => 'naag xirfad u leh sixirka: jidh nooc madaw oo dhexe',
    '🧙🏿‍♀' => 'naag xirfad u leh sixirka: jidh madaw',
    '🧚🏻‍♂' => 'nin qurux badan: jidh fudud',
    '🧚🏼‍♂' => 'nin qurux badan: jidh fudud oo dhexe',
    '🧚🏽‍♂' => 'nin qurux badan: jidh nooc dhexe',
    '🧚🏾‍♂' => 'nin qurux badan: jidh nooc madaw oo dhexe',
    '🧚🏿‍♂' => 'nin qurux badan: jidh madaw',
    '🧚🏻‍♀' => 'naag qurux badan: jidh fudud',
    '🧚🏼‍♀' => 'naag qurux badan: jidh fudud oo dhexe',
    '🧚🏽‍♀' => 'naag qurux badan: jidh nooc dhexe',
    '🧚🏾‍♀' => 'naag qurux badan: jidh nooc madaw oo dhexe',
    '🧚🏿‍♀' => 'naag qurux badan: jidh madaw',
    '🧛🏻‍♂' => 'nin reer-aakhiraad dhiig cab ah: jidh fudud',
    '🧛🏼‍♂' => 'nin reer-aakhiraad dhiig cab ah: jidh fudud oo dhexe',
    '🧛🏽‍♂' => 'nin reer-aakhiraad dhiig cab ah: jidh nooc dhexe',
    '🧛🏾‍♂' => 'nin reer-aakhiraad dhiig cab ah: jidh nooc madaw oo dhexe',
    '🧛🏿‍♂' => 'nin reer-aakhiraad dhiig cab ah: jidh madaw',
    '🧛🏻‍♀' => 'naag reer-aakhiraad dhiig cab ah: jidh fudud',
    '🧛🏼‍♀' => 'naag reer-aakhiraad dhiig cab ah: jidh fudud oo dhexe',
    '🧛🏽‍♀' => 'naag reer-aakhiraad dhiig cab ah: jidh nooc dhexe',
    '🧛🏾‍♀' => 'naag reer-aakhiraad dhiig cab ah: jidh nooc madaw oo dhexe',
    '🧛🏿‍♀' => 'naag reer-aakhiraad dhiig cab ah: jidh madaw',
    '🧜🏻‍♂' => 'wiilo-maanyo: jidh fudud',
    '🧜🏼‍♂' => 'wiilo-maanyo: jidh fudud oo dhexe',
    '🧜🏽‍♂' => 'wiilo-maanyo: jidh nooc dhexe',
    '🧜🏾‍♂' => 'wiilo-maanyo: jidh nooc madaw oo dhexe',
    '🧜🏿‍♂' => 'wiilo-maanyo: jidh madaw',
    '🧜🏻‍♀' => 'gabreey-maanyo: jidh fudud',
    '🧜🏼‍♀' => 'gabreey-maanyo: jidh fudud oo dhexe',
    '🧜🏽‍♀' => 'gabreey-maanyo: jidh nooc dhexe',
    '🧜🏾‍♀' => 'gabreey-maanyo: jidh nooc madaw oo dhexe',
    '🧜🏿‍♀' => 'gabreey-maanyo: jidh madaw',
    '🧝🏻‍♂' => 'ruuxaanta ragga: jidh fudud',
    '🧝🏼‍♂' => 'ruuxaanta ragga: jidh fudud oo dhexe',
    '🧝🏽‍♂' => 'ruuxaanta ragga: jidh nooc dhexe',
    '🧝🏾‍♂' => 'ruuxaanta ragga: jidh nooc madaw oo dhexe',
    '🧝🏿‍♂' => 'ruuxaanta ragga: jidh madaw',
    '🧝🏻‍♀' => 'ruuxaanta haweenka: jidh fudud',
    '🧝🏼‍♀' => 'ruuxaanta haweenka: jidh fudud oo dhexe',
    '🧝🏽‍♀' => 'ruuxaanta haweenka: jidh nooc dhexe',
    '🧝🏾‍♀' => 'ruuxaanta haweenka: jidh nooc madaw oo dhexe',
    '🧝🏿‍♀' => 'ruuxaanta haweenka: jidh madaw',
    '💆🏻‍♂' => 'nin loo duugayo: jidh fudud',
    '💆🏼‍♂' => 'nin loo duugayo: jidh fudud oo dhexe',
    '💆🏽‍♂' => 'nin loo duugayo: jidh nooc dhexe',
    '💆🏾‍♂' => 'nin loo duugayo: jidh nooc madaw oo dhexe',
    '💆🏿‍♂' => 'nin loo duugayo: jidh madaw',
    '💆🏻‍♀' => 'haweeneey loo duugayo: jidh fudud',
    '💆🏼‍♀' => 'haweeneey loo duugayo: jidh fudud oo dhexe',
    '💆🏽‍♀' => 'haweeneey loo duugayo: jidh nooc dhexe',
    '💆🏾‍♀' => 'haweeneey loo duugayo: jidh nooc madaw oo dhexe',
    '💆🏿‍♀' => 'haweeneey loo duugayo: jidh madaw',
    '💇🏻‍♂' => 'nin timaha loo jarayo: jidh fudud',
    '💇🏼‍♂' => 'nin timaha loo jarayo: jidh fudud oo dhexe',
    '💇🏽‍♂' => 'nin timaha loo jarayo: jidh nooc dhexe',
    '💇🏾‍♂' => 'nin timaha loo jarayo: jidh nooc madaw oo dhexe',
    '💇🏿‍♂' => 'nin timaha loo jarayo: jidh madaw',
    '💇🏻‍♀' => 'haweeney timaha loo jarayo: jidh fudud',
    '💇🏼‍♀' => 'haweeney timaha loo jarayo: jidh fudud oo dhexe',
    '💇🏽‍♀' => 'haweeney timaha loo jarayo: jidh nooc dhexe',
    '💇🏾‍♀' => 'haweeney timaha loo jarayo: jidh nooc madaw oo dhexe',
    '💇🏿‍♀' => 'haweeney timaha loo jarayo: jidh madaw',
    '🚶🏻‍♂' => 'nin soconaya: jidh fudud',
    '🚶🏼‍♂' => 'nin soconaya: jidh fudud oo dhexe',
    '🚶🏽‍♂' => 'nin soconaya: jidh nooc dhexe',
    '🚶🏾‍♂' => 'nin soconaya: jidh nooc madaw oo dhexe',
    '🚶🏿‍♂' => 'nin soconaya: jidh madaw',
    '🚶🏻‍♀' => 'haweeney soconaysa: jidh fudud',
    '🚶🏼‍♀' => 'haweeney soconaysa: jidh fudud oo dhexe',
    '🚶🏽‍♀' => 'haweeney soconaysa: jidh nooc dhexe',
    '🚶🏾‍♀' => 'haweeney soconaysa: jidh nooc madaw oo dhexe',
    '🚶🏿‍♀' => 'haweeney soconaysa: jidh madaw',
    '🚶🏻‍➡' => 'qof soconaya: jidh fudud, midig u jeeda',
    '🚶🏼‍➡' => 'qof soconaya: jidh fudud oo dhexe, midig u jeeda',
    '🚶🏽‍➡' => 'qof soconaya: jidh nooc dhexe, midig u jeeda',
    '🚶🏾‍➡' => 'qof soconaya: jidh nooc madaw oo dhexe, midig u jeeda',
    '🚶🏿‍➡' => 'qof soconaya: jidh madaw, midig u jeeda',
    '🧍🏻‍♂' => 'nin taaggan: jidh fudud',
    '🧍🏼‍♂' => 'nin taaggan: jidh fudud oo dhexe',
    '🧍🏽‍♂' => 'nin taaggan: jidh nooc dhexe',
    '🧍🏾‍♂' => 'nin taaggan: jidh nooc madaw oo dhexe',
    '🧍🏿‍♂' => 'nin taaggan: jidh madaw',
    '🧍🏻‍♀' => 'naag taaggan: jidh fudud',
    '🧍🏼‍♀' => 'naag taaggan: jidh fudud oo dhexe',
    '🧍🏽‍♀' => 'naag taaggan: jidh nooc dhexe',
    '🧍🏾‍♀' => 'naag taaggan: jidh nooc madaw oo dhexe',
    '🧍🏿‍♀' => 'naag taaggan: jidh madaw',
    '🧎🏻‍♂' => 'nin jilba dhiganaya: jidh fudud',
    '🧎🏼‍♂' => 'nin jilba dhiganaya: jidh fudud oo dhexe',
    '🧎🏽‍♂' => 'nin jilba dhiganaya: jidh nooc dhexe',
    '🧎🏾‍♂' => 'nin jilba dhiganaya: jidh nooc madaw oo dhexe',
    '🧎🏿‍♂' => 'nin jilba dhiganaya: jidh madaw',
    '🧎🏻‍♀' => 'naag jilba dhiganaysa: jidh fudud',
    '🧎🏼‍♀' => 'naag jilba dhiganaysa: jidh fudud oo dhexe',
    '🧎🏽‍♀' => 'naag jilba dhiganaysa: jidh nooc dhexe',
    '🧎🏾‍♀' => 'naag jilba dhiganaysa: jidh nooc madaw oo dhexe',
    '🧎🏿‍♀' => 'naag jilba dhiganaysa: jidh madaw',
    '🧎🏻‍➡' => 'qof jilbaha dhiganaya: jidh fudud, midig u jeeda',
    '🧎🏼‍➡' => 'qof jilbaha dhiganaya: jidh fudud oo dhexe, midig u jeeda',
    '🧎🏽‍➡' => 'qof jilbaha dhiganaya: jidh nooc dhexe, midig u jeeda',
    '🧎🏾‍➡' => 'qof jilbaha dhiganaya: jidh nooc madaw oo dhexe, midig u jeeda',
    '🧎🏿‍➡' => 'qof jilbaha dhiganaya: jidh madaw, midig u jeeda',
    '🧑🏻‍🦯' => 'qof wata bakoorad cas: jidh fudud',
    '🧑🏼‍🦯' => 'qof wata bakoorad cas: jidh fudud oo dhexe',
    '🧑🏽‍🦯' => 'qof wata bakoorad cas: jidh nooc dhexe',
    '🧑🏾‍🦯' => 'qof wata bakoorad cas: jidh nooc madaw oo dhexe',
    '🧑🏿‍🦯' => 'qof wata bakoorad cas: jidh madaw',
    '👨🏻‍🦯' => 'nin sita usha cad indhoolaha: jidh fudud',
    '👨🏼‍🦯' => 'nin sita usha cad indhoolaha: jidh fudud oo dhexe',
    '👨🏽‍🦯' => 'nin sita usha cad indhoolaha: jidh nooc dhexe',
    '👨🏾‍🦯' => 'nin sita usha cad indhoolaha: jidh nooc madaw oo dhexe',
    '👨🏿‍🦯' => 'nin sita usha cad indhoolaha: jidh madaw',
    '👩🏻‍🦯' => 'naag sidata usha cad indhoolaha: jidh fudud',
    '👩🏼‍🦯' => 'naag sidata usha cad indhoolaha: jidh fudud oo dhexe',
    '👩🏽‍🦯' => 'naag sidata usha cad indhoolaha: jidh nooc dhexe',
    '👩🏾‍🦯' => 'naag sidata usha cad indhoolaha: jidh nooc madaw oo dhexe',
    '👩🏿‍🦯' => 'naag sidata usha cad indhoolaha: jidh madaw',
    '🧑🏻‍🦼' => 'qof kufadhiya gaari matoor leh: jidh fudud',
    '🧑🏼‍🦼' => 'qof kufadhiya gaari matoor leh: jidh fudud oo dhexe',
    '🧑🏽‍🦼' => 'qof kufadhiya gaari matoor leh: jidh nooc dhexe',
    '🧑🏾‍🦼' => 'qof kufadhiya gaari matoor leh: jidh nooc madaw oo dhexe',
    '🧑🏿‍🦼' => 'qof kufadhiya gaari matoor leh: jidh madaw',
    '👨🏻‍🦼' => 'nin saaran kursi curyaan matoor leh: jidh fudud',
    '👨🏼‍🦼' => 'nin saaran kursi curyaan matoor leh: jidh fudud oo dhexe',
    '👨🏽‍🦼' => 'nin saaran kursi curyaan matoor leh: jidh nooc dhexe',
    '👨🏾‍🦼' => 'nin saaran kursi curyaan matoor leh: jidh nooc madaw oo dhexe',
    '👨🏿‍🦼' => 'nin saaran kursi curyaan matoor leh: jidh madaw',
    '👩🏻‍🦼' => 'gabadh saaran kursi curyaan matoor leh: jidh fudud',
    '👩🏼‍🦼' => 'gabadh saaran kursi curyaan matoor leh: jidh fudud oo dhexe',
    '👩🏽‍🦼' => 'gabadh saaran kursi curyaan matoor leh: jidh nooc dhexe',
    '👩🏾‍🦼' => 'gabadh saaran kursi curyaan matoor leh: jidh nooc madaw oo dhexe',
    '👩🏿‍🦼' => 'gabadh saaran kursi curyaan matoor leh: jidh madaw',
    '🧑🏻‍🦽' => 'qof ku fadhiya gaari curyaanka gacanta: jidh fudud',
    '🧑🏼‍🦽' => 'qof ku fadhiya gaari curyaanka gacanta: jidh fudud oo dhexe',
    '🧑🏽‍🦽' => 'qof ku fadhiya gaari curyaanka gacanta: jidh nooc dhexe',
    '🧑🏾‍🦽' => 'qof ku fadhiya gaari curyaanka gacanta: jidh nooc madaw oo dhexe',
    '🧑🏿‍🦽' => 'qof ku fadhiya gaari curyaanka gacanta: jidh madaw',
    '👨🏻‍🦽' => 'nin saaran kursiga curyaanka macmac ah: jidh fudud',
    '👨🏼‍🦽' => 'nin saaran kursiga curyaanka macmac ah: jidh fudud oo dhexe',
    '👨🏽‍🦽' => 'nin saaran kursiga curyaanka macmac ah: jidh nooc dhexe',
    '👨🏾‍🦽' => 'nin saaran kursiga curyaanka macmac ah: jidh nooc madaw oo dhexe',
    '👨🏿‍🦽' => 'nin saaran kursiga curyaanka macmac ah: jidh madaw',
    '👩🏻‍🦽' => 'naag fadhida kursiga curyaanka macmal ah: jidh fudud',
    '👩🏼‍🦽' => 'naag fadhida kursiga curyaanka macmal ah: jidh fudud oo dhexe',
    '👩🏽‍🦽' => 'naag fadhida kursiga curyaanka macmal ah: jidh nooc dhexe',
    '👩🏾‍🦽' => 'naag fadhida kursiga curyaanka macmal ah: jidh nooc madaw oo dhexe',
    '👩🏿‍🦽' => 'naag fadhida kursiga curyaanka macmal ah: jidh madaw',
    '🏃🏻‍♂' => 'nin ordaya: jidh fudud',
    '🏃🏼‍♂' => 'nin ordaya: jidh fudud oo dhexe',
    '🏃🏽‍♂' => 'nin ordaya: jidh nooc dhexe',
    '🏃🏾‍♂' => 'nin ordaya: jidh nooc madaw oo dhexe',
    '🏃🏿‍♂' => 'nin ordaya: jidh madaw',
    '🏃🏻‍♀' => 'naag ordaysa: jidh fudud',
    '🏃🏼‍♀' => 'naag ordaysa: jidh fudud oo dhexe',
    '🏃🏽‍♀' => 'naag ordaysa: jidh nooc dhexe',
    '🏃🏾‍♀' => 'naag ordaysa: jidh nooc madaw oo dhexe',
    '🏃🏿‍♀' => 'naag ordaysa: jidh madaw',
    '🏃🏻‍➡' => 'qof ordaya: jidh fudud, midig u jeeda',
    '🏃🏼‍➡' => 'qof ordaya: jidh fudud oo dhexe, midig u jeeda',
    '🏃🏽‍➡' => 'qof ordaya: jidh nooc dhexe, midig u jeeda',
    '🏃🏾‍➡' => 'qof ordaya: jidh nooc madaw oo dhexe, midig u jeeda',
    '🏃🏿‍➡' => 'qof ordaya: jidh madaw, midig u jeeda',
    '👯🏻‍♀' => 'naag leh dhaggo bakayle: jidh fudud',
    '👯🏼‍♀' => 'naag leh dhaggo bakayle: jidh fudud oo dhexe',
    '👯🏽‍♀' => 'naag leh dhaggo bakayle: jidh nooc dhexe',
    '👯🏾‍♀' => 'naag leh dhaggo bakayle: jidh nooc madaw oo dhexe',
    '👯🏿‍♀' => 'naag leh dhaggo bakayle: jidh madaw',
    '👯🏻‍♂' => 'rag leh dhaggo bakayle: jidh fudud',
    '👯🏼‍♂' => 'rag leh dhaggo bakayle: jidh fudud oo dhexe',
    '👯🏽‍♂' => 'rag leh dhaggo bakayle: jidh nooc dhexe',
    '👯🏾‍♂' => 'rag leh dhaggo bakayle: jidh nooc madaw oo dhexe',
    '👯🏿‍♂' => 'rag leh dhaggo bakayle: jidh madaw',
    '🧖🏻‍♂' => 'nin ku jira qol uummi ah: jidh fudud',
    '🧖🏼‍♂' => 'nin ku jira qol uummi ah: jidh fudud oo dhexe',
    '🧖🏽‍♂' => 'nin ku jira qol uummi ah: jidh nooc dhexe',
    '🧖🏾‍♂' => 'nin ku jira qol uummi ah: jidh nooc madaw oo dhexe',
    '🧖🏿‍♂' => 'nin ku jira qol uummi ah: jidh madaw',
    '🧖🏻‍♀' => 'naag ku jirta qol uummi ah: jidh fudud',
    '🧖🏼‍♀' => 'naag ku jirta qol uummi ah: jidh fudud oo dhexe',
    '🧖🏽‍♀' => 'naag ku jirta qol uummi ah: jidh nooc dhexe',
    '🧖🏾‍♀' => 'naag ku jirta qol uummi ah: jidh nooc madaw oo dhexe',
    '🧖🏿‍♀' => 'naag ku jirta qol uummi ah: jidh madaw',
    '🧗🏻‍♂' => 'nin meel fuulaya: jidh fudud',
    '🧗🏼‍♂' => 'nin meel fuulaya: jidh fudud oo dhexe',
    '🧗🏽‍♂' => 'nin meel fuulaya: jidh nooc dhexe',
    '🧗🏾‍♂' => 'nin meel fuulaya: jidh nooc madaw oo dhexe',
    '🧗🏿‍♂' => 'nin meel fuulaya: jidh madaw',
    '🧗🏻‍♀' => 'naag meel fuulaysa: jidh fudud',
    '🧗🏼‍♀' => 'naag meel fuulaysa: jidh fudud oo dhexe',
    '🧗🏽‍♀' => 'naag meel fuulaysa: jidh nooc dhexe',
    '🧗🏾‍♀' => 'naag meel fuulaysa: jidh nooc madaw oo dhexe',
    '🧗🏿‍♀' => 'naag meel fuulaysa: jidh madaw',
    '🏌🏻‍♂' => 'nin cayaaraya goolof: jidh fudud',
    '🏌🏼‍♂' => 'nin cayaaraya goolof: jidh fudud oo dhexe',
    '🏌🏽‍♂' => 'nin cayaaraya goolof: jidh nooc dhexe',
    '🏌🏾‍♂' => 'nin cayaaraya goolof: jidh nooc madaw oo dhexe',
    '🏌🏿‍♂' => 'nin cayaaraya goolof: jidh madaw',
    '🏌🏻‍♀' => 'naag cayaaraysa goolof: jidh fudud',
    '🏌🏼‍♀' => 'naag cayaaraysa goolof: jidh fudud oo dhexe',
    '🏌🏽‍♀' => 'naag cayaaraysa goolof: jidh nooc dhexe',
    '🏌🏾‍♀' => 'naag cayaaraysa goolof: jidh nooc madaw oo dhexe',
    '🏌🏿‍♀' => 'naag cayaaraysa goolof: jidh madaw',
    '🏄🏻‍♂' => 'nin alwaaxa hirka biyaha kula soconaya: jidh fudud',
    '🏄🏼‍♂' => 'nin alwaaxa hirka biyaha kula soconaya: jidh fudud oo dhexe',
    '🏄🏽‍♂' => 'nin alwaaxa hirka biyaha kula soconaya: jidh nooc dhexe',
    '🏄🏾‍♂' => 'nin alwaaxa hirka biyaha kula soconaya: jidh nooc madaw oo dhexe',
    '🏄🏿‍♂' => 'nin alwaaxa hirka biyaha kula soconaya: jidh madaw',
    '🏄🏻‍♀' => 'naag alwaaxa hirka biyaha kula soconaysa: jidh fudud',
    '🏄🏼‍♀' => 'naag alwaaxa hirka biyaha kula soconaysa: jidh fudud oo dhexe',
    '🏄🏽‍♀' => 'naag alwaaxa hirka biyaha kula soconaysa: jidh nooc dhexe',
    '🏄🏾‍♀' => 'naag alwaaxa hirka biyaha kula soconaysa: jidh nooc madaw oo dhexe',
    '🏄🏿‍♀' => 'naag alwaaxa hirka biyaha kula soconaysa: jidh madaw',
    '🚣🏻‍♂' => 'nin doon wada: jidh fudud',
    '🚣🏼‍♂' => 'nin doon wada: jidh fudud oo dhexe',
    '🚣🏽‍♂' => 'nin doon wada: jidh nooc dhexe',
    '🚣🏾‍♂' => 'nin doon wada: jidh nooc madaw oo dhexe',
    '🚣🏿‍♂' => 'nin doon wada: jidh madaw',
    '🚣🏻‍♀' => 'naag doon wadda: jidh fudud',
    '🚣🏼‍♀' => 'naag doon wadda: jidh fudud oo dhexe',
    '🚣🏽‍♀' => 'naag doon wadda: jidh nooc dhexe',
    '🚣🏾‍♀' => 'naag doon wadda: jidh nooc madaw oo dhexe',
    '🚣🏿‍♀' => 'naag doon wadda: jidh madaw',
    '🏊🏻‍♂' => 'nin dabaalanaya: jidh fudud',
    '🏊🏼‍♂' => 'nin dabaalanaya: jidh fudud oo dhexe',
    '🏊🏽‍♂' => 'nin dabaalanaya: jidh nooc dhexe',
    '🏊🏾‍♂' => 'nin dabaalanaya: jidh nooc madaw oo dhexe',
    '🏊🏿‍♂' => 'nin dabaalanaya: jidh madaw',
    '🏊🏻‍♀' => 'naag dabaalanaysa: jidh fudud',
    '🏊🏼‍♀' => 'naag dabaalanaysa: jidh fudud oo dhexe',
    '🏊🏽‍♀' => 'naag dabaalanaysa: jidh nooc dhexe',
    '🏊🏾‍♀' => 'naag dabaalanaysa: jidh nooc madaw oo dhexe',
    '🏊🏿‍♀' => 'naag dabaalanaysa: jidh madaw',
    '⛹🏻‍♂' => 'nin cayaaraya kubadda boodda: jidh fudud',
    '⛹🏼‍♂' => 'nin cayaaraya kubadda boodda: jidh fudud oo dhexe',
    '⛹🏽‍♂' => 'nin cayaaraya kubadda boodda: jidh nooc dhexe',
    '⛹🏾‍♂' => 'nin cayaaraya kubadda boodda: jidh nooc madaw oo dhexe',
    '⛹🏿‍♂' => 'nin cayaaraya kubadda boodda: jidh madaw',
    '⛹🏻‍♀' => 'naag cayaaraysa kubadda boodda: jidh fudud',
    '⛹🏼‍♀' => 'naag cayaaraysa kubadda boodda: jidh fudud oo dhexe',
    '⛹🏽‍♀' => 'naag cayaaraysa kubadda boodda: jidh nooc dhexe',
    '⛹🏾‍♀' => 'naag cayaaraysa kubadda boodda: jidh nooc madaw oo dhexe',
    '⛹🏿‍♀' => 'naag cayaaraysa kubadda boodda: jidh madaw',
    '🏋🏻‍♂' => 'nin qaadaya culeyska: jidh fudud',
    '🏋🏼‍♂' => 'nin qaadaya culeyska: jidh fudud oo dhexe',
    '🏋🏽‍♂' => 'nin qaadaya culeyska: jidh nooc dhexe',
    '🏋🏾‍♂' => 'nin qaadaya culeyska: jidh nooc madaw oo dhexe',
    '🏋🏿‍♂' => 'nin qaadaya culeyska: jidh madaw',
    '🏋🏻‍♀' => 'naag qaadaysa culeyska: jidh fudud',
    '🏋🏼‍♀' => 'naag qaadaysa culeyska: jidh fudud oo dhexe',
    '🏋🏽‍♀' => 'naag qaadaysa culeyska: jidh nooc dhexe',
    '🏋🏾‍♀' => 'naag qaadaysa culeyska: jidh nooc madaw oo dhexe',
    '🏋🏿‍♀' => 'naag qaadaysa culeyska: jidh madaw',
    '🚴🏻‍♂' => 'nin baaskiil wada: jidh fudud',
    '🚴🏼‍♂' => 'nin baaskiil wada: jidh fudud oo dhexe',
    '🚴🏽‍♂' => 'nin baaskiil wada: jidh nooc dhexe',
    '🚴🏾‍♂' => 'nin baaskiil wada: jidh nooc madaw oo dhexe',
    '🚴🏿‍♂' => 'nin baaskiil wada: jidh madaw',
    '🚴🏻‍♀' => 'naag baaskiil wadda: jidh fudud',
    '🚴🏼‍♀' => 'naag baaskiil wadda: jidh fudud oo dhexe',
    '🚴🏽‍♀' => 'naag baaskiil wadda: jidh nooc dhexe',
    '🚴🏾‍♀' => 'naag baaskiil wadda: jidh nooc madaw oo dhexe',
    '🚴🏿‍♀' => 'naag baaskiil wadda: jidh madaw',
    '🚵🏻‍♂' => 'nin baaskiil buur ku wada: jidh fudud',
    '🚵🏼‍♂' => 'nin baaskiil buur ku wada: jidh fudud oo dhexe',
    '🚵🏽‍♂' => 'nin baaskiil buur ku wada: jidh nooc dhexe',
    '🚵🏾‍♂' => 'nin baaskiil buur ku wada: jidh nooc madaw oo dhexe',
    '🚵🏿‍♂' => 'nin baaskiil buur ku wada: jidh madaw',
    '🚵🏻‍♀' => 'naag baaskiil buur ku wadda: jidh fudud',
    '🚵🏼‍♀' => 'naag baaskiil buur ku wadda: jidh fudud oo dhexe',
    '🚵🏽‍♀' => 'naag baaskiil buur ku wadda: jidh nooc dhexe',
    '🚵🏾‍♀' => 'naag baaskiil buur ku wadda: jidh nooc madaw oo dhexe',
    '🚵🏿‍♀' => 'naag baaskiil buur ku wadda: jidh madaw',
    '🤸🏻‍♂' => 'nin jimicsiga gacma saarka samaynaya: jidh fudud',
    '🤸🏼‍♂' => 'nin jimicsiga gacma saarka samaynaya: jidh fudud oo dhexe',
    '🤸🏽‍♂' => 'nin jimicsiga gacma saarka samaynaya: jidh nooc dhexe',
    '🤸🏾‍♂' => 'nin jimicsiga gacma saarka samaynaya: jidh nooc madaw oo dhexe',
    '🤸🏿‍♂' => 'nin jimicsiga gacma saarka samaynaya: jidh madaw',
    '🤸🏻‍♀' => 'naag jimicsanaysa: jidh fudud',
    '🤸🏼‍♀' => 'naag jimicsanaysa: jidh fudud oo dhexe',
    '🤸🏽‍♀' => 'naag jimicsanaysa: jidh nooc dhexe',
    '🤸🏾‍♀' => 'naag jimicsanaysa: jidh nooc madaw oo dhexe',
    '🤸🏿‍♀' => 'naag jimicsanaysa: jidh madaw',
    '🤼🏻‍♀' => 'naaga lagdamaya: jidh fudud',
    '🤼🏼‍♀' => 'naaga lagdamaya: jidh fudud oo dhexe',
    '🤼🏽‍♀' => 'naaga lagdamaya: jidh nooc dhexe',
    '🤼🏾‍♀' => 'naaga lagdamaya: jidh nooc madaw oo dhexe',
    '🤼🏿‍♀' => 'naaga lagdamaya: jidh madaw',
    '🤼🏻‍♂' => 'rag lagdamaya: jidh fudud',
    '🤼🏼‍♂' => 'rag lagdamaya: jidh fudud oo dhexe',
    '🤼🏽‍♂' => 'rag lagdamaya: jidh nooc dhexe',
    '🤼🏾‍♂' => 'rag lagdamaya: jidh nooc madaw oo dhexe',
    '🤼🏿‍♂' => 'rag lagdamaya: jidh madaw',
    '🤽🏻‍♂' => 'nin cayaaraya kubadda biyaha: jidh fudud',
    '🤽🏼‍♂' => 'nin cayaaraya kubadda biyaha: jidh fudud oo dhexe',
    '🤽🏽‍♂' => 'nin cayaaraya kubadda biyaha: jidh nooc dhexe',
    '🤽🏾‍♂' => 'nin cayaaraya kubadda biyaha: jidh nooc madaw oo dhexe',
    '🤽🏿‍♂' => 'nin cayaaraya kubadda biyaha: jidh madaw',
    '🤽🏻‍♀' => 'naag cayaaraysa kubadda biyaha: jidh fudud',
    '🤽🏼‍♀' => 'naag cayaaraysa kubadda biyaha: jidh fudud oo dhexe',
    '🤽🏽‍♀' => 'naag cayaaraysa kubadda biyaha: jidh nooc dhexe',
    '🤽🏾‍♀' => 'naag cayaaraysa kubadda biyaha: jidh nooc madaw oo dhexe',
    '🤽🏿‍♀' => 'naag cayaaraysa kubadda biyaha: jidh madaw',
    '🤾🏻‍♂' => 'nin cayaaraya kubadda gacanta: jidh fudud',
    '🤾🏼‍♂' => 'nin cayaaraya kubadda gacanta: jidh fudud oo dhexe',
    '🤾🏽‍♂' => 'nin cayaaraya kubadda gacanta: jidh nooc dhexe',
    '🤾🏾‍♂' => 'nin cayaaraya kubadda gacanta: jidh nooc madaw oo dhexe',
    '🤾🏿‍♂' => 'nin cayaaraya kubadda gacanta: jidh madaw',
    '🤾🏻‍♀' => 'naag cayaaraysa kubadda gacanta: jidh fudud',
    '🤾🏼‍♀' => 'naag cayaaraysa kubadda gacanta: jidh fudud oo dhexe',
    '🤾🏽‍♀' => 'naag cayaaraysa kubadda gacanta: jidh nooc dhexe',
    '🤾🏾‍♀' => 'naag cayaaraysa kubadda gacanta: jidh nooc madaw oo dhexe',
    '🤾🏿‍♀' => 'naag cayaaraysa kubadda gacanta: jidh madaw',
    '🤹🏻‍♂' => 'nin hawla badan wada qabanaya: jidh fudud',
    '🤹🏼‍♂' => 'nin hawla badan wada qabanaya: jidh fudud oo dhexe',
    '🤹🏽‍♂' => 'nin hawla badan wada qabanaya: jidh nooc dhexe',
    '🤹🏾‍♂' => 'nin hawla badan wada qabanaya: jidh nooc madaw oo dhexe',
    '🤹🏿‍♂' => 'nin hawla badan wada qabanaya: jidh madaw',
    '🤹🏻‍♀' => 'naag hawla badan wada qabanaysa: jidh fudud',
    '🤹🏼‍♀' => 'naag hawla badan wada qabanaysa: jidh fudud oo dhexe',
    '🤹🏽‍♀' => 'naag hawla badan wada qabanaysa: jidh nooc dhexe',
    '🤹🏾‍♀' => 'naag hawla badan wada qabanaysa: jidh nooc madaw oo dhexe',
    '🤹🏿‍♀' => 'naag hawla badan wada qabanaysa: jidh madaw',
    '🧘🏻‍♂' => 'nin ku jira habka fadhiga luga is gudubka: jidh fudud',
    '🧘🏼‍♂' => 'nin ku jira habka fadhiga luga is gudubka: jidh fudud oo dhexe',
    '🧘🏽‍♂' => 'nin ku jira habka fadhiga luga is gudubka: jidh nooc dhexe',
    '🧘🏾‍♂' => 'nin ku jira habka fadhiga luga is gudubka: jidh nooc madaw oo dhexe',
    '🧘🏿‍♂' => 'nin ku jira habka fadhiga luga is gudubka: jidh madaw',
    '🧘🏻‍♀' => 'naag u fadhida habka luga is-gudubka: jidh fudud',
    '🧘🏼‍♀' => 'naag u fadhida habka luga is-gudubka: jidh fudud oo dhexe',
    '🧘🏽‍♀' => 'naag u fadhida habka luga is-gudubka: jidh nooc dhexe',
    '🧘🏾‍♀' => 'naag u fadhida habka luga is-gudubka: jidh nooc madaw oo dhexe',
    '🧘🏿‍♀' => 'naag u fadhida habka luga is-gudubka: jidh madaw',
    '🧑‍🦰' => 'qof: timo cas',
    '🧑‍🦱' => 'qof: timo walaaqan',
    '🧑‍🦳' => 'qof: caddaan',
    '🧑‍🦲' => 'qof: bidaar',
    '👨‍🦰' => 'ninka: timo cas',
    '👨‍🦱' => 'ninka: timo walaaqan',
    '👨‍🦳' => 'ninka: caddaan',
    '👨‍🦲' => 'ninka: bidaar',
    '👩‍🦰' => 'naag: timo cas',
    '👩‍🦱' => 'naag: timo walaaqan',
    '👩‍🦳' => 'naag: caddaan',
    '👩‍🦲' => 'naag: bidaar',
    '🚶‍➡' => 'qof soconaya: midig u jeeda',
    '🧎‍➡' => 'qof jilbaha dhiganaya: midig u jeeda',
    '🏃‍➡' => 'qof ordaya: midig u jeeda',
    '👨‍👦' => 'Qooys caruur ah: ninka, wiil',
    '👨‍👧' => 'Qooys caruur ah: ninka, gabar',
    '👩‍👦' => 'Qooys caruur ah: naag, wiil',
    '👩‍👧' => 'Qooys caruur ah: naag, gabar',
    '😶‍🌫' => 'waji daruuro ku jira',
    '😮‍💨' => 'waji afka kala qaday',
    '🙂‍↕' => 'madax u luxida sida toosan',
    '😵‍💫' => 'waji indho wareegsan leh',
    '❤‍🔥' => 'wadne ololaya',
    '❤‍🩹' => 'wadne dhaawacan',
    '👁‍🗨' => 'il xumbo hadal ku leh',
    '🧔‍♂' => 'nin: gadh',
    '👱‍♂' => 'nin: timo cad',
    '🧔‍♀' => 'gabadh: gadh',
    '👱‍♀' => 'naag: timo cad',
    '🙍‍♂' => 'nin wajiga kaduudaya',
    '🙍‍♀' => 'naag wajiga kaduudaya',
    '🙎‍♂' => 'nin bushinta qaniinaya',
    '🙎‍♀' => 'naag bushinta qaniinaysa',
    '🙅‍♂' => 'nin ku meedaaraya MAYA',
    '🙅‍♀' => 'naag ku meedaaraysa MAYA',
    '🙆‍♂' => 'nin ku meedaaraya HAA',
    '🙆‍♀' => 'haweeney ku meedaaraysa MAYA',
    '💁‍♂' => 'nin war bixinaya',
    '💁‍♀' => 'naag warbixin bixinaysa',
    '🙋‍♂' => 'nin gcan taagaya',
    '🙋‍♀' => 'naag gacan taagaysa',
    '🧏‍♂' => 'nin dhagoole ah',
    '🧏‍♀' => 'naag dhagoole ah',
    '🙇‍♂' => 'nin fooraraya',
    '🙇‍♀' => 'naag fooraraysa',
    '🤦‍♂' => 'nin calaacal waji saaranaya',
    '🤦‍♀' => 'naag calaacal waji saaranaysa',
    '🤷‍♂' => 'nin garba-ruxaya',
    '🤷‍♀' => 'naag garba-ruxaysa',
    '🧑‍⚕' => 'shaqaale caafimaad',
    '👨‍⚕' => 'nin shaqaale caafimaad ah',
    '👩‍⚕' => 'naag shaqaale caafimaad ah',
    '🧑‍🎓' => 'arday',
    '👨‍🎓' => 'nin arday ah',
    '👩‍🎓' => 'naag ardayad ah',
    '🧑‍🏫' => 'bare',
    '👨‍🏫' => 'nin macallin ah',
    '👩‍🏫' => 'naag macallimad ah',
    '🧑‍⚖' => 'qaalli',
    '👨‍⚖' => 'nin garsoore ah',
    '👩‍⚖' => 'naag garsoore ah',
    '🧑‍🌾' => 'Beeraley',
    '👨‍🌾' => 'nin beeraleey ah',
    '👩‍🌾' => 'naag beeraleeyad ah',
    '🧑‍🍳' => 'cunno kariye',
    '👨‍🍳' => 'nin kariye ah',
    '👩‍🍳' => 'naag kariso ah',
    '🧑‍🔧' => 'makaanik',
    '👨‍🔧' => 'nin makaanik ah',
    '👩‍🔧' => 'naag makaanikad ah',
    '🧑‍🏭' => 'shaqaale warshadeed',
    '👨‍🏭' => 'nin shaqaale warshad ah',
    '👩‍🏭' => 'naag shaqaale warshad ah',
    '🧑‍💼' => 'shaqaale xafiis',
    '👨‍💼' => 'nin shaqaale xafiis ah',
    '👩‍💼' => 'naag shaqaale xafiis ah',
    '🧑‍🔬' => 'saynisyahan',
    '👨‍🔬' => 'qabiir saynisyahan ah',
    '👩‍🔬' => 'haweeney cilmi sayniska taqaan',
    '🧑‍💻' => 'Tiknoolajiste',
    '👨‍💻' => 'nin tiknoolijiste ah',
    '👩‍💻' => 'naag tiknoolijisate ah',
    '🧑‍🎤' => 'heesaa',
    '👨‍🎤' => 'nin fannaan ah',
    '👩‍🎤' => 'naag fannaanad ah',
    '🧑‍🎨' => 'fanaan',
    '👨‍🎨' => 'nin farsama yaqaan ah',
    '👩‍🎨' => 'naag farsama yaqaan ah',
    '🧑‍✈' => 'darawal dayuurad',
    '👨‍✈' => 'nin duuliye ah',
    '👩‍✈' => 'naag duuliye ah',
    '🧑‍🚀' => 'dayax u safre',
    '👨‍🚀' => 'nin cirbixiyeen ah',
    '👩‍🚀' => 'naag cir bixiyeenad ah',
    '🧑‍🚒' => 'dab damis',
    '👨‍🚒' => 'ninka dab-demiska ah',
    '👩‍🚒' => 'naag dab-demis ah',
    '👮‍♂' => 'nin sarkaal boolis ah',
    '👮‍♀' => 'haweeney sarkaal boolis ah',
    '🕵‍♂' => 'nin dambi-baare ah',
    '🕵‍♀' => 'naag dambi-baarto ah',
    '💂‍♂' => 'nin illaaliye ah',
    '💂‍♀' => 'haweeney ilaaliye ah',
    '👷‍♂' => 'nin shaqaale dhismo ah',
    '👷‍♀' => 'naag shaqaale dhismo ah',
    '👳‍♂' => 'nin cammaamad xiran',
    '👳‍♀' => 'naag cammaamad xiran',
    '🤵‍♂' => 'nin xidhan suut ka rasmiga ah',
    '🤵‍♀' => 'gabadh xidhan suut',
    '👰‍♂' => 'nin niqaamaban',
    '👰‍♀' => 'naag niqaaban',
    '👩‍🍼' => 'naag canug quudineeysa',
    '👨‍🍼' => 'nin canug quudinaya',
    '🧑‍🍼' => 'qof canug quudinaya',
    '🧑‍🎄' => 'mx claus',
    '🦸‍♂' => 'nin halyeey ah',
    '🦸‍♀' => 'haweeney geesinnimadeedu sareeyso',
    '🦹‍♂' => 'nin sheyddaannimadiisu sareeyso',
    '🦹‍♀' => 'haweeney shayddaannimadeedu sareeyso',
    '🧙‍♂' => 'nin xirfad u leh sixirka',
    '🧙‍♀' => 'naag xirfad u leh sixirka',
    '🧚‍♂' => 'nin qurux badan',
    '🧚‍♀' => 'naag qurux badan',
    '🧛‍♂' => 'nin reer-aakhiraad dhiig cab ah',
    '🧛‍♀' => 'naag reer-aakhiraad dhiig cab ah',
    '🧜‍♂' => 'wiilo-maanyo',
    '🧜‍♀' => 'gabreey-maanyo',
    '🧝‍♂' => 'ruuxaanta ragga',
    '🧝‍♀' => 'ruuxaanta haweenka',
    '🧞‍♂' => 'jinka ragga',
    '🧞‍♀' => 'jinka haweenka',
    '🧟‍♂' => 'nin dhintay oo soo noolaaday',
    '🧟‍♀' => 'haweeney dhimatay soo laabatay',
    '💆‍♂' => 'nin loo duugayo',
    '💆‍♀' => 'haweeneey loo duugayo',
    '💇‍♂' => 'nin timaha loo jarayo',
    '💇‍♀' => 'haweeney timaha loo jarayo',
    '🚶‍♂' => 'nin soconaya',
    '🚶‍♀' => 'haweeney soconaysa',
    '🧍‍♂' => 'nin taaggan',
    '🧍‍♀' => 'naag taaggan',
    '🧎‍♂' => 'nin jilba dhiganaya',
    '🧎‍♀' => 'naag jilba dhiganaysa',
    '🧑‍🦯' => 'qof wata bakoorad cas',
    '👨‍🦯' => 'nin sita usha cad indhoolaha',
    '👩‍🦯' => 'naag sidata usha cad indhoolaha',
    '🧑‍🦼' => 'qof kufadhiya gaari matoor leh',
    '👨‍🦼' => 'nin saaran kursi curyaan matoor leh',
    '👩‍🦼' => 'gabadh saaran kursi curyaan matoor leh',
    '🧑‍🦽' => 'qof ku fadhiya gaari curyaanka gacanta',
    '👨‍🦽' => 'nin saaran kursiga curyaanka macmac ah',
    '👩‍🦽' => 'naag fadhida kursiga curyaanka macmal ah',
    '🏃‍♂' => 'nin ordaya',
    '🏃‍♀' => 'naag ordaysa',
    '🧑‍🩰' => 'qoob ka ciyaare faneed',
    '👯‍♂' => 'rag leh dhaggo bakayle',
    '👯‍♀' => 'naag leh dhaggo bakayle',
    '🧖‍♂' => 'nin ku jira qol uummi ah',
    '🧖‍♀' => 'naag ku jirta qol uummi ah',
    '🧗‍♂' => 'nin meel fuulaya',
    '🧗‍♀' => 'naag meel fuulaysa',
    '🏌‍♂' => 'nin cayaaraya goolof',
    '🏌‍♀' => 'naag cayaaraysa goolof',
    '🏄‍♂' => 'nin alwaaxa hirka biyaha kula soconaya',
    '🏄‍♀' => 'naag alwaaxa hirka biyaha kula soconaysa',
    '🚣‍♂' => 'nin doon wada',
    '🚣‍♀' => 'naag doon wadda',
    '🏊‍♂' => 'nin dabaalanaya',
    '🏊‍♀' => 'naag dabaalanaysa',
    '⛹‍♂' => 'nin cayaaraya kubadda boodda',
    '⛹‍♀' => 'naag cayaaraysa kubadda boodda',
    '🏋‍♂' => 'nin qaadaya culeyska',
    '🏋‍♀' => 'naag qaadaysa culeyska',
    '🚴‍♂' => 'nin baaskiil wada',
    '🚴‍♀' => 'naag baaskiil wadda',
    '🚵‍♂' => 'nin baaskiil buur ku wada',
    '🚵‍♀' => 'naag baaskiil buur ku wadda',
    '🤸‍♂' => 'nin jimicsiga gacma saarka samaynaya',
    '🤸‍♀' => 'naag jimicsanaysa',
    '🤼‍♂' => 'rag lagdamaya',
    '🤼‍♀' => 'naaga lagdamaya',
    '🤽‍♂' => 'nin cayaaraya kubadda biyaha',
    '🤽‍♀' => 'naag cayaaraysa kubadda biyaha',
    '🤾‍♂' => 'nin cayaaraya kubadda gacanta',
    '🤾‍♀' => 'naag cayaaraysa kubadda gacanta',
    '🤹‍♂' => 'nin hawla badan wada qabanaya',
    '🤹‍♀' => 'naag hawla badan wada qabanaysa',
    '🧘‍♂' => 'nin ku jira habka fadhiga luga is gudubka',
    '🧘‍♀' => 'naag u fadhida habka luga is-gudubka',
    '🧑‍🧒' => 'qoys: qof weyn, ilmo',
    '🐕‍🦺' => 'eyga adeegga',
    '🐈‍⬛' => 'bisadda madoow',
    '🐻‍❄' => 'oorso waqooyi',
    '🐦‍⬛' => 'shimbir madoow',
    '🐦‍🔥' => 'phoenix',
    '🍋‍🟩' => 'lin',
    '🍄‍🟫' => 'boqoshaa bunni ah',
    '⛓‍💥' => 'silsillad jabtay',
    '🏳‍🌈' => 'calanka qaanso roobeed',
    '🏳‍⚧' => 'calanka laba dhidiga',
    '🏴‍☠' => 'calanka burcad badeedda',
    '👋🏻' => 'gacan haadin: jidh fudud',
    '👋🏼' => 'gacan haadin: jidh fudud oo dhexe',
    '👋🏽' => 'gacan haadin: jidh nooc dhexe',
    '👋🏾' => 'gacan haadin: jidh nooc madaw oo dhexe',
    '👋🏿' => 'gacan haadin: jidh madaw',
    '🤚🏻' => 'kor u qaaday gacanta gadaal: jidh fudud',
    '🤚🏼' => 'kor u qaaday gacanta gadaal: jidh fudud oo dhexe',
    '🤚🏽' => 'kor u qaaday gacanta gadaal: jidh nooc dhexe',
    '🤚🏾' => 'kor u qaaday gacanta gadaal: jidh nooc madaw oo dhexe',
    '🤚🏿' => 'kor u qaaday gacanta gadaal: jidh madaw',
    '🖐🏻' => 'gacan iyo faraha ayaa lagu fidiyay: jidh fudud',
    '🖐🏼' => 'gacan iyo faraha ayaa lagu fidiyay: jidh fudud oo dhexe',
    '🖐🏽' => 'gacan iyo faraha ayaa lagu fidiyay: jidh nooc dhexe',
    '🖐🏾' => 'gacan iyo faraha ayaa lagu fidiyay: jidh nooc madaw oo dhexe',
    '🖐🏿' => 'gacan iyo faraha ayaa lagu fidiyay: jidh madaw',
    '✋🏻' => 'gacan kor loo qaday: jidh fudud',
    '✋🏼' => 'gacan kor loo qaday: jidh fudud oo dhexe',
    '✋🏽' => 'gacan kor loo qaday: jidh nooc dhexe',
    '✋🏾' => 'gacan kor loo qaday: jidh nooc madaw oo dhexe',
    '✋🏿' => 'gacan kor loo qaday: jidh madaw',
    '🖖🏻' => 'salaan sharaf: jidh fudud',
    '🖖🏼' => 'salaan sharaf: jidh fudud oo dhexe',
    '🖖🏽' => 'salaan sharaf: jidh nooc dhexe',
    '🖖🏾' => 'salaan sharaf: jidh nooc madaw oo dhexe',
    '🖖🏿' => 'salaan sharaf: jidh madaw',
    '🫱🏻' => 'dhinaca gacanta midig: jidh fudud',
    '🫱🏼' => 'dhinaca gacanta midig: jidh fudud oo dhexe',
    '🫱🏽' => 'dhinaca gacanta midig: jidh nooc dhexe',
    '🫱🏾' => 'dhinaca gacanta midig: jidh nooc madaw oo dhexe',
    '🫱🏿' => 'dhinaca gacanta midig: jidh madaw',
    '🫲🏻' => 'dhinaca gacanta bidix: jidh fudud',
    '🫲🏼' => 'dhinaca gacanta bidix: jidh fudud oo dhexe',
    '🫲🏽' => 'dhinaca gacanta bidix: jidh nooc dhexe',
    '🫲🏾' => 'dhinaca gacanta bidix: jidh nooc madaw oo dhexe',
    '🫲🏿' => 'dhinaca gacanta bidix: jidh madaw',
    '🫳🏻' => 'baabacada gacanta hoose: jidh fudud',
    '🫳🏼' => 'baabacada gacanta hoose: jidh fudud oo dhexe',
    '🫳🏽' => 'baabacada gacanta hoose: jidh nooc dhexe',
    '🫳🏾' => 'baabacada gacanta hoose: jidh nooc madaw oo dhexe',
    '🫳🏿' => 'baabacada gacanta hoose: jidh madaw',
    '🫴🏻' => 'Baabacada kore: jidh fudud',
    '🫴🏼' => 'Baabacada kore: jidh fudud oo dhexe',
    '🫴🏽' => 'Baabacada kore: jidh nooc dhexe',
    '🫴🏾' => 'Baabacada kore: jidh nooc madaw oo dhexe',
    '🫴🏿' => 'Baabacada kore: jidh madaw',
    '🫷🏻' => 'gacanta u riixaysa dhinaca bidix: jidh fudud',
    '🫷🏼' => 'gacanta u riixaysa dhinaca bidix: jidh fudud oo dhexe',
    '🫷🏽' => 'gacanta u riixaysa dhinaca bidix: jidh nooc dhexe',
    '🫷🏾' => 'gacanta u riixaysa dhinaca bidix: jidh nooc madaw oo dhexe',
    '🫷🏿' => 'gacanta u riixaysa dhinaca bidix: jidh madaw',
    '🫸🏻' => 'gacanta riixid bidix u socota: jidh fudud',
    '🫸🏼' => 'gacanta riixid bidix u socota: jidh fudud oo dhexe',
    '🫸🏽' => 'gacanta riixid bidix u socota: jidh nooc dhexe',
    '🫸🏾' => 'gacanta riixid bidix u socota: jidh nooc madaw oo dhexe',
    '🫸🏿' => 'gacanta riixid bidix u socota: jidh madaw',
    '👌🏻' => 'gacanta saxda ah: jidh fudud',
    '👌🏼' => 'gacanta saxda ah: jidh fudud oo dhexe',
    '👌🏽' => 'gacanta saxda ah: jidh nooc dhexe',
    '👌🏾' => 'gacanta saxda ah: jidh nooc madaw oo dhexe',
    '👌🏿' => 'gacanta saxda ah: jidh madaw',
    '🤌🏻' => 'faro la isku wada duubay: jidh fudud',
    '🤌🏼' => 'faro la isku wada duubay: jidh fudud oo dhexe',
    '🤌🏽' => 'faro la isku wada duubay: jidh nooc dhexe',
    '🤌🏾' => 'faro la isku wada duubay: jidh nooc madaw oo dhexe',
    '🤌🏿' => 'faro la isku wada duubay: jidh madaw',
    '🤏🏻' => 'qanjaruufo: jidh fudud',
    '🤏🏼' => 'qanjaruufo: jidh fudud oo dhexe',
    '🤏🏽' => 'qanjaruufo: jidh nooc dhexe',
    '🤏🏾' => 'qanjaruufo: jidh nooc madaw oo dhexe',
    '🤏🏿' => 'qanjaruufo: jidh madaw',
    '✌🏻' => 'gacanta guusha: jidh fudud',
    '✌🏼' => 'gacanta guusha: jidh fudud oo dhexe',
    '✌🏽' => 'gacanta guusha: jidh nooc dhexe',
    '✌🏾' => 'gacanta guusha: jidh nooc madaw oo dhexe',
    '✌🏿' => 'gacanta guusha: jidh madaw',
    '🤞🏻' => 'faraha gudban; Alla bari: jidh fudud',
    '🤞🏼' => 'faraha gudban; Alla bari: jidh fudud oo dhexe',
    '🤞🏽' => 'faraha gudban; Alla bari: jidh nooc dhexe',
    '🤞🏾' => 'faraha gudban; Alla bari: jidh nooc madaw oo dhexe',
    '🤞🏿' => 'faraha gudban; Alla bari: jidh madaw',
    '🫰🏻' => 'gacanta farta caarada iyo suulka la dhaafay: jidh fudud',
    '🫰🏼' => 'gacanta farta caarada iyo suulka la dhaafay: jidh fudud oo dhexe',
    '🫰🏽' => 'gacanta farta caarada iyo suulka la dhaafay: jidh nooc dhexe',
    '🫰🏾' => 'gacanta farta caarada iyo suulka la dhaafay: jidh nooc madaw oo dhexe',
    '🫰🏿' => 'gacanta farta caarada iyo suulka la dhaafay: jidh madaw',
    '🤟🏻' => 'meedaarta waan ku jecelahay ah: jidh fudud',
    '🤟🏼' => 'meedaarta waan ku jecelahay ah: jidh fudud oo dhexe',
    '🤟🏽' => 'meedaarta waan ku jecelahay ah: jidh nooc dhexe',
    '🤟🏾' => 'meedaarta waan ku jecelahay ah: jidh nooc madaw oo dhexe',
    '🤟🏿' => 'meedaarta waan ku jecelahay ah: jidh madaw',
    '🤘🏻' => 'calaamadda geesaha: jidh fudud',
    '🤘🏼' => 'calaamadda geesaha: jidh fudud oo dhexe',
    '🤘🏽' => 'calaamadda geesaha: jidh nooc dhexe',
    '🤘🏾' => 'calaamadda geesaha: jidh nooc madaw oo dhexe',
    '🤘🏿' => 'calaamadda geesaha: jidh madaw',
    '🤙🏻' => 'gacanta ah isoo wac: jidh fudud',
    '🤙🏼' => 'gacanta ah isoo wac: jidh fudud oo dhexe',
    '🤙🏽' => 'gacanta ah isoo wac: jidh nooc dhexe',
    '🤙🏾' => 'gacanta ah isoo wac: jidh nooc madaw oo dhexe',
    '🤙🏿' => 'gacanta ah isoo wac: jidh madaw',
    '👈🏻' => 'Gacan tilmaamaysa bidix: jidh fudud',
    '👈🏼' => 'Gacan tilmaamaysa bidix: jidh fudud oo dhexe',
    '👈🏽' => 'Gacan tilmaamaysa bidix: jidh nooc dhexe',
    '👈🏾' => 'Gacan tilmaamaysa bidix: jidh nooc madaw oo dhexe',
    '👈🏿' => 'Gacan tilmaamaysa bidix: jidh madaw',
    '👉🏻' => 'gacan tilmaamaysa midig: jidh fudud',
    '👉🏼' => 'gacan tilmaamaysa midig: jidh fudud oo dhexe',
    '👉🏽' => 'gacan tilmaamaysa midig: jidh nooc dhexe',
    '👉🏾' => 'gacan tilmaamaysa midig: jidh nooc madaw oo dhexe',
    '👉🏿' => 'gacan tilmaamaysa midig: jidh madaw',
    '👆🏻' => 'gacan tilmaamaysa kor: jidh fudud',
    '👆🏼' => 'gacan tilmaamaysa kor: jidh fudud oo dhexe',
    '👆🏽' => 'gacan tilmaamaysa kor: jidh nooc dhexe',
    '👆🏾' => 'gacan tilmaamaysa kor: jidh nooc madaw oo dhexe',
    '👆🏿' => 'gacan tilmaamaysa kor: jidh madaw',
    '🖕🏻' => 'farta dhexe: jidh fudud',
    '🖕🏼' => 'farta dhexe: jidh fudud oo dhexe',
    '🖕🏽' => 'farta dhexe: jidh nooc dhexe',
    '🖕🏾' => 'farta dhexe: jidh nooc madaw oo dhexe',
    '🖕🏿' => 'farta dhexe: jidh madaw',
    '👇🏻' => 'gacan tilmaamaysa hoos: jidh fudud',
    '👇🏼' => 'gacan tilmaamaysa hoos: jidh fudud oo dhexe',
    '👇🏽' => 'gacan tilmaamaysa hoos: jidh nooc dhexe',
    '👇🏾' => 'gacan tilmaamaysa hoos: jidh nooc madaw oo dhexe',
    '👇🏿' => 'gacan tilmaamaysa hoos: jidh madaw',
    '☝🏻' => 'farta muujinta tilmaamaysa kor: jidh fudud',
    '☝🏼' => 'farta muujinta tilmaamaysa kor: jidh fudud oo dhexe',
    '☝🏽' => 'farta muujinta tilmaamaysa kor: jidh nooc dhexe',
    '☝🏾' => 'farta muujinta tilmaamaysa kor: jidh nooc madaw oo dhexe',
    '☝🏿' => 'farta muujinta tilmaamaysa kor: jidh madaw',
    '🫵🏻' => 'tusmo tilmaame daawadaha: jidh fudud',
    '🫵🏼' => 'tusmo tilmaame daawadaha: jidh fudud oo dhexe',
    '🫵🏽' => 'tusmo tilmaame daawadaha: jidh nooc dhexe',
    '🫵🏾' => 'tusmo tilmaame daawadaha: jidh nooc madaw oo dhexe',
    '🫵🏿' => 'tusmo tilmaame daawadaha: jidh madaw',
    '👍🏻' => 'suulka kor: jidh fudud',
    '👍🏼' => 'suulka kor: jidh fudud oo dhexe',
    '👍🏽' => 'suulka kor: jidh nooc dhexe',
    '👍🏾' => 'suulka kor: jidh nooc madaw oo dhexe',
    '👍🏿' => 'suulka kor: jidh madaw',
    '👎🏻' => 'suulka hoos: jidh fudud',
    '👎🏼' => 'suulka hoos: jidh fudud oo dhexe',
    '👎🏽' => 'suulka hoos: jidh nooc dhexe',
    '👎🏾' => 'suulka hoos: jidh nooc madaw oo dhexe',
    '👎🏿' => 'suulka hoos: jidh madaw',
    '✊🏻' => 'kor u qaadid tantoonyo (feer): jidh fudud',
    '✊🏼' => 'kor u qaadid tantoonyo (feer): jidh fudud oo dhexe',
    '✊🏽' => 'kor u qaadid tantoonyo (feer): jidh nooc dhexe',
    '✊🏾' => 'kor u qaadid tantoonyo (feer): jidh nooc madaw oo dhexe',
    '✊🏿' => 'kor u qaadid tantoonyo (feer): jidh madaw',
    '👊🏻' => 'feer soo socoto: jidh fudud',
    '👊🏼' => 'feer soo socoto: jidh fudud oo dhexe',
    '👊🏽' => 'feer soo socoto: jidh nooc dhexe',
    '👊🏾' => 'feer soo socoto: jidh nooc madaw oo dhexe',
    '👊🏿' => 'feer soo socoto: jidh madaw',
    '🤛🏻' => 'feerka tilmaamaysa bidix: jidh fudud',
    '🤛🏼' => 'feerka tilmaamaysa bidix: jidh fudud oo dhexe',
    '🤛🏽' => 'feerka tilmaamaysa bidix: jidh nooc dhexe',
    '🤛🏾' => 'feerka tilmaamaysa bidix: jidh nooc madaw oo dhexe',
    '🤛🏿' => 'feerka tilmaamaysa bidix: jidh madaw',
    '🤜🏻' => 'feerka tilmaamaya midig: jidh fudud',
    '🤜🏼' => 'feerka tilmaamaya midig: jidh fudud oo dhexe',
    '🤜🏽' => 'feerka tilmaamaya midig: jidh nooc dhexe',
    '🤜🏾' => 'feerka tilmaamaya midig: jidh nooc madaw oo dhexe',
    '🤜🏿' => 'feerka tilmaamaya midig: jidh madaw',
    '👏🏻' => 'sacabinta gacmaha: jidh fudud',
    '👏🏼' => 'sacabinta gacmaha: jidh fudud oo dhexe',
    '👏🏽' => 'sacabinta gacmaha: jidh nooc dhexe',
    '👏🏾' => 'sacabinta gacmaha: jidh nooc madaw oo dhexe',
    '👏🏿' => 'sacabinta gacmaha: jidh madaw',
    '🙌🏻' => 'gacmo kor u taagid: jidh fudud',
    '🙌🏼' => 'gacmo kor u taagid: jidh fudud oo dhexe',
    '🙌🏽' => 'gacmo kor u taagid: jidh nooc dhexe',
    '🙌🏾' => 'gacmo kor u taagid: jidh nooc madaw oo dhexe',
    '🙌🏿' => 'gacmo kor u taagid: jidh madaw',
    '🫶🏻' => 'gacanta qalbiga: jidh fudud',
    '🫶🏼' => 'gacanta qalbiga: jidh fudud oo dhexe',
    '🫶🏽' => 'gacanta qalbiga: jidh nooc dhexe',
    '🫶🏾' => 'gacanta qalbiga: jidh nooc madaw oo dhexe',
    '🫶🏿' => 'gacanta qalbiga: jidh madaw',
    '👐🏻' => 'gacmo furan: jidh fudud',
    '👐🏼' => 'gacmo furan: jidh fudud oo dhexe',
    '👐🏽' => 'gacmo furan: jidh nooc dhexe',
    '👐🏾' => 'gacmo furan: jidh nooc madaw oo dhexe',
    '👐🏿' => 'gacmo furan: jidh madaw',
    '🤲🏻' => 'calaacalaha si wadajir ah kor loogu taaggo: jidh fudud',
    '🤲🏼' => 'calaacalaha si wadajir ah kor loogu taaggo: jidh fudud oo dhexe',
    '🤲🏽' => 'calaacalaha si wadajir ah kor loogu taaggo: jidh nooc dhexe',
    '🤲🏾' => 'calaacalaha si wadajir ah kor loogu taaggo: jidh nooc madaw oo dhexe',
    '🤲🏿' => 'calaacalaha si wadajir ah kor loogu taaggo: jidh madaw',
    '🤝🏻' => 'gacan-qaadka salaanta: jidh fudud',
    '🤝🏼' => 'gacan-qaadka salaanta: jidh fudud oo dhexe',
    '🤝🏽' => 'gacan-qaadka salaanta: jidh nooc dhexe',
    '🤝🏾' => 'gacan-qaadka salaanta: jidh nooc madaw oo dhexe',
    '🤝🏿' => 'gacan-qaadka salaanta: jidh madaw',
    '🙏🏻' => 'gacmo laaban: jidh fudud',
    '🙏🏼' => 'gacmo laaban: jidh fudud oo dhexe',
    '🙏🏽' => 'gacmo laaban: jidh nooc dhexe',
    '🙏🏾' => 'gacmo laaban: jidh nooc madaw oo dhexe',
    '🙏🏿' => 'gacmo laaban: jidh madaw',
    '✍🏻' => 'gacan wax qoraysa: jidh fudud',
    '✍🏼' => 'gacan wax qoraysa: jidh fudud oo dhexe',
    '✍🏽' => 'gacan wax qoraysa: jidh nooc dhexe',
    '✍🏾' => 'gacan wax qoraysa: jidh nooc madaw oo dhexe',
    '✍🏿' => 'gacan wax qoraysa: jidh madaw',
    '💅🏻' => 'dhalaalinta ciddiyaha: jidh fudud',
    '💅🏼' => 'dhalaalinta ciddiyaha: jidh fudud oo dhexe',
    '💅🏽' => 'dhalaalinta ciddiyaha: jidh nooc dhexe',
    '💅🏾' => 'dhalaalinta ciddiyaha: jidh nooc madaw oo dhexe',
    '💅🏿' => 'dhalaalinta ciddiyaha: jidh madaw',
    '🤳🏻' => 'sawir iska-qaadis: jidh fudud',
    '🤳🏼' => 'sawir iska-qaadis: jidh fudud oo dhexe',
    '🤳🏽' => 'sawir iska-qaadis: jidh nooc dhexe',
    '🤳🏾' => 'sawir iska-qaadis: jidh nooc madaw oo dhexe',
    '🤳🏿' => 'sawir iska-qaadis: jidh madaw',
    '💪🏻' => 'suxulka oo laaban: jidh fudud',
    '💪🏼' => 'suxulka oo laaban: jidh fudud oo dhexe',
    '💪🏽' => 'suxulka oo laaban: jidh nooc dhexe',
    '💪🏾' => 'suxulka oo laaban: jidh nooc madaw oo dhexe',
    '💪🏿' => 'suxulka oo laaban: jidh madaw',
    '🦵🏻' => 'lug: jidh fudud',
    '🦵🏼' => 'lug: jidh fudud oo dhexe',
    '🦵🏽' => 'lug: jidh nooc dhexe',
    '🦵🏾' => 'lug: jidh nooc madaw oo dhexe',
    '🦵🏿' => 'lug: jidh madaw',
    '🦶🏻' => 'cagta: jidh fudud',
    '🦶🏼' => 'cagta: jidh fudud oo dhexe',
    '🦶🏽' => 'cagta: jidh nooc dhexe',
    '🦶🏾' => 'cagta: jidh nooc madaw oo dhexe',
    '🦶🏿' => 'cagta: jidh madaw',
    '👂🏻' => 'dhagta: jidh fudud',
    '👂🏼' => 'dhagta: jidh fudud oo dhexe',
    '👂🏽' => 'dhagta: jidh nooc dhexe',
    '👂🏾' => 'dhagta: jidh nooc madaw oo dhexe',
    '👂🏿' => 'dhagta: jidh madaw',
    '🦻🏻' => 'dhag leh gargaarka maqalka: jidh fudud',
    '🦻🏼' => 'dhag leh gargaarka maqalka: jidh fudud oo dhexe',
    '🦻🏽' => 'dhag leh gargaarka maqalka: jidh nooc dhexe',
    '🦻🏾' => 'dhag leh gargaarka maqalka: jidh nooc madaw oo dhexe',
    '🦻🏿' => 'dhag leh gargaarka maqalka: jidh madaw',
    '👃🏻' => 'sanka: jidh fudud',
    '👃🏼' => 'sanka: jidh fudud oo dhexe',
    '👃🏽' => 'sanka: jidh nooc dhexe',
    '👃🏾' => 'sanka: jidh nooc madaw oo dhexe',
    '👃🏿' => 'sanka: jidh madaw',
    '👶🏻' => 'cunug: jidh fudud',
    '👶🏼' => 'cunug: jidh fudud oo dhexe',
    '👶🏽' => 'cunug: jidh nooc dhexe',
    '👶🏾' => 'cunug: jidh nooc madaw oo dhexe',
    '👶🏿' => 'cunug: jidh madaw',
    '🧒🏻' => 'ilmo: jidh fudud',
    '🧒🏼' => 'ilmo: jidh fudud oo dhexe',
    '🧒🏽' => 'ilmo: jidh nooc dhexe',
    '🧒🏾' => 'ilmo: jidh nooc madaw oo dhexe',
    '🧒🏿' => 'ilmo: jidh madaw',
    '👦🏻' => 'wiil: jidh fudud',
    '👦🏼' => 'wiil: jidh fudud oo dhexe',
    '👦🏽' => 'wiil: jidh nooc dhexe',
    '👦🏾' => 'wiil: jidh nooc madaw oo dhexe',
    '👦🏿' => 'wiil: jidh madaw',
    '👧🏻' => 'gabar: jidh fudud',
    '👧🏼' => 'gabar: jidh fudud oo dhexe',
    '👧🏽' => 'gabar: jidh nooc dhexe',
    '👧🏾' => 'gabar: jidh nooc madaw oo dhexe',
    '👧🏿' => 'gabar: jidh madaw',
    '🧑🏻' => 'qof: jidh fudud',
    '🧑🏼' => 'qof: jidh fudud oo dhexe',
    '🧑🏽' => 'qof: jidh nooc dhexe',
    '🧑🏾' => 'qof: jidh nooc madaw oo dhexe',
    '🧑🏿' => 'qof: jidh madaw',
    '👱🏻' => 'qof: jidh fudud, timo cad',
    '👱🏼' => 'qof: jidh fudud oo dhexe, timo cad',
    '👱🏽' => 'qof: jidh nooc dhexe, timo cad',
    '👱🏾' => 'qof: jidh nooc madaw oo dhexe, timo cad',
    '👱🏿' => 'qof: jidh madaw, timo cad',
    '👨🏻' => 'ninka: jidh fudud',
    '👨🏼' => 'ninka: jidh fudud oo dhexe',
    '👨🏽' => 'ninka: jidh nooc dhexe',
    '👨🏾' => 'ninka: jidh nooc madaw oo dhexe',
    '👨🏿' => 'ninka: jidh madaw',
    '🧔🏻' => 'nin: jidh fudud, gar',
    '🧔🏼' => 'nin: jidh fudud oo dhexe, gar',
    '🧔🏽' => 'nin: jidh nooc dhexe, gar',
    '🧔🏾' => 'nin: jidh nooc madaw oo dhexe, gar',
    '🧔🏿' => 'nin: jidh madaw, gar',
    '👩🏻' => 'naag: jidh fudud',
    '👩🏼' => 'naag: jidh fudud oo dhexe',
    '👩🏽' => 'naag: jidh nooc dhexe',
    '👩🏾' => 'naag: jidh nooc madaw oo dhexe',
    '👩🏿' => 'naag: jidh madaw',
    '🧓🏻' => 'qof weyn: jidh fudud',
    '🧓🏼' => 'qof weyn: jidh fudud oo dhexe',
    '🧓🏽' => 'qof weyn: jidh nooc dhexe',
    '🧓🏾' => 'qof weyn: jidh nooc madaw oo dhexe',
    '🧓🏿' => 'qof weyn: jidh madaw',
    '👴🏻' => 'nin da’ weyn: jidh fudud',
    '👴🏼' => 'nin da’ weyn: jidh fudud oo dhexe',
    '👴🏽' => 'nin da’ weyn: jidh nooc dhexe',
    '👴🏾' => 'nin da’ weyn: jidh nooc madaw oo dhexe',
    '👴🏿' => 'nin da’ weyn: jidh madaw',
    '👵🏻' => 'naag weyn: jidh fudud',
    '👵🏼' => 'naag weyn: jidh fudud oo dhexe',
    '👵🏽' => 'naag weyn: jidh nooc dhexe',
    '👵🏾' => 'naag weyn: jidh nooc madaw oo dhexe',
    '👵🏿' => 'naag weyn: jidh madaw',
    '🙍🏻' => 'qof wajiga kaduudaya: jidh fudud',
    '🙍🏼' => 'qof wajiga kaduudaya: jidh fudud oo dhexe',
    '🙍🏽' => 'qof wajiga kaduudaya: jidh nooc dhexe',
    '🙍🏾' => 'qof wajiga kaduudaya: jidh nooc madaw oo dhexe',
    '🙍🏿' => 'qof wajiga kaduudaya: jidh madaw',
    '🙎🏻' => 'bushin qaniinidda: jidh fudud',
    '🙎🏼' => 'bushin qaniinidda: jidh fudud oo dhexe',
    '🙎🏽' => 'bushin qaniinidda: jidh nooc dhexe',
    '🙎🏾' => 'bushin qaniinidda: jidh nooc madaw oo dhexe',
    '🙎🏿' => 'bushin qaniinidda: jidh madaw',
    '🙅🏻' => 'qof ku meedaaraya MAYA: jidh fudud',
    '🙅🏼' => 'qof ku meedaaraya MAYA: jidh fudud oo dhexe',
    '🙅🏽' => 'qof ku meedaaraya MAYA: jidh nooc dhexe',
    '🙅🏾' => 'qof ku meedaaraya MAYA: jidh nooc madaw oo dhexe',
    '🙅🏿' => 'qof ku meedaaraya MAYA: jidh madaw',
    '🙆🏻' => 'naag ku meedaaraysa HAA: jidh fudud',
    '🙆🏼' => 'naag ku meedaaraysa HAA: jidh fudud oo dhexe',
    '🙆🏽' => 'naag ku meedaaraysa HAA: jidh nooc dhexe',
    '🙆🏾' => 'naag ku meedaaraysa HAA: jidh nooc madaw oo dhexe',
    '🙆🏿' => 'naag ku meedaaraysa HAA: jidh madaw',
    '💁🏻' => 'qof warbixin bixinaya: jidh fudud',
    '💁🏼' => 'qof warbixin bixinaya: jidh fudud oo dhexe',
    '💁🏽' => 'qof warbixin bixinaya: jidh nooc dhexe',
    '💁🏾' => 'qof warbixin bixinaya: jidh nooc madaw oo dhexe',
    '💁🏿' => 'qof warbixin bixinaya: jidh madaw',
    '🙋🏻' => 'qof gacan taagaya: jidh fudud',
    '🙋🏼' => 'qof gacan taagaya: jidh fudud oo dhexe',
    '🙋🏽' => 'qof gacan taagaya: jidh nooc dhexe',
    '🙋🏾' => 'qof gacan taagaya: jidh nooc madaw oo dhexe',
    '🙋🏿' => 'qof gacan taagaya: jidh madaw',
    '🧏🏻' => 'qof dhagoole ah: jidh fudud',
    '🧏🏼' => 'qof dhagoole ah: jidh fudud oo dhexe',
    '🧏🏽' => 'qof dhagoole ah: jidh nooc dhexe',
    '🧏🏾' => 'qof dhagoole ah: jidh nooc madaw oo dhexe',
    '🧏🏿' => 'qof dhagoole ah: jidh madaw',
    '🙇🏻' => 'qof fooraraya: jidh fudud',
    '🙇🏼' => 'qof fooraraya: jidh fudud oo dhexe',
    '🙇🏽' => 'qof fooraraya: jidh nooc dhexe',
    '🙇🏾' => 'qof fooraraya: jidh nooc madaw oo dhexe',
    '🙇🏿' => 'qof fooraraya: jidh madaw',
    '🤦🏻' => 'qof calaacal waji saaranaya: jidh fudud',
    '🤦🏼' => 'qof calaacal waji saaranaya: jidh fudud oo dhexe',
    '🤦🏽' => 'qof calaacal waji saaranaya: jidh nooc dhexe',
    '🤦🏾' => 'qof calaacal waji saaranaya: jidh nooc madaw oo dhexe',
    '🤦🏿' => 'qof calaacal waji saaranaya: jidh madaw',
    '🤷🏻' => 'qof garba-ruxaya: jidh fudud',
    '🤷🏼' => 'qof garba-ruxaya: jidh fudud oo dhexe',
    '🤷🏽' => 'qof garba-ruxaya: jidh nooc dhexe',
    '🤷🏾' => 'qof garba-ruxaya: jidh nooc madaw oo dhexe',
    '🤷🏿' => 'qof garba-ruxaya: jidh madaw',
    '👮🏻' => 'sarkaal boolis: jidh fudud',
    '👮🏼' => 'sarkaal boolis: jidh fudud oo dhexe',
    '👮🏽' => 'sarkaal boolis: jidh nooc dhexe',
    '👮🏾' => 'sarkaal boolis: jidh nooc madaw oo dhexe',
    '👮🏿' => 'sarkaal boolis: jidh madaw',
    '🕵🏻' => 'dambi-baare: jidh fudud',
    '🕵🏼' => 'dambi-baare: jidh fudud oo dhexe',
    '🕵🏽' => 'dambi-baare: jidh nooc dhexe',
    '🕵🏾' => 'dambi-baare: jidh nooc madaw oo dhexe',
    '🕵🏿' => 'dambi-baare: jidh madaw',
    '💂🏻' => 'ilaaliye: jidh fudud',
    '💂🏼' => 'ilaaliye: jidh fudud oo dhexe',
    '💂🏽' => 'ilaaliye: jidh nooc dhexe',
    '💂🏾' => 'ilaaliye: jidh nooc madaw oo dhexe',
    '💂🏿' => 'ilaaliye: jidh madaw',
    '🥷🏻' => 'ninja: jidh fudud',
    '🥷🏼' => 'ninja: jidh fudud oo dhexe',
    '🥷🏽' => 'ninja: jidh nooc dhexe',
    '🥷🏾' => 'ninja: jidh nooc madaw oo dhexe',
    '🥷🏿' => 'ninja: jidh madaw',
    '👷🏻' => 'shaqaale dhismo: jidh fudud',
    '👷🏼' => 'shaqaale dhismo: jidh fudud oo dhexe',
    '👷🏽' => 'shaqaale dhismo: jidh nooc dhexe',
    '👷🏾' => 'shaqaale dhismo: jidh nooc madaw oo dhexe',
    '👷🏿' => 'shaqaale dhismo: jidh madaw',
    '🫅🏻' => 'qof leh taaj: jidh fudud',
    '🫅🏼' => 'qof leh taaj: jidh fudud oo dhexe',
    '🫅🏽' => 'qof leh taaj: jidh nooc dhexe',
    '🫅🏾' => 'qof leh taaj: jidh nooc madaw oo dhexe',
    '🫅🏿' => 'qof leh taaj: jidh madaw',
    '🤴🏻' => 'boqor: jidh fudud',
    '🤴🏼' => 'boqor: jidh fudud oo dhexe',
    '🤴🏽' => 'boqor: jidh nooc dhexe',
    '🤴🏾' => 'boqor: jidh nooc madaw oo dhexe',
    '🤴🏿' => 'boqor: jidh madaw',
    '👸🏻' => 'boqorad: jidh fudud',
    '👸🏼' => 'boqorad: jidh fudud oo dhexe',
    '👸🏽' => 'boqorad: jidh nooc dhexe',
    '👸🏾' => 'boqorad: jidh nooc madaw oo dhexe',
    '👸🏿' => 'boqorad: jidh madaw',
    '👳🏻' => 'qof cammaamad xiran: jidh fudud',
    '👳🏼' => 'qof cammaamad xiran: jidh fudud oo dhexe',
    '👳🏽' => 'qof cammaamad xiran: jidh nooc dhexe',
    '👳🏾' => 'qof cammaamad xiran: jidh nooc madaw oo dhexe',
    '👳🏿' => 'qof cammaamad xiran: jidh madaw',
    '👲🏻' => 'nin xiran koofiyadda shiinaha: jidh fudud',
    '👲🏼' => 'nin xiran koofiyadda shiinaha: jidh fudud oo dhexe',
    '👲🏽' => 'nin xiran koofiyadda shiinaha: jidh nooc dhexe',
    '👲🏾' => 'nin xiran koofiyadda shiinaha: jidh nooc madaw oo dhexe',
    '👲🏿' => 'nin xiran koofiyadda shiinaha: jidh madaw',
    '🧕🏻' => 'naag xiran qammaar: jidh fudud',
    '🧕🏼' => 'naag xiran qammaar: jidh fudud oo dhexe',
    '🧕🏽' => 'naag xiran qammaar: jidh nooc dhexe',
    '🧕🏾' => 'naag xiran qammaar: jidh nooc madaw oo dhexe',
    '🧕🏿' => 'naag xiran qammaar: jidh madaw',
    '🤵🏻' => 'nin xiran suudka rasmiga ah: jidh fudud',
    '🤵🏼' => 'nin xiran suudka rasmiga ah: jidh fudud oo dhexe',
    '🤵🏽' => 'nin xiran suudka rasmiga ah: jidh nooc dhexe',
    '🤵🏾' => 'nin xiran suudka rasmiga ah: jidh nooc madaw oo dhexe',
    '🤵🏿' => 'nin xiran suudka rasmiga ah: jidh madaw',
    '👰🏻' => 'shaqsi niqaam xidhan: jidh fudud',
    '👰🏼' => 'shaqsi niqaam xidhan: jidh fudud oo dhexe',
    '👰🏽' => 'shaqsi niqaam xidhan: jidh nooc dhexe',
    '👰🏾' => 'shaqsi niqaam xidhan: jidh nooc madaw oo dhexe',
    '👰🏿' => 'shaqsi niqaam xidhan: jidh madaw',
    '🤰🏻' => 'haweeney uur leh: jidh fudud',
    '🤰🏼' => 'haweeney uur leh: jidh fudud oo dhexe',
    '🤰🏽' => 'haweeney uur leh: jidh nooc dhexe',
    '🤰🏾' => 'haweeney uur leh: jidh nooc madaw oo dhexe',
    '🤰🏿' => 'haweeney uur leh: jidh madaw',
    '🫃🏻' => 'nin uur leh: jidh fudud',
    '🫃🏼' => 'nin uur leh: jidh fudud oo dhexe',
    '🫃🏽' => 'nin uur leh: jidh nooc dhexe',
    '🫃🏾' => 'nin uur leh: jidh nooc madaw oo dhexe',
    '🫃🏿' => 'nin uur leh: jidh madaw',
    '🫄🏻' => 'qof uur leh: jidh fudud',
    '🫄🏼' => 'qof uur leh: jidh fudud oo dhexe',
    '🫄🏽' => 'qof uur leh: jidh nooc dhexe',
    '🫄🏾' => 'qof uur leh: jidh nooc madaw oo dhexe',
    '🫄🏿' => 'qof uur leh: jidh madaw',
    '🤱🏻' => 'naas-nuujin: jidh fudud',
    '🤱🏼' => 'naas-nuujin: jidh fudud oo dhexe',
    '🤱🏽' => 'naas-nuujin: jidh nooc dhexe',
    '🤱🏾' => 'naas-nuujin: jidh nooc madaw oo dhexe',
    '🤱🏿' => 'naas-nuujin: jidh madaw',
    '👼🏻' => 'malaa’igta caruurta: jidh fudud',
    '👼🏼' => 'malaa’igta caruurta: jidh fudud oo dhexe',
    '👼🏽' => 'malaa’igta caruurta: jidh nooc dhexe',
    '👼🏾' => 'malaa’igta caruurta: jidh nooc madaw oo dhexe',
    '👼🏿' => 'malaa’igta caruurta: jidh madaw',
    '🎅🏻' => 'Aabaha Ciidda Masiixigga: jidh fudud',
    '🎅🏼' => 'Aabaha Ciidda Masiixigga: jidh fudud oo dhexe',
    '🎅🏽' => 'Aabaha Ciidda Masiixigga: jidh nooc dhexe',
    '🎅🏾' => 'Aabaha Ciidda Masiixigga: jidh nooc madaw oo dhexe',
    '🎅🏿' => 'Aabaha Ciidda Masiixigga: jidh madaw',
    '🤶🏻' => 'Marwada Masiixigga: jidh fudud',
    '🤶🏼' => 'Marwada Masiixigga: jidh fudud oo dhexe',
    '🤶🏽' => 'Marwada Masiixigga: jidh nooc dhexe',
    '🤶🏾' => 'Marwada Masiixigga: jidh nooc madaw oo dhexe',
    '🤶🏿' => 'Marwada Masiixigga: jidh madaw',
    '🦸🏻' => 'halyeey ah: jidh fudud',
    '🦸🏼' => 'halyeey ah: jidh fudud oo dhexe',
    '🦸🏽' => 'halyeey ah: jidh nooc dhexe',
    '🦸🏾' => 'halyeey ah: jidh nooc madaw oo dhexe',
    '🦸🏿' => 'halyeey ah: jidh madaw',
    '🦹🏻' => 'qof sheyddaankiisu sareeyo: jidh fudud',
    '🦹🏼' => 'qof sheyddaankiisu sareeyo: jidh fudud oo dhexe',
    '🦹🏽' => 'qof sheyddaankiisu sareeyo: jidh nooc dhexe',
    '🦹🏾' => 'qof sheyddaankiisu sareeyo: jidh nooc madaw oo dhexe',
    '🦹🏿' => 'qof sheyddaankiisu sareeyo: jidh madaw',
    '🧙🏻' => 'sixiroole: jidh fudud',
    '🧙🏼' => 'sixiroole: jidh fudud oo dhexe',
    '🧙🏽' => 'sixiroole: jidh nooc dhexe',
    '🧙🏾' => 'sixiroole: jidh nooc madaw oo dhexe',
    '🧙🏿' => 'sixiroole: jidh madaw',
    '🧚🏻' => 'qurux badan: jidh fudud',
    '🧚🏼' => 'qurux badan: jidh fudud oo dhexe',
    '🧚🏽' => 'qurux badan: jidh nooc dhexe',
    '🧚🏾' => 'qurux badan: jidh nooc madaw oo dhexe',
    '🧚🏿' => 'qurux badan: jidh madaw',
    '🧛🏻' => 'reer-aakhiraad dhiig cab ah: jidh fudud',
    '🧛🏼' => 'reer-aakhiraad dhiig cab ah: jidh fudud oo dhexe',
    '🧛🏽' => 'reer-aakhiraad dhiig cab ah: jidh nooc dhexe',
    '🧛🏾' => 'reer-aakhiraad dhiig cab ah: jidh nooc madaw oo dhexe',
    '🧛🏿' => 'reer-aakhiraad dhiig cab ah: jidh madaw',
    '🧜🏻' => 'qof cajiib ah: jidh fudud',
    '🧜🏼' => 'qof cajiib ah: jidh fudud oo dhexe',
    '🧜🏽' => 'qof cajiib ah: jidh nooc dhexe',
    '🧜🏾' => 'qof cajiib ah: jidh nooc madaw oo dhexe',
    '🧜🏿' => 'qof cajiib ah: jidh madaw',
    '🧝🏻' => 'ruuxaan: jidh fudud',
    '🧝🏼' => 'ruuxaan: jidh fudud oo dhexe',
    '🧝🏽' => 'ruuxaan: jidh nooc dhexe',
    '🧝🏾' => 'ruuxaan: jidh nooc madaw oo dhexe',
    '🧝🏿' => 'ruuxaan: jidh madaw',
    '💆🏻' => 'qof loo duugayo: jidh fudud',
    '💆🏼' => 'qof loo duugayo: jidh fudud oo dhexe',
    '💆🏽' => 'qof loo duugayo: jidh nooc dhexe',
    '💆🏾' => 'qof loo duugayo: jidh nooc madaw oo dhexe',
    '💆🏿' => 'qof loo duugayo: jidh madaw',
    '💇🏻' => 'qof timaha loo jarayo: jidh fudud',
    '💇🏼' => 'qof timaha loo jarayo: jidh fudud oo dhexe',
    '💇🏽' => 'qof timaha loo jarayo: jidh nooc dhexe',
    '💇🏾' => 'qof timaha loo jarayo: jidh nooc madaw oo dhexe',
    '💇🏿' => 'qof timaha loo jarayo: jidh madaw',
    '🚶🏻' => 'qof soconaya: jidh fudud',
    '🚶🏼' => 'qof soconaya: jidh fudud oo dhexe',
    '🚶🏽' => 'qof soconaya: jidh nooc dhexe',
    '🚶🏾' => 'qof soconaya: jidh nooc madaw oo dhexe',
    '🚶🏿' => 'qof soconaya: jidh madaw',
    '🧍🏻' => 'qof taaggan: jidh fudud',
    '🧍🏼' => 'qof taaggan: jidh fudud oo dhexe',
    '🧍🏽' => 'qof taaggan: jidh nooc dhexe',
    '🧍🏾' => 'qof taaggan: jidh nooc madaw oo dhexe',
    '🧍🏿' => 'qof taaggan: jidh madaw',
    '🧎🏻' => 'qof jilbaha dhiganaya: jidh fudud',
    '🧎🏼' => 'qof jilbaha dhiganaya: jidh fudud oo dhexe',
    '🧎🏽' => 'qof jilbaha dhiganaya: jidh nooc dhexe',
    '🧎🏾' => 'qof jilbaha dhiganaya: jidh nooc madaw oo dhexe',
    '🧎🏿' => 'qof jilbaha dhiganaya: jidh madaw',
    '🏃🏻' => 'qof ordaya: jidh fudud',
    '🏃🏼' => 'qof ordaya: jidh fudud oo dhexe',
    '🏃🏽' => 'qof ordaya: jidh nooc dhexe',
    '🏃🏾' => 'qof ordaya: jidh nooc madaw oo dhexe',
    '🏃🏿' => 'qof ordaya: jidh madaw',
    '💃🏻' => 'naag qoob-ka-cayaaraysa: jidh fudud',
    '💃🏼' => 'naag qoob-ka-cayaaraysa: jidh fudud oo dhexe',
    '💃🏽' => 'naag qoob-ka-cayaaraysa: jidh nooc dhexe',
    '💃🏾' => 'naag qoob-ka-cayaaraysa: jidh nooc madaw oo dhexe',
    '💃🏿' => 'naag qoob-ka-cayaaraysa: jidh madaw',
    '🕺🏻' => 'nin qoob-ka-cayaaraya: jidh fudud',
    '🕺🏼' => 'nin qoob-ka-cayaaraya: jidh fudud oo dhexe',
    '🕺🏽' => 'nin qoob-ka-cayaaraya: jidh nooc dhexe',
    '🕺🏾' => 'nin qoob-ka-cayaaraya: jidh nooc madaw oo dhexe',
    '🕺🏿' => 'nin qoob-ka-cayaaraya: jidh madaw',
    '🕴🏻' => 'nin suud xiran oo milicsanaya: jidh fudud',
    '🕴🏼' => 'nin suud xiran oo milicsanaya: jidh fudud oo dhexe',
    '🕴🏽' => 'nin suud xiran oo milicsanaya: jidh nooc dhexe',
    '🕴🏾' => 'nin suud xiran oo milicsanaya: jidh nooc madaw oo dhexe',
    '🕴🏿' => 'nin suud xiran oo milicsanaya: jidh madaw',
    '👯🏻' => 'dad leh dhaggo bakayle: jidh fudud',
    '👯🏼' => 'dad leh dhaggo bakayle: jidh fudud oo dhexe',
    '👯🏽' => 'dad leh dhaggo bakayle: jidh nooc dhexe',
    '👯🏾' => 'dad leh dhaggo bakayle: jidh nooc madaw oo dhexe',
    '👯🏿' => 'dad leh dhaggo bakayle: jidh madaw',
    '🧖🏻' => 'qof ku jira qol uummi ah: jidh fudud',
    '🧖🏼' => 'qof ku jira qol uummi ah: jidh fudud oo dhexe',
    '🧖🏽' => 'qof ku jira qol uummi ah: jidh nooc dhexe',
    '🧖🏾' => 'qof ku jira qol uummi ah: jidh nooc madaw oo dhexe',
    '🧖🏿' => 'qof ku jira qol uummi ah: jidh madaw',
    '🧗🏻' => 'qof meel fuulaya: jidh fudud',
    '🧗🏼' => 'qof meel fuulaya: jidh fudud oo dhexe',
    '🧗🏽' => 'qof meel fuulaya: jidh nooc dhexe',
    '🧗🏾' => 'qof meel fuulaya: jidh nooc madaw oo dhexe',
    '🧗🏿' => 'qof meel fuulaya: jidh madaw',
    '🏇🏻' => 'tartan fardoodka: jidh fudud',
    '🏇🏼' => 'tartan fardoodka: jidh fudud oo dhexe',
    '🏇🏽' => 'tartan fardoodka: jidh nooc dhexe',
    '🏇🏾' => 'tartan fardoodka: jidh nooc madaw oo dhexe',
    '🏇🏿' => 'tartan fardoodka: jidh madaw',
    '🏂🏻' => 'qofka alwaaxa barafka kula socda: jidh fudud',
    '🏂🏼' => 'qofka alwaaxa barafka kula socda: jidh fudud oo dhexe',
    '🏂🏽' => 'qofka alwaaxa barafka kula socda: jidh nooc dhexe',
    '🏂🏾' => 'qofka alwaaxa barafka kula socda: jidh nooc madaw oo dhexe',
    '🏂🏿' => 'qofka alwaaxa barafka kula socda: jidh madaw',
    '🏌🏻' => 'qof cayaaraya goolof: jidh fudud',
    '🏌🏼' => 'qof cayaaraya goolof: jidh fudud oo dhexe',
    '🏌🏽' => 'qof cayaaraya goolof: jidh nooc dhexe',
    '🏌🏾' => 'qof cayaaraya goolof: jidh nooc madaw oo dhexe',
    '🏌🏿' => 'qof cayaaraya goolof: jidh madaw',
    '🏄🏻' => 'qof alwaaxa hirka biyaha kula soconaya: jidh fudud',
    '🏄🏼' => 'qof alwaaxa hirka biyaha kula soconaya: jidh fudud oo dhexe',
    '🏄🏽' => 'qof alwaaxa hirka biyaha kula soconaya: jidh nooc dhexe',
    '🏄🏾' => 'qof alwaaxa hirka biyaha kula soconaya: jidh nooc madaw oo dhexe',
    '🏄🏿' => 'qof alwaaxa hirka biyaha kula soconaya: jidh madaw',
    '🚣🏻' => 'qof doon wada: jidh fudud',
    '🚣🏼' => 'qof doon wada: jidh fudud oo dhexe',
    '🚣🏽' => 'qof doon wada: jidh nooc dhexe',
    '🚣🏾' => 'qof doon wada: jidh nooc madaw oo dhexe',
    '🚣🏿' => 'qof doon wada: jidh madaw',
    '🏊🏻' => 'qof dabaalanaya: jidh fudud',
    '🏊🏼' => 'qof dabaalanaya: jidh fudud oo dhexe',
    '🏊🏽' => 'qof dabaalanaya: jidh nooc dhexe',
    '🏊🏾' => 'qof dabaalanaya: jidh nooc madaw oo dhexe',
    '🏊🏿' => 'qof dabaalanaya: jidh madaw',
    '⛹🏻' => 'qof cayaaraya kubadda boodda: jidh fudud',
    '⛹🏼' => 'qof cayaaraya kubadda boodda: jidh fudud oo dhexe',
    '⛹🏽' => 'qof cayaaraya kubadda boodda: jidh nooc dhexe',
    '⛹🏾' => 'qof cayaaraya kubadda boodda: jidh nooc madaw oo dhexe',
    '⛹🏿' => 'qof cayaaraya kubadda boodda: jidh madaw',
    '🏋🏻' => 'qof qaadaya culeyska: jidh fudud',
    '🏋🏼' => 'qof qaadaya culeyska: jidh fudud oo dhexe',
    '🏋🏽' => 'qof qaadaya culeyska: jidh nooc dhexe',
    '🏋🏾' => 'qof qaadaya culeyska: jidh nooc madaw oo dhexe',
    '🏋🏿' => 'qof qaadaya culeyska: jidh madaw',
    '🚴🏻' => 'qof baaskiil wada: jidh fudud',
    '🚴🏼' => 'qof baaskiil wada: jidh fudud oo dhexe',
    '🚴🏽' => 'qof baaskiil wada: jidh nooc dhexe',
    '🚴🏾' => 'qof baaskiil wada: jidh nooc madaw oo dhexe',
    '🚴🏿' => 'qof baaskiil wada: jidh madaw',
    '🚵🏻' => 'qof baaskiil buur ku wada: jidh fudud',
    '🚵🏼' => 'qof baaskiil buur ku wada: jidh fudud oo dhexe',
    '🚵🏽' => 'qof baaskiil buur ku wada: jidh nooc dhexe',
    '🚵🏾' => 'qof baaskiil buur ku wada: jidh nooc madaw oo dhexe',
    '🚵🏿' => 'qof baaskiil buur ku wada: jidh madaw',
    '🤸🏻' => 'qof samayanaya jimicsiga gacma saarka: jidh fudud',
    '🤸🏼' => 'qof samayanaya jimicsiga gacma saarka: jidh fudud oo dhexe',
    '🤸🏽' => 'qof samayanaya jimicsiga gacma saarka: jidh nooc dhexe',
    '🤸🏾' => 'qof samayanaya jimicsiga gacma saarka: jidh nooc madaw oo dhexe',
    '🤸🏿' => 'qof samayanaya jimicsiga gacma saarka: jidh madaw',
    '🤼🏻' => 'dad lagdamaya: jidh fudud',
    '🤼🏼' => 'dad lagdamaya: jidh fudud oo dhexe',
    '🤼🏽' => 'dad lagdamaya: jidh nooc dhexe',
    '🤼🏾' => 'dad lagdamaya: jidh nooc madaw oo dhexe',
    '🤼🏿' => 'dad lagdamaya: jidh madaw',
    '🤽🏻' => 'qof cayaaraya kubadda biyaha: jidh fudud',
    '🤽🏼' => 'qof cayaaraya kubadda biyaha: jidh fudud oo dhexe',
    '🤽🏽' => 'qof cayaaraya kubadda biyaha: jidh nooc dhexe',
    '🤽🏾' => 'qof cayaaraya kubadda biyaha: jidh nooc madaw oo dhexe',
    '🤽🏿' => 'qof cayaaraya kubadda biyaha: jidh madaw',
    '🤾🏻' => 'qof cayaaraya kubadda gacanta: jidh fudud',
    '🤾🏼' => 'qof cayaaraya kubadda gacanta: jidh fudud oo dhexe',
    '🤾🏽' => 'qof cayaaraya kubadda gacanta: jidh nooc dhexe',
    '🤾🏾' => 'qof cayaaraya kubadda gacanta: jidh nooc madaw oo dhexe',
    '🤾🏿' => 'qof cayaaraya kubadda gacanta: jidh madaw',
    '🤹🏻' => 'qof shaqo badan wada qabanaya: jidh fudud',
    '🤹🏼' => 'qof shaqo badan wada qabanaya: jidh fudud oo dhexe',
    '🤹🏽' => 'qof shaqo badan wada qabanaya: jidh nooc dhexe',
    '🤹🏾' => 'qof shaqo badan wada qabanaya: jidh nooc madaw oo dhexe',
    '🤹🏿' => 'qof shaqo badan wada qabanaya: jidh madaw',
    '🧘🏻' => 'qof ku jira habka fadhiga luga is gudubka: jidh fudud',
    '🧘🏼' => 'qof ku jira habka fadhiga luga is gudubka: jidh fudud oo dhexe',
    '🧘🏽' => 'qof ku jira habka fadhiga luga is gudubka: jidh nooc dhexe',
    '🧘🏾' => 'qof ku jira habka fadhiga luga is gudubka: jidh nooc madaw oo dhexe',
    '🧘🏿' => 'qof ku jira habka fadhiga luga is gudubka: jidh madaw',
    '🛀🏻' => 'qof qubeysanaya: jidh fudud',
    '🛀🏼' => 'qof qubeysanaya: jidh fudud oo dhexe',
    '🛀🏽' => 'qof qubeysanaya: jidh nooc dhexe',
    '🛀🏾' => 'qof qubeysanaya: jidh nooc madaw oo dhexe',
    '🛀🏿' => 'qof qubeysanaya: jidh madaw',
    '🛌🏻' => 'qof sariir ku jira: jidh fudud',
    '🛌🏼' => 'qof sariir ku jira: jidh fudud oo dhexe',
    '🛌🏽' => 'qof sariir ku jira: jidh nooc dhexe',
    '🛌🏾' => 'qof sariir ku jira: jidh nooc madaw oo dhexe',
    '🛌🏿' => 'qof sariir ku jira: jidh madaw',
    '👭🏻' => 'haween haysta is gacmaha: jidh fudud',
    '👭🏼' => 'haween haysta is gacmaha: jidh fudud oo dhexe',
    '👭🏽' => 'haween haysta is gacmaha: jidh nooc dhexe',
    '👭🏾' => 'haween haysta is gacmaha: jidh nooc madaw oo dhexe',
    '👭🏿' => 'haween haysta is gacmaha: jidh madaw',
    '👫🏻' => 'naag iyo nin gacmaha is haysta: jidh fudud',
    '👫🏼' => 'naag iyo nin gacmaha is haysta: jidh fudud oo dhexe',
    '👫🏽' => 'naag iyo nin gacmaha is haysta: jidh nooc dhexe',
    '👫🏾' => 'naag iyo nin gacmaha is haysta: jidh nooc madaw oo dhexe',
    '👫🏿' => 'naag iyo nin gacmaha is haysta: jidh madaw',
    '👬🏻' => 'laba nin oo gacmaha is haysta: jidh fudud',
    '👬🏼' => 'laba nin oo gacmaha is haysta: jidh fudud oo dhexe',
    '👬🏽' => 'laba nin oo gacmaha is haysta: jidh nooc dhexe',
    '👬🏾' => 'laba nin oo gacmaha is haysta: jidh nooc madaw oo dhexe',
    '👬🏿' => 'laba nin oo gacmaha is haysta: jidh madaw',
    '💏🏻' => 'shumis: jidh fudud',
    '💏🏼' => 'shumis: jidh fudud oo dhexe',
    '💏🏽' => 'shumis: jidh nooc dhexe',
    '💏🏾' => 'shumis: jidh nooc madaw oo dhexe',
    '💏🏿' => 'shumis: jidh madaw',
    '💑🏻' => 'lammaane is jecel: jidh fudud',
    '💑🏼' => 'lammaane is jecel: jidh fudud oo dhexe',
    '💑🏽' => 'lammaane is jecel: jidh nooc dhexe',
    '💑🏾' => 'lammaane is jecel: jidh nooc madaw oo dhexe',
    '💑🏿' => 'lammaane is jecel: jidh madaw',
    '🇦🇨' => 'calan: Jasiiradda Asensiyoon',
    '🇦🇩' => 'calan: Andora',
    '🇦🇪' => 'calan: Midawga Imaaraatka Carabta',
    '🇦🇫' => 'calan: Afgaanistaan',
    '🇦🇬' => 'calan: Antigua & Barbuuda',
    '🇦🇮' => 'calan: Anguula',
    '🇦🇱' => 'calan: Albaaniya',
    '🇦🇲' => 'calan: Armeeniya',
    '🇦🇴' => 'calan: Angoola',
    '🇦🇶' => 'calan: Antaarktika',
    '🇦🇷' => 'calan: Arjentiina',
    '🇦🇸' => 'calan: Samowa Ameerika',
    '🇦🇹' => 'calan: Awsteriya',
    '🇦🇺' => 'calan: Awstaraaliya',
    '🇦🇼' => 'calan: Aruba',
    '🇦🇽' => 'calan: Jasiiradda Aland',
    '🇦🇿' => 'calan: Asarbajan',
    '🇧🇦' => 'calan: Boosniya & Harsegofina',
    '🇧🇧' => 'calan: Baarbadoos',
    '🇧🇩' => 'calan: Bangaladhesh',
    '🇧🇪' => 'calan: Biljam',
    '🇧🇫' => 'calan: Burkiina Faaso',
    '🇧🇬' => 'calan: Bulgaariya',
    '🇧🇭' => 'calan: Baxreyn',
    '🇧🇮' => 'calan: Burundi',
    '🇧🇯' => 'calan: Biniin',
    '🇧🇱' => 'calan: St. Baathelemiy',
    '🇧🇲' => 'calan: Barmuuda',
    '🇧🇳' => 'calan: Buruneey',
    '🇧🇴' => 'calan: Boliifiya',
    '🇧🇶' => 'calan: Karibiyaan Nadarlands',
    '🇧🇷' => 'calan: Baraasiil',
    '🇧🇸' => 'calan: Bahaamas',
    '🇧🇹' => 'calan: Buutan',
    '🇧🇻' => 'calan: Buufet Island',
    '🇧🇼' => 'calan: Botuswaana',
    '🇧🇾' => 'calan: Belarus',
    '🇧🇿' => 'calan: Beliis',
    '🇨🇦' => 'calan: Kanada',
    '🇨🇨' => 'calan: Jasiiradda Kookoos',
    '🇨🇩' => 'calan: Jamhuuriyadda Dimuquraadiga Kongo',
    '🇨🇫' => 'calan: Jamhuuriyadda Afrikada Dhexe',
    '🇨🇬' => 'calan: Kongo',
    '🇨🇭' => 'calan: Swiiserlaand',
    '🇨🇮' => 'calan: Ayfori Koost',
    '🇨🇰' => 'calan: Jasiiradda Kook',
    '🇨🇱' => 'calan: Jili',
    '🇨🇲' => 'calan: Kaameruun',
    '🇨🇳' => 'calan: Shiinaha',
    '🇨🇴' => 'calan: Koloombiya',
    '🇨🇵' => 'calan: Jasiiradda Kilibarton',
    '🇨🇶' => 'calan: Sark',
    '🇨🇷' => 'calan: Costa Rica',
    '🇨🇺' => 'calan: Kuuba',
    '🇨🇻' => 'calan: Jasiiradda Kayb Faarde',
    '🇨🇼' => 'calan: Kurakaaw',
    '🇨🇽' => 'calan: Jasiiradda Kirismas',
    '🇨🇾' => 'calan: Qubrus',
    '🇨🇿' => 'calan: Jekiya',
    '🇩🇪' => 'calan: Jarmal',
    '🇩🇬' => 'calan: Diyeego Karsiya',
    '🇩🇯' => 'calan: Jabuuti',
    '🇩🇰' => 'calan: Denmark',
    '🇩🇲' => 'calan: Dominika',
    '🇩🇴' => 'calan: Jamhuuriyaddda Dominika',
    '🇩🇿' => 'calan: Aljeeriya',
    '🇪🇦' => 'calan: Seyuta & Meliila',
    '🇪🇨' => 'calan: Ikuwadoor',
    '🇪🇪' => 'calan: Estooniya',
    '🇪🇬' => 'calan: Masar',
    '🇪🇭' => 'calan: Saxaraha Galbeed',
    '🇪🇷' => 'calan: Eritreeya',
    '🇪🇸' => 'calan: Isbeyn',
    '🇪🇹' => 'calan: Itoobiya',
    '🇪🇺' => 'calan: Midowga Yurub',
    '🇫🇮' => 'calan: Finland',
    '🇫🇯' => 'calan: Fiji',
    '🇫🇰' => 'calan: Jaziiradaha Fooklaan',
    '🇫🇲' => 'calan: Mikroneesiya',
    '🇫🇴' => 'calan: Jasiiradda Faroo',
    '🇫🇷' => 'calan: Faransiis',
    '🇬🇦' => 'calan: Gaaboon',
    '🇬🇧' => 'calan: Boqortooyada Midowday',
    '🇬🇩' => 'calan: Giriinaada',
    '🇬🇪' => 'calan: Joorjiya',
    '🇬🇫' => 'calan: Faransiis Gini',
    '🇬🇬' => 'calan: Guurnsey',
    '🇬🇭' => 'calan: Gaana',
    '🇬🇮' => 'calan: Gibraltar',
    '🇬🇱' => 'calan: Greenland',
    '🇬🇲' => 'calan: Gambiya',
    '🇬🇳' => 'calan: Gini',
    '🇬🇵' => 'calan: Guadeluub',
    '🇬🇶' => 'calan: Ekuwatooriyal Gini',
    '🇬🇷' => 'calan: Giriig',
    '🇬🇸' => 'calan: Jasiiradda Joorjiyada Koonfureed & Sandwij',
    '🇬🇹' => 'calan: Guwaatamaala',
    '🇬🇺' => 'calan: Guaam',
    '🇬🇼' => 'calan: Gini-Bisaaw',
    '🇬🇾' => 'calan: Guyana',
    '🇭🇰' => 'calan: Hong Kong',
    '🇭🇲' => 'calan: Jasiiradda Haad & MakDonald',
    '🇭🇳' => 'calan: Honduras',
    '🇭🇷' => 'calan: Korweeshiya',
    '🇭🇹' => 'calan: Haiti',
    '🇭🇺' => 'calan: Hangari',
    '🇮🇨' => 'calan: Jasiiradda Kanari',
    '🇮🇩' => 'calan: Indoneesiya',
    '🇮🇪' => 'calan: Ayrlaand',
    '🇮🇱' => 'calan: Israaʼiil',
    '🇮🇲' => 'calan: Jasiiradda Isle of Man',
    '🇮🇳' => 'calan: Hindiya',
    '🇮🇴' => 'calan: Dhul xadeedka Badweynta Hindiya ee Ingiriiska',
    '🇮🇶' => 'calan: Ciraaq',
    '🇮🇷' => 'calan: Iiraan',
    '🇮🇸' => 'calan: Ayslaand',
    '🇮🇹' => 'calan: Talyaani',
    '🇯🇪' => 'calan: Jaarsey',
    '🇯🇲' => 'calan: Jamaaika',
    '🇯🇴' => 'calan: Urdun',
    '🇯🇵' => 'calan: Jabaan',
    '🇰🇪' => 'calan: Kenya',
    '🇰🇬' => 'calan: Kirgistaan',
    '🇰🇭' => 'calan: Kamboodiya',
    '🇰🇮' => 'calan: Kiribati',
    '🇰🇲' => 'calan: Komooros',
    '🇰🇳' => 'calan: St. Kitts iyo Nevis',
    '🇰🇵' => 'calan: Kuuriyada Waqooyi',
    '🇰🇷' => 'calan: Kuuriyada Koonfureed',
    '🇰🇼' => 'calan: Kuwayt',
    '🇰🇾' => 'calan: Cayman Islands',
    '🇰🇿' => 'calan: Kasaakhistaan',
    '🇱🇦' => 'calan: Laos',
    '🇱🇧' => 'calan: Lubnaan',
    '🇱🇨' => 'calan: St. Lusia',
    '🇱🇮' => 'calan: Liyjtensteyn',
    '🇱🇰' => 'calan: Sirilaanka',
    '🇱🇷' => 'calan: Laybeeriya',
    '🇱🇸' => 'calan: Losooto',
    '🇱🇹' => 'calan: Lituweeniya',
    '🇱🇺' => 'calan: Luksemboorg',
    '🇱🇻' => 'calan: Latfiya',
    '🇱🇾' => 'calan: Liibya',
    '🇲🇦' => 'calan: Morooko',
    '🇲🇨' => 'calan: Moonako',
    '🇲🇩' => 'calan: Moldofa',
    '🇲🇪' => 'calan: Moontenegro',
    '🇲🇫' => 'calan: St. Maartin',
    '🇲🇬' => 'calan: Madagaskar',
    '🇲🇭' => 'calan: Jasiiradda Maarshal',
    '🇲🇰' => 'calan: Masedooniya Waqooyi',
    '🇲🇱' => 'calan: Maali',
    '🇲🇲' => 'calan: Mayanmar',
    '🇲🇳' => 'calan: Mongooliya',
    '🇲🇴' => 'calan: Makaaw',
    '🇲🇵' => 'calan: Jasiiradda Waqooyiga Mariaana',
    '🇲🇶' => 'calan: Maartinik',
    '🇲🇷' => 'calan: Muritaaniya',
    '🇲🇸' => 'calan: Montserrat',
    '🇲🇹' => 'calan: Maalta',
    '🇲🇺' => 'calan: Mawrishiyaas',
    '🇲🇻' => 'calan: Maaldiifis',
    '🇲🇼' => 'calan: Malaawi',
    '🇲🇽' => 'calan: Meksiko',
    '🇲🇾' => 'calan: Malaysiya',
    '🇲🇿' => 'calan: Musambiik',
    '🇳🇦' => 'calan: Namiibiya',
    '🇳🇨' => 'calan: Jasiiradda Niyuu Kaledooniya',
    '🇳🇪' => 'calan: Nayjer',
    '🇳🇫' => 'calan: Jasiiradda Noorfolk',
    '🇳🇬' => 'calan: Nayjeeriya',
    '🇳🇮' => 'calan: Nikaraaguwa',
    '🇳🇱' => 'calan: Nederlaands',
    '🇳🇴' => 'calan: Noorweey',
    '🇳🇵' => 'calan: Nebaal',
    '🇳🇷' => 'calan: Nauru',
    '🇳🇺' => 'calan: Niue',
    '🇳🇿' => 'calan: Niyuusiilaand',
    '🇴🇲' => 'calan: Cumaan',
    '🇵🇦' => 'calan: Baanama',
    '🇵🇪' => 'calan: Beeru',
    '🇵🇫' => 'calan: Booliyneesiya Faransiiska',
    '🇵🇬' => 'calan: Babwa Niyuu Gini',
    '🇵🇭' => 'calan: Filibiin',
    '🇵🇰' => 'calan: Bakistaan',
    '🇵🇱' => 'calan: Booland',
    '🇵🇲' => 'calan: St. Pierre iyo Miquelon',
    '🇵🇳' => 'calan: Bitkairn',
    '🇵🇷' => 'calan: Bueerto Riiko',
    '🇵🇸' => 'calan: Dhulka Falastiiniyiinta daanta galbeed iyo marinka qasa',
    '🇵🇹' => 'calan: Bortugaal',
    '🇵🇼' => 'calan: Balaaw',
    '🇵🇾' => 'calan: Baraguaay',
    '🇶🇦' => 'calan: Qadar',
    '🇷🇪' => 'calan: Riyuuniyon',
    '🇷🇴' => 'calan: Rumaaniya',
    '🇷🇸' => 'calan: Seerbiya',
    '🇷🇺' => 'calan: Ruush',
    '🇷🇼' => 'calan: Ruwanda',
    '🇸🇦' => 'calan: Sacuudi Carabiya',
    '🇸🇧' => 'calan: Jasiiradda Solomon',
    '🇸🇨' => 'calan: Sishelis',
    '🇸🇩' => 'calan: Suudaan',
    '🇸🇪' => 'calan: Iswidhan',
    '🇸🇬' => 'calan: Singaboor',
    '🇸🇭' => 'calan: Saynt Helena',
    '🇸🇮' => 'calan: Islofeeniya',
    '🇸🇯' => 'calan: Jasiiradda Sfaldbaad & Jaan Mayen',
    '🇸🇰' => 'calan: Islofaakiya',
    '🇸🇱' => 'calan: Siraaliyoon',
    '🇸🇲' => 'calan: San Marino',
    '🇸🇳' => 'calan: Sinigaal',
    '🇸🇴' => 'calan: Soomaaliya',
    '🇸🇷' => 'calan: Surineym',
    '🇸🇸' => 'calan: Koonfur Suudaan',
    '🇸🇹' => 'calan: Sao Tome & Birincibal',
    '🇸🇻' => 'calan: El Salfadoor',
    '🇸🇽' => 'calan: Siint Maarteen',
    '🇸🇾' => 'calan: Suuriya',
    '🇸🇿' => 'calan: Eswaatiini',
    '🇹🇦' => 'calan: Tiristan da Kunha',
    '🇹🇨' => 'calan: Turks & Kaikos Island',
    '🇹🇩' => 'calan: Jaad',
    '🇹🇫' => 'calan: Dhul xadeedka Koonfureed ee Faransiiska',
    '🇹🇬' => 'calan: Toogo',
    '🇹🇭' => 'calan: Taylaand',
    '🇹🇯' => 'calan: Tajikistan',
    '🇹🇰' => 'calan: Tokelaaw',
    '🇹🇱' => 'calan: Timor-Leste',
    '🇹🇲' => 'calan: Turkmenistan',
    '🇹🇳' => 'calan: Tuniisiya',
    '🇹🇴' => 'calan: Tonga',
    '🇹🇷' => 'calan: Turki',
    '🇹🇹' => 'calan: Tirinidaad & Tobago',
    '🇹🇻' => 'calan: Tufaalu',
    '🇹🇼' => 'calan: Taywaan',
    '🇹🇿' => 'calan: Tansaaniya',
    '🇺🇦' => 'calan: Yukrayn',
    '🇺🇬' => 'calan: Ugaanda',
    '🇺🇲' => 'calan: Jasiiradaha ka baxsan Maraykanka',
    '🇺🇳' => 'calan: Qaramada Midoobay',
    '🇺🇸' => 'calan: Maraykanka',
    '🇺🇾' => 'calan: Uruguwaay',
    '🇺🇿' => 'calan: Usbakistan',
    '🇻🇦' => 'calan: Magaalada Faatikaan',
    '🇻🇨' => 'calan: St. Finsent & Girenadiins',
    '🇻🇪' => 'calan: Fenisuweela',
    '🇻🇬' => 'calan: Biritish Farjin Island',
    '🇻🇮' => 'calan: U.S Fargin Island',
    '🇻🇳' => 'calan: Fiyetnaam',
    '🇻🇺' => 'calan: Fanuaatu',
    '🇼🇫' => 'calan: Walis & Futuna',
    '🇼🇸' => 'calan: Samoowa',
    '🇽🇰' => 'calan: Koosofo',
    '🇾🇪' => 'calan: Yaman',
    '🇾🇹' => 'calan: Mayotte',
    '🇿🇦' => 'calan: Koonfur Afrika',
    '🇿🇲' => 'calan: Saambiya',
    '🇿🇼' => 'calan: Simbaabwe',
    '🔟' => 'daboolka furaha: 10',
    '🏻' => 'jidh fudud',
    '🏼' => 'jidh fudud oo dhexe',
    '🏽' => 'jidh nooc dhexe',
    '🏾' => 'jidh nooc madaw oo dhexe',
    '🏿' => 'jidh madaw',
    '😀' => 'dareenka wajiga',
    '😃' => 'muuqaalka wejiga indhaha weyn',
    '😄' => 'waji indho dhoola cadynaya leh',
    '😁' => 'waji dhalaal indho dhoola cadeynaaayo leh',
    '😆' => 'dareenka wajiga ee qoslaya',
    '😅' => 'waji gariiraya oo dhididsan',
    '🤣' => 'dhulka ku rafanaayo oo qoslaya',
    '😂' => 'waji ilin farxad leh',
    '🙂' => 'waji yara dhoola cadeynaya',
    '🙃' => 'waji hoos-hoos u raaraca',
    '🫠' => 'waji dhalaalaya',
    '😉' => 'waji il jabinaaya',
    '😊' => 'waji iyo indho dhoolo cadeynaaya',
    '😇' => 'waji dhoolo cadeynaya wareeg leh',
    '🥰' => 'waji dhoolo cadeynaya qalbi',
    '😍' => 'waji dhoolo cadeynaya qalbi-indho',
    '🤩' => 'xiddig-dhufsaday',
    '😘' => 'waji afuufayo dhunkasho',
    '😗' => 'wajiga dhunkashada',
    '☺' => 'waji dhoolo cadeynaya',
    '😚' => 'waji dhunkanaayo indho xiran',
    '😙' => 'waji dhunkanaayo indho dhoolo cadeynaya',
    '🥲' => 'waaji ilin ladhoola cadeeynaya',
    '😋' => 'waji cunto dhadhaminaayo',
    '😛' => 'waji iyo carrab',
    '😜' => 'waji il jabinaayo carrab leh',
    '🤪' => 'waji qallafsan',
    '😝' => 'waji foolxun carrab leh',
    '🤑' => 'waji af-lacag',
    '🤗' => 'waji habsiinaaya',
    '🤭' => 'waji afka gacan ka saaran',
    '🫢' => 'ku wajah indhaha oo ku furan iyo gacmaha oo aad afka saaratay',
    '🫣' => 'wajah indhaha oo fiirinaya',
    '🤫' => 'waji ruxmaya',
    '🤔' => 'waji fakarsan',
    '🫡' => 'wajiga salaameed',
    '🤐' => 'waji af xiran',
    '🤨' => 'waji sunniyo kor u qaadan leh',
    '😐' => 'waji dhexdhexaad ah',
    '😑' => 'waji aan muuqan lahayn',
    '😶' => 'waji af la’aan',
    '🫥' => 'wajiga ku leh dhibco',
    '😏' => 'waji isku dhagan',
    '😒' => 'waji aan la taaban karin',
    '🙄' => 'waji indho wareegayo leh',
    '😬' => 'waji naxdin leh',
    '🤥' => 'waji jiifo',
    '🫨' => 'Ruxida madaxa',
    '😌' => 'waji niyad jabn',
    '😔' => 'waji caajisan',
    '😪' => 'waji hurdeysan',
    '🤤' => 'waji dhareer',
    '😴' => 'waji hurdadeysan',
    '🫩' => 'weji ay baagag uga hoos yaalan indhaha',
    '😷' => 'waji maaskaro caafimaad leh',
    '🤒' => 'waji leh heerkulbeegga',
    '🤕' => 'waji leh faashid madaxeed',
    '🤢' => 'waji lalabo leh',
    '🤮' => 'waji mantaq leh',
    '🤧' => 'waji hindhisaayo',
    '🥵' => 'waji kulul',
    '🥶' => 'waji qaboow',
    '🥴' => 'waji aan dagneyn',
    '😵' => 'waji wareersan',
    '🤯' => 'madax qarxa',
    '🤠' => 'waji koofid leh',
    '🥳' => 'waji farxadeysan',
    '🥸' => 'waji badalan',
    '😎' => 'waji dhoola cadeynaya ookiyaala wato',
    '🤓' => 'waji xirfad la’aan',
    '🧐' => 'waji hal ookiyaalo leh',
    '😕' => 'waji jah wareersan',
    '🫤' => 'ku wajah af dadban',
    '😟' => 'waji walaacsan',
    '🙁' => 'waji yara macbuusan',
    '☹' => 'waji macbuus',
    '😮' => 'waji af furan leh',
    '😯' => 'waji iftiimaayo',
    '😲' => 'waji amakaagsan',
    '😳' => 'waji xishood leh',
    '🫪' => 'weji la qaloociyay',
    '🥺' => 'waji doodsan',
    '🥹' => 'wajah adoo oohinta celinaya',
    '😦' => 'waji macbuus af furan leh',
    '😧' => 'waji xanaaqsan',
    '😨' => 'waji cabsi leh',
    '😰' => 'waji walaacsan oo dhidid leh',
    '😥' => 'waji xanaaqsan laakiin dabacsan',
    '😢' => 'waji ooynaayo',
    '😭' => 'waji zaaid u ooynaayo',
    '😱' => 'waji cabsi darteed u qeylinaayo',
    '😖' => 'waji shakisan',
    '😣' => 'waji dulqaad leh',
    '😞' => 'waji niyadjabsan',
    '😓' => 'waji hoos u dhacsan oo dhididsan',
    '😩' => 'waji daal ka muuqdo',
    '😫' => 'waji daalan',
    '🥱' => 'waji hammaansanaya',
    '😤' => 'waji sanka qiiqaayo',
    '😡' => 'waji xanaaq leh',
    '😠' => 'waji careysan',
    '🤬' => 'waji afka calaamada ku leh',
    '😈' => 'waji dhool cadeynaayo geeso leh',
    '👿' => 'waji xanaaqsan geeso leh',
    '💀' => 'laf madaxa',
    '☠' => 'laf madaxa iyo iskutallabta',
    '💩' => 'raso saxaro ah',
    '🤡' => 'waji qosol leh',
    '👹' => 'dad cun',
    '👺' => 'noole foolxun',
    '👻' => 'reer-aakhiraad',
    '👽' => 'shisheeye',
    '👾' => 'shayddaan shisheeye ah',
    '🤖' => 'mashiin',
    '😺' => 'bisad ba’an',
    '😸' => 'bisad gariireyso indha dhoolo cadeyneysa',
    '😹' => 'bisad illin faraxded leh',
    '😻' => 'bisad dhoolo cadeyneysa qalbi leh',
    '😼' => 'bisad kaftan dhoolo cadeyn leh',
    '😽' => 'bisad shuminayso',
    '🙀' => 'bisad baqdin leh',
    '😿' => 'bisad ooyneeysa',
    '😾' => 'bisad xanaaqsan',
    '🙈' => 'aan arkeyn daanyeer xun',
    '🙉' => 'aan-maqaleyn-daanyeer xun',
    '🙊' => 'aan la hadleynin daanyeer xun',
    '💌' => 'warqad jaceyl',
    '💘' => 'wadno leh fallaar',
    '💝' => 'wadno mara lagu xiray',
    '💖' => 'wadno dhalaalaayo',
    '💗' => 'wadno kubcayo',
    '💓' => 'wadno garaac',
    '💞' => 'wadno warwareegaayo',
    '💕' => 'labo wadno',
    '💟' => 'qurxinta wadnaha',
    '❣' => 'claamad ujeedka wadnaha',
    '💔' => 'wadno jaban',
    '❤' => 'wadno cas',
    '🩷' => 'wadnaha casaan ah',
    '🧡' => 'wadno oranji ah',
    '💛' => 'wadno jaalle ah',
    '💚' => 'wadno cagaaran',
    '💙' => 'wadno buluug ah',
    '🩵' => 'qalbi buluug khafiif ah',
    '💜' => 'wadno midab-buluug-guddud ah',
    '🤎' => 'wadne bunni ah',
    '🖤' => 'wadno madoow',
    '🩶' => 'qalbi cawlan',
    '🤍' => 'wadne cad (cabsi og)',
    '💋' => 'calaamadda dhunkashada',
    '💯' => 'boqol dhibco',
    '💢' => 'calaamadda xanaaqa',
    '🫯' => 'daruur dagaalameyso',
    '💥' => 'isku dhac',
    '💫' => 'wareer',
    '💦' => 'dhibco dhidid ah',
    '💨' => 'tagaayo',
    '🕳' => 'god',
    '💬' => 'balluun hadal',
    '🗨' => 'xumbo hadal bidix',
    '🗯' => 'xanaaqa xumbo midig',
    '💭' => 'baalluunta fakarka',
    '💤' => 'ZZZ',
    '👋' => 'gacan haadin',
    '🤚' => 'kor u qaaday gacanta gadaal',
    '🖐' => 'gacan iyo faraha ayaa lagu fidiyay',
    '✋' => 'gacan kor loo qaday',
    '🖖' => 'salaan sharaf',
    '🫱' => 'dhinaca gacanta midig',
    '🫲' => 'dhinaca gacanta bidix',
    '🫳' => 'baabacada gacanta hoose',
    '🫴' => 'Baabacada kore',
    '🫷' => 'gacanta u riixaysa dhinaca bidix',
    '🫸' => 'gacanta riixid bidix u socota',
    '👌' => 'gacanta saxda ah',
    '🤌' => 'faro la isku wada duubay',
    '🤏' => 'qanjaruufo',
    '✌' => 'gacanta guusha',
    '🤞' => 'faraha gudban; Alla bari',
    '🫰' => 'gacanta farta caarada iyo suulka la dhaafay',
    '🤟' => 'meedaarta waan ku jecelahay ah',
    '🤘' => 'calaamadda geesaha',
    '🤙' => 'gacanta ah isoo wac',
    '👈' => 'Gacan tilmaamaysa bidix',
    '👉' => 'gacan tilmaamaysa midig',
    '👆' => 'gacan tilmaamaysa kor',
    '🖕' => 'farta dhexe',
    '👇' => 'gacan tilmaamaysa hoos',
    '☝' => 'farta muujinta tilmaamaysa kor',
    '🫵' => 'tusmo tilmaame daawadaha',
    '👍' => 'suulka kor',
    '👎' => 'suulka hoos',
    '✊' => 'kor u qaadid tantoonyo (feer)',
    '👊' => 'feer soo socoto',
    '🤛' => 'feerka tilmaamaysa bidix',
    '🤜' => 'feerka tilmaamaya midig',
    '👏' => 'sacabinta gacmaha',
    '🙌' => 'gacmo kor u taagid',
    '🫶' => 'gacanta qalbiga',
    '👐' => 'gacmo furan',
    '🤲' => 'calaacalaha si wadajir ah kor loogu taaggo',
    '🤝' => 'gacan-qaadka salaanta',
    '🙏' => 'gacmo laaban',
    '✍' => 'gacan wax qoraysa',
    '💅' => 'dhalaalinta ciddiyaha',
    '🤳' => 'sawir iska-qaadis',
    '💪' => 'suxulka oo laaban',
    '🦾' => 'gacan mashiin ah',
    '🦿' => 'lug mashiin ah',
    '🦵' => 'lug',
    '🦶' => 'cagta',
    '👂' => 'dhagta',
    '🦻' => 'dhag leh gargaarka maqalka',
    '👃' => 'sanka',
    '🧠' => 'maskaxda',
    '🫀' => 'garaaca wadnaha',
    '🫁' => 'sambabka',
    '🦷' => 'ilig',
    '🦴' => 'laf',
    '👀' => 'indhaha',
    '👁' => 'il',
    '👅' => 'carab',
    '👄' => 'bishimo',
    '🫦' => 'faruurta qaniinaya',
    '👶' => 'cunug',
    '🧒' => 'ilmo',
    '👦' => 'wiil',
    '👧' => 'gabar',
    '🧑' => 'qof',
    '👱' => 'qof: timo cad',
    '👨' => 'ninka',
    '🧔' => 'nin: gar',
    '👩' => 'naag',
    '🧓' => 'qof weyn',
    '👴' => 'nin da’ weyn',
    '👵' => 'naag weyn',
    '🙍' => 'qof wajiga kaduudaya',
    '🙎' => 'bushin qaniinidda',
    '🙅' => 'qof ku meedaaraya MAYA',
    '🙆' => 'naag ku meedaaraysa HAA',
    '💁' => 'qof warbixin bixinaya',
    '🙋' => 'qof gacan taagaya',
    '🧏' => 'qof dhagoole ah',
    '🙇' => 'qof fooraraya',
    '🤦' => 'qof calaacal waji saaranaya',
    '🤷' => 'qof garba-ruxaya',
    '👮' => 'sarkaal boolis',
    '🕵' => 'dambi-baare',
    '💂' => 'ilaaliye',
    '🥷' => 'ninja',
    '👷' => 'shaqaale dhismo',
    '🫅' => 'qof leh taaj',
    '🤴' => 'boqor',
    '👸' => 'boqorad',
    '👳' => 'qof cammaamad xiran',
    '👲' => 'nin xiran koofiyadda shiinaha',
    '🧕' => 'naag xiran qammaar',
    '🤵' => 'nin xiran suudka rasmiga ah',
    '👰' => 'shaqsi niqaam xidhan',
    '🤰' => 'haweeney uur leh',
    '🫃' => 'nin uur leh',
    '🫄' => 'qof uur leh',
    '🤱' => 'naas-nuujin',
    '👼' => 'malaa’igta caruurta',
    '🎅' => 'Aabaha Ciidda Masiixigga',
    '🤶' => 'Marwada Masiixigga',
    '🦸' => 'halyeey ah',
    '🦹' => 'qof sheyddaankiisu sareeyo',
    '🧙' => 'sixiroole',
    '🧚' => 'qurux badan',
    '🧛' => 'reer-aakhiraad dhiig cab ah',
    '🧜' => 'qof cajiib ah',
    '🧝' => 'ruuxaan',
    '🧞' => 'jinka',
    '🧟' => 'qof dhintay soo noolaaday',
    '🧌' => 'foolxun',
    '🫈' => 'makhluuqa xaadoolaha',
    '💆' => 'qof loo duugayo',
    '💇' => 'qof timaha loo jarayo',
    '🚶' => 'qof soconaya',
    '🧍' => 'qof taaggan',
    '🧎' => 'qof jilbaha dhiganaya',
    '🏃' => 'qof ordaya',
    '💃' => 'naag qoob-ka-cayaaraysa',
    '🕺' => 'nin qoob-ka-cayaaraya',
    '🕴' => 'nin suud xiran oo milicsanaya',
    '👯' => 'dad leh dhaggo bakayle',
    '🧖' => 'qof ku jira qol uummi ah',
    '🧗' => 'qof meel fuulaya',
    '🤺' => 'qof ku loolamaya seef',
    '🏇' => 'tartan fardoodka',
    '⛷' => 'qof alwaaxa barafka kula socda',
    '🏂' => 'qofka alwaaxa barafka kula socda',
    '🏌' => 'qof cayaaraya goolof',
    '🏄' => 'qof alwaaxa hirka biyaha kula soconaya',
    '🚣' => 'qof doon wada',
    '🏊' => 'qof dabaalanaya',
    '⛹' => 'qof cayaaraya kubadda boodda',
    '🏋' => 'qof qaadaya culeyska',
    '🚴' => 'qof baaskiil wada',
    '🚵' => 'qof baaskiil buur ku wada',
    '🤸' => 'qof samayanaya jimicsiga gacma saarka',
    '🤼' => 'dad lagdamaya',
    '🤽' => 'qof cayaaraya kubadda biyaha',
    '🤾' => 'qof cayaaraya kubadda gacanta',
    '🤹' => 'qof shaqo badan wada qabanaya',
    '🧘' => 'qof ku jira habka fadhiga luga is gudubka',
    '🛀' => 'qof qubeysanaya',
    '🛌' => 'qof sariir ku jira',
    '👭' => 'haween haysta is gacmaha',
    '👫' => 'naag iyo nin gacmaha is haysta',
    '👬' => 'laba nin oo gacmaha is haysta',
    '💏' => 'shumis',
    '💑' => 'lammaane is jecel',
    '🗣' => 'Madax hadlaya',
    '👤' => 'Sawir muuqaal dumar qaarka hore mugdi ah',
    '👥' => 'Farshaxan sawir xabad dumar oo mugdi ah',
    '🫂' => 'dad hab isi siinaya',
    '👪' => 'Qooys caruur ah',
    '👣' => 'raadad',
    '🫆' => 'sawirka faraha',
    '🦰' => 'timo cas',
    '🦱' => 'timo walaaqan',
    '🦳' => 'caddaan',
    '🦲' => 'bidaar',
    '🐵' => 'waji daanyeer',
    '🐒' => 'daanyeer',
    '🦍' => 'goriilla',
    '🦧' => 'danyeer weyn cas',
    '🐶' => 'waji eey',
    '🐕' => 'eey',
    '🦮' => 'eyga haggaha',
    '🐩' => 'dhogorta',
    '🐺' => 'yeey',
    '🦊' => 'dawaco',
    '🦝' => 'dabacaddeeye',
    '🐱' => 'waji bisad',
    '🐈' => 'bisad',
    '🦁' => 'libaax',
    '🐯' => 'waji shabeel',
    '🐅' => 'shabeel',
    '🐆' => 'haramacad',
    '🐴' => 'waji faras',
    '🫎' => 'deero maraykan',
    '🫏' => 'dameer',
    '🐎' => 'faras',
    '🦄' => 'xayawaan khuraafi ah',
    '🦓' => 'dameer-farow',
    '🦌' => 'deero',
    '🦬' => 'dibi reer galbeed',
    '🐮' => 'waji sac',
    '🐂' => 'baqay',
    '🐃' => 'lo’ gisida biyaha',
    '🐄' => 'sac',
    '🐷' => 'waji doofaar',
    '🐖' => 'doofaar',
    '🐗' => 'khinsiir',
    '🐽' => 'san doofaar',
    '🐏' => 'wan',
    '🐑' => 'lax',
    '🐐' => 'ri',
    '🐪' => 'geel',
    '🐫' => 'geel laba-tuure',
    '🦙' => 'geel bakayle',
    '🦒' => 'geri',
    '🐘' => 'maroodi',
    '🦣' => 'Maroodiga weeyn',
    '🦏' => 'wiyil',
    '🦛' => 'jeer',
    '🐭' => 'waji walasandheer',
    '🐁' => 'walasandheer',
    '🐀' => 'jiir',
    '🐹' => 'jiir booge',
    '🐰' => 'waji',
    '🐇' => 'bakayle',
    '🐿' => 'bushucle boor',
    '🦫' => 'oorso yar oo xeeb kunool',
    '🦔' => 'xiddig-dhul',
    '🦇' => 'fiidmeer',
    '🐻' => 'oorso',
    '🐨' => 'korow',
    '🐼' => 'ooroso madow',
    '🦥' => 'wahsi',
    '🦦' => 'kalluunka casiirka',
    '🦨' => 'xayawaan uuro leh',
    '🦘' => 'kangaaruu',
    '🦡' => 'xoor',
    '🐾' => 'raad xayawaan',
    '🦃' => 'diikh rumiin',
    '🐔' => 'diggaag',
    '🐓' => 'diiq',
    '🐣' => 'jiiw dhalanay',
    '🐤' => 'cunug diggaag',
    '🐥' => 'cunugga diggaaga hor soo eegaya',
    '🐦' => 'shimbir',
    '🐧' => 'shimbir baraf',
    '🕊' => 'qoolleey',
    '🦅' => 'gorgor',
    '🦆' => 'muwaata',
    '🦢' => 'shimbiraha booloboolada',
    '🦉' => 'guumays',
    '🦤' => 'shimbir boolo',
    '🪶' => 'baalal',
    '🦩' => 'qudunquuto',
    '🦚' => 'daa’uus',
    '🦜' => 'baqbaqaaq',
    '🪽' => 'wing',
    '🪿' => 'booloboolo',
    '🐸' => 'rah',
    '🐊' => 'yaxaas',
    '🐢' => 'qubo',
    '🦎' => 'qoroto',
    '🐍' => 'mas',
    '🐲' => 'waji masduulaagi',
    '🐉' => 'masduulaagi',
    '🦕' => 'sauropod-ka',
    '🦖' => 'waa wax la aqoon',
    '🐳' => 'nibiriga mataga',
    '🐋' => 'nibiri',
    '🐬' => 'hoon-baro',
    '🫍' => 'nibiriga orkaha',
    '🦭' => 'shaabad',
    '🐟' => 'kalluun',
    '🐠' => 'kalluunka kulaylaha',
    '🐡' => 'kalluunka baaqa',
    '🦈' => 'kalluun libaax',
    '🐙' => 'farammugo',
    '🐚' => 'xanjaleel wareegaya',
    '🪸' => 'dhagax badeed',
    '🪼' => 'kaluun qolof leh',
    '🦀' => 'carsaanyo',
    '🦞' => 'argoosto',
    '🦐' => 'kalluun qolof la shiilay',
    '🦑' => 'xayawaan badeed',
    '🦪' => 'lohod',
    '🐌' => 'dixiri qolof leh',
    '🦋' => 'balanbaalis',
    '🐛' => 'kutaan',
    '🐜' => 'quraanjo',
    '🐝' => 'shinni malab',
    '🪲' => 'faraanfar',
    '🐞' => 'duqsiyada dheddiga',
    '🦗' => 'jiiq-jiiqle',
    '🪳' => 'baranbaro',
    '🕷' => 'caaro',
    '🕸' => 'xuub caaro',
    '🦂' => 'dib qallooc',
    '🦟' => 'kaneeco',
    '🪰' => 'duqsi',
    '🪱' => 'dirxi',
    '🦠' => 'mikrobe',
    '💐' => 'ubaxyo',
    '🌸' => 'ubaxa buundada',
    '💮' => 'ubax cad',
    '🪷' => 'lotus',
    '🏵' => 'ubaxa sharraxa',
    '🌹' => 'ubax koob',
    '🥀' => 'ubaxa didilaaca',
    '🌺' => 'jirrid leh',
    '🌻' => 'gabbaldaye',
    '🌼' => 'ubax geed',
    '🌷' => 'ubax caano',
    '🪻' => 'hyacinth',
    '🌱' => 'geed naqan',
    '🪴' => 'dhirta guriga',
    '🌲' => 'geed abaareed',
    '🌳' => 'geed magool',
    '🌴' => 'geed timir',
    '🌵' => 'tiin',
    '🌾' => 'geedka bariiska',
    '🌿' => 'geed',
    '☘' => 'dhir gaaban saddex caleen leh',
    '🍀' => 'geed afar caleenle',
    '🍁' => 'caleen jiifta',
    '🍂' => 'caleen dhacday',
    '🍃' => 'caleen dhex buubaysa dabaysha',
    '🪹' => 'buul faaruq ah',
    '🪺' => 'buul leh ukumo',
    '🍄' => 'barkin waraabe',
    '🪾' => 'geed caleen la’aan ah',
    '🍇' => 'canab',
    '🍈' => 'batiikh',
    '🍉' => 'qare',
    '🍊' => 'liin banbeelo',
    '🍋' => 'liin dhannaan',
    '🍌' => 'moos',
    '🍍' => 'caananaas',
    '🥭' => 'cambe',
    '🍎' => 'tufaax guduud',
    '🍏' => 'tufaax cagaar',
    '🍐' => 'cambaruud',
    '🍑' => 'miro guduud',
    '🍒' => 'jeerigga',
    '🍓' => 'frawla',
    '🫐' => 'canabka baluuga ah',
    '🥝' => 'miraha qamboob',
    '🍅' => 'yaanyo',
    '🫒' => 'saytuun',
    '🥥' => 'qumbe',
    '🥑' => 'afokaadho',
    '🍆' => 'dhir ukun',
    '🥔' => 'baradha',
    '🥕' => 'dabocase',
    '🌽' => 'sabuul galley',
    '🌶' => 'basbaas',
    '🫑' => 'basbaas dawan',
    '🥒' => 'qajaar',
    '🥬' => 'caleenta cagaaran',
    '🥦' => 'barakooli',
    '🧄' => 'toon',
    '🧅' => 'basal',
    '🥜' => 'loows',
    '🫘' => 'digir',
    '🌰' => 'loows duban',
    '🫚' => 'xidid sinjibiil',
    '🫛' => 'Qubka digirta',
    '🫜' => 'khudradda xididka ah',
    '🍞' => 'rooti',
    '🥐' => 'qureec faransiis macaan',
    '🥖' => 'rootiga baguette-ka',
    '🫓' => 'rooti bafloow',
    '🥨' => 'buskud ulo ah',
    '🥯' => 'pagel-ka',
    '🥞' => 'canjeelo',
    '🧇' => 'doolshe',
    '🧀' => 'gabal burcad',
    '🍖' => 'hilibka lafta',
    '🍗' => 'lug diggaag',
    '🥩' => 'gooyo hilib',
    '🥓' => 'hilib doofaar',
    '🍔' => 'hambaagar',
    '🍟' => 'shiilid faransiis',
    '🍕' => 'pizza-da',
    '🌭' => 'eey kulul',
    '🥪' => 'saanbuus',
    '🌮' => 'taako',
    '🌯' => 'toortiilada meksikaanka',
    '🫔' => 'unno maksikaan',
    '🥙' => 'rooti khudrad laga buuxiyay',
    '🧆' => 'falafeel',
    '🥚' => 'ukun',
    '🍳' => 'karinta',
    '🥘' => 'bir daawo gun-dhow oo cunno ah',
    '🍲' => 'digsi cunno ah',
    '🫕' => 'digsi cunnno lagu diyaariyay',
    '🥣' => 'baaquli iyo qaaddo',
    '🥗' => 'anslaata cagaaran',
    '🍿' => 'salool',
    '🧈' => 'subag',
    '🧂' => 'cusbo',
    '🥫' => 'cunno qasacadaysan',
    '🍱' => 'sanduuq qado',
    '🍘' => 'qubka bariis',
    '🍙' => 'bariis kubbad',
    '🍚' => 'bariis karsan',
    '🍛' => 'bariis khudrad hilib leh',
    '🍜' => 'baaquligga uumigga',
    '🍝' => 'isbageeti',
    '🍠' => 'bataata la solay',
    '🍢' => 'cunno hal digsi wax badan ka kooban',
    '🍣' => 'cunnada jabbaanka',
    '🍤' => 'kalluun la shiilay',
    '🍥' => 'kalluun keeg oo duuban',
    '🥮' => 'kalluunka dayaxa',
    '🍡' => 'daango',
    '🥟' => 'cajiimid',
    '🥠' => 'buskud macaan',
    '🥡' => 'sabduuqa lohodka lagu qaato',
    '🍦' => 'jallaato jilicsan',
    '🍧' => 'macmacaan baraf la buburiyay',
    '🍨' => 'jallaato',
    '🍩' => 'keek macaan loo shiilan cajiin ahaan',
    '🍪' => 'keeg macaan',
    '🎂' => 'keegga maalinka dhalashada',
    '🍰' => 'keeg yar',
    '🧁' => 'koob keeg',
    '🥧' => 'doolsho',
    '🍫' => 'shukulaato',
    '🍬' => 'nacnac',
    '🍭' => 'nacnac ul ballaaran',
    '🍮' => 'labaniyad',
    '🍯' => 'digsi malab',
    '🍼' => 'dhalada ilmaha',
    '🥛' => 'galaas caano ah',
    '☕' => 'cabitaan kulul',
    '🫖' => 'kirli',
    '🍵' => 'koob shah ah oon sidda lahayn',
    '🍶' => 'khamro jabbaan',
    '🍾' => 'dhalo khamri ubrinaysa',
    '🍷' => 'galaas khamri ah',
    '🍸' => 'galaas kooktayl ah',
    '🍹' => 'khamriga kulul',
    '🍺' => 'koob khamri ah',
    '🍻' => 'isku dhufsashada koobab khamri ah',
    '🥂' => 'galaasyo isku dhufashada',
    '🥃' => 'galaas dhalo',
    '🫗' => 'ku shubaya dareere',
    '🥤' => 'koob wata istaroow',
    '🧋' => 'shaah xumbaale',
    '🧃' => 'sanduuq cabitaan',
    '🧉' => 'lamaane',
    '🧊' => 'baraf',
    '🥢' => 'qori wax lagu cuno',
    '🍽' => 'saxan iyo fargeeta iyo mindi',
    '🍴' => 'fargeeta iyo mindi',
    '🥄' => 'qaaddo',
    '🔪' => 'mindi kushiin',
    '🫙' => 'dhalo',
    '🏺' => 'jeeg dheer labo sidda leh',
    '🌍' => 'adduunka muujinaya Yurub-Afrika',
    '🌎' => 'adduunka oo muujinaya Ameerika',
    '🌏' => 'adduunka muujinaya Aasiya-Awstaraaliya',
    '🌐' => 'adduunka oo leh dhigo',
    '🗺' => 'khariiradadda dunida',
    '🗾' => 'khariidadda Jabbaan',
    '🧭' => 'jiheeye',
    '🏔' => 'buur baraf ah',
    '⛰' => 'buur',
    '🛘' => 'dhul go’id',
    '🌋' => 'folkano',
    '🗻' => 'buurta fuji',
    '🏕' => 'xero',
    '🏖' => 'dallad kula xeeb qaadashada',
    '🏜' => 'lamadegaan',
    '🏝' => 'jasiirad lamadegaan ah',
    '🏞' => 'carwo qaran',
    '🏟' => 'garoon',
    '🏛' => 'dhismo heer sare ah',
    '🏗' => 'daar dhisidda',
    '🧱' => 'bulukeeti',
    '🪨' => 'dhagax',
    '🪵' => 'xaabo',
    '🛖' => 'aqal hoori',
    '🏘' => 'guryo',
    '🏚' => 'guri burbursan',
    '🏠' => 'guri',
    '🏡' => 'guri beer leh',
    '🏢' => 'dhismo xafiis',
    '🏣' => 'xafiiska boostada ee Jabbaanka',
    '🏤' => 'xafiis boosto',
    '🏥' => 'isbitaal',
    '🏦' => 'bangi',
    '🏨' => 'hudheel',
    '🏩' => 'hudheel Jaceyl',
    '🏪' => 'bakhaar habboon',
    '🏫' => 'dugsi',
    '🏬' => 'waax bakhaar',
    '🏭' => 'warshad',
    '🏯' => 'dabaqa Jabbaanka',
    '🏰' => 'dabaq',
    '💒' => 'aroos',
    '🗼' => 'munaaradda Tokyo',
    '🗽' => 'Taalada Xurriyadda',
    '⛪' => 'Kaniisad',
    '🕌' => 'masaajid',
    '🛕' => 'macbadka hindida',
    '🕍' => 'kaniisad Yuhuud',
    '⛩' => 'Meel Caabudaad',
    '🕋' => 'Kacbah',
    '⛲' => 'tuubo biyo kor u ganta',
    '⛺' => 'teendho',
    '🌁' => 'ciryaamo leh',
    '🌃' => 'habbeenka xiddigaha',
    '🏙' => 'muuqaal magaalo',
    '🌄' => 'qorrax ka soo baxa buuraha',
    '🌅' => 'qorrax soo bax',
    '🌆' => 'muuqaal magaalo ee qorrax dhaca',
    '🌇' => 'qorrax dhac',
    '🌉' => 'buundada habeenkii',
    '♨' => 'ilo kulul',
    '🎠' => 'faraska farxad wareegga',
    '🛝' => 'Barxadda ciyaarta',
    '🎡' => 'shaagga gaariga markabka',
    '🎢' => 'dusha sare ee tareeka',
    '💈' => 'tiirka tima-jaraha',
    '🎪' => 'teendho rogad',
    '🚂' => 'dhaqdhaqaaq',
    '🚃' => 'gaariga jidka tareenka',
    '🚄' => 'tareen aad u dheereeya',
    '🚅' => 'tareen xawaare sare',
    '🚆' => 'tareen',
    '🚇' => 'waddo hoose',
    '🚈' => 'tareenka fudud',
    '🚉' => 'saldhig',
    '🚊' => 'taraam',
    '🚝' => 'hal jid tareen kor u qaadan',
    '🚞' => 'jidka tareenka buurta',
    '🚋' => 'gaariga taraam',
    '🚌' => 'bas',
    '🚍' => 'bas soo socda',
    '🚎' => 'baska ragaad',
    '🚐' => 'bas yar',
    '🚑' => 'ambalaas',
    '🚒' => 'mashiinka dabka',
    '🚓' => 'gaari boolis',
    '🚔' => 'gaari boolis soo socda',
    '🚕' => 'taksi',
    '🚖' => 'taksi soo socda',
    '🚗' => 'baabuur',
    '🚘' => 'gaari soo socda',
    '🚙' => 'gaadiidka cayaaraha',
    '🛻' => 'qabaalka',
    '🚚' => 'gaari xammuulka adeegga',
    '🚛' => 'looriga xammuulka',
    '🚜' => 'cagaf-cagaf',
    '🏎' => 'tartan gaari',
    '🏍' => 'mooto',
    '🛵' => 'mooto matoor qaawan',
    '🦽' => 'kursiga curyaanka macmalka ah',
    '🦼' => 'kursiga curyaanka korontada ku shaqeeya',
    '🛺' => 'jiide is-wada',
    '🚲' => 'baaskiil',
    '🛴' => 'mooto laadid',
    '🛹' => 'alwaaxa qalfoofka',
    '🛼' => 'skaytka kaha',
    '🚏' => 'boosteejada',
    '🛣' => 'waddo ballaaran',
    '🛤' => 'jidka waddada tareenka',
    '🛢' => 'durbaan saliid ah',
    '⛽' => 'bamka shidaalka',
    '🛞' => 'gaari',
    '🚨' => 'iftiinka gaariga booliska',
    '🚥' => 'iftiinka taraafikada oo jiifta',
    '🚦' => 'iftiin taraafika oo toosan',
    '🛑' => 'calaamad joogsi',
    '🚧' => 'dhismo',
    '⚓' => 'baroosinka',
    '🛟' => 'giraan sabanaysa',
    '⛵' => 'doon shiraac',
    '🛶' => 'huuri',
    '🚤' => 'doon dheeraysa',
    '🛳' => 'rakaab markab',
    '⛴' => 'rakaab qaadis',
    '🛥' => 'doon matoor',
    '🚢' => 'markab',
    '✈' => 'diyaarad',
    '🛩' => 'diyaarad yar',
    '🛫' => 'bixitaanka diyaaradda',
    '🛬' => 'immaanshaha diyaaradda',
    '🪂' => 'baarashuud',
    '💺' => 'fadhi',
    '🚁' => 'diyaarad helikobtar',
    '🚟' => 'joojinta jidka tareenka',
    '🚠' => 'waddo fiilo buureed',
    '🚡' => 'waddada tareenka oo hawada ah',
    '🛰' => 'dayax gacmeed',
    '🚀' => 'gantaal',
    '🛸' => 'shey sidii digsi oo duulaya',
    '🛎' => 'boorsa-qaade',
    '🧳' => 'boorsooyin',
    '⌛' => 'dhalada saacad-beegtada ah oo dhamaysay',
    '⏳' => 'dhalada saacad-beegtada ah wali ma dhamayn',
    '⌚' => 'goor-sheeg',
    '⏰' => 'saacadda qaylo-dhaanta',
    '⏱' => 'saacad-joojin',
    '⏲' => 'saacadda goor-sheegtada ah',
    '🕰' => 'qaanadda kore ee saacadda',
    '🕛' => 'toban iyo labadii iyo bar',
    '🕧' => 'laba iyo tobanki iyo bar',
    '🕐' => 'hal saac',
    '🕜' => 'hal saac iyo bar',
    '🕑' => 'laba saac',
    '🕝' => 'labadii iyo bar',
    '🕒' => 'saddex saac',
    '🕞' => 'saddexdii iyo bar',
    '🕓' => 'afar saac',
    '🕟' => 'afartii iyo bar',
    '🕔' => 'shan saac',
    '🕠' => 'shantii iyo bar',
    '🕕' => 'lix saac',
    '🕡' => 'lixdii iyo bar',
    '🕖' => 'toddoba saac',
    '🕢' => 'toddobadii iyo bar',
    '🕗' => 'siddeed saac',
    '🕣' => 'siddeeddi iyo bar',
    '🕘' => 'sagaal saac',
    '🕤' => 'sagaal iyo bar',
    '🕙' => 'toban saac',
    '🕥' => 'tobanki iyo bar',
    '🕚' => 'kow iyo toban saac',
    '🕦' => 'kow iyo toban iyo bar',
    '🌑' => 'dayaxa cusub',
    '🌒' => 'qoolaabanka dayaxa oo badanaya',
    '🌓' => 'rubaca hore ee dayaxa',
    '🌔' => 'weynaanta dayaxa oo sii badanaya',
    '🌕' => 'dayax buuxa',
    '🌖' => 'gaabinta wayninka dayaxa',
    '🌗' => 'rubaca dambe ee dayaxa',
    '🌘' => 'gaabinta dayaxa qoolaaban',
    '🌙' => 'dayax qoolaaban',
    '🌚' => 'waji daxeedka cusub',
    '🌛' => 'rubaca hore ee waji dayaxeedka',
    '🌜' => 'waji dayaxeedda rubaca dambe',
    '🌡' => 'heerkul-beegge',
    '☀' => 'qorrax',
    '🌝' => 'waji dayaxeed buuxa',
    '🌞' => 'qorrax wajiyeed',
    '🪐' => 'meeraha gaaban',
    '⭐' => 'Summadda xiddigta',
    '🌟' => 'xiddig kaahaya',
    '🌠' => 'waran cireed',
    '🌌' => 'habarjiid',
    '☁' => 'daruur',
    '⛅' => 'qorrax ka dambaysa daruur',
    '⛈' => 'daruur leh hillaac iyo roob',
    '🌤' => 'qorrax ka dambaysa daruur yar',
    '🌥' => 'qorrax ka dambaysa daruur weyn',
    '🌦' => 'qorrax ka dambaysa daruur roobeed',
    '🌧' => 'daruur roobeed',
    '🌨' => 'darruur wadata baraf',
    '🌩' => 'daruur hillaac leh',
    '🌪' => 'tornaado',
    '🌫' => 'ciiryaamo',
    '🌬' => 'waji dabayl',
    '🌀' => 'gufaaco',
    '🌈' => 'qaanso-roobaad',
    '🌂' => 'dallad xiran',
    '☂' => 'dallad',
    '☔' => 'dallad leh dhibco roob',
    '⛱' => 'daallad dhulka ka taagan',
    '⚡' => 'tamar sare',
    '❄' => 'baraf-qolof',
    '☃' => 'baraf-naag',
    '⛄' => 'baraf-naag oo naag la’aan ah',
    '☄' => 'dhagax-xiddig',
    '🔥' => 'dab',
    '💧' => 'dhibicda',
    '🌊' => 'hirka biyaha',
    '🎃' => 'jack-o-cirifka',
    '🎄' => 'geedka Ciid Masiixigga',
    '🎆' => 'shaqooyinka dabka',
    '🎇' => 'dhalaaliye',
    '🧨' => 'dab-demiyeyaasha',
    '✨' => 'dhalaali',
    '🎈' => 'baaluun',
    '🎉' => 'dhawaaqa xafladda',
    '🎊' => 'kubada qarsoon',
    '🎋' => 'geedka axdiga',
    '🎍' => 'geed qurxin',
    '🎎' => 'boombalaha Japanese ka',
    '🎏' => 'socodka xargaha',
    '🎐' => 'dabeesha musqusha',
    '🎑' => 'Munaasabada daawashada dayaxa',
    '🧧' => 'baqshad gaduudan',
    '🎀' => 'xabo',
    '🎁' => 'hadiyada duuban',
    '🎗' => 'xabo xasuusin',
    '🎟' => 'tikidka diiwaangelinta',
    '🎫' => 'tikid',
    '🎖' => 'bilad ciidan',
    '🏆' => 'koop',
    '🏅' => 'bilada ciyaaraha',
    '🥇' => 'bilada kaalinta koowaad',
    '🥈' => 'bilada kaalinta labaad',
    '🥉' => 'bilada kaalinta saddexaad',
    '⚽' => 'cayaaraha kubada',
    '⚾' => 'kubada usha',
    '🥎' => 'kubada usha iyo gacanta',
    '🏀' => 'kubbadda kolayga',
    '🏐' => 'kubada gacanta',
    '🏈' => 'kubadda cagta Mareykanka',
    '🏉' => 'kubada cagta iyo rugbida',
    '🎾' => 'teeniska',
    '🥏' => 'diskiga duulaayo',
    '🎳' => 'shiishka',
    '🏏' => 'cayaarta kirikitka',
    '🏑' => 'goobta kubada usha',
    '🏒' => 'kubada usha ee barafka',
    '🥍' => 'ciyaarta usha orodka',
    '🏓' => 'teeniska miiska',
    '🏸' => 'kubada shabaqa',
    '🥊' => 'gashiga feerka',
    '🥋' => 'lebiska dagaalka farshaxanka',
    '🥅' => 'shabaqa goolka',
    '⛳' => 'calanka godka',
    '⛸' => 'kan lugu socdo barafka',
    '🎣' => 'xargaha kalluumeysiga',
    '🤿' => 'maaskarada quusitaanka',
    '🎽' => 'shaatiga orodka',
    '🎿' => 'lugu gashi',
    '🛷' => 'gaariga barafka',
    '🥌' => 'dhagaxa ifa',
    '🎯' => 'kudhaca toosan',
    '🪀' => 'qaanso',
    '🪁' => 'abitey',
    '🔫' => 'bastoolad',
    '🎱' => 'kubada barkada 8',
    '🔮' => 'kubada kareemka',
    '🪄' => 'ul mucjiso',
    '🎮' => 'cayaarta maqal-muuqal',
    '🕹' => 'usha farxada',
    '🎰' => 'mashiinka kabaha',
    '🎲' => 'ciyaarta dhimashada',
    '🧩' => 'gabal xujo',
    '🧸' => 'boombalo',
    '🪅' => 'boombalaha isbaanishka',
    '🪩' => 'kubada muraayadda',
    '🪆' => 'buulka boombalaha',
    '♠' => 'farshaxan',
    '♥' => 'lebiska qalbiga',
    '♦' => 'dheemanka lebiska',
    '♣' => 'lebiska naadiga',
    '♟' => 'jarta fiyooraha',
    '🃏' => 'jookar',
    '🀄' => 'mahjong masduulaagii gaduudnaa',
    '🎴' => 'ubaxa turubka',
    '🎭' => 'fulinta farshaxanka',
    '🖼' => 'sawirka la wareegay',
    '🎨' => 'farshaxan saxan',
    '🧵' => 'dun',
    '🪡' => 'irbada dharka',
    '🧶' => 'tidcidda',
    '🪢' => 'siriq',
    '👓' => 'muraayado',
    '🕶' => 'muraayada qoraxda',
    '🥽' => 'murayaadaha ilaalinta',
    '🥼' => 'koodhka laabka',
    '🦺' => 'jaakeetka garbo-gaabka ah ee badbaadada',
    '👔' => 'taayga qoorta',
    '👕' => 'garan',
    '👖' => 'jiinis',
    '🧣' => 'safaleeti',
    '🧤' => 'gacmo-gashi',
    '🧥' => 'koodh',
    '🧦' => 'sharibaado',
    '👗' => 'toob',
    '👘' => 'kimoono',
    '🥻' => 'saarii',
    '🩱' => 'hal calal oo dharka dabaasha ah',
    '🩲' => 'nigis',
    '🩳' => 'shoorti',
    '👙' => 'nigis iyo keeshali',
    '👚' => 'dharka dumarka',
    '🪭' => 'taageere gacanta laablaaban',
    '👛' => 'boorso',
    '👜' => 'shandada gacanta',
    '👝' => 'shandad yar',
    '🛍' => 'bacaha dukaameysiga',
    '🎒' => 'shandad dhabar',
    '🩴' => 'dacas',
    '👞' => 'kabo rag',
    '👟' => 'kabo orod',
    '🥾' => 'buudjhka socodka dheer',
    '🥿' => 'kabo siman',
    '👠' => 'kabo cidhib dhaadheer',
    '👡' => 'sandhalka dumarka',
    '🩰' => 'kabaha ballet-ka',
    '👢' => 'buudh dumar',
    '🪮' => 'timo qaadis',
    '👑' => 'taaj',
    '👒' => 'koofiyad dumar',
    '🎩' => 'koofiyad dheer',
    '🎓' => 'koofiyada qalinjabinta',
    '🧢' => 'koofiyad caadiya',
    '🪖' => 'koofiyada millatariga',
    '⛑' => 'madax-gashiga shaqaalaha badbaadinta',
    '📿' => 'tusbax',
    '💄' => 'libis',
    '💍' => 'fargal',
    '💎' => 'dhagax qaali ah',
    '🔇' => 'sameecad la aamusiiyay',
    '🔈' => 'sameecad cod yar',
    '🔉' => 'sameecad codkeedu dhexdhexaad yahay',
    '🔊' => 'sameecad codkeedu sareeyo',
    '📢' => 'kor u hadle',
    '📣' => 'mikirifoon',
    '📯' => 'hoonka boostada',
    '🔔' => 'jalas',
    '🔕' => 'jalas xariiqi saarantay',
    '🎼' => 'xaashida muusika',
    '🎵' => 'qoraal muusika',
    '🎶' => 'qoraalo muusika',
    '🎙' => 'mikirifoonka istuudyaha',
    '🎚' => 'heer qaade/dejiye',
    '🎛' => 'badhanada kaantaroolida',
    '🎤' => 'mikirifon',
    '🎧' => 'dhago',
    '📻' => 'raadiyow',
    '🎷' => 'buun',
    '🎺' => 'fuugwo',
    '🪊' => 'turumbo',
    '🪗' => 'alab muusik',
    '🎸' => 'giitaar',
    '🎹' => 'kiiboodhka muusika',
    '🎻' => 'seese',
    '🪕' => 'gitaar nooc mareykan ah',
    '🥁' => 'durbaan',
    '🪘' => 'durbaan dheer',
    '🪇' => 'maracas',
    '🪈' => 'biibiile',
    '🪉' => 'gitaar',
    '📱' => 'moobil',
    '📲' => 'moobil leh xariiq',
    '☎' => 'telefoon',
    '📞' => 'gacanta telefoonka',
    '📟' => 'ogeysiiye',
    '📠' => 'mishiinka fakiska',
    '🔋' => 'baytari',
    '🪫' => 'batari dabka ka dhacay',
    '🔌' => 'xadhiga dabka',
    '💻' => 'koombuyuutar laabtob ah',
    '🖥' => 'koombuyuutarka miiska',
    '🖨' => 'daabace',
    '⌨' => 'kiiboodh',
    '🖱' => 'mawska koombuyuutarka',
    '🖲' => 'kubada mowska',
    '💽' => 'cajalada koombuyuutarka',
    '💾' => 'cajalada faloobida',
    '💿' => 'cajalada obtikaalka ah',
    '📀' => 'dvd',
    '🧮' => 'tiriye',
    '🎥' => 'kamarada filimada',
    '🎞' => 'fareemyada filimka',
    '📽' => 'borojektarka filimada',
    '🎬' => 'samuurada bilowga duubista',
    '📺' => 'telefishan',
    '📷' => 'kamarad',
    '📸' => 'kamarad khashaafad leh',
    '📹' => 'kamarad fiidiyow',
    '📼' => 'cajalad fiidiyow',
    '🔍' => 'quruurad weynayso ah oo u jeeda bidix',
    '🔎' => 'quruurad weynayso ah oo u jeeda midig',
    '🕯' => 'shamac',
    '💡' => 'laambad dab',
    '🔦' => 'toosh',
    '🏮' => 'siraad warqad cas',
    '🪔' => 'feynuusta diya',
    '📔' => 'buug gal qurux badan leh',
    '📕' => 'buug xidhan',
    '📖' => 'buug furan',
    '📗' => 'buug akhtara',
    '📘' => 'buug buluuga',
    '📙' => 'buug liimi ah',
    '📚' => 'buugaag',
    '📓' => 'buug',
    '📒' => 'buuga xisaabaadka',
    '📃' => 'bog laaban',
    '📜' => 'duuban',
    '📄' => 'bog kor u jeeda',
    '📰' => 'jaraaid',
    '🗞' => 'jaraaid duuduuban',
    '📑' => 'qeybaha calaamadeynta buuga',
    '🔖' => 'calaamadeeye',
    '🏷' => 'warqad wax sheegaysa',
    '🪙' => 'lacag bir ah',
    '💰' => 'bac lacaga',
    '🪎' => 'sanduuqa keyd maaliyadeedka',
    '💴' => 'lacag yeen ah',
    '💵' => 'lacag doolar ah',
    '💶' => 'lacag yuuro ah',
    '💷' => 'lacag bownd ah',
    '💸' => 'lacag baalal leh',
    '💳' => 'kaarka deynta',
    '🧾' => 'rasiidh',
    '💹' => 'shaxan muujinaya yeen kordhaysa',
    '✉' => 'baqshad',
    '📧' => 'iimayl',
    '📨' => 'baqshad timi',
    '📩' => 'baqshad leh falaar',
    '📤' => 'qeybta fariimaha la diray',
    '📥' => 'qeybta fariimaha lasoo diray',
    '📦' => 'bushqad',
    '📫' => 'sanduuq boosto oo xidhan oo leh calan sareeya',
    '📪' => 'sanduuq boosto oo xidhan oo leh calan hooseeya',
    '📬' => 'sanduuq boosto oo furan oo leh calan sareeya',
    '📭' => 'sanduuq boosto oo furan oo leh calan hooseeya',
    '📮' => 'sanduuq boosto',
    '🗳' => 'sanduuq codeyn oo leh warqad codeyn',
    '✏' => 'qalin qori',
    '✒' => 'af-qalin madow',
    '🖋' => 'qalin saxeex',
    '🖊' => 'qalin',
    '🖌' => 'burushka buufinta',
    '🖍' => 'kalar',
    '📝' => 'xusuus qor',
    '💼' => 'shandad shaqo',
    '📁' => 'fooldarka faylasha',
    '📂' => 'fooldarka faylasha oo furan',
    '🗂' => 'kala qeybiyayaasha kaararka',
    '📅' => 'kaalandar',
    '📆' => 'kaalandarka la jaro',
    '🗒' => 'buug xaashiyiihiisa la rogo',
    '🗓' => 'kaalandar la rogo',
    '📇' => 'nidaaminta kaararka',
    '📈' => 'shaxan kordhaya',
    '📉' => 'shaxan yaraanaya',
    '📊' => 'shaxanka baar',
    '📋' => 'faylka qorista',
    '📌' => 'biinka wax lagu dhajiyo',
    '📍' => 'biinka wax lagu dhajiyo oo goobo ah',
    '📎' => 'biinka waraaqaha',
    '🖇' => 'biinanka waraaqaha oo isku xidhan',
    '📏' => 'mastarad toosan',
    '📐' => 'mastarad saddex-gees ah',
    '✂' => 'maqas',
    '🗃' => 'faylka kaararka',
    '🗄' => 'khaanadaha faylasha',
    '🗑' => 'caaga xashiishka',
    '🔒' => 'qufulan',
    '🔓' => 'furan',
    '🔏' => 'xidhan oo qalin wata',
    '🔐' => 'xidhan oo fure wata',
    '🔑' => 'fure',
    '🗝' => 'fure qadiimi ah',
    '🔨' => 'dube',
    '🪓' => 'faas',
    '⛏' => 'madaraq',
    '⚒' => 'dube iyo madaraq',
    '🛠' => 'dube iyo baanad',
    '🗡' => 'toorey',
    '⚔' => 'seefo isweydaarsan',
    '💣' => 'bam',
    '🪃' => 'majo',
    '🏹' => 'leeb iyo qaanso',
    '🛡' => 'gaashaan',
    '🪚' => 'miinshaar',
    '🔧' => 'baanad',
    '🪛' => 'kashwiito',
    '🔩' => 'weesar iyo bool',
    '⚙' => 'geer',
    '🗜' => 'isku xajiye',
    '⚖' => 'miisaan',
    '🦯' => 'usha cad indhoolaha',
    '🔗' => 'liinki',
    '⛓' => 'silsilado',
    '🪝' => 'jilaab',
    '🧰' => 'tuulbogos',
    '🧲' => 'birlab',
    '🪜' => 'jaranjaro',
    '🪏' => 'badeel',
    '⚗' => 'qalab nadiifin',
    '🧪' => 'tuyuubka tijaabinta',
    '🧫' => 'saxan wax laga dhex arki karo',
    '🧬' => 'dna',
    '🔬' => 'maykriskoob',
    '🔭' => 'diirad',
    '📡' => 'aanteenada satalaytka',
    '💉' => 'irbad',
    '🩸' => 'dhibic dhiig ah',
    '💊' => 'kiniin',
    '🩹' => 'balastar jilicsan',
    '🩼' => 'qoryo',
    '🩺' => 'qalabka wadnaha lagu dhageysto',
    '🩻' => 'raajo',
    '🚪' => 'albaab',
    '🛗' => 'wiish',
    '🪞' => 'muraayad',
    '🪟' => 'daaqad',
    '🛏' => 'sariir',
    '🛋' => 'fadhi iyo laambad',
    '🪑' => 'kursi',
    '🚽' => 'musqul',
    '🪠' => 'biyo mareen baneeye',
    '🚿' => 'shaawar',
    '🛁' => 'sinxi maydhasho',
    '🪤' => 'dabin jiirka',
    '🪒' => 'sakiin',
    '🧴' => 'caagada looshinka',
    '🧷' => 'biinka dharka',
    '🧹' => 'mafiiq/buluuyey',
    '🧺' => 'salad',
    '🧻' => 'duub waraaq ah',
    '🪣' => 'baaldi',
    '🧼' => 'saabuun',
    '🫧' => 'xumbo',
    '🪥' => 'caday',
    '🧽' => 'isboonji',
    '🧯' => 'dab-damiye',
    '🛒' => 'gaari-gacanka dukaameysiga',
    '🚬' => 'sigaar',
    '⚰' => 'sanduuq',
    '🪦' => 'qudbo',
    '⚱' => 'aas',
    '🧿' => 'balaayo xijaab',
    '🪬' => 'hamsa',
    '🗿' => 'farshaxanka dadkii hore la sawiray',
    '🪧' => 'calaamad',
    '🪪' => 'kaar aqoonsi',
    '🏧' => 'calaamadda ATM',
    '🚮' => 'calaamadda qashin qubidda',
    '🚰' => 'biyaha la cabi karo',
    '♿' => 'calaamadda kursiga curyaanka',
    '🚹' => 'qolka ragga',
    '🚺' => 'qolka haweenka',
    '🚻' => 'suuliga',
    '🚼' => 'calaamadda ilmaha',
    '🚾' => 'qolka biyaha',
    '🛂' => 'xakamaynta baasaboorka',
    '🛃' => 'canshuurta',
    '🛄' => 'boorso sheegasho',
    '🛅' => 'ka tagid cafash',
    '⚠' => 'digniin',
    '🚸' => 'caruurta oo gudbaya',
    '⛔' => 'Ma jirto gelitaan',
    '🚫' => 'reebban',
    '🚳' => 'baaskiil maya',
    '🚭' => 'sigaar cabidda maya',
    '🚯' => 'qashinka maya',
    '🚱' => 'biyaha aan la isticmaali karin',
    '🚷' => 'dadka lugaynaya maya',
    '📵' => 'ma jiraan taleefoonada gacanta',
    '🔞' => 'lama oggola qof ka yar siddeed iyo tobban',
    '☢' => 'kaah fale',
    '☣' => 'halis ku ah noolaha',
    '⬆' => 'fallaarta kor',
    '↗' => 'fallaarta kor ee midig',
    '➡' => 'fallarta midig',
    '↘' => 'fallaarta hoose ee midig',
    '⬇' => 'fallaarta hoose',
    '↙' => 'fallaarta hoose ee bidix',
    '⬅' => 'fallarta bidix',
    '↖' => 'fallaarta kor ee bidix',
    '↕' => 'falaadh kor u-jeeda',
    '↔' => 'fallaarta bidix-midig',
    '↩' => 'fallaarta midig u qalloocsan bidix',
    '↪' => 'fallaarta bidix u qalloocsan midig',
    '⤴' => 'fallaarta midig u qalloocsan kor',
    '⤵' => 'fallaarta midig u qalloocsan hoos',
    '🔃' => 'fallaarada taaggan ee saacad-wareegga',
    '🔄' => 'badhanka fallaarada ee lid saacad-wareegga',
    '🔙' => 'fallaarta GADAAL',
    '🔚' => 'Fallaarta DHAMMAADKA',
    '🔛' => 'fallaarta DUSHA!',
    '🔜' => 'falaarta DHAKHSASHADA',
    '🔝' => 'falaarta SARE',
    '🛐' => 'goobta cibaadada',
    '⚛' => 'calaamadda atam',
    '🕉' => 'Xuruuf diini ee Hindida',
    '✡' => 'xiddigga Da’uud',
    '☸' => 'diinta Hindida ee dharma',
    '☯' => 'diinta Shiinaha ee yin yang',
    '✝' => 'mactabka latin',
    '☦' => 'mactabka diinta asal-raacnimada',
    '☪' => 'bil iyo xiddig',
    '☮' => 'calaamadda nabadda',
    '🕎' => 'shumac caabudaan Yuhuudda',
    '🔯' => 'xiddig lix geeslood oo dhibic leh',
    '🪯' => 'khanda',
    '♈' => 'laxo',
    '♉' => 'dibigga Taurus',
    '♊' => 'mataanaha',
    '♋' => 'naaf',
    '♌' => 'boqorka libaaxa',
    '♍' => 'afaggaal',
    '♎' => 'cutubka miisaanka',
    '♏' => 'dib-qallooc',
    '♐' => 'dameerajoogeen',
    '♑' => 'riyaha',
    '♒' => 'cutubka xiddigga biyaha',
    '♓' => 'cutubka xiddiga ee kalluunka',
    '⛎' => 'abeeso',
    '🔀' => 'badhanka muusik daarista',
    '🔁' => 'badhanka ku celinta',
    '🔂' => 'ku celinta halka badhan',
    '▶' => 'badhanka cayaar',
    '⏩' => 'badhanka mootinta',
    '⏭' => 'badhanka muusik daarista xigga',
    '⏯' => 'bdhanka cayaar ama jooji ah',
    '◀' => 'badhanka dib u celinta',
    '⏪' => 'badhanka dib u celinta degdegga',
    '⏮' => 'badhanka daarista ugu dambeeya',
    '🔼' => 'badhanka xagga sare',
    '⏫' => 'badhanka degdegga sare ah',
    '🔽' => 'badhanka xagga hoose',
    '⏬' => 'badhanka degdegga hoose',
    '⏸' => 'badhanka hakinta',
    '⏹' => 'badhanka joojinta',
    '⏺' => 'badhanka duubista',
    '⏏' => 'badhanka ka soo saarista',
    '🎦' => 'shaleemo',
    '🔅' => 'daciif',
    '🔆' => 'badhanka dhalaalka',
    '📶' => 'xariiqaha anteenada',
    '🛜' => 'xaraga dhagaha',
    '📳' => 'habka gariirka',
    '📴' => 'dami taleefoonka gacanta',
    '♀' => 'calaamad dheddig',
    '♂' => 'calaamad lab',
    '⚧' => 'calaamada laba dhidiga',
    '✖' => 'calaamadda isku dhufashada',
    '➕' => 'calaamadda isugeynta',
    '➖' => 'calaamadda ka jar',
    '➗' => 'calaamadda isu qaybinta',
    '🟰' => 'calaamado isku mid ah oo culus',
    '♾' => 'xad la’aan',
    '‼' => 'laba calaamadood cajiib ah',
    '⁉' => 'calaamad cajiib su’aal ah',
    '❓' => 'calaamad su’aal',
    '❔' => 'ccalaamad su’aal cad',
    '❕' => 'calaamad cajiib cad',
    '❗' => 'calaamad cajiib',
    '〰' => 'qulqulka hirka',
    '💱' => 'sarifka lacagaha',
    '💲' => 'calaamad doolar oo muujisan',
    '⚕' => 'calaamad caafimaad',
    '♻' => 'calaamadda dib-u-warshadaynta',
    '⚜' => 'saddex midnimada quduuska',
    '🔱' => 'astaanta garab',
    '📛' => 'calaamadda magaca',
    '🔰' => 'calaamadda Jabbaaka ee dadka bilowga ah',
    '⭕' => 'goobo cas dalool leh',
    '✅' => 'badhanka calaamadda sax',
    '☑' => 'ku calaamadee sanduuqa sax',
    '✔' => 'ku calaamadee calaamad',
    '❌' => 'calaamadda iskutallaabta',
    '❎' => 'badhanka calaamadda iskutallaabta',
    '➰' => 'laaban oo sargo’an',
    '➿' => 'maroogsin sargo’an oo laban-laab ah',
    '〽' => 'qaybta calaamadda talantaalliga ah',
    '✳' => 'siddeed geesood oo isku nooc u taaggan',
    '✴' => 'xiddig siddeed geeslood oo tilmaama',
    '❇' => 'dhalaal',
    '™' => 'sumadda ganacsiga',
    '🫟' => 'firdhiye',
    '🔠' => 'geli xarfa weyn oo latin ah',
    '🔡' => 'geli xarfo latin oo yar yar',
    '🔢' => 'geli tirooyin',
    '🔣' => 'geli calaamado',
    '🔤' => 'geli xuruuf latin ah',
    '🅰' => 'badhan (nooca dhiigga)',
    '🆎' => 'AB badhan (nooca dhiigga)',
    '🅱' => 'B badhan (nooca dhiigga)',
    '🆑' => 'badhan CL',
    '🆒' => 'badhanka QABOW',
    '🆓' => 'badhanka BILAASH AH',
    'ℹ' => 'macluumaad',
    '🆔' => 'badhanka ID-ga',
    'Ⓜ' => 'M goobaysan',
    '🆕' => 'badhanka CUSUB',
    '🆖' => 'badhanka NG',
    '🅾' => 'badhanka O (nooca dhiigga)',
    '🆗' => 'badhanka OK',
    '🅿' => 'badhanka P',
    '🆘' => 'badhanka SOS',
    '🆙' => 'badhanka KOR!',
    '🆚' => 'badhanka VS',
    '🈁' => 'badhanka Jabbaanka “halkan”',
    '🈂' => 'badhanka ‘‘lacagta adeegga’‘ ee Jabbaanka',
    '🈷' => 'badhanka “qaddarka billaha ah” ee Jabbaanka',
    '🈶' => 'badhanka “ma aha bilaash” ee Jabbaanka',
    '🈯' => 'badhanka “kaydsan” ee Jabbaanka',
    '🉐' => 'badhanka ‘‘gorgortan’‘ ee Jabbaanka',
    '🈹' => 'badhanka ‘‘sicir-dhimis’‘ ee Jabbaanka',
    '🈚' => 'badhanka ‘‘waa bilaash’‘ ee Jabbaanka',
    '🈲' => 'badhanka ‘‘mamnuuc’‘ ee Jabbaanka',
    '🉑' => 'badhanka ‘‘la aqbali karo’‘ ee Jabbaanka',
    '🈸' => 'badhanka ‘‘codsiga’‘ ee Jabbaanka',
    '🈴' => 'badhanka ‘‘darajada baasitaanka’‘ ee Jabbaanka',
    '🈳' => 'badhanka ‘‘bannaan’‘ ee Jabbaanka',
    '㊗' => 'badhanka ‘‘hambalyo’‘ ee Jabbaanka',
    '㊙' => 'badhanka ‘‘sir’‘ ee Jabbaanka',
    '🈺' => 'badhanka ‘‘u furan ganacsi’‘ ee Jabbaanka',
    '🈵' => 'badhanka ‘‘ma bannaana’‘ ee Jabbaanka',
    '🔴' => 'goobada cas',
    '🟠' => 'goobada oranjiga ah',
    '🟡' => 'goobada jaallaha ah',
    '🟢' => 'goobada caggaarka ah',
    '🔵' => 'goobada buluugga',
    '🟣' => 'goobada buluug-guduudka ah',
    '🟤' => 'goobada bunniga ah',
    '⚫' => 'goobo madow',
    '⚪' => 'goobo cad',
    '🟥' => 'afar geeska casaanka ah',
    '🟧' => 'afar geeska oranjiga ah',
    '🟨' => 'afar geeska jaalaha',
    '🟩' => 'afar geeska caggaarka ah',
    '🟦' => 'afar geeska buluugga ah',
    '🟪' => 'afar geeska buluug-guduudka ah',
    '🟫' => 'afar geeska bunniga ah',
    '⬛' => 'afar gees weyn oo madow',
    '⬜' => 'afar gees weyn oo cad',
    '◼' => 'afar gees dhexdhexaad oo madow',
    '◻' => 'afar gees dhexdhexaad oo cad',
    '◾' => 'afar gees dhexdhexaad yar oo madow',
    '◽' => 'afar gees dhexdhexaad yar oo cad',
    '▪' => 'afar gees yar oo madow',
    '▫' => 'afar gees yar oo cad',
    '🔶' => 'dheeman weyn oo oranji ah',
    '🔷' => 'dheeman weyn oo buluug ah',
    '🔸' => 'dheeman yar oo oranji ah',
    '🔹' => 'dheeman yar oo buluug ah',
    '🔺' => 'saddex xaggale cas oo kor tilmaamaya',
    '🔻' => 'saddex xaggale cas oo hoos tilmaamaya',
    '💠' => 'dheeman leh dhibic',
    '🔘' => 'badhan raadiye',
    '🔳' => 'badhan afar gees oo cad',
    '🔲' => 'badhan afar gees ah oo madow',
    '🏁' => 'calanka la saxay',
    '🚩' => 'calanka saddex-geesoodka',
    '🎌' => 'calanka ka gudba',
    '🏴' => 'calanka madoow',
    '🏳' => 'calanka cad',
];
