<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 1–2 и тип на кожа 3',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 1–2 и тип на кожа 4',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 1–2 и тип на кожа 5',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 1–2 и тип на кожа 6',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 3 и тип на кожа 1–2',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 3 и тип на кожа 4',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 3 и тип на кожа 5',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 3 и тип на кожа 6',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 4 и тип на кожа 1–2',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 4 и тип на кожа 3',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 4 и тип на кожа 5',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 4 и тип на кожа 6',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 5 и тип на кожа 1–2',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 5 и тип на кожа 3',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 5 и тип на кожа 4',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 5 и тип на кожа 6',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 6 и тип на кожа 1–2',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 6 и тип на кожа 3',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 6 и тип на кожа 4',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'бакнеж: возрасно лице, возрасно лице, тип на кожа 6 и тип на кожа 5',
    '👨🏻‍❤‍💋‍👨🏻' => 'бакнеж: маж, маж и тип на кожа 1–2',
    '👨🏻‍❤‍💋‍👨🏼' => 'бакнеж: маж, маж, тип на кожа 1–2 и тип на кожа 3',
    '👨🏻‍❤‍💋‍👨🏽' => 'бакнеж: маж, маж, тип на кожа 1–2 и тип на кожа 4',
    '👨🏻‍❤‍💋‍👨🏾' => 'бакнеж: маж, маж, тип на кожа 1–2 и тип на кожа 5',
    '👨🏻‍❤‍💋‍👨🏿' => 'бакнеж: маж, маж, тип на кожа 1–2 и тип на кожа 6',
    '👨🏼‍❤‍💋‍👨🏻' => 'бакнеж: маж, маж, тип на кожа 3 и тип на кожа 1–2',
    '👨🏼‍❤‍💋‍👨🏼' => 'бакнеж: маж, маж и тип на кожа 3',
    '👨🏼‍❤‍💋‍👨🏽' => 'бакнеж: маж, маж, тип на кожа 3 и тип на кожа 4',
    '👨🏼‍❤‍💋‍👨🏾' => 'бакнеж: маж, маж, тип на кожа 3 и тип на кожа 5',
    '👨🏼‍❤‍💋‍👨🏿' => 'бакнеж: маж, маж, тип на кожа 3 и тип на кожа 6',
    '👨🏽‍❤‍💋‍👨🏻' => 'бакнеж: маж, маж, тип на кожа 4 и тип на кожа 1–2',
    '👨🏽‍❤‍💋‍👨🏼' => 'бакнеж: маж, маж, тип на кожа 4 и тип на кожа 3',
    '👨🏽‍❤‍💋‍👨🏽' => 'бакнеж: маж, маж и тип на кожа 4',
    '👨🏽‍❤‍💋‍👨🏾' => 'бакнеж: маж, маж, тип на кожа 4 и тип на кожа 5',
    '👨🏽‍❤‍💋‍👨🏿' => 'бакнеж: маж, маж, тип на кожа 4 и тип на кожа 6',
    '👨🏾‍❤‍💋‍👨🏻' => 'бакнеж: маж, маж, тип на кожа 5 и тип на кожа 1–2',
    '👨🏾‍❤‍💋‍👨🏼' => 'бакнеж: маж, маж, тип на кожа 5 и тип на кожа 3',
    '👨🏾‍❤‍💋‍👨🏽' => 'бакнеж: маж, маж, тип на кожа 5 и тип на кожа 4',
    '👨🏾‍❤‍💋‍👨🏾' => 'бакнеж: маж, маж и тип на кожа 5',
    '👨🏾‍❤‍💋‍👨🏿' => 'бакнеж: маж, маж, тип на кожа 5 и тип на кожа 6',
    '👨🏿‍❤‍💋‍👨🏻' => 'бакнеж: маж, маж, тип на кожа 6 и тип на кожа 1–2',
    '👨🏿‍❤‍💋‍👨🏼' => 'бакнеж: маж, маж, тип на кожа 6 и тип на кожа 3',
    '👨🏿‍❤‍💋‍👨🏽' => 'бакнеж: маж, маж, тип на кожа 6 и тип на кожа 4',
    '👨🏿‍❤‍💋‍👨🏾' => 'бакнеж: маж, маж, тип на кожа 6 и тип на кожа 5',
    '👨🏿‍❤‍💋‍👨🏿' => 'бакнеж: маж, маж и тип на кожа 6',
    '👩🏻‍❤‍💋‍👨🏻' => 'бакнеж: жена, маж и тип на кожа 1–2',
    '👩🏻‍❤‍💋‍👨🏼' => 'бакнеж: жена, маж, тип на кожа 1–2 и тип на кожа 3',
    '👩🏻‍❤‍💋‍👨🏽' => 'бакнеж: жена, маж, тип на кожа 1–2 и тип на кожа 4',
    '👩🏻‍❤‍💋‍👨🏾' => 'бакнеж: жена, маж, тип на кожа 1–2 и тип на кожа 5',
    '👩🏻‍❤‍💋‍👨🏿' => 'бакнеж: жена, маж, тип на кожа 1–2 и тип на кожа 6',
    '👩🏼‍❤‍💋‍👨🏻' => 'бакнеж: жена, маж, тип на кожа 3 и тип на кожа 1–2',
    '👩🏼‍❤‍💋‍👨🏼' => 'бакнеж: жена, маж и тип на кожа 3',
    '👩🏼‍❤‍💋‍👨🏽' => 'бакнеж: жена, маж, тип на кожа 3 и тип на кожа 4',
    '👩🏼‍❤‍💋‍👨🏾' => 'бакнеж: жена, маж, тип на кожа 3 и тип на кожа 5',
    '👩🏼‍❤‍💋‍👨🏿' => 'бакнеж: жена, маж, тип на кожа 3 и тип на кожа 6',
    '👩🏽‍❤‍💋‍👨🏻' => 'бакнеж: жена, маж, тип на кожа 4 и тип на кожа 1–2',
    '👩🏽‍❤‍💋‍👨🏼' => 'бакнеж: жена, маж, тип на кожа 4 и тип на кожа 3',
    '👩🏽‍❤‍💋‍👨🏽' => 'бакнеж: жена, маж и тип на кожа 4',
    '👩🏽‍❤‍💋‍👨🏾' => 'бакнеж: жена, маж, тип на кожа 4 и тип на кожа 5',
    '👩🏽‍❤‍💋‍👨🏿' => 'бакнеж: жена, маж, тип на кожа 4 и тип на кожа 6',
    '👩🏾‍❤‍💋‍👨🏻' => 'бакнеж: жена, маж, тип на кожа 5 и тип на кожа 1–2',
    '👩🏾‍❤‍💋‍👨🏼' => 'бакнеж: жена, маж, тип на кожа 5 и тип на кожа 3',
    '👩🏾‍❤‍💋‍👨🏽' => 'бакнеж: жена, маж, тип на кожа 5 и тип на кожа 4',
    '👩🏾‍❤‍💋‍👨🏾' => 'бакнеж: жена, маж и тип на кожа 5',
    '👩🏾‍❤‍💋‍👨🏿' => 'бакнеж: жена, маж, тип на кожа 5 и тип на кожа 6',
    '👩🏿‍❤‍💋‍👨🏻' => 'бакнеж: жена, маж, тип на кожа 6 и тип на кожа 1–2',
    '👩🏿‍❤‍💋‍👨🏼' => 'бакнеж: жена, маж, тип на кожа 6 и тип на кожа 3',
    '👩🏿‍❤‍💋‍👨🏽' => 'бакнеж: жена, маж, тип на кожа 6 и тип на кожа 4',
    '👩🏿‍❤‍💋‍👨🏾' => 'бакнеж: жена, маж, тип на кожа 6 и тип на кожа 5',
    '👩🏿‍❤‍💋‍👨🏿' => 'бакнеж: жена, маж и тип на кожа 6',
    '👩🏻‍❤‍💋‍👩🏻' => 'бакнеж: жена, жена и тип на кожа 1–2',
    '👩🏻‍❤‍💋‍👩🏼' => 'бакнеж: жена, жена, тип на кожа 1–2 и тип на кожа 3',
    '👩🏻‍❤‍💋‍👩🏽' => 'бакнеж: жена, жена, тип на кожа 1–2 и тип на кожа 4',
    '👩🏻‍❤‍💋‍👩🏾' => 'бакнеж: жена, жена, тип на кожа 1–2 и тип на кожа 5',
    '👩🏻‍❤‍💋‍👩🏿' => 'бакнеж: жена, жена, тип на кожа 1–2 и тип на кожа 6',
    '👩🏼‍❤‍💋‍👩🏻' => 'бакнеж: жена, жена, тип на кожа 3 и тип на кожа 1–2',
    '👩🏼‍❤‍💋‍👩🏼' => 'бакнеж: жена, жена и тип на кожа 3',
    '👩🏼‍❤‍💋‍👩🏽' => 'бакнеж: жена, жена, тип на кожа 3 и тип на кожа 4',
    '👩🏼‍❤‍💋‍👩🏾' => 'бакнеж: жена, жена, тип на кожа 3 и тип на кожа 5',
    '👩🏼‍❤‍💋‍👩🏿' => 'бакнеж: жена, жена, тип на кожа 3 и тип на кожа 6',
    '👩🏽‍❤‍💋‍👩🏻' => 'бакнеж: жена, жена, тип на кожа 4 и тип на кожа 1–2',
    '👩🏽‍❤‍💋‍👩🏼' => 'бакнеж: жена, жена, тип на кожа 4 и тип на кожа 3',
    '👩🏽‍❤‍💋‍👩🏽' => 'бакнеж: жена, жена и тип на кожа 4',
    '👩🏽‍❤‍💋‍👩🏾' => 'бакнеж: жена, жена, тип на кожа 4 и тип на кожа 5',
    '👩🏽‍❤‍💋‍👩🏿' => 'бакнеж: жена, жена, тип на кожа 4 и тип на кожа 6',
    '👩🏾‍❤‍💋‍👩🏻' => 'бакнеж: жена, жена, тип на кожа 5 и тип на кожа 1–2',
    '👩🏾‍❤‍💋‍👩🏼' => 'бакнеж: жена, жена, тип на кожа 5 и тип на кожа 3',
    '👩🏾‍❤‍💋‍👩🏽' => 'бакнеж: жена, жена, тип на кожа 5 и тип на кожа 4',
    '👩🏾‍❤‍💋‍👩🏾' => 'бакнеж: жена, жена и тип на кожа 5',
    '👩🏾‍❤‍💋‍👩🏿' => 'бакнеж: жена, жена, тип на кожа 5 и тип на кожа 6',
    '👩🏿‍❤‍💋‍👩🏻' => 'бакнеж: жена, жена, тип на кожа 6 и тип на кожа 1–2',
    '👩🏿‍❤‍💋‍👩🏼' => 'бакнеж: жена, жена, тип на кожа 6 и тип на кожа 3',
    '👩🏿‍❤‍💋‍👩🏽' => 'бакнеж: жена, жена, тип на кожа 6 и тип на кожа 4',
    '👩🏿‍❤‍💋‍👩🏾' => 'бакнеж: жена, жена, тип на кожа 6 и тип на кожа 5',
    '👩🏿‍❤‍💋‍👩🏿' => 'бакнеж: жена, жена и тип на кожа 6',
    '🧑🏻‍🫯‍🧑🏼' => 'лица кои се борат: тип на кожа 1–2 и тип на кожа 3',
    '🧑🏻‍🫯‍🧑🏽' => 'лица кои се борат: тип на кожа 1–2 и тип на кожа 4',
    '🧑🏻‍🫯‍🧑🏾' => 'лица кои се борат: тип на кожа 1–2 и тип на кожа 5',
    '🧑🏻‍🫯‍🧑🏿' => 'лица кои се борат: тип на кожа 1–2 и тип на кожа 6',
    '🧑🏼‍🫯‍🧑🏻' => 'лица кои се борат: тип на кожа 3 и тип на кожа 1–2',
    '🧑🏼‍🫯‍🧑🏽' => 'лица кои се борат: тип на кожа 3 и тип на кожа 4',
    '🧑🏼‍🫯‍🧑🏾' => 'лица кои се борат: тип на кожа 3 и тип на кожа 5',
    '🧑🏼‍🫯‍🧑🏿' => 'лица кои се борат: тип на кожа 3 и тип на кожа 6',
    '🧑🏽‍🫯‍🧑🏻' => 'лица кои се борат: тип на кожа 4 и тип на кожа 1–2',
    '🧑🏽‍🫯‍🧑🏼' => 'лица кои се борат: тип на кожа 4 и тип на кожа 3',
    '🧑🏽‍🫯‍🧑🏾' => 'лица кои се борат: тип на кожа 4 и тип на кожа 5',
    '🧑🏽‍🫯‍🧑🏿' => 'лица кои се борат: тип на кожа 4 и тип на кожа 6',
    '🧑🏾‍🫯‍🧑🏻' => 'лица кои се борат: тип на кожа 5 и тип на кожа 1–2',
    '🧑🏾‍🫯‍🧑🏼' => 'лица кои се борат: тип на кожа 5 и тип на кожа 3',
    '🧑🏾‍🫯‍🧑🏽' => 'лица кои се борат: тип на кожа 5 и тип на кожа 4',
    '🧑🏾‍🫯‍🧑🏿' => 'лица кои се борат: тип на кожа 5 и тип на кожа 6',
    '🧑🏿‍🫯‍🧑🏻' => 'лица кои се борат: тип на кожа 6 и тип на кожа 1–2',
    '🧑🏿‍🫯‍🧑🏼' => 'лица кои се борат: тип на кожа 6 и тип на кожа 3',
    '🧑🏿‍🫯‍🧑🏽' => 'лица кои се борат: тип на кожа 6 и тип на кожа 4',
    '🧑🏿‍🫯‍🧑🏾' => 'лица кои се борат: тип на кожа 6 и тип на кожа 5',
    '🧑🏻‍❤‍🧑🏼' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 1–2 и тип на кожа 3',
    '🧑🏻‍❤‍🧑🏽' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 1–2 и тип на кожа 4',
    '🧑🏻‍❤‍🧑🏾' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 1–2 и тип на кожа 5',
    '🧑🏻‍❤‍🧑🏿' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 1–2 и тип на кожа 6',
    '🧑🏼‍❤‍🧑🏻' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 3 и тип на кожа 1–2',
    '🧑🏼‍❤‍🧑🏽' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 3 и тип на кожа 4',
    '🧑🏼‍❤‍🧑🏾' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 3 и тип на кожа 5',
    '🧑🏼‍❤‍🧑🏿' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 3 и тип на кожа 6',
    '🧑🏽‍❤‍🧑🏻' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 4 и тип на кожа 1–2',
    '🧑🏽‍❤‍🧑🏼' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 4 и тип на кожа 3',
    '🧑🏽‍❤‍🧑🏾' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 4 и тип на кожа 5',
    '🧑🏽‍❤‍🧑🏿' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 4 и тип на кожа 6',
    '🧑🏾‍❤‍🧑🏻' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 5 и тип на кожа 1–2',
    '🧑🏾‍❤‍🧑🏼' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 5 и тип на кожа 3',
    '🧑🏾‍❤‍🧑🏽' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 5 и тип на кожа 4',
    '🧑🏾‍❤‍🧑🏿' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 5 и тип на кожа 6',
    '🧑🏿‍❤‍🧑🏻' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 6 и тип на кожа 1–2',
    '🧑🏿‍❤‍🧑🏼' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 6 и тип на кожа 3',
    '🧑🏿‍❤‍🧑🏽' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 6 и тип на кожа 4',
    '🧑🏿‍❤‍🧑🏾' => 'пар со срце: возрасно лице, возрасно лице, тип на кожа 6 и тип на кожа 5',
    '🧑🏻‍🐰‍🧑🏼' => 'лица кои се забавуваат: тип на кожа 1–2 и тип на кожа 3',
    '🧑🏻‍🐰‍🧑🏽' => 'лица кои се забавуваат: тип на кожа 1–2 и тип на кожа 4',
    '🧑🏻‍🐰‍🧑🏾' => 'лица кои се забавуваат: тип на кожа 1–2 и тип на кожа 5',
    '🧑🏻‍🐰‍🧑🏿' => 'лица кои се забавуваат: тип на кожа 1–2 и тип на кожа 6',
    '🧑🏼‍🐰‍🧑🏻' => 'лица кои се забавуваат: тип на кожа 3 и тип на кожа 1–2',
    '🧑🏼‍🐰‍🧑🏽' => 'лица кои се забавуваат: тип на кожа 3 и тип на кожа 4',
    '🧑🏼‍🐰‍🧑🏾' => 'лица кои се забавуваат: тип на кожа 3 и тип на кожа 5',
    '🧑🏼‍🐰‍🧑🏿' => 'лица кои се забавуваат: тип на кожа 3 и тип на кожа 6',
    '🧑🏽‍🐰‍🧑🏻' => 'лица кои се забавуваат: тип на кожа 4 и тип на кожа 1–2',
    '🧑🏽‍🐰‍🧑🏼' => 'лица кои се забавуваат: тип на кожа 4 и тип на кожа 3',
    '🧑🏽‍🐰‍🧑🏾' => 'лица кои се забавуваат: тип на кожа 4 и тип на кожа 5',
    '🧑🏽‍🐰‍🧑🏿' => 'лица кои се забавуваат: тип на кожа 4 и тип на кожа 6',
    '🧑🏾‍🐰‍🧑🏻' => 'лица кои се забавуваат: тип на кожа 5 и тип на кожа 1–2',
    '🧑🏾‍🐰‍🧑🏼' => 'лица кои се забавуваат: тип на кожа 5 и тип на кожа 3',
    '🧑🏾‍🐰‍🧑🏽' => 'лица кои се забавуваат: тип на кожа 5 и тип на кожа 4',
    '🧑🏾‍🐰‍🧑🏿' => 'лица кои се забавуваат: тип на кожа 5 и тип на кожа 6',
    '🧑🏿‍🐰‍🧑🏻' => 'лица кои се забавуваат: тип на кожа 6 и тип на кожа 1–2',
    '🧑🏿‍🐰‍🧑🏼' => 'лица кои се забавуваат: тип на кожа 6 и тип на кожа 3',
    '🧑🏿‍🐰‍🧑🏽' => 'лица кои се забавуваат: тип на кожа 6 и тип на кожа 4',
    '🧑🏿‍🐰‍🧑🏾' => 'лица кои се забавуваат: тип на кожа 6 и тип на кожа 5',
    '👨🏻‍🫯‍👨🏼' => 'борачи: тип на кожа 1–2 и тип на кожа 3',
    '👨🏻‍🫯‍👨🏽' => 'борачи: тип на кожа 1–2 и тип на кожа 4',
    '👨🏻‍🫯‍👨🏾' => 'борачи: тип на кожа 1–2 и тип на кожа 5',
    '👨🏻‍🫯‍👨🏿' => 'борачи: тип на кожа 1–2 и тип на кожа 6',
    '👨🏼‍🫯‍👨🏻' => 'борачи: тип на кожа 3 и тип на кожа 1–2',
    '👨🏼‍🫯‍👨🏽' => 'борачи: тип на кожа 3 и тип на кожа 4',
    '👨🏼‍🫯‍👨🏾' => 'борачи: тип на кожа 3 и тип на кожа 5',
    '👨🏼‍🫯‍👨🏿' => 'борачи: тип на кожа 3 и тип на кожа 6',
    '👨🏽‍🫯‍👨🏻' => 'борачи: тип на кожа 4 и тип на кожа 1–2',
    '👨🏽‍🫯‍👨🏼' => 'борачи: тип на кожа 4 и тип на кожа 3',
    '👨🏽‍🫯‍👨🏾' => 'борачи: тип на кожа 4 и тип на кожа 5',
    '👨🏽‍🫯‍👨🏿' => 'борачи: тип на кожа 4 и тип на кожа 6',
    '👨🏾‍🫯‍👨🏻' => 'борачи: тип на кожа 5 и тип на кожа 1–2',
    '👨🏾‍🫯‍👨🏼' => 'борачи: тип на кожа 5 и тип на кожа 3',
    '👨🏾‍🫯‍👨🏽' => 'борачи: тип на кожа 5 и тип на кожа 4',
    '👨🏾‍🫯‍👨🏿' => 'борачи: тип на кожа 5 и тип на кожа 6',
    '👨🏿‍🫯‍👨🏻' => 'борачи: тип на кожа 6 и тип на кожа 1–2',
    '👨🏿‍🫯‍👨🏼' => 'борачи: тип на кожа 6 и тип на кожа 3',
    '👨🏿‍🫯‍👨🏽' => 'борачи: тип на кожа 6 и тип на кожа 4',
    '👨🏿‍🫯‍👨🏾' => 'борачи: тип на кожа 6 и тип на кожа 5',
    '👨🏻‍❤‍👨🏻' => 'пар со срце: маж, маж и тип на кожа 1–2',
    '👨🏻‍❤‍👨🏼' => 'пар со срце: маж, маж, тип на кожа 1–2 и тип на кожа 3',
    '👨🏻‍❤‍👨🏽' => 'пар со срце: маж, маж, тип на кожа 1–2 и тип на кожа 4',
    '👨🏻‍❤‍👨🏾' => 'пар со срце: маж, маж, тип на кожа 1–2 и тип на кожа 5',
    '👨🏻‍❤‍👨🏿' => 'пар со срце: маж, маж, тип на кожа 1–2 и тип на кожа 6',
    '👨🏼‍❤‍👨🏻' => 'пар со срце: маж, маж, тип на кожа 3 и тип на кожа 1–2',
    '👨🏼‍❤‍👨🏼' => 'пар со срце: маж, маж и тип на кожа 3',
    '👨🏼‍❤‍👨🏽' => 'пар со срце: маж, маж, тип на кожа 3 и тип на кожа 4',
    '👨🏼‍❤‍👨🏾' => 'пар со срце: маж, маж, тип на кожа 3 и тип на кожа 5',
    '👨🏼‍❤‍👨🏿' => 'пар со срце: маж, маж, тип на кожа 3 и тип на кожа 6',
    '👨🏽‍❤‍👨🏻' => 'пар со срце: маж, маж, тип на кожа 4 и тип на кожа 1–2',
    '👨🏽‍❤‍👨🏼' => 'пар со срце: маж, маж, тип на кожа 4 и тип на кожа 3',
    '👨🏽‍❤‍👨🏽' => 'пар со срце: маж, маж и тип на кожа 4',
    '👨🏽‍❤‍👨🏾' => 'пар со срце: маж, маж, тип на кожа 4 и тип на кожа 5',
    '👨🏽‍❤‍👨🏿' => 'пар со срце: маж, маж, тип на кожа 4 и тип на кожа 6',
    '👨🏾‍❤‍👨🏻' => 'пар со срце: маж, маж, тип на кожа 5 и тип на кожа 1–2',
    '👨🏾‍❤‍👨🏼' => 'пар со срце: маж, маж, тип на кожа 5 и тип на кожа 3',
    '👨🏾‍❤‍👨🏽' => 'пар со срце: маж, маж, тип на кожа 5 и тип на кожа 4',
    '👨🏾‍❤‍👨🏾' => 'пар со срце: маж, маж и тип на кожа 5',
    '👨🏾‍❤‍👨🏿' => 'пар со срце: маж, маж, тип на кожа 5 и тип на кожа 6',
    '👨🏿‍❤‍👨🏻' => 'пар со срце: маж, маж, тип на кожа 6 и тип на кожа 1–2',
    '👨🏿‍❤‍👨🏼' => 'пар со срце: маж, маж, тип на кожа 6 и тип на кожа 3',
    '👨🏿‍❤‍👨🏽' => 'пар со срце: маж, маж, тип на кожа 6 и тип на кожа 4',
    '👨🏿‍❤‍👨🏾' => 'пар со срце: маж, маж, тип на кожа 6 и тип на кожа 5',
    '👨🏿‍❤‍👨🏿' => 'пар со срце: маж, маж и тип на кожа 6',
    '👨🏻‍🐰‍👨🏼' => 'мажи кои се забавуваат: тип на кожа 1–2 и тип на кожа 3',
    '👨🏻‍🐰‍👨🏽' => 'мажи кои се забавуваат: тип на кожа 1–2 и тип на кожа 4',
    '👨🏻‍🐰‍👨🏾' => 'мажи кои се забавуваат: тип на кожа 1–2 и тип на кожа 5',
    '👨🏻‍🐰‍👨🏿' => 'мажи кои се забавуваат: тип на кожа 1–2 и тип на кожа 6',
    '👨🏼‍🐰‍👨🏻' => 'мажи кои се забавуваат: тип на кожа 3 и тип на кожа 1–2',
    '👨🏼‍🐰‍👨🏽' => 'мажи кои се забавуваат: тип на кожа 3 и тип на кожа 4',
    '👨🏼‍🐰‍👨🏾' => 'мажи кои се забавуваат: тип на кожа 3 и тип на кожа 5',
    '👨🏼‍🐰‍👨🏿' => 'мажи кои се забавуваат: тип на кожа 3 и тип на кожа 6',
    '👨🏽‍🐰‍👨🏻' => 'мажи кои се забавуваат: тип на кожа 4 и тип на кожа 1–2',
    '👨🏽‍🐰‍👨🏼' => 'мажи кои се забавуваат: тип на кожа 4 и тип на кожа 3',
    '👨🏽‍🐰‍👨🏾' => 'мажи кои се забавуваат: тип на кожа 4 и тип на кожа 5',
    '👨🏽‍🐰‍👨🏿' => 'мажи кои се забавуваат: тип на кожа 4 и тип на кожа 6',
    '👨🏾‍🐰‍👨🏻' => 'мажи кои се забавуваат: тип на кожа 5 и тип на кожа 1–2',
    '👨🏾‍🐰‍👨🏼' => 'мажи кои се забавуваат: тип на кожа 5 и тип на кожа 3',
    '👨🏾‍🐰‍👨🏽' => 'мажи кои се забавуваат: тип на кожа 5 и тип на кожа 4',
    '👨🏾‍🐰‍👨🏿' => 'мажи кои се забавуваат: тип на кожа 5 и тип на кожа 6',
    '👨🏿‍🐰‍👨🏻' => 'мажи кои се забавуваат: тип на кожа 6 и тип на кожа 1–2',
    '👨🏿‍🐰‍👨🏼' => 'мажи кои се забавуваат: тип на кожа 6 и тип на кожа 3',
    '👨🏿‍🐰‍👨🏽' => 'мажи кои се забавуваат: тип на кожа 6 и тип на кожа 4',
    '👨🏿‍🐰‍👨🏾' => 'мажи кои се забавуваат: тип на кожа 6 и тип на кожа 5',
    '👩🏻‍🫯‍👩🏼' => 'борачки: тип на кожа 1–2 и тип на кожа 3',
    '👩🏻‍🫯‍👩🏽' => 'борачки: тип на кожа 1–2 и тип на кожа 4',
    '👩🏻‍🫯‍👩🏾' => 'борачки: тип на кожа 1–2 и тип на кожа 5',
    '👩🏻‍🫯‍👩🏿' => 'борачки: тип на кожа 1–2 и тип на кожа 6',
    '👩🏼‍🫯‍👩🏻' => 'борачки: тип на кожа 3 и тип на кожа 1–2',
    '👩🏼‍🫯‍👩🏽' => 'борачки: тип на кожа 3 и тип на кожа 4',
    '👩🏼‍🫯‍👩🏾' => 'борачки: тип на кожа 3 и тип на кожа 5',
    '👩🏼‍🫯‍👩🏿' => 'борачки: тип на кожа 3 и тип на кожа 6',
    '👩🏽‍🫯‍👩🏻' => 'борачки: тип на кожа 4 и тип на кожа 1–2',
    '👩🏽‍🫯‍👩🏼' => 'борачки: тип на кожа 4 и тип на кожа 3',
    '👩🏽‍🫯‍👩🏾' => 'борачки: тип на кожа 4 и тип на кожа 5',
    '👩🏽‍🫯‍👩🏿' => 'борачки: тип на кожа 4 и тип на кожа 6',
    '👩🏾‍🫯‍👩🏻' => 'борачки: тип на кожа 5 и тип на кожа 1–2',
    '👩🏾‍🫯‍👩🏼' => 'борачки: тип на кожа 5 и тип на кожа 3',
    '👩🏾‍🫯‍👩🏽' => 'борачки: тип на кожа 5 и тип на кожа 4',
    '👩🏾‍🫯‍👩🏿' => 'борачки: тип на кожа 5 и тип на кожа 6',
    '👩🏿‍🫯‍👩🏻' => 'борачки: тип на кожа 6 и тип на кожа 1–2',
    '👩🏿‍🫯‍👩🏼' => 'борачки: тип на кожа 6 и тип на кожа 3',
    '👩🏿‍🫯‍👩🏽' => 'борачки: тип на кожа 6 и тип на кожа 4',
    '👩🏿‍🫯‍👩🏾' => 'борачки: тип на кожа 6 и тип на кожа 5',
    '👩🏻‍❤‍👨🏻' => 'пар со срце: жена, маж и тип на кожа 1–2',
    '👩🏻‍❤‍👨🏼' => 'пар со срце: жена, маж, тип на кожа 1–2 и тип на кожа 3',
    '👩🏻‍❤‍👨🏽' => 'пар со срце: жена, маж, тип на кожа 1–2 и тип на кожа 4',
    '👩🏻‍❤‍👨🏾' => 'пар со срце: жена, маж, тип на кожа 1–2 и тип на кожа 5',
    '👩🏻‍❤‍👨🏿' => 'пар со срце: жена, маж, тип на кожа 1–2 и тип на кожа 6',
    '👩🏼‍❤‍👨🏻' => 'пар со срце: жена, маж, тип на кожа 3 и тип на кожа 1–2',
    '👩🏼‍❤‍👨🏼' => 'пар со срце: жена, маж и тип на кожа 3',
    '👩🏼‍❤‍👨🏽' => 'пар со срце: жена, маж, тип на кожа 3 и тип на кожа 4',
    '👩🏼‍❤‍👨🏾' => 'пар со срце: жена, маж, тип на кожа 3 и тип на кожа 5',
    '👩🏼‍❤‍👨🏿' => 'пар со срце: жена, маж, тип на кожа 3 и тип на кожа 6',
    '👩🏽‍❤‍👨🏻' => 'пар со срце: жена, маж, тип на кожа 4 и тип на кожа 1–2',
    '👩🏽‍❤‍👨🏼' => 'пар со срце: жена, маж, тип на кожа 4 и тип на кожа 3',
    '👩🏽‍❤‍👨🏽' => 'пар со срце: жена, маж и тип на кожа 4',
    '👩🏽‍❤‍👨🏾' => 'пар со срце: жена, маж, тип на кожа 4 и тип на кожа 5',
    '👩🏽‍❤‍👨🏿' => 'пар со срце: жена, маж, тип на кожа 4 и тип на кожа 6',
    '👩🏾‍❤‍👨🏻' => 'пар со срце: жена, маж, тип на кожа 5 и тип на кожа 1–2',
    '👩🏾‍❤‍👨🏼' => 'пар со срце: жена, маж, тип на кожа 5 и тип на кожа 3',
    '👩🏾‍❤‍👨🏽' => 'пар со срце: жена, маж, тип на кожа 5 и тип на кожа 4',
    '👩🏾‍❤‍👨🏾' => 'пар со срце: жена, маж и тип на кожа 5',
    '👩🏾‍❤‍👨🏿' => 'пар со срце: жена, маж, тип на кожа 5 и тип на кожа 6',
    '👩🏿‍❤‍👨🏻' => 'пар со срце: жена, маж, тип на кожа 6 и тип на кожа 1–2',
    '👩🏿‍❤‍👨🏼' => 'пар со срце: жена, маж, тип на кожа 6 и тип на кожа 3',
    '👩🏿‍❤‍👨🏽' => 'пар со срце: жена, маж, тип на кожа 6 и тип на кожа 4',
    '👩🏿‍❤‍👨🏾' => 'пар со срце: жена, маж, тип на кожа 6 и тип на кожа 5',
    '👩🏿‍❤‍👨🏿' => 'пар со срце: жена, маж и тип на кожа 6',
    '👩🏻‍❤‍👩🏻' => 'пар со срце: жена, жена и тип на кожа 1–2',
    '👩🏻‍❤‍👩🏼' => 'пар со срце: жена, жена, тип на кожа 1–2 и тип на кожа 3',
    '👩🏻‍❤‍👩🏽' => 'пар со срце: жена, жена, тип на кожа 1–2 и тип на кожа 4',
    '👩🏻‍❤‍👩🏾' => 'пар со срце: жена, жена, тип на кожа 1–2 и тип на кожа 5',
    '👩🏻‍❤‍👩🏿' => 'пар со срце: жена, жена, тип на кожа 1–2 и тип на кожа 6',
    '👩🏼‍❤‍👩🏻' => 'пар со срце: жена, жена, тип на кожа 3 и тип на кожа 1–2',
    '👩🏼‍❤‍👩🏼' => 'пар со срце: жена, жена и тип на кожа 3',
    '👩🏼‍❤‍👩🏽' => 'пар со срце: жена, жена, тип на кожа 3 и тип на кожа 4',
    '👩🏼‍❤‍👩🏾' => 'пар со срце: жена, жена, тип на кожа 3 и тип на кожа 5',
    '👩🏼‍❤‍👩🏿' => 'пар со срце: жена, жена, тип на кожа 3 и тип на кожа 6',
    '👩🏽‍❤‍👩🏻' => 'пар со срце: жена, жена, тип на кожа 4 и тип на кожа 1–2',
    '👩🏽‍❤‍👩🏼' => 'пар со срце: жена, жена, тип на кожа 4 и тип на кожа 3',
    '👩🏽‍❤‍👩🏽' => 'пар со срце: жена, жена и тип на кожа 4',
    '👩🏽‍❤‍👩🏾' => 'пар со срце: жена, жена, тип на кожа 4 и тип на кожа 5',
    '👩🏽‍❤‍👩🏿' => 'пар со срце: жена, жена, тип на кожа 4 и тип на кожа 6',
    '👩🏾‍❤‍👩🏻' => 'пар со срце: жена, жена, тип на кожа 5 и тип на кожа 1–2',
    '👩🏾‍❤‍👩🏼' => 'пар со срце: жена, жена, тип на кожа 5 и тип на кожа 3',
    '👩🏾‍❤‍👩🏽' => 'пар со срце: жена, жена, тип на кожа 5 и тип на кожа 4',
    '👩🏾‍❤‍👩🏾' => 'пар со срце: жена, жена и тип на кожа 5',
    '👩🏾‍❤‍👩🏿' => 'пар со срце: жена, жена, тип на кожа 5 и тип на кожа 6',
    '👩🏿‍❤‍👩🏻' => 'пар со срце: жена, жена, тип на кожа 6 и тип на кожа 1–2',
    '👩🏿‍❤‍👩🏼' => 'пар со срце: жена, жена, тип на кожа 6 и тип на кожа 3',
    '👩🏿‍❤‍👩🏽' => 'пар со срце: жена, жена, тип на кожа 6 и тип на кожа 4',
    '👩🏿‍❤‍👩🏾' => 'пар со срце: жена, жена, тип на кожа 6 и тип на кожа 5',
    '👩🏿‍❤‍👩🏿' => 'пар со срце: жена, жена и тип на кожа 6',
    '👩🏻‍🐰‍👩🏼' => 'жени кои се забавуваат: тип на кожа 1–2 и тип на кожа 3',
    '👩🏻‍🐰‍👩🏽' => 'жени кои се забавуваат: тип на кожа 1–2 и тип на кожа 4',
    '👩🏻‍🐰‍👩🏾' => 'жени кои се забавуваат: тип на кожа 1–2 и тип на кожа 5',
    '👩🏻‍🐰‍👩🏿' => 'жени кои се забавуваат: тип на кожа 1–2 и тип на кожа 6',
    '👩🏼‍🐰‍👩🏻' => 'жени кои се забавуваат: тип на кожа 3 и тип на кожа 1–2',
    '👩🏼‍🐰‍👩🏽' => 'жени кои се забавуваат: тип на кожа 3 и тип на кожа 4',
    '👩🏼‍🐰‍👩🏾' => 'жени кои се забавуваат: тип на кожа 3 и тип на кожа 5',
    '👩🏼‍🐰‍👩🏿' => 'жени кои се забавуваат: тип на кожа 3 и тип на кожа 6',
    '👩🏽‍🐰‍👩🏻' => 'жени кои се забавуваат: тип на кожа 4 и тип на кожа 1–2',
    '👩🏽‍🐰‍👩🏼' => 'жени кои се забавуваат: тип на кожа 4 и тип на кожа 3',
    '👩🏽‍🐰‍👩🏾' => 'жени кои се забавуваат: тип на кожа 4 и тип на кожа 5',
    '👩🏽‍🐰‍👩🏿' => 'жени кои се забавуваат: тип на кожа 4 и тип на кожа 6',
    '👩🏾‍🐰‍👩🏻' => 'жени кои се забавуваат: тип на кожа 5 и тип на кожа 1–2',
    '👩🏾‍🐰‍👩🏼' => 'жени кои се забавуваат: тип на кожа 5 и тип на кожа 3',
    '👩🏾‍🐰‍👩🏽' => 'жени кои се забавуваат: тип на кожа 5 и тип на кожа 4',
    '👩🏾‍🐰‍👩🏿' => 'жени кои се забавуваат: тип на кожа 5 и тип на кожа 6',
    '👩🏿‍🐰‍👩🏻' => 'жени кои се забавуваат: тип на кожа 6 и тип на кожа 1–2',
    '👩🏿‍🐰‍👩🏼' => 'жени кои се забавуваат: тип на кожа 6 и тип на кожа 3',
    '👩🏿‍🐰‍👩🏽' => 'жени кои се забавуваат: тип на кожа 6 и тип на кожа 4',
    '👩🏿‍🐰‍👩🏾' => 'жени кои се забавуваат: тип на кожа 6 и тип на кожа 5',
    '🧑🏻‍🤝‍🧑🏻' => 'луѓе се држат за раце: тип на кожа 1–2',
    '🧑🏻‍🤝‍🧑🏼' => 'луѓе се држат за раце: тип на кожа 1–2 и тип на кожа 3',
    '🧑🏻‍🤝‍🧑🏽' => 'луѓе се држат за раце: тип на кожа 1–2 и тип на кожа 4',
    '🧑🏻‍🤝‍🧑🏾' => 'луѓе се држат за раце: тип на кожа 1–2 и тип на кожа 5',
    '🧑🏻‍🤝‍🧑🏿' => 'луѓе се држат за раце: тип на кожа 1–2 и тип на кожа 6',
    '🧑🏼‍🤝‍🧑🏻' => 'луѓе се држат за раце: тип на кожа 3 и тип на кожа 1–2',
    '🧑🏼‍🤝‍🧑🏼' => 'луѓе се држат за раце: тип на кожа 3',
    '🧑🏼‍🤝‍🧑🏽' => 'луѓе се држат за раце: тип на кожа 3 и тип на кожа 4',
    '🧑🏼‍🤝‍🧑🏾' => 'луѓе се држат за раце: тип на кожа 3 и тип на кожа 5',
    '🧑🏼‍🤝‍🧑🏿' => 'луѓе се држат за раце: тип на кожа 3 и тип на кожа 6',
    '🧑🏽‍🤝‍🧑🏻' => 'луѓе се држат за раце: тип на кожа 4 и тип на кожа 1–2',
    '🧑🏽‍🤝‍🧑🏼' => 'луѓе се држат за раце: тип на кожа 4 и тип на кожа 3',
    '🧑🏽‍🤝‍🧑🏽' => 'луѓе се држат за раце: тип на кожа 4',
    '🧑🏽‍🤝‍🧑🏾' => 'луѓе се држат за раце: тип на кожа 4 и тип на кожа 5',
    '🧑🏽‍🤝‍🧑🏿' => 'луѓе се држат за раце: тип на кожа 4 и тип на кожа 6',
    '🧑🏾‍🤝‍🧑🏻' => 'луѓе се држат за раце: тип на кожа 5 и тип на кожа 1–2',
    '🧑🏾‍🤝‍🧑🏼' => 'луѓе се држат за раце: тип на кожа 5 и тип на кожа 3',
    '🧑🏾‍🤝‍🧑🏽' => 'луѓе се држат за раце: тип на кожа 5 и тип на кожа 4',
    '🧑🏾‍🤝‍🧑🏾' => 'луѓе се држат за раце: тип на кожа 5',
    '🧑🏾‍🤝‍🧑🏿' => 'луѓе се држат за раце: тип на кожа 5 и тип на кожа 6',
    '🧑🏿‍🤝‍🧑🏻' => 'луѓе се држат за раце: тип на кожа 6 и тип на кожа 1–2',
    '🧑🏿‍🤝‍🧑🏼' => 'луѓе се држат за раце: тип на кожа 6 и тип на кожа 3',
    '🧑🏿‍🤝‍🧑🏽' => 'луѓе се држат за раце: тип на кожа 6 и тип на кожа 4',
    '🧑🏿‍🤝‍🧑🏾' => 'луѓе се држат за раце: тип на кожа 6 и тип на кожа 5',
    '🧑🏿‍🤝‍🧑🏿' => 'луѓе се држат за раце: тип на кожа 6',
    '👩🏻‍🤝‍👩🏼' => 'две жени се држат за рака: тип на кожа 1–2 и тип на кожа 3',
    '👩🏻‍🤝‍👩🏽' => 'две жени се држат за рака: тип на кожа 1–2 и тип на кожа 4',
    '👩🏻‍🤝‍👩🏾' => 'две жени се држат за рака: тип на кожа 1–2 и тип на кожа 5',
    '👩🏻‍🤝‍👩🏿' => 'две жени се држат за рака: тип на кожа 1–2 и тип на кожа 6',
    '👩🏼‍🤝‍👩🏻' => 'две жени се држат за рака: тип на кожа 3 и тип на кожа 1–2',
    '👩🏼‍🤝‍👩🏽' => 'две жени се држат за рака: тип на кожа 3 и тип на кожа 4',
    '👩🏼‍🤝‍👩🏾' => 'две жени се држат за рака: тип на кожа 3 и тип на кожа 5',
    '👩🏼‍🤝‍👩🏿' => 'две жени се држат за рака: тип на кожа 3 и тип на кожа 6',
    '👩🏽‍🤝‍👩🏻' => 'две жени се држат за рака: тип на кожа 4 и тип на кожа 1–2',
    '👩🏽‍🤝‍👩🏼' => 'две жени се држат за рака: тип на кожа 4 и тип на кожа 3',
    '👩🏽‍🤝‍👩🏾' => 'две жени се држат за рака: тип на кожа 4 и тип на кожа 5',
    '👩🏽‍🤝‍👩🏿' => 'две жени се држат за рака: тип на кожа 4 и тип на кожа 6',
    '👩🏾‍🤝‍👩🏻' => 'две жени се држат за рака: тип на кожа 5 и тип на кожа 1–2',
    '👩🏾‍🤝‍👩🏼' => 'две жени се држат за рака: тип на кожа 5 и тип на кожа 3',
    '👩🏾‍🤝‍👩🏽' => 'две жени се држат за рака: тип на кожа 5 и тип на кожа 4',
    '👩🏾‍🤝‍👩🏿' => 'две жени се држат за рака: тип на кожа 5 и тип на кожа 6',
    '👩🏿‍🤝‍👩🏻' => 'две жени се држат за рака: тип на кожа 6 и тип на кожа 1–2',
    '👩🏿‍🤝‍👩🏼' => 'две жени се држат за рака: тип на кожа 6 и тип на кожа 3',
    '👩🏿‍🤝‍👩🏽' => 'две жени се држат за рака: тип на кожа 6 и тип на кожа 4',
    '👩🏿‍🤝‍👩🏾' => 'две жени се држат за рака: тип на кожа 6 и тип на кожа 5',
    '👩🏻‍🤝‍👨🏼' => 'маж и жена се држат за рака: тип на кожа 1–2 и тип на кожа 3',
    '👩🏻‍🤝‍👨🏽' => 'маж и жена се држат за рака: тип на кожа 1–2 и тип на кожа 4',
    '👩🏻‍🤝‍👨🏾' => 'маж и жена се држат за рака: тип на кожа 1–2 и тип на кожа 5',
    '👩🏻‍🤝‍👨🏿' => 'маж и жена се држат за рака: тип на кожа 1–2 и тип на кожа 6',
    '👩🏼‍🤝‍👨🏻' => 'маж и жена се држат за рака: тип на кожа 3 и тип на кожа 1–2',
    '👩🏼‍🤝‍👨🏽' => 'маж и жена се држат за рака: тип на кожа 3 и тип на кожа 4',
    '👩🏼‍🤝‍👨🏾' => 'маж и жена се држат за рака: тип на кожа 3 и тип на кожа 5',
    '👩🏼‍🤝‍👨🏿' => 'маж и жена се држат за рака: тип на кожа 3 и тип на кожа 6',
    '👩🏽‍🤝‍👨🏻' => 'маж и жена се држат за рака: тип на кожа 4 и тип на кожа 1–2',
    '👩🏽‍🤝‍👨🏼' => 'маж и жена се држат за рака: тип на кожа 4 и тип на кожа 3',
    '👩🏽‍🤝‍👨🏾' => 'маж и жена се држат за рака: тип на кожа 4 и тип на кожа 5',
    '👩🏽‍🤝‍👨🏿' => 'маж и жена се држат за рака: тип на кожа 4 и тип на кожа 6',
    '👩🏾‍🤝‍👨🏻' => 'маж и жена се држат за рака: тип на кожа 5 и тип на кожа 1–2',
    '👩🏾‍🤝‍👨🏼' => 'маж и жена се држат за рака: тип на кожа 5 и тип на кожа 3',
    '👩🏾‍🤝‍👨🏽' => 'маж и жена се држат за рака: тип на кожа 5 и тип на кожа 4',
    '👩🏾‍🤝‍👨🏿' => 'маж и жена се држат за рака: тип на кожа 5 и тип на кожа 6',
    '👩🏿‍🤝‍👨🏻' => 'маж и жена се држат за рака: тип на кожа 6 и тип на кожа 1–2',
    '👩🏿‍🤝‍👨🏼' => 'маж и жена се држат за рака: тип на кожа 6 и тип на кожа 3',
    '👩🏿‍🤝‍👨🏽' => 'маж и жена се држат за рака: тип на кожа 6 и тип на кожа 4',
    '👩🏿‍🤝‍👨🏾' => 'маж и жена се држат за рака: тип на кожа 6 и тип на кожа 5',
    '👨🏻‍🤝‍👨🏼' => 'двајца мажи се држат за рака: тип на кожа 1–2 и тип на кожа 3',
    '👨🏻‍🤝‍👨🏽' => 'двајца мажи се држат за рака: тип на кожа 1–2 и тип на кожа 4',
    '👨🏻‍🤝‍👨🏾' => 'двајца мажи се држат за рака: тип на кожа 1–2 и тип на кожа 5',
    '👨🏻‍🤝‍👨🏿' => 'двајца мажи се држат за рака: тип на кожа 1–2 и тип на кожа 6',
    '👨🏼‍🤝‍👨🏻' => 'двајца мажи се држат за рака: тип на кожа 3 и тип на кожа 1–2',
    '👨🏼‍🤝‍👨🏽' => 'двајца мажи се држат за рака: тип на кожа 3 и тип на кожа 4',
    '👨🏼‍🤝‍👨🏾' => 'двајца мажи се држат за рака: тип на кожа 3 и тип на кожа 5',
    '👨🏼‍🤝‍👨🏿' => 'двајца мажи се држат за рака: тип на кожа 3 и тип на кожа 6',
    '👨🏽‍🤝‍👨🏻' => 'двајца мажи се држат за рака: тип на кожа 4 и тип на кожа 1–2',
    '👨🏽‍🤝‍👨🏼' => 'двајца мажи се држат за рака: тип на кожа 4 и тип на кожа 3',
    '👨🏽‍🤝‍👨🏾' => 'двајца мажи се држат за рака: тип на кожа 4 и тип на кожа 5',
    '👨🏽‍🤝‍👨🏿' => 'двајца мажи се држат за рака: тип на кожа 4 и тип на кожа 6',
    '👨🏾‍🤝‍👨🏻' => 'двајца мажи се држат за рака: тип на кожа 5 и тип на кожа 1–2',
    '👨🏾‍🤝‍👨🏼' => 'двајца мажи се држат за рака: тип на кожа 5 и тип на кожа 3',
    '👨🏾‍🤝‍👨🏽' => 'двајца мажи се држат за рака: тип на кожа 5 и тип на кожа 4',
    '👨🏾‍🤝‍👨🏿' => 'двајца мажи се држат за рака: тип на кожа 5 и тип на кожа 6',
    '👨🏿‍🤝‍👨🏻' => 'двајца мажи се држат за рака: тип на кожа 6 и тип на кожа 1–2',
    '👨🏿‍🤝‍👨🏼' => 'двајца мажи се држат за рака: тип на кожа 6 и тип на кожа 3',
    '👨🏿‍🤝‍👨🏽' => 'двајца мажи се држат за рака: тип на кожа 6 и тип на кожа 4',
    '👨🏿‍🤝‍👨🏾' => 'двајца мажи се држат за рака: тип на кожа 6 и тип на кожа 5',
    '👩‍❤‍💋‍👨' => 'бакнеж: жена и маж',
    '👨‍❤‍💋‍👨' => 'бакнеж: маж и маж',
    '👩‍❤‍💋‍👩' => 'бакнеж: жена и жена',
    '👨‍👩‍👧‍👦' => 'семејство: маж, жена, девојче и момче',
    '👨‍👩‍👦‍👦' => 'семејство: маж, жена, момче и момче',
    '👨‍👩‍👧‍👧' => 'семејство: маж, жена, девојче и девојче',
    '👨‍👨‍👧‍👦' => 'семејство: маж, маж, девојче и момче',
    '👨‍👨‍👦‍👦' => 'семејство: маж, маж, момче и момче',
    '👨‍👨‍👧‍👧' => 'семејство: маж, маж, девојче и девојче',
    '👩‍👩‍👧‍👦' => 'семејство: жена, жена, девојче и момче',
    '👩‍👩‍👦‍👦' => 'семејство: жена, жена, момче и момче',
    '👩‍👩‍👧‍👧' => 'семејство: жена, жена, девојче и девојче',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'знаме: Англија',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'знаме: Шкотска',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'знаме: Велс',
    '🧑‍🧑‍🧒‍🧒' => 'семејство: возрасен, возрасно лице, дете, дете',
    '🚶🏻‍♀‍➡' => 'жена пешачи: тип на кожа 1–2 и кон десно',
    '🚶🏼‍♀‍➡' => 'жена пешачи: тип на кожа 3 и кон десно',
    '🚶🏽‍♀‍➡' => 'жена пешачи: тип на кожа 4 и кон десно',
    '🚶🏾‍♀‍➡' => 'жена пешачи: тип на кожа 5 и кон десно',
    '🚶🏿‍♀‍➡' => 'жена пешачи: тип на кожа 6 и кон десно',
    '🚶🏻‍♂‍➡' => 'маж пешачи: тип на кожа 1–2 и кон десно',
    '🚶🏼‍♂‍➡' => 'маж пешачи: тип на кожа 3 и кон десно',
    '🚶🏽‍♂‍➡' => 'маж пешачи: тип на кожа 4 и кон десно',
    '🚶🏾‍♂‍➡' => 'маж пешачи: тип на кожа 5 и кон десно',
    '🚶🏿‍♂‍➡' => 'маж пешачи: тип на кожа 6 и кон десно',
    '🧎🏻‍♀‍➡' => 'жена која клечи: тип на кожа 1–2 и кон десно',
    '🧎🏼‍♀‍➡' => 'жена која клечи: тип на кожа 3 и кон десно',
    '🧎🏽‍♀‍➡' => 'жена која клечи: тип на кожа 4 и кон десно',
    '🧎🏾‍♀‍➡' => 'жена која клечи: тип на кожа 5 и кон десно',
    '🧎🏿‍♀‍➡' => 'жена која клечи: тип на кожа 6 и кон десно',
    '🧎🏻‍♂‍➡' => 'маж кој клечи: тип на кожа 1–2 и кон десно',
    '🧎🏼‍♂‍➡' => 'маж кој клечи: тип на кожа 3 и кон десно',
    '🧎🏽‍♂‍➡' => 'маж кој клечи: тип на кожа 4 и кон десно',
    '🧎🏾‍♂‍➡' => 'маж кој клечи: тип на кожа 5 и кон десно',
    '🧎🏿‍♂‍➡' => 'маж кој клечи: тип на кожа 6 и кон десно',
    '🧑🏻‍🦯‍➡' => 'лице со стап за слепи: тип на кожа 1–2 и кон десно',
    '🧑🏼‍🦯‍➡' => 'лице со стап за слепи: тип на кожа 3 и кон десно',
    '🧑🏽‍🦯‍➡' => 'лице со стап за слепи: тип на кожа 4 и кон десно',
    '🧑🏾‍🦯‍➡' => 'лице со стап за слепи: тип на кожа 5 и кон десно',
    '🧑🏿‍🦯‍➡' => 'лице со стап за слепи: тип на кожа 6 и кон десно',
    '👨🏻‍🦯‍➡' => 'маж со стап за слепи: тип на кожа 1–2 и кон десно',
    '👨🏼‍🦯‍➡' => 'маж со стап за слепи: тип на кожа 3 и кон десно',
    '👨🏽‍🦯‍➡' => 'маж со стап за слепи: тип на кожа 4 и кон десно',
    '👨🏾‍🦯‍➡' => 'маж со стап за слепи: тип на кожа 5 и кон десно',
    '👨🏿‍🦯‍➡' => 'маж со стап за слепи: тип на кожа 6 и кон десно',
    '👩🏻‍🦯‍➡' => 'жена со стап за слепи: тип на кожа 1–2 и кон десно',
    '👩🏼‍🦯‍➡' => 'жена со стап за слепи: тип на кожа 3 и кон десно',
    '👩🏽‍🦯‍➡' => 'жена со стап за слепи: тип на кожа 4 и кон десно',
    '👩🏾‍🦯‍➡' => 'жена со стап за слепи: тип на кожа 5 и кон десно',
    '👩🏿‍🦯‍➡' => 'жена со стап за слепи: тип на кожа 6 и кон десно',
    '🧑🏻‍🦼‍➡' => 'лице во моторизирана количка: тип на кожа 1–2 и кон десно',
    '🧑🏼‍🦼‍➡' => 'лице во моторизирана количка: тип на кожа 3 и кон десно',
    '🧑🏽‍🦼‍➡' => 'лице во моторизирана количка: тип на кожа 4 и кон десно',
    '🧑🏾‍🦼‍➡' => 'лице во моторизирана количка: тип на кожа 5 и кон десно',
    '🧑🏿‍🦼‍➡' => 'лице во моторизирана количка: тип на кожа 6 и кон десно',
    '👨🏻‍🦼‍➡' => 'маж во моторизирана количка: тип на кожа 1–2 и кон десно',
    '👨🏼‍🦼‍➡' => 'маж во моторизирана количка: тип на кожа 3 и кон десно',
    '👨🏽‍🦼‍➡' => 'маж во моторизирана количка: тип на кожа 4 и кон десно',
    '👨🏾‍🦼‍➡' => 'маж во моторизирана количка: тип на кожа 5 и кон десно',
    '👨🏿‍🦼‍➡' => 'маж во моторизирана количка: тип на кожа 6 и кон десно',
    '👩🏻‍🦼‍➡' => 'жена во моторизирана количка: тип на кожа 1–2 и кон десно',
    '👩🏼‍🦼‍➡' => 'жена во моторизирана количка: тип на кожа 3 и кон десно',
    '👩🏽‍🦼‍➡' => 'жена во моторизирана количка: тип на кожа 4 и кон десно',
    '👩🏾‍🦼‍➡' => 'жена во моторизирана количка: тип на кожа 5 и кон десно',
    '👩🏿‍🦼‍➡' => 'жена во моторизирана количка: тип на кожа 6 и кон десно',
    '🧑🏻‍🦽‍➡' => 'лице во рачна инвалидска количка: тип на кожа 1–2 и кон десно',
    '🧑🏼‍🦽‍➡' => 'лице во рачна инвалидска количка: тип на кожа 3 и кон десно',
    '🧑🏽‍🦽‍➡' => 'лице во рачна инвалидска количка: тип на кожа 4 и кон десно',
    '🧑🏾‍🦽‍➡' => 'лице во рачна инвалидска количка: тип на кожа 5 и кон десно',
    '🧑🏿‍🦽‍➡' => 'лице во рачна инвалидска количка: тип на кожа 6 и кон десно',
    '👨🏻‍🦽‍➡' => 'маж во рачна инвалидска количка: тип на кожа 1–2 и кон десно',
    '👨🏼‍🦽‍➡' => 'маж во рачна инвалидска количка: тип на кожа 3 и кон десно',
    '👨🏽‍🦽‍➡' => 'маж во рачна инвалидска количка: тип на кожа 4 и кон десно',
    '👨🏾‍🦽‍➡' => 'маж во рачна инвалидска количка: тип на кожа 5 и кон десно',
    '👨🏿‍🦽‍➡' => 'маж во рачна инвалидска количка: тип на кожа 6 и кон десно',
    '👩🏻‍🦽‍➡' => 'жена во рачна инвалидска количка: тип на кожа 1–2 и кон десно',
    '👩🏼‍🦽‍➡' => 'жена во рачна инвалидска количка: тип на кожа 3 и кон десно',
    '👩🏽‍🦽‍➡' => 'жена во рачна инвалидска количка: тип на кожа 4 и кон десно',
    '👩🏾‍🦽‍➡' => 'жена во рачна инвалидска количка: тип на кожа 5 и кон десно',
    '👩🏿‍🦽‍➡' => 'жена во рачна инвалидска количка: тип на кожа 6 и кон десно',
    '🏃🏻‍♀‍➡' => 'жена трча: тип на кожа 1–2 и кон десно',
    '🏃🏼‍♀‍➡' => 'жена трча: тип на кожа 3 и кон десно',
    '🏃🏽‍♀‍➡' => 'жена трча: тип на кожа 4 и кон десно',
    '🏃🏾‍♀‍➡' => 'жена трча: тип на кожа 5 и кон десно',
    '🏃🏿‍♀‍➡' => 'жена трча: тип на кожа 6 и кон десно',
    '🏃🏻‍♂‍➡' => 'маж трча: тип на кожа 1–2 и кон десно',
    '🏃🏼‍♂‍➡' => 'маж трча: тип на кожа 3 и кон десно',
    '🏃🏽‍♂‍➡' => 'маж трча: тип на кожа 4 и кон десно',
    '🏃🏾‍♂‍➡' => 'маж трча: тип на кожа 5 и кон десно',
    '🏃🏿‍♂‍➡' => 'маж трча: тип на кожа 6 и кон десно',
    '🫱🏻‍🫲🏼' => 'ракување: тип на кожа 1–2 и тип на кожа 3',
    '🫱🏻‍🫲🏽' => 'ракување: тип на кожа 1–2 и тип на кожа 4',
    '🫱🏻‍🫲🏾' => 'ракување: тип на кожа 1–2 и тип на кожа 5',
    '🫱🏻‍🫲🏿' => 'ракување: тип на кожа 1–2 и тип на кожа 6',
    '🫱🏼‍🫲🏻' => 'ракување: тип на кожа 3 и тип на кожа 1–2',
    '🫱🏼‍🫲🏽' => 'ракување: тип на кожа 3 и тип на кожа 4',
    '🫱🏼‍🫲🏾' => 'ракување: тип на кожа 3 и тип на кожа 5',
    '🫱🏼‍🫲🏿' => 'ракување: тип на кожа 3 и тип на кожа 6',
    '🫱🏽‍🫲🏻' => 'ракување: тип на кожа 4 и тип на кожа 1–2',
    '🫱🏽‍🫲🏼' => 'ракување: тип на кожа 4 и тип на кожа 3',
    '🫱🏽‍🫲🏾' => 'ракување: тип на кожа 4 и тип на кожа 5',
    '🫱🏽‍🫲🏿' => 'ракување: тип на кожа 4 и тип на кожа 6',
    '🫱🏾‍🫲🏻' => 'ракување: тип на кожа 5 и тип на кожа 1–2',
    '🫱🏾‍🫲🏼' => 'ракување: тип на кожа 5 и тип на кожа 3',
    '🫱🏾‍🫲🏽' => 'ракување: тип на кожа 5 и тип на кожа 4',
    '🫱🏾‍🫲🏿' => 'ракување: тип на кожа 5 и тип на кожа 6',
    '🫱🏿‍🫲🏻' => 'ракување: тип на кожа 6 и тип на кожа 1–2',
    '🫱🏿‍🫲🏼' => 'ракување: тип на кожа 6 и тип на кожа 3',
    '🫱🏿‍🫲🏽' => 'ракување: тип на кожа 6 и тип на кожа 4',
    '🫱🏿‍🫲🏾' => 'ракување: тип на кожа 6 и тип на кожа 5',
    '🚶‍♀‍➡' => 'жена пешачи: кон десно',
    '🚶‍♂‍➡' => 'маж пешачи: кон десно',
    '🧎‍♀‍➡' => 'жена која клечи: кон десно',
    '🧎‍♂‍➡' => 'маж кој клечи: кон десно',
    '🧑‍🦯‍➡' => 'лице со стап за слепи: кон десно',
    '👨‍🦯‍➡' => 'маж со стап за слепи: кон десно',
    '👩‍🦯‍➡' => 'жена со стап за слепи: кон десно',
    '🧑‍🦼‍➡' => 'лице во моторизирана количка: кон десно',
    '👨‍🦼‍➡' => 'маж во моторизирана количка: кон десно',
    '👩‍🦼‍➡' => 'жена во моторизирана количка: кон десно',
    '🧑‍🦽‍➡' => 'лице во рачна инвалидска количка: кон десно',
    '👨‍🦽‍➡' => 'маж во рачна инвалидска количка: кон десно',
    '👩‍🦽‍➡' => 'жена во рачна инвалидска количка: кон десно',
    '🏃‍♀‍➡' => 'жена трча: кон десно',
    '🏃‍♂‍➡' => 'маж трча: кон десно',
    '👩‍❤‍👨' => 'пар со срце: жена и маж',
    '👨‍❤‍👨' => 'пар со срце: маж и маж',
    '👩‍❤‍👩' => 'пар со срце: жена и жена',
    '👨‍👩‍👦' => 'семејство: маж, жена и момче',
    '👨‍👩‍👧' => 'семејство: маж, жена и девојче',
    '👨‍👨‍👦' => 'семејство: маж, маж и момче',
    '👨‍👨‍👧' => 'семејство: маж, маж и девојче',
    '👩‍👩‍👦' => 'семејство: жена, жена и момче',
    '👩‍👩‍👧' => 'семејство: жена, жена и девојче',
    '👨‍👦‍👦' => 'семејство: маж, момче и момче',
    '👨‍👧‍👦' => 'семејство: маж, девојче и момче',
    '👨‍👧‍👧' => 'семејство: маж, девојче и девојче',
    '👩‍👦‍👦' => 'семејство: жена, момче и момче',
    '👩‍👧‍👦' => 'семејство: жена, девојче и момче',
    '👩‍👧‍👧' => 'семејство: жена, девојче и девојче',
    '🧑‍🤝‍🧑' => 'луѓе се држат за раце',
    '🧑‍🧑‍🧒' => 'семејство: возрасен, возрасно лице, дете',
    '🧑‍🧒‍🧒' => 'семејство: возрасно лице, дете, дете',
    '🧑🏻‍🦰' => 'возрасно лице: тип на кожа 1–2 и црвена коса',
    '🧑🏼‍🦰' => 'возрасно лице: тип на кожа 3 и црвена коса',
    '🧑🏽‍🦰' => 'возрасно лице: тип на кожа 4 и црвена коса',
    '🧑🏾‍🦰' => 'возрасно лице: тип на кожа 5 и црвена коса',
    '🧑🏿‍🦰' => 'возрасно лице: тип на кожа 6 и црвена коса',
    '🧑🏻‍🦱' => 'возрасно лице: тип на кожа 1–2 и кадрава коса',
    '🧑🏼‍🦱' => 'возрасно лице: тип на кожа 3 и кадрава коса',
    '🧑🏽‍🦱' => 'возрасно лице: тип на кожа 4 и кадрава коса',
    '🧑🏾‍🦱' => 'возрасно лице: тип на кожа 5 и кадрава коса',
    '🧑🏿‍🦱' => 'возрасно лице: тип на кожа 6 и кадрава коса',
    '🧑🏻‍🦳' => 'возрасно лице: тип на кожа 1–2 и бела коса',
    '🧑🏼‍🦳' => 'возрасно лице: тип на кожа 3 и бела коса',
    '🧑🏽‍🦳' => 'возрасно лице: тип на кожа 4 и бела коса',
    '🧑🏾‍🦳' => 'возрасно лице: тип на кожа 5 и бела коса',
    '🧑🏿‍🦳' => 'возрасно лице: тип на кожа 6 и бела коса',
    '🧑🏻‍🦲' => 'возрасно лице: тип на кожа 1–2 и ќелав',
    '🧑🏼‍🦲' => 'возрасно лице: тип на кожа 3 и ќелав',
    '🧑🏽‍🦲' => 'возрасно лице: тип на кожа 4 и ќелав',
    '🧑🏾‍🦲' => 'возрасно лице: тип на кожа 5 и ќелав',
    '🧑🏿‍🦲' => 'возрасно лице: тип на кожа 6 и ќелав',
    '🧑🏻‍🩰' => 'балерина: тип на кожа 1–2',
    '🧑🏼‍🩰' => 'балерина: тип на кожа 3',
    '🧑🏽‍🩰' => 'балерина: тип на кожа 4',
    '🧑🏾‍🩰' => 'балерина: тип на кожа 5',
    '🧑🏿‍🩰' => 'балерина: тип на кожа 6',
    '🧔🏻‍♂' => 'маж: тип на кожа 1–2 и брада',
    '🧔🏼‍♂' => 'маж: тип на кожа 3 и брада',
    '🧔🏽‍♂' => 'маж: тип на кожа 4 и брада',
    '🧔🏾‍♂' => 'маж: тип на кожа 5 и брада',
    '🧔🏿‍♂' => 'маж: тип на кожа 6 и брада',
    '👱🏻‍♂' => 'русокос маж: тип на кожа 1–2',
    '👱🏼‍♂' => 'русокос маж: тип на кожа 3',
    '👱🏽‍♂' => 'русокос маж: тип на кожа 4',
    '👱🏾‍♂' => 'русокос маж: тип на кожа 5',
    '👱🏿‍♂' => 'русокос маж: тип на кожа 6',
    '👨🏻‍🦰' => 'маж: тип на кожа 1–2 и црвена коса',
    '👨🏼‍🦰' => 'маж: тип на кожа 3 и црвена коса',
    '👨🏽‍🦰' => 'маж: тип на кожа 4 и црвена коса',
    '👨🏾‍🦰' => 'маж: тип на кожа 5 и црвена коса',
    '👨🏿‍🦰' => 'маж: тип на кожа 6 и црвена коса',
    '👨🏻‍🦱' => 'маж: тип на кожа 1–2 и кадрава коса',
    '👨🏼‍🦱' => 'маж: тип на кожа 3 и кадрава коса',
    '👨🏽‍🦱' => 'маж: тип на кожа 4 и кадрава коса',
    '👨🏾‍🦱' => 'маж: тип на кожа 5 и кадрава коса',
    '👨🏿‍🦱' => 'маж: тип на кожа 6 и кадрава коса',
    '👨🏻‍🦳' => 'маж: тип на кожа 1–2 и бела коса',
    '👨🏼‍🦳' => 'маж: тип на кожа 3 и бела коса',
    '👨🏽‍🦳' => 'маж: тип на кожа 4 и бела коса',
    '👨🏾‍🦳' => 'маж: тип на кожа 5 и бела коса',
    '👨🏿‍🦳' => 'маж: тип на кожа 6 и бела коса',
    '👨🏻‍🦲' => 'маж: тип на кожа 1–2 и ќелав',
    '👨🏼‍🦲' => 'маж: тип на кожа 3 и ќелав',
    '👨🏽‍🦲' => 'маж: тип на кожа 4 и ќелав',
    '👨🏾‍🦲' => 'маж: тип на кожа 5 и ќелав',
    '👨🏿‍🦲' => 'маж: тип на кожа 6 и ќелав',
    '🧔🏻‍♀' => 'жена: тип на кожа 1–2 и брада',
    '🧔🏼‍♀' => 'жена: тип на кожа 3 и брада',
    '🧔🏽‍♀' => 'жена: тип на кожа 4 и брада',
    '🧔🏾‍♀' => 'жена: тип на кожа 5 и брада',
    '🧔🏿‍♀' => 'жена: тип на кожа 6 и брада',
    '👱🏻‍♀' => 'русокоса жена: тип на кожа 1–2',
    '👱🏼‍♀' => 'русокоса жена: тип на кожа 3',
    '👱🏽‍♀' => 'русокоса жена: тип на кожа 4',
    '👱🏾‍♀' => 'русокоса жена: тип на кожа 5',
    '👱🏿‍♀' => 'русокоса жена: тип на кожа 6',
    '👩🏻‍🦰' => 'жена: тип на кожа 1–2 и црвена коса',
    '👩🏼‍🦰' => 'жена: тип на кожа 3 и црвена коса',
    '👩🏽‍🦰' => 'жена: тип на кожа 4 и црвена коса',
    '👩🏾‍🦰' => 'жена: тип на кожа 5 и црвена коса',
    '👩🏿‍🦰' => 'жена: тип на кожа 6 и црвена коса',
    '👩🏻‍🦱' => 'жена: тип на кожа 1–2 и кадрава коса',
    '👩🏼‍🦱' => 'жена: тип на кожа 3 и кадрава коса',
    '👩🏽‍🦱' => 'жена: тип на кожа 4 и кадрава коса',
    '👩🏾‍🦱' => 'жена: тип на кожа 5 и кадрава коса',
    '👩🏿‍🦱' => 'жена: тип на кожа 6 и кадрава коса',
    '👩🏻‍🦳' => 'жена: тип на кожа 1–2 и бела коса',
    '👩🏼‍🦳' => 'жена: тип на кожа 3 и бела коса',
    '👩🏽‍🦳' => 'жена: тип на кожа 4 и бела коса',
    '👩🏾‍🦳' => 'жена: тип на кожа 5 и бела коса',
    '👩🏿‍🦳' => 'жена: тип на кожа 6 и бела коса',
    '👩🏻‍🦲' => 'жена: тип на кожа 1–2 и ќелав',
    '👩🏼‍🦲' => 'жена: тип на кожа 3 и ќелав',
    '👩🏽‍🦲' => 'жена: тип на кожа 4 и ќелав',
    '👩🏾‍🦲' => 'жена: тип на кожа 5 и ќелав',
    '👩🏿‍🦲' => 'жена: тип на кожа 6 и ќелав',
    '🙍🏻‍♂' => 'намуртен маж: тип на кожа 1–2',
    '🙍🏼‍♂' => 'намуртен маж: тип на кожа 3',
    '🙍🏽‍♂' => 'намуртен маж: тип на кожа 4',
    '🙍🏾‍♂' => 'намуртен маж: тип на кожа 5',
    '🙍🏿‍♂' => 'намуртен маж: тип на кожа 6',
    '🙍🏻‍♀' => 'намуртена жена: тип на кожа 1–2',
    '🙍🏼‍♀' => 'намуртена жена: тип на кожа 3',
    '🙍🏽‍♀' => 'намуртена жена: тип на кожа 4',
    '🙍🏾‍♀' => 'намуртена жена: тип на кожа 5',
    '🙍🏿‍♀' => 'намуртена жена: тип на кожа 6',
    '🙎🏻‍♂' => 'налутен маж: тип на кожа 1–2',
    '🙎🏼‍♂' => 'налутен маж: тип на кожа 3',
    '🙎🏽‍♂' => 'налутен маж: тип на кожа 4',
    '🙎🏾‍♂' => 'налутен маж: тип на кожа 5',
    '🙎🏿‍♂' => 'налутен маж: тип на кожа 6',
    '🙎🏻‍♀' => 'налутена жена: тип на кожа 1–2',
    '🙎🏼‍♀' => 'налутена жена: тип на кожа 3',
    '🙎🏽‍♀' => 'налутена жена: тип на кожа 4',
    '🙎🏾‍♀' => 'налутена жена: тип на кожа 5',
    '🙎🏿‍♀' => 'налутена жена: тип на кожа 6',
    '🙅🏻‍♂' => 'маж што неодобрува: тип на кожа 1–2',
    '🙅🏼‍♂' => 'маж што неодобрува: тип на кожа 3',
    '🙅🏽‍♂' => 'маж што неодобрува: тип на кожа 4',
    '🙅🏾‍♂' => 'маж што неодобрува: тип на кожа 5',
    '🙅🏿‍♂' => 'маж што неодобрува: тип на кожа 6',
    '🙅🏻‍♀' => 'жена што неодобрува: тип на кожа 1–2',
    '🙅🏼‍♀' => 'жена што неодобрува: тип на кожа 3',
    '🙅🏽‍♀' => 'жена што неодобрува: тип на кожа 4',
    '🙅🏾‍♀' => 'жена што неодобрува: тип на кожа 5',
    '🙅🏿‍♀' => 'жена што неодобрува: тип на кожа 6',
    '🙆🏻‍♂' => 'маж што одобрува: тип на кожа 1–2',
    '🙆🏼‍♂' => 'маж што одобрува: тип на кожа 3',
    '🙆🏽‍♂' => 'маж што одобрува: тип на кожа 4',
    '🙆🏾‍♂' => 'маж што одобрува: тип на кожа 5',
    '🙆🏿‍♂' => 'маж што одобрува: тип на кожа 6',
    '🙆🏻‍♀' => 'жена што одобрува: тип на кожа 1–2',
    '🙆🏼‍♀' => 'жена што одобрува: тип на кожа 3',
    '🙆🏽‍♀' => 'жена што одобрува: тип на кожа 4',
    '🙆🏾‍♀' => 'жена што одобрува: тип на кожа 5',
    '🙆🏿‍♀' => 'жена што одобрува: тип на кожа 6',
    '💁🏻‍♂' => 'феминизиран маж: тип на кожа 1–2',
    '💁🏼‍♂' => 'феминизиран маж: тип на кожа 3',
    '💁🏽‍♂' => 'феминизиран маж: тип на кожа 4',
    '💁🏾‍♂' => 'феминизиран маж: тип на кожа 5',
    '💁🏿‍♂' => 'феминизиран маж: тип на кожа 6',
    '💁🏻‍♀' => 'шмизла: тип на кожа 1–2',
    '💁🏼‍♀' => 'шмизла: тип на кожа 3',
    '💁🏽‍♀' => 'шмизла: тип на кожа 4',
    '💁🏾‍♀' => 'шмизла: тип на кожа 5',
    '💁🏿‍♀' => 'шмизла: тип на кожа 6',
    '🙋🏻‍♂' => 'маж со подигната рака: тип на кожа 1–2',
    '🙋🏼‍♂' => 'маж со подигната рака: тип на кожа 3',
    '🙋🏽‍♂' => 'маж со подигната рака: тип на кожа 4',
    '🙋🏾‍♂' => 'маж со подигната рака: тип на кожа 5',
    '🙋🏿‍♂' => 'маж со подигната рака: тип на кожа 6',
    '🙋🏻‍♀' => 'жена со подигната рака: тип на кожа 1–2',
    '🙋🏼‍♀' => 'жена со подигната рака: тип на кожа 3',
    '🙋🏽‍♀' => 'жена со подигната рака: тип на кожа 4',
    '🙋🏾‍♀' => 'жена со подигната рака: тип на кожа 5',
    '🙋🏿‍♀' => 'жена со подигната рака: тип на кожа 6',
    '🧏🏻‍♂' => 'глув маж: тип на кожа 1–2',
    '🧏🏼‍♂' => 'глув маж: тип на кожа 3',
    '🧏🏽‍♂' => 'глув маж: тип на кожа 4',
    '🧏🏾‍♂' => 'глув маж: тип на кожа 5',
    '🧏🏿‍♂' => 'глув маж: тип на кожа 6',
    '🧏🏻‍♀' => 'глува жена: тип на кожа 1–2',
    '🧏🏼‍♀' => 'глува жена: тип на кожа 3',
    '🧏🏽‍♀' => 'глува жена: тип на кожа 4',
    '🧏🏾‍♀' => 'глува жена: тип на кожа 5',
    '🧏🏿‍♀' => 'глува жена: тип на кожа 6',
    '🙇🏻‍♂' => 'маж се поклонува: тип на кожа 1–2',
    '🙇🏼‍♂' => 'маж се поклонува: тип на кожа 3',
    '🙇🏽‍♂' => 'маж се поклонува: тип на кожа 4',
    '🙇🏾‍♂' => 'маж се поклонува: тип на кожа 5',
    '🙇🏿‍♂' => 'маж се поклонува: тип на кожа 6',
    '🙇🏻‍♀' => 'жена се поклонува: тип на кожа 1–2',
    '🙇🏼‍♀' => 'жена се поклонува: тип на кожа 3',
    '🙇🏽‍♀' => 'жена се поклонува: тип на кожа 4',
    '🙇🏾‍♀' => 'жена се поклонува: тип на кожа 5',
    '🙇🏿‍♀' => 'жена се поклонува: тип на кожа 6',
    '🤦🏻‍♂' => 'маж и неверување: тип на кожа 1–2',
    '🤦🏼‍♂' => 'маж и неверување: тип на кожа 3',
    '🤦🏽‍♂' => 'маж и неверување: тип на кожа 4',
    '🤦🏾‍♂' => 'маж и неверување: тип на кожа 5',
    '🤦🏿‍♂' => 'маж и неверување: тип на кожа 6',
    '🤦🏻‍♀' => 'жена и неверување: тип на кожа 1–2',
    '🤦🏼‍♀' => 'жена и неверување: тип на кожа 3',
    '🤦🏽‍♀' => 'жена и неверување: тип на кожа 4',
    '🤦🏾‍♀' => 'жена и неверување: тип на кожа 5',
    '🤦🏿‍♀' => 'жена и неверување: тип на кожа 6',
    '🤷🏻‍♂' => 'маж и кревање раменици: тип на кожа 1–2',
    '🤷🏼‍♂' => 'маж и кревање раменици: тип на кожа 3',
    '🤷🏽‍♂' => 'маж и кревање раменици: тип на кожа 4',
    '🤷🏾‍♂' => 'маж и кревање раменици: тип на кожа 5',
    '🤷🏿‍♂' => 'маж и кревање раменици: тип на кожа 6',
    '🤷🏻‍♀' => 'жена и кревање раменици: тип на кожа 1–2',
    '🤷🏼‍♀' => 'жена и кревање раменици: тип на кожа 3',
    '🤷🏽‍♀' => 'жена и кревање раменици: тип на кожа 4',
    '🤷🏾‍♀' => 'жена и кревање раменици: тип на кожа 5',
    '🤷🏿‍♀' => 'жена и кревање раменици: тип на кожа 6',
    '🧑🏻‍⚕' => 'здравствен работник: тип на кожа 1–2',
    '🧑🏼‍⚕' => 'здравствен работник: тип на кожа 3',
    '🧑🏽‍⚕' => 'здравствен работник: тип на кожа 4',
    '🧑🏾‍⚕' => 'здравствен работник: тип на кожа 5',
    '🧑🏿‍⚕' => 'здравствен работник: тип на кожа 6',
    '👨🏻‍⚕' => 'доктор: тип на кожа 1–2',
    '👨🏼‍⚕' => 'доктор: тип на кожа 3',
    '👨🏽‍⚕' => 'доктор: тип на кожа 4',
    '👨🏾‍⚕' => 'доктор: тип на кожа 5',
    '👨🏿‍⚕' => 'доктор: тип на кожа 6',
    '👩🏻‍⚕' => 'докторка: тип на кожа 1–2',
    '👩🏼‍⚕' => 'докторка: тип на кожа 3',
    '👩🏽‍⚕' => 'докторка: тип на кожа 4',
    '👩🏾‍⚕' => 'докторка: тип на кожа 5',
    '👩🏿‍⚕' => 'докторка: тип на кожа 6',
    '🧑🏻‍🎓' => 'студент: тип на кожа 1–2',
    '🧑🏼‍🎓' => 'студент: тип на кожа 3',
    '🧑🏽‍🎓' => 'студент: тип на кожа 4',
    '🧑🏾‍🎓' => 'студент: тип на кожа 5',
    '🧑🏿‍🎓' => 'студент: тип на кожа 6',
    '👨🏻‍🎓' => 'маж студент: тип на кожа 1–2',
    '👨🏼‍🎓' => 'маж студент: тип на кожа 3',
    '👨🏽‍🎓' => 'маж студент: тип на кожа 4',
    '👨🏾‍🎓' => 'маж студент: тип на кожа 5',
    '👨🏿‍🎓' => 'маж студент: тип на кожа 6',
    '👩🏻‍🎓' => 'студентка: тип на кожа 1–2',
    '👩🏼‍🎓' => 'студентка: тип на кожа 3',
    '👩🏽‍🎓' => 'студентка: тип на кожа 4',
    '👩🏾‍🎓' => 'студентка: тип на кожа 5',
    '👩🏿‍🎓' => 'студентка: тип на кожа 6',
    '🧑🏻‍🏫' => 'учител: тип на кожа 1–2',
    '🧑🏼‍🏫' => 'учител: тип на кожа 3',
    '🧑🏽‍🏫' => 'учител: тип на кожа 4',
    '🧑🏾‍🏫' => 'учител: тип на кожа 5',
    '🧑🏿‍🏫' => 'учител: тип на кожа 6',
    '👨🏻‍🏫' => 'маж учител: тип на кожа 1–2',
    '👨🏼‍🏫' => 'маж учител: тип на кожа 3',
    '👨🏽‍🏫' => 'маж учител: тип на кожа 4',
    '👨🏾‍🏫' => 'маж учител: тип на кожа 5',
    '👨🏿‍🏫' => 'маж учител: тип на кожа 6',
    '👩🏻‍🏫' => 'учителка: тип на кожа 1–2',
    '👩🏼‍🏫' => 'учителка: тип на кожа 3',
    '👩🏽‍🏫' => 'учителка: тип на кожа 4',
    '👩🏾‍🏫' => 'учителка: тип на кожа 5',
    '👩🏿‍🏫' => 'учителка: тип на кожа 6',
    '🧑🏻‍⚖' => 'судија: тип на кожа 1–2',
    '🧑🏼‍⚖' => 'судија: тип на кожа 3',
    '🧑🏽‍⚖' => 'судија: тип на кожа 4',
    '🧑🏾‍⚖' => 'судија: тип на кожа 5',
    '🧑🏿‍⚖' => 'судија: тип на кожа 6',
    '👨🏻‍⚖' => 'маж судија: тип на кожа 1–2',
    '👨🏼‍⚖' => 'маж судија: тип на кожа 3',
    '👨🏽‍⚖' => 'маж судија: тип на кожа 4',
    '👨🏾‍⚖' => 'маж судија: тип на кожа 5',
    '👨🏿‍⚖' => 'маж судија: тип на кожа 6',
    '👩🏻‍⚖' => 'судијка: тип на кожа 1–2',
    '👩🏼‍⚖' => 'судијка: тип на кожа 3',
    '👩🏽‍⚖' => 'судијка: тип на кожа 4',
    '👩🏾‍⚖' => 'судијка: тип на кожа 5',
    '👩🏿‍⚖' => 'судијка: тип на кожа 6',
    '🧑🏻‍🌾' => 'фармер: тип на кожа 1–2',
    '🧑🏼‍🌾' => 'фармер: тип на кожа 3',
    '🧑🏽‍🌾' => 'фармер: тип на кожа 4',
    '🧑🏾‍🌾' => 'фармер: тип на кожа 5',
    '🧑🏿‍🌾' => 'фармер: тип на кожа 6',
    '👨🏻‍🌾' => 'земјоделец: тип на кожа 1–2',
    '👨🏼‍🌾' => 'земјоделец: тип на кожа 3',
    '👨🏽‍🌾' => 'земјоделец: тип на кожа 4',
    '👨🏾‍🌾' => 'земјоделец: тип на кожа 5',
    '👨🏿‍🌾' => 'земјоделец: тип на кожа 6',
    '👩🏻‍🌾' => 'земјоделка: тип на кожа 1–2',
    '👩🏼‍🌾' => 'земјоделка: тип на кожа 3',
    '👩🏽‍🌾' => 'земјоделка: тип на кожа 4',
    '👩🏾‍🌾' => 'земјоделка: тип на кожа 5',
    '👩🏿‍🌾' => 'земјоделка: тип на кожа 6',
    '🧑🏻‍🍳' => 'готвач: тип на кожа 1–2',
    '🧑🏼‍🍳' => 'готвач: тип на кожа 3',
    '🧑🏽‍🍳' => 'готвач: тип на кожа 4',
    '🧑🏾‍🍳' => 'готвач: тип на кожа 5',
    '🧑🏿‍🍳' => 'готвач: тип на кожа 6',
    '👨🏻‍🍳' => 'маж готвач: тип на кожа 1–2',
    '👨🏼‍🍳' => 'маж готвач: тип на кожа 3',
    '👨🏽‍🍳' => 'маж готвач: тип на кожа 4',
    '👨🏾‍🍳' => 'маж готвач: тип на кожа 5',
    '👨🏿‍🍳' => 'маж готвач: тип на кожа 6',
    '👩🏻‍🍳' => 'готвачка: тип на кожа 1–2',
    '👩🏼‍🍳' => 'готвачка: тип на кожа 3',
    '👩🏽‍🍳' => 'готвачка: тип на кожа 4',
    '👩🏾‍🍳' => 'готвачка: тип на кожа 5',
    '👩🏿‍🍳' => 'готвачка: тип на кожа 6',
    '🧑🏻‍🔧' => 'механичар: тип на кожа 1–2',
    '🧑🏼‍🔧' => 'механичар: тип на кожа 3',
    '🧑🏽‍🔧' => 'механичар: тип на кожа 4',
    '🧑🏾‍🔧' => 'механичар: тип на кожа 5',
    '🧑🏿‍🔧' => 'механичар: тип на кожа 6',
    '👨🏻‍🔧' => 'маж механичар: тип на кожа 1–2',
    '👨🏼‍🔧' => 'маж механичар: тип на кожа 3',
    '👨🏽‍🔧' => 'маж механичар: тип на кожа 4',
    '👨🏾‍🔧' => 'маж механичар: тип на кожа 5',
    '👨🏿‍🔧' => 'маж механичар: тип на кожа 6',
    '👩🏻‍🔧' => 'механичарка: тип на кожа 1–2',
    '👩🏼‍🔧' => 'механичарка: тип на кожа 3',
    '👩🏽‍🔧' => 'механичарка: тип на кожа 4',
    '👩🏾‍🔧' => 'механичарка: тип на кожа 5',
    '👩🏿‍🔧' => 'механичарка: тип на кожа 6',
    '🧑🏻‍🏭' => 'работник во фабрика: тип на кожа 1–2',
    '🧑🏼‍🏭' => 'работник во фабрика: тип на кожа 3',
    '🧑🏽‍🏭' => 'работник во фабрика: тип на кожа 4',
    '🧑🏾‍🏭' => 'работник во фабрика: тип на кожа 5',
    '🧑🏿‍🏭' => 'работник во фабрика: тип на кожа 6',
    '👨🏻‍🏭' => 'работник: тип на кожа 1–2',
    '👨🏼‍🏭' => 'работник: тип на кожа 3',
    '👨🏽‍🏭' => 'работник: тип на кожа 4',
    '👨🏾‍🏭' => 'работник: тип на кожа 5',
    '👨🏿‍🏭' => 'работник: тип на кожа 6',
    '👩🏻‍🏭' => 'работничка: тип на кожа 1–2',
    '👩🏼‍🏭' => 'работничка: тип на кожа 3',
    '👩🏽‍🏭' => 'работничка: тип на кожа 4',
    '👩🏾‍🏭' => 'работничка: тип на кожа 5',
    '👩🏿‍🏭' => 'работничка: тип на кожа 6',
    '🧑🏻‍💼' => 'канцелариски работник: тип на кожа 1–2',
    '🧑🏼‍💼' => 'канцелариски работник: тип на кожа 3',
    '🧑🏽‍💼' => 'канцелариски работник: тип на кожа 4',
    '🧑🏾‍💼' => 'канцелариски работник: тип на кожа 5',
    '🧑🏿‍💼' => 'канцелариски работник: тип на кожа 6',
    '👨🏻‍💼' => 'административец: тип на кожа 1–2',
    '👨🏼‍💼' => 'административец: тип на кожа 3',
    '👨🏽‍💼' => 'административец: тип на кожа 4',
    '👨🏾‍💼' => 'административец: тип на кожа 5',
    '👨🏿‍💼' => 'административец: тип на кожа 6',
    '👩🏻‍💼' => 'административка: тип на кожа 1–2',
    '👩🏼‍💼' => 'административка: тип на кожа 3',
    '👩🏽‍💼' => 'административка: тип на кожа 4',
    '👩🏾‍💼' => 'административка: тип на кожа 5',
    '👩🏿‍💼' => 'административка: тип на кожа 6',
    '🧑🏻‍🔬' => 'научник: тип на кожа 1–2',
    '🧑🏼‍🔬' => 'научник: тип на кожа 3',
    '🧑🏽‍🔬' => 'научник: тип на кожа 4',
    '🧑🏾‍🔬' => 'научник: тип на кожа 5',
    '🧑🏿‍🔬' => 'научник: тип на кожа 6',
    '👨🏻‍🔬' => 'маж научник: тип на кожа 1–2',
    '👨🏼‍🔬' => 'маж научник: тип на кожа 3',
    '👨🏽‍🔬' => 'маж научник: тип на кожа 4',
    '👨🏾‍🔬' => 'маж научник: тип на кожа 5',
    '👨🏿‍🔬' => 'маж научник: тип на кожа 6',
    '👩🏻‍🔬' => 'жена научник: тип на кожа 1–2',
    '👩🏼‍🔬' => 'жена научник: тип на кожа 3',
    '👩🏽‍🔬' => 'жена научник: тип на кожа 4',
    '👩🏾‍🔬' => 'жена научник: тип на кожа 5',
    '👩🏿‍🔬' => 'жена научник: тип на кожа 6',
    '🧑🏻‍💻' => 'технолог: тип на кожа 1–2',
    '🧑🏼‍💻' => 'технолог: тип на кожа 3',
    '🧑🏽‍💻' => 'технолог: тип на кожа 4',
    '🧑🏾‍💻' => 'технолог: тип на кожа 5',
    '🧑🏿‍💻' => 'технолог: тип на кожа 6',
    '👨🏻‍💻' => 'маж технолог: тип на кожа 1–2',
    '👨🏼‍💻' => 'маж технолог: тип на кожа 3',
    '👨🏽‍💻' => 'маж технолог: тип на кожа 4',
    '👨🏾‍💻' => 'маж технолог: тип на кожа 5',
    '👨🏿‍💻' => 'маж технолог: тип на кожа 6',
    '👩🏻‍💻' => 'жена технолог: тип на кожа 1–2',
    '👩🏼‍💻' => 'жена технолог: тип на кожа 3',
    '👩🏽‍💻' => 'жена технолог: тип на кожа 4',
    '👩🏾‍💻' => 'жена технолог: тип на кожа 5',
    '👩🏿‍💻' => 'жена технолог: тип на кожа 6',
    '🧑🏻‍🎤' => 'пејач: тип на кожа 1–2',
    '🧑🏼‍🎤' => 'пејач: тип на кожа 3',
    '🧑🏽‍🎤' => 'пејач: тип на кожа 4',
    '🧑🏾‍🎤' => 'пејач: тип на кожа 5',
    '🧑🏿‍🎤' => 'пејач: тип на кожа 6',
    '👨🏻‍🎤' => 'маж пејач: тип на кожа 1–2',
    '👨🏼‍🎤' => 'маж пејач: тип на кожа 3',
    '👨🏽‍🎤' => 'маж пејач: тип на кожа 4',
    '👨🏾‍🎤' => 'маж пејач: тип на кожа 5',
    '👨🏿‍🎤' => 'маж пејач: тип на кожа 6',
    '👩🏻‍🎤' => 'пејачка: тип на кожа 1–2',
    '👩🏼‍🎤' => 'пејачка: тип на кожа 3',
    '👩🏽‍🎤' => 'пејачка: тип на кожа 4',
    '👩🏾‍🎤' => 'пејачка: тип на кожа 5',
    '👩🏿‍🎤' => 'пејачка: тип на кожа 6',
    '🧑🏻‍🎨' => 'уметник: тип на кожа 1–2',
    '🧑🏼‍🎨' => 'уметник: тип на кожа 3',
    '🧑🏽‍🎨' => 'уметник: тип на кожа 4',
    '🧑🏾‍🎨' => 'уметник: тип на кожа 5',
    '🧑🏿‍🎨' => 'уметник: тип на кожа 6',
    '👨🏻‍🎨' => 'маж уметник: тип на кожа 1–2',
    '👨🏼‍🎨' => 'маж уметник: тип на кожа 3',
    '👨🏽‍🎨' => 'маж уметник: тип на кожа 4',
    '👨🏾‍🎨' => 'маж уметник: тип на кожа 5',
    '👨🏿‍🎨' => 'маж уметник: тип на кожа 6',
    '👩🏻‍🎨' => 'уметничка: тип на кожа 1–2',
    '👩🏼‍🎨' => 'уметничка: тип на кожа 3',
    '👩🏽‍🎨' => 'уметничка: тип на кожа 4',
    '👩🏾‍🎨' => 'уметничка: тип на кожа 5',
    '👩🏿‍🎨' => 'уметничка: тип на кожа 6',
    '🧑🏻‍✈' => 'пилот: тип на кожа 1–2',
    '🧑🏼‍✈' => 'пилот: тип на кожа 3',
    '🧑🏽‍✈' => 'пилот: тип на кожа 4',
    '🧑🏾‍✈' => 'пилот: тип на кожа 5',
    '🧑🏿‍✈' => 'пилот: тип на кожа 6',
    '👨🏻‍✈' => 'маж пилот: тип на кожа 1–2',
    '👨🏼‍✈' => 'маж пилот: тип на кожа 3',
    '👨🏽‍✈' => 'маж пилот: тип на кожа 4',
    '👨🏾‍✈' => 'маж пилот: тип на кожа 5',
    '👨🏿‍✈' => 'маж пилот: тип на кожа 6',
    '👩🏻‍✈' => 'жена пилот: тип на кожа 1–2',
    '👩🏼‍✈' => 'жена пилот: тип на кожа 3',
    '👩🏽‍✈' => 'жена пилот: тип на кожа 4',
    '👩🏾‍✈' => 'жена пилот: тип на кожа 5',
    '👩🏿‍✈' => 'жена пилот: тип на кожа 6',
    '🧑🏻‍🚀' => 'астронаут: тип на кожа 1–2',
    '🧑🏼‍🚀' => 'астронаут: тип на кожа 3',
    '🧑🏽‍🚀' => 'астронаут: тип на кожа 4',
    '🧑🏾‍🚀' => 'астронаут: тип на кожа 5',
    '🧑🏿‍🚀' => 'астронаут: тип на кожа 6',
    '👨🏻‍🚀' => 'маж астронаут: тип на кожа 1–2',
    '👨🏼‍🚀' => 'маж астронаут: тип на кожа 3',
    '👨🏽‍🚀' => 'маж астронаут: тип на кожа 4',
    '👨🏾‍🚀' => 'маж астронаут: тип на кожа 5',
    '👨🏿‍🚀' => 'маж астронаут: тип на кожа 6',
    '👩🏻‍🚀' => 'жена астронаут: тип на кожа 1–2',
    '👩🏼‍🚀' => 'жена астронаут: тип на кожа 3',
    '👩🏽‍🚀' => 'жена астронаут: тип на кожа 4',
    '👩🏾‍🚀' => 'жена астронаут: тип на кожа 5',
    '👩🏿‍🚀' => 'жена астронаут: тип на кожа 6',
    '🧑🏻‍🚒' => 'пожарникар: тип на кожа 1–2',
    '🧑🏼‍🚒' => 'пожарникар: тип на кожа 3',
    '🧑🏽‍🚒' => 'пожарникар: тип на кожа 4',
    '🧑🏾‍🚒' => 'пожарникар: тип на кожа 5',
    '🧑🏿‍🚒' => 'пожарникар: тип на кожа 6',
    '👨🏻‍🚒' => 'маж пожарникар: тип на кожа 1–2',
    '👨🏼‍🚒' => 'маж пожарникар: тип на кожа 3',
    '👨🏽‍🚒' => 'маж пожарникар: тип на кожа 4',
    '👨🏾‍🚒' => 'маж пожарникар: тип на кожа 5',
    '👨🏿‍🚒' => 'маж пожарникар: тип на кожа 6',
    '👩🏻‍🚒' => 'жена пожарникар: тип на кожа 1–2',
    '👩🏼‍🚒' => 'жена пожарникар: тип на кожа 3',
    '👩🏽‍🚒' => 'жена пожарникар: тип на кожа 4',
    '👩🏾‍🚒' => 'жена пожарникар: тип на кожа 5',
    '👩🏿‍🚒' => 'жена пожарникар: тип на кожа 6',
    '👮🏻‍♂' => 'полицаец: тип на кожа 1–2',
    '👮🏼‍♂' => 'полицаец: тип на кожа 3',
    '👮🏽‍♂' => 'полицаец: тип на кожа 4',
    '👮🏾‍♂' => 'полицаец: тип на кожа 5',
    '👮🏿‍♂' => 'полицаец: тип на кожа 6',
    '👮🏻‍♀' => 'полицајка: тип на кожа 1–2',
    '👮🏼‍♀' => 'полицајка: тип на кожа 3',
    '👮🏽‍♀' => 'полицајка: тип на кожа 4',
    '👮🏾‍♀' => 'полицајка: тип на кожа 5',
    '👮🏿‍♀' => 'полицајка: тип на кожа 6',
    '🕵🏻‍♂' => 'детектив: тип на кожа 1–2',
    '🕵🏼‍♂' => 'детектив: тип на кожа 3',
    '🕵🏽‍♂' => 'детектив: тип на кожа 4',
    '🕵🏾‍♂' => 'детектив: тип на кожа 5',
    '🕵🏿‍♂' => 'детектив: тип на кожа 6',
    '🕵🏻‍♀' => 'детективка: тип на кожа 1–2',
    '🕵🏼‍♀' => 'детективка: тип на кожа 3',
    '🕵🏽‍♀' => 'детективка: тип на кожа 4',
    '🕵🏾‍♀' => 'детективка: тип на кожа 5',
    '🕵🏿‍♀' => 'детективка: тип на кожа 6',
    '💂🏻‍♂' => 'гардист: тип на кожа 1–2',
    '💂🏼‍♂' => 'гардист: тип на кожа 3',
    '💂🏽‍♂' => 'гардист: тип на кожа 4',
    '💂🏾‍♂' => 'гардист: тип на кожа 5',
    '💂🏿‍♂' => 'гардист: тип на кожа 6',
    '💂🏻‍♀' => 'гардистка: тип на кожа 1–2',
    '💂🏼‍♀' => 'гардистка: тип на кожа 3',
    '💂🏽‍♀' => 'гардистка: тип на кожа 4',
    '💂🏾‍♀' => 'гардистка: тип на кожа 5',
    '💂🏿‍♀' => 'гардистка: тип на кожа 6',
    '👷🏻‍♂' => 'градежник: тип на кожа 1–2',
    '👷🏼‍♂' => 'градежник: тип на кожа 3',
    '👷🏽‍♂' => 'градежник: тип на кожа 4',
    '👷🏾‍♂' => 'градежник: тип на кожа 5',
    '👷🏿‍♂' => 'градежник: тип на кожа 6',
    '👷🏻‍♀' => 'жена градежник: тип на кожа 1–2',
    '👷🏼‍♀' => 'жена градежник: тип на кожа 3',
    '👷🏽‍♀' => 'жена градежник: тип на кожа 4',
    '👷🏾‍♀' => 'жена градежник: тип на кожа 5',
    '👷🏿‍♀' => 'жена градежник: тип на кожа 6',
    '👳🏻‍♂' => 'маж со турбан: тип на кожа 1–2',
    '👳🏼‍♂' => 'маж со турбан: тип на кожа 3',
    '👳🏽‍♂' => 'маж со турбан: тип на кожа 4',
    '👳🏾‍♂' => 'маж со турбан: тип на кожа 5',
    '👳🏿‍♂' => 'маж со турбан: тип на кожа 6',
    '👳🏻‍♀' => 'жена со турбан: тип на кожа 1–2',
    '👳🏼‍♀' => 'жена со турбан: тип на кожа 3',
    '👳🏽‍♀' => 'жена со турбан: тип на кожа 4',
    '👳🏾‍♀' => 'жена со турбан: тип на кожа 5',
    '👳🏿‍♀' => 'жена со турбан: тип на кожа 6',
    '🤵🏻‍♂' => 'маж во смокинг: тип на кожа 1–2',
    '🤵🏼‍♂' => 'маж во смокинг: тип на кожа 3',
    '🤵🏽‍♂' => 'маж во смокинг: тип на кожа 4',
    '🤵🏾‍♂' => 'маж во смокинг: тип на кожа 5',
    '🤵🏿‍♂' => 'маж во смокинг: тип на кожа 6',
    '🤵🏻‍♀' => 'жена во смокинг: тип на кожа 1–2',
    '🤵🏼‍♀' => 'жена во смокинг: тип на кожа 3',
    '🤵🏽‍♀' => 'жена во смокинг: тип на кожа 4',
    '🤵🏾‍♀' => 'жена во смокинг: тип на кожа 5',
    '🤵🏿‍♀' => 'жена во смокинг: тип на кожа 6',
    '👰🏻‍♂' => 'маж со превез: тип на кожа 1–2',
    '👰🏼‍♂' => 'маж со превез: тип на кожа 3',
    '👰🏽‍♂' => 'маж со превез: тип на кожа 4',
    '👰🏾‍♂' => 'маж со превез: тип на кожа 5',
    '👰🏿‍♂' => 'маж со превез: тип на кожа 6',
    '👰🏻‍♀' => 'жена со превез: тип на кожа 1–2',
    '👰🏼‍♀' => 'жена со превез: тип на кожа 3',
    '👰🏽‍♀' => 'жена со превез: тип на кожа 4',
    '👰🏾‍♀' => 'жена со превез: тип на кожа 5',
    '👰🏿‍♀' => 'жена со превез: тип на кожа 6',
    '👩🏻‍🍼' => 'жена храни бебе: тип на кожа 1–2',
    '👩🏼‍🍼' => 'жена храни бебе: тип на кожа 3',
    '👩🏽‍🍼' => 'жена храни бебе: тип на кожа 4',
    '👩🏾‍🍼' => 'жена храни бебе: тип на кожа 5',
    '👩🏿‍🍼' => 'жена храни бебе: тип на кожа 6',
    '👨🏻‍🍼' => 'маж храни бебе: тип на кожа 1–2',
    '👨🏼‍🍼' => 'маж храни бебе: тип на кожа 3',
    '👨🏽‍🍼' => 'маж храни бебе: тип на кожа 4',
    '👨🏾‍🍼' => 'маж храни бебе: тип на кожа 5',
    '👨🏿‍🍼' => 'маж храни бебе: тип на кожа 6',
    '🧑🏻‍🍼' => 'лице храни бебе: тип на кожа 1–2',
    '🧑🏼‍🍼' => 'лице храни бебе: тип на кожа 3',
    '🧑🏽‍🍼' => 'лице храни бебе: тип на кожа 4',
    '🧑🏾‍🍼' => 'лице храни бебе: тип на кожа 5',
    '🧑🏿‍🍼' => 'лице храни бебе: тип на кожа 6',
    '🧑🏻‍🎄' => 'лице Мраз: тип на кожа 1–2',
    '🧑🏼‍🎄' => 'лице Мраз: тип на кожа 3',
    '🧑🏽‍🎄' => 'лице Мраз: тип на кожа 4',
    '🧑🏾‍🎄' => 'лице Мраз: тип на кожа 5',
    '🧑🏿‍🎄' => 'лице Мраз: тип на кожа 6',
    '🦸🏻‍♂' => 'маж суперхерој: тип на кожа 1–2',
    '🦸🏼‍♂' => 'маж суперхерој: тип на кожа 3',
    '🦸🏽‍♂' => 'маж суперхерој: тип на кожа 4',
    '🦸🏾‍♂' => 'маж суперхерој: тип на кожа 5',
    '🦸🏿‍♂' => 'маж суперхерој: тип на кожа 6',
    '🦸🏻‍♀' => 'жена-суперхерој: тип на кожа 1–2',
    '🦸🏼‍♀' => 'жена-суперхерој: тип на кожа 3',
    '🦸🏽‍♀' => 'жена-суперхерој: тип на кожа 4',
    '🦸🏾‍♀' => 'жена-суперхерој: тип на кожа 5',
    '🦸🏿‍♀' => 'жена-суперхерој: тип на кожа 6',
    '🦹🏻‍♂' => 'маж супернегативец: тип на кожа 1–2',
    '🦹🏼‍♂' => 'маж супернегативец: тип на кожа 3',
    '🦹🏽‍♂' => 'маж супернегативец: тип на кожа 4',
    '🦹🏾‍♂' => 'маж супернегативец: тип на кожа 5',
    '🦹🏿‍♂' => 'маж супернегативец: тип на кожа 6',
    '🦹🏻‍♀' => 'жена супернегативец: тип на кожа 1–2',
    '🦹🏼‍♀' => 'жена супернегативец: тип на кожа 3',
    '🦹🏽‍♀' => 'жена супернегативец: тип на кожа 4',
    '🦹🏾‍♀' => 'жена супернегативец: тип на кожа 5',
    '🦹🏿‍♀' => 'жена супернегативец: тип на кожа 6',
    '🧙🏻‍♂' => 'маж магичар: тип на кожа 1–2',
    '🧙🏼‍♂' => 'маж магичар: тип на кожа 3',
    '🧙🏽‍♂' => 'маж магичар: тип на кожа 4',
    '🧙🏾‍♂' => 'маж магичар: тип на кожа 5',
    '🧙🏿‍♂' => 'маж магичар: тип на кожа 6',
    '🧙🏻‍♀' => 'жена магичар: тип на кожа 1–2',
    '🧙🏼‍♀' => 'жена магичар: тип на кожа 3',
    '🧙🏽‍♀' => 'жена магичар: тип на кожа 4',
    '🧙🏾‍♀' => 'жена магичар: тип на кожа 5',
    '🧙🏿‍♀' => 'жена магичар: тип на кожа 6',
    '🧚🏻‍♂' => 'виленик: тип на кожа 1–2',
    '🧚🏼‍♂' => 'виленик: тип на кожа 3',
    '🧚🏽‍♂' => 'виленик: тип на кожа 4',
    '🧚🏾‍♂' => 'виленик: тип на кожа 5',
    '🧚🏿‍♂' => 'виленик: тип на кожа 6',
    '🧚🏻‍♀' => 'жена самовила: тип на кожа 1–2',
    '🧚🏼‍♀' => 'жена самовила: тип на кожа 3',
    '🧚🏽‍♀' => 'жена самовила: тип на кожа 4',
    '🧚🏾‍♀' => 'жена самовила: тип на кожа 5',
    '🧚🏿‍♀' => 'жена самовила: тип на кожа 6',
    '🧛🏻‍♂' => 'маж вампир: тип на кожа 1–2',
    '🧛🏼‍♂' => 'маж вампир: тип на кожа 3',
    '🧛🏽‍♂' => 'маж вампир: тип на кожа 4',
    '🧛🏾‍♂' => 'маж вампир: тип на кожа 5',
    '🧛🏿‍♂' => 'маж вампир: тип на кожа 6',
    '🧛🏻‍♀' => 'жена вампир: тип на кожа 1–2',
    '🧛🏼‍♀' => 'жена вампир: тип на кожа 3',
    '🧛🏽‍♀' => 'жена вампир: тип на кожа 4',
    '🧛🏾‍♀' => 'жена вампир: тип на кожа 5',
    '🧛🏿‍♀' => 'жена вампир: тип на кожа 6',
    '🧜🏻‍♂' => 'маж сирена: тип на кожа 1–2',
    '🧜🏼‍♂' => 'маж сирена: тип на кожа 3',
    '🧜🏽‍♂' => 'маж сирена: тип на кожа 4',
    '🧜🏾‍♂' => 'маж сирена: тип на кожа 5',
    '🧜🏿‍♂' => 'маж сирена: тип на кожа 6',
    '🧜🏻‍♀' => 'сирена: тип на кожа 1–2',
    '🧜🏼‍♀' => 'сирена: тип на кожа 3',
    '🧜🏽‍♀' => 'сирена: тип на кожа 4',
    '🧜🏾‍♀' => 'сирена: тип на кожа 5',
    '🧜🏿‍♀' => 'сирена: тип на кожа 6',
    '🧝🏻‍♂' => 'маж шумски елф: тип на кожа 1–2',
    '🧝🏼‍♂' => 'маж шумски елф: тип на кожа 3',
    '🧝🏽‍♂' => 'маж шумски елф: тип на кожа 4',
    '🧝🏾‍♂' => 'маж шумски елф: тип на кожа 5',
    '🧝🏿‍♂' => 'маж шумски елф: тип на кожа 6',
    '🧝🏻‍♀' => 'жена шумски елф: тип на кожа 1–2',
    '🧝🏼‍♀' => 'жена шумски елф: тип на кожа 3',
    '🧝🏽‍♀' => 'жена шумски елф: тип на кожа 4',
    '🧝🏾‍♀' => 'жена шумски елф: тип на кожа 5',
    '🧝🏿‍♀' => 'жена шумски елф: тип на кожа 6',
    '💆🏻‍♂' => 'маж и масажа на лице: тип на кожа 1–2',
    '💆🏼‍♂' => 'маж и масажа на лице: тип на кожа 3',
    '💆🏽‍♂' => 'маж и масажа на лице: тип на кожа 4',
    '💆🏾‍♂' => 'маж и масажа на лице: тип на кожа 5',
    '💆🏿‍♂' => 'маж и масажа на лице: тип на кожа 6',
    '💆🏻‍♀' => 'жена и масажа на лице: тип на кожа 1–2',
    '💆🏼‍♀' => 'жена и масажа на лице: тип на кожа 3',
    '💆🏽‍♀' => 'жена и масажа на лице: тип на кожа 4',
    '💆🏾‍♀' => 'жена и масажа на лице: тип на кожа 5',
    '💆🏿‍♀' => 'жена и масажа на лице: тип на кожа 6',
    '💇🏻‍♂' => 'маж се потстрижува: тип на кожа 1–2',
    '💇🏼‍♂' => 'маж се потстрижува: тип на кожа 3',
    '💇🏽‍♂' => 'маж се потстрижува: тип на кожа 4',
    '💇🏾‍♂' => 'маж се потстрижува: тип на кожа 5',
    '💇🏿‍♂' => 'маж се потстрижува: тип на кожа 6',
    '💇🏻‍♀' => 'жена се потстрижува: тип на кожа 1–2',
    '💇🏼‍♀' => 'жена се потстрижува: тип на кожа 3',
    '💇🏽‍♀' => 'жена се потстрижува: тип на кожа 4',
    '💇🏾‍♀' => 'жена се потстрижува: тип на кожа 5',
    '💇🏿‍♀' => 'жена се потстрижува: тип на кожа 6',
    '🚶🏻‍♂' => 'маж пешачи: тип на кожа 1–2',
    '🚶🏼‍♂' => 'маж пешачи: тип на кожа 3',
    '🚶🏽‍♂' => 'маж пешачи: тип на кожа 4',
    '🚶🏾‍♂' => 'маж пешачи: тип на кожа 5',
    '🚶🏿‍♂' => 'маж пешачи: тип на кожа 6',
    '🚶🏻‍♀' => 'жена пешачи: тип на кожа 1–2',
    '🚶🏼‍♀' => 'жена пешачи: тип на кожа 3',
    '🚶🏽‍♀' => 'жена пешачи: тип на кожа 4',
    '🚶🏾‍♀' => 'жена пешачи: тип на кожа 5',
    '🚶🏿‍♀' => 'жена пешачи: тип на кожа 6',
    '🚶🏻‍➡' => 'лице пешачи: тип на кожа 1–2 и кон десно',
    '🚶🏼‍➡' => 'лице пешачи: тип на кожа 3 и кон десно',
    '🚶🏽‍➡' => 'лице пешачи: тип на кожа 4 и кон десно',
    '🚶🏾‍➡' => 'лице пешачи: тип на кожа 5 и кон десно',
    '🚶🏿‍➡' => 'лице пешачи: тип на кожа 6 и кон десно',
    '🧍🏻‍♂' => 'маж кој стои: тип на кожа 1–2',
    '🧍🏼‍♂' => 'маж кој стои: тип на кожа 3',
    '🧍🏽‍♂' => 'маж кој стои: тип на кожа 4',
    '🧍🏾‍♂' => 'маж кој стои: тип на кожа 5',
    '🧍🏿‍♂' => 'маж кој стои: тип на кожа 6',
    '🧍🏻‍♀' => 'жена која стои: тип на кожа 1–2',
    '🧍🏼‍♀' => 'жена која стои: тип на кожа 3',
    '🧍🏽‍♀' => 'жена која стои: тип на кожа 4',
    '🧍🏾‍♀' => 'жена која стои: тип на кожа 5',
    '🧍🏿‍♀' => 'жена која стои: тип на кожа 6',
    '🧎🏻‍♂' => 'маж кој клечи: тип на кожа 1–2',
    '🧎🏼‍♂' => 'маж кој клечи: тип на кожа 3',
    '🧎🏽‍♂' => 'маж кој клечи: тип на кожа 4',
    '🧎🏾‍♂' => 'маж кој клечи: тип на кожа 5',
    '🧎🏿‍♂' => 'маж кој клечи: тип на кожа 6',
    '🧎🏻‍♀' => 'жена која клечи: тип на кожа 1–2',
    '🧎🏼‍♀' => 'жена која клечи: тип на кожа 3',
    '🧎🏽‍♀' => 'жена која клечи: тип на кожа 4',
    '🧎🏾‍♀' => 'жена која клечи: тип на кожа 5',
    '🧎🏿‍♀' => 'жена која клечи: тип на кожа 6',
    '🧎🏻‍➡' => 'лице кое клечи: тип на кожа 1–2 и кон десно',
    '🧎🏼‍➡' => 'лице кое клечи: тип на кожа 3 и кон десно',
    '🧎🏽‍➡' => 'лице кое клечи: тип на кожа 4 и кон десно',
    '🧎🏾‍➡' => 'лице кое клечи: тип на кожа 5 и кон десно',
    '🧎🏿‍➡' => 'лице кое клечи: тип на кожа 6 и кон десно',
    '🧑🏻‍🦯' => 'лице со стап за слепи: тип на кожа 1–2',
    '🧑🏼‍🦯' => 'лице со стап за слепи: тип на кожа 3',
    '🧑🏽‍🦯' => 'лице со стап за слепи: тип на кожа 4',
    '🧑🏾‍🦯' => 'лице со стап за слепи: тип на кожа 5',
    '🧑🏿‍🦯' => 'лице со стап за слепи: тип на кожа 6',
    '👨🏻‍🦯' => 'маж со стап за слепи: тип на кожа 1–2',
    '👨🏼‍🦯' => 'маж со стап за слепи: тип на кожа 3',
    '👨🏽‍🦯' => 'маж со стап за слепи: тип на кожа 4',
    '👨🏾‍🦯' => 'маж со стап за слепи: тип на кожа 5',
    '👨🏿‍🦯' => 'маж со стап за слепи: тип на кожа 6',
    '👩🏻‍🦯' => 'жена со стап за слепи: тип на кожа 1–2',
    '👩🏼‍🦯' => 'жена со стап за слепи: тип на кожа 3',
    '👩🏽‍🦯' => 'жена со стап за слепи: тип на кожа 4',
    '👩🏾‍🦯' => 'жена со стап за слепи: тип на кожа 5',
    '👩🏿‍🦯' => 'жена со стап за слепи: тип на кожа 6',
    '🧑🏻‍🦼' => 'лице во моторизирана количка: тип на кожа 1–2',
    '🧑🏼‍🦼' => 'лице во моторизирана количка: тип на кожа 3',
    '🧑🏽‍🦼' => 'лице во моторизирана количка: тип на кожа 4',
    '🧑🏾‍🦼' => 'лице во моторизирана количка: тип на кожа 5',
    '🧑🏿‍🦼' => 'лице во моторизирана количка: тип на кожа 6',
    '👨🏻‍🦼' => 'маж во моторизирана количка: тип на кожа 1–2',
    '👨🏼‍🦼' => 'маж во моторизирана количка: тип на кожа 3',
    '👨🏽‍🦼' => 'маж во моторизирана количка: тип на кожа 4',
    '👨🏾‍🦼' => 'маж во моторизирана количка: тип на кожа 5',
    '👨🏿‍🦼' => 'маж во моторизирана количка: тип на кожа 6',
    '👩🏻‍🦼' => 'жена во моторизирана количка: тип на кожа 1–2',
    '👩🏼‍🦼' => 'жена во моторизирана количка: тип на кожа 3',
    '👩🏽‍🦼' => 'жена во моторизирана количка: тип на кожа 4',
    '👩🏾‍🦼' => 'жена во моторизирана количка: тип на кожа 5',
    '👩🏿‍🦼' => 'жена во моторизирана количка: тип на кожа 6',
    '🧑🏻‍🦽' => 'лице во рачна инвалидска количка: тип на кожа 1–2',
    '🧑🏼‍🦽' => 'лице во рачна инвалидска количка: тип на кожа 3',
    '🧑🏽‍🦽' => 'лице во рачна инвалидска количка: тип на кожа 4',
    '🧑🏾‍🦽' => 'лице во рачна инвалидска количка: тип на кожа 5',
    '🧑🏿‍🦽' => 'лице во рачна инвалидска количка: тип на кожа 6',
    '👨🏻‍🦽' => 'маж во рачна инвалидска количка: тип на кожа 1–2',
    '👨🏼‍🦽' => 'маж во рачна инвалидска количка: тип на кожа 3',
    '👨🏽‍🦽' => 'маж во рачна инвалидска количка: тип на кожа 4',
    '👨🏾‍🦽' => 'маж во рачна инвалидска количка: тип на кожа 5',
    '👨🏿‍🦽' => 'маж во рачна инвалидска количка: тип на кожа 6',
    '👩🏻‍🦽' => 'жена во рачна инвалидска количка: тип на кожа 1–2',
    '👩🏼‍🦽' => 'жена во рачна инвалидска количка: тип на кожа 3',
    '👩🏽‍🦽' => 'жена во рачна инвалидска количка: тип на кожа 4',
    '👩🏾‍🦽' => 'жена во рачна инвалидска количка: тип на кожа 5',
    '👩🏿‍🦽' => 'жена во рачна инвалидска количка: тип на кожа 6',
    '🏃🏻‍♂' => 'маж трча: тип на кожа 1–2',
    '🏃🏼‍♂' => 'маж трча: тип на кожа 3',
    '🏃🏽‍♂' => 'маж трча: тип на кожа 4',
    '🏃🏾‍♂' => 'маж трча: тип на кожа 5',
    '🏃🏿‍♂' => 'маж трча: тип на кожа 6',
    '🏃🏻‍♀' => 'жена трча: тип на кожа 1–2',
    '🏃🏼‍♀' => 'жена трча: тип на кожа 3',
    '🏃🏽‍♀' => 'жена трча: тип на кожа 4',
    '🏃🏾‍♀' => 'жена трча: тип на кожа 5',
    '🏃🏿‍♀' => 'жена трча: тип на кожа 6',
    '🏃🏻‍➡' => 'лице трча: тип на кожа 1–2 и кон десно',
    '🏃🏼‍➡' => 'лице трча: тип на кожа 3 и кон десно',
    '🏃🏽‍➡' => 'лице трча: тип на кожа 4 и кон десно',
    '🏃🏾‍➡' => 'лице трча: тип на кожа 5 и кон десно',
    '🏃🏿‍➡' => 'лице трча: тип на кожа 6 и кон десно',
    '👯🏻‍♀' => 'жени кои се забавуваат: тип на кожа 1–2',
    '👯🏼‍♀' => 'жени кои се забавуваат: тип на кожа 3',
    '👯🏽‍♀' => 'жени кои се забавуваат: тип на кожа 4',
    '👯🏾‍♀' => 'жени кои се забавуваат: тип на кожа 5',
    '👯🏿‍♀' => 'жени кои се забавуваат: тип на кожа 6',
    '👯🏻‍♂' => 'мажи кои се забавуваат: тип на кожа 1–2',
    '👯🏼‍♂' => 'мажи кои се забавуваат: тип на кожа 3',
    '👯🏽‍♂' => 'мажи кои се забавуваат: тип на кожа 4',
    '👯🏾‍♂' => 'мажи кои се забавуваат: тип на кожа 5',
    '👯🏿‍♂' => 'мажи кои се забавуваат: тип на кожа 6',
    '🧖🏻‍♂' => 'маж во парна соба: тип на кожа 1–2',
    '🧖🏼‍♂' => 'маж во парна соба: тип на кожа 3',
    '🧖🏽‍♂' => 'маж во парна соба: тип на кожа 4',
    '🧖🏾‍♂' => 'маж во парна соба: тип на кожа 5',
    '🧖🏿‍♂' => 'маж во парна соба: тип на кожа 6',
    '🧖🏻‍♀' => 'жена во парна соба: тип на кожа 1–2',
    '🧖🏼‍♀' => 'жена во парна соба: тип на кожа 3',
    '🧖🏽‍♀' => 'жена во парна соба: тип на кожа 4',
    '🧖🏾‍♀' => 'жена во парна соба: тип на кожа 5',
    '🧖🏿‍♀' => 'жена во парна соба: тип на кожа 6',
    '🧗🏻‍♂' => 'маж планинари: тип на кожа 1–2',
    '🧗🏼‍♂' => 'маж планинари: тип на кожа 3',
    '🧗🏽‍♂' => 'маж планинари: тип на кожа 4',
    '🧗🏾‍♂' => 'маж планинари: тип на кожа 5',
    '🧗🏿‍♂' => 'маж планинари: тип на кожа 6',
    '🧗🏻‍♀' => 'жена планинари: тип на кожа 1–2',
    '🧗🏼‍♀' => 'жена планинари: тип на кожа 3',
    '🧗🏽‍♀' => 'жена планинари: тип на кожа 4',
    '🧗🏾‍♀' => 'жена планинари: тип на кожа 5',
    '🧗🏿‍♀' => 'жена планинари: тип на кожа 6',
    '🏌🏻‍♂' => 'голфер: тип на кожа 1–2',
    '🏌🏼‍♂' => 'голфер: тип на кожа 3',
    '🏌🏽‍♂' => 'голфер: тип на кожа 4',
    '🏌🏾‍♂' => 'голфер: тип на кожа 5',
    '🏌🏿‍♂' => 'голфер: тип на кожа 6',
    '🏌🏻‍♀' => 'голферка: тип на кожа 1–2',
    '🏌🏼‍♀' => 'голферка: тип на кожа 3',
    '🏌🏽‍♀' => 'голферка: тип на кожа 4',
    '🏌🏾‍♀' => 'голферка: тип на кожа 5',
    '🏌🏿‍♀' => 'голферка: тип на кожа 6',
    '🏄🏻‍♂' => 'сурфер: тип на кожа 1–2',
    '🏄🏼‍♂' => 'сурфер: тип на кожа 3',
    '🏄🏽‍♂' => 'сурфер: тип на кожа 4',
    '🏄🏾‍♂' => 'сурфер: тип на кожа 5',
    '🏄🏿‍♂' => 'сурфер: тип на кожа 6',
    '🏄🏻‍♀' => 'сурферка: тип на кожа 1–2',
    '🏄🏼‍♀' => 'сурферка: тип на кожа 3',
    '🏄🏽‍♀' => 'сурферка: тип на кожа 4',
    '🏄🏾‍♀' => 'сурферка: тип на кожа 5',
    '🏄🏿‍♀' => 'сурферка: тип на кожа 6',
    '🚣🏻‍♂' => 'веслач: тип на кожа 1–2',
    '🚣🏼‍♂' => 'веслач: тип на кожа 3',
    '🚣🏽‍♂' => 'веслач: тип на кожа 4',
    '🚣🏾‍♂' => 'веслач: тип на кожа 5',
    '🚣🏿‍♂' => 'веслач: тип на кожа 6',
    '🚣🏻‍♀' => 'веслачка: тип на кожа 1–2',
    '🚣🏼‍♀' => 'веслачка: тип на кожа 3',
    '🚣🏽‍♀' => 'веслачка: тип на кожа 4',
    '🚣🏾‍♀' => 'веслачка: тип на кожа 5',
    '🚣🏿‍♀' => 'веслачка: тип на кожа 6',
    '🏊🏻‍♂' => 'пливач: тип на кожа 1–2',
    '🏊🏼‍♂' => 'пливач: тип на кожа 3',
    '🏊🏽‍♂' => 'пливач: тип на кожа 4',
    '🏊🏾‍♂' => 'пливач: тип на кожа 5',
    '🏊🏿‍♂' => 'пливач: тип на кожа 6',
    '🏊🏻‍♀' => 'пливачка: тип на кожа 1–2',
    '🏊🏼‍♀' => 'пливачка: тип на кожа 3',
    '🏊🏽‍♀' => 'пливачка: тип на кожа 4',
    '🏊🏾‍♀' => 'пливачка: тип на кожа 5',
    '🏊🏿‍♀' => 'пливачка: тип на кожа 6',
    '⛹🏻‍♂' => 'маж со топка: тип на кожа 1–2',
    '⛹🏼‍♂' => 'маж со топка: тип на кожа 3',
    '⛹🏽‍♂' => 'маж со топка: тип на кожа 4',
    '⛹🏾‍♂' => 'маж со топка: тип на кожа 5',
    '⛹🏿‍♂' => 'маж со топка: тип на кожа 6',
    '⛹🏻‍♀' => 'жена со топка: тип на кожа 1–2',
    '⛹🏼‍♀' => 'жена со топка: тип на кожа 3',
    '⛹🏽‍♀' => 'жена со топка: тип на кожа 4',
    '⛹🏾‍♀' => 'жена со топка: тип на кожа 5',
    '⛹🏿‍♀' => 'жена со топка: тип на кожа 6',
    '🏋🏻‍♂' => 'маж крева тегови: тип на кожа 1–2',
    '🏋🏼‍♂' => 'маж крева тегови: тип на кожа 3',
    '🏋🏽‍♂' => 'маж крева тегови: тип на кожа 4',
    '🏋🏾‍♂' => 'маж крева тегови: тип на кожа 5',
    '🏋🏿‍♂' => 'маж крева тегови: тип на кожа 6',
    '🏋🏻‍♀' => 'жена крева тегови: тип на кожа 1–2',
    '🏋🏼‍♀' => 'жена крева тегови: тип на кожа 3',
    '🏋🏽‍♀' => 'жена крева тегови: тип на кожа 4',
    '🏋🏾‍♀' => 'жена крева тегови: тип на кожа 5',
    '🏋🏿‍♀' => 'жена крева тегови: тип на кожа 6',
    '🚴🏻‍♂' => 'велосипедист: тип на кожа 1–2',
    '🚴🏼‍♂' => 'велосипедист: тип на кожа 3',
    '🚴🏽‍♂' => 'велосипедист: тип на кожа 4',
    '🚴🏾‍♂' => 'велосипедист: тип на кожа 5',
    '🚴🏿‍♂' => 'велосипедист: тип на кожа 6',
    '🚴🏻‍♀' => 'велосипедистка: тип на кожа 1–2',
    '🚴🏼‍♀' => 'велосипедистка: тип на кожа 3',
    '🚴🏽‍♀' => 'велосипедистка: тип на кожа 4',
    '🚴🏾‍♀' => 'велосипедистка: тип на кожа 5',
    '🚴🏿‍♀' => 'велосипедистка: тип на кожа 6',
    '🚵🏻‍♂' => 'планински велосипедист: тип на кожа 1–2',
    '🚵🏼‍♂' => 'планински велосипедист: тип на кожа 3',
    '🚵🏽‍♂' => 'планински велосипедист: тип на кожа 4',
    '🚵🏾‍♂' => 'планински велосипедист: тип на кожа 5',
    '🚵🏿‍♂' => 'планински велосипедист: тип на кожа 6',
    '🚵🏻‍♀' => 'планинска велосипедистка: тип на кожа 1–2',
    '🚵🏼‍♀' => 'планинска велосипедистка: тип на кожа 3',
    '🚵🏽‍♀' => 'планинска велосипедистка: тип на кожа 4',
    '🚵🏾‍♀' => 'планинска велосипедистка: тип на кожа 5',
    '🚵🏿‍♀' => 'планинска велосипедистка: тип на кожа 6',
    '🤸🏻‍♂' => 'маж прави ѕвезда: тип на кожа 1–2',
    '🤸🏼‍♂' => 'маж прави ѕвезда: тип на кожа 3',
    '🤸🏽‍♂' => 'маж прави ѕвезда: тип на кожа 4',
    '🤸🏾‍♂' => 'маж прави ѕвезда: тип на кожа 5',
    '🤸🏿‍♂' => 'маж прави ѕвезда: тип на кожа 6',
    '🤸🏻‍♀' => 'жена прави ѕвезда: тип на кожа 1–2',
    '🤸🏼‍♀' => 'жена прави ѕвезда: тип на кожа 3',
    '🤸🏽‍♀' => 'жена прави ѕвезда: тип на кожа 4',
    '🤸🏾‍♀' => 'жена прави ѕвезда: тип на кожа 5',
    '🤸🏿‍♀' => 'жена прави ѕвезда: тип на кожа 6',
    '🤼🏻‍♀' => 'борачки: тип на кожа 1–2',
    '🤼🏼‍♀' => 'борачки: тип на кожа 3',
    '🤼🏽‍♀' => 'борачки: тип на кожа 4',
    '🤼🏾‍♀' => 'борачки: тип на кожа 5',
    '🤼🏿‍♀' => 'борачки: тип на кожа 6',
    '🤼🏻‍♂' => 'борачи: тип на кожа 1–2',
    '🤼🏼‍♂' => 'борачи: тип на кожа 3',
    '🤼🏽‍♂' => 'борачи: тип на кожа 4',
    '🤼🏾‍♂' => 'борачи: тип на кожа 5',
    '🤼🏿‍♂' => 'борачи: тип на кожа 6',
    '🤽🏻‍♂' => 'ватерполист: тип на кожа 1–2',
    '🤽🏼‍♂' => 'ватерполист: тип на кожа 3',
    '🤽🏽‍♂' => 'ватерполист: тип на кожа 4',
    '🤽🏾‍♂' => 'ватерполист: тип на кожа 5',
    '🤽🏿‍♂' => 'ватерполист: тип на кожа 6',
    '🤽🏻‍♀' => 'ватерполистка: тип на кожа 1–2',
    '🤽🏼‍♀' => 'ватерполистка: тип на кожа 3',
    '🤽🏽‍♀' => 'ватерполистка: тип на кожа 4',
    '🤽🏾‍♀' => 'ватерполистка: тип на кожа 5',
    '🤽🏿‍♀' => 'ватерполистка: тип на кожа 6',
    '🤾🏻‍♂' => 'ракометар: тип на кожа 1–2',
    '🤾🏼‍♂' => 'ракометар: тип на кожа 3',
    '🤾🏽‍♂' => 'ракометар: тип на кожа 4',
    '🤾🏾‍♂' => 'ракометар: тип на кожа 5',
    '🤾🏿‍♂' => 'ракометар: тип на кожа 6',
    '🤾🏻‍♀' => 'ракометарка: тип на кожа 1–2',
    '🤾🏼‍♀' => 'ракометарка: тип на кожа 3',
    '🤾🏽‍♀' => 'ракометарка: тип на кожа 4',
    '🤾🏾‍♀' => 'ракометарка: тип на кожа 5',
    '🤾🏿‍♀' => 'ракометарка: тип на кожа 6',
    '🤹🏻‍♂' => 'жонглер: тип на кожа 1–2',
    '🤹🏼‍♂' => 'жонглер: тип на кожа 3',
    '🤹🏽‍♂' => 'жонглер: тип на кожа 4',
    '🤹🏾‍♂' => 'жонглер: тип на кожа 5',
    '🤹🏿‍♂' => 'жонглер: тип на кожа 6',
    '🤹🏻‍♀' => 'жонглерка: тип на кожа 1–2',
    '🤹🏼‍♀' => 'жонглерка: тип на кожа 3',
    '🤹🏽‍♀' => 'жонглерка: тип на кожа 4',
    '🤹🏾‍♀' => 'жонглерка: тип на кожа 5',
    '🤹🏿‍♀' => 'жонглерка: тип на кожа 6',
    '🧘🏻‍♂' => 'маж во положба лотос: тип на кожа 1–2',
    '🧘🏼‍♂' => 'маж во положба лотос: тип на кожа 3',
    '🧘🏽‍♂' => 'маж во положба лотос: тип на кожа 4',
    '🧘🏾‍♂' => 'маж во положба лотос: тип на кожа 5',
    '🧘🏿‍♂' => 'маж во положба лотос: тип на кожа 6',
    '🧘🏻‍♀' => 'жена во положба лотос: тип на кожа 1–2',
    '🧘🏼‍♀' => 'жена во положба лотос: тип на кожа 3',
    '🧘🏽‍♀' => 'жена во положба лотос: тип на кожа 4',
    '🧘🏾‍♀' => 'жена во положба лотос: тип на кожа 5',
    '🧘🏿‍♀' => 'жена во положба лотос: тип на кожа 6',
    '🧑‍🦰' => 'возрасно лице: црвена коса',
    '🧑‍🦱' => 'возрасно лице: кадрава коса',
    '🧑‍🦳' => 'возрасно лице: бела коса',
    '🧑‍🦲' => 'возрасно лице: ќелав',
    '👨‍🦰' => 'маж: црвена коса',
    '👨‍🦱' => 'маж: кадрава коса',
    '👨‍🦳' => 'маж: бела коса',
    '👨‍🦲' => 'маж: ќелав',
    '👩‍🦰' => 'жена: црвена коса',
    '👩‍🦱' => 'жена: кадрава коса',
    '👩‍🦳' => 'жена: бела коса',
    '👩‍🦲' => 'жена: ќелав',
    '🚶‍➡' => 'лице пешачи: кон десно',
    '🧎‍➡' => 'лице кое клечи: кон десно',
    '🏃‍➡' => 'лице трча: кон десно',
    '👨‍👦' => 'семејство: маж и момче',
    '👨‍👧' => 'семејство: маж и девојче',
    '👩‍👦' => 'семејство: жена и момче',
    '👩‍👧' => 'семејство: жена и девојче',
    '😶‍🌫' => 'лице во облаци',
    '😮‍💨' => 'лице издишува',
    '🙂‍↕' => 'климнување со главата',
    '😵‍💫' => 'лице со спирални очи',
    '❤‍🔥' => 'запалено срце',
    '❤‍🩹' => 'залечено срце',
    '👁‍🗨' => 'око во балон за говор',
    '🧔‍♂' => 'маж: брада',
    '👱‍♂' => 'русокос маж',
    '🧔‍♀' => 'жена: брада',
    '👱‍♀' => 'русокоса жена',
    '🙍‍♂' => 'намуртен маж',
    '🙍‍♀' => 'намуртена жена',
    '🙎‍♂' => 'налутен маж',
    '🙎‍♀' => 'налутена жена',
    '🙅‍♂' => 'маж што неодобрува',
    '🙅‍♀' => 'жена што неодобрува',
    '🙆‍♂' => 'маж што одобрува',
    '🙆‍♀' => 'жена што одобрува',
    '💁‍♂' => 'феминизиран маж',
    '💁‍♀' => 'шмизла',
    '🙋‍♂' => 'маж со подигната рака',
    '🙋‍♀' => 'жена со подигната рака',
    '🧏‍♂' => 'глув маж',
    '🧏‍♀' => 'глува жена',
    '🙇‍♂' => 'маж се поклонува',
    '🙇‍♀' => 'жена се поклонува',
    '🤦‍♂' => 'маж и неверување',
    '🤦‍♀' => 'жена и неверување',
    '🤷‍♂' => 'маж и кревање раменици',
    '🤷‍♀' => 'жена и кревање раменици',
    '🧑‍⚕' => 'здравствен работник',
    '👨‍⚕' => 'доктор',
    '👩‍⚕' => 'докторка',
    '🧑‍🎓' => 'студент',
    '👨‍🎓' => 'маж студент',
    '👩‍🎓' => 'студентка',
    '🧑‍🏫' => 'учител',
    '👨‍🏫' => 'маж учител',
    '👩‍🏫' => 'учителка',
    '🧑‍⚖' => 'судија',
    '👨‍⚖' => 'маж судија',
    '👩‍⚖' => 'судијка',
    '🧑‍🌾' => 'фармер',
    '👨‍🌾' => 'земјоделец',
    '👩‍🌾' => 'земјоделка',
    '🧑‍🍳' => 'готвач',
    '👨‍🍳' => 'маж готвач',
    '👩‍🍳' => 'готвачка',
    '🧑‍🔧' => 'механичар',
    '👨‍🔧' => 'маж механичар',
    '👩‍🔧' => 'механичарка',
    '🧑‍🏭' => 'работник во фабрика',
    '👨‍🏭' => 'работник',
    '👩‍🏭' => 'работничка',
    '🧑‍💼' => 'канцелариски работник',
    '👨‍💼' => 'административец',
    '👩‍💼' => 'административка',
    '🧑‍🔬' => 'научник',
    '👨‍🔬' => 'маж научник',
    '👩‍🔬' => 'жена научник',
    '🧑‍💻' => 'технолог',
    '👨‍💻' => 'маж технолог',
    '👩‍💻' => 'жена технолог',
    '🧑‍🎤' => 'пејач',
    '👨‍🎤' => 'маж пејач',
    '👩‍🎤' => 'пејачка',
    '🧑‍🎨' => 'уметник',
    '👨‍🎨' => 'маж уметник',
    '👩‍🎨' => 'уметничка',
    '🧑‍✈' => 'пилот',
    '👨‍✈' => 'маж пилот',
    '👩‍✈' => 'жена пилот',
    '🧑‍🚀' => 'астронаут',
    '👨‍🚀' => 'маж астронаут',
    '👩‍🚀' => 'жена астронаут',
    '🧑‍🚒' => 'пожарникар',
    '👨‍🚒' => 'маж пожарникар',
    '👩‍🚒' => 'жена пожарникар',
    '👮‍♂' => 'полицаец',
    '👮‍♀' => 'полицајка',
    '🕵‍♂' => 'детектив',
    '🕵‍♀' => 'детективка',
    '💂‍♂' => 'гардист',
    '💂‍♀' => 'гардистка',
    '👷‍♂' => 'градежник',
    '👷‍♀' => 'жена градежник',
    '👳‍♂' => 'маж со турбан',
    '👳‍♀' => 'жена со турбан',
    '🤵‍♂' => 'маж во смокинг',
    '🤵‍♀' => 'жена во смокинг',
    '👰‍♂' => 'маж со превез',
    '👰‍♀' => 'жена со превез',
    '👩‍🍼' => 'жена храни бебе',
    '👨‍🍼' => 'маж храни бебе',
    '🧑‍🍼' => 'лице храни бебе',
    '🧑‍🎄' => 'лице Мраз',
    '🦸‍♂' => 'маж суперхерој',
    '🦸‍♀' => 'жена-суперхерој',
    '🦹‍♂' => 'маж супернегативец',
    '🦹‍♀' => 'жена супернегативец',
    '🧙‍♂' => 'маж магичар',
    '🧙‍♀' => 'жена магичар',
    '🧚‍♂' => 'виленик',
    '🧚‍♀' => 'жена самовила',
    '🧛‍♂' => 'маж вампир',
    '🧛‍♀' => 'жена вампир',
    '🧜‍♂' => 'маж сирена',
    '🧜‍♀' => 'сирена',
    '🧝‍♂' => 'маж шумски елф',
    '🧝‍♀' => 'жена шумски елф',
    '🧞‍♂' => 'маж џини',
    '🧞‍♀' => 'жена џини',
    '🧟‍♂' => 'маж зомби',
    '🧟‍♀' => 'жена зомби',
    '💆‍♂' => 'маж и масажа на лице',
    '💆‍♀' => 'жена и масажа на лице',
    '💇‍♂' => 'маж се потстрижува',
    '💇‍♀' => 'жена се потстрижува',
    '🚶‍♂' => 'маж пешачи',
    '🚶‍♀' => 'жена пешачи',
    '🧍‍♂' => 'маж кој стои',
    '🧍‍♀' => 'жена која стои',
    '🧎‍♂' => 'маж кој клечи',
    '🧎‍♀' => 'жена која клечи',
    '🧑‍🦯' => 'лице со стап за слепи',
    '👨‍🦯' => 'маж со стап за слепи',
    '👩‍🦯' => 'жена со стап за слепи',
    '🧑‍🦼' => 'лице во моторизирана количка',
    '👨‍🦼' => 'маж во моторизирана количка',
    '👩‍🦼' => 'жена во моторизирана количка',
    '🧑‍🦽' => 'лице во рачна инвалидска количка',
    '👨‍🦽' => 'маж во рачна инвалидска количка',
    '👩‍🦽' => 'жена во рачна инвалидска количка',
    '🏃‍♂' => 'маж трча',
    '🏃‍♀' => 'жена трча',
    '🧑‍🩰' => 'балерина',
    '👯‍♂' => 'мажи кои се забавуваат',
    '👯‍♀' => 'жени кои се забавуваат',
    '🧖‍♂' => 'маж во парна соба',
    '🧖‍♀' => 'жена во парна соба',
    '🧗‍♂' => 'маж планинари',
    '🧗‍♀' => 'жена планинари',
    '🏌‍♂' => 'голфер',
    '🏌‍♀' => 'голферка',
    '🏄‍♂' => 'сурфер',
    '🏄‍♀' => 'сурферка',
    '🚣‍♂' => 'веслач',
    '🚣‍♀' => 'веслачка',
    '🏊‍♂' => 'пливач',
    '🏊‍♀' => 'пливачка',
    '⛹‍♂' => 'маж со топка',
    '⛹‍♀' => 'жена со топка',
    '🏋‍♂' => 'маж крева тегови',
    '🏋‍♀' => 'жена крева тегови',
    '🚴‍♂' => 'велосипедист',
    '🚴‍♀' => 'велосипедистка',
    '🚵‍♂' => 'планински велосипедист',
    '🚵‍♀' => 'планинска велосипедистка',
    '🤸‍♂' => 'маж прави ѕвезда',
    '🤸‍♀' => 'жена прави ѕвезда',
    '🤼‍♂' => 'борачи',
    '🤼‍♀' => 'борачки',
    '🤽‍♂' => 'ватерполист',
    '🤽‍♀' => 'ватерполистка',
    '🤾‍♂' => 'ракометар',
    '🤾‍♀' => 'ракометарка',
    '🤹‍♂' => 'жонглер',
    '🤹‍♀' => 'жонглерка',
    '🧘‍♂' => 'маж во положба лотос',
    '🧘‍♀' => 'жена во положба лотос',
    '🧑‍🧒' => 'семејство: возрасно лице, дете',
    '🐕‍🦺' => 'куче за хендикепирани',
    '🐈‍⬛' => 'црна мачка',
    '🐻‍❄' => 'поларна мечка',
    '🐦‍⬛' => 'црна птица',
    '🐦‍🔥' => 'феникс',
    '🍋‍🟩' => 'лимета',
    '🍄‍🟫' => 'кафеава печурка',
    '⛓‍💥' => 'скршен синџир',
    '🏳‍🌈' => 'знаме на виножитото',
    '🏳‍⚧' => 'сино-розово-бело знаме',
    '🏴‍☠' => 'пиратско знаме',
    '👋🏻' => 'мавтање со рака: тип на кожа 1–2',
    '👋🏼' => 'мавтање со рака: тип на кожа 3',
    '👋🏽' => 'мавтање со рака: тип на кожа 4',
    '👋🏾' => 'мавтање со рака: тип на кожа 5',
    '👋🏿' => 'мавтање со рака: тип на кожа 6',
    '🤚🏻' => 'подигната дланка: тип на кожа 1–2',
    '🤚🏼' => 'подигната дланка: тип на кожа 3',
    '🤚🏽' => 'подигната дланка: тип на кожа 4',
    '🤚🏾' => 'подигната дланка: тип на кожа 5',
    '🤚🏿' => 'подигната дланка: тип на кожа 6',
    '🖐🏻' => 'крената рака со раширени прсти: тип на кожа 1–2',
    '🖐🏼' => 'крената рака со раширени прсти: тип на кожа 3',
    '🖐🏽' => 'крената рака со раширени прсти: тип на кожа 4',
    '🖐🏾' => 'крената рака со раширени прсти: тип на кожа 5',
    '🖐🏿' => 'крената рака со раширени прсти: тип на кожа 6',
    '✋🏻' => 'крената рака: тип на кожа 1–2',
    '✋🏼' => 'крената рака: тип на кожа 3',
    '✋🏽' => 'крената рака: тип на кожа 4',
    '✋🏾' => 'крената рака: тип на кожа 5',
    '✋🏿' => 'крената рака: тип на кожа 6',
    '🖖🏻' => 'вулкански поздрав: тип на кожа 1–2',
    '🖖🏼' => 'вулкански поздрав: тип на кожа 3',
    '🖖🏽' => 'вулкански поздрав: тип на кожа 4',
    '🖖🏾' => 'вулкански поздрав: тип на кожа 5',
    '🖖🏿' => 'вулкански поздрав: тип на кожа 6',
    '🫱🏻' => 'рака на десно: тип на кожа 1–2',
    '🫱🏼' => 'рака на десно: тип на кожа 3',
    '🫱🏽' => 'рака на десно: тип на кожа 4',
    '🫱🏾' => 'рака на десно: тип на кожа 5',
    '🫱🏿' => 'рака на десно: тип на кожа 6',
    '🫲🏻' => 'рака на лево: тип на кожа 1–2',
    '🫲🏼' => 'рака на лево: тип на кожа 3',
    '🫲🏽' => 'рака на лево: тип на кожа 4',
    '🫲🏾' => 'рака на лево: тип на кожа 5',
    '🫲🏿' => 'рака на лево: тип на кожа 6',
    '🫳🏻' => 'рака со дланката надолу: тип на кожа 1–2',
    '🫳🏼' => 'рака со дланката надолу: тип на кожа 3',
    '🫳🏽' => 'рака со дланката надолу: тип на кожа 4',
    '🫳🏾' => 'рака со дланката надолу: тип на кожа 5',
    '🫳🏿' => 'рака со дланката надолу: тип на кожа 6',
    '🫴🏻' => 'рака со дланката нагоре: тип на кожа 1–2',
    '🫴🏼' => 'рака со дланката нагоре: тип на кожа 3',
    '🫴🏽' => 'рака со дланката нагоре: тип на кожа 4',
    '🫴🏾' => 'рака со дланката нагоре: тип на кожа 5',
    '🫴🏿' => 'рака со дланката нагоре: тип на кожа 6',
    '🫷🏻' => 'дланка турка налево: тип на кожа 1–2',
    '🫷🏼' => 'дланка турка налево: тип на кожа 3',
    '🫷🏽' => 'дланка турка налево: тип на кожа 4',
    '🫷🏾' => 'дланка турка налево: тип на кожа 5',
    '🫷🏿' => 'дланка турка налево: тип на кожа 6',
    '🫸🏻' => 'дланка турка надесно: тип на кожа 1–2',
    '🫸🏼' => 'дланка турка надесно: тип на кожа 3',
    '🫸🏽' => 'дланка турка надесно: тип на кожа 4',
    '🫸🏾' => 'дланка турка надесно: тип на кожа 5',
    '🫸🏿' => 'дланка турка надесно: тип на кожа 6',
    '👌🏻' => 'рака што се согласува: тип на кожа 1–2',
    '👌🏼' => 'рака што се согласува: тип на кожа 3',
    '👌🏽' => 'рака што се согласува: тип на кожа 4',
    '👌🏾' => 'рака што се согласува: тип на кожа 5',
    '👌🏿' => 'рака што се согласува: тип на кожа 6',
    '🤌🏻' => 'стиснати прсти: тип на кожа 1–2',
    '🤌🏼' => 'стиснати прсти: тип на кожа 3',
    '🤌🏽' => 'стиснати прсти: тип на кожа 4',
    '🤌🏾' => 'стиснати прсти: тип на кожа 5',
    '🤌🏿' => 'стиснати прсти: тип на кожа 6',
    '🤏🏻' => 'дланка што штипе: тип на кожа 1–2',
    '🤏🏼' => 'дланка што штипе: тип на кожа 3',
    '🤏🏽' => 'дланка што штипе: тип на кожа 4',
    '🤏🏾' => 'дланка што штипе: тип на кожа 5',
    '🤏🏿' => 'дланка што штипе: тип на кожа 6',
    '✌🏻' => 'рака покажува победа: тип на кожа 1–2',
    '✌🏼' => 'рака покажува победа: тип на кожа 3',
    '✌🏽' => 'рака покажува победа: тип на кожа 4',
    '✌🏾' => 'рака покажува победа: тип на кожа 5',
    '✌🏿' => 'рака покажува победа: тип на кожа 6',
    '🤞🏻' => 'стискање палци: тип на кожа 1–2',
    '🤞🏼' => 'стискање палци: тип на кожа 3',
    '🤞🏽' => 'стискање палци: тип на кожа 4',
    '🤞🏾' => 'стискање палци: тип на кожа 5',
    '🤞🏿' => 'стискање палци: тип на кожа 6',
    '🫰🏻' => 'рака со вкрстени палец и показалец: тип на кожа 1–2',
    '🫰🏼' => 'рака со вкрстени палец и показалец: тип на кожа 3',
    '🫰🏽' => 'рака со вкрстени палец и показалец: тип на кожа 4',
    '🫰🏾' => 'рака со вкрстени палец и показалец: тип на кожа 5',
    '🫰🏿' => 'рака со вкрстени палец и показалец: тип на кожа 6',
    '🤟🏻' => 'знак „те сакам“: тип на кожа 1–2',
    '🤟🏼' => 'знак „те сакам“: тип на кожа 3',
    '🤟🏽' => 'знак „те сакам“: тип на кожа 4',
    '🤟🏾' => 'знак „те сакам“: тип на кожа 5',
    '🤟🏿' => 'знак „те сакам“: тип на кожа 6',
    '🤘🏻' => 'рака што покажува рогови: тип на кожа 1–2',
    '🤘🏼' => 'рака што покажува рогови: тип на кожа 3',
    '🤘🏽' => 'рака што покажува рогови: тип на кожа 4',
    '🤘🏾' => 'рака што покажува рогови: тип на кожа 5',
    '🤘🏿' => 'рака што покажува рогови: тип на кожа 6',
    '🤙🏻' => 'јави ми се: тип на кожа 1–2',
    '🤙🏼' => 'јави ми се: тип на кожа 3',
    '🤙🏽' => 'јави ми се: тип на кожа 4',
    '🤙🏾' => 'јави ми се: тип на кожа 5',
    '🤙🏿' => 'јави ми се: тип на кожа 6',
    '👈🏻' => 'показалец свртен налево: тип на кожа 1–2',
    '👈🏼' => 'показалец свртен налево: тип на кожа 3',
    '👈🏽' => 'показалец свртен налево: тип на кожа 4',
    '👈🏾' => 'показалец свртен налево: тип на кожа 5',
    '👈🏿' => 'показалец свртен налево: тип на кожа 6',
    '👉🏻' => 'показалец свртен надесно: тип на кожа 1–2',
    '👉🏼' => 'показалец свртен надесно: тип на кожа 3',
    '👉🏽' => 'показалец свртен надесно: тип на кожа 4',
    '👉🏾' => 'показалец свртен надесно: тип на кожа 5',
    '👉🏿' => 'показалец свртен надесно: тип на кожа 6',
    '👆🏻' => 'показалец свртен нагоре: тип на кожа 1–2',
    '👆🏼' => 'показалец свртен нагоре: тип на кожа 3',
    '👆🏽' => 'показалец свртен нагоре: тип на кожа 4',
    '👆🏾' => 'показалец свртен нагоре: тип на кожа 5',
    '👆🏿' => 'показалец свртен нагоре: тип на кожа 6',
    '🖕🏻' => 'среден прст: тип на кожа 1–2',
    '🖕🏼' => 'среден прст: тип на кожа 3',
    '🖕🏽' => 'среден прст: тип на кожа 4',
    '🖕🏾' => 'среден прст: тип на кожа 5',
    '🖕🏿' => 'среден прст: тип на кожа 6',
    '👇🏻' => 'показалец свртен надолу: тип на кожа 1–2',
    '👇🏼' => 'показалец свртен надолу: тип на кожа 3',
    '👇🏽' => 'показалец свртен надолу: тип на кожа 4',
    '👇🏾' => 'показалец свртен надолу: тип на кожа 5',
    '👇🏿' => 'показалец свртен надолу: тип на кожа 6',
    '☝🏻' => 'показалец нагоре: тип на кожа 1–2',
    '☝🏼' => 'показалец нагоре: тип на кожа 3',
    '☝🏽' => 'показалец нагоре: тип на кожа 4',
    '☝🏾' => 'показалец нагоре: тип на кожа 5',
    '☝🏿' => 'показалец нагоре: тип на кожа 6',
    '🫵🏻' => 'показалец покажува кон гледачот: тип на кожа 1–2',
    '🫵🏼' => 'показалец покажува кон гледачот: тип на кожа 3',
    '🫵🏽' => 'показалец покажува кон гледачот: тип на кожа 4',
    '🫵🏾' => 'показалец покажува кон гледачот: тип на кожа 5',
    '🫵🏿' => 'показалец покажува кон гледачот: тип на кожа 6',
    '👍🏻' => 'палец нагоре: тип на кожа 1–2',
    '👍🏼' => 'палец нагоре: тип на кожа 3',
    '👍🏽' => 'палец нагоре: тип на кожа 4',
    '👍🏾' => 'палец нагоре: тип на кожа 5',
    '👍🏿' => 'палец нагоре: тип на кожа 6',
    '👎🏻' => 'палец надолу: тип на кожа 1–2',
    '👎🏼' => 'палец надолу: тип на кожа 3',
    '👎🏽' => 'палец надолу: тип на кожа 4',
    '👎🏾' => 'палец надолу: тип на кожа 5',
    '👎🏿' => 'палец надолу: тип на кожа 6',
    '✊🏻' => 'крената тупаница: тип на кожа 1–2',
    '✊🏼' => 'крената тупаница: тип на кожа 3',
    '✊🏽' => 'крената тупаница: тип на кожа 4',
    '✊🏾' => 'крената тупаница: тип на кожа 5',
    '✊🏿' => 'крената тупаница: тип на кожа 6',
    '👊🏻' => 'тупаница што се приближува: тип на кожа 1–2',
    '👊🏼' => 'тупаница што се приближува: тип на кожа 3',
    '👊🏽' => 'тупаница што се приближува: тип на кожа 4',
    '👊🏾' => 'тупаница што се приближува: тип на кожа 5',
    '👊🏿' => 'тупаница што се приближува: тип на кожа 6',
    '🤛🏻' => 'лева тупаница: тип на кожа 1–2',
    '🤛🏼' => 'лева тупаница: тип на кожа 3',
    '🤛🏽' => 'лева тупаница: тип на кожа 4',
    '🤛🏾' => 'лева тупаница: тип на кожа 5',
    '🤛🏿' => 'лева тупаница: тип на кожа 6',
    '🤜🏻' => 'десна тупаница: тип на кожа 1–2',
    '🤜🏼' => 'десна тупаница: тип на кожа 3',
    '🤜🏽' => 'десна тупаница: тип на кожа 4',
    '🤜🏾' => 'десна тупаница: тип на кожа 5',
    '🤜🏿' => 'десна тупаница: тип на кожа 6',
    '👏🏻' => 'аплауз: тип на кожа 1–2',
    '👏🏼' => 'аплауз: тип на кожа 3',
    '👏🏽' => 'аплауз: тип на кожа 4',
    '👏🏾' => 'аплауз: тип на кожа 5',
    '👏🏿' => 'аплауз: тип на кожа 6',
    '🙌🏻' => 'кренати дланки: тип на кожа 1–2',
    '🙌🏼' => 'кренати дланки: тип на кожа 3',
    '🙌🏽' => 'кренати дланки: тип на кожа 4',
    '🙌🏾' => 'кренати дланки: тип на кожа 5',
    '🙌🏿' => 'кренати дланки: тип на кожа 6',
    '🫶🏻' => 'срце од раце: тип на кожа 1–2',
    '🫶🏼' => 'срце од раце: тип на кожа 3',
    '🫶🏽' => 'срце од раце: тип на кожа 4',
    '🫶🏾' => 'срце од раце: тип на кожа 5',
    '🫶🏿' => 'срце од раце: тип на кожа 6',
    '👐🏻' => 'отворени дланки: тип на кожа 1–2',
    '👐🏼' => 'отворени дланки: тип на кожа 3',
    '👐🏽' => 'отворени дланки: тип на кожа 4',
    '👐🏾' => 'отворени дланки: тип на кожа 5',
    '👐🏿' => 'отворени дланки: тип на кожа 6',
    '🤲🏻' => 'дланки една до друга: тип на кожа 1–2',
    '🤲🏼' => 'дланки една до друга: тип на кожа 3',
    '🤲🏽' => 'дланки една до друга: тип на кожа 4',
    '🤲🏾' => 'дланки една до друга: тип на кожа 5',
    '🤲🏿' => 'дланки една до друга: тип на кожа 6',
    '🤝🏻' => 'ракување: тип на кожа 1–2',
    '🤝🏼' => 'ракување: тип на кожа 3',
    '🤝🏽' => 'ракување: тип на кожа 4',
    '🤝🏾' => 'ракување: тип на кожа 5',
    '🤝🏿' => 'ракување: тип на кожа 6',
    '🙏🏻' => 'споени дланки: тип на кожа 1–2',
    '🙏🏼' => 'споени дланки: тип на кожа 3',
    '🙏🏽' => 'споени дланки: тип на кожа 4',
    '🙏🏾' => 'споени дланки: тип на кожа 5',
    '🙏🏿' => 'споени дланки: тип на кожа 6',
    '✍🏻' => 'рака што пишува: тип на кожа 1–2',
    '✍🏼' => 'рака што пишува: тип на кожа 3',
    '✍🏽' => 'рака што пишува: тип на кожа 4',
    '✍🏾' => 'рака што пишува: тип на кожа 5',
    '✍🏿' => 'рака што пишува: тип на кожа 6',
    '💅🏻' => 'лак за нокти: тип на кожа 1–2',
    '💅🏼' => 'лак за нокти: тип на кожа 3',
    '💅🏽' => 'лак за нокти: тип на кожа 4',
    '💅🏾' => 'лак за нокти: тип на кожа 5',
    '💅🏿' => 'лак за нокти: тип на кожа 6',
    '🤳🏻' => 'селфи: тип на кожа 1–2',
    '🤳🏼' => 'селфи: тип на кожа 3',
    '🤳🏽' => 'селфи: тип на кожа 4',
    '🤳🏾' => 'селфи: тип на кожа 5',
    '🤳🏿' => 'селфи: тип на кожа 6',
    '💪🏻' => 'покажува бицепс: тип на кожа 1–2',
    '💪🏼' => 'покажува бицепс: тип на кожа 3',
    '💪🏽' => 'покажува бицепс: тип на кожа 4',
    '💪🏾' => 'покажува бицепс: тип на кожа 5',
    '💪🏿' => 'покажува бицепс: тип на кожа 6',
    '🦵🏻' => 'нога: тип на кожа 1–2',
    '🦵🏼' => 'нога: тип на кожа 3',
    '🦵🏽' => 'нога: тип на кожа 4',
    '🦵🏾' => 'нога: тип на кожа 5',
    '🦵🏿' => 'нога: тип на кожа 6',
    '🦶🏻' => 'стапало: тип на кожа 1–2',
    '🦶🏼' => 'стапало: тип на кожа 3',
    '🦶🏽' => 'стапало: тип на кожа 4',
    '🦶🏾' => 'стапало: тип на кожа 5',
    '🦶🏿' => 'стапало: тип на кожа 6',
    '👂🏻' => 'уво: тип на кожа 1–2',
    '👂🏼' => 'уво: тип на кожа 3',
    '👂🏽' => 'уво: тип на кожа 4',
    '👂🏾' => 'уво: тип на кожа 5',
    '👂🏿' => 'уво: тип на кожа 6',
    '🦻🏻' => 'уво со апарат за слушање: тип на кожа 1–2',
    '🦻🏼' => 'уво со апарат за слушање: тип на кожа 3',
    '🦻🏽' => 'уво со апарат за слушање: тип на кожа 4',
    '🦻🏾' => 'уво со апарат за слушање: тип на кожа 5',
    '🦻🏿' => 'уво со апарат за слушање: тип на кожа 6',
    '👃🏻' => 'нос: тип на кожа 1–2',
    '👃🏼' => 'нос: тип на кожа 3',
    '👃🏽' => 'нос: тип на кожа 4',
    '👃🏾' => 'нос: тип на кожа 5',
    '👃🏿' => 'нос: тип на кожа 6',
    '👶🏻' => 'бебе: тип на кожа 1–2',
    '👶🏼' => 'бебе: тип на кожа 3',
    '👶🏽' => 'бебе: тип на кожа 4',
    '👶🏾' => 'бебе: тип на кожа 5',
    '👶🏿' => 'бебе: тип на кожа 6',
    '🧒🏻' => 'дете: тип на кожа 1–2',
    '🧒🏼' => 'дете: тип на кожа 3',
    '🧒🏽' => 'дете: тип на кожа 4',
    '🧒🏾' => 'дете: тип на кожа 5',
    '🧒🏿' => 'дете: тип на кожа 6',
    '👦🏻' => 'момче: тип на кожа 1–2',
    '👦🏼' => 'момче: тип на кожа 3',
    '👦🏽' => 'момче: тип на кожа 4',
    '👦🏾' => 'момче: тип на кожа 5',
    '👦🏿' => 'момче: тип на кожа 6',
    '👧🏻' => 'девојче: тип на кожа 1–2',
    '👧🏼' => 'девојче: тип на кожа 3',
    '👧🏽' => 'девојче: тип на кожа 4',
    '👧🏾' => 'девојче: тип на кожа 5',
    '👧🏿' => 'девојче: тип на кожа 6',
    '🧑🏻' => 'возрасно лице: тип на кожа 1–2',
    '🧑🏼' => 'возрасно лице: тип на кожа 3',
    '🧑🏽' => 'возрасно лице: тип на кожа 4',
    '🧑🏾' => 'возрасно лице: тип на кожа 5',
    '🧑🏿' => 'возрасно лице: тип на кожа 6',
    '👱🏻' => 'русокосо лице: тип на кожа 1–2',
    '👱🏼' => 'русокосо лице: тип на кожа 3',
    '👱🏽' => 'русокосо лице: тип на кожа 4',
    '👱🏾' => 'русокосо лице: тип на кожа 5',
    '👱🏿' => 'русокосо лице: тип на кожа 6',
    '👨🏻' => 'маж: тип на кожа 1–2',
    '👨🏼' => 'маж: тип на кожа 3',
    '👨🏽' => 'маж: тип на кожа 4',
    '👨🏾' => 'маж: тип на кожа 5',
    '👨🏿' => 'маж: тип на кожа 6',
    '🧔🏻' => 'забраден човек: тип на кожа 1–2',
    '🧔🏼' => 'забраден човек: тип на кожа 3',
    '🧔🏽' => 'забраден човек: тип на кожа 4',
    '🧔🏾' => 'забраден човек: тип на кожа 5',
    '🧔🏿' => 'забраден човек: тип на кожа 6',
    '👩🏻' => 'жена: тип на кожа 1–2',
    '👩🏼' => 'жена: тип на кожа 3',
    '👩🏽' => 'жена: тип на кожа 4',
    '👩🏾' => 'жена: тип на кожа 5',
    '👩🏿' => 'жена: тип на кожа 6',
    '🧓🏻' => 'постаро возрасно лице: тип на кожа 1–2',
    '🧓🏼' => 'постаро возрасно лице: тип на кожа 3',
    '🧓🏽' => 'постаро возрасно лице: тип на кожа 4',
    '🧓🏾' => 'постаро возрасно лице: тип на кожа 5',
    '🧓🏿' => 'постаро возрасно лице: тип на кожа 6',
    '👴🏻' => 'старец: тип на кожа 1–2',
    '👴🏼' => 'старец: тип на кожа 3',
    '👴🏽' => 'старец: тип на кожа 4',
    '👴🏾' => 'старец: тип на кожа 5',
    '👴🏿' => 'старец: тип на кожа 6',
    '👵🏻' => 'старица: тип на кожа 1–2',
    '👵🏼' => 'старица: тип на кожа 3',
    '👵🏽' => 'старица: тип на кожа 4',
    '👵🏾' => 'старица: тип на кожа 5',
    '👵🏿' => 'старица: тип на кожа 6',
    '🙍🏻' => 'намуртен човек: тип на кожа 1–2',
    '🙍🏼' => 'намуртен човек: тип на кожа 3',
    '🙍🏽' => 'намуртен човек: тип на кожа 4',
    '🙍🏾' => 'намуртен човек: тип на кожа 5',
    '🙍🏿' => 'намуртен човек: тип на кожа 6',
    '🙎🏻' => 'налутен човек: тип на кожа 1–2',
    '🙎🏼' => 'налутен човек: тип на кожа 3',
    '🙎🏽' => 'налутен човек: тип на кожа 4',
    '🙎🏾' => 'налутен човек: тип на кожа 5',
    '🙎🏿' => 'налутен човек: тип на кожа 6',
    '🙅🏻' => 'човек што неодобрува: тип на кожа 1–2',
    '🙅🏼' => 'човек што неодобрува: тип на кожа 3',
    '🙅🏽' => 'човек што неодобрува: тип на кожа 4',
    '🙅🏾' => 'човек што неодобрува: тип на кожа 5',
    '🙅🏿' => 'човек што неодобрува: тип на кожа 6',
    '🙆🏻' => 'човек што одобрува: тип на кожа 1–2',
    '🙆🏼' => 'човек што одобрува: тип на кожа 3',
    '🙆🏽' => 'човек што одобрува: тип на кожа 4',
    '🙆🏾' => 'човек што одобрува: тип на кожа 5',
    '🙆🏿' => 'човек што одобрува: тип на кожа 6',
    '💁🏻' => 'лице со феминизиран гест: тип на кожа 1–2',
    '💁🏼' => 'лице со феминизиран гест: тип на кожа 3',
    '💁🏽' => 'лице со феминизиран гест: тип на кожа 4',
    '💁🏾' => 'лице со феминизиран гест: тип на кожа 5',
    '💁🏿' => 'лице со феминизиран гест: тип на кожа 6',
    '🙋🏻' => 'лице со подигната рака: тип на кожа 1–2',
    '🙋🏼' => 'лице со подигната рака: тип на кожа 3',
    '🙋🏽' => 'лице со подигната рака: тип на кожа 4',
    '🙋🏾' => 'лице со подигната рака: тип на кожа 5',
    '🙋🏿' => 'лице со подигната рака: тип на кожа 6',
    '🧏🏻' => 'глуво лице: тип на кожа 1–2',
    '🧏🏼' => 'глуво лице: тип на кожа 3',
    '🧏🏽' => 'глуво лице: тип на кожа 4',
    '🧏🏾' => 'глуво лице: тип на кожа 5',
    '🧏🏿' => 'глуво лице: тип на кожа 6',
    '🙇🏻' => 'човек кој се поклонува: тип на кожа 1–2',
    '🙇🏼' => 'човек кој се поклонува: тип на кожа 3',
    '🙇🏽' => 'човек кој се поклонува: тип на кожа 4',
    '🙇🏾' => 'човек кој се поклонува: тип на кожа 5',
    '🙇🏿' => 'човек кој се поклонува: тип на кожа 6',
    '🤦🏻' => 'неверување: тип на кожа 1–2',
    '🤦🏼' => 'неверување: тип на кожа 3',
    '🤦🏽' => 'неверување: тип на кожа 4',
    '🤦🏾' => 'неверување: тип на кожа 5',
    '🤦🏿' => 'неверување: тип на кожа 6',
    '🤷🏻' => 'кревање раменици: тип на кожа 1–2',
    '🤷🏼' => 'кревање раменици: тип на кожа 3',
    '🤷🏽' => 'кревање раменици: тип на кожа 4',
    '🤷🏾' => 'кревање раменици: тип на кожа 5',
    '🤷🏿' => 'кревање раменици: тип на кожа 6',
    '👮🏻' => 'полициски службеник: тип на кожа 1–2',
    '👮🏼' => 'полициски службеник: тип на кожа 3',
    '👮🏽' => 'полициски службеник: тип на кожа 4',
    '👮🏾' => 'полициски службеник: тип на кожа 5',
    '👮🏿' => 'полициски службеник: тип на кожа 6',
    '🕵🏻' => 'детектив(ка): тип на кожа 1–2',
    '🕵🏼' => 'детектив(ка): тип на кожа 3',
    '🕵🏽' => 'детектив(ка): тип на кожа 4',
    '🕵🏾' => 'детектив(ка): тип на кожа 5',
    '🕵🏿' => 'детектив(ка): тип на кожа 6',
    '💂🏻' => 'гардист(ка): тип на кожа 1–2',
    '💂🏼' => 'гардист(ка): тип на кожа 3',
    '💂🏽' => 'гардист(ка): тип на кожа 4',
    '💂🏾' => 'гардист(ка): тип на кожа 5',
    '💂🏿' => 'гардист(ка): тип на кожа 6',
    '🥷🏻' => 'нинџа: тип на кожа 1–2',
    '🥷🏼' => 'нинџа: тип на кожа 3',
    '🥷🏽' => 'нинџа: тип на кожа 4',
    '🥷🏾' => 'нинџа: тип на кожа 5',
    '🥷🏿' => 'нинџа: тип на кожа 6',
    '👷🏻' => 'градежен работник: тип на кожа 1–2',
    '👷🏼' => 'градежен работник: тип на кожа 3',
    '👷🏽' => 'градежен работник: тип на кожа 4',
    '👷🏾' => 'градежен работник: тип на кожа 5',
    '👷🏿' => 'градежен работник: тип на кожа 6',
    '🫅🏻' => 'лице со круна: тип на кожа 1–2',
    '🫅🏼' => 'лице со круна: тип на кожа 3',
    '🫅🏽' => 'лице со круна: тип на кожа 4',
    '🫅🏾' => 'лице со круна: тип на кожа 5',
    '🫅🏿' => 'лице со круна: тип на кожа 6',
    '🤴🏻' => 'принц: тип на кожа 1–2',
    '🤴🏼' => 'принц: тип на кожа 3',
    '🤴🏽' => 'принц: тип на кожа 4',
    '🤴🏾' => 'принц: тип на кожа 5',
    '🤴🏿' => 'принц: тип на кожа 6',
    '👸🏻' => 'принцеза: тип на кожа 1–2',
    '👸🏼' => 'принцеза: тип на кожа 3',
    '👸🏽' => 'принцеза: тип на кожа 4',
    '👸🏾' => 'принцеза: тип на кожа 5',
    '👸🏿' => 'принцеза: тип на кожа 6',
    '👳🏻' => 'лице со турбан: тип на кожа 1–2',
    '👳🏼' => 'лице со турбан: тип на кожа 3',
    '👳🏽' => 'лице со турбан: тип на кожа 4',
    '👳🏾' => 'лице со турбан: тип на кожа 5',
    '👳🏿' => 'лице со турбан: тип на кожа 6',
    '👲🏻' => 'маж со кинеска капа: тип на кожа 1–2',
    '👲🏼' => 'маж со кинеска капа: тип на кожа 3',
    '👲🏽' => 'маж со кинеска капа: тип на кожа 4',
    '👲🏾' => 'маж со кинеска капа: тип на кожа 5',
    '👲🏿' => 'маж со кинеска капа: тип на кожа 6',
    '🧕🏻' => 'жена со шамија: тип на кожа 1–2',
    '🧕🏼' => 'жена со шамија: тип на кожа 3',
    '🧕🏽' => 'жена со шамија: тип на кожа 4',
    '🧕🏾' => 'жена со шамија: тип на кожа 5',
    '🧕🏿' => 'жена со шамија: тип на кожа 6',
    '🤵🏻' => 'човек во смокинг: тип на кожа 1–2',
    '🤵🏼' => 'човек во смокинг: тип на кожа 3',
    '🤵🏽' => 'човек во смокинг: тип на кожа 4',
    '🤵🏾' => 'човек во смокинг: тип на кожа 5',
    '🤵🏿' => 'човек во смокинг: тип на кожа 6',
    '👰🏻' => 'човек со превез: тип на кожа 1–2',
    '👰🏼' => 'човек со превез: тип на кожа 3',
    '👰🏽' => 'човек со превез: тип на кожа 4',
    '👰🏾' => 'човек со превез: тип на кожа 5',
    '👰🏿' => 'човек со превез: тип на кожа 6',
    '🤰🏻' => 'трудница: тип на кожа 1–2',
    '🤰🏼' => 'трудница: тип на кожа 3',
    '🤰🏽' => 'трудница: тип на кожа 4',
    '🤰🏾' => 'трудница: тип на кожа 5',
    '🤰🏿' => 'трудница: тип на кожа 6',
    '🫃🏻' => 'труден маж: тип на кожа 1–2',
    '🫃🏼' => 'труден маж: тип на кожа 3',
    '🫃🏽' => 'труден маж: тип на кожа 4',
    '🫃🏾' => 'труден маж: тип на кожа 5',
    '🫃🏿' => 'труден маж: тип на кожа 6',
    '🫄🏻' => 'трудно лице: тип на кожа 1–2',
    '🫄🏼' => 'трудно лице: тип на кожа 3',
    '🫄🏽' => 'трудно лице: тип на кожа 4',
    '🫄🏾' => 'трудно лице: тип на кожа 5',
    '🫄🏿' => 'трудно лице: тип на кожа 6',
    '🤱🏻' => 'доење: тип на кожа 1–2',
    '🤱🏼' => 'доење: тип на кожа 3',
    '🤱🏽' => 'доење: тип на кожа 4',
    '🤱🏾' => 'доење: тип на кожа 5',
    '🤱🏿' => 'доење: тип на кожа 6',
    '👼🏻' => 'бебе ангел: тип на кожа 1–2',
    '👼🏼' => 'бебе ангел: тип на кожа 3',
    '👼🏽' => 'бебе ангел: тип на кожа 4',
    '👼🏾' => 'бебе ангел: тип на кожа 5',
    '👼🏿' => 'бебе ангел: тип на кожа 6',
    '🎅🏻' => 'дедо мраз: тип на кожа 1–2',
    '🎅🏼' => 'дедо мраз: тип на кожа 3',
    '🎅🏽' => 'дедо мраз: тип на кожа 4',
    '🎅🏾' => 'дедо мраз: тип на кожа 5',
    '🎅🏿' => 'дедо мраз: тип на кожа 6',
    '🤶🏻' => 'баба мразица: тип на кожа 1–2',
    '🤶🏼' => 'баба мразица: тип на кожа 3',
    '🤶🏽' => 'баба мразица: тип на кожа 4',
    '🤶🏾' => 'баба мразица: тип на кожа 5',
    '🤶🏿' => 'баба мразица: тип на кожа 6',
    '🦸🏻' => 'суперхерој: тип на кожа 1–2',
    '🦸🏼' => 'суперхерој: тип на кожа 3',
    '🦸🏽' => 'суперхерој: тип на кожа 4',
    '🦸🏾' => 'суперхерој: тип на кожа 5',
    '🦸🏿' => 'суперхерој: тип на кожа 6',
    '🦹🏻' => 'супер-негативец: тип на кожа 1–2',
    '🦹🏼' => 'супер-негативец: тип на кожа 3',
    '🦹🏽' => 'супер-негативец: тип на кожа 4',
    '🦹🏾' => 'супер-негативец: тип на кожа 5',
    '🦹🏿' => 'супер-негативец: тип на кожа 6',
    '🧙🏻' => 'магичар: тип на кожа 1–2',
    '🧙🏼' => 'магичар: тип на кожа 3',
    '🧙🏽' => 'магичар: тип на кожа 4',
    '🧙🏾' => 'магичар: тип на кожа 5',
    '🧙🏿' => 'магичар: тип на кожа 6',
    '🧚🏻' => 'самовила: тип на кожа 1–2',
    '🧚🏼' => 'самовила: тип на кожа 3',
    '🧚🏽' => 'самовила: тип на кожа 4',
    '🧚🏾' => 'самовила: тип на кожа 5',
    '🧚🏿' => 'самовила: тип на кожа 6',
    '🧛🏻' => 'вампир: тип на кожа 1–2',
    '🧛🏼' => 'вампир: тип на кожа 3',
    '🧛🏽' => 'вампир: тип на кожа 4',
    '🧛🏾' => 'вампир: тип на кожа 5',
    '🧛🏿' => 'вампир: тип на кожа 6',
    '🧜🏻' => 'морско лице: тип на кожа 1–2',
    '🧜🏼' => 'морско лице: тип на кожа 3',
    '🧜🏽' => 'морско лице: тип на кожа 4',
    '🧜🏾' => 'морско лице: тип на кожа 5',
    '🧜🏿' => 'морско лице: тип на кожа 6',
    '🧝🏻' => 'шумски елф: тип на кожа 1–2',
    '🧝🏼' => 'шумски елф: тип на кожа 3',
    '🧝🏽' => 'шумски елф: тип на кожа 4',
    '🧝🏾' => 'шумски елф: тип на кожа 5',
    '🧝🏿' => 'шумски елф: тип на кожа 6',
    '💆🏻' => 'масажа на лице: тип на кожа 1–2',
    '💆🏼' => 'масажа на лице: тип на кожа 3',
    '💆🏽' => 'масажа на лице: тип на кожа 4',
    '💆🏾' => 'масажа на лице: тип на кожа 5',
    '💆🏿' => 'масажа на лице: тип на кожа 6',
    '💇🏻' => 'потстрижување: тип на кожа 1–2',
    '💇🏼' => 'потстрижување: тип на кожа 3',
    '💇🏽' => 'потстрижување: тип на кожа 4',
    '💇🏾' => 'потстрижување: тип на кожа 5',
    '💇🏿' => 'потстрижување: тип на кожа 6',
    '🚶🏻' => 'лице пешачи: тип на кожа 1–2',
    '🚶🏼' => 'лице пешачи: тип на кожа 3',
    '🚶🏽' => 'лице пешачи: тип на кожа 4',
    '🚶🏾' => 'лице пешачи: тип на кожа 5',
    '🚶🏿' => 'лице пешачи: тип на кожа 6',
    '🧍🏻' => 'лице кое стои: тип на кожа 1–2',
    '🧍🏼' => 'лице кое стои: тип на кожа 3',
    '🧍🏽' => 'лице кое стои: тип на кожа 4',
    '🧍🏾' => 'лице кое стои: тип на кожа 5',
    '🧍🏿' => 'лице кое стои: тип на кожа 6',
    '🧎🏻' => 'лице кое клечи: тип на кожа 1–2',
    '🧎🏼' => 'лице кое клечи: тип на кожа 3',
    '🧎🏽' => 'лице кое клечи: тип на кожа 4',
    '🧎🏾' => 'лице кое клечи: тип на кожа 5',
    '🧎🏿' => 'лице кое клечи: тип на кожа 6',
    '🏃🏻' => 'лице трча: тип на кожа 1–2',
    '🏃🏼' => 'лице трча: тип на кожа 3',
    '🏃🏽' => 'лице трча: тип на кожа 4',
    '🏃🏾' => 'лице трча: тип на кожа 5',
    '🏃🏿' => 'лице трча: тип на кожа 6',
    '💃🏻' => 'танчарка: тип на кожа 1–2',
    '💃🏼' => 'танчарка: тип на кожа 3',
    '💃🏽' => 'танчарка: тип на кожа 4',
    '💃🏾' => 'танчарка: тип на кожа 5',
    '💃🏿' => 'танчарка: тип на кожа 6',
    '🕺🏻' => 'танчар: тип на кожа 1–2',
    '🕺🏼' => 'танчар: тип на кожа 3',
    '🕺🏽' => 'танчар: тип на кожа 4',
    '🕺🏾' => 'танчар: тип на кожа 5',
    '🕺🏿' => 'танчар: тип на кожа 6',
    '🕴🏻' => 'лебдечки човек во деловен костум: тип на кожа 1–2',
    '🕴🏼' => 'лебдечки човек во деловен костум: тип на кожа 3',
    '🕴🏽' => 'лебдечки човек во деловен костум: тип на кожа 4',
    '🕴🏾' => 'лебдечки човек во деловен костум: тип на кожа 5',
    '🕴🏿' => 'лебдечки човек во деловен костум: тип на кожа 6',
    '👯🏻' => 'лица кои се забавуваат: тип на кожа 1–2',
    '👯🏼' => 'лица кои се забавуваат: тип на кожа 3',
    '👯🏽' => 'лица кои се забавуваат: тип на кожа 4',
    '👯🏾' => 'лица кои се забавуваат: тип на кожа 5',
    '👯🏿' => 'лица кои се забавуваат: тип на кожа 6',
    '🧖🏻' => 'лице во парна соба: тип на кожа 1–2',
    '🧖🏼' => 'лице во парна соба: тип на кожа 3',
    '🧖🏽' => 'лице во парна соба: тип на кожа 4',
    '🧖🏾' => 'лице во парна соба: тип на кожа 5',
    '🧖🏿' => 'лице во парна соба: тип на кожа 6',
    '🧗🏻' => 'лице планинари: тип на кожа 1–2',
    '🧗🏼' => 'лице планинари: тип на кожа 3',
    '🧗🏽' => 'лице планинари: тип на кожа 4',
    '🧗🏾' => 'лице планинари: тип на кожа 5',
    '🧗🏿' => 'лице планинари: тип на кожа 6',
    '🏇🏻' => 'трка со коњи: тип на кожа 1–2',
    '🏇🏼' => 'трка со коњи: тип на кожа 3',
    '🏇🏽' => 'трка со коњи: тип на кожа 4',
    '🏇🏾' => 'трка со коњи: тип на кожа 5',
    '🏇🏿' => 'трка со коњи: тип на кожа 6',
    '🏂🏻' => 'скијање на штица: тип на кожа 1–2',
    '🏂🏼' => 'скијање на штица: тип на кожа 3',
    '🏂🏽' => 'скијање на штица: тип на кожа 4',
    '🏂🏾' => 'скијање на штица: тип на кожа 5',
    '🏂🏿' => 'скијање на штица: тип на кожа 6',
    '🏌🏻' => 'играч на голф: тип на кожа 1–2',
    '🏌🏼' => 'играч на голф: тип на кожа 3',
    '🏌🏽' => 'играч на голф: тип на кожа 4',
    '🏌🏾' => 'играч на голф: тип на кожа 5',
    '🏌🏿' => 'играч на голф: тип на кожа 6',
    '🏄🏻' => 'лице кое сурфа: тип на кожа 1–2',
    '🏄🏼' => 'лице кое сурфа: тип на кожа 3',
    '🏄🏽' => 'лице кое сурфа: тип на кожа 4',
    '🏄🏾' => 'лице кое сурфа: тип на кожа 5',
    '🏄🏿' => 'лице кое сурфа: тип на кожа 6',
    '🚣🏻' => 'веслање чамец: тип на кожа 1–2',
    '🚣🏼' => 'веслање чамец: тип на кожа 3',
    '🚣🏽' => 'веслање чамец: тип на кожа 4',
    '🚣🏾' => 'веслање чамец: тип на кожа 5',
    '🚣🏿' => 'веслање чамец: тип на кожа 6',
    '🏊🏻' => 'лице кое плива: тип на кожа 1–2',
    '🏊🏼' => 'лице кое плива: тип на кожа 3',
    '🏊🏽' => 'лице кое плива: тип на кожа 4',
    '🏊🏾' => 'лице кое плива: тип на кожа 5',
    '🏊🏿' => 'лице кое плива: тип на кожа 6',
    '⛹🏻' => 'човек со топка: тип на кожа 1–2',
    '⛹🏼' => 'човек со топка: тип на кожа 3',
    '⛹🏽' => 'човек со топка: тип на кожа 4',
    '⛹🏾' => 'човек со топка: тип на кожа 5',
    '⛹🏿' => 'човек со топка: тип на кожа 6',
    '🏋🏻' => 'кревање тегови: тип на кожа 1–2',
    '🏋🏼' => 'кревање тегови: тип на кожа 3',
    '🏋🏽' => 'кревање тегови: тип на кожа 4',
    '🏋🏾' => 'кревање тегови: тип на кожа 5',
    '🏋🏿' => 'кревање тегови: тип на кожа 6',
    '🚴🏻' => 'лице кое вози велосипед: тип на кожа 1–2',
    '🚴🏼' => 'лице кое вози велосипед: тип на кожа 3',
    '🚴🏽' => 'лице кое вози велосипед: тип на кожа 4',
    '🚴🏾' => 'лице кое вози велосипед: тип на кожа 5',
    '🚴🏿' => 'лице кое вози велосипед: тип на кожа 6',
    '🚵🏻' => 'лице кое вози планински велосипед: тип на кожа 1–2',
    '🚵🏼' => 'лице кое вози планински велосипед: тип на кожа 3',
    '🚵🏽' => 'лице кое вози планински велосипед: тип на кожа 4',
    '🚵🏾' => 'лице кое вози планински велосипед: тип на кожа 5',
    '🚵🏿' => 'лице кое вози планински велосипед: тип на кожа 6',
    '🤸🏻' => 'лице прави ѕвезда: тип на кожа 1–2',
    '🤸🏼' => 'лице прави ѕвезда: тип на кожа 3',
    '🤸🏽' => 'лице прави ѕвезда: тип на кожа 4',
    '🤸🏾' => 'лице прави ѕвезда: тип на кожа 5',
    '🤸🏿' => 'лице прави ѕвезда: тип на кожа 6',
    '🤼🏻' => 'лица кои се борат: тип на кожа 1–2',
    '🤼🏼' => 'лица кои се борат: тип на кожа 3',
    '🤼🏽' => 'лица кои се борат: тип на кожа 4',
    '🤼🏾' => 'лица кои се борат: тип на кожа 5',
    '🤼🏿' => 'лица кои се борат: тип на кожа 6',
    '🤽🏻' => 'ватерполо: тип на кожа 1–2',
    '🤽🏼' => 'ватерполо: тип на кожа 3',
    '🤽🏽' => 'ватерполо: тип на кожа 4',
    '🤽🏾' => 'ватерполо: тип на кожа 5',
    '🤽🏿' => 'ватерполо: тип на кожа 6',
    '🤾🏻' => 'ракомет: тип на кожа 1–2',
    '🤾🏼' => 'ракомет: тип на кожа 3',
    '🤾🏽' => 'ракомет: тип на кожа 4',
    '🤾🏾' => 'ракомет: тип на кожа 5',
    '🤾🏿' => 'ракомет: тип на кожа 6',
    '🤹🏻' => 'жонглирање: тип на кожа 1–2',
    '🤹🏼' => 'жонглирање: тип на кожа 3',
    '🤹🏽' => 'жонглирање: тип на кожа 4',
    '🤹🏾' => 'жонглирање: тип на кожа 5',
    '🤹🏿' => 'жонглирање: тип на кожа 6',
    '🧘🏻' => 'лице во положба лотос: тип на кожа 1–2',
    '🧘🏼' => 'лице во положба лотос: тип на кожа 3',
    '🧘🏽' => 'лице во положба лотос: тип на кожа 4',
    '🧘🏾' => 'лице во положба лотос: тип на кожа 5',
    '🧘🏿' => 'лице во положба лотос: тип на кожа 6',
    '🛀🏻' => 'човек во када: тип на кожа 1–2',
    '🛀🏼' => 'човек во када: тип на кожа 3',
    '🛀🏽' => 'човек во када: тип на кожа 4',
    '🛀🏾' => 'човек во када: тип на кожа 5',
    '🛀🏿' => 'човек во када: тип на кожа 6',
    '🛌🏻' => 'човек во кревет: тип на кожа 1–2',
    '🛌🏼' => 'човек во кревет: тип на кожа 3',
    '🛌🏽' => 'човек во кревет: тип на кожа 4',
    '🛌🏾' => 'човек во кревет: тип на кожа 5',
    '🛌🏿' => 'човек во кревет: тип на кожа 6',
    '👭🏻' => 'две жени се држат за рака: тип на кожа 1–2',
    '👭🏼' => 'две жени се држат за рака: тип на кожа 3',
    '👭🏽' => 'две жени се држат за рака: тип на кожа 4',
    '👭🏾' => 'две жени се држат за рака: тип на кожа 5',
    '👭🏿' => 'две жени се држат за рака: тип на кожа 6',
    '👫🏻' => 'маж и жена се држат за рака: тип на кожа 1–2',
    '👫🏼' => 'маж и жена се држат за рака: тип на кожа 3',
    '👫🏽' => 'маж и жена се држат за рака: тип на кожа 4',
    '👫🏾' => 'маж и жена се држат за рака: тип на кожа 5',
    '👫🏿' => 'маж и жена се држат за рака: тип на кожа 6',
    '👬🏻' => 'двајца мажи се држат за рака: тип на кожа 1–2',
    '👬🏼' => 'двајца мажи се држат за рака: тип на кожа 3',
    '👬🏽' => 'двајца мажи се држат за рака: тип на кожа 4',
    '👬🏾' => 'двајца мажи се држат за рака: тип на кожа 5',
    '👬🏿' => 'двајца мажи се држат за рака: тип на кожа 6',
    '💏🏻' => 'бакнеж: тип на кожа 1–2',
    '💏🏼' => 'бакнеж: тип на кожа 3',
    '💏🏽' => 'бакнеж: тип на кожа 4',
    '💏🏾' => 'бакнеж: тип на кожа 5',
    '💏🏿' => 'бакнеж: тип на кожа 6',
    '💑🏻' => 'пар со срце: тип на кожа 1–2',
    '💑🏼' => 'пар со срце: тип на кожа 3',
    '💑🏽' => 'пар со срце: тип на кожа 4',
    '💑🏾' => 'пар со срце: тип на кожа 5',
    '💑🏿' => 'пар со срце: тип на кожа 6',
    '🇦🇨' => 'знаме: Остров Асенсион',
    '🇦🇩' => 'знаме: Андора',
    '🇦🇪' => 'знаме: Обединети Арапски Емирати',
    '🇦🇫' => 'знаме: Авганистан',
    '🇦🇬' => 'знаме: Антига и Барбуда',
    '🇦🇮' => 'знаме: Ангвила',
    '🇦🇱' => 'знаме: Албанија',
    '🇦🇲' => 'знаме: Ерменија',
    '🇦🇴' => 'знаме: Ангола',
    '🇦🇶' => 'знаме: Антарктик',
    '🇦🇷' => 'знаме: Аргентина',
    '🇦🇸' => 'знаме: Американска Самоа',
    '🇦🇹' => 'знаме: Австрија',
    '🇦🇺' => 'знаме: Австралија',
    '🇦🇼' => 'знаме: Аруба',
    '🇦🇽' => 'знаме: Оландски Острови',
    '🇦🇿' => 'знаме: Азербејџан',
    '🇧🇦' => 'знаме: Босна и Херцеговина',
    '🇧🇧' => 'знаме: Барбадос',
    '🇧🇩' => 'знаме: Бангладеш',
    '🇧🇪' => 'знаме: Белгија',
    '🇧🇫' => 'знаме: Буркина Фасо',
    '🇧🇬' => 'знаме: Бугарија',
    '🇧🇭' => 'знаме: Бахреин',
    '🇧🇮' => 'знаме: Бурунди',
    '🇧🇯' => 'знаме: Бенин',
    '🇧🇱' => 'знаме: Свети Вартоломеј',
    '🇧🇲' => 'знаме: Бермуди',
    '🇧🇳' => 'знаме: Брунеј',
    '🇧🇴' => 'знаме: Боливија',
    '🇧🇶' => 'знаме: Карипска Холандија',
    '🇧🇷' => 'знаме: Бразил',
    '🇧🇸' => 'знаме: Бахами',
    '🇧🇹' => 'знаме: Бутан',
    '🇧🇻' => 'знаме: Остров Буве',
    '🇧🇼' => 'знаме: Боцвана',
    '🇧🇾' => 'знаме: Белорусија',
    '🇧🇿' => 'знаме: Белизе',
    '🇨🇦' => 'знаме: Канада',
    '🇨🇨' => 'знаме: Кокосови (Килиншки) Острови',
    '🇨🇩' => 'знаме: Конго - Киншаса',
    '🇨🇫' => 'знаме: Централноафриканска Република',
    '🇨🇬' => 'знаме: Конго - Бразавил',
    '🇨🇭' => 'знаме: Швајцарија',
    '🇨🇮' => 'знаме: Брегот на Слоновата Коска',
    '🇨🇰' => 'знаме: Кукови Острови',
    '🇨🇱' => 'знаме: Чиле',
    '🇨🇲' => 'знаме: Камерун',
    '🇨🇳' => 'знаме: Кина',
    '🇨🇴' => 'знаме: Колумбија',
    '🇨🇵' => 'знаме: Остров Клипертон',
    '🇨🇶' => 'знаме: Сарк',
    '🇨🇷' => 'знаме: Костарика',
    '🇨🇺' => 'знаме: Куба',
    '🇨🇻' => 'знаме: Кабо Верде',
    '🇨🇼' => 'знаме: Курасао',
    '🇨🇽' => 'знаме: Божиќен Остров',
    '🇨🇾' => 'знаме: Кипар',
    '🇨🇿' => 'знаме: Чешка',
    '🇩🇪' => 'знаме: Германија',
    '🇩🇬' => 'знаме: Диего Гарсија',
    '🇩🇯' => 'знаме: Џибути',
    '🇩🇰' => 'знаме: Данска',
    '🇩🇲' => 'знаме: Доминика',
    '🇩🇴' => 'знаме: Доминиканска Република',
    '🇩🇿' => 'знаме: Алжир',
    '🇪🇦' => 'знаме: Сеута и Мелиља',
    '🇪🇨' => 'знаме: Еквадор',
    '🇪🇪' => 'знаме: Естонија',
    '🇪🇬' => 'знаме: Египет',
    '🇪🇭' => 'знаме: Западна Сахара',
    '🇪🇷' => 'знаме: Еритреја',
    '🇪🇸' => 'знаме: Шпанија',
    '🇪🇹' => 'знаме: Етиопија',
    '🇪🇺' => 'знаме: Европска унија',
    '🇫🇮' => 'знаме: Финска',
    '🇫🇯' => 'знаме: Фиџи',
    '🇫🇰' => 'знаме: Фолкландски Острови',
    '🇫🇲' => 'знаме: Микронезија',
    '🇫🇴' => 'знаме: Фарски Острови',
    '🇫🇷' => 'знаме: Франција',
    '🇬🇦' => 'знаме: Габон',
    '🇬🇧' => 'знаме: Обединето Кралство',
    '🇬🇩' => 'знаме: Гренада',
    '🇬🇪' => 'знаме: Грузија',
    '🇬🇫' => 'знаме: Француска Гвајана',
    '🇬🇬' => 'знаме: Гернзи',
    '🇬🇭' => 'знаме: Гана',
    '🇬🇮' => 'знаме: Гибралтар',
    '🇬🇱' => 'знаме: Гренланд',
    '🇬🇲' => 'знаме: Гамбија',
    '🇬🇳' => 'знаме: Гвинеја',
    '🇬🇵' => 'знаме: Гвадалупе',
    '🇬🇶' => 'знаме: Екваторска Гвинеја',
    '🇬🇷' => 'знаме: Грција',
    '🇬🇸' => 'знаме: Јужна Џорџија и Јужни Сендвички Острови',
    '🇬🇹' => 'знаме: Гватемала',
    '🇬🇺' => 'знаме: Гуам',
    '🇬🇼' => 'знаме: Гвинеја Бисао',
    '🇬🇾' => 'знаме: Гвајана',
    '🇭🇰' => 'знаме: Хонгконг САР Кина',
    '🇭🇲' => 'знаме: Остров Херд и Острови Мекдоналд',
    '🇭🇳' => 'знаме: Хондурас',
    '🇭🇷' => 'знаме: Хрватска',
    '🇭🇹' => 'знаме: Хаити',
    '🇭🇺' => 'знаме: Унгарија',
    '🇮🇨' => 'знаме: Канарски Острови',
    '🇮🇩' => 'знаме: Индонезија',
    '🇮🇪' => 'знаме: Ирска',
    '🇮🇱' => 'знаме: Израел',
    '🇮🇲' => 'знаме: Остров Ман',
    '🇮🇳' => 'знаме: Индија',
    '🇮🇴' => 'знаме: Британска Индоокеанска Територија',
    '🇮🇶' => 'знаме: Ирак',
    '🇮🇷' => 'знаме: Иран',
    '🇮🇸' => 'знаме: Исланд',
    '🇮🇹' => 'знаме: Италија',
    '🇯🇪' => 'знаме: Џерси',
    '🇯🇲' => 'знаме: Јамајка',
    '🇯🇴' => 'знаме: Јордан',
    '🇯🇵' => 'знаме: Јапонија',
    '🇰🇪' => 'знаме: Кенија',
    '🇰🇬' => 'знаме: Киргистан',
    '🇰🇭' => 'знаме: Камбоџа',
    '🇰🇮' => 'знаме: Кирибати',
    '🇰🇲' => 'знаме: Коморски Острови',
    '🇰🇳' => 'знаме: Свети Китс и Невис',
    '🇰🇵' => 'знаме: Северна Кореја',
    '🇰🇷' => 'знаме: Јужна Кореја',
    '🇰🇼' => 'знаме: Кувајт',
    '🇰🇾' => 'знаме: Кајмански Острови',
    '🇰🇿' => 'знаме: Казахстан',
    '🇱🇦' => 'знаме: Лаос',
    '🇱🇧' => 'знаме: Либан',
    '🇱🇨' => 'знаме: Сент Лусија',
    '🇱🇮' => 'знаме: Лихтенштајн',
    '🇱🇰' => 'знаме: Шри Ланка',
    '🇱🇷' => 'знаме: Либерија',
    '🇱🇸' => 'знаме: Лесото',
    '🇱🇹' => 'знаме: Литванија',
    '🇱🇺' => 'знаме: Луксембург',
    '🇱🇻' => 'знаме: Латвија',
    '🇱🇾' => 'знаме: Либија',
    '🇲🇦' => 'знаме: Мароко',
    '🇲🇨' => 'знаме: Монако',
    '🇲🇩' => 'знаме: Молдавија',
    '🇲🇪' => 'знаме: Црна Гора',
    '🇲🇫' => 'знаме: Сент Мартин',
    '🇲🇬' => 'знаме: Мадагаскар',
    '🇲🇭' => 'знаме: Маршалски Острови',
    '🇲🇰' => 'знаме: Северна Македонија',
    '🇲🇱' => 'знаме: Мали',
    '🇲🇲' => 'знаме: Мјанмар (Бурма)',
    '🇲🇳' => 'знаме: Монголија',
    '🇲🇴' => 'знаме: Макао САР',
    '🇲🇵' => 'знаме: Северни Маријански Острови',
    '🇲🇶' => 'знаме: Мартиник',
    '🇲🇷' => 'знаме: Мавританија',
    '🇲🇸' => 'знаме: Монсерат',
    '🇲🇹' => 'знаме: Малта',
    '🇲🇺' => 'знаме: Маврициус',
    '🇲🇻' => 'знаме: Малдиви',
    '🇲🇼' => 'знаме: Малави',
    '🇲🇽' => 'знаме: Мексико',
    '🇲🇾' => 'знаме: Малезија',
    '🇲🇿' => 'знаме: Мозамбик',
    '🇳🇦' => 'знаме: Намибија',
    '🇳🇨' => 'знаме: Нова Каледонија',
    '🇳🇪' => 'знаме: Нигер',
    '🇳🇫' => 'знаме: Норфолшки Остров',
    '🇳🇬' => 'знаме: Нигерија',
    '🇳🇮' => 'знаме: Никарагва',
    '🇳🇱' => 'знаме: Холандија',
    '🇳🇴' => 'знаме: Норвешка',
    '🇳🇵' => 'знаме: Непал',
    '🇳🇷' => 'знаме: Науру',
    '🇳🇺' => 'знаме: Ниује',
    '🇳🇿' => 'знаме: Нов Зеланд',
    '🇴🇲' => 'знаме: Оман',
    '🇵🇦' => 'знаме: Панама',
    '🇵🇪' => 'знаме: Перу',
    '🇵🇫' => 'знаме: Француска Полинезија',
    '🇵🇬' => 'знаме: Папуа Нова Гвинеја',
    '🇵🇭' => 'знаме: Филипини',
    '🇵🇰' => 'знаме: Пакистан',
    '🇵🇱' => 'знаме: Полска',
    '🇵🇲' => 'знаме: Сент Пјер и Микелан',
    '🇵🇳' => 'знаме: Питкернски Острови',
    '🇵🇷' => 'знаме: Порторико',
    '🇵🇸' => 'знаме: Палестински Територии',
    '🇵🇹' => 'знаме: Португалија',
    '🇵🇼' => 'знаме: Палау',
    '🇵🇾' => 'знаме: Парагвај',
    '🇶🇦' => 'знаме: Катар',
    '🇷🇪' => 'знаме: Рејунион',
    '🇷🇴' => 'знаме: Романија',
    '🇷🇸' => 'знаме: Србија',
    '🇷🇺' => 'знаме: Русија',
    '🇷🇼' => 'знаме: Руанда',
    '🇸🇦' => 'знаме: Саудиска Арабија',
    '🇸🇧' => 'знаме: Соломонски Острови',
    '🇸🇨' => 'знаме: Сејшели',
    '🇸🇩' => 'знаме: Судан',
    '🇸🇪' => 'знаме: Шведска',
    '🇸🇬' => 'знаме: Сингапур',
    '🇸🇭' => 'знаме: Света Елена',
    '🇸🇮' => 'знаме: Словенија',
    '🇸🇯' => 'знаме: Свалбард и Јан Мајен',
    '🇸🇰' => 'знаме: Словачка',
    '🇸🇱' => 'знаме: Сиера Леоне',
    '🇸🇲' => 'знаме: Сан Марино',
    '🇸🇳' => 'знаме: Сенегал',
    '🇸🇴' => 'знаме: Сомалија',
    '🇸🇷' => 'знаме: Суринам',
    '🇸🇸' => 'знаме: Јужен Судан',
    '🇸🇹' => 'знаме: Саун Томе и Принсип',
    '🇸🇻' => 'знаме: Ел Салвадор',
    '🇸🇽' => 'знаме: Свети Мартин',
    '🇸🇾' => 'знаме: Сирија',
    '🇸🇿' => 'знаме: Есватини',
    '🇹🇦' => 'знаме: Тристан да Куња',
    '🇹🇨' => 'знаме: Острови Туркс и Каикос',
    '🇹🇩' => 'знаме: Чад',
    '🇹🇫' => 'знаме: Француски Јужни Територии',
    '🇹🇬' => 'знаме: Того',
    '🇹🇭' => 'знаме: Тајланд',
    '🇹🇯' => 'знаме: Таџикистан',
    '🇹🇰' => 'знаме: Токелау',
    '🇹🇱' => 'знаме: Тимор Лесте',
    '🇹🇲' => 'знаме: Туркменистан',
    '🇹🇳' => 'знаме: Тунис',
    '🇹🇴' => 'знаме: Тонга',
    '🇹🇷' => 'знаме: Турција',
    '🇹🇹' => 'знаме: Тринидад и Тобаго',
    '🇹🇻' => 'знаме: Тувалу',
    '🇹🇼' => 'знаме: Тајван',
    '🇹🇿' => 'знаме: Танзанија',
    '🇺🇦' => 'знаме: Украина',
    '🇺🇬' => 'знаме: Уганда',
    '🇺🇲' => 'знаме: Американски територии во Пацификот',
    '🇺🇳' => 'знаме: Обединети нации',
    '🇺🇸' => 'знаме: Соединети Американски Држави',
    '🇺🇾' => 'знаме: Уругвај',
    '🇺🇿' => 'знаме: Узбекистан',
    '🇻🇦' => 'знаме: Ватикан',
    '🇻🇨' => 'знаме: Сент Винсент и Гренадини',
    '🇻🇪' => 'знаме: Венецуела',
    '🇻🇬' => 'знаме: Британски Девствени Острови',
    '🇻🇮' => 'знаме: Американски Девствени Острови',
    '🇻🇳' => 'знаме: Виетнам',
    '🇻🇺' => 'знаме: Вануату',
    '🇼🇫' => 'знаме: Валис и Футуна',
    '🇼🇸' => 'знаме: Самоа',
    '🇽🇰' => 'знаме: Косово',
    '🇾🇪' => 'знаме: Јемен',
    '🇾🇹' => 'знаме: Мајот',
    '🇿🇦' => 'знаме: Јужноафриканска Република',
    '🇿🇲' => 'знаме: Замбија',
    '🇿🇼' => 'знаме: Зимбабве',
    '🔟' => 'копче: 10',
    '🏻' => 'тип на кожа 1–2',
    '🏼' => 'тип на кожа 3',
    '🏽' => 'тип на кожа 4',
    '🏾' => 'тип на кожа 5',
    '🏿' => 'тип на кожа 6',
    '😀' => 'широко насмеано лице',
    '😃' => 'насмеано лице со големи очи',
    '😄' => 'лице со отворена уста и насмеани очи',
    '😁' => 'широко насмеано лице со насмеани очи',
    '😆' => 'лице со отворена уста и затворени очи',
    '😅' => 'насмеано лице со отворена уста и пот',
    '🤣' => 'превртување од смеење',
    '😂' => 'лице со солзи радосници',
    '🙂' => 'лице со блага насмевка',
    '🙃' => 'превртено лице',
    '🫠' => 'лице што се топи',
    '😉' => 'лице што намигнува',
    '😊' => 'насмеано лице со насмеани очи',
    '😇' => 'насмеано лице со ореол',
    '🥰' => 'насмеано лице со срца',
    '😍' => 'насмеано лице со очи во облик на срца',
    '🤩' => 'лице здогледува славна личност',
    '😘' => 'лице што испраќа бакнеж',
    '😗' => 'лице што бакнува',
    '☺' => 'насмеано лице',
    '😚' => 'лице што бакнува со затворени очи',
    '😙' => 'лице што бакнува со насмеани очи',
    '🥲' => 'насмеано лице со солза',
    '😋' => 'лице што ужива во вкусна храна',
    '😛' => 'лице со исплазен јазик',
    '😜' => 'лице со исплазен јазик и намигнато око',
    '🤪' => 'лудо лице',
    '😝' => 'лице со исплазен јазик и затворени очи',
    '🤑' => 'лице со пари на устата',
    '🤗' => 'лице што гушка',
    '🤭' => 'лице со дланка преку устата',
    '🫢' => 'лице со отворени очи и рака на уста',
    '🫣' => 'лице со око што ѕирка',
    '🤫' => 'лице прави „шшш“',
    '🤔' => 'лице што размислува',
    '🫡' => 'лице што отпоздравува',
    '🤐' => 'лице со закопчана уста',
    '🤨' => 'лице со крената веѓа',
    '😐' => 'рамнодушно лице',
    '😑' => 'лице без никаков израз',
    '😶' => 'лице без уста',
    '🫥' => 'лице од испрекината линија',
    '😏' => 'лице со подбивна насмевка',
    '😒' => 'незаинтересирано лице',
    '🙄' => 'лице што превртува очи',
    '😬' => 'лице со гримаса',
    '🤥' => 'лажење',
    '🫨' => 'лице што се тресе',
    '😌' => 'лице со олеснување',
    '😔' => 'замислено лице',
    '😪' => 'поспано лице',
    '🤤' => 'лигавење',
    '😴' => 'заспано лице',
    '🫩' => 'лице со подочници',
    '😷' => 'лице со медицинска маска',
    '🤒' => 'лице со термометар',
    '🤕' => 'лице со преврска на главата',
    '🤢' => 'мачнина',
    '🤮' => 'лице повраќа',
    '🤧' => 'кивање',
    '🥵' => 'лице зацрвенето од жештина',
    '🥶' => 'замрзнато лице',
    '🥴' => 'пијано лице',
    '😵' => 'зашеметено лице',
    '🤯' => 'експлодирачка глава',
    '🤠' => 'каубој',
    '🥳' => 'лице што се забавува',
    '🥸' => 'лице со маска',
    '😎' => 'насмеано лице со очила за сонце',
    '🤓' => 'лице на бубалица',
    '🧐' => 'лице со монокл',
    '😕' => 'збунето лице',
    '🫤' => 'лице со дијагонална уста',
    '😟' => 'загрижено лице',
    '🙁' => 'малку намуртено лице',
    '☹' => 'намуртено лице',
    '😮' => 'лице со отворена уста',
    '😯' => 'замолчено лице',
    '😲' => 'вчудовидено лице',
    '😳' => 'вцрвенето лице',
    '🫪' => 'изобличено лице',
    '🥺' => 'лице што моли',
    '🥹' => 'лице спремно да заплаче',
    '😦' => 'намуртено лице со отворена уста',
    '😧' => 'лице во очај',
    '😨' => 'лице во страв',
    '😰' => 'лице со отворена уста и капка пот',
    '😥' => 'разочарано, но лице со олеснување',
    '😢' => 'расплакано лице',
    '😭' => 'гласно расплакано лице',
    '😱' => 'лице кое вреска од страв',
    '😖' => 'збркано лице',
    '😣' => 'издржливо лице',
    '😞' => 'разочарано лице',
    '😓' => 'лице со капка пот',
    '😩' => 'исцрпено лице',
    '😫' => 'уморно лице',
    '🥱' => 'лице што се проѕева',
    '😤' => 'лице на кое му чади од носот',
    '😡' => 'лице зацрвенето од лутина',
    '😠' => 'налутено лице',
    '🤬' => 'лице со симболи на устата',
    '😈' => 'насмеано лице со рогови',
    '👿' => 'ѓаволче',
    '💀' => 'череп',
    '☠' => 'череп и вкрстени коски',
    '💩' => 'куп измет',
    '🤡' => 'кловн',
    '👹' => 'џиновско чудовиште',
    '👺' => 'гоблин',
    '👻' => 'дух',
    '👽' => 'вонземјанин',
    '👾' => 'вонземно чудовиште',
    '🤖' => 'робот',
    '😺' => 'насмеано лице на мачка со отворена уста',
    '😸' => 'широко насмеана мачка со насмеани очи',
    '😹' => 'лице на мачка со солзи радосници',
    '😻' => 'насмеана мачка со очи како срца',
    '😼' => 'мачка со иронична насмевка',
    '😽' => 'мачка бакнува со затворени очи',
    '🙀' => 'уморна мачка',
    '😿' => 'расплакана мачка',
    '😾' => 'намуртена мачка',
    '🙈' => 'мајмун со покриени очи',
    '🙉' => 'мајмун со покриени уши',
    '🙊' => 'мајмун со покриена уста',
    '💌' => 'љубовно писмо',
    '💘' => 'срце прободено со стрела',
    '💝' => 'срце со панделка',
    '💖' => 'светкаво срце',
    '💗' => 'срце што расте',
    '💓' => 'срце што чука',
    '💞' => 'ротирачки срца',
    '💕' => 'две срца',
    '💟' => 'украс со срце',
    '❣' => 'извичник во вид на срце',
    '💔' => 'скршено срце',
    '❤' => 'црвено срце',
    '🩷' => 'розово срце',
    '🧡' => 'портокалово срце',
    '💛' => 'жолто срце',
    '💚' => 'зелено срце',
    '💙' => 'сино срце',
    '🩵' => 'светлосино срце',
    '💜' => 'виолетово срце',
    '🤎' => 'кафеаво срце',
    '🖤' => 'црно срце',
    '🩶' => 'сиво срце',
    '🤍' => 'бело срце',
    '💋' => 'бакнеж со кармин',
    '💯' => 'сто поени',
    '💢' => 'лутина',
    '🫯' => 'борба во облак',
    '💥' => 'судир',
    '💫' => 'вртоглавица',
    '💦' => 'капки пот',
    '💨' => 'брзање',
    '🕳' => 'дупка',
    '💬' => 'балон за говор',
    '🗨' => 'лев балон за говор',
    '🗯' => 'десен балон за лутина',
    '💭' => 'балон за размислување',
    '💤' => 'ззз',
    '👋' => 'мавтање со рака',
    '🤚' => 'подигната дланка',
    '🖐' => 'крената рака со раширени прсти',
    '✋' => 'крената рака',
    '🖖' => 'вулкански поздрав',
    '🫱' => 'рака на десно',
    '🫲' => 'рака на лево',
    '🫳' => 'рака со дланката надолу',
    '🫴' => 'рака со дланката нагоре',
    '🫷' => 'дланка турка налево',
    '🫸' => 'дланка турка надесно',
    '👌' => 'рака што се согласува',
    '🤌' => 'стиснати прсти',
    '🤏' => 'дланка што штипе',
    '✌' => 'рака покажува победа',
    '🤞' => 'стискање палци',
    '🫰' => 'рака со вкрстени палец и показалец',
    '🤟' => 'знак „те сакам“',
    '🤘' => 'рака што покажува рогови',
    '🤙' => 'јави ми се',
    '👈' => 'показалец свртен налево',
    '👉' => 'показалец свртен надесно',
    '👆' => 'показалец свртен нагоре',
    '🖕' => 'среден прст',
    '👇' => 'показалец свртен надолу',
    '☝' => 'показалец нагоре',
    '🫵' => 'показалец покажува кон гледачот',
    '👍' => 'палец нагоре',
    '👎' => 'палец надолу',
    '✊' => 'крената тупаница',
    '👊' => 'тупаница што се приближува',
    '🤛' => 'лева тупаница',
    '🤜' => 'десна тупаница',
    '👏' => 'аплауз',
    '🙌' => 'кренати дланки',
    '🫶' => 'срце од раце',
    '👐' => 'отворени дланки',
    '🤲' => 'дланки една до друга',
    '🤝' => 'ракување',
    '🙏' => 'споени дланки',
    '✍' => 'рака што пишува',
    '💅' => 'лак за нокти',
    '🤳' => 'селфи',
    '💪' => 'покажува бицепс',
    '🦾' => 'механичка рака',
    '🦿' => 'механичка нога',
    '🦵' => 'нога',
    '🦶' => 'стапало',
    '👂' => 'уво',
    '🦻' => 'уво со апарат за слушање',
    '👃' => 'нос',
    '🧠' => 'мозок',
    '🫀' => 'срцев орган',
    '🫁' => 'бели дробови',
    '🦷' => 'заб',
    '🦴' => 'коска',
    '👀' => 'очи',
    '👁' => 'око',
    '👅' => 'јазик',
    '👄' => 'уста',
    '🫦' => 'гризната усна',
    '👶' => 'бебе',
    '🧒' => 'дете',
    '👦' => 'момче',
    '👧' => 'девојче',
    '🧑' => 'возрасно лице',
    '👱' => 'русокосо лице',
    '👨' => 'маж',
    '🧔' => 'забраден човек',
    '👩' => 'жена',
    '🧓' => 'постаро возрасно лице',
    '👴' => 'старец',
    '👵' => 'старица',
    '🙍' => 'намуртен човек',
    '🙎' => 'налутен човек',
    '🙅' => 'човек што неодобрува',
    '🙆' => 'човек што одобрува',
    '💁' => 'лице со феминизиран гест',
    '🙋' => 'лице со подигната рака',
    '🧏' => 'глуво лице',
    '🙇' => 'човек кој се поклонува',
    '🤦' => 'неверување',
    '🤷' => 'кревање раменици',
    '👮' => 'полициски службеник',
    '🕵' => 'детектив(ка)',
    '💂' => 'гардист(ка)',
    '🥷' => 'нинџа',
    '👷' => 'градежен работник',
    '🫅' => 'лице со круна',
    '🤴' => 'принц',
    '👸' => 'принцеза',
    '👳' => 'лице со турбан',
    '👲' => 'маж со кинеска капа',
    '🧕' => 'жена со шамија',
    '🤵' => 'човек во смокинг',
    '👰' => 'човек со превез',
    '🤰' => 'трудница',
    '🫃' => 'труден маж',
    '🫄' => 'трудно лице',
    '🤱' => 'доење',
    '👼' => 'бебе ангел',
    '🎅' => 'дедо мраз',
    '🤶' => 'баба мразица',
    '🦸' => 'суперхерој',
    '🦹' => 'супер-негативец',
    '🧙' => 'магичар',
    '🧚' => 'самовила',
    '🧛' => 'вампир',
    '🧜' => 'морско лице',
    '🧝' => 'шумски елф',
    '🧞' => 'џини',
    '🧟' => 'зомби',
    '🧌' => 'трол',
    '🫈' => 'влакнесто суштество',
    '💆' => 'масажа на лице',
    '💇' => 'потстрижување',
    '🚶' => 'лице пешачи',
    '🧍' => 'лице кое стои',
    '🧎' => 'лице кое клечи',
    '🏃' => 'лице трча',
    '💃' => 'танчарка',
    '🕺' => 'танчар',
    '🕴' => 'лебдечки човек во деловен костум',
    '👯' => 'лица кои се забавуваат',
    '🧖' => 'лице во парна соба',
    '🧗' => 'лице планинари',
    '🤺' => 'мечувач',
    '🏇' => 'трка со коњи',
    '⛷' => 'скијач',
    '🏂' => 'скијање на штица',
    '🏌' => 'играч на голф',
    '🏄' => 'лице кое сурфа',
    '🚣' => 'веслање чамец',
    '🏊' => 'лице кое плива',
    '⛹' => 'човек со топка',
    '🏋' => 'кревање тегови',
    '🚴' => 'лице кое вози велосипед',
    '🚵' => 'лице кое вози планински велосипед',
    '🤸' => 'лице прави ѕвезда',
    '🤼' => 'лица кои се борат',
    '🤽' => 'ватерполо',
    '🤾' => 'ракомет',
    '🤹' => 'жонглирање',
    '🧘' => 'лице во положба лотос',
    '🛀' => 'човек во када',
    '🛌' => 'човек во кревет',
    '👭' => 'две жени се држат за рака',
    '👫' => 'маж и жена се држат за рака',
    '👬' => 'двајца мажи се држат за рака',
    '💏' => 'бакнеж',
    '💑' => 'пар со срце',
    '🗣' => 'глава што зборува',
    '👤' => 'силуета на биста',
    '👥' => 'силуета на бисти',
    '🫂' => 'луѓе се гушкаат',
    '👪' => 'семејство',
    '👣' => 'отпечатоци од стапала',
    '🫆' => 'отпечаток',
    '🦰' => 'црвена коса',
    '🦱' => 'кадрава коса',
    '🦳' => 'бела коса',
    '🦲' => 'ќелав',
    '🐵' => 'глава на мајмун',
    '🐒' => 'мајмун',
    '🦍' => 'горила',
    '🦧' => 'орангутан',
    '🐶' => 'глава на куче',
    '🐕' => 'куче',
    '🦮' => 'куче за водење',
    '🐩' => 'пудлица',
    '🐺' => 'волк',
    '🦊' => 'лисица',
    '🦝' => 'ракун',
    '🐱' => 'глава на мачка',
    '🐈' => 'мачка',
    '🦁' => 'лав',
    '🐯' => 'глава на тигар',
    '🐅' => 'тигар',
    '🐆' => 'леопард',
    '🐴' => 'глава на коњ',
    '🫎' => 'лос',
    '🫏' => 'магаре',
    '🐎' => 'коњ',
    '🦄' => 'еднорог',
    '🦓' => 'зебра',
    '🦌' => 'елен',
    '🦬' => 'бизон',
    '🐮' => 'глава на крава',
    '🐂' => 'вол',
    '🐃' => 'бивол',
    '🐄' => 'крава',
    '🐷' => 'глава на прасе',
    '🐖' => 'прасе',
    '🐗' => 'дива свиња',
    '🐽' => 'нос на прасе',
    '🐏' => 'овен',
    '🐑' => 'овца',
    '🐐' => 'коза',
    '🐪' => 'камила',
    '🐫' => 'двогрба камила',
    '🦙' => 'лама',
    '🦒' => 'жирафа',
    '🐘' => 'слон',
    '🦣' => 'мамут',
    '🦏' => 'носорог',
    '🦛' => 'нилски коњ',
    '🐭' => 'глава на глушец',
    '🐁' => 'глушец',
    '🐀' => 'стаорец',
    '🐹' => '‘рчко',
    '🐰' => 'глава на зајак',
    '🐇' => 'зајак',
    '🐿' => 'верверица',
    '🦫' => 'дабар',
    '🦔' => 'еж',
    '🦇' => 'лилјак',
    '🐻' => 'мечка',
    '🐨' => 'коала',
    '🐼' => 'панда',
    '🦥' => 'мрзливец',
    '🦦' => 'видра',
    '🦨' => 'твор',
    '🦘' => 'кенгур',
    '🦡' => 'јазовец',
    '🐾' => 'отпечатоци од шепи',
    '🦃' => 'мисирка',
    '🐔' => 'кокошка',
    '🐓' => 'петел',
    '🐣' => 'испилено пиле',
    '🐤' => 'пиле',
    '🐥' => 'пиле свртено нанапред',
    '🐦' => 'птица',
    '🐧' => 'пингвин',
    '🕊' => 'гулабица',
    '🦅' => 'орел',
    '🦆' => 'патка',
    '🦢' => 'лебед',
    '🦉' => 'був',
    '🦤' => 'додо',
    '🪶' => 'пердув',
    '🦩' => 'фламинго',
    '🦚' => 'паун',
    '🦜' => 'папагал',
    '🪽' => 'крило',
    '🪿' => 'гуска',
    '🐸' => 'жаба',
    '🐊' => 'крокодил',
    '🐢' => 'желка',
    '🦎' => 'гуштер',
    '🐍' => 'змија',
    '🐲' => 'глава на змеј',
    '🐉' => 'змеј',
    '🦕' => 'сауропод',
    '🦖' => 'Т-рекс',
    '🐳' => 'кит што прска вода',
    '🐋' => 'кит',
    '🐬' => 'делфин',
    '🫍' => 'орка',
    '🦭' => 'фока',
    '🐟' => 'риба',
    '🐠' => 'тропска риба',
    '🐡' => 'риба со боцки',
    '🦈' => 'ајкула',
    '🐙' => 'октопод',
    '🐚' => 'спирална школка',
    '🪸' => 'корал',
    '🪼' => 'медуза',
    '🦀' => 'рак',
    '🦞' => 'јастог',
    '🦐' => 'ракче',
    '🦑' => 'лигња',
    '🦪' => 'острига',
    '🐌' => 'полжав',
    '🦋' => 'пеперутка',
    '🐛' => 'бубачка',
    '🐜' => 'мравка',
    '🐝' => 'пчела',
    '🪲' => 'бумбар',
    '🐞' => 'бубамара',
    '🦗' => 'штурец',
    '🪳' => 'лебарка',
    '🕷' => 'пајак',
    '🕸' => 'пајакова мрежа',
    '🦂' => 'скорпија',
    '🦟' => 'комарец',
    '🪰' => 'мува',
    '🪱' => 'црв',
    '🦠' => 'микроба',
    '💐' => 'букет',
    '🌸' => 'црешов цвет',
    '💮' => 'бел цвет',
    '🪷' => 'лотос',
    '🏵' => 'розета',
    '🌹' => 'роза',
    '🥀' => 'овенато цвеќе',
    '🌺' => 'хибискус',
    '🌻' => 'сончоглед',
    '🌼' => 'цут',
    '🌷' => 'лале',
    '🪻' => 'зумбул',
    '🌱' => 'садница',
    '🪴' => 'растение во саксија',
    '🌲' => 'зимзелено дрво',
    '🌳' => 'листопадно дрво',
    '🌴' => 'палма',
    '🌵' => 'кактус',
    '🌾' => 'сноп ориз',
    '🌿' => 'билка',
    '☘' => 'детелина',
    '🍀' => 'детелина со четири листа',
    '🍁' => 'јаворов лист',
    '🍂' => 'паднат лист',
    '🍃' => 'лист што се вее на ветрот',
    '🪹' => 'празно гнездо',
    '🪺' => 'гнездо со јајца',
    '🍄' => 'печурка',
    '🪾' => 'безлисно дрво',
    '🍇' => 'грозје',
    '🍈' => 'диња',
    '🍉' => 'лубеница',
    '🍊' => 'мандарина',
    '🍋' => 'лимон',
    '🍌' => 'банана',
    '🍍' => 'ананас',
    '🥭' => 'манго',
    '🍎' => 'црвено јаболко',
    '🍏' => 'зелено јаболко',
    '🍐' => 'круша',
    '🍑' => 'праска',
    '🍒' => 'цреши',
    '🍓' => 'јагода',
    '🫐' => 'боровинки',
    '🥝' => 'киви',
    '🍅' => 'домат',
    '🫒' => 'маслинка',
    '🥥' => 'кокосов орев',
    '🥑' => 'авокадо',
    '🍆' => 'модар патлиџан',
    '🥔' => 'компир',
    '🥕' => 'морков',
    '🌽' => 'клас пченка',
    '🌶' => 'лута пиперка',
    '🫑' => 'бабура',
    '🥒' => 'краставица',
    '🥬' => 'зелени листови',
    '🥦' => 'брокола',
    '🧄' => 'лук',
    '🧅' => 'кромид',
    '🥜' => 'кикиритки',
    '🫘' => 'грав',
    '🌰' => 'костен',
    '🫚' => 'корен од ѓумбир',
    '🫛' => 'мешунка',
    '🫜' => 'коренест зеленчук',
    '🍞' => 'леб',
    '🥐' => 'кроасан',
    '🥖' => 'багет',
    '🫓' => 'гиро-пита',
    '🥨' => 'перек',
    '🥯' => 'ѓеврек',
    '🥞' => 'палачинки',
    '🧇' => 'вафла',
    '🧀' => 'парче сирење',
    '🍖' => 'месо со коска',
    '🍗' => 'копан',
    '🥩' => 'парче месо',
    '🥓' => 'сланина',
    '🍔' => 'хамбургер',
    '🍟' => 'помфрит',
    '🍕' => 'пица',
    '🌭' => 'хот дог',
    '🥪' => 'сендвич',
    '🌮' => 'тако',
    '🌯' => 'бурито',
    '🫔' => 'тамале',
    '🥙' => 'гиро',
    '🧆' => 'фалафел',
    '🥚' => 'јајце',
    '🍳' => 'готвење',
    '🥘' => 'тавче со храна',
    '🍲' => 'лонец со храна',
    '🫕' => 'топено сирење',
    '🥣' => 'сад со лажица',
    '🥗' => 'зелена салата',
    '🍿' => 'пуканки',
    '🧈' => 'путер',
    '🧂' => 'сол',
    '🥫' => 'конзервирана храна',
    '🍱' => 'јапонска храна за носење',
    '🍘' => 'колачи од ориз',
    '🍙' => 'топки од ориз',
    '🍚' => 'варен ориз',
    '🍛' => 'ориз со кари',
    '🍜' => 'длабока чинија со жешка храна',
    '🍝' => 'шпагети',
    '🍠' => 'печен сладок компир',
    '🍢' => 'јапонски ражен',
    '🍣' => 'суши',
    '🍤' => 'пржено ракче',
    '🍥' => 'спирално колаче со риба',
    '🥮' => 'месечев колач',
    '🍡' => 'јапонски слатки кнедли',
    '🥟' => 'кнедла',
    '🥠' => 'колаче на среќата',
    '🥡' => 'кутија за храна за носење',
    '🍦' => 'сладолед на точење',
    '🍧' => 'сладолед од мраз',
    '🍨' => 'сладолед',
    '🍩' => 'крофна',
    '🍪' => 'колаче',
    '🎂' => 'роденденска торта',
    '🍰' => 'овошна торта',
    '🧁' => 'тортичка',
    '🥧' => 'пита',
    '🍫' => 'чоколадо',
    '🍬' => 'бонбона',
    '🍭' => 'лижалче',
    '🍮' => 'пудинг',
    '🍯' => 'грне со мед',
    '🍼' => 'шише за бебе',
    '🥛' => 'чаша млеко',
    '☕' => 'топол напиток',
    '🫖' => 'чајник',
    '🍵' => 'чаша за чај без рачка',
    '🍶' => 'саке',
    '🍾' => 'шише шампањ',
    '🍷' => 'чаша за вино',
    '🍸' => 'чаша за коктел',
    '🍹' => 'тропски пијалак',
    '🍺' => 'кригла пиво',
    '🍻' => 'наздравување со кригли пиво',
    '🥂' => 'здравица',
    '🥃' => 'жесток пијалак',
    '🫗' => 'истурање течност',
    '🥤' => 'чаша со сламка',
    '🧋' => 'чај со топчиња',
    '🧃' => 'сокче во тетрапак',
    '🧉' => 'мате',
    '🧊' => 'коцка мраз',
    '🥢' => 'стапчиња за јадење',
    '🍽' => 'виљушка и нож со чинија',
    '🍴' => 'виљушка и нож',
    '🥄' => 'лажица',
    '🔪' => 'кујнски нож',
    '🫙' => 'тегла',
    '🏺' => 'амфора',
    '🌍' => 'глобус што ги покажува Европа и Африка',
    '🌎' => 'глобус со Јужна и Северна Америка',
    '🌏' => 'глобус со Азија и Австралија',
    '🌐' => 'глобус со меридијаните',
    '🗺' => 'карта на светот',
    '🗾' => 'карта на Јапонија',
    '🧭' => 'компас',
    '🏔' => 'планина со снежен врв',
    '⛰' => 'планина',
    '🛘' => 'одрон',
    '🌋' => 'вулкан',
    '🗻' => 'планината Фуџи',
    '🏕' => 'кампување',
    '🏖' => 'плажа со чадор за сонце',
    '🏜' => 'пустина',
    '🏝' => 'пуст остров',
    '🏞' => 'национален парк',
    '🏟' => 'стадион',
    '🏛' => 'класична зграда',
    '🏗' => 'градежен објект',
    '🧱' => 'тула',
    '🪨' => 'камен',
    '🪵' => 'дрво',
    '🛖' => 'колиба',
    '🏘' => 'куќи',
    '🏚' => 'напуштена куќа',
    '🏠' => 'куќа',
    '🏡' => 'куќа со градина',
    '🏢' => 'деловна зграда',
    '🏣' => 'јапонска пошта',
    '🏤' => 'пошта',
    '🏥' => 'болница',
    '🏦' => 'банка',
    '🏨' => 'хотел',
    '🏩' => 'љубовен хотел',
    '🏪' => 'минимаркет',
    '🏫' => 'училиште',
    '🏬' => 'стоковна куќа',
    '🏭' => 'фабрика',
    '🏯' => 'јапонски замок',
    '🏰' => 'замок',
    '💒' => 'свадба',
    '🗼' => 'токиската кула',
    '🗽' => 'статуата на слободата',
    '⛪' => 'црква',
    '🕌' => 'џамија',
    '🛕' => 'хиндуски храм',
    '🕍' => 'синагога',
    '⛩' => 'шинтоистички храм',
    '🕋' => 'ќаба',
    '⛲' => 'фонтана',
    '⛺' => 'шатор',
    '🌁' => 'магливо',
    '🌃' => 'ноќ со ѕвезди',
    '🏙' => 'градски пејзаж',
    '🌄' => 'изгрејсонце над планините',
    '🌅' => 'изгрејсонце',
    '🌆' => 'градски пејзаж во приквечерина',
    '🌇' => 'зајдисонце',
    '🌉' => 'мост навечер',
    '♨' => 'извори на топла вода',
    '🎠' => 'коњче од вртелешка',
    '🛝' => 'лизгалка за деца',
    '🎡' => 'панорамско тркало',
    '🎢' => 'тобоган',
    '💈' => 'столб пред берберница',
    '🎪' => 'циркуски шатор',
    '🚂' => 'локомотива',
    '🚃' => 'вагон',
    '🚄' => 'брз воз',
    '🚅' => 'воз-куршум',
    '🚆' => 'воз',
    '🚇' => 'метро',
    '🚈' => 'лесна железница',
    '🚉' => 'станица',
    '🚊' => 'трамвај',
    '🚝' => 'едношинска железница',
    '🚞' => 'планинска железница',
    '🚋' => 'вагон на трамвај',
    '🚌' => 'автобус',
    '🚍' => 'автобус што пристигнува',
    '🚎' => 'тролејбус',
    '🚐' => 'минибус',
    '🚑' => 'амбуланта',
    '🚒' => 'противпожарно возило',
    '🚓' => 'полициски автомобил',
    '🚔' => 'полициски автомобил што пристигнува',
    '🚕' => 'такси',
    '🚖' => 'такси што пристигнува',
    '🚗' => 'автомобил',
    '🚘' => 'автомобил што пристигнува',
    '🚙' => 'кампинг возила',
    '🛻' => 'камионет',
    '🚚' => 'камион за испорака',
    '🚛' => 'шлепер',
    '🚜' => 'трактор',
    '🏎' => 'тркачки автомобил',
    '🏍' => 'мотор',
    '🛵' => 'скутер',
    '🦽' => 'инвалидска количка на рачен погон',
    '🦼' => 'инвалидска количка на моторен погон',
    '🛺' => 'моторизирана рикша',
    '🚲' => 'велосипед',
    '🛴' => 'тротинет',
    '🛹' => 'скејтборд',
    '🛼' => 'ролшуи',
    '🚏' => 'автобуска постојка',
    '🛣' => 'автопат',
    '🛤' => 'железничка пруга',
    '🛢' => 'буре за нафта',
    '⛽' => 'бензинска пумпа',
    '🛞' => 'тркало',
    '🚨' => 'светло на полициски автомобил',
    '🚥' => 'хоризонтален семафор',
    '🚦' => 'вертикален семафор',
    '🛑' => 'стоп',
    '🚧' => 'градежни работи на патот',
    '⚓' => 'сидро',
    '🛟' => 'гума за спасување',
    '⛵' => 'едреник',
    '🛶' => 'кајак',
    '🚤' => 'глисер',
    '🛳' => 'патнички брод',
    '⛴' => 'траект',
    '🛥' => 'моторен чамец',
    '🚢' => 'брод',
    '✈' => 'авион',
    '🛩' => 'мал авион',
    '🛫' => 'полетување',
    '🛬' => 'слетување',
    '🪂' => 'падобран',
    '💺' => 'столица',
    '🚁' => 'хеликоптер',
    '🚟' => 'висечка железница',
    '🚠' => 'планинска жичарница',
    '🚡' => 'воздушен трамвај',
    '🛰' => 'сателит',
    '🚀' => 'ракета',
    '🛸' => 'летечка чинија',
    '🛎' => 'ѕвонче на рецепција',
    '🧳' => 'багаж',
    '⌛' => 'песочен часовник',
    '⏳' => 'превртен песочен часовник',
    '⌚' => 'рачен часовник',
    '⏰' => 'часовник со аларм',
    '⏱' => 'штоперица',
    '⏲' => 'тајмер',
    '🕰' => 'часовник над каминот',
    '🕛' => 'дванаесет часот',
    '🕧' => 'дванаесет и пол',
    '🕐' => 'еден часот',
    '🕜' => 'еден и пол',
    '🕑' => 'два часот',
    '🕝' => 'два и пол',
    '🕒' => 'три часот',
    '🕞' => 'три и пол',
    '🕓' => 'четири часот',
    '🕟' => 'четири и пол',
    '🕔' => 'пет часот',
    '🕠' => 'пет и пол',
    '🕕' => 'шест часот',
    '🕡' => 'шест и пол',
    '🕖' => 'седум часот',
    '🕢' => 'седум и пол',
    '🕗' => 'осум часот',
    '🕣' => 'осум и пол',
    '🕘' => 'девет часот',
    '🕤' => 'девет и пол',
    '🕙' => 'десет часот',
    '🕥' => 'десет и пол',
    '🕚' => 'единаесет',
    '🕦' => 'единаесет и пол',
    '🌑' => 'млада месечина',
    '🌒' => 'прва фаза - новина',
    '🌓' => 'прва четвртина',
    '🌔' => 'последна фаза на осветлување',
    '🌕' => 'полна месечина',
    '🌖' => 'прва фаза на затемнување',
    '🌗' => 'последна четвртина',
    '🌘' => 'последна фаза на затемнување',
    '🌙' => 'месечев срп',
    '🌚' => 'млада месечина со лице',
    '🌛' => 'прва четвртина на месечината со лице',
    '🌜' => 'посл. четврт. на месечина со лице',
    '🌡' => 'термометар',
    '☀' => 'сонце',
    '🌝' => 'полна месечина со лице',
    '🌞' => 'сонце со лице',
    '🪐' => 'планета со прстени',
    '⭐' => 'средна бела ѕвезда',
    '🌟' => 'светлечка ѕвезда',
    '🌠' => 'ѕвезда што паѓа',
    '🌌' => 'млечниот пат',
    '☁' => 'облак',
    '⛅' => 'сонце зад облак',
    '⛈' => 'облак со гром и дожд',
    '🌤' => 'сонце зад мал облак',
    '🌥' => 'сонце зад голем облак',
    '🌦' => 'сонце зад облак со дожд',
    '🌧' => 'облак со дожд',
    '🌨' => 'облак со снег',
    '🌩' => 'облак со гром',
    '🌪' => 'торнадо',
    '🌫' => 'магла',
    '🌬' => 'лице на ветер',
    '🌀' => 'циклон',
    '🌈' => 'виножито',
    '🌂' => 'затворен чадор',
    '☂' => 'чадор',
    '☔' => 'чадор со капки дожд',
    '⛱' => 'чадор за сонце',
    '⚡' => 'висок напон',
    '❄' => 'снегулка',
    '☃' => 'снешко',
    '⛄' => 'снешко без снег',
    '☄' => 'комета',
    '🔥' => 'оган',
    '💧' => 'капка',
    '🌊' => 'бран',
    '🎃' => 'фенер од тиква',
    '🎄' => 'новогодишна елка',
    '🎆' => 'огномет',
    '🎇' => 'прскалка',
    '🧨' => 'петарда',
    '✨' => 'светки',
    '🎈' => 'балон',
    '🎉' => 'прскалка со конфети',
    '🎊' => 'топка со конфети',
    '🎋' => 'јапонско дрво на желбите',
    '🎍' => 'украс од бор',
    '🎎' => 'јапонски кукли',
    '🎏' => 'летало со крапови',
    '🎐' => 'ветерно ѕвонче',
    '🎑' => 'прослава на месечината',
    '🧧' => 'црвен плик',
    '🎀' => 'панделка',
    '🎁' => 'завиткан подарок',
    '🎗' => 'панделка за сеќавање',
    '🎟' => 'влезни билети',
    '🎫' => 'билет',
    '🎖' => 'воен медал',
    '🏆' => 'трофеј',
    '🏅' => 'спортски медал',
    '🥇' => 'медал за прво место',
    '🥈' => 'медал за второ место',
    '🥉' => 'медал за трето место',
    '⚽' => 'фудбалска топка',
    '⚾' => 'топка за бејзбол',
    '🥎' => 'софтбол',
    '🏀' => 'баскет',
    '🏐' => 'одбојка',
    '🏈' => 'топка за американски фудбал',
    '🏉' => 'топка за рагби',
    '🎾' => 'тениско топче',
    '🥏' => 'летечки диск',
    '🎳' => 'куглање',
    '🏏' => 'крикет',
    '🏑' => 'хокеј на трева',
    '🏒' => 'хокеј на мраз',
    '🥍' => 'лакрос',
    '🏓' => 'пинг понг',
    '🏸' => 'бадминтон',
    '🥊' => 'боксерска ракавица',
    '🥋' => 'униформа за боречки вештини',
    '🥅' => 'мрежа на гол',
    '⛳' => 'знаме во дупка',
    '⛸' => 'лизгалка',
    '🎣' => 'рибарски стап',
    '🤿' => 'нуркачка маска',
    '🎽' => 'спортска маица на прерамки',
    '🎿' => 'скии',
    '🛷' => 'санка',
    '🥌' => 'камен за карлинг',
    '🎯' => 'пикадо',
    '🪀' => 'јојо',
    '🪁' => 'летечки змеј',
    '🔫' => 'пиштол на вода',
    '🎱' => 'црна топка за билјард',
    '🔮' => 'кристална топка',
    '🪄' => 'волшебно стапче',
    '🎮' => 'видеоигра',
    '🕹' => 'џојстик',
    '🎰' => 'автомат за игри',
    '🎲' => 'коцка',
    '🧩' => 'сложувалка',
    '🧸' => 'плишано мече',
    '🪅' => 'пињата',
    '🪩' => 'дискотопка',
    '🪆' => 'руска кукла',
    '♠' => 'пик во карти',
    '♥' => 'срце во карти',
    '♦' => 'каро во карти',
    '♣' => 'треф во карти',
    '♟' => 'шаховски пион',
    '🃏' => 'џокер',
    '🀄' => 'плочка со црвен змеј',
    '🎴' => 'цветни карти',
    '🎭' => 'сценски уметности',
    '🖼' => 'рамка со слика',
    '🎨' => 'сликарска палета',
    '🧵' => 'конец',
    '🪡' => 'игла за шиење',
    '🧶' => 'предиво',
    '🪢' => 'јазол',
    '👓' => 'очила',
    '🕶' => 'очила за сонце',
    '🥽' => 'заштитни очила',
    '🥼' => 'мантил',
    '🦺' => 'безбедносен елек',
    '👔' => 'вратоврска',
    '👕' => 'маица',
    '👖' => 'фармерки',
    '🧣' => 'шал',
    '🧤' => 'ракавици',
    '🧥' => 'палто',
    '🧦' => 'чорапи',
    '👗' => 'фустан',
    '👘' => 'кимоно',
    '🥻' => 'сари',
    '🩱' => 'едноделен костим за капење',
    '🩲' => 'килоти',
    '🩳' => 'шорцеви',
    '👙' => 'бикини',
    '👚' => 'женска облека',
    '🪭' => 'лепеза',
    '👛' => 'паричник',
    '👜' => 'чанта',
    '👝' => 'торбичка',
    '🛍' => 'кеси за пазарење',
    '🎒' => 'училишен ранец',
    '🩴' => 'апостолка',
    '👞' => 'машки чевел',
    '👟' => 'патика',
    '🥾' => 'чизми за планинарење',
    '🥿' => 'балетанка',
    '👠' => 'чевел со висока потпетица',
    '👡' => 'женска сандала',
    '🩰' => 'балетанки',
    '👢' => 'женска чизма',
    '🪮' => 'чешел',
    '👑' => 'круна',
    '👒' => 'женска шапка',
    '🎩' => 'цилиндар',
    '🎓' => 'капа за дипломирање',
    '🧢' => 'капче',
    '🪖' => 'војнички шлем',
    '⛑' => 'шлем со бел крст',
    '📿' => 'бројаница',
    '💄' => 'кармин',
    '💍' => 'прстен',
    '💎' => 'скапоцен камен',
    '🔇' => 'исклучен звучник',
    '🔈' => 'звучник',
    '🔉' => 'вклучен звучник',
    '🔊' => 'гласен звучник',
    '📢' => 'разглас',
    '📣' => 'мегафон',
    '📯' => 'поштенски рог',
    '🔔' => 'ѕвоно',
    '🔕' => 'пречкртано ѕвонче',
    '🎼' => 'петолиние',
    '🎵' => 'музичка нота',
    '🎶' => 'музички ноти',
    '🎙' => 'студиски микрофон',
    '🎚' => 'лизгач',
    '🎛' => 'копчиња за управување',
    '🎤' => 'микрофон',
    '🎧' => 'слушалки',
    '📻' => 'радио',
    '🎷' => 'саксофон',
    '🎺' => 'труба',
    '🪊' => 'тромбон',
    '🪗' => 'хармоника',
    '🎸' => 'гитара',
    '🎹' => 'клавијатура',
    '🎻' => 'виолина',
    '🪕' => 'бенџо',
    '🥁' => 'тапан',
    '🪘' => 'конга',
    '🪇' => 'маракас',
    '🪈' => 'флејта',
    '🪉' => 'харфа',
    '📱' => 'мобилен телефон',
    '📲' => 'мобилен телефон со стрелка',
    '☎' => 'телефон',
    '📞' => 'телефонска слушалка',
    '📟' => 'пејџер',
    '📠' => 'факс',
    '🔋' => 'батерија',
    '🪫' => 'слаба батерија',
    '🔌' => 'електричен приклучок',
    '💻' => 'лаптоп',
    '🖥' => 'компјутер',
    '🖨' => 'печатач',
    '⌨' => 'тастатура',
    '🖱' => 'глувче за компјутер',
    '🖲' => 'топче за управување',
    '💽' => 'минидиск',
    '💾' => 'дискета',
    '💿' => 'цд',
    '📀' => 'двд',
    '🧮' => 'сметалка',
    '🎥' => 'филмска камера',
    '🎞' => 'филмска лента',
    '📽' => 'филмски прожектор',
    '🎬' => 'филмска клапа',
    '📺' => 'телевизор',
    '📷' => 'фотоапарат',
    '📸' => 'фотоапарат со блиц',
    '📹' => 'видеокамера',
    '📼' => 'видеокасета',
    '🔍' => 'лупа свртена налево',
    '🔎' => 'лупа свртена надесно',
    '🕯' => 'свеќа',
    '💡' => 'светилка',
    '🔦' => 'батериска ламба',
    '🏮' => 'црвен фенер',
    '🪔' => 'ламба дија',
    '📔' => 'тетратка со украсна корица',
    '📕' => 'затворена книга',
    '📖' => 'отворена книга',
    '📗' => 'зелена книга',
    '📘' => 'сина книга',
    '📙' => 'портокалова книга',
    '📚' => 'книги',
    '📓' => 'бележник',
    '📒' => 'тефтер',
    '📃' => 'свиткан лист',
    '📜' => 'свиток',
    '📄' => 'страница свртена нагоре',
    '📰' => 'весник',
    '🗞' => 'замотан весник',
    '📑' => 'обележани страници',
    '🔖' => 'обележувач',
    '🏷' => 'етикета',
    '🪙' => 'паричка',
    '💰' => 'вреќа со пари',
    '🪎' => 'ковчег со богатство',
    '💴' => 'банкнота на јен',
    '💵' => 'банкнота на долар',
    '💶' => 'банкнота на евро',
    '💷' => 'банкнота на фунта',
    '💸' => 'пари со крилја',
    '💳' => 'кредитна картичка',
    '🧾' => 'сметка',
    '💹' => 'растечки графикон на јенот',
    '✉' => 'плик',
    '📧' => 'е-пошта',
    '📨' => 'плик што пристигнува',
    '📩' => 'плик со стрелка',
    '📤' => 'фиока на излезно сандаче',
    '📥' => 'фиока на влезно сандаче',
    '📦' => 'пакет',
    '📫' => 'затворено сандаче со кренато знаменце',
    '📪' => 'затворено сандаче со спуштено знаменце',
    '📬' => 'отворено сандаче со кренато знаменце',
    '📭' => 'отворено сандаче со спуштено знаменце',
    '📮' => 'поштенско сандаче',
    '🗳' => 'гласачка кутија со гласачко ливче',
    '✏' => 'молив',
    '✒' => 'црно перо',
    '🖋' => 'наливно перо',
    '🖊' => 'пенкало',
    '🖌' => 'четка за боење',
    '🖍' => 'мрсна боица',
    '📝' => 'белешка',
    '💼' => 'актовка',
    '📁' => 'папка со датотеки',
    '📂' => 'отворена папка со датотеки',
    '🗂' => 'прегради на картотека',
    '📅' => 'календар',
    '📆' => 'календар на кинење',
    '🗒' => 'тетратка со спирала',
    '🗓' => 'календар со спирала',
    '📇' => 'држач за картички',
    '📈' => 'растечки графикон',
    '📉' => 'опаѓачки графикон',
    '📊' => 'столбест дијаграм',
    '📋' => 'табла за хартија',
    '📌' => 'притискач',
    '📍' => 'топуска',
    '📎' => 'спојувалка',
    '🖇' => 'поврзани спојувалки',
    '📏' => 'прав линијар',
    '📐' => 'триаголен линијар',
    '✂' => 'ножици',
    '🗃' => 'кутија за картотека',
    '🗄' => 'шкаф за картотека',
    '🗑' => 'корпа за отпадоци',
    '🔒' => 'заклучен катанец',
    '🔓' => 'отклучен катанец',
    '🔏' => 'заклучен катанец со перо',
    '🔐' => 'заклучен катанец со клуч',
    '🔑' => 'клуч',
    '🗝' => 'стар клуч',
    '🔨' => 'чекан',
    '🪓' => 'секира',
    '⛏' => 'копач',
    '⚒' => 'чекан и копач',
    '🛠' => 'чекан и француски клуч',
    '🗡' => 'кама',
    '⚔' => 'вкрстени мечови',
    '💣' => 'бомба',
    '🪃' => 'бумеранг',
    '🏹' => 'лак и стрела',
    '🛡' => 'штит',
    '🪚' => 'столарска пила',
    '🔧' => 'француски клуч',
    '🪛' => 'шрафцигер',
    '🔩' => 'завртка и навртка',
    '⚙' => 'запченик',
    '🗜' => 'стега',
    '⚖' => 'механичка вага',
    '🦯' => 'стап за слепи',
    '🔗' => 'алка',
    '⛓' => 'синџири',
    '🪝' => 'кука',
    '🧰' => 'кутија за алат',
    '🧲' => 'магнет',
    '🪜' => 'скала',
    '🪏' => 'лопата',
    '⚗' => 'дестилатор',
    '🧪' => 'епрувета',
    '🧫' => 'петриев сад',
    '🧬' => 'днк',
    '🔬' => 'микроскоп',
    '🔭' => 'телескоп',
    '📡' => 'сателитска антена',
    '💉' => 'шприц',
    '🩸' => 'капка крв',
    '💊' => 'капсула',
    '🩹' => 'леплив фластер',
    '🩼' => 'патерица',
    '🩺' => 'стетоскоп',
    '🩻' => 'рендген',
    '🚪' => 'врата',
    '🛗' => 'лифт',
    '🪞' => 'огледало',
    '🪟' => 'прозорец',
    '🛏' => 'кревет',
    '🛋' => 'кауч и ламба',
    '🪑' => 'стол',
    '🚽' => 'тоалетна школка',
    '🪠' => 'одзатнувач',
    '🚿' => 'туш',
    '🛁' => 'када',
    '🪤' => 'стапица за глувци',
    '🪒' => 'брич',
    '🧴' => 'шише со лосион',
    '🧷' => 'безопасна игла',
    '🧹' => 'метла',
    '🧺' => 'корпа',
    '🧻' => 'ролна хартија',
    '🪣' => 'кофа',
    '🧼' => 'сапун',
    '🫧' => 'меурчиња',
    '🪥' => 'четкичка за заби',
    '🧽' => 'сунѓер',
    '🧯' => 'противпожарен апарат',
    '🛒' => 'шопинг',
    '🚬' => 'цигара',
    '⚰' => 'ковчег',
    '🪦' => 'надгробна плоча',
    '⚱' => 'погребна урна',
    '🧿' => 'назар (амајлија)',
    '🪬' => 'хамса',
    '🗿' => 'монолитни статуи',
    '🪧' => 'натпис',
    '🪪' => 'лична карта',
    '🏧' => 'банкомат',
    '🚮' => 'канта за отпадоци',
    '🚰' => 'вода за пиење',
    '♿' => 'инвалидска количка',
    '🚹' => 'машки тоалет',
    '🚺' => 'женски тоалет',
    '🚻' => 'тоалет',
    '🚼' => 'простор за преслекување бебе',
    '🚾' => 'вц',
    '🛂' => 'пасошка контрола',
    '🛃' => 'царина',
    '🛄' => 'подигање багаж',
    '🛅' => 'чување багаж',
    '⚠' => 'предупредување',
    '🚸' => 'деца на патот',
    '⛔' => 'забрана за сообраќај во една насока',
    '🚫' => 'забрана за влез',
    '🚳' => 'забрана за велосипеди',
    '🚭' => 'забрана за пушење',
    '🚯' => 'забрана за фрлање отпадоци',
    '🚱' => 'водата не е за пиење',
    '🚷' => 'забрана за пешаци',
    '📵' => 'забрана за мобилни телефони',
    '🔞' => 'забрана за малолетници',
    '☢' => 'радиоактивно',
    '☣' => 'биолошка опасност',
    '⬆' => 'стрелка нагоре',
    '↗' => 'стрелка нагоре десно',
    '➡' => 'стрелка надесно',
    '↘' => 'стрелка надолу десно',
    '⬇' => 'стрелка надолу',
    '↙' => 'стрелка надолу лево',
    '⬅' => 'стрелка налево',
    '↖' => 'стрелка нагоре лево',
    '↕' => 'стрелка нагоре-надолу',
    '↔' => 'стрелка налево-надесно',
    '↩' => 'стрелка надесно што врти лево',
    '↪' => 'стрелка налево што врти десно',
    '⤴' => 'десна стрелка што врти нагоре',
    '⤵' => 'десна стрелка што врти надолу',
    '🔃' => 'вертикални стрелки што вртат надесно',
    '🔄' => 'копче со стрелки што вртат налево',
    '🔙' => 'стрелка за назад',
    '🔚' => 'стрелка за крај',
    '🔛' => 'стрелка за вклучено',
    '🔜' => 'стрелка за наскоро',
    '🔝' => 'стрелка за горе',
    '🛐' => 'место за богослужба',
    '⚛' => 'атом',
    '🕉' => 'ом',
    '✡' => 'ѕвездата на Давид',
    '☸' => 'тркалото на дарма',
    '☯' => 'јин јанг',
    '✝' => 'латински крст',
    '☦' => 'православен крст',
    '☪' => 'ѕвезда и полумесечина',
    '☮' => 'мир',
    '🕎' => 'менора',
    '🔯' => 'шестокрака ѕвезда со точка',
    '🪯' => 'канда',
    '♈' => 'хороскопски знак овен',
    '♉' => 'хороскопски знак бик',
    '♊' => 'хороскопски знак близнаци',
    '♋' => 'хороскопски знак рак',
    '♌' => 'хороскопски знак лав',
    '♍' => 'хороскопски знак девица',
    '♎' => 'хороскопски знак вага',
    '♏' => 'хороскопски знак скорпија',
    '♐' => 'хороскопски знак стрелец',
    '♑' => 'хороскопски знак јарец',
    '♒' => 'хороскопски знак водолија',
    '♓' => 'хороскопски знак риби',
    '⛎' => 'хороскопски знак змијоносец',
    '🔀' => 'копче за пуштање по случаен избор',
    '🔁' => 'копче за повторување',
    '🔂' => 'копче за повторување една песна',
    '▶' => 'копче за пуштање',
    '⏩' => 'копче за брзо премотување нанапред',
    '⏭' => 'копче за следна песна',
    '⏯' => 'копче за пуштање или паузирање',
    '◀' => 'копче за премотување наназад',
    '⏪' => 'копче за брзо премотување наназад',
    '⏮' => 'копче за последна песна',
    '🔼' => 'копче за горе',
    '⏫' => 'копче за брзо горе',
    '🔽' => 'копче за долу',
    '⏬' => 'копче за брзо долу',
    '⏸' => 'копче за пауза',
    '⏹' => 'копче за стоп',
    '⏺' => 'копче за снимање',
    '⏏' => 'копче за исфрлање',
    '🎦' => 'кино',
    '🔅' => 'копче за затемнување',
    '🔆' => 'копче за осветлување',
    '📶' => 'цртички на антената',
    '🛜' => 'безжично',
    '📳' => 'режим на вибрации',
    '📴' => 'мобилниот телефон е исклучен',
    '♀' => 'знак за женско',
    '♂' => 'знак за машко',
    '⚧' => 'трансродов симбол',
    '✖' => 'множење',
    '➕' => 'плус',
    '➖' => 'минус',
    '➗' => 'делење',
    '🟰' => 'задебелен знак за равенство',
    '♾' => 'бесконечност',
    '‼' => 'двоен извичник',
    '⁉' => 'извичник и прашалник',
    '❓' => 'црвен прашалник',
    '❔' => 'бел прашалник',
    '❕' => 'бел извичник',
    '❗' => 'црвен извичник',
    '〰' => 'брановидна црта',
    '💱' => 'размена на валути',
    '💲' => 'задебелен знак за долар',
    '⚕' => 'медицински симбол',
    '♻' => 'симбол за рециклирање',
    '⚜' => 'трилистен цвет од лилјан',
    '🔱' => 'трозабец',
    '📛' => 'значка со име',
    '🔰' => 'почетник на јапонски',
    '⭕' => 'празен црвен круг',
    '✅' => 'копче за штиклирање',
    '☑' => 'штиклирано поле',
    '✔' => 'знак за штиклирање',
    '❌' => 'знак за пречкртано',
    '❎' => 'копче со знак за пречкртано',
    '➰' => 'свиткана јамка',
    '➿' => 'двојна свиткана јамка',
    '〽' => 'почеток на пеење',
    '✳' => 'ѕвездичка со осум крака',
    '✴' => 'ѕвезда со осум крака',
    '❇' => 'искра',
    '™' => 'трговска марка',
    '🫟' => 'испрскано',
    '🔠' => 'латинични големи букви',
    '🔡' => 'латинични мали букви',
    '🔢' => 'броеви',
    '🔣' => 'симболи',
    '🔤' => 'латинични букви',
    '🅰' => 'копче А (крвна група)',
    '🆎' => 'копче АБ (крвна група)',
    '🅱' => 'копче Б (крвна група)',
    '🆑' => 'копче ЦЛ',
    '🆒' => 'копче КУЛ',
    '🆓' => 'копче ФРИ',
    'ℹ' => 'информации',
    '🆔' => 'копче ИД',
    'Ⓜ' => 'буквата м во круг',
    '🆕' => 'копче ЊУ',
    '🆖' => 'копче НГ',
    '🅾' => 'копче О (крвна група)',
    '🆗' => 'копче ОК',
    '🅿' => 'копче П',
    '🆘' => 'копче СОС',
    '🆙' => 'копче УП!',
    '🆚' => 'копче ВС',
    '🈁' => 'копче „тука“ на јапонски',
    '🈂' => 'копче „услугата се наплаќа“ на јапонски',
    '🈷' => 'копче „месечна сума“ на јапонски',
    '🈶' => 'копче „не е бесплатно“ на јапонски',
    '🈯' => 'копче „резервирано“ на јапонски',
    '🉐' => 'копче „зделка“ на јапонски',
    '🈹' => 'копче „попуст“ на јапонски',
    '🈚' => 'копче „бесплатно“ на јапонски',
    '🈲' => 'копче „забрането“ на јапонски',
    '🉑' => 'копче „прифатливо“ на јапонски',
    '🈸' => 'копче „апликација“ на јапонски',
    '🈴' => 'копче „преодна оценка“ на јапонски',
    '🈳' => 'копче „слободно“ на јапонски',
    '㊗' => 'копче „честитки“ на јапонски',
    '㊙' => 'копче „тајно“ на јапонски',
    '🈺' => 'копче „отворено“ на јапонски',
    '🈵' => 'копче „зафатено“ на јапонски',
    '🔴' => 'црвен круг',
    '🟠' => 'портокалов круг',
    '🟡' => 'жолт круг',
    '🟢' => 'зелен круг',
    '🔵' => 'син круг',
    '🟣' => 'виолетов круг',
    '🟤' => 'кафен круг',
    '⚫' => 'црн круг',
    '⚪' => 'бел круг',
    '🟥' => 'црвен квадрат',
    '🟧' => 'портокалов квадрат',
    '🟨' => 'жолт квадрат',
    '🟩' => 'зелен квадрат',
    '🟦' => 'син квадрат',
    '🟪' => 'виолетов квадрат',
    '🟫' => 'кафен квадрат',
    '⬛' => 'голем црн квадрат',
    '⬜' => 'голем бел квадрат',
    '◼' => 'среден црн квадрат',
    '◻' => 'среден бел квадрат',
    '◾' => 'црн квадрат со средна големина',
    '◽' => 'бел квадрат со средна големина',
    '▪' => 'мал црн квадрат',
    '▫' => 'мал бел квадрат',
    '🔶' => 'голем портокалов дијамант',
    '🔷' => 'голем син дијамант',
    '🔸' => 'мал портокалов дијамант',
    '🔹' => 'мал син дијамант',
    '🔺' => 'црвен триаголник свртен нагоре',
    '🔻' => 'црвен триаголник свртен надолу',
    '💠' => 'дијамант со точка',
    '🔘' => 'тркалезно копче',
    '🔳' => 'копче со бел квадрат',
    '🔲' => 'копче со црн квадрат',
    '🏁' => 'шаховско знаме',
    '🚩' => 'триаголно знаме',
    '🎌' => 'вкрстени знамиња',
    '🏴' => 'црно знаме',
    '🏳' => 'бело знаме',
];
