<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'Ifɛnuko: àgbà, àgbà, amɔ́lára, amɔ́lára díɛ̀',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'Ifɛnuko: àgbà, àgbà, amɔ́lára, amɔ́láwɔ̀ díɛ̀',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'Ifɛnuko: àgbà, àgbà, amɔ́lára, adúláwɔ̀ díɛ̀',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'Ifɛnuko: àgbà, àgbà, amɔ́lára, adúláwɔ̀',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'Ifɛnuko: àgbà, àgbà, amɔ́lára díɛ̀, amɔ́lára',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'Ifɛnuko: àgbà, àgbà, amɔ́lára díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'Ifɛnuko: àgbà, àgbà, amɔ́lára díɛ̀, adúláwɔ̀ díɛ̀',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'Ifɛnuko: àgbà, àgbà, amɔ́lára díɛ̀, adúláwɔ̀',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'Ifɛnuko: àgbà, àgbà, amɔ́láwɔ̀ díɛ̀, amɔ́lára',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'Ifɛnuko: àgbà, àgbà, amɔ́láwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'Ifɛnuko: àgbà, àgbà, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀ díɛ̀',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'Ifɛnuko: àgbà, àgbà, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'Ifɛnuko: àgbà, àgbà, adúláwɔ̀ díɛ̀, amɔ́lára',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'Ifɛnuko: àgbà, àgbà, adúláwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'Ifɛnuko: àgbà, àgbà, adúláwɔ̀ díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'Ifɛnuko: àgbà, àgbà, adúláwɔ̀ díɛ̀, adúláwɔ̀',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'Ifɛnuko: àgbà, àgbà, adúláwɔ̀, amɔ́lára',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'Ifɛnuko: àgbà, àgbà, adúláwɔ̀, amɔ́lára díɛ̀',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'Ifɛnuko: àgbà, àgbà, adúláwɔ̀, amɔ́láwɔ̀ díɛ̀',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'Ifɛnuko: àgbà, àgbà, adúláwɔ̀, adúláwɔ̀ díɛ̀',
    '👨🏻‍❤‍💋‍👨🏻' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára',
    '👨🏻‍❤‍💋‍👨🏼' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára, amɔ́lára díɛ̀',
    '👨🏻‍❤‍💋‍👨🏽' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára, amɔ́láwɔ̀ díɛ̀',
    '👨🏻‍❤‍💋‍👨🏾' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára, adúláwɔ̀ díɛ̀',
    '👨🏻‍❤‍💋‍👨🏿' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára, adúláwɔ̀',
    '👨🏼‍❤‍💋‍👨🏻' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀, amɔ́lára',
    '👨🏼‍❤‍💋‍👨🏼' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀',
    '👨🏼‍❤‍💋‍👨🏽' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👨🏼‍❤‍💋‍👨🏾' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀, adúláwɔ̀ díɛ̀',
    '👨🏼‍❤‍💋‍👨🏿' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀, adúláwɔ̀',
    '👨🏽‍❤‍💋‍👨🏻' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára',
    '👨🏽‍❤‍💋‍👨🏼' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👨🏽‍❤‍💋‍👨🏽' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀',
    '👨🏽‍❤‍💋‍👨🏾' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀ díɛ̀',
    '👨🏽‍❤‍💋‍👨🏿' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀',
    '👨🏾‍❤‍💋‍👨🏻' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́lára',
    '👨🏾‍❤‍💋‍👨🏼' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👨🏾‍❤‍💋‍👨🏽' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍❤‍💋‍👨🏾' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀',
    '👨🏾‍❤‍💋‍👨🏿' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, adúláwɔ̀',
    '👨🏿‍❤‍💋‍👨🏻' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀, amɔ́lára',
    '👨🏿‍❤‍💋‍👨🏼' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀, amɔ́lára díɛ̀',
    '👨🏿‍❤‍💋‍👨🏽' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀, amɔ́láwɔ̀ díɛ̀',
    '👨🏿‍❤‍💋‍👨🏾' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀, adúláwɔ̀ díɛ̀',
    '👨🏿‍❤‍💋‍👨🏿' => 'Ifɛnuko: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀',
    '👩🏻‍❤‍💋‍👨🏻' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára',
    '👩🏻‍❤‍💋‍👨🏼' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára, amɔ́lára díɛ̀',
    '👩🏻‍❤‍💋‍👨🏽' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára, amɔ́láwɔ̀ díɛ̀',
    '👩🏻‍❤‍💋‍👨🏾' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára, adúláwɔ̀ díɛ̀',
    '👩🏻‍❤‍💋‍👨🏿' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára, adúláwɔ̀',
    '👩🏼‍❤‍💋‍👨🏻' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀, amɔ́lára',
    '👩🏼‍❤‍💋‍👨🏼' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀',
    '👩🏼‍❤‍💋‍👨🏽' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏼‍❤‍💋‍👨🏾' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀, adúláwɔ̀ díɛ̀',
    '👩🏼‍❤‍💋‍👨🏿' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀, adúláwɔ̀',
    '👩🏽‍❤‍💋‍👨🏻' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára',
    '👩🏽‍❤‍💋‍👨🏼' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👩🏽‍❤‍💋‍👨🏽' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀',
    '👩🏽‍❤‍💋‍👨🏾' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀ díɛ̀',
    '👩🏽‍❤‍💋‍👨🏿' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀',
    '👩🏾‍❤‍💋‍👨🏻' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́lára',
    '👩🏾‍❤‍💋‍👨🏼' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👩🏾‍❤‍💋‍👨🏽' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍❤‍💋‍👨🏾' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀',
    '👩🏾‍❤‍💋‍👨🏿' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, adúláwɔ̀',
    '👩🏿‍❤‍💋‍👨🏻' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀, amɔ́lára',
    '👩🏿‍❤‍💋‍👨🏼' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀, amɔ́lára díɛ̀',
    '👩🏿‍❤‍💋‍👨🏽' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏿‍❤‍💋‍👨🏾' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀, adúláwɔ̀ díɛ̀',
    '👩🏿‍❤‍💋‍👨🏿' => 'Ifɛnuko: Obìnrin, Ɔkùnrin, adúláwɔ̀',
    '👩🏻‍❤‍💋‍👩🏻' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára',
    '👩🏻‍❤‍💋‍👩🏼' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára, amɔ́lára díɛ̀',
    '👩🏻‍❤‍💋‍👩🏽' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára, amɔ́láwɔ̀ díɛ̀',
    '👩🏻‍❤‍💋‍👩🏾' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára, adúláwɔ̀ díɛ̀',
    '👩🏻‍❤‍💋‍👩🏿' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára, adúláwɔ̀',
    '👩🏼‍❤‍💋‍👩🏻' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára díɛ̀, amɔ́lára',
    '👩🏼‍❤‍💋‍👩🏼' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára díɛ̀',
    '👩🏼‍❤‍💋‍👩🏽' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏼‍❤‍💋‍👩🏾' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára díɛ̀, adúláwɔ̀ díɛ̀',
    '👩🏼‍❤‍💋‍👩🏿' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́lára díɛ̀, adúláwɔ̀',
    '👩🏽‍❤‍💋‍👩🏻' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára',
    '👩🏽‍❤‍💋‍👩🏼' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👩🏽‍❤‍💋‍👩🏽' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀',
    '👩🏽‍❤‍💋‍👩🏾' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀ díɛ̀',
    '👩🏽‍❤‍💋‍👩🏿' => 'Ifɛnuko: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀',
    '👩🏾‍❤‍💋‍👩🏻' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀, amɔ́lára',
    '👩🏾‍❤‍💋‍👩🏼' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👩🏾‍❤‍💋‍👩🏽' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍❤‍💋‍👩🏾' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀',
    '👩🏾‍❤‍💋‍👩🏿' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀, adúláwɔ̀',
    '👩🏿‍❤‍💋‍👩🏻' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀, amɔ́lára',
    '👩🏿‍❤‍💋‍👩🏼' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀, amɔ́lára díɛ̀',
    '👩🏿‍❤‍💋‍👩🏽' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏿‍❤‍💋‍👩🏾' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀, adúláwɔ̀ díɛ̀',
    '👩🏿‍❤‍💋‍👩🏿' => 'Ifɛnuko: Obìnrin, Obìnrin, adúláwɔ̀',
    '🧑🏻‍🫯‍🧑🏼' => 'Awɔn Onigidigbo: amɔ́lára àtiamɔ́lára díɛ̀',
    '🧑🏻‍🫯‍🧑🏽' => 'Awɔn Onigidigbo: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏻‍🫯‍🧑🏾' => 'Awɔn Onigidigbo: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '🧑🏻‍🫯‍🧑🏿' => 'Awɔn Onigidigbo: amɔ́lára àtiadúláwɔ̀',
    '🧑🏼‍🫯‍🧑🏻' => 'Awɔn Onigidigbo: amɔ́lára díɛ̀ àtiamɔ́lára',
    '🧑🏼‍🫯‍🧑🏽' => 'Awɔn Onigidigbo: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏼‍🫯‍🧑🏾' => 'Awɔn Onigidigbo: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '🧑🏼‍🫯‍🧑🏿' => 'Awɔn Onigidigbo: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '🧑🏽‍🫯‍🧑🏻' => 'Awɔn Onigidigbo: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '🧑🏽‍🫯‍🧑🏼' => 'Awɔn Onigidigbo: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '🧑🏽‍🫯‍🧑🏾' => 'Awɔn Onigidigbo: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '🧑🏽‍🫯‍🧑🏿' => 'Awɔn Onigidigbo: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '🧑🏾‍🫯‍🧑🏻' => 'Awɔn Onigidigbo: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '🧑🏾‍🫯‍🧑🏼' => 'Awɔn Onigidigbo: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '🧑🏾‍🫯‍🧑🏽' => 'Awɔn Onigidigbo: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🫯‍🧑🏿' => 'Awɔn Onigidigbo: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '🧑🏿‍🫯‍🧑🏻' => 'Awɔn Onigidigbo: adúláwɔ̀ àtiamɔ́lára',
    '🧑🏿‍🫯‍🧑🏼' => 'Awɔn Onigidigbo: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '🧑🏿‍🫯‍🧑🏽' => 'Awɔn Onigidigbo: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏿‍🫯‍🧑🏾' => 'Awɔn Onigidigbo: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '🧑🏻‍❤‍🧑🏼' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́lára, amɔ́lára díɛ̀',
    '🧑🏻‍❤‍🧑🏽' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́lára, amɔ́láwɔ̀ díɛ̀',
    '🧑🏻‍❤‍🧑🏾' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́lára, adúláwɔ̀ díɛ̀',
    '🧑🏻‍❤‍🧑🏿' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́lára, adúláwɔ̀',
    '🧑🏼‍❤‍🧑🏻' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́lára díɛ̀, amɔ́lára',
    '🧑🏼‍❤‍🧑🏽' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́lára díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '🧑🏼‍❤‍🧑🏾' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́lára díɛ̀, adúláwɔ̀ díɛ̀',
    '🧑🏼‍❤‍🧑🏿' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́lára díɛ̀, adúláwɔ̀',
    '🧑🏽‍❤‍🧑🏻' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́láwɔ̀ díɛ̀, amɔ́lára',
    '🧑🏽‍❤‍🧑🏼' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́láwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '🧑🏽‍❤‍🧑🏾' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀ díɛ̀',
    '🧑🏽‍❤‍🧑🏿' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀',
    '🧑🏾‍❤‍🧑🏻' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, adúláwɔ̀ díɛ̀, amɔ́lára',
    '🧑🏾‍❤‍🧑🏼' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, adúláwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '🧑🏾‍❤‍🧑🏽' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, adúláwɔ̀ díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍❤‍🧑🏿' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, adúláwɔ̀ díɛ̀, adúláwɔ̀',
    '🧑🏿‍❤‍🧑🏻' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, adúláwɔ̀, amɔ́lára',
    '🧑🏿‍❤‍🧑🏼' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, adúláwɔ̀, amɔ́lára díɛ̀',
    '🧑🏿‍❤‍🧑🏽' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, adúláwɔ̀, amɔ́láwɔ̀ díɛ̀',
    '🧑🏿‍❤‍🧑🏾' => 'Lɔkɔlaya Pɛlu ɔkan: àgbà, àgbà, adúláwɔ̀, adúláwɔ̀ díɛ̀',
    '🧑🏻‍🐰‍🧑🏼' => 'awɔn eniyan eleti ehoro: amɔ́lára àtiamɔ́lára díɛ̀',
    '🧑🏻‍🐰‍🧑🏽' => 'awɔn eniyan eleti ehoro: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏻‍🐰‍🧑🏾' => 'awɔn eniyan eleti ehoro: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '🧑🏻‍🐰‍🧑🏿' => 'awɔn eniyan eleti ehoro: amɔ́lára àtiadúláwɔ̀',
    '🧑🏼‍🐰‍🧑🏻' => 'awɔn eniyan eleti ehoro: amɔ́lára díɛ̀ àtiamɔ́lára',
    '🧑🏼‍🐰‍🧑🏽' => 'awɔn eniyan eleti ehoro: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏼‍🐰‍🧑🏾' => 'awɔn eniyan eleti ehoro: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '🧑🏼‍🐰‍🧑🏿' => 'awɔn eniyan eleti ehoro: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '🧑🏽‍🐰‍🧑🏻' => 'awɔn eniyan eleti ehoro: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '🧑🏽‍🐰‍🧑🏼' => 'awɔn eniyan eleti ehoro: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '🧑🏽‍🐰‍🧑🏾' => 'awɔn eniyan eleti ehoro: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '🧑🏽‍🐰‍🧑🏿' => 'awɔn eniyan eleti ehoro: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '🧑🏾‍🐰‍🧑🏻' => 'awɔn eniyan eleti ehoro: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '🧑🏾‍🐰‍🧑🏼' => 'awɔn eniyan eleti ehoro: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '🧑🏾‍🐰‍🧑🏽' => 'awɔn eniyan eleti ehoro: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🐰‍🧑🏿' => 'awɔn eniyan eleti ehoro: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '🧑🏿‍🐰‍🧑🏻' => 'awɔn eniyan eleti ehoro: adúláwɔ̀ àtiamɔ́lára',
    '🧑🏿‍🐰‍🧑🏼' => 'awɔn eniyan eleti ehoro: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '🧑🏿‍🐰‍🧑🏽' => 'awɔn eniyan eleti ehoro: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏿‍🐰‍🧑🏾' => 'awɔn eniyan eleti ehoro: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '👨🏻‍🫯‍👨🏼' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára àtiamɔ́lára díɛ̀',
    '👨🏻‍🫯‍👨🏽' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏻‍🫯‍👨🏾' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '👨🏻‍🫯‍👨🏿' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára àtiadúláwɔ̀',
    '👨🏼‍🫯‍👨🏻' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára díɛ̀ àtiamɔ́lára',
    '👨🏼‍🫯‍👨🏽' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏼‍🫯‍👨🏾' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👨🏼‍🫯‍👨🏿' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '👨🏽‍🫯‍👨🏻' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '👨🏽‍🫯‍👨🏼' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👨🏽‍🫯‍👨🏾' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👨🏽‍🫯‍👨🏿' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👨🏾‍🫯‍👨🏻' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '👨🏾‍🫯‍👨🏼' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👨🏾‍🫯‍👨🏽' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🫯‍👨🏿' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👨🏿‍🫯‍👨🏻' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀ àtiamɔ́lára',
    '👨🏿‍🫯‍👨🏼' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '👨🏿‍🫯‍👨🏽' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏿‍🫯‍👨🏾' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '👨🏻‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára',
    '👨🏻‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára, amɔ́lára díɛ̀',
    '👨🏻‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára, amɔ́láwɔ̀ díɛ̀',
    '👨🏻‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára, adúláwɔ̀ díɛ̀',
    '👨🏻‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára, adúláwɔ̀',
    '👨🏼‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀, amɔ́lára',
    '👨🏼‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀',
    '👨🏼‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👨🏼‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀, adúláwɔ̀ díɛ̀',
    '👨🏼‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́lára díɛ̀, adúláwɔ̀',
    '👨🏽‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára',
    '👨🏽‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👨🏽‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀',
    '👨🏽‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀ díɛ̀',
    '👨🏽‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀',
    '👨🏾‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́lára',
    '👨🏾‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👨🏾‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀',
    '👨🏾‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, adúláwɔ̀',
    '👨🏿‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀, amɔ́lára',
    '👨🏿‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀, amɔ́lára díɛ̀',
    '👨🏿‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀, amɔ́láwɔ̀ díɛ̀',
    '👨🏿‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀, adúláwɔ̀ díɛ̀',
    '👨🏿‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin, Ɔkùnrin, adúláwɔ̀',
    '👨🏻‍🐰‍👨🏼' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára àtiamɔ́lára díɛ̀',
    '👨🏻‍🐰‍👨🏽' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏻‍🐰‍👨🏾' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '👨🏻‍🐰‍👨🏿' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára àtiadúláwɔ̀',
    '👨🏼‍🐰‍👨🏻' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára díɛ̀ àtiamɔ́lára',
    '👨🏼‍🐰‍👨🏽' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏼‍🐰‍👨🏾' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👨🏼‍🐰‍👨🏿' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '👨🏽‍🐰‍👨🏻' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '👨🏽‍🐰‍👨🏼' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👨🏽‍🐰‍👨🏾' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👨🏽‍🐰‍👨🏿' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👨🏾‍🐰‍👨🏻' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '👨🏾‍🐰‍👨🏼' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👨🏾‍🐰‍👨🏽' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🐰‍👨🏿' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👨🏿‍🐰‍👨🏻' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀ àtiamɔ́lára',
    '👨🏿‍🐰‍👨🏼' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '👨🏿‍🐰‍👨🏽' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏿‍🐰‍👨🏾' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏻‍🫯‍👩🏼' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára àtiamɔ́lára díɛ̀',
    '👩🏻‍🫯‍👩🏽' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏻‍🫯‍👩🏾' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '👩🏻‍🫯‍👩🏿' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára àtiadúláwɔ̀',
    '👩🏼‍🫯‍👩🏻' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára díɛ̀ àtiamɔ́lára',
    '👩🏼‍🫯‍👩🏽' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏼‍🫯‍👩🏾' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏼‍🫯‍👩🏿' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '👩🏽‍🫯‍👩🏻' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '👩🏽‍🫯‍👩🏼' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👩🏽‍🫯‍👩🏾' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏽‍🫯‍👩🏿' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👩🏾‍🫯‍👩🏻' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '👩🏾‍🫯‍👩🏼' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👩🏾‍🫯‍👩🏽' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🫯‍👩🏿' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👩🏿‍🫯‍👩🏻' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀ àtiamɔ́lára',
    '👩🏿‍🫯‍👩🏼' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '👩🏿‍🫯‍👩🏽' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏿‍🫯‍👩🏾' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏻‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára',
    '👩🏻‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára, amɔ́lára díɛ̀',
    '👩🏻‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára, amɔ́láwɔ̀ díɛ̀',
    '👩🏻‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára, adúláwɔ̀ díɛ̀',
    '👩🏻‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára, adúláwɔ̀',
    '👩🏼‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀, amɔ́lára',
    '👩🏼‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀',
    '👩🏼‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏼‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀, adúláwɔ̀ díɛ̀',
    '👩🏼‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́lára díɛ̀, adúláwɔ̀',
    '👩🏽‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára',
    '👩🏽‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👩🏽‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀',
    '👩🏽‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀ díɛ̀',
    '👩🏽‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀',
    '👩🏾‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́lára',
    '👩🏾‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👩🏾‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀',
    '👩🏾‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀ díɛ̀, adúláwɔ̀',
    '👩🏿‍❤‍👨🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀, amɔ́lára',
    '👩🏿‍❤‍👨🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀, amɔ́lára díɛ̀',
    '👩🏿‍❤‍👨🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏿‍❤‍👨🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀, adúláwɔ̀ díɛ̀',
    '👩🏿‍❤‍👨🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Ɔkùnrin, adúláwɔ̀',
    '👩🏻‍❤‍👩🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára',
    '👩🏻‍❤‍👩🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára, amɔ́lára díɛ̀',
    '👩🏻‍❤‍👩🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára, amɔ́láwɔ̀ díɛ̀',
    '👩🏻‍❤‍👩🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára, adúláwɔ̀ díɛ̀',
    '👩🏻‍❤‍👩🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára, adúláwɔ̀',
    '👩🏼‍❤‍👩🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára díɛ̀, amɔ́lára',
    '👩🏼‍❤‍👩🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára díɛ̀',
    '👩🏼‍❤‍👩🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏼‍❤‍👩🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára díɛ̀, adúláwɔ̀ díɛ̀',
    '👩🏼‍❤‍👩🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́lára díɛ̀, adúláwɔ̀',
    '👩🏽‍❤‍👩🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára',
    '👩🏽‍❤‍👩🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👩🏽‍❤‍👩🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀',
    '👩🏽‍❤‍👩🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀ díɛ̀',
    '👩🏽‍❤‍👩🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, amɔ́láwɔ̀ díɛ̀, adúláwɔ̀',
    '👩🏾‍❤‍👩🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀, amɔ́lára',
    '👩🏾‍❤‍👩🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀, amɔ́lára díɛ̀',
    '👩🏾‍❤‍👩🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍❤‍👩🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀',
    '👩🏾‍❤‍👩🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀ díɛ̀, adúláwɔ̀',
    '👩🏿‍❤‍👩🏻' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀, amɔ́lára',
    '👩🏿‍❤‍👩🏼' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀, amɔ́lára díɛ̀',
    '👩🏿‍❤‍👩🏽' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀, amɔ́láwɔ̀ díɛ̀',
    '👩🏿‍❤‍👩🏾' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀, adúláwɔ̀ díɛ̀',
    '👩🏿‍❤‍👩🏿' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin, Obìnrin, adúláwɔ̀',
    '👩🏻‍🐰‍👩🏼' => 'awɔn obìnrin eleti ehoro: amɔ́lára àtiamɔ́lára díɛ̀',
    '👩🏻‍🐰‍👩🏽' => 'awɔn obìnrin eleti ehoro: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏻‍🐰‍👩🏾' => 'awɔn obìnrin eleti ehoro: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '👩🏻‍🐰‍👩🏿' => 'awɔn obìnrin eleti ehoro: amɔ́lára àtiadúláwɔ̀',
    '👩🏼‍🐰‍👩🏻' => 'awɔn obìnrin eleti ehoro: amɔ́lára díɛ̀ àtiamɔ́lára',
    '👩🏼‍🐰‍👩🏽' => 'awɔn obìnrin eleti ehoro: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏼‍🐰‍👩🏾' => 'awɔn obìnrin eleti ehoro: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏼‍🐰‍👩🏿' => 'awɔn obìnrin eleti ehoro: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '👩🏽‍🐰‍👩🏻' => 'awɔn obìnrin eleti ehoro: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '👩🏽‍🐰‍👩🏼' => 'awɔn obìnrin eleti ehoro: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👩🏽‍🐰‍👩🏾' => 'awɔn obìnrin eleti ehoro: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏽‍🐰‍👩🏿' => 'awɔn obìnrin eleti ehoro: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👩🏾‍🐰‍👩🏻' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '👩🏾‍🐰‍👩🏼' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👩🏾‍🐰‍👩🏽' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🐰‍👩🏿' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👩🏿‍🐰‍👩🏻' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀ àtiamɔ́lára',
    '👩🏿‍🐰‍👩🏼' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '👩🏿‍🐰‍👩🏽' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏿‍🐰‍👩🏾' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '🧑🏻‍🤝‍🧑🏻' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára',
    '🧑🏻‍🤝‍🧑🏼' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára àtiamɔ́lára díɛ̀',
    '🧑🏻‍🤝‍🧑🏽' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏻‍🤝‍🧑🏾' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '🧑🏻‍🤝‍🧑🏿' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára àtiadúláwɔ̀',
    '🧑🏼‍🤝‍🧑🏻' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára díɛ̀ àtiamɔ́lára',
    '🧑🏼‍🤝‍🧑🏼' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára díɛ̀',
    '🧑🏼‍🤝‍🧑🏽' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏼‍🤝‍🧑🏾' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '🧑🏼‍🤝‍🧑🏿' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '🧑🏽‍🤝‍🧑🏻' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '🧑🏽‍🤝‍🧑🏼' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '🧑🏽‍🤝‍🧑🏽' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́láwɔ̀ díɛ̀',
    '🧑🏽‍🤝‍🧑🏾' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '🧑🏽‍🤝‍🧑🏿' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '🧑🏾‍🤝‍🧑🏻' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '🧑🏾‍🤝‍🧑🏼' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '🧑🏾‍🤝‍🧑🏽' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🤝‍🧑🏾' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀ díɛ̀',
    '🧑🏾‍🤝‍🧑🏿' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '🧑🏿‍🤝‍🧑🏻' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀ àtiamɔ́lára',
    '🧑🏿‍🤝‍🧑🏼' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '🧑🏿‍🤝‍🧑🏽' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🧑🏿‍🤝‍🧑🏾' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '🧑🏿‍🤝‍🧑🏿' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú: adúláwɔ̀',
    '👩🏻‍🤝‍👩🏼' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiamɔ́lára díɛ̀',
    '👩🏻‍🤝‍👩🏽' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏻‍🤝‍👩🏾' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '👩🏻‍🤝‍👩🏿' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiadúláwɔ̀',
    '👩🏼‍🤝‍👩🏻' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiamɔ́lára',
    '👩🏼‍🤝‍👩🏽' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏼‍🤝‍👩🏾' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏼‍🤝‍👩🏿' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '👩🏽‍🤝‍👩🏻' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '👩🏽‍🤝‍👩🏼' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👩🏽‍🤝‍👩🏾' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏽‍🤝‍👩🏿' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👩🏾‍🤝‍👩🏻' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '👩🏾‍🤝‍👩🏼' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👩🏾‍🤝‍👩🏽' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🤝‍👩🏿' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👩🏿‍🤝‍👩🏻' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiamɔ́lára',
    '👩🏿‍🤝‍👩🏼' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '👩🏿‍🤝‍👩🏽' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏿‍🤝‍👩🏾' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏻‍🤝‍👨🏼' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiamɔ́lára díɛ̀',
    '👩🏻‍🤝‍👨🏽' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏻‍🤝‍👨🏾' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '👩🏻‍🤝‍👨🏿' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiadúláwɔ̀',
    '👩🏼‍🤝‍👨🏻' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiamɔ́lára',
    '👩🏼‍🤝‍👨🏽' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏼‍🤝‍👨🏾' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏼‍🤝‍👨🏿' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '👩🏽‍🤝‍👨🏻' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '👩🏽‍🤝‍👨🏼' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👩🏽‍🤝‍👨🏾' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👩🏽‍🤝‍👨🏿' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👩🏾‍🤝‍👨🏻' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '👩🏾‍🤝‍👨🏼' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👩🏾‍🤝‍👨🏽' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🤝‍👨🏿' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👩🏿‍🤝‍👨🏻' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiamɔ́lára',
    '👩🏿‍🤝‍👨🏼' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '👩🏿‍🤝‍👨🏽' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👩🏿‍🤝‍👨🏾' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '👨🏻‍🤝‍👨🏼' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiamɔ́lára díɛ̀',
    '👨🏻‍🤝‍👨🏽' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏻‍🤝‍👨🏾' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '👨🏻‍🤝‍👨🏿' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára àtiadúláwɔ̀',
    '👨🏼‍🤝‍👨🏻' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiamɔ́lára',
    '👨🏼‍🤝‍👨🏽' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏼‍🤝‍👨🏾' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👨🏼‍🤝‍👨🏿' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '👨🏽‍🤝‍👨🏻' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '👨🏽‍🤝‍👨🏼' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👨🏽‍🤝‍👨🏾' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '👨🏽‍🤝‍👨🏿' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👨🏾‍🤝‍👨🏻' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '👨🏾‍🤝‍👨🏼' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '👨🏾‍🤝‍👨🏽' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🤝‍👨🏿' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '👨🏿‍🤝‍👨🏻' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiamɔ́lára',
    '👨🏿‍🤝‍👨🏼' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '👨🏿‍🤝‍👨🏽' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '👨🏿‍🤝‍👨🏾' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '👩‍❤‍💋‍👨' => 'Ifɛnuko: Obìnrin àtiƆkùnrin',
    '👨‍❤‍💋‍👨' => 'Ifɛnuko: Ɔkùnrin àtiƆkùnrin',
    '👩‍❤‍💋‍👩' => 'Ifɛnuko: Obìnrin àtiObìnrin',
    '👨‍👩‍👧‍👦' => 'Ɛbí: Ɔkùnrin, Obìnrin, ɔmɔbìrin, ɔmɔkùnrin',
    '👨‍👩‍👦‍👦' => 'Ɛbí: Ɔkùnrin, Obìnrin, ɔmɔkùnrin, ɔmɔkùnrin',
    '👨‍👩‍👧‍👧' => 'Ɛbí: Ɔkùnrin, Obìnrin, ɔmɔbìrin, ɔmɔbìrin',
    '👨‍👨‍👧‍👦' => 'Ɛbí: Ɔkùnrin, Ɔkùnrin, ɔmɔbìrin, ɔmɔkùnrin',
    '👨‍👨‍👦‍👦' => 'Ɛbí: Ɔkùnrin, Ɔkùnrin, ɔmɔkùnrin, ɔmɔkùnrin',
    '👨‍👨‍👧‍👧' => 'Ɛbí: Ɔkùnrin, Ɔkùnrin, ɔmɔbìrin, ɔmɔbìrin',
    '👩‍👩‍👧‍👦' => 'Ɛbí: Obìnrin, Obìnrin, ɔmɔbìrin, ɔmɔkùnrin',
    '👩‍👩‍👦‍👦' => 'Ɛbí: Obìnrin, Obìnrin, ɔmɔkùnrin, ɔmɔkùnrin',
    '👩‍👩‍👧‍👧' => 'Ɛbí: Obìnrin, Obìnrin, ɔmɔbìrin, ɔmɔbìrin',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'filaagi: Ilɛ̀gɛ̀ɛ́sì',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'filaagi: Skɔ́tlándì',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'filaagi: Wélsì',
    '🧑‍🧑‍🧒‍🧒' => 'ìdílé: àgbàlagbà, àgbàlagbà, ɔmɔdé, ɔmɔdé',
    '🚶🏻‍♀‍➡' => 'obìnrin tí ń rìn: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🚶🏼‍♀‍➡' => 'obìnrin tí ń rìn: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏽‍♀‍➡' => 'obìnrin tí ń rìn: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏾‍♀‍➡' => 'obìnrin tí ń rìn: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏿‍♀‍➡' => 'obìnrin tí ń rìn: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏻‍♂‍➡' => 'ɔkùnrin tí ń rìn: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🚶🏼‍♂‍➡' => 'ɔkùnrin tí ń rìn: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏽‍♂‍➡' => 'ɔkùnrin tí ń rìn: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏾‍♂‍➡' => 'ɔkùnrin tí ń rìn: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏿‍♂‍➡' => 'ɔkùnrin tí ń rìn: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏻‍♀‍➡' => 'obìnrin tó kúnlɛ̀: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🧎🏼‍♀‍➡' => 'obìnrin tó kúnlɛ̀: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏽‍♀‍➡' => 'obìnrin tó kúnlɛ̀: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏾‍♀‍➡' => 'obìnrin tó kúnlɛ̀: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏿‍♀‍➡' => 'obìnrin tó kúnlɛ̀: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏻‍♂‍➡' => 'ɔkùnrin tó kúnlɛ̀: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🧎🏼‍♂‍➡' => 'ɔkùnrin tó kúnlɛ̀: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏽‍♂‍➡' => 'ɔkùnrin tó kúnlɛ̀: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏾‍♂‍➡' => 'ɔkùnrin tó kúnlɛ̀: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏿‍♂‍➡' => 'ɔkùnrin tó kúnlɛ̀: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏻‍🦯‍➡' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🧑🏼‍🦯‍➡' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏽‍🦯‍➡' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏾‍🦯‍➡' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏿‍🦯‍➡' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏻‍🦯‍➡' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '👨🏼‍🦯‍➡' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏽‍🦯‍➡' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏾‍🦯‍➡' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏿‍🦯‍➡' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏻‍🦯‍➡' => 'obìnrin pɛ̀lú ɔ̀pá funfun: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '👩🏼‍🦯‍➡' => 'obìnrin pɛ̀lú ɔ̀pá funfun: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏽‍🦯‍➡' => 'obìnrin pɛ̀lú ɔ̀pá funfun: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏾‍🦯‍➡' => 'obìnrin pɛ̀lú ɔ̀pá funfun: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏿‍🦯‍➡' => 'obìnrin pɛ̀lú ɔ̀pá funfun: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏻‍🦼‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🧑🏼‍🦼‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏽‍🦼‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏾‍🦼‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏿‍🦼‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏻‍🦼‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '👨🏼‍🦼‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏽‍🦼‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏾‍🦼‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏿‍🦼‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏻‍🦼‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '👩🏼‍🦼‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏽‍🦼‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏾‍🦼‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏿‍🦼‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏻‍🦽‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🧑🏼‍🦽‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏽‍🦽‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏾‍🦽‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏿‍🦽‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏻‍🦽‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '👨🏼‍🦽‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏽‍🦽‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏾‍🦽‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👨🏿‍🦽‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏻‍🦽‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '👩🏼‍🦽‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏽‍🦽‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏾‍🦽‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '👩🏿‍🦽‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏻‍♀‍➡' => 'obìrin tí ń sáré: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🏃🏼‍♀‍➡' => 'obìrin tí ń sáré: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏽‍♀‍➡' => 'obìrin tí ń sáré: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏾‍♀‍➡' => 'obìrin tí ń sáré: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏿‍♀‍➡' => 'obìrin tí ń sáré: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏻‍♂‍➡' => 'ɔkùnrin tí ń sáré: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🏃🏼‍♂‍➡' => 'ɔkùnrin tí ń sáré: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏽‍♂‍➡' => 'ɔkùnrin tí ń sáré: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏾‍♂‍➡' => 'ɔkùnrin tí ń sáré: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏿‍♂‍➡' => 'ɔkùnrin tí ń sáré: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🫱🏻‍🫲🏼' => 'Ìbɔwɔ́: amɔ́lára àtiamɔ́lára díɛ̀',
    '🫱🏻‍🫲🏽' => 'Ìbɔwɔ́: amɔ́lára àtiamɔ́láwɔ̀ díɛ̀',
    '🫱🏻‍🫲🏾' => 'Ìbɔwɔ́: amɔ́lára àtiadúláwɔ̀ díɛ̀',
    '🫱🏻‍🫲🏿' => 'Ìbɔwɔ́: amɔ́lára àtiadúláwɔ̀',
    '🫱🏼‍🫲🏻' => 'Ìbɔwɔ́: amɔ́lára díɛ̀ àtiamɔ́lára',
    '🫱🏼‍🫲🏽' => 'Ìbɔwɔ́: amɔ́lára díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🫱🏼‍🫲🏾' => 'Ìbɔwɔ́: amɔ́lára díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '🫱🏼‍🫲🏿' => 'Ìbɔwɔ́: amɔ́lára díɛ̀ àtiadúláwɔ̀',
    '🫱🏽‍🫲🏻' => 'Ìbɔwɔ́: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára',
    '🫱🏽‍🫲🏼' => 'Ìbɔwɔ́: amɔ́láwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '🫱🏽‍🫲🏾' => 'Ìbɔwɔ́: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀ díɛ̀',
    '🫱🏽‍🫲🏿' => 'Ìbɔwɔ́: amɔ́láwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '🫱🏾‍🫲🏻' => 'Ìbɔwɔ́: adúláwɔ̀ díɛ̀ àtiamɔ́lára',
    '🫱🏾‍🫲🏼' => 'Ìbɔwɔ́: adúláwɔ̀ díɛ̀ àtiamɔ́lára díɛ̀',
    '🫱🏾‍🫲🏽' => 'Ìbɔwɔ́: adúláwɔ̀ díɛ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🫱🏾‍🫲🏿' => 'Ìbɔwɔ́: adúláwɔ̀ díɛ̀ àtiadúláwɔ̀',
    '🫱🏿‍🫲🏻' => 'Ìbɔwɔ́: adúláwɔ̀ àtiamɔ́lára',
    '🫱🏿‍🫲🏼' => 'Ìbɔwɔ́: adúláwɔ̀ àtiamɔ́lára díɛ̀',
    '🫱🏿‍🫲🏽' => 'Ìbɔwɔ́: adúláwɔ̀ àtiamɔ́láwɔ̀ díɛ̀',
    '🫱🏿‍🫲🏾' => 'Ìbɔwɔ́: adúláwɔ̀ àtiadúláwɔ̀ díɛ̀',
    '🚶‍♀‍➡' => 'obìnrin tí ń rìn: ìdojúkɔ ɔ̀tún',
    '🚶‍♂‍➡' => 'ɔkùnrin tí ń rìn: ìdojúkɔ ɔ̀tún',
    '🧎‍♀‍➡' => 'obìnrin tó kúnlɛ̀: ìdojúkɔ ɔ̀tún',
    '🧎‍♂‍➡' => 'ɔkùnrin tó kúnlɛ̀: ìdojúkɔ ɔ̀tún',
    '🧑‍🦯‍➡' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: ìdojúkɔ ɔ̀tún',
    '👨‍🦯‍➡' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: ìdojúkɔ ɔ̀tún',
    '👩‍🦯‍➡' => 'obìnrin pɛ̀lú ɔ̀pá funfun: ìdojúkɔ ɔ̀tún',
    '🧑‍🦼‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: ìdojúkɔ ɔ̀tún',
    '👨‍🦼‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: ìdojúkɔ ɔ̀tún',
    '👩‍🦼‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: ìdojúkɔ ɔ̀tún',
    '🧑‍🦽‍➡' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: ìdojúkɔ ɔ̀tún',
    '👨‍🦽‍➡' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: ìdojúkɔ ɔ̀tún',
    '👩‍🦽‍➡' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: ìdojúkɔ ɔ̀tún',
    '🏃‍♀‍➡' => 'obìrin tí ń sáré: ìdojúkɔ ɔ̀tún',
    '🏃‍♂‍➡' => 'ɔkùnrin tí ń sáré: ìdojúkɔ ɔ̀tún',
    '👩‍❤‍👨' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin àtiƆkùnrin',
    '👨‍❤‍👨' => 'Lɔkɔlaya Pɛlu ɔkan: Ɔkùnrin àtiƆkùnrin',
    '👩‍❤‍👩' => 'Lɔkɔlaya Pɛlu ɔkan: Obìnrin àtiObìnrin',
    '👨‍👩‍👦' => 'Ɛbí: Ɔkùnrin, Obìnrin, ɔmɔkùnrin',
    '👨‍👩‍👧' => 'Ɛbí: Ɔkùnrin, Obìnrin, ɔmɔbìrin',
    '👨‍👨‍👦' => 'Ɛbí: Ɔkùnrin, Ɔkùnrin, ɔmɔkùnrin',
    '👨‍👨‍👧' => 'Ɛbí: Ɔkùnrin, Ɔkùnrin, ɔmɔbìrin',
    '👩‍👩‍👦' => 'Ɛbí: Obìnrin, Obìnrin, ɔmɔkùnrin',
    '👩‍👩‍👧' => 'Ɛbí: Obìnrin, Obìnrin, ɔmɔbìrin',
    '👨‍👦‍👦' => 'Ɛbí: Ɔkùnrin, ɔmɔkùnrin, ɔmɔkùnrin',
    '👨‍👧‍👦' => 'Ɛbí: Ɔkùnrin, ɔmɔbìrin, ɔmɔkùnrin',
    '👨‍👧‍👧' => 'Ɛbí: Ɔkùnrin, ɔmɔbìrin, ɔmɔbìrin',
    '👩‍👦‍👦' => 'Ɛbí: Obìnrin, ɔmɔkùnrin, ɔmɔkùnrin',
    '👩‍👧‍👦' => 'Ɛbí: Obìnrin, ɔmɔbìrin, ɔmɔkùnrin',
    '👩‍👧‍👧' => 'Ɛbí: Obìnrin, ɔmɔbìrin, ɔmɔbìrin',
    '🧑‍🤝‍🧑' => 'àwɔn ènìyàn tó di ara wɔn lɔ́wɔ́ mú',
    '🧑‍🧑‍🧒' => 'ìdílé: àgbàlagbà, àgbàlagbà, ɔmɔdé',
    '🧑‍🧒‍🧒' => 'ìdílé: àgbàlagbà, ɔmɔdé, ɔmɔdé',
    '🧑🏻‍🦰' => 'àgbà: amɔ́lára àtiirun pupa',
    '🧑🏼‍🦰' => 'àgbà: amɔ́lára díɛ̀ àtiirun pupa',
    '🧑🏽‍🦰' => 'àgbà: amɔ́láwɔ̀ díɛ̀ àtiirun pupa',
    '🧑🏾‍🦰' => 'àgbà: adúláwɔ̀ díɛ̀ àtiirun pupa',
    '🧑🏿‍🦰' => 'àgbà: adúláwɔ̀ àtiirun pupa',
    '🧑🏻‍🦱' => 'àgbà: amɔ́lára àtiirun rírɔ̀',
    '🧑🏼‍🦱' => 'àgbà: amɔ́lára díɛ̀ àtiirun rírɔ̀',
    '🧑🏽‍🦱' => 'àgbà: amɔ́láwɔ̀ díɛ̀ àtiirun rírɔ̀',
    '🧑🏾‍🦱' => 'àgbà: adúláwɔ̀ díɛ̀ àtiirun rírɔ̀',
    '🧑🏿‍🦱' => 'àgbà: adúláwɔ̀ àtiirun rírɔ̀',
    '🧑🏻‍🦳' => 'àgbà: amɔ́lára àtiirun funfun',
    '🧑🏼‍🦳' => 'àgbà: amɔ́lára díɛ̀ àtiirun funfun',
    '🧑🏽‍🦳' => 'àgbà: amɔ́láwɔ̀ díɛ̀ àtiirun funfun',
    '🧑🏾‍🦳' => 'àgbà: adúláwɔ̀ díɛ̀ àtiirun funfun',
    '🧑🏿‍🦳' => 'àgbà: adúláwɔ̀ àtiirun funfun',
    '🧑🏻‍🦲' => 'àgbà: amɔ́lára àtiorí pípá',
    '🧑🏼‍🦲' => 'àgbà: amɔ́lára díɛ̀ àtiorí pípá',
    '🧑🏽‍🦲' => 'àgbà: amɔ́láwɔ̀ díɛ̀ àtiorí pípá',
    '🧑🏾‍🦲' => 'àgbà: adúláwɔ̀ díɛ̀ àtiorí pípá',
    '🧑🏿‍🦲' => 'àgbà: adúláwɔ̀ àtiorí pípá',
    '🧑🏻‍🩰' => 'oníjó alájòóyípo: amɔ́lára',
    '🧑🏼‍🩰' => 'oníjó alájòóyípo: amɔ́lára díɛ̀',
    '🧑🏽‍🩰' => 'oníjó alájòóyípo: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🩰' => 'oníjó alájòóyípo: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🩰' => 'oníjó alájòóyípo: adúláwɔ̀',
    '🧔🏻‍♂' => 'ɔkùnrin: amɔ́lára àtiirùgbɔ̀n',
    '🧔🏼‍♂' => 'ɔkùnrin: amɔ́lára díɛ̀ àtiirùgbɔ̀n',
    '🧔🏽‍♂' => 'ɔkùnrin: amɔ́láwɔ̀ díɛ̀ àtiirùgbɔ̀n',
    '🧔🏾‍♂' => 'ɔkùnrin: adúláwɔ̀ díɛ̀ àtiirùgbɔ̀n',
    '🧔🏿‍♂' => 'ɔkùnrin: adúláwɔ̀ àtiirùgbɔ̀n',
    '👱🏻‍♂' => 'ɔkùnrin onírun funfun: amɔ́lára',
    '👱🏼‍♂' => 'ɔkùnrin onírun funfun: amɔ́lára díɛ̀',
    '👱🏽‍♂' => 'ɔkùnrin onírun funfun: amɔ́láwɔ̀ díɛ̀',
    '👱🏾‍♂' => 'ɔkùnrin onírun funfun: adúláwɔ̀ díɛ̀',
    '👱🏿‍♂' => 'ɔkùnrin onírun funfun: adúláwɔ̀',
    '👨🏻‍🦰' => 'Ɔkùnrin: amɔ́lára àtiirun pupa',
    '👨🏼‍🦰' => 'Ɔkùnrin: amɔ́lára díɛ̀ àtiirun pupa',
    '👨🏽‍🦰' => 'Ɔkùnrin: amɔ́láwɔ̀ díɛ̀ àtiirun pupa',
    '👨🏾‍🦰' => 'Ɔkùnrin: adúláwɔ̀ díɛ̀ àtiirun pupa',
    '👨🏿‍🦰' => 'Ɔkùnrin: adúláwɔ̀ àtiirun pupa',
    '👨🏻‍🦱' => 'Ɔkùnrin: amɔ́lára àtiirun rírɔ̀',
    '👨🏼‍🦱' => 'Ɔkùnrin: amɔ́lára díɛ̀ àtiirun rírɔ̀',
    '👨🏽‍🦱' => 'Ɔkùnrin: amɔ́láwɔ̀ díɛ̀ àtiirun rírɔ̀',
    '👨🏾‍🦱' => 'Ɔkùnrin: adúláwɔ̀ díɛ̀ àtiirun rírɔ̀',
    '👨🏿‍🦱' => 'Ɔkùnrin: adúláwɔ̀ àtiirun rírɔ̀',
    '👨🏻‍🦳' => 'Ɔkùnrin: amɔ́lára àtiirun funfun',
    '👨🏼‍🦳' => 'Ɔkùnrin: amɔ́lára díɛ̀ àtiirun funfun',
    '👨🏽‍🦳' => 'Ɔkùnrin: amɔ́láwɔ̀ díɛ̀ àtiirun funfun',
    '👨🏾‍🦳' => 'Ɔkùnrin: adúláwɔ̀ díɛ̀ àtiirun funfun',
    '👨🏿‍🦳' => 'Ɔkùnrin: adúláwɔ̀ àtiirun funfun',
    '👨🏻‍🦲' => 'Ɔkùnrin: amɔ́lára àtiorí pípá',
    '👨🏼‍🦲' => 'Ɔkùnrin: amɔ́lára díɛ̀ àtiorí pípá',
    '👨🏽‍🦲' => 'Ɔkùnrin: amɔ́láwɔ̀ díɛ̀ àtiorí pípá',
    '👨🏾‍🦲' => 'Ɔkùnrin: adúláwɔ̀ díɛ̀ àtiorí pípá',
    '👨🏿‍🦲' => 'Ɔkùnrin: adúláwɔ̀ àtiorí pípá',
    '🧔🏻‍♀' => 'obìnrin: amɔ́lára àtiirùgbɔ̀n',
    '🧔🏼‍♀' => 'obìnrin: amɔ́lára díɛ̀ àtiirùgbɔ̀n',
    '🧔🏽‍♀' => 'obìnrin: amɔ́láwɔ̀ díɛ̀ àtiirùgbɔ̀n',
    '🧔🏾‍♀' => 'obìnrin: adúláwɔ̀ díɛ̀ àtiirùgbɔ̀n',
    '🧔🏿‍♀' => 'obìnrin: adúláwɔ̀ àtiirùgbɔ̀n',
    '👱🏻‍♀' => 'obìnrin onírun funfun: amɔ́lára',
    '👱🏼‍♀' => 'obìnrin onírun funfun: amɔ́lára díɛ̀',
    '👱🏽‍♀' => 'obìnrin onírun funfun: amɔ́láwɔ̀ díɛ̀',
    '👱🏾‍♀' => 'obìnrin onírun funfun: adúláwɔ̀ díɛ̀',
    '👱🏿‍♀' => 'obìnrin onírun funfun: adúláwɔ̀',
    '👩🏻‍🦰' => 'Obìnrin: amɔ́lára àtiirun pupa',
    '👩🏼‍🦰' => 'Obìnrin: amɔ́lára díɛ̀ àtiirun pupa',
    '👩🏽‍🦰' => 'Obìnrin: amɔ́láwɔ̀ díɛ̀ àtiirun pupa',
    '👩🏾‍🦰' => 'Obìnrin: adúláwɔ̀ díɛ̀ àtiirun pupa',
    '👩🏿‍🦰' => 'Obìnrin: adúláwɔ̀ àtiirun pupa',
    '👩🏻‍🦱' => 'Obìnrin: amɔ́lára àtiirun rírɔ̀',
    '👩🏼‍🦱' => 'Obìnrin: amɔ́lára díɛ̀ àtiirun rírɔ̀',
    '👩🏽‍🦱' => 'Obìnrin: amɔ́láwɔ̀ díɛ̀ àtiirun rírɔ̀',
    '👩🏾‍🦱' => 'Obìnrin: adúláwɔ̀ díɛ̀ àtiirun rírɔ̀',
    '👩🏿‍🦱' => 'Obìnrin: adúláwɔ̀ àtiirun rírɔ̀',
    '👩🏻‍🦳' => 'Obìnrin: amɔ́lára àtiirun funfun',
    '👩🏼‍🦳' => 'Obìnrin: amɔ́lára díɛ̀ àtiirun funfun',
    '👩🏽‍🦳' => 'Obìnrin: amɔ́láwɔ̀ díɛ̀ àtiirun funfun',
    '👩🏾‍🦳' => 'Obìnrin: adúláwɔ̀ díɛ̀ àtiirun funfun',
    '👩🏿‍🦳' => 'Obìnrin: adúláwɔ̀ àtiirun funfun',
    '👩🏻‍🦲' => 'Obìnrin: amɔ́lára àtiorí pípá',
    '👩🏼‍🦲' => 'Obìnrin: amɔ́lára díɛ̀ àtiorí pípá',
    '👩🏽‍🦲' => 'Obìnrin: amɔ́láwɔ̀ díɛ̀ àtiorí pípá',
    '👩🏾‍🦲' => 'Obìnrin: adúláwɔ̀ díɛ̀ àtiorí pípá',
    '👩🏿‍🦲' => 'Obìnrin: adúláwɔ̀ àtiorí pípá',
    '🙍🏻‍♂' => 'ɔkùnrin tí ń fajúro: amɔ́lára',
    '🙍🏼‍♂' => 'ɔkùnrin tí ń fajúro: amɔ́lára díɛ̀',
    '🙍🏽‍♂' => 'ɔkùnrin tí ń fajúro: amɔ́láwɔ̀ díɛ̀',
    '🙍🏾‍♂' => 'ɔkùnrin tí ń fajúro: adúláwɔ̀ díɛ̀',
    '🙍🏿‍♂' => 'ɔkùnrin tí ń fajúro: adúláwɔ̀',
    '🙍🏻‍♀' => 'obìnrin tí ń fajúro: amɔ́lára',
    '🙍🏼‍♀' => 'obìnrin tí ń fajúro: amɔ́lára díɛ̀',
    '🙍🏽‍♀' => 'obìnrin tí ń fajúro: amɔ́láwɔ̀ díɛ̀',
    '🙍🏾‍♀' => 'obìnrin tí ń fajúro: adúláwɔ̀ díɛ̀',
    '🙍🏿‍♀' => 'obìnrin tí ń fajúro: adúláwɔ̀',
    '🙎🏻‍♂' => 'ɔkùnrin tí ń shíshù ètè síta: amɔ́lára',
    '🙎🏼‍♂' => 'ɔkùnrin tí ń shíshù ètè síta: amɔ́lára díɛ̀',
    '🙎🏽‍♂' => 'ɔkùnrin tí ń shíshù ètè síta: amɔ́láwɔ̀ díɛ̀',
    '🙎🏾‍♂' => 'ɔkùnrin tí ń shíshù ètè síta: adúláwɔ̀ díɛ̀',
    '🙎🏿‍♂' => 'ɔkùnrin tí ń shíshù ètè síta: adúláwɔ̀',
    '🙎🏻‍♀' => 'obìnrin tí ń shíshù ètè síta: amɔ́lára',
    '🙎🏼‍♀' => 'obìnrin tí ń shíshù ètè síta: amɔ́lára díɛ̀',
    '🙎🏽‍♀' => 'obìnrin tí ń shíshù ètè síta: amɔ́láwɔ̀ díɛ̀',
    '🙎🏾‍♀' => 'obìnrin tí ń shíshù ètè síta: adúláwɔ̀ díɛ̀',
    '🙎🏿‍♀' => 'obìnrin tí ń shíshù ètè síta: adúláwɔ̀',
    '🙅🏻‍♂' => 'ɔkùnrin tí ń sɔ RÁRÁ: amɔ́lára',
    '🙅🏼‍♂' => 'ɔkùnrin tí ń sɔ RÁRÁ: amɔ́lára díɛ̀',
    '🙅🏽‍♂' => 'ɔkùnrin tí ń sɔ RÁRÁ: amɔ́láwɔ̀ díɛ̀',
    '🙅🏾‍♂' => 'ɔkùnrin tí ń sɔ RÁRÁ: adúláwɔ̀ díɛ̀',
    '🙅🏿‍♂' => 'ɔkùnrin tí ń sɔ RÁRÁ: adúláwɔ̀',
    '🙅🏻‍♀' => 'obìnrin tí ń sɔ RÁRÁ: amɔ́lára',
    '🙅🏼‍♀' => 'obìnrin tí ń sɔ RÁRÁ: amɔ́lára díɛ̀',
    '🙅🏽‍♀' => 'obìnrin tí ń sɔ RÁRÁ: amɔ́láwɔ̀ díɛ̀',
    '🙅🏾‍♀' => 'obìnrin tí ń sɔ RÁRÁ: adúláwɔ̀ díɛ̀',
    '🙅🏿‍♀' => 'obìnrin tí ń sɔ RÁRÁ: adúláwɔ̀',
    '🙆🏻‍♂' => 'ɔkùnrin tí ń sɔ ÓDÁRA: amɔ́lára',
    '🙆🏼‍♂' => 'ɔkùnrin tí ń sɔ ÓDÁRA: amɔ́lára díɛ̀',
    '🙆🏽‍♂' => 'ɔkùnrin tí ń sɔ ÓDÁRA: amɔ́láwɔ̀ díɛ̀',
    '🙆🏾‍♂' => 'ɔkùnrin tí ń sɔ ÓDÁRA: adúláwɔ̀ díɛ̀',
    '🙆🏿‍♂' => 'ɔkùnrin tí ń sɔ ÓDÁRA: adúláwɔ̀',
    '🙆🏻‍♀' => 'obìnrin tí ń sɔ ÓDÁRA: amɔ́lára',
    '🙆🏼‍♀' => 'obìnrin tí ń sɔ ÓDÁRA: amɔ́lára díɛ̀',
    '🙆🏽‍♀' => 'obìnrin tí ń sɔ ÓDÁRA: amɔ́láwɔ̀ díɛ̀',
    '🙆🏾‍♀' => 'obìnrin tí ń sɔ ÓDÁRA: adúláwɔ̀ díɛ̀',
    '🙆🏿‍♀' => 'obìnrin tí ń sɔ ÓDÁRA: adúláwɔ̀',
    '💁🏻‍♂' => 'ɔkùnrin tí ń tɔ́ka ɔwɔ́: amɔ́lára',
    '💁🏼‍♂' => 'ɔkùnrin tí ń tɔ́ka ɔwɔ́: amɔ́lára díɛ̀',
    '💁🏽‍♂' => 'ɔkùnrin tí ń tɔ́ka ɔwɔ́: amɔ́láwɔ̀ díɛ̀',
    '💁🏾‍♂' => 'ɔkùnrin tí ń tɔ́ka ɔwɔ́: adúláwɔ̀ díɛ̀',
    '💁🏿‍♂' => 'ɔkùnrin tí ń tɔ́ka ɔwɔ́: adúláwɔ̀',
    '💁🏻‍♀' => 'obìnrin tí ń tɔ́ka ɔwɔ́: amɔ́lára',
    '💁🏼‍♀' => 'obìnrin tí ń tɔ́ka ɔwɔ́: amɔ́lára díɛ̀',
    '💁🏽‍♀' => 'obìnrin tí ń tɔ́ka ɔwɔ́: amɔ́láwɔ̀ díɛ̀',
    '💁🏾‍♀' => 'obìnrin tí ń tɔ́ka ɔwɔ́: adúláwɔ̀ díɛ̀',
    '💁🏿‍♀' => 'obìnrin tí ń tɔ́ka ɔwɔ́: adúláwɔ̀',
    '🙋🏻‍♂' => 'ɔkùnrintí ń nawɔ́ sókè: amɔ́lára',
    '🙋🏼‍♂' => 'ɔkùnrintí ń nawɔ́ sókè: amɔ́lára díɛ̀',
    '🙋🏽‍♂' => 'ɔkùnrintí ń nawɔ́ sókè: amɔ́láwɔ̀ díɛ̀',
    '🙋🏾‍♂' => 'ɔkùnrintí ń nawɔ́ sókè: adúláwɔ̀ díɛ̀',
    '🙋🏿‍♂' => 'ɔkùnrintí ń nawɔ́ sókè: adúláwɔ̀',
    '🙋🏻‍♀' => 'obìnrin tí ń nawɔ́ sókè: amɔ́lára',
    '🙋🏼‍♀' => 'obìnrin tí ń nawɔ́ sókè: amɔ́lára díɛ̀',
    '🙋🏽‍♀' => 'obìnrin tí ń nawɔ́ sókè: amɔ́láwɔ̀ díɛ̀',
    '🙋🏾‍♀' => 'obìnrin tí ń nawɔ́ sókè: adúláwɔ̀ díɛ̀',
    '🙋🏿‍♀' => 'obìnrin tí ń nawɔ́ sókè: adúláwɔ̀',
    '🧏🏻‍♂' => 'ɔkùnrin adití: amɔ́lára',
    '🧏🏼‍♂' => 'ɔkùnrin adití: amɔ́lára díɛ̀',
    '🧏🏽‍♂' => 'ɔkùnrin adití: amɔ́láwɔ̀ díɛ̀',
    '🧏🏾‍♂' => 'ɔkùnrin adití: adúláwɔ̀ díɛ̀',
    '🧏🏿‍♂' => 'ɔkùnrin adití: adúláwɔ̀',
    '🧏🏻‍♀' => 'obìnrin adití: amɔ́lára',
    '🧏🏼‍♀' => 'obìnrin adití: amɔ́lára díɛ̀',
    '🧏🏽‍♀' => 'obìnrin adití: amɔ́láwɔ̀ díɛ̀',
    '🧏🏾‍♀' => 'obìnrin adití: adúláwɔ̀ díɛ̀',
    '🧏🏿‍♀' => 'obìnrin adití: adúláwɔ̀',
    '🙇🏻‍♂' => 'ɔkùnrin tí ń tɛríba: amɔ́lára',
    '🙇🏼‍♂' => 'ɔkùnrin tí ń tɛríba: amɔ́lára díɛ̀',
    '🙇🏽‍♂' => 'ɔkùnrin tí ń tɛríba: amɔ́láwɔ̀ díɛ̀',
    '🙇🏾‍♂' => 'ɔkùnrin tí ń tɛríba: adúláwɔ̀ díɛ̀',
    '🙇🏿‍♂' => 'ɔkùnrin tí ń tɛríba: adúláwɔ̀',
    '🙇🏻‍♀' => 'obìnrin tí ń tɛríba: amɔ́lára',
    '🙇🏼‍♀' => 'obìnrin tí ń tɛríba: amɔ́lára díɛ̀',
    '🙇🏽‍♀' => 'obìnrin tí ń tɛríba: amɔ́láwɔ̀ díɛ̀',
    '🙇🏾‍♀' => 'obìnrin tí ń tɛríba: adúláwɔ̀ díɛ̀',
    '🙇🏿‍♀' => 'obìnrin tí ń tɛríba: adúláwɔ̀',
    '🤦🏻‍♂' => 'ɔkùnrin tín fɔwɔ́bojú: amɔ́lára',
    '🤦🏼‍♂' => 'ɔkùnrin tín fɔwɔ́bojú: amɔ́lára díɛ̀',
    '🤦🏽‍♂' => 'ɔkùnrin tín fɔwɔ́bojú: amɔ́láwɔ̀ díɛ̀',
    '🤦🏾‍♂' => 'ɔkùnrin tín fɔwɔ́bojú: adúláwɔ̀ díɛ̀',
    '🤦🏿‍♂' => 'ɔkùnrin tín fɔwɔ́bojú: adúláwɔ̀',
    '🤦🏻‍♀' => 'obìnrí tín fɔwɔ́bojú: amɔ́lára',
    '🤦🏼‍♀' => 'obìnrí tín fɔwɔ́bojú: amɔ́lára díɛ̀',
    '🤦🏽‍♀' => 'obìnrí tín fɔwɔ́bojú: amɔ́láwɔ̀ díɛ̀',
    '🤦🏾‍♀' => 'obìnrí tín fɔwɔ́bojú: adúláwɔ̀ díɛ̀',
    '🤦🏿‍♀' => 'obìnrí tín fɔwɔ́bojú: adúláwɔ̀',
    '🤷🏻‍♂' => 'ɔkùnrin tí ń gúnpá: amɔ́lára',
    '🤷🏼‍♂' => 'ɔkùnrin tí ń gúnpá: amɔ́lára díɛ̀',
    '🤷🏽‍♂' => 'ɔkùnrin tí ń gúnpá: amɔ́láwɔ̀ díɛ̀',
    '🤷🏾‍♂' => 'ɔkùnrin tí ń gúnpá: adúláwɔ̀ díɛ̀',
    '🤷🏿‍♂' => 'ɔkùnrin tí ń gúnpá: adúláwɔ̀',
    '🤷🏻‍♀' => 'obìǹrin tí ń gúnpa: amɔ́lára',
    '🤷🏼‍♀' => 'obìǹrin tí ń gúnpa: amɔ́lára díɛ̀',
    '🤷🏽‍♀' => 'obìǹrin tí ń gúnpa: amɔ́láwɔ̀ díɛ̀',
    '🤷🏾‍♀' => 'obìǹrin tí ń gúnpa: adúláwɔ̀ díɛ̀',
    '🤷🏿‍♀' => 'obìǹrin tí ń gúnpa: adúláwɔ̀',
    '🧑🏻‍⚕' => 'òshìshɛ́ ìlera: amɔ́lára',
    '🧑🏼‍⚕' => 'òshìshɛ́ ìlera: amɔ́lára díɛ̀',
    '🧑🏽‍⚕' => 'òshìshɛ́ ìlera: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍⚕' => 'òshìshɛ́ ìlera: adúláwɔ̀ díɛ̀',
    '🧑🏿‍⚕' => 'òshìshɛ́ ìlera: adúláwɔ̀',
    '👨🏻‍⚕' => 'ɔkùnrín òshìshɛ́ ètò ìlera: amɔ́lára',
    '👨🏼‍⚕' => 'ɔkùnrín òshìshɛ́ ètò ìlera: amɔ́lára díɛ̀',
    '👨🏽‍⚕' => 'ɔkùnrín òshìshɛ́ ètò ìlera: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍⚕' => 'ɔkùnrín òshìshɛ́ ètò ìlera: adúláwɔ̀ díɛ̀',
    '👨🏿‍⚕' => 'ɔkùnrín òshìshɛ́ ètò ìlera: adúláwɔ̀',
    '👩🏻‍⚕' => 'obìrin òshìshɛ́ ètò ìlera: amɔ́lára',
    '👩🏼‍⚕' => 'obìrin òshìshɛ́ ètò ìlera: amɔ́lára díɛ̀',
    '👩🏽‍⚕' => 'obìrin òshìshɛ́ ètò ìlera: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍⚕' => 'obìrin òshìshɛ́ ètò ìlera: adúláwɔ̀ díɛ̀',
    '👩🏿‍⚕' => 'obìrin òshìshɛ́ ètò ìlera: adúláwɔ̀',
    '🧑🏻‍🎓' => 'akɛ́kɔ̀ɔ́: amɔ́lára',
    '🧑🏼‍🎓' => 'akɛ́kɔ̀ɔ́: amɔ́lára díɛ̀',
    '🧑🏽‍🎓' => 'akɛ́kɔ̀ɔ́: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🎓' => 'akɛ́kɔ̀ɔ́: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🎓' => 'akɛ́kɔ̀ɔ́: adúláwɔ̀',
    '👨🏻‍🎓' => 'ɔkùnrin akɛ́kɔ̀ɔ́: amɔ́lára',
    '👨🏼‍🎓' => 'ɔkùnrin akɛ́kɔ̀ɔ́: amɔ́lára díɛ̀',
    '👨🏽‍🎓' => 'ɔkùnrin akɛ́kɔ̀ɔ́: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🎓' => 'ɔkùnrin akɛ́kɔ̀ɔ́: adúláwɔ̀ díɛ̀',
    '👨🏿‍🎓' => 'ɔkùnrin akɛ́kɔ̀ɔ́: adúláwɔ̀',
    '👩🏻‍🎓' => 'obìrin akɛ́kɔ̀ɔ́: amɔ́lára',
    '👩🏼‍🎓' => 'obìrin akɛ́kɔ̀ɔ́: amɔ́lára díɛ̀',
    '👩🏽‍🎓' => 'obìrin akɛ́kɔ̀ɔ́: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🎓' => 'obìrin akɛ́kɔ̀ɔ́: adúláwɔ̀ díɛ̀',
    '👩🏿‍🎓' => 'obìrin akɛ́kɔ̀ɔ́: adúláwɔ̀',
    '🧑🏻‍🏫' => 'olùkɔ́: amɔ́lára',
    '🧑🏼‍🏫' => 'olùkɔ́: amɔ́lára díɛ̀',
    '🧑🏽‍🏫' => 'olùkɔ́: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🏫' => 'olùkɔ́: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🏫' => 'olùkɔ́: adúláwɔ̀',
    '👨🏻‍🏫' => 'ɔkùnrin olùkɔ́: amɔ́lára',
    '👨🏼‍🏫' => 'ɔkùnrin olùkɔ́: amɔ́lára díɛ̀',
    '👨🏽‍🏫' => 'ɔkùnrin olùkɔ́: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🏫' => 'ɔkùnrin olùkɔ́: adúláwɔ̀ díɛ̀',
    '👨🏿‍🏫' => 'ɔkùnrin olùkɔ́: adúláwɔ̀',
    '👩🏻‍🏫' => 'obìnrin olùkɔ́: amɔ́lára',
    '👩🏼‍🏫' => 'obìnrin olùkɔ́: amɔ́lára díɛ̀',
    '👩🏽‍🏫' => 'obìnrin olùkɔ́: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🏫' => 'obìnrin olùkɔ́: adúláwɔ̀ díɛ̀',
    '👩🏿‍🏫' => 'obìnrin olùkɔ́: adúláwɔ̀',
    '🧑🏻‍⚖' => 'adájɔ́: amɔ́lára',
    '🧑🏼‍⚖' => 'adájɔ́: amɔ́lára díɛ̀',
    '🧑🏽‍⚖' => 'adájɔ́: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍⚖' => 'adájɔ́: adúláwɔ̀ díɛ̀',
    '🧑🏿‍⚖' => 'adájɔ́: adúláwɔ̀',
    '👨🏻‍⚖' => 'ɔkùnrin adájɔ́: amɔ́lára',
    '👨🏼‍⚖' => 'ɔkùnrin adájɔ́: amɔ́lára díɛ̀',
    '👨🏽‍⚖' => 'ɔkùnrin adájɔ́: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍⚖' => 'ɔkùnrin adájɔ́: adúláwɔ̀ díɛ̀',
    '👨🏿‍⚖' => 'ɔkùnrin adájɔ́: adúláwɔ̀',
    '👩🏻‍⚖' => 'obìnrin adájɔ́: amɔ́lára',
    '👩🏼‍⚖' => 'obìnrin adájɔ́: amɔ́lára díɛ̀',
    '👩🏽‍⚖' => 'obìnrin adájɔ́: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍⚖' => 'obìnrin adájɔ́: adúláwɔ̀ díɛ̀',
    '👩🏿‍⚖' => 'obìnrin adájɔ́: adúláwɔ̀',
    '🧑🏻‍🌾' => 'àgbɛ̀: amɔ́lára',
    '🧑🏼‍🌾' => 'àgbɛ̀: amɔ́lára díɛ̀',
    '🧑🏽‍🌾' => 'àgbɛ̀: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🌾' => 'àgbɛ̀: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🌾' => 'àgbɛ̀: adúláwɔ̀',
    '👨🏻‍🌾' => 'ɔkùnrin àgbɛ́: amɔ́lára',
    '👨🏼‍🌾' => 'ɔkùnrin àgbɛ́: amɔ́lára díɛ̀',
    '👨🏽‍🌾' => 'ɔkùnrin àgbɛ́: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🌾' => 'ɔkùnrin àgbɛ́: adúláwɔ̀ díɛ̀',
    '👨🏿‍🌾' => 'ɔkùnrin àgbɛ́: adúláwɔ̀',
    '👩🏻‍🌾' => 'obìrinàgbɛ́: amɔ́lára',
    '👩🏼‍🌾' => 'obìrinàgbɛ́: amɔ́lára díɛ̀',
    '👩🏽‍🌾' => 'obìrinàgbɛ́: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🌾' => 'obìrinàgbɛ́: adúláwɔ̀ díɛ̀',
    '👩🏿‍🌾' => 'obìrinàgbɛ́: adúláwɔ̀',
    '🧑🏻‍🍳' => 'alásè: amɔ́lára',
    '🧑🏼‍🍳' => 'alásè: amɔ́lára díɛ̀',
    '🧑🏽‍🍳' => 'alásè: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🍳' => 'alásè: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🍳' => 'alásè: adúláwɔ̀',
    '👨🏻‍🍳' => 'ɔkùnrin olùse ónjɛ: amɔ́lára',
    '👨🏼‍🍳' => 'ɔkùnrin olùse ónjɛ: amɔ́lára díɛ̀',
    '👨🏽‍🍳' => 'ɔkùnrin olùse ónjɛ: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🍳' => 'ɔkùnrin olùse ónjɛ: adúláwɔ̀ díɛ̀',
    '👨🏿‍🍳' => 'ɔkùnrin olùse ónjɛ: adúláwɔ̀',
    '👩🏻‍🍳' => 'obìrin olùse ónjɛ: amɔ́lára',
    '👩🏼‍🍳' => 'obìrin olùse ónjɛ: amɔ́lára díɛ̀',
    '👩🏽‍🍳' => 'obìrin olùse ónjɛ: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🍳' => 'obìrin olùse ónjɛ: adúláwɔ̀ díɛ̀',
    '👩🏿‍🍳' => 'obìrin olùse ónjɛ: adúláwɔ̀',
    '🧑🏻‍🔧' => 'mɛkáníìkì: amɔ́lára',
    '🧑🏼‍🔧' => 'mɛkáníìkì: amɔ́lára díɛ̀',
    '🧑🏽‍🔧' => 'mɛkáníìkì: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🔧' => 'mɛkáníìkì: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🔧' => 'mɛkáníìkì: adúláwɔ̀',
    '👨🏻‍🔧' => 'ɔkùnrin atún ɔkɔ̀ she: amɔ́lára',
    '👨🏼‍🔧' => 'ɔkùnrin atún ɔkɔ̀ she: amɔ́lára díɛ̀',
    '👨🏽‍🔧' => 'ɔkùnrin atún ɔkɔ̀ she: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🔧' => 'ɔkùnrin atún ɔkɔ̀ she: adúláwɔ̀ díɛ̀',
    '👨🏿‍🔧' => 'ɔkùnrin atún ɔkɔ̀ she: adúláwɔ̀',
    '👩🏻‍🔧' => 'obìrin atún ɔkɔ̀ she: amɔ́lára',
    '👩🏼‍🔧' => 'obìrin atún ɔkɔ̀ she: amɔ́lára díɛ̀',
    '👩🏽‍🔧' => 'obìrin atún ɔkɔ̀ she: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🔧' => 'obìrin atún ɔkɔ̀ she: adúláwɔ̀ díɛ̀',
    '👩🏿‍🔧' => 'obìrin atún ɔkɔ̀ she: adúláwɔ̀',
    '🧑🏻‍🏭' => 'òshìshɛ́ ilé-ishɛ́ ashàgbéjáde ɔjà: amɔ́lára',
    '🧑🏼‍🏭' => 'òshìshɛ́ ilé-ishɛ́ ashàgbéjáde ɔjà: amɔ́lára díɛ̀',
    '🧑🏽‍🏭' => 'òshìshɛ́ ilé-ishɛ́ ashàgbéjáde ɔjà: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🏭' => 'òshìshɛ́ ilé-ishɛ́ ashàgbéjáde ɔjà: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🏭' => 'òshìshɛ́ ilé-ishɛ́ ashàgbéjáde ɔjà: adúláwɔ̀',
    '👨🏻‍🏭' => 'ɔkùnrin òshìshɛ́ ilé-ishɛ́: amɔ́lára',
    '👨🏼‍🏭' => 'ɔkùnrin òshìshɛ́ ilé-ishɛ́: amɔ́lára díɛ̀',
    '👨🏽‍🏭' => 'ɔkùnrin òshìshɛ́ ilé-ishɛ́: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🏭' => 'ɔkùnrin òshìshɛ́ ilé-ishɛ́: adúláwɔ̀ díɛ̀',
    '👨🏿‍🏭' => 'ɔkùnrin òshìshɛ́ ilé-ishɛ́: adúláwɔ̀',
    '👩🏻‍🏭' => 'obìrin òshìshɛ́ ilé-ishɛ́: amɔ́lára',
    '👩🏼‍🏭' => 'obìrin òshìshɛ́ ilé-ishɛ́: amɔ́lára díɛ̀',
    '👩🏽‍🏭' => 'obìrin òshìshɛ́ ilé-ishɛ́: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🏭' => 'obìrin òshìshɛ́ ilé-ishɛ́: adúláwɔ̀ díɛ̀',
    '👩🏿‍🏭' => 'obìrin òshìshɛ́ ilé-ishɛ́: adúláwɔ̀',
    '🧑🏻‍💼' => 'òshìshɛ́ ɔ́fíìsì: amɔ́lára',
    '🧑🏼‍💼' => 'òshìshɛ́ ɔ́fíìsì: amɔ́lára díɛ̀',
    '🧑🏽‍💼' => 'òshìshɛ́ ɔ́fíìsì: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍💼' => 'òshìshɛ́ ɔ́fíìsì: adúláwɔ̀ díɛ̀',
    '🧑🏿‍💼' => 'òshìshɛ́ ɔ́fíìsì: adúláwɔ̀',
    '👨🏻‍💼' => 'ɔkùnrin òshìshɛ́ ɔ́físì: amɔ́lára',
    '👨🏼‍💼' => 'ɔkùnrin òshìshɛ́ ɔ́físì: amɔ́lára díɛ̀',
    '👨🏽‍💼' => 'ɔkùnrin òshìshɛ́ ɔ́físì: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍💼' => 'ɔkùnrin òshìshɛ́ ɔ́físì: adúláwɔ̀ díɛ̀',
    '👨🏿‍💼' => 'ɔkùnrin òshìshɛ́ ɔ́físì: adúláwɔ̀',
    '👩🏻‍💼' => 'obìrin òshìshɛ́ ɔ́físì: amɔ́lára',
    '👩🏼‍💼' => 'obìrin òshìshɛ́ ɔ́físì: amɔ́lára díɛ̀',
    '👩🏽‍💼' => 'obìrin òshìshɛ́ ɔ́físì: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍💼' => 'obìrin òshìshɛ́ ɔ́físì: adúláwɔ̀ díɛ̀',
    '👩🏿‍💼' => 'obìrin òshìshɛ́ ɔ́físì: adúláwɔ̀',
    '🧑🏻‍🔬' => 'onímɔ̀ sáyɛ́ǹsì: amɔ́lára',
    '🧑🏼‍🔬' => 'onímɔ̀ sáyɛ́ǹsì: amɔ́lára díɛ̀',
    '🧑🏽‍🔬' => 'onímɔ̀ sáyɛ́ǹsì: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🔬' => 'onímɔ̀ sáyɛ́ǹsì: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🔬' => 'onímɔ̀ sáyɛ́ǹsì: adúláwɔ̀',
    '👨🏻‍🔬' => 'ɔkùnrín síyɛ́nsì: amɔ́lára',
    '👨🏼‍🔬' => 'ɔkùnrín síyɛ́nsì: amɔ́lára díɛ̀',
    '👨🏽‍🔬' => 'ɔkùnrín síyɛ́nsì: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🔬' => 'ɔkùnrín síyɛ́nsì: adúláwɔ̀ díɛ̀',
    '👨🏿‍🔬' => 'ɔkùnrín síyɛ́nsì: adúláwɔ̀',
    '👩🏻‍🔬' => 'obìrin síyɛ́nsì: amɔ́lára',
    '👩🏼‍🔬' => 'obìrin síyɛ́nsì: amɔ́lára díɛ̀',
    '👩🏽‍🔬' => 'obìrin síyɛ́nsì: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🔬' => 'obìrin síyɛ́nsì: adúláwɔ̀ díɛ̀',
    '👩🏿‍🔬' => 'obìrin síyɛ́nsì: adúláwɔ̀',
    '🧑🏻‍💻' => 'akɔ́shɛ́mɔshɛ́ ìmɔ̀-ɛ̀rɔ: amɔ́lára',
    '🧑🏼‍💻' => 'akɔ́shɛ́mɔshɛ́ ìmɔ̀-ɛ̀rɔ: amɔ́lára díɛ̀',
    '🧑🏽‍💻' => 'akɔ́shɛ́mɔshɛ́ ìmɔ̀-ɛ̀rɔ: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍💻' => 'akɔ́shɛ́mɔshɛ́ ìmɔ̀-ɛ̀rɔ: adúláwɔ̀ díɛ̀',
    '🧑🏿‍💻' => 'akɔ́shɛ́mɔshɛ́ ìmɔ̀-ɛ̀rɔ: adúláwɔ̀',
    '👨🏻‍💻' => 'ɔkùnrin oníms ɛ̀rɔ: amɔ́lára',
    '👨🏼‍💻' => 'ɔkùnrin oníms ɛ̀rɔ: amɔ́lára díɛ̀',
    '👨🏽‍💻' => 'ɔkùnrin oníms ɛ̀rɔ: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍💻' => 'ɔkùnrin oníms ɛ̀rɔ: adúláwɔ̀ díɛ̀',
    '👨🏿‍💻' => 'ɔkùnrin oníms ɛ̀rɔ: adúláwɔ̀',
    '👩🏻‍💻' => 'obìrin onímɔ̀ ɛ̀rɔ: amɔ́lára',
    '👩🏼‍💻' => 'obìrin onímɔ̀ ɛ̀rɔ: amɔ́lára díɛ̀',
    '👩🏽‍💻' => 'obìrin onímɔ̀ ɛ̀rɔ: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍💻' => 'obìrin onímɔ̀ ɛ̀rɔ: adúláwɔ̀ díɛ̀',
    '👩🏿‍💻' => 'obìrin onímɔ̀ ɛ̀rɔ: adúláwɔ̀',
    '🧑🏻‍🎤' => 'akɔrin: amɔ́lára',
    '🧑🏼‍🎤' => 'akɔrin: amɔ́lára díɛ̀',
    '🧑🏽‍🎤' => 'akɔrin: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🎤' => 'akɔrin: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🎤' => 'akɔrin: adúláwɔ̀',
    '👨🏻‍🎤' => 'ɔkùnrin olórin: amɔ́lára',
    '👨🏼‍🎤' => 'ɔkùnrin olórin: amɔ́lára díɛ̀',
    '👨🏽‍🎤' => 'ɔkùnrin olórin: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🎤' => 'ɔkùnrin olórin: adúláwɔ̀ díɛ̀',
    '👨🏿‍🎤' => 'ɔkùnrin olórin: adúláwɔ̀',
    '👩🏻‍🎤' => 'obìnrin olórin: amɔ́lára',
    '👩🏼‍🎤' => 'obìnrin olórin: amɔ́lára díɛ̀',
    '👩🏽‍🎤' => 'obìnrin olórin: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🎤' => 'obìnrin olórin: adúláwɔ̀ díɛ̀',
    '👩🏿‍🎤' => 'obìnrin olórin: adúláwɔ̀',
    '🧑🏻‍🎨' => 'ashɛ̀dá àwòrán: amɔ́lára',
    '🧑🏼‍🎨' => 'ashɛ̀dá àwòrán: amɔ́lára díɛ̀',
    '🧑🏽‍🎨' => 'ashɛ̀dá àwòrán: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🎨' => 'ashɛ̀dá àwòrán: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🎨' => 'ashɛ̀dá àwòrán: adúláwɔ̀',
    '👨🏻‍🎨' => 'ɔkùnrin òshèré: amɔ́lára',
    '👨🏼‍🎨' => 'ɔkùnrin òshèré: amɔ́lára díɛ̀',
    '👨🏽‍🎨' => 'ɔkùnrin òshèré: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🎨' => 'ɔkùnrin òshèré: adúláwɔ̀ díɛ̀',
    '👨🏿‍🎨' => 'ɔkùnrin òshèré: adúláwɔ̀',
    '👩🏻‍🎨' => 'obìrin òshèré: amɔ́lára',
    '👩🏼‍🎨' => 'obìrin òshèré: amɔ́lára díɛ̀',
    '👩🏽‍🎨' => 'obìrin òshèré: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🎨' => 'obìrin òshèré: adúláwɔ̀ díɛ̀',
    '👩🏿‍🎨' => 'obìrin òshèré: adúláwɔ̀',
    '🧑🏻‍✈' => 'atukɔ̀-òfurufú: amɔ́lára',
    '🧑🏼‍✈' => 'atukɔ̀-òfurufú: amɔ́lára díɛ̀',
    '🧑🏽‍✈' => 'atukɔ̀-òfurufú: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍✈' => 'atukɔ̀-òfurufú: adúláwɔ̀ díɛ̀',
    '🧑🏿‍✈' => 'atukɔ̀-òfurufú: adúláwɔ̀',
    '👨🏻‍✈' => 'ɔkùnrin awa ɔkɔ́ bàlú: amɔ́lára',
    '👨🏼‍✈' => 'ɔkùnrin awa ɔkɔ́ bàlú: amɔ́lára díɛ̀',
    '👨🏽‍✈' => 'ɔkùnrin awa ɔkɔ́ bàlú: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍✈' => 'ɔkùnrin awa ɔkɔ́ bàlú: adúláwɔ̀ díɛ̀',
    '👨🏿‍✈' => 'ɔkùnrin awa ɔkɔ́ bàlú: adúláwɔ̀',
    '👩🏻‍✈' => 'obìrin awa ɔkɔ́ bàlú: amɔ́lára',
    '👩🏼‍✈' => 'obìrin awa ɔkɔ́ bàlú: amɔ́lára díɛ̀',
    '👩🏽‍✈' => 'obìrin awa ɔkɔ́ bàlú: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍✈' => 'obìrin awa ɔkɔ́ bàlú: adúláwɔ̀ díɛ̀',
    '👩🏿‍✈' => 'obìrin awa ɔkɔ́ bàlú: adúláwɔ̀',
    '🧑🏻‍🚀' => 'arìnrìn-àjò lɔ sí ayé mìíràn: amɔ́lára',
    '🧑🏼‍🚀' => 'arìnrìn-àjò lɔ sí ayé mìíràn: amɔ́lára díɛ̀',
    '🧑🏽‍🚀' => 'arìnrìn-àjò lɔ sí ayé mìíràn: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🚀' => 'arìnrìn-àjò lɔ sí ayé mìíràn: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🚀' => 'arìnrìn-àjò lɔ sí ayé mìíràn: adúláwɔ̀',
    '👨🏻‍🚀' => 'ɔkùnrin olùwádìí inú òshùpá: amɔ́lára',
    '👨🏼‍🚀' => 'ɔkùnrin olùwádìí inú òshùpá: amɔ́lára díɛ̀',
    '👨🏽‍🚀' => 'ɔkùnrin olùwádìí inú òshùpá: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🚀' => 'ɔkùnrin olùwádìí inú òshùpá: adúláwɔ̀ díɛ̀',
    '👨🏿‍🚀' => 'ɔkùnrin olùwádìí inú òshùpá: adúláwɔ̀',
    '👩🏻‍🚀' => 'obìrinolùwádìí inú òshùpá: amɔ́lára',
    '👩🏼‍🚀' => 'obìrinolùwádìí inú òshùpá: amɔ́lára díɛ̀',
    '👩🏽‍🚀' => 'obìrinolùwádìí inú òshùpá: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🚀' => 'obìrinolùwádìí inú òshùpá: adúláwɔ̀ díɛ̀',
    '👩🏿‍🚀' => 'obìrinolùwádìí inú òshùpá: adúláwɔ̀',
    '🧑🏻‍🚒' => 'panápaná: amɔ́lára',
    '🧑🏼‍🚒' => 'panápaná: amɔ́lára díɛ̀',
    '🧑🏽‍🚒' => 'panápaná: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🚒' => 'panápaná: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🚒' => 'panápaná: adúláwɔ̀',
    '👨🏻‍🚒' => 'ɔkùnrin panapanɔ́: amɔ́lára',
    '👨🏼‍🚒' => 'ɔkùnrin panapanɔ́: amɔ́lára díɛ̀',
    '👨🏽‍🚒' => 'ɔkùnrin panapanɔ́: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🚒' => 'ɔkùnrin panapanɔ́: adúláwɔ̀ díɛ̀',
    '👨🏿‍🚒' => 'ɔkùnrin panapanɔ́: adúláwɔ̀',
    '👩🏻‍🚒' => 'obìrin panapanɔ́: amɔ́lára',
    '👩🏼‍🚒' => 'obìrin panapanɔ́: amɔ́lára díɛ̀',
    '👩🏽‍🚒' => 'obìrin panapanɔ́: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🚒' => 'obìrin panapanɔ́: adúláwɔ̀ díɛ̀',
    '👩🏿‍🚒' => 'obìrin panapanɔ́: adúláwɔ̀',
    '👮🏻‍♂' => 'ɔkùnrin ɔlɔpa: amɔ́lára',
    '👮🏼‍♂' => 'ɔkùnrin ɔlɔpa: amɔ́lára díɛ̀',
    '👮🏽‍♂' => 'ɔkùnrin ɔlɔpa: amɔ́láwɔ̀ díɛ̀',
    '👮🏾‍♂' => 'ɔkùnrin ɔlɔpa: adúláwɔ̀ díɛ̀',
    '👮🏿‍♂' => 'ɔkùnrin ɔlɔpa: adúláwɔ̀',
    '👮🏻‍♀' => 'obìnrin ɔlɔpa: amɔ́lára',
    '👮🏼‍♀' => 'obìnrin ɔlɔpa: amɔ́lára díɛ̀',
    '👮🏽‍♀' => 'obìnrin ɔlɔpa: amɔ́láwɔ̀ díɛ̀',
    '👮🏾‍♀' => 'obìnrin ɔlɔpa: adúláwɔ̀ díɛ̀',
    '👮🏿‍♀' => 'obìnrin ɔlɔpa: adúláwɔ̀',
    '🕵🏻‍♂' => 'ɔkùnrin ɔ̀tɛlèmúyé: amɔ́lára',
    '🕵🏼‍♂' => 'ɔkùnrin ɔ̀tɛlèmúyé: amɔ́lára díɛ̀',
    '🕵🏽‍♂' => 'ɔkùnrin ɔ̀tɛlèmúyé: amɔ́láwɔ̀ díɛ̀',
    '🕵🏾‍♂' => 'ɔkùnrin ɔ̀tɛlèmúyé: adúláwɔ̀ díɛ̀',
    '🕵🏿‍♂' => 'ɔkùnrin ɔ̀tɛlèmúyé: adúláwɔ̀',
    '🕵🏻‍♀' => 'obìnrin ɔ̀tɛlèmúyé: amɔ́lára',
    '🕵🏼‍♀' => 'obìnrin ɔ̀tɛlèmúyé: amɔ́lára díɛ̀',
    '🕵🏽‍♀' => 'obìnrin ɔ̀tɛlèmúyé: amɔ́láwɔ̀ díɛ̀',
    '🕵🏾‍♀' => 'obìnrin ɔ̀tɛlèmúyé: adúláwɔ̀ díɛ̀',
    '🕵🏿‍♀' => 'obìnrin ɔ̀tɛlèmúyé: adúláwɔ̀',
    '💂🏻‍♂' => 'ɔkùnrin olùshɔ́: amɔ́lára',
    '💂🏼‍♂' => 'ɔkùnrin olùshɔ́: amɔ́lára díɛ̀',
    '💂🏽‍♂' => 'ɔkùnrin olùshɔ́: amɔ́láwɔ̀ díɛ̀',
    '💂🏾‍♂' => 'ɔkùnrin olùshɔ́: adúláwɔ̀ díɛ̀',
    '💂🏿‍♂' => 'ɔkùnrin olùshɔ́: adúláwɔ̀',
    '💂🏻‍♀' => 'obìnrin olùshɔ́: amɔ́lára',
    '💂🏼‍♀' => 'obìnrin olùshɔ́: amɔ́lára díɛ̀',
    '💂🏽‍♀' => 'obìnrin olùshɔ́: amɔ́láwɔ̀ díɛ̀',
    '💂🏾‍♀' => 'obìnrin olùshɔ́: adúláwɔ̀ díɛ̀',
    '💂🏿‍♀' => 'obìnrin olùshɔ́: adúláwɔ̀',
    '👷🏻‍♂' => 'òshishɛ́ ìkɔ́lé ɔkùnrin: amɔ́lára',
    '👷🏼‍♂' => 'òshishɛ́ ìkɔ́lé ɔkùnrin: amɔ́lára díɛ̀',
    '👷🏽‍♂' => 'òshishɛ́ ìkɔ́lé ɔkùnrin: amɔ́láwɔ̀ díɛ̀',
    '👷🏾‍♂' => 'òshishɛ́ ìkɔ́lé ɔkùnrin: adúláwɔ̀ díɛ̀',
    '👷🏿‍♂' => 'òshishɛ́ ìkɔ́lé ɔkùnrin: adúláwɔ̀',
    '👷🏻‍♀' => 'òshishɛ́ ìkɔ́lé obìnrin: amɔ́lára',
    '👷🏼‍♀' => 'òshishɛ́ ìkɔ́lé obìnrin: amɔ́lára díɛ̀',
    '👷🏽‍♀' => 'òshishɛ́ ìkɔ́lé obìnrin: amɔ́láwɔ̀ díɛ̀',
    '👷🏾‍♀' => 'òshishɛ́ ìkɔ́lé obìnrin: adúláwɔ̀ díɛ̀',
    '👷🏿‍♀' => 'òshishɛ́ ìkɔ́lé obìnrin: adúláwɔ̀',
    '👳🏻‍♂' => 'ɔkùnrin tó dé láwàní: amɔ́lára',
    '👳🏼‍♂' => 'ɔkùnrin tó dé láwàní: amɔ́lára díɛ̀',
    '👳🏽‍♂' => 'ɔkùnrin tó dé láwàní: amɔ́láwɔ̀ díɛ̀',
    '👳🏾‍♂' => 'ɔkùnrin tó dé láwàní: adúláwɔ̀ díɛ̀',
    '👳🏿‍♂' => 'ɔkùnrin tó dé láwàní: adúláwɔ̀',
    '👳🏻‍♀' => 'obìnrin tó dé láwàní: amɔ́lára',
    '👳🏼‍♀' => 'obìnrin tó dé láwàní: amɔ́lára díɛ̀',
    '👳🏽‍♀' => 'obìnrin tó dé láwàní: amɔ́láwɔ̀ díɛ̀',
    '👳🏾‍♀' => 'obìnrin tó dé láwàní: adúláwɔ̀ díɛ̀',
    '👳🏿‍♀' => 'obìnrin tó dé láwàní: adúláwɔ̀',
    '🤵🏻‍♂' => 'ɔkùnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: amɔ́lára',
    '🤵🏼‍♂' => 'ɔkùnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: amɔ́lára díɛ̀',
    '🤵🏽‍♂' => 'ɔkùnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: amɔ́láwɔ̀ díɛ̀',
    '🤵🏾‍♂' => 'ɔkùnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: adúláwɔ̀ díɛ̀',
    '🤵🏿‍♂' => 'ɔkùnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: adúláwɔ̀',
    '🤵🏻‍♀' => 'obìnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: amɔ́lára',
    '🤵🏼‍♀' => 'obìnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: amɔ́lára díɛ̀',
    '🤵🏽‍♀' => 'obìnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: amɔ́láwɔ̀ díɛ̀',
    '🤵🏾‍♀' => 'obìnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: adúláwɔ̀ díɛ̀',
    '🤵🏿‍♀' => 'obìnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́: adúláwɔ̀',
    '👰🏻‍♂' => 'ɔkùnrin tó fi ashɔ bojú: amɔ́lára',
    '👰🏼‍♂' => 'ɔkùnrin tó fi ashɔ bojú: amɔ́lára díɛ̀',
    '👰🏽‍♂' => 'ɔkùnrin tó fi ashɔ bojú: amɔ́láwɔ̀ díɛ̀',
    '👰🏾‍♂' => 'ɔkùnrin tó fi ashɔ bojú: adúláwɔ̀ díɛ̀',
    '👰🏿‍♂' => 'ɔkùnrin tó fi ashɔ bojú: adúláwɔ̀',
    '👰🏻‍♀' => 'obìnrin tó fi ashɔ bojú: amɔ́lára',
    '👰🏼‍♀' => 'obìnrin tó fi ashɔ bojú: amɔ́lára díɛ̀',
    '👰🏽‍♀' => 'obìnrin tó fi ashɔ bojú: amɔ́láwɔ̀ díɛ̀',
    '👰🏾‍♀' => 'obìnrin tó fi ashɔ bojú: adúláwɔ̀ díɛ̀',
    '👰🏿‍♀' => 'obìnrin tó fi ashɔ bojú: adúláwɔ̀',
    '👩🏻‍🍼' => 'obìnrin tó ń fɔ́mɔ lóúnjɛ: amɔ́lára',
    '👩🏼‍🍼' => 'obìnrin tó ń fɔ́mɔ lóúnjɛ: amɔ́lára díɛ̀',
    '👩🏽‍🍼' => 'obìnrin tó ń fɔ́mɔ lóúnjɛ: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🍼' => 'obìnrin tó ń fɔ́mɔ lóúnjɛ: adúláwɔ̀ díɛ̀',
    '👩🏿‍🍼' => 'obìnrin tó ń fɔ́mɔ lóúnjɛ: adúláwɔ̀',
    '👨🏻‍🍼' => 'ɔkùnrin tó ń fɔ́mɔ lóúnjɛ: amɔ́lára',
    '👨🏼‍🍼' => 'ɔkùnrin tó ń fɔ́mɔ lóúnjɛ: amɔ́lára díɛ̀',
    '👨🏽‍🍼' => 'ɔkùnrin tó ń fɔ́mɔ lóúnjɛ: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🍼' => 'ɔkùnrin tó ń fɔ́mɔ lóúnjɛ: adúláwɔ̀ díɛ̀',
    '👨🏿‍🍼' => 'ɔkùnrin tó ń fɔ́mɔ lóúnjɛ: adúláwɔ̀',
    '🧑🏻‍🍼' => 'ɛnìkan tó ń fɔ́mɔ lóúnjɛ: amɔ́lára',
    '🧑🏼‍🍼' => 'ɛnìkan tó ń fɔ́mɔ lóúnjɛ: amɔ́lára díɛ̀',
    '🧑🏽‍🍼' => 'ɛnìkan tó ń fɔ́mɔ lóúnjɛ: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🍼' => 'ɛnìkan tó ń fɔ́mɔ lóúnjɛ: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🍼' => 'ɛnìkan tó ń fɔ́mɔ lóúnjɛ: adúláwɔ̀',
    '🧑🏻‍🎄' => 'mx claus: amɔ́lára',
    '🧑🏼‍🎄' => 'mx claus: amɔ́lára díɛ̀',
    '🧑🏽‍🎄' => 'mx claus: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🎄' => 'mx claus: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🎄' => 'mx claus: adúláwɔ̀',
    '🦸🏻‍♂' => 'ɔkùnrin akɔni ńlá: amɔ́lára',
    '🦸🏼‍♂' => 'ɔkùnrin akɔni ńlá: amɔ́lára díɛ̀',
    '🦸🏽‍♂' => 'ɔkùnrin akɔni ńlá: amɔ́láwɔ̀ díɛ̀',
    '🦸🏾‍♂' => 'ɔkùnrin akɔni ńlá: adúláwɔ̀ díɛ̀',
    '🦸🏿‍♂' => 'ɔkùnrin akɔni ńlá: adúláwɔ̀',
    '🦸🏻‍♀' => 'obìnrin akɔni ńlá: amɔ́lára',
    '🦸🏼‍♀' => 'obìnrin akɔni ńlá: amɔ́lára díɛ̀',
    '🦸🏽‍♀' => 'obìnrin akɔni ńlá: amɔ́láwɔ̀ díɛ̀',
    '🦸🏾‍♀' => 'obìnrin akɔni ńlá: adúláwɔ̀ díɛ̀',
    '🦸🏿‍♀' => 'obìnrin akɔni ńlá: adúláwɔ̀',
    '🦹🏻‍♂' => 'ɔkùnrin ashèbàjɛ́ ńlá: amɔ́lára',
    '🦹🏼‍♂' => 'ɔkùnrin ashèbàjɛ́ ńlá: amɔ́lára díɛ̀',
    '🦹🏽‍♂' => 'ɔkùnrin ashèbàjɛ́ ńlá: amɔ́láwɔ̀ díɛ̀',
    '🦹🏾‍♂' => 'ɔkùnrin ashèbàjɛ́ ńlá: adúláwɔ̀ díɛ̀',
    '🦹🏿‍♂' => 'ɔkùnrin ashèbàjɛ́ ńlá: adúláwɔ̀',
    '🦹🏻‍♀' => 'obìnrin ashèbàjɛ́ ńlá: amɔ́lára',
    '🦹🏼‍♀' => 'obìnrin ashèbàjɛ́ ńlá: amɔ́lára díɛ̀',
    '🦹🏽‍♀' => 'obìnrin ashèbàjɛ́ ńlá: amɔ́láwɔ̀ díɛ̀',
    '🦹🏾‍♀' => 'obìnrin ashèbàjɛ́ ńlá: adúláwɔ̀ díɛ̀',
    '🦹🏿‍♀' => 'obìnrin ashèbàjɛ́ ńlá: adúláwɔ̀',
    '🧙🏻‍♂' => 'Ɔkùnrin onídán: amɔ́lára',
    '🧙🏼‍♂' => 'Ɔkùnrin onídán: amɔ́lára díɛ̀',
    '🧙🏽‍♂' => 'Ɔkùnrin onídán: amɔ́láwɔ̀ díɛ̀',
    '🧙🏾‍♂' => 'Ɔkùnrin onídán: adúláwɔ̀ díɛ̀',
    '🧙🏿‍♂' => 'Ɔkùnrin onídán: adúláwɔ̀',
    '🧙🏻‍♀' => 'Obìnrin onídán: amɔ́lára',
    '🧙🏼‍♀' => 'Obìnrin onídán: amɔ́lára díɛ̀',
    '🧙🏽‍♀' => 'Obìnrin onídán: amɔ́láwɔ̀ díɛ̀',
    '🧙🏾‍♀' => 'Obìnrin onídán: adúláwɔ̀ díɛ̀',
    '🧙🏿‍♀' => 'Obìnrin onídán: adúláwɔ̀',
    '🧚🏻‍♂' => 'Iwin ɔkùnrin: amɔ́lára',
    '🧚🏼‍♂' => 'Iwin ɔkùnrin: amɔ́lára díɛ̀',
    '🧚🏽‍♂' => 'Iwin ɔkùnrin: amɔ́láwɔ̀ díɛ̀',
    '🧚🏾‍♂' => 'Iwin ɔkùnrin: adúláwɔ̀ díɛ̀',
    '🧚🏿‍♂' => 'Iwin ɔkùnrin: adúláwɔ̀',
    '🧚🏻‍♀' => 'Iwin obìnrin: amɔ́lára',
    '🧚🏼‍♀' => 'Iwin obìnrin: amɔ́lára díɛ̀',
    '🧚🏽‍♀' => 'Iwin obìnrin: amɔ́láwɔ̀ díɛ̀',
    '🧚🏾‍♀' => 'Iwin obìnrin: adúláwɔ̀ díɛ̀',
    '🧚🏿‍♀' => 'Iwin obìnrin: adúláwɔ̀',
    '🧛🏻‍♂' => 'Fánpáyà ɔkùnrin: amɔ́lára',
    '🧛🏼‍♂' => 'Fánpáyà ɔkùnrin: amɔ́lára díɛ̀',
    '🧛🏽‍♂' => 'Fánpáyà ɔkùnrin: amɔ́láwɔ̀ díɛ̀',
    '🧛🏾‍♂' => 'Fánpáyà ɔkùnrin: adúláwɔ̀ díɛ̀',
    '🧛🏿‍♂' => 'Fánpáyà ɔkùnrin: adúláwɔ̀',
    '🧛🏻‍♀' => 'Fánpáyà obìnrin: amɔ́lára',
    '🧛🏼‍♀' => 'Fánpáyà obìnrin: amɔ́lára díɛ̀',
    '🧛🏽‍♀' => 'Fánpáyà obìnrin: amɔ́láwɔ̀ díɛ̀',
    '🧛🏾‍♀' => 'Fánpáyà obìnrin: adúláwɔ̀ díɛ̀',
    '🧛🏿‍♀' => 'Fánpáyà obìnrin: adúláwɔ̀',
    '🧜🏻‍♂' => 'Yemɔja ɔkùnrin: amɔ́lára',
    '🧜🏼‍♂' => 'Yemɔja ɔkùnrin: amɔ́lára díɛ̀',
    '🧜🏽‍♂' => 'Yemɔja ɔkùnrin: amɔ́láwɔ̀ díɛ̀',
    '🧜🏾‍♂' => 'Yemɔja ɔkùnrin: adúláwɔ̀ díɛ̀',
    '🧜🏿‍♂' => 'Yemɔja ɔkùnrin: adúláwɔ̀',
    '🧜🏻‍♀' => 'iyemɔja: amɔ́lára',
    '🧜🏼‍♀' => 'iyemɔja: amɔ́lára díɛ̀',
    '🧜🏽‍♀' => 'iyemɔja: amɔ́láwɔ̀ díɛ̀',
    '🧜🏾‍♀' => 'iyemɔja: adúláwɔ̀ díɛ̀',
    '🧜🏿‍♀' => 'iyemɔja: adúláwɔ̀',
    '🧝🏻‍♂' => 'egbére ɔkùnrin: amɔ́lára',
    '🧝🏼‍♂' => 'egbére ɔkùnrin: amɔ́lára díɛ̀',
    '🧝🏽‍♂' => 'egbére ɔkùnrin: amɔ́láwɔ̀ díɛ̀',
    '🧝🏾‍♂' => 'egbére ɔkùnrin: adúláwɔ̀ díɛ̀',
    '🧝🏿‍♂' => 'egbére ɔkùnrin: adúláwɔ̀',
    '🧝🏻‍♀' => 'egbére obìnrin: amɔ́lára',
    '🧝🏼‍♀' => 'egbére obìnrin: amɔ́lára díɛ̀',
    '🧝🏽‍♀' => 'egbére obìnrin: amɔ́láwɔ̀ díɛ̀',
    '🧝🏾‍♀' => 'egbére obìnrin: adúláwɔ̀ díɛ̀',
    '🧝🏿‍♀' => 'egbére obìnrin: adúláwɔ̀',
    '💆🏻‍♂' => 'ɔkùnrin tí ń gba ifɔwɔwɔnilara: amɔ́lára',
    '💆🏼‍♂' => 'ɔkùnrin tí ń gba ifɔwɔwɔnilara: amɔ́lára díɛ̀',
    '💆🏽‍♂' => 'ɔkùnrin tí ń gba ifɔwɔwɔnilara: amɔ́láwɔ̀ díɛ̀',
    '💆🏾‍♂' => 'ɔkùnrin tí ń gba ifɔwɔwɔnilara: adúláwɔ̀ díɛ̀',
    '💆🏿‍♂' => 'ɔkùnrin tí ń gba ifɔwɔwɔnilara: adúláwɔ̀',
    '💆🏻‍♀' => 'obìnrin tí ń gba ifɔwɔwɔnilara: amɔ́lára',
    '💆🏼‍♀' => 'obìnrin tí ń gba ifɔwɔwɔnilara: amɔ́lára díɛ̀',
    '💆🏽‍♀' => 'obìnrin tí ń gba ifɔwɔwɔnilara: amɔ́láwɔ̀ díɛ̀',
    '💆🏾‍♀' => 'obìnrin tí ń gba ifɔwɔwɔnilara: adúláwɔ̀ díɛ̀',
    '💆🏿‍♀' => 'obìnrin tí ń gba ifɔwɔwɔnilara: adúláwɔ̀',
    '💇🏻‍♂' => 'ɔkùnrin tí ń gɛrun: amɔ́lára',
    '💇🏼‍♂' => 'ɔkùnrin tí ń gɛrun: amɔ́lára díɛ̀',
    '💇🏽‍♂' => 'ɔkùnrin tí ń gɛrun: amɔ́láwɔ̀ díɛ̀',
    '💇🏾‍♂' => 'ɔkùnrin tí ń gɛrun: adúláwɔ̀ díɛ̀',
    '💇🏿‍♂' => 'ɔkùnrin tí ń gɛrun: adúláwɔ̀',
    '💇🏻‍♀' => 'obìnrin tí ń gɛrun: amɔ́lára',
    '💇🏼‍♀' => 'obìnrin tí ń gɛrun: amɔ́lára díɛ̀',
    '💇🏽‍♀' => 'obìnrin tí ń gɛrun: amɔ́láwɔ̀ díɛ̀',
    '💇🏾‍♀' => 'obìnrin tí ń gɛrun: adúláwɔ̀ díɛ̀',
    '💇🏿‍♀' => 'obìnrin tí ń gɛrun: adúláwɔ̀',
    '🚶🏻‍♂' => 'ɔkùnrin tí ń rìn: amɔ́lára',
    '🚶🏼‍♂' => 'ɔkùnrin tí ń rìn: amɔ́lára díɛ̀',
    '🚶🏽‍♂' => 'ɔkùnrin tí ń rìn: amɔ́láwɔ̀ díɛ̀',
    '🚶🏾‍♂' => 'ɔkùnrin tí ń rìn: adúláwɔ̀ díɛ̀',
    '🚶🏿‍♂' => 'ɔkùnrin tí ń rìn: adúláwɔ̀',
    '🚶🏻‍♀' => 'obìnrin tí ń rìn: amɔ́lára',
    '🚶🏼‍♀' => 'obìnrin tí ń rìn: amɔ́lára díɛ̀',
    '🚶🏽‍♀' => 'obìnrin tí ń rìn: amɔ́láwɔ̀ díɛ̀',
    '🚶🏾‍♀' => 'obìnrin tí ń rìn: adúláwɔ̀ díɛ̀',
    '🚶🏿‍♀' => 'obìnrin tí ń rìn: adúláwɔ̀',
    '🚶🏻‍➡' => 'Ɛni N Rin: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🚶🏼‍➡' => 'Ɛni N Rin: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏽‍➡' => 'Ɛni N Rin: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏾‍➡' => 'Ɛni N Rin: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🚶🏿‍➡' => 'Ɛni N Rin: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🧍🏻‍♂' => 'ɔkùnrin tó dúró: amɔ́lára',
    '🧍🏼‍♂' => 'ɔkùnrin tó dúró: amɔ́lára díɛ̀',
    '🧍🏽‍♂' => 'ɔkùnrin tó dúró: amɔ́láwɔ̀ díɛ̀',
    '🧍🏾‍♂' => 'ɔkùnrin tó dúró: adúláwɔ̀ díɛ̀',
    '🧍🏿‍♂' => 'ɔkùnrin tó dúró: adúláwɔ̀',
    '🧍🏻‍♀' => 'obìnrin tó dúró: amɔ́lára',
    '🧍🏼‍♀' => 'obìnrin tó dúró: amɔ́lára díɛ̀',
    '🧍🏽‍♀' => 'obìnrin tó dúró: amɔ́láwɔ̀ díɛ̀',
    '🧍🏾‍♀' => 'obìnrin tó dúró: adúláwɔ̀ díɛ̀',
    '🧍🏿‍♀' => 'obìnrin tó dúró: adúláwɔ̀',
    '🧎🏻‍♂' => 'ɔkùnrin tó kúnlɛ̀: amɔ́lára',
    '🧎🏼‍♂' => 'ɔkùnrin tó kúnlɛ̀: amɔ́lára díɛ̀',
    '🧎🏽‍♂' => 'ɔkùnrin tó kúnlɛ̀: amɔ́láwɔ̀ díɛ̀',
    '🧎🏾‍♂' => 'ɔkùnrin tó kúnlɛ̀: adúláwɔ̀ díɛ̀',
    '🧎🏿‍♂' => 'ɔkùnrin tó kúnlɛ̀: adúláwɔ̀',
    '🧎🏻‍♀' => 'obìnrin tó kúnlɛ̀: amɔ́lára',
    '🧎🏼‍♀' => 'obìnrin tó kúnlɛ̀: amɔ́lára díɛ̀',
    '🧎🏽‍♀' => 'obìnrin tó kúnlɛ̀: amɔ́láwɔ̀ díɛ̀',
    '🧎🏾‍♀' => 'obìnrin tó kúnlɛ̀: adúláwɔ̀ díɛ̀',
    '🧎🏿‍♀' => 'obìnrin tó kúnlɛ̀: adúláwɔ̀',
    '🧎🏻‍➡' => 'ènìyàn kíkúnlɛ̀: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🧎🏼‍➡' => 'ènìyàn kíkúnlɛ̀: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏽‍➡' => 'ènìyàn kíkúnlɛ̀: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏾‍➡' => 'ènìyàn kíkúnlɛ̀: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🧎🏿‍➡' => 'ènìyàn kíkúnlɛ̀: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '🧑🏻‍🦯' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: amɔ́lára',
    '🧑🏼‍🦯' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: amɔ́lára díɛ̀',
    '🧑🏽‍🦯' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🦯' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🦯' => 'ènìyàn pɛ̀lú ɔ̀pá funfun: adúláwɔ̀',
    '👨🏻‍🦯' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: amɔ́lára',
    '👨🏼‍🦯' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: amɔ́lára díɛ̀',
    '👨🏽‍🦯' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🦯' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: adúláwɔ̀ díɛ̀',
    '👨🏿‍🦯' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun: adúláwɔ̀',
    '👩🏻‍🦯' => 'obìnrin pɛ̀lú ɔ̀pá funfun: amɔ́lára',
    '👩🏼‍🦯' => 'obìnrin pɛ̀lú ɔ̀pá funfun: amɔ́lára díɛ̀',
    '👩🏽‍🦯' => 'obìnrin pɛ̀lú ɔ̀pá funfun: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🦯' => 'obìnrin pɛ̀lú ɔ̀pá funfun: adúláwɔ̀ díɛ̀',
    '👩🏿‍🦯' => 'obìnrin pɛ̀lú ɔ̀pá funfun: adúláwɔ̀',
    '🧑🏻‍🦼' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára',
    '🧑🏼‍🦼' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára díɛ̀',
    '🧑🏽‍🦼' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🦼' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🦼' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀',
    '👨🏻‍🦼' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára',
    '👨🏼‍🦼' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára díɛ̀',
    '👨🏽‍🦼' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🦼' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀ díɛ̀',
    '👨🏿‍🦼' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀',
    '👩🏻‍🦼' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára',
    '👩🏼‍🦼' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́lára díɛ̀',
    '👩🏽‍🦼' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🦼' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀ díɛ̀',
    '👩🏿‍🦼' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò: adúláwɔ̀',
    '🧑🏻‍🦽' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára',
    '🧑🏼‍🦽' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára díɛ̀',
    '🧑🏽‍🦽' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾‍🦽' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀ díɛ̀',
    '🧑🏿‍🦽' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀',
    '👨🏻‍🦽' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára',
    '👨🏼‍🦽' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára díɛ̀',
    '👨🏽‍🦽' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́láwɔ̀ díɛ̀',
    '👨🏾‍🦽' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀ díɛ̀',
    '👨🏿‍🦽' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀',
    '👩🏻‍🦽' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára',
    '👩🏼‍🦽' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́lára díɛ̀',
    '👩🏽‍🦽' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: amɔ́láwɔ̀ díɛ̀',
    '👩🏾‍🦽' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀ díɛ̀',
    '👩🏿‍🦽' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí: adúláwɔ̀',
    '🏃🏻‍♂' => 'ɔkùnrin tí ń sáré: amɔ́lára',
    '🏃🏼‍♂' => 'ɔkùnrin tí ń sáré: amɔ́lára díɛ̀',
    '🏃🏽‍♂' => 'ɔkùnrin tí ń sáré: amɔ́láwɔ̀ díɛ̀',
    '🏃🏾‍♂' => 'ɔkùnrin tí ń sáré: adúláwɔ̀ díɛ̀',
    '🏃🏿‍♂' => 'ɔkùnrin tí ń sáré: adúláwɔ̀',
    '🏃🏻‍♀' => 'obìrin tí ń sáré: amɔ́lára',
    '🏃🏼‍♀' => 'obìrin tí ń sáré: amɔ́lára díɛ̀',
    '🏃🏽‍♀' => 'obìrin tí ń sáré: amɔ́láwɔ̀ díɛ̀',
    '🏃🏾‍♀' => 'obìrin tí ń sáré: adúláwɔ̀ díɛ̀',
    '🏃🏿‍♀' => 'obìrin tí ń sáré: adúláwɔ̀',
    '🏃🏻‍➡' => 'Ɛni N Sare: amɔ́lára àtiìdojúkɔ ɔ̀tún',
    '🏃🏼‍➡' => 'Ɛni N Sare: amɔ́lára díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏽‍➡' => 'Ɛni N Sare: amɔ́láwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏾‍➡' => 'Ɛni N Sare: adúláwɔ̀ díɛ̀ àtiìdojúkɔ ɔ̀tún',
    '🏃🏿‍➡' => 'Ɛni N Sare: adúláwɔ̀ àtiìdojúkɔ ɔ̀tún',
    '👯🏻‍♀' => 'awɔn obìnrin eleti ehoro: amɔ́lára',
    '👯🏼‍♀' => 'awɔn obìnrin eleti ehoro: amɔ́lára díɛ̀',
    '👯🏽‍♀' => 'awɔn obìnrin eleti ehoro: amɔ́láwɔ̀ díɛ̀',
    '👯🏾‍♀' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀ díɛ̀',
    '👯🏿‍♀' => 'awɔn obìnrin eleti ehoro: adúláwɔ̀',
    '👯🏻‍♂' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára',
    '👯🏼‍♂' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́lára díɛ̀',
    '👯🏽‍♂' => 'àwɔn ɔkùnrin elétí ehoro: amɔ́láwɔ̀ díɛ̀',
    '👯🏾‍♂' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀ díɛ̀',
    '👯🏿‍♂' => 'àwɔn ɔkùnrin elétí ehoro: adúláwɔ̀',
    '🧖🏻‍♂' => 'Ɔkùnrin nínú Ìyàrá tó n gbóná: amɔ́lára',
    '🧖🏼‍♂' => 'Ɔkùnrin nínú Ìyàrá tó n gbóná: amɔ́lára díɛ̀',
    '🧖🏽‍♂' => 'Ɔkùnrin nínú Ìyàrá tó n gbóná: amɔ́láwɔ̀ díɛ̀',
    '🧖🏾‍♂' => 'Ɔkùnrin nínú Ìyàrá tó n gbóná: adúláwɔ̀ díɛ̀',
    '🧖🏿‍♂' => 'Ɔkùnrin nínú Ìyàrá tó n gbóná: adúláwɔ̀',
    '🧖🏻‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: amɔ́lára',
    '🧖🏼‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: amɔ́lára díɛ̀',
    '🧖🏽‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: amɔ́láwɔ̀ díɛ̀',
    '🧖🏾‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: adúláwɔ̀ díɛ̀',
    '🧖🏿‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná: adúláwɔ̀',
    '🧗🏻‍♂' => 'O̩kùnrin tó n gòkè: amɔ́lára',
    '🧗🏼‍♂' => 'O̩kùnrin tó n gòkè: amɔ́lára díɛ̀',
    '🧗🏽‍♂' => 'O̩kùnrin tó n gòkè: amɔ́láwɔ̀ díɛ̀',
    '🧗🏾‍♂' => 'O̩kùnrin tó n gòkè: adúláwɔ̀ díɛ̀',
    '🧗🏿‍♂' => 'O̩kùnrin tó n gòkè: adúláwɔ̀',
    '🧗🏻‍♀' => 'Obìnrin tó n gòkè: amɔ́lára',
    '🧗🏼‍♀' => 'Obìnrin tó n gòkè: amɔ́lára díɛ̀',
    '🧗🏽‍♀' => 'Obìnrin tó n gòkè: amɔ́láwɔ̀ díɛ̀',
    '🧗🏾‍♀' => 'Obìnrin tó n gòkè: adúláwɔ̀ díɛ̀',
    '🧗🏿‍♀' => 'Obìnrin tó n gòkè: adúláwɔ̀',
    '🏌🏻‍♂' => 'ɔkùnrin tí ń gɔ́ɔ̀fù: amɔ́lára',
    '🏌🏼‍♂' => 'ɔkùnrin tí ń gɔ́ɔ̀fù: amɔ́lára díɛ̀',
    '🏌🏽‍♂' => 'ɔkùnrin tí ń gɔ́ɔ̀fù: amɔ́láwɔ̀ díɛ̀',
    '🏌🏾‍♂' => 'ɔkùnrin tí ń gɔ́ɔ̀fù: adúláwɔ̀ díɛ̀',
    '🏌🏿‍♂' => 'ɔkùnrin tí ń gɔ́ɔ̀fù: adúláwɔ̀',
    '🏌🏻‍♀' => 'obìnrin tí ń gɔ́ɔ̀fù: amɔ́lára',
    '🏌🏼‍♀' => 'obìnrin tí ń gɔ́ɔ̀fù: amɔ́lára díɛ̀',
    '🏌🏽‍♀' => 'obìnrin tí ń gɔ́ɔ̀fù: amɔ́láwɔ̀ díɛ̀',
    '🏌🏾‍♀' => 'obìnrin tí ń gɔ́ɔ̀fù: adúláwɔ̀ díɛ̀',
    '🏌🏿‍♀' => 'obìnrin tí ń gɔ́ɔ̀fù: adúláwɔ̀',
    '🏄🏻‍♂' => 'ɔkùnrin tí ń wá íńtánɛ́tì: amɔ́lára',
    '🏄🏼‍♂' => 'ɔkùnrin tí ń wá íńtánɛ́tì: amɔ́lára díɛ̀',
    '🏄🏽‍♂' => 'ɔkùnrin tí ń wá íńtánɛ́tì: amɔ́láwɔ̀ díɛ̀',
    '🏄🏾‍♂' => 'ɔkùnrin tí ń wá íńtánɛ́tì: adúláwɔ̀ díɛ̀',
    '🏄🏿‍♂' => 'ɔkùnrin tí ń wá íńtánɛ́tì: adúláwɔ̀',
    '🏄🏻‍♀' => 'obìnrín tí ń wá íńtánɛ́tì: amɔ́lára',
    '🏄🏼‍♀' => 'obìnrín tí ń wá íńtánɛ́tì: amɔ́lára díɛ̀',
    '🏄🏽‍♀' => 'obìnrín tí ń wá íńtánɛ́tì: amɔ́láwɔ̀ díɛ̀',
    '🏄🏾‍♀' => 'obìnrín tí ń wá íńtánɛ́tì: adúláwɔ̀ díɛ̀',
    '🏄🏿‍♀' => 'obìnrín tí ń wá íńtánɛ́tì: adúláwɔ̀',
    '🚣🏻‍♂' => 'ɔkùnrin tí ń wakɔ̀ ojú omi kékeré: amɔ́lára',
    '🚣🏼‍♂' => 'ɔkùnrin tí ń wakɔ̀ ojú omi kékeré: amɔ́lára díɛ̀',
    '🚣🏽‍♂' => 'ɔkùnrin tí ń wakɔ̀ ojú omi kékeré: amɔ́láwɔ̀ díɛ̀',
    '🚣🏾‍♂' => 'ɔkùnrin tí ń wakɔ̀ ojú omi kékeré: adúláwɔ̀ díɛ̀',
    '🚣🏿‍♂' => 'ɔkùnrin tí ń wakɔ̀ ojú omi kékeré: adúláwɔ̀',
    '🚣🏻‍♀' => 'obìnrin tí ń wakɔ̀ ojú omi kékeré: amɔ́lára',
    '🚣🏼‍♀' => 'obìnrin tí ń wakɔ̀ ojú omi kékeré: amɔ́lára díɛ̀',
    '🚣🏽‍♀' => 'obìnrin tí ń wakɔ̀ ojú omi kékeré: amɔ́láwɔ̀ díɛ̀',
    '🚣🏾‍♀' => 'obìnrin tí ń wakɔ̀ ojú omi kékeré: adúláwɔ̀ díɛ̀',
    '🚣🏿‍♀' => 'obìnrin tí ń wakɔ̀ ojú omi kékeré: adúláwɔ̀',
    '🏊🏻‍♂' => 'ɔkùnrin tí ń wɛdò: amɔ́lára',
    '🏊🏼‍♂' => 'ɔkùnrin tí ń wɛdò: amɔ́lára díɛ̀',
    '🏊🏽‍♂' => 'ɔkùnrin tí ń wɛdò: amɔ́láwɔ̀ díɛ̀',
    '🏊🏾‍♂' => 'ɔkùnrin tí ń wɛdò: adúláwɔ̀ díɛ̀',
    '🏊🏿‍♂' => 'ɔkùnrin tí ń wɛdò: adúláwɔ̀',
    '🏊🏻‍♀' => 'obìnrin tí ń wɛdò: amɔ́lára',
    '🏊🏼‍♀' => 'obìnrin tí ń wɛdò: amɔ́lára díɛ̀',
    '🏊🏽‍♀' => 'obìnrin tí ń wɛdò: amɔ́láwɔ̀ díɛ̀',
    '🏊🏾‍♀' => 'obìnrin tí ń wɛdò: adúláwɔ̀ díɛ̀',
    '🏊🏿‍♀' => 'obìnrin tí ń wɛdò: adúláwɔ̀',
    '⛹🏻‍♂' => 'ɔkùnrin tí ń tà boun bɔ́ɔ̀lù: amɔ́lára',
    '⛹🏼‍♂' => 'ɔkùnrin tí ń tà boun bɔ́ɔ̀lù: amɔ́lára díɛ̀',
    '⛹🏽‍♂' => 'ɔkùnrin tí ń tà boun bɔ́ɔ̀lù: amɔ́láwɔ̀ díɛ̀',
    '⛹🏾‍♂' => 'ɔkùnrin tí ń tà boun bɔ́ɔ̀lù: adúláwɔ̀ díɛ̀',
    '⛹🏿‍♂' => 'ɔkùnrin tí ń tà boun bɔ́ɔ̀lù: adúláwɔ̀',
    '⛹🏻‍♀' => 'obìnrin tà boun bɔ́ɔ̀lù: amɔ́lára',
    '⛹🏼‍♀' => 'obìnrin tà boun bɔ́ɔ̀lù: amɔ́lára díɛ̀',
    '⛹🏽‍♀' => 'obìnrin tà boun bɔ́ɔ̀lù: amɔ́láwɔ̀ díɛ̀',
    '⛹🏾‍♀' => 'obìnrin tà boun bɔ́ɔ̀lù: adúláwɔ̀ díɛ̀',
    '⛹🏿‍♀' => 'obìnrin tà boun bɔ́ɔ̀lù: adúláwɔ̀',
    '🏋🏻‍♂' => 'ɔkùnrin tí ń a fà ìwɔ̀n sókè: amɔ́lára',
    '🏋🏼‍♂' => 'ɔkùnrin tí ń a fà ìwɔ̀n sókè: amɔ́lára díɛ̀',
    '🏋🏽‍♂' => 'ɔkùnrin tí ń a fà ìwɔ̀n sókè: amɔ́láwɔ̀ díɛ̀',
    '🏋🏾‍♂' => 'ɔkùnrin tí ń a fà ìwɔ̀n sókè: adúláwɔ̀ díɛ̀',
    '🏋🏿‍♂' => 'ɔkùnrin tí ń a fà ìwɔ̀n sókè: adúláwɔ̀',
    '🏋🏻‍♀' => 'obìnrin tí ń a fà ìwɔ̀n sókè: amɔ́lára',
    '🏋🏼‍♀' => 'obìnrin tí ń a fà ìwɔ̀n sókè: amɔ́lára díɛ̀',
    '🏋🏽‍♀' => 'obìnrin tí ń a fà ìwɔ̀n sókè: amɔ́láwɔ̀ díɛ̀',
    '🏋🏾‍♀' => 'obìnrin tí ń a fà ìwɔ̀n sókè: adúláwɔ̀ díɛ̀',
    '🏋🏿‍♀' => 'obìnrin tí ń a fà ìwɔ̀n sókè: adúláwɔ̀',
    '🚴🏻‍♂' => 'ɔkùnrin tí ń wa kɛ̀kɛ́: amɔ́lára',
    '🚴🏼‍♂' => 'ɔkùnrin tí ń wa kɛ̀kɛ́: amɔ́lára díɛ̀',
    '🚴🏽‍♂' => 'ɔkùnrin tí ń wa kɛ̀kɛ́: amɔ́láwɔ̀ díɛ̀',
    '🚴🏾‍♂' => 'ɔkùnrin tí ń wa kɛ̀kɛ́: adúláwɔ̀ díɛ̀',
    '🚴🏿‍♂' => 'ɔkùnrin tí ń wa kɛ̀kɛ́: adúláwɔ̀',
    '🚴🏻‍♀' => 'obìnrin tí ń wa kɛ̀kɛ́: amɔ́lára',
    '🚴🏼‍♀' => 'obìnrin tí ń wa kɛ̀kɛ́: amɔ́lára díɛ̀',
    '🚴🏽‍♀' => 'obìnrin tí ń wa kɛ̀kɛ́: amɔ́láwɔ̀ díɛ̀',
    '🚴🏾‍♀' => 'obìnrin tí ń wa kɛ̀kɛ́: adúláwɔ̀ díɛ̀',
    '🚴🏿‍♀' => 'obìnrin tí ń wa kɛ̀kɛ́: adúláwɔ̀',
    '🚵🏻‍♂' => 'ɔkùnrin tín gùn kè wa kɛ̀kɛ́: amɔ́lára',
    '🚵🏼‍♂' => 'ɔkùnrin tín gùn kè wa kɛ̀kɛ́: amɔ́lára díɛ̀',
    '🚵🏽‍♂' => 'ɔkùnrin tín gùn kè wa kɛ̀kɛ́: amɔ́láwɔ̀ díɛ̀',
    '🚵🏾‍♂' => 'ɔkùnrin tín gùn kè wa kɛ̀kɛ́: adúláwɔ̀ díɛ̀',
    '🚵🏿‍♂' => 'ɔkùnrin tín gùn kè wa kɛ̀kɛ́: adúláwɔ̀',
    '🚵🏻‍♀' => 'obìnrin tín gùn kè wa kɛ̀kɛ́: amɔ́lára',
    '🚵🏼‍♀' => 'obìnrin tín gùn kè wa kɛ̀kɛ́: amɔ́lára díɛ̀',
    '🚵🏽‍♀' => 'obìnrin tín gùn kè wa kɛ̀kɛ́: amɔ́láwɔ̀ díɛ̀',
    '🚵🏾‍♀' => 'obìnrin tín gùn kè wa kɛ̀kɛ́: adúláwɔ̀ díɛ̀',
    '🚵🏿‍♀' => 'obìnrin tín gùn kè wa kɛ̀kɛ́: adúláwɔ̀',
    '🤸🏻‍♂' => 'ɔkùnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: amɔ́lára',
    '🤸🏼‍♂' => 'ɔkùnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: amɔ́lára díɛ̀',
    '🤸🏽‍♂' => 'ɔkùnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: amɔ́láwɔ̀ díɛ̀',
    '🤸🏾‍♂' => 'ɔkùnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: adúláwɔ̀ díɛ̀',
    '🤸🏿‍♂' => 'ɔkùnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: adúláwɔ̀',
    '🤸🏻‍♀' => 'obìnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: amɔ́lára',
    '🤸🏼‍♀' => 'obìnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: amɔ́lára díɛ̀',
    '🤸🏽‍♀' => 'obìnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: amɔ́láwɔ̀ díɛ̀',
    '🤸🏾‍♀' => 'obìnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: adúláwɔ̀ díɛ̀',
    '🤸🏿‍♀' => 'obìnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n: adúláwɔ̀',
    '🤼🏻‍♀' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára',
    '🤼🏼‍♀' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́lára díɛ̀',
    '🤼🏽‍♀' => 'àwɔn obìnrn tí ń jà ijakadi: amɔ́láwɔ̀ díɛ̀',
    '🤼🏾‍♀' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀ díɛ̀',
    '🤼🏿‍♀' => 'àwɔn obìnrn tí ń jà ijakadi: adúláwɔ̀',
    '🤼🏻‍♂' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára',
    '🤼🏼‍♂' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́lára díɛ̀',
    '🤼🏽‍♂' => 'àwɔn ɔkùnrin ti n ja ijakadi: amɔ́láwɔ̀ díɛ̀',
    '🤼🏾‍♂' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀ díɛ̀',
    '🤼🏿‍♂' => 'àwɔn ɔkùnrin ti n ja ijakadi: adúláwɔ̀',
    '🤽🏻‍♂' => 'ɔkùnrin n shere olomi: amɔ́lára',
    '🤽🏼‍♂' => 'ɔkùnrin n shere olomi: amɔ́lára díɛ̀',
    '🤽🏽‍♂' => 'ɔkùnrin n shere olomi: amɔ́láwɔ̀ díɛ̀',
    '🤽🏾‍♂' => 'ɔkùnrin n shere olomi: adúláwɔ̀ díɛ̀',
    '🤽🏿‍♂' => 'ɔkùnrin n shere olomi: adúláwɔ̀',
    '🤽🏻‍♀' => 'obìnrin n shere olomi: amɔ́lára',
    '🤽🏼‍♀' => 'obìnrin n shere olomi: amɔ́lára díɛ̀',
    '🤽🏽‍♀' => 'obìnrin n shere olomi: amɔ́láwɔ̀ díɛ̀',
    '🤽🏾‍♀' => 'obìnrin n shere olomi: adúláwɔ̀ díɛ̀',
    '🤽🏿‍♀' => 'obìnrin n shere olomi: adúláwɔ̀',
    '🤾🏻‍♂' => 'ɔkùnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: amɔ́lára',
    '🤾🏼‍♂' => 'ɔkùnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: amɔ́lára díɛ̀',
    '🤾🏽‍♂' => 'ɔkùnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: amɔ́láwɔ̀ díɛ̀',
    '🤾🏾‍♂' => 'ɔkùnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: adúláwɔ̀ díɛ̀',
    '🤾🏿‍♂' => 'ɔkùnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: adúláwɔ̀',
    '🤾🏻‍♀' => 'obìnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: amɔ́lára',
    '🤾🏼‍♀' => 'obìnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: amɔ́lára díɛ̀',
    '🤾🏽‍♀' => 'obìnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: amɔ́láwɔ̀ díɛ̀',
    '🤾🏾‍♀' => 'obìnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: adúláwɔ̀ díɛ̀',
    '🤾🏿‍♀' => 'obìnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́: adúláwɔ̀',
    '🤹🏻‍♂' => 'ɔkùnrin tí ń jù ǹkan sókè: amɔ́lára',
    '🤹🏼‍♂' => 'ɔkùnrin tí ń jù ǹkan sókè: amɔ́lára díɛ̀',
    '🤹🏽‍♂' => 'ɔkùnrin tí ń jù ǹkan sókè: amɔ́láwɔ̀ díɛ̀',
    '🤹🏾‍♂' => 'ɔkùnrin tí ń jù ǹkan sókè: adúláwɔ̀ díɛ̀',
    '🤹🏿‍♂' => 'ɔkùnrin tí ń jù ǹkan sókè: adúláwɔ̀',
    '🤹🏻‍♀' => 'obìnrin tí ń jú ǹkan sókè: amɔ́lára',
    '🤹🏼‍♀' => 'obìnrin tí ń jú ǹkan sókè: amɔ́lára díɛ̀',
    '🤹🏽‍♀' => 'obìnrin tí ń jú ǹkan sókè: amɔ́láwɔ̀ díɛ̀',
    '🤹🏾‍♀' => 'obìnrin tí ń jú ǹkan sókè: adúláwɔ̀ díɛ̀',
    '🤹🏿‍♀' => 'obìnrin tí ń jú ǹkan sókè: adúláwɔ̀',
    '🧘🏻‍♂' => 'Ɔkùnrin nípò ìgbàgbé: amɔ́lára',
    '🧘🏼‍♂' => 'Ɔkùnrin nípò ìgbàgbé: amɔ́lára díɛ̀',
    '🧘🏽‍♂' => 'Ɔkùnrin nípò ìgbàgbé: amɔ́láwɔ̀ díɛ̀',
    '🧘🏾‍♂' => 'Ɔkùnrin nípò ìgbàgbé: adúláwɔ̀ díɛ̀',
    '🧘🏿‍♂' => 'Ɔkùnrin nípò ìgbàgbé: adúláwɔ̀',
    '🧘🏻‍♀' => 'Obìnrin nípò ìgbàgbé: amɔ́lára',
    '🧘🏼‍♀' => 'Obìnrin nípò ìgbàgbé: amɔ́lára díɛ̀',
    '🧘🏽‍♀' => 'Obìnrin nípò ìgbàgbé: amɔ́láwɔ̀ díɛ̀',
    '🧘🏾‍♀' => 'Obìnrin nípò ìgbàgbé: adúláwɔ̀ díɛ̀',
    '🧘🏿‍♀' => 'Obìnrin nípò ìgbàgbé: adúláwɔ̀',
    '🧑‍🦰' => 'àgbà: irun pupa',
    '🧑‍🦱' => 'àgbà: irun rírɔ̀',
    '🧑‍🦳' => 'àgbà: irun funfun',
    '🧑‍🦲' => 'àgbà: orí pípá',
    '👨‍🦰' => 'Ɔkùnrin: irun pupa',
    '👨‍🦱' => 'Ɔkùnrin: irun rírɔ̀',
    '👨‍🦳' => 'Ɔkùnrin: irun funfun',
    '👨‍🦲' => 'Ɔkùnrin: orí pípá',
    '👩‍🦰' => 'Obìnrin: irun pupa',
    '👩‍🦱' => 'Obìnrin: irun rírɔ̀',
    '👩‍🦳' => 'Obìnrin: irun funfun',
    '👩‍🦲' => 'Obìnrin: orí pípá',
    '🚶‍➡' => 'Ɛni N Rin: ìdojúkɔ ɔ̀tún',
    '🧎‍➡' => 'ènìyàn kíkúnlɛ̀: ìdojúkɔ ɔ̀tún',
    '🏃‍➡' => 'Ɛni N Sare: ìdojúkɔ ɔ̀tún',
    '👨‍👦' => 'Ɛbí: Ɔkùnrin àtiɔmɔkùnrin',
    '👨‍👧' => 'Ɛbí: Ɔkùnrin àtiɔmɔbìrin',
    '👩‍👦' => 'Ɛbí: Obìnrin àtiɔmɔkùnrin',
    '👩‍👧' => 'Ɛbí: Obìnrin àtiɔmɔbìrin',
    '😶‍🌫' => 'ojú nínú àwɔ̀sánmà',
    '😮‍💨' => 'ojú ń mí síta',
    '🙂‍↕' => 'orí mímì látòkè-sílɛ̀',
    '😵‍💫' => 'ojú pɛ̀lú ɛyinjú lílɔ́pɔ̀',
    '❤‍🔥' => 'iná ń jóni lɔ́kàn',
    '❤‍🩹' => 'ɔkàn tó ń shàtúnshe ara rɛ̀',
    '👁‍🗨' => 'ojú ní àlú ɔ̀rɔ̀',
    '🧔‍♂' => 'ɔkùnrin: irùgbɔ̀n',
    '👱‍♂' => 'ɔkùnrin onírun funfun',
    '🧔‍♀' => 'obìnrin: irùgbɔ̀n',
    '👱‍♀' => 'obìnrin onírun funfun',
    '🙍‍♂' => 'ɔkùnrin tí ń fajúro',
    '🙍‍♀' => 'obìnrin tí ń fajúro',
    '🙎‍♂' => 'ɔkùnrin tí ń shíshù ètè síta',
    '🙎‍♀' => 'obìnrin tí ń shíshù ètè síta',
    '🙅‍♂' => 'ɔkùnrin tí ń sɔ RÁRÁ',
    '🙅‍♀' => 'obìnrin tí ń sɔ RÁRÁ',
    '🙆‍♂' => 'ɔkùnrin tí ń sɔ ÓDÁRA',
    '🙆‍♀' => 'obìnrin tí ń sɔ ÓDÁRA',
    '💁‍♂' => 'ɔkùnrin tí ń tɔ́ka ɔwɔ́',
    '💁‍♀' => 'obìnrin tí ń tɔ́ka ɔwɔ́',
    '🙋‍♂' => 'ɔkùnrintí ń nawɔ́ sókè',
    '🙋‍♀' => 'obìnrin tí ń nawɔ́ sókè',
    '🧏‍♂' => 'ɔkùnrin adití',
    '🧏‍♀' => 'obìnrin adití',
    '🙇‍♂' => 'ɔkùnrin tí ń tɛríba',
    '🙇‍♀' => 'obìnrin tí ń tɛríba',
    '🤦‍♂' => 'ɔkùnrin tín fɔwɔ́bojú',
    '🤦‍♀' => 'obìnrí tín fɔwɔ́bojú',
    '🤷‍♂' => 'ɔkùnrin tí ń gúnpá',
    '🤷‍♀' => 'obìǹrin tí ń gúnpa',
    '🧑‍⚕' => 'òshìshɛ́ ìlera',
    '👨‍⚕' => 'ɔkùnrín òshìshɛ́ ètò ìlera',
    '👩‍⚕' => 'obìrin òshìshɛ́ ètò ìlera',
    '🧑‍🎓' => 'akɛ́kɔ̀ɔ́',
    '👨‍🎓' => 'ɔkùnrin akɛ́kɔ̀ɔ́',
    '👩‍🎓' => 'obìrin akɛ́kɔ̀ɔ́',
    '🧑‍🏫' => 'olùkɔ́',
    '👨‍🏫' => 'ɔkùnrin olùkɔ́',
    '👩‍🏫' => 'obìnrin olùkɔ́',
    '🧑‍⚖' => 'adájɔ́',
    '👨‍⚖' => 'ɔkùnrin adájɔ́',
    '👩‍⚖' => 'obìnrin adájɔ́',
    '🧑‍🌾' => 'àgbɛ̀',
    '👨‍🌾' => 'ɔkùnrin àgbɛ́',
    '👩‍🌾' => 'obìrinàgbɛ́',
    '🧑‍🍳' => 'alásè',
    '👨‍🍳' => 'ɔkùnrin olùse ónjɛ',
    '👩‍🍳' => 'obìrin olùse ónjɛ',
    '🧑‍🔧' => 'mɛkáníìkì',
    '👨‍🔧' => 'ɔkùnrin atún ɔkɔ̀ she',
    '👩‍🔧' => 'obìrin atún ɔkɔ̀ she',
    '🧑‍🏭' => 'òshìshɛ́ ilé-ishɛ́ ashàgbéjáde ɔjà',
    '👨‍🏭' => 'ɔkùnrin òshìshɛ́ ilé-ishɛ́',
    '👩‍🏭' => 'obìrin òshìshɛ́ ilé-ishɛ́',
    '🧑‍💼' => 'òshìshɛ́ ɔ́fíìsì',
    '👨‍💼' => 'ɔkùnrin òshìshɛ́ ɔ́físì',
    '👩‍💼' => 'obìrin òshìshɛ́ ɔ́físì',
    '🧑‍🔬' => 'onímɔ̀ sáyɛ́ǹsì',
    '👨‍🔬' => 'ɔkùnrín síyɛ́nsì',
    '👩‍🔬' => 'obìrin síyɛ́nsì',
    '🧑‍💻' => 'akɔ́shɛ́mɔshɛ́ ìmɔ̀-ɛ̀rɔ',
    '👨‍💻' => 'ɔkùnrin oníms ɛ̀rɔ',
    '👩‍💻' => 'obìrin onímɔ̀ ɛ̀rɔ',
    '🧑‍🎤' => 'akɔrin',
    '👨‍🎤' => 'ɔkùnrin olórin',
    '👩‍🎤' => 'obìnrin olórin',
    '🧑‍🎨' => 'ashɛ̀dá àwòrán',
    '👨‍🎨' => 'ɔkùnrin òshèré',
    '👩‍🎨' => 'obìrin òshèré',
    '🧑‍✈' => 'atukɔ̀-òfurufú',
    '👨‍✈' => 'ɔkùnrin awa ɔkɔ́ bàlú',
    '👩‍✈' => 'obìrin awa ɔkɔ́ bàlú',
    '🧑‍🚀' => 'arìnrìn-àjò lɔ sí ayé mìíràn',
    '👨‍🚀' => 'ɔkùnrin olùwádìí inú òshùpá',
    '👩‍🚀' => 'obìrinolùwádìí inú òshùpá',
    '🧑‍🚒' => 'panápaná',
    '👨‍🚒' => 'ɔkùnrin panapanɔ́',
    '👩‍🚒' => 'obìrin panapanɔ́',
    '👮‍♂' => 'ɔkùnrin ɔlɔpa',
    '👮‍♀' => 'obìnrin ɔlɔpa',
    '🕵‍♂' => 'ɔkùnrin ɔ̀tɛlèmúyé',
    '🕵‍♀' => 'obìnrin ɔ̀tɛlèmúyé',
    '💂‍♂' => 'ɔkùnrin olùshɔ́',
    '💂‍♀' => 'obìnrin olùshɔ́',
    '👷‍♂' => 'òshishɛ́ ìkɔ́lé ɔkùnrin',
    '👷‍♀' => 'òshishɛ́ ìkɔ́lé obìnrin',
    '👳‍♂' => 'ɔkùnrin tó dé láwàní',
    '👳‍♀' => 'obìnrin tó dé láwàní',
    '🤵‍♂' => 'ɔkùnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́',
    '🤵‍♀' => 'obìnrin tó wɔ kóòtù ìlɔsóde ìrɔ̀lɛ́',
    '👰‍♂' => 'ɔkùnrin tó fi ashɔ bojú',
    '👰‍♀' => 'obìnrin tó fi ashɔ bojú',
    '👩‍🍼' => 'obìnrin tó ń fɔ́mɔ lóúnjɛ',
    '👨‍🍼' => 'ɔkùnrin tó ń fɔ́mɔ lóúnjɛ',
    '🧑‍🍼' => 'ɛnìkan tó ń fɔ́mɔ lóúnjɛ',
    '🧑‍🎄' => 'mx claus',
    '🦸‍♂' => 'ɔkùnrin akɔni ńlá',
    '🦸‍♀' => 'obìnrin akɔni ńlá',
    '🦹‍♂' => 'ɔkùnrin ashèbàjɛ́ ńlá',
    '🦹‍♀' => 'obìnrin ashèbàjɛ́ ńlá',
    '🧙‍♂' => 'Ɔkùnrin onídán',
    '🧙‍♀' => 'Obìnrin onídán',
    '🧚‍♂' => 'Iwin ɔkùnrin',
    '🧚‍♀' => 'Iwin obìnrin',
    '🧛‍♂' => 'Fánpáyà ɔkùnrin',
    '🧛‍♀' => 'Fánpáyà obìnrin',
    '🧜‍♂' => 'Yemɔja ɔkùnrin',
    '🧜‍♀' => 'iyemɔja',
    '🧝‍♂' => 'egbére ɔkùnrin',
    '🧝‍♀' => 'egbére obìnrin',
    '🧞‍♂' => 'Ànjɔ̀nnú ɔkùnrin',
    '🧞‍♀' => 'Ànjɔ̀nnú obìnrin',
    '🧟‍♂' => 'Ɛbɔra ɔkùnrin',
    '🧟‍♀' => 'Ɛbɔra obìnrin',
    '💆‍♂' => 'ɔkùnrin tí ń gba ifɔwɔwɔnilara',
    '💆‍♀' => 'obìnrin tí ń gba ifɔwɔwɔnilara',
    '💇‍♂' => 'ɔkùnrin tí ń gɛrun',
    '💇‍♀' => 'obìnrin tí ń gɛrun',
    '🚶‍♂' => 'ɔkùnrin tí ń rìn',
    '🚶‍♀' => 'obìnrin tí ń rìn',
    '🧍‍♂' => 'ɔkùnrin tó dúró',
    '🧍‍♀' => 'obìnrin tó dúró',
    '🧎‍♂' => 'ɔkùnrin tó kúnlɛ̀',
    '🧎‍♀' => 'obìnrin tó kúnlɛ̀',
    '🧑‍🦯' => 'ènìyàn pɛ̀lú ɔ̀pá funfun',
    '👨‍🦯' => 'ɔkùnrin pɛ̀lú ɔ̀pá funfun',
    '👩‍🦯' => 'obìnrin pɛ̀lú ɔ̀pá funfun',
    '🧑‍🦼' => 'ènìyàn nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò',
    '👨‍🦼' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò',
    '👩‍🦼' => 'obìnrin nínú kɛ̀kɛ́-abirùn ɛlɛ́rɔ-mɔ́tò',
    '🧑‍🦽' => 'ènìyàn nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí',
    '👨‍🦽' => 'ɔkùnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí',
    '👩‍🦽' => 'obìnrin nínú kɛ̀kɛ́-abirùn aláfɔwɔ́yí',
    '🏃‍♂' => 'ɔkùnrin tí ń sáré',
    '🏃‍♀' => 'obìrin tí ń sáré',
    '🧑‍🩰' => 'oníjó alájòóyípo',
    '👯‍♂' => 'àwɔn ɔkùnrin elétí ehoro',
    '👯‍♀' => 'awɔn obìnrin eleti ehoro',
    '🧖‍♂' => 'Ɔkùnrin nínú Ìyàrá tó n gbóná',
    '🧖‍♀' => 'Obìnrin nínú Ìyàrá tó n gbóná',
    '🧗‍♂' => 'O̩kùnrin tó n gòkè',
    '🧗‍♀' => 'Obìnrin tó n gòkè',
    '🏌‍♂' => 'ɔkùnrin tí ń gɔ́ɔ̀fù',
    '🏌‍♀' => 'obìnrin tí ń gɔ́ɔ̀fù',
    '🏄‍♂' => 'ɔkùnrin tí ń wá íńtánɛ́tì',
    '🏄‍♀' => 'obìnrín tí ń wá íńtánɛ́tì',
    '🚣‍♂' => 'ɔkùnrin tí ń wakɔ̀ ojú omi kékeré',
    '🚣‍♀' => 'obìnrin tí ń wakɔ̀ ojú omi kékeré',
    '🏊‍♂' => 'ɔkùnrin tí ń wɛdò',
    '🏊‍♀' => 'obìnrin tí ń wɛdò',
    '⛹‍♂' => 'ɔkùnrin tí ń tà boun bɔ́ɔ̀lù',
    '⛹‍♀' => 'obìnrin tà boun bɔ́ɔ̀lù',
    '🏋‍♂' => 'ɔkùnrin tí ń a fà ìwɔ̀n sókè',
    '🏋‍♀' => 'obìnrin tí ń a fà ìwɔ̀n sókè',
    '🚴‍♂' => 'ɔkùnrin tí ń wa kɛ̀kɛ́',
    '🚴‍♀' => 'obìnrin tí ń wa kɛ̀kɛ́',
    '🚵‍♂' => 'ɔkùnrin tín gùn kè wa kɛ̀kɛ́',
    '🚵‍♀' => 'obìnrin tín gùn kè wa kɛ̀kɛ́',
    '🤸‍♂' => 'ɔkùnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n',
    '🤸‍♀' => 'obìnrin tí ń yí kɛ̀kɛ́ alágbɔ̀n',
    '🤼‍♂' => 'àwɔn ɔkùnrin ti n ja ijakadi',
    '🤼‍♀' => 'àwɔn obìnrn tí ń jà ijakadi',
    '🤽‍♂' => 'ɔkùnrin n shere olomi',
    '🤽‍♀' => 'obìnrin n shere olomi',
    '🤾‍♂' => 'ɔkùnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́',
    '🤾‍♀' => 'obìnrin tí ń gbá bɔ́ɔ̀lù ɔlɔ́wɔ́',
    '🤹‍♂' => 'ɔkùnrin tí ń jù ǹkan sókè',
    '🤹‍♀' => 'obìnrin tí ń jú ǹkan sókè',
    '🧘‍♂' => 'Ɔkùnrin nípò ìgbàgbé',
    '🧘‍♀' => 'Obìnrin nípò ìgbàgbé',
    '🧑‍🧒' => 'ìdílé: àgbàlagbà, ɔmɔdé',
    '🐕‍🦺' => 'ajá ishɛ́ àwɔn abirùn',
    '🐈‍⬛' => 'ológbò dúdú',
    '🐻‍❄' => 'ɛranko beari funfun tí ń gbé orí yìnyín',
    '🐦‍⬛' => 'ɛyɛ dúdú',
    '🐦‍🔥' => 'ɛyɛ ìtàn àìlèkú',
    '🍋‍🟩' => 'ɔsàn wɛ́wɛ́',
    '🍄‍🟫' => 'olú aláwɔ̀ pupa rɛ́súrɛ́sú',
    '⛓‍💥' => 'ìdè tó ti já',
    '🏳‍🌈' => 'àsíá olóshùmarè',
    '🏳‍⚧' => 'àsíá ashàyípadà-akɔ-n-bábo',
    '🏴‍☠' => 'àsíá jàgùdà orí omi-òkun',
    '👋🏻' => 'N Juwɔ: amɔ́lára',
    '👋🏼' => 'N Juwɔ: amɔ́lára díɛ̀',
    '👋🏽' => 'N Juwɔ: amɔ́láwɔ̀ díɛ̀',
    '👋🏾' => 'N Juwɔ: adúláwɔ̀ díɛ̀',
    '👋🏿' => 'N Juwɔ: adúláwɔ̀',
    '🤚🏻' => 'Na Ɛhin Ɔwɔ Soke: amɔ́lára',
    '🤚🏼' => 'Na Ɛhin Ɔwɔ Soke: amɔ́lára díɛ̀',
    '🤚🏽' => 'Na Ɛhin Ɔwɔ Soke: amɔ́láwɔ̀ díɛ̀',
    '🤚🏾' => 'Na Ɛhin Ɔwɔ Soke: adúláwɔ̀ díɛ̀',
    '🤚🏿' => 'Na Ɛhin Ɔwɔ Soke: adúláwɔ̀',
    '🖐🏻' => 'nawɔ́ sókè pɛ̀lú ìyàka: amɔ́lára',
    '🖐🏼' => 'nawɔ́ sókè pɛ̀lú ìyàka: amɔ́lára díɛ̀',
    '🖐🏽' => 'nawɔ́ sókè pɛ̀lú ìyàka: amɔ́láwɔ̀ díɛ̀',
    '🖐🏾' => 'nawɔ́ sókè pɛ̀lú ìyàka: adúláwɔ̀ díɛ̀',
    '🖐🏿' => 'nawɔ́ sókè pɛ̀lú ìyàka: adúláwɔ̀',
    '✋🏻' => 'Ɔwɔ Nina Soke: amɔ́lára',
    '✋🏼' => 'Ɔwɔ Nina Soke: amɔ́lára díɛ̀',
    '✋🏽' => 'Ɔwɔ Nina Soke: amɔ́láwɔ̀ díɛ̀',
    '✋🏾' => 'Ɔwɔ Nina Soke: adúláwɔ̀ díɛ̀',
    '✋🏿' => 'Ɔwɔ Nina Soke: adúláwɔ̀',
    '🖖🏻' => 'Kiki Ibɛri Funni: amɔ́lára',
    '🖖🏼' => 'Kiki Ibɛri Funni: amɔ́lára díɛ̀',
    '🖖🏽' => 'Kiki Ibɛri Funni: amɔ́láwɔ̀ díɛ̀',
    '🖖🏾' => 'Kiki Ibɛri Funni: adúláwɔ̀ díɛ̀',
    '🖖🏿' => 'Kiki Ibɛri Funni: adúláwɔ̀',
    '🫱🏻' => 'ɔwɔ́ ɔ̀tún: amɔ́lára',
    '🫱🏼' => 'ɔwɔ́ ɔ̀tún: amɔ́lára díɛ̀',
    '🫱🏽' => 'ɔwɔ́ ɔ̀tún: amɔ́láwɔ̀ díɛ̀',
    '🫱🏾' => 'ɔwɔ́ ɔ̀tún: adúláwɔ̀ díɛ̀',
    '🫱🏿' => 'ɔwɔ́ ɔ̀tún: adúláwɔ̀',
    '🫲🏻' => 'ɔwɔ́ òsì: amɔ́lára',
    '🫲🏼' => 'ɔwɔ́ òsì: amɔ́lára díɛ̀',
    '🫲🏽' => 'ɔwɔ́ òsì: amɔ́láwɔ̀ díɛ̀',
    '🫲🏾' => 'ɔwɔ́ òsì: adúláwɔ̀ díɛ̀',
    '🫲🏿' => 'ɔwɔ́ òsì: adúláwɔ̀',
    '🫳🏻' => 'àtɛ́lɛ̀wɔ́ ìsàlɛ̀: amɔ́lára',
    '🫳🏼' => 'àtɛ́lɛ̀wɔ́ ìsàlɛ̀: amɔ́lára díɛ̀',
    '🫳🏽' => 'àtɛ́lɛ̀wɔ́ ìsàlɛ̀: amɔ́láwɔ̀ díɛ̀',
    '🫳🏾' => 'àtɛ́lɛ̀wɔ́ ìsàlɛ̀: adúláwɔ̀ díɛ̀',
    '🫳🏿' => 'àtɛ́lɛ̀wɔ́ ìsàlɛ̀: adúláwɔ̀',
    '🫴🏻' => 'àtɛ́lɛwɔ́ òkè: amɔ́lára',
    '🫴🏼' => 'àtɛ́lɛwɔ́ òkè: amɔ́lára díɛ̀',
    '🫴🏽' => 'àtɛ́lɛwɔ́ òkè: amɔ́láwɔ̀ díɛ̀',
    '🫴🏾' => 'àtɛ́lɛwɔ́ òkè: adúláwɔ̀ díɛ̀',
    '🫴🏿' => 'àtɛ́lɛwɔ́ òkè: adúláwɔ̀',
    '🫷🏻' => 'títi ɔwɔ́ sɔ́sì: amɔ́lára',
    '🫷🏼' => 'títi ɔwɔ́ sɔ́sì: amɔ́lára díɛ̀',
    '🫷🏽' => 'títi ɔwɔ́ sɔ́sì: amɔ́láwɔ̀ díɛ̀',
    '🫷🏾' => 'títi ɔwɔ́ sɔ́sì: adúláwɔ̀ díɛ̀',
    '🫷🏿' => 'títi ɔwɔ́ sɔ́sì: adúláwɔ̀',
    '🫸🏻' => 'títi ɔwɔ́ sɔ́tun: amɔ́lára',
    '🫸🏼' => 'títi ɔwɔ́ sɔ́tun: amɔ́lára díɛ̀',
    '🫸🏽' => 'títi ɔwɔ́ sɔ́tun: amɔ́láwɔ̀ díɛ̀',
    '🫸🏾' => 'títi ɔwɔ́ sɔ́tun: adúláwɔ̀ díɛ̀',
    '🫸🏿' => 'títi ɔwɔ́ sɔ́tun: adúláwɔ̀',
    '👌🏻' => 'Ɔwɔ ODARA: amɔ́lára',
    '👌🏼' => 'Ɔwɔ ODARA: amɔ́lára díɛ̀',
    '👌🏽' => 'Ɔwɔ ODARA: amɔ́láwɔ̀ díɛ̀',
    '👌🏾' => 'Ɔwɔ ODARA: adúláwɔ̀ díɛ̀',
    '👌🏿' => 'Ɔwɔ ODARA: adúláwɔ̀',
    '🤌🏻' => 'ìka kíkákò: amɔ́lára',
    '🤌🏼' => 'ìka kíkákò: amɔ́lára díɛ̀',
    '🤌🏽' => 'ìka kíkákò: amɔ́láwɔ̀ díɛ̀',
    '🤌🏾' => 'ìka kíkákò: adúláwɔ̀ díɛ̀',
    '🤌🏿' => 'ìka kíkákò: adúláwɔ̀',
    '🤏🏻' => 'ìka kíká: amɔ́lára',
    '🤏🏼' => 'ìka kíká: amɔ́lára díɛ̀',
    '🤏🏽' => 'ìka kíká: amɔ́láwɔ̀ díɛ̀',
    '🤏🏾' => 'ìka kíká: adúláwɔ̀ díɛ̀',
    '🤏🏿' => 'ìka kíká: adúláwɔ̀',
    '✌🏻' => 'asheyɔrí ɔwɔ́: amɔ́lára',
    '✌🏼' => 'asheyɔrí ɔwɔ́: amɔ́lára díɛ̀',
    '✌🏽' => 'asheyɔrí ɔwɔ́: amɔ́láwɔ̀ díɛ̀',
    '✌🏾' => 'asheyɔrí ɔwɔ́: adúláwɔ̀ díɛ̀',
    '✌🏿' => 'asheyɔrí ɔwɔ́: adúláwɔ̀',
    '🤞🏻' => 'Igbekalera: amɔ́lára',
    '🤞🏼' => 'Igbekalera: amɔ́lára díɛ̀',
    '🤞🏽' => 'Igbekalera: amɔ́láwɔ̀ díɛ̀',
    '🤞🏾' => 'Igbekalera: adúláwɔ̀ díɛ̀',
    '🤞🏿' => 'Igbekalera: adúláwɔ̀',
    '🫰🏻' => 'ɔwɔ́ pɛ̀lú ìka kɛ́keré àti ìka ńlá ní pípapɔ̀: amɔ́lára',
    '🫰🏼' => 'ɔwɔ́ pɛ̀lú ìka kɛ́keré àti ìka ńlá ní pípapɔ̀: amɔ́lára díɛ̀',
    '🫰🏽' => 'ɔwɔ́ pɛ̀lú ìka kɛ́keré àti ìka ńlá ní pípapɔ̀: amɔ́láwɔ̀ díɛ̀',
    '🫰🏾' => 'ɔwɔ́ pɛ̀lú ìka kɛ́keré àti ìka ńlá ní pípapɔ̀: adúláwɔ̀ díɛ̀',
    '🫰🏿' => 'ɔwɔ́ pɛ̀lú ìka kɛ́keré àti ìka ńlá ní pípapɔ̀: adúláwɔ̀',
    '🤟🏻' => 'ìfɔwɔ́júwè mo ní ìfɛ́: amɔ́lára',
    '🤟🏼' => 'ìfɔwɔ́júwè mo ní ìfɛ́: amɔ́lára díɛ̀',
    '🤟🏽' => 'ìfɔwɔ́júwè mo ní ìfɛ́: amɔ́láwɔ̀ díɛ̀',
    '🤟🏾' => 'ìfɔwɔ́júwè mo ní ìfɛ́: adúláwɔ̀ díɛ̀',
    '🤟🏿' => 'ìfɔwɔ́júwè mo ní ìfɛ́: adúláwɔ̀',
    '🤘🏻' => 'Aami Awɔn Iwo: amɔ́lára',
    '🤘🏼' => 'Aami Awɔn Iwo: amɔ́lára díɛ̀',
    '🤘🏽' => 'Aami Awɔn Iwo: amɔ́láwɔ̀ díɛ̀',
    '🤘🏾' => 'Aami Awɔn Iwo: adúláwɔ̀ díɛ̀',
    '🤘🏿' => 'Aami Awɔn Iwo: adúláwɔ̀',
    '🤙🏻' => 'Ɔwɔ Ipeni: amɔ́lára',
    '🤙🏼' => 'Ɔwɔ Ipeni: amɔ́lára díɛ̀',
    '🤙🏽' => 'Ɔwɔ Ipeni: amɔ́láwɔ̀ díɛ̀',
    '🤙🏾' => 'Ɔwɔ Ipeni: adúláwɔ̀ díɛ̀',
    '🤙🏿' => 'Ɔwɔ Ipeni: adúláwɔ̀',
    '👈🏻' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Osi: amɔ́lára',
    '👈🏼' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Osi: amɔ́lára díɛ̀',
    '👈🏽' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Osi: amɔ́láwɔ̀ díɛ̀',
    '👈🏾' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Osi: adúláwɔ̀ díɛ̀',
    '👈🏿' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Osi: adúláwɔ̀',
    '👉🏻' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Ɔtun: amɔ́lára',
    '👉🏼' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Ɔtun: amɔ́lára díɛ̀',
    '👉🏽' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Ɔtun: amɔ́láwɔ̀ díɛ̀',
    '👉🏾' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Ɔtun: adúláwɔ̀ díɛ̀',
    '👉🏿' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Ɔtun: adúláwɔ̀',
    '👆🏻' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Oke: amɔ́lára',
    '👆🏼' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Oke: amɔ́lára díɛ̀',
    '👆🏽' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Oke: amɔ́láwɔ̀ díɛ̀',
    '👆🏾' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Oke: adúláwɔ̀ díɛ̀',
    '👆🏿' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Oke: adúláwɔ̀',
    '🖕🏻' => 'ìka àárín: amɔ́lára',
    '🖕🏼' => 'ìka àárín: amɔ́lára díɛ̀',
    '🖕🏽' => 'ìka àárín: amɔ́láwɔ̀ díɛ̀',
    '🖕🏾' => 'ìka àárín: adúláwɔ̀ díɛ̀',
    '🖕🏿' => 'ìka àárín: adúláwɔ̀',
    '👇🏻' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Isalɛ: amɔ́lára',
    '👇🏼' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Isalɛ: amɔ́lára díɛ̀',
    '👇🏽' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Isalɛ: amɔ́láwɔ̀ díɛ̀',
    '👇🏾' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Isalɛ: adúláwɔ̀ díɛ̀',
    '👇🏿' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Isalɛ: adúláwɔ̀',
    '☝🏻' => 'ìka kékeré tí ń tɔ́ka sókè: amɔ́lára',
    '☝🏼' => 'ìka kékeré tí ń tɔ́ka sókè: amɔ́lára díɛ̀',
    '☝🏽' => 'ìka kékeré tí ń tɔ́ka sókè: amɔ́láwɔ̀ díɛ̀',
    '☝🏾' => 'ìka kékeré tí ń tɔ́ka sókè: adúláwɔ̀ díɛ̀',
    '☝🏿' => 'ìka kékeré tí ń tɔ́ka sókè: adúláwɔ̀',
    '🫵🏻' => 'títɔ́ka sí olùwòran: amɔ́lára',
    '🫵🏼' => 'títɔ́ka sí olùwòran: amɔ́lára díɛ̀',
    '🫵🏽' => 'títɔ́ka sí olùwòran: amɔ́láwɔ̀ díɛ̀',
    '🫵🏾' => 'títɔ́ka sí olùwòran: adúláwɔ̀ díɛ̀',
    '🫵🏿' => 'títɔ́ka sí olùwòran: adúláwɔ̀',
    '👍🏻' => 'Atanpako Loke: amɔ́lára',
    '👍🏼' => 'Atanpako Loke: amɔ́lára díɛ̀',
    '👍🏽' => 'Atanpako Loke: amɔ́láwɔ̀ díɛ̀',
    '👍🏾' => 'Atanpako Loke: adúláwɔ̀ díɛ̀',
    '👍🏿' => 'Atanpako Loke: adúláwɔ̀',
    '👎🏻' => 'Atanpako Nisalɛ: amɔ́lára',
    '👎🏼' => 'Atanpako Nisalɛ: amɔ́lára díɛ̀',
    '👎🏽' => 'Atanpako Nisalɛ: amɔ́láwɔ̀ díɛ̀',
    '👎🏾' => 'Atanpako Nisalɛ: adúláwɔ̀ díɛ̀',
    '👎🏿' => 'Atanpako Nisalɛ: adúláwɔ̀',
    '✊🏻' => 'Ɛshɛ Ti a Na Soke: amɔ́lára',
    '✊🏼' => 'Ɛshɛ Ti a Na Soke: amɔ́lára díɛ̀',
    '✊🏽' => 'Ɛshɛ Ti a Na Soke: amɔ́láwɔ̀ díɛ̀',
    '✊🏾' => 'Ɛshɛ Ti a Na Soke: adúláwɔ̀ díɛ̀',
    '✊🏿' => 'Ɛshɛ Ti a Na Soke: adúláwɔ̀',
    '👊🏻' => 'Ɛshɛ Ti o Nbɔ: amɔ́lára',
    '👊🏼' => 'Ɛshɛ Ti o Nbɔ: amɔ́lára díɛ̀',
    '👊🏽' => 'Ɛshɛ Ti o Nbɔ: amɔ́láwɔ̀ díɛ̀',
    '👊🏾' => 'Ɛshɛ Ti o Nbɔ: adúláwɔ̀ díɛ̀',
    '👊🏿' => 'Ɛshɛ Ti o Nbɔ: adúláwɔ̀',
    '🤛🏻' => 'Ɛsɛ ti O Kɔju sosi: amɔ́lára',
    '🤛🏼' => 'Ɛsɛ ti O Kɔju sosi: amɔ́lára díɛ̀',
    '🤛🏽' => 'Ɛsɛ ti O Kɔju sosi: amɔ́láwɔ̀ díɛ̀',
    '🤛🏾' => 'Ɛsɛ ti O Kɔju sosi: adúláwɔ̀ díɛ̀',
    '🤛🏿' => 'Ɛsɛ ti O Kɔju sosi: adúláwɔ̀',
    '🤜🏻' => 'Ɛsɛ ti O Kɔju sɔtun: amɔ́lára',
    '🤜🏼' => 'Ɛsɛ ti O Kɔju sɔtun: amɔ́lára díɛ̀',
    '🤜🏽' => 'Ɛsɛ ti O Kɔju sɔtun: amɔ́láwɔ̀ díɛ̀',
    '🤜🏾' => 'Ɛsɛ ti O Kɔju sɔtun: adúláwɔ̀ díɛ̀',
    '🤜🏿' => 'Ɛsɛ ti O Kɔju sɔtun: adúláwɔ̀',
    '👏🏻' => 'N Patɛwɔ: amɔ́lára',
    '👏🏼' => 'N Patɛwɔ: amɔ́lára díɛ̀',
    '👏🏽' => 'N Patɛwɔ: amɔ́láwɔ̀ díɛ̀',
    '👏🏾' => 'N Patɛwɔ: adúláwɔ̀ díɛ̀',
    '👏🏿' => 'N Patɛwɔ: adúláwɔ̀',
    '🙌🏻' => 'Ina Awɔn Ɔwɔ: amɔ́lára',
    '🙌🏼' => 'Ina Awɔn Ɔwɔ: amɔ́lára díɛ̀',
    '🙌🏽' => 'Ina Awɔn Ɔwɔ: amɔ́láwɔ̀ díɛ̀',
    '🙌🏾' => 'Ina Awɔn Ɔwɔ: adúláwɔ̀ díɛ̀',
    '🙌🏿' => 'Ina Awɔn Ɔwɔ: adúláwɔ̀',
    '🫶🏻' => 'ɔwɔ́ ɔkàn: amɔ́lára',
    '🫶🏼' => 'ɔwɔ́ ɔkàn: amɔ́lára díɛ̀',
    '🫶🏽' => 'ɔwɔ́ ɔkàn: amɔ́láwɔ̀ díɛ̀',
    '🫶🏾' => 'ɔwɔ́ ɔkàn: adúláwɔ̀ díɛ̀',
    '🫶🏿' => 'ɔwɔ́ ɔkàn: adúláwɔ̀',
    '👐🏻' => 'Awɔn Ɔwɔ Shishi: amɔ́lára',
    '👐🏼' => 'Awɔn Ɔwɔ Shishi: amɔ́lára díɛ̀',
    '👐🏽' => 'Awɔn Ɔwɔ Shishi: amɔ́láwɔ̀ díɛ̀',
    '👐🏾' => 'Awɔn Ɔwɔ Shishi: adúláwɔ̀ díɛ̀',
    '👐🏿' => 'Awɔn Ɔwɔ Shishi: adúláwɔ̀',
    '🤲🏻' => 'àtɛ́lɛ́ɔwɔ́ papɔ̀: amɔ́lára',
    '🤲🏼' => 'àtɛ́lɛ́ɔwɔ́ papɔ̀: amɔ́lára díɛ̀',
    '🤲🏽' => 'àtɛ́lɛ́ɔwɔ́ papɔ̀: amɔ́láwɔ̀ díɛ̀',
    '🤲🏾' => 'àtɛ́lɛ́ɔwɔ́ papɔ̀: adúláwɔ̀ díɛ̀',
    '🤲🏿' => 'àtɛ́lɛ́ɔwɔ́ papɔ̀: adúláwɔ̀',
    '🤝🏻' => 'Ìbɔwɔ́: amɔ́lára',
    '🤝🏼' => 'Ìbɔwɔ́: amɔ́lára díɛ̀',
    '🤝🏽' => 'Ìbɔwɔ́: amɔ́láwɔ̀ díɛ̀',
    '🤝🏾' => 'Ìbɔwɔ́: adúláwɔ̀ díɛ̀',
    '🤝🏿' => 'Ìbɔwɔ́: adúláwɔ̀',
    '🙏🏻' => 'Ika Awɔn Ɔwɔ: amɔ́lára',
    '🙏🏼' => 'Ika Awɔn Ɔwɔ: amɔ́lára díɛ̀',
    '🙏🏽' => 'Ika Awɔn Ɔwɔ: amɔ́láwɔ̀ díɛ̀',
    '🙏🏾' => 'Ika Awɔn Ɔwɔ: adúláwɔ̀ díɛ̀',
    '🙏🏿' => 'Ika Awɔn Ɔwɔ: adúláwɔ̀',
    '✍🏻' => 'ńkɔ́wé: amɔ́lára',
    '✍🏼' => 'ńkɔ́wé: amɔ́lára díɛ̀',
    '✍🏽' => 'ńkɔ́wé: amɔ́láwɔ̀ díɛ̀',
    '✍🏾' => 'ńkɔ́wé: adúláwɔ̀ díɛ̀',
    '✍🏿' => 'ńkɔ́wé: adúláwɔ̀',
    '💅🏻' => 'Ikun Eekanna: amɔ́lára',
    '💅🏼' => 'Ikun Eekanna: amɔ́lára díɛ̀',
    '💅🏽' => 'Ikun Eekanna: amɔ́láwɔ̀ díɛ̀',
    '💅🏾' => 'Ikun Eekanna: adúláwɔ̀ díɛ̀',
    '💅🏿' => 'Ikun Eekanna: adúláwɔ̀',
    '🤳🏻' => 'Yiya Ara ɛni: amɔ́lára',
    '🤳🏼' => 'Yiya Ara ɛni: amɔ́lára díɛ̀',
    '🤳🏽' => 'Yiya Ara ɛni: amɔ́láwɔ̀ díɛ̀',
    '🤳🏾' => 'Yiya Ara ɛni: adúláwɔ̀ díɛ̀',
    '🤳🏿' => 'Yiya Ara ɛni: adúláwɔ̀',
    '💪🏻' => 'Aya Fifɛ: amɔ́lára',
    '💪🏼' => 'Aya Fifɛ: amɔ́lára díɛ̀',
    '💪🏽' => 'Aya Fifɛ: amɔ́láwɔ̀ díɛ̀',
    '💪🏾' => 'Aya Fifɛ: adúláwɔ̀ díɛ̀',
    '💪🏿' => 'Aya Fifɛ: adúláwɔ̀',
    '🦵🏻' => 'ese: amɔ́lára',
    '🦵🏼' => 'ese: amɔ́lára díɛ̀',
    '🦵🏽' => 'ese: amɔ́láwɔ̀ díɛ̀',
    '🦵🏾' => 'ese: adúláwɔ̀ díɛ̀',
    '🦵🏿' => 'ese: adúláwɔ̀',
    '🦶🏻' => 'ɛsɛ̀: amɔ́lára',
    '🦶🏼' => 'ɛsɛ̀: amɔ́lára díɛ̀',
    '🦶🏽' => 'ɛsɛ̀: amɔ́láwɔ̀ díɛ̀',
    '🦶🏾' => 'ɛsɛ̀: adúláwɔ̀ díɛ̀',
    '🦶🏿' => 'ɛsɛ̀: adúláwɔ̀',
    '👂🏻' => 'Etí: amɔ́lára',
    '👂🏼' => 'Etí: amɔ́lára díɛ̀',
    '👂🏽' => 'Etí: amɔ́láwɔ̀ díɛ̀',
    '👂🏾' => 'Etí: adúláwɔ̀ díɛ̀',
    '👂🏿' => 'Etí: adúláwɔ̀',
    '🦻🏻' => 'etí pɛ̀lú ohun ìgbɔ́ràn: amɔ́lára',
    '🦻🏼' => 'etí pɛ̀lú ohun ìgbɔ́ràn: amɔ́lára díɛ̀',
    '🦻🏽' => 'etí pɛ̀lú ohun ìgbɔ́ràn: amɔ́láwɔ̀ díɛ̀',
    '🦻🏾' => 'etí pɛ̀lú ohun ìgbɔ́ràn: adúláwɔ̀ díɛ̀',
    '🦻🏿' => 'etí pɛ̀lú ohun ìgbɔ́ràn: adúláwɔ̀',
    '👃🏻' => 'Imu: amɔ́lára',
    '👃🏼' => 'Imu: amɔ́lára díɛ̀',
    '👃🏽' => 'Imu: amɔ́láwɔ̀ díɛ̀',
    '👃🏾' => 'Imu: adúláwɔ̀ díɛ̀',
    '👃🏿' => 'Imu: adúláwɔ̀',
    '👶🏻' => 'ìkókó: amɔ́lára',
    '👶🏼' => 'ìkókó: amɔ́lára díɛ̀',
    '👶🏽' => 'ìkókó: amɔ́láwɔ̀ díɛ̀',
    '👶🏾' => 'ìkókó: adúláwɔ̀ díɛ̀',
    '👶🏿' => 'ìkókó: adúláwɔ̀',
    '🧒🏻' => 'ɔmɔ: amɔ́lára',
    '🧒🏼' => 'ɔmɔ: amɔ́lára díɛ̀',
    '🧒🏽' => 'ɔmɔ: amɔ́láwɔ̀ díɛ̀',
    '🧒🏾' => 'ɔmɔ: adúláwɔ̀ díɛ̀',
    '🧒🏿' => 'ɔmɔ: adúláwɔ̀',
    '👦🏻' => 'ɔmɔkùnrin: amɔ́lára',
    '👦🏼' => 'ɔmɔkùnrin: amɔ́lára díɛ̀',
    '👦🏽' => 'ɔmɔkùnrin: amɔ́láwɔ̀ díɛ̀',
    '👦🏾' => 'ɔmɔkùnrin: adúláwɔ̀ díɛ̀',
    '👦🏿' => 'ɔmɔkùnrin: adúláwɔ̀',
    '👧🏻' => 'ɔmɔbìrin: amɔ́lára',
    '👧🏼' => 'ɔmɔbìrin: amɔ́lára díɛ̀',
    '👧🏽' => 'ɔmɔbìrin: amɔ́láwɔ̀ díɛ̀',
    '👧🏾' => 'ɔmɔbìrin: adúláwɔ̀ díɛ̀',
    '👧🏿' => 'ɔmɔbìrin: adúláwɔ̀',
    '🧑🏻' => 'àgbà: amɔ́lára',
    '🧑🏼' => 'àgbà: amɔ́lára díɛ̀',
    '🧑🏽' => 'àgbà: amɔ́láwɔ̀ díɛ̀',
    '🧑🏾' => 'àgbà: adúláwɔ̀ díɛ̀',
    '🧑🏿' => 'àgbà: adúláwɔ̀',
    '👱🏻' => 'Eniyan Onirun funfun: amɔ́lára',
    '👱🏼' => 'Eniyan Onirun funfun: amɔ́lára díɛ̀',
    '👱🏽' => 'Eniyan Onirun funfun: amɔ́láwɔ̀ díɛ̀',
    '👱🏾' => 'Eniyan Onirun funfun: adúláwɔ̀ díɛ̀',
    '👱🏿' => 'Eniyan Onirun funfun: adúláwɔ̀',
    '👨🏻' => 'Ɔkùnrin: amɔ́lára',
    '👨🏼' => 'Ɔkùnrin: amɔ́lára díɛ̀',
    '👨🏽' => 'Ɔkùnrin: amɔ́láwɔ̀ díɛ̀',
    '👨🏾' => 'Ɔkùnrin: adúláwɔ̀ díɛ̀',
    '👨🏿' => 'Ɔkùnrin: adúláwɔ̀',
    '🧔🏻' => 'apárí: amɔ́lára',
    '🧔🏼' => 'apárí: amɔ́lára díɛ̀',
    '🧔🏽' => 'apárí: amɔ́láwɔ̀ díɛ̀',
    '🧔🏾' => 'apárí: adúláwɔ̀ díɛ̀',
    '🧔🏿' => 'apárí: adúláwɔ̀',
    '👩🏻' => 'Obìnrin: amɔ́lára',
    '👩🏼' => 'Obìnrin: amɔ́lára díɛ̀',
    '👩🏽' => 'Obìnrin: amɔ́láwɔ̀ díɛ̀',
    '👩🏾' => 'Obìnrin: adúláwɔ̀ díɛ̀',
    '👩🏿' => 'Obìnrin: adúláwɔ̀',
    '🧓🏻' => 'àgbàlagbà: amɔ́lára',
    '🧓🏼' => 'àgbàlagbà: amɔ́lára díɛ̀',
    '🧓🏽' => 'àgbàlagbà: amɔ́láwɔ̀ díɛ̀',
    '🧓🏾' => 'àgbàlagbà: adúláwɔ̀ díɛ̀',
    '🧓🏿' => 'àgbàlagbà: adúláwɔ̀',
    '👴🏻' => 'Agbalagba Ɔkunrin: amɔ́lára',
    '👴🏼' => 'Agbalagba Ɔkunrin: amɔ́lára díɛ̀',
    '👴🏽' => 'Agbalagba Ɔkunrin: amɔ́láwɔ̀ díɛ̀',
    '👴🏾' => 'Agbalagba Ɔkunrin: adúláwɔ̀ díɛ̀',
    '👴🏿' => 'Agbalagba Ɔkunrin: adúláwɔ̀',
    '👵🏻' => 'Agbalagba Obinrin: amɔ́lára',
    '👵🏼' => 'Agbalagba Obinrin: amɔ́lára díɛ̀',
    '👵🏽' => 'Agbalagba Obinrin: amɔ́láwɔ̀ díɛ̀',
    '👵🏾' => 'Agbalagba Obinrin: adúláwɔ̀ díɛ̀',
    '👵🏿' => 'Agbalagba Obinrin: adúláwɔ̀',
    '🙍🏻' => 'Ɛni N Bojujɛ: amɔ́lára',
    '🙍🏼' => 'Ɛni N Bojujɛ: amɔ́lára díɛ̀',
    '🙍🏽' => 'Ɛni N Bojujɛ: amɔ́láwɔ̀ díɛ̀',
    '🙍🏾' => 'Ɛni N Bojujɛ: adúláwɔ̀ díɛ̀',
    '🙍🏿' => 'Ɛni N Bojujɛ: adúláwɔ̀',
    '🙎🏻' => 'Ɛni Yahɔn sita: amɔ́lára',
    '🙎🏼' => 'Ɛni Yahɔn sita: amɔ́lára díɛ̀',
    '🙎🏽' => 'Ɛni Yahɔn sita: amɔ́láwɔ̀ díɛ̀',
    '🙎🏾' => 'Ɛni Yahɔn sita: adúláwɔ̀ díɛ̀',
    '🙎🏿' => 'Ɛni Yahɔn sita: adúláwɔ̀',
    '🙅🏻' => 'Ɛni Nsɔ RARA: amɔ́lára',
    '🙅🏼' => 'Ɛni Nsɔ RARA: amɔ́lára díɛ̀',
    '🙅🏽' => 'Ɛni Nsɔ RARA: amɔ́láwɔ̀ díɛ̀',
    '🙅🏾' => 'Ɛni Nsɔ RARA: adúláwɔ̀ díɛ̀',
    '🙅🏿' => 'Ɛni Nsɔ RARA: adúláwɔ̀',
    '🙆🏻' => 'Ɛni Nsɔ O DARA: amɔ́lára',
    '🙆🏼' => 'Ɛni Nsɔ O DARA: amɔ́lára díɛ̀',
    '🙆🏽' => 'Ɛni Nsɔ O DARA: amɔ́láwɔ̀ díɛ̀',
    '🙆🏾' => 'Ɛni Nsɔ O DARA: adúláwɔ̀ díɛ̀',
    '🙆🏿' => 'Ɛni Nsɔ O DARA: adúláwɔ̀',
    '💁🏻' => 'Ɛni N Tɔka Ɔwɔ: amɔ́lára',
    '💁🏼' => 'Ɛni N Tɔka Ɔwɔ: amɔ́lára díɛ̀',
    '💁🏽' => 'Ɛni N Tɔka Ɔwɔ: amɔ́láwɔ̀ díɛ̀',
    '💁🏾' => 'Ɛni N Tɔka Ɔwɔ: adúláwɔ̀ díɛ̀',
    '💁🏿' => 'Ɛni N Tɔka Ɔwɔ: adúláwɔ̀',
    '🙋🏻' => 'Ɛni N Nawɔ Soke: amɔ́lára',
    '🙋🏼' => 'Ɛni N Nawɔ Soke: amɔ́lára díɛ̀',
    '🙋🏽' => 'Ɛni N Nawɔ Soke: amɔ́láwɔ̀ díɛ̀',
    '🙋🏾' => 'Ɛni N Nawɔ Soke: adúláwɔ̀ díɛ̀',
    '🙋🏿' => 'Ɛni N Nawɔ Soke: adúláwɔ̀',
    '🧏🏻' => 'odi: amɔ́lára',
    '🧏🏼' => 'odi: amɔ́lára díɛ̀',
    '🧏🏽' => 'odi: amɔ́láwɔ̀ díɛ̀',
    '🧏🏾' => 'odi: adúláwɔ̀ díɛ̀',
    '🧏🏿' => 'odi: adúláwɔ̀',
    '🙇🏻' => 'Ɛni N Tɛriba: amɔ́lára',
    '🙇🏼' => 'Ɛni N Tɛriba: amɔ́lára díɛ̀',
    '🙇🏽' => 'Ɛni N Tɛriba: amɔ́láwɔ̀ díɛ̀',
    '🙇🏾' => 'Ɛni N Tɛriba: adúláwɔ̀ díɛ̀',
    '🙇🏿' => 'Ɛni N Tɛriba: adúláwɔ̀',
    '🤦🏻' => 'Ɛni Fɔwɔ Boju: amɔ́lára',
    '🤦🏼' => 'Ɛni Fɔwɔ Boju: amɔ́lára díɛ̀',
    '🤦🏽' => 'Ɛni Fɔwɔ Boju: amɔ́láwɔ̀ díɛ̀',
    '🤦🏾' => 'Ɛni Fɔwɔ Boju: adúláwɔ̀ díɛ̀',
    '🤦🏿' => 'Ɛni Fɔwɔ Boju: adúláwɔ̀',
    '🤷🏻' => 'Ɛni N Gunpa: amɔ́lára',
    '🤷🏼' => 'Ɛni N Gunpa: amɔ́lára díɛ̀',
    '🤷🏽' => 'Ɛni N Gunpa: amɔ́láwɔ̀ díɛ̀',
    '🤷🏾' => 'Ɛni N Gunpa: adúláwɔ̀ díɛ̀',
    '🤷🏿' => 'Ɛni N Gunpa: adúláwɔ̀',
    '👮🏻' => 'Ɔlɔpa: amɔ́lára',
    '👮🏼' => 'Ɔlɔpa: amɔ́lára díɛ̀',
    '👮🏽' => 'Ɔlɔpa: amɔ́láwɔ̀ díɛ̀',
    '👮🏾' => 'Ɔlɔpa: adúláwɔ̀ díɛ̀',
    '👮🏿' => 'Ɔlɔpa: adúláwɔ̀',
    '🕵🏻' => 'ɔ̀tɛlèmúyé: amɔ́lára',
    '🕵🏼' => 'ɔ̀tɛlèmúyé: amɔ́lára díɛ̀',
    '🕵🏽' => 'ɔ̀tɛlèmúyé: amɔ́láwɔ̀ díɛ̀',
    '🕵🏾' => 'ɔ̀tɛlèmúyé: adúláwɔ̀ díɛ̀',
    '🕵🏿' => 'ɔ̀tɛlèmúyé: adúláwɔ̀',
    '💂🏻' => 'Olushɔ: amɔ́lára',
    '💂🏼' => 'Olushɔ: amɔ́lára díɛ̀',
    '💂🏽' => 'Olushɔ: amɔ́láwɔ̀ díɛ̀',
    '💂🏾' => 'Olushɔ: adúláwɔ̀ díɛ̀',
    '💂🏿' => 'Olushɔ: adúláwɔ̀',
    '🥷🏻' => 'nínjà: amɔ́lára',
    '🥷🏼' => 'nínjà: amɔ́lára díɛ̀',
    '🥷🏽' => 'nínjà: amɔ́láwɔ̀ díɛ̀',
    '🥷🏾' => 'nínjà: adúláwɔ̀ díɛ̀',
    '🥷🏿' => 'nínjà: adúláwɔ̀',
    '👷🏻' => 'Oshishɛ Ikɔle: amɔ́lára',
    '👷🏼' => 'Oshishɛ Ikɔle: amɔ́lára díɛ̀',
    '👷🏽' => 'Oshishɛ Ikɔle: amɔ́láwɔ̀ díɛ̀',
    '👷🏾' => 'Oshishɛ Ikɔle: adúláwɔ̀ díɛ̀',
    '👷🏿' => 'Oshishɛ Ikɔle: adúláwɔ̀',
    '🫅🏻' => 'ènìyàn pɛ̀lú adé: amɔ́lára',
    '🫅🏼' => 'ènìyàn pɛ̀lú adé: amɔ́lára díɛ̀',
    '🫅🏽' => 'ènìyàn pɛ̀lú adé: amɔ́láwɔ̀ díɛ̀',
    '🫅🏾' => 'ènìyàn pɛ̀lú adé: adúláwɔ̀ díɛ̀',
    '🫅🏿' => 'ènìyàn pɛ̀lú adé: adúláwɔ̀',
    '🤴🏻' => 'Ɔmɔkunrin Alade: amɔ́lára',
    '🤴🏼' => 'Ɔmɔkunrin Alade: amɔ́lára díɛ̀',
    '🤴🏽' => 'Ɔmɔkunrin Alade: amɔ́láwɔ̀ díɛ̀',
    '🤴🏾' => 'Ɔmɔkunrin Alade: adúláwɔ̀ díɛ̀',
    '🤴🏿' => 'Ɔmɔkunrin Alade: adúláwɔ̀',
    '👸🏻' => 'Ɔmɔbinrin Alade: amɔ́lára',
    '👸🏼' => 'Ɔmɔbinrin Alade: amɔ́lára díɛ̀',
    '👸🏽' => 'Ɔmɔbinrin Alade: amɔ́láwɔ̀ díɛ̀',
    '👸🏾' => 'Ɔmɔbinrin Alade: adúláwɔ̀ díɛ̀',
    '👸🏿' => 'Ɔmɔbinrin Alade: adúláwɔ̀',
    '👳🏻' => 'Ɛni wɔ Lawani: amɔ́lára',
    '👳🏼' => 'Ɛni wɔ Lawani: amɔ́lára díɛ̀',
    '👳🏽' => 'Ɛni wɔ Lawani: amɔ́láwɔ̀ díɛ̀',
    '👳🏾' => 'Ɛni wɔ Lawani: adúláwɔ̀ díɛ̀',
    '👳🏿' => 'Ɛni wɔ Lawani: adúláwɔ̀',
    '👲🏻' => 'Ɔkunrin Pɛlu Fila Shainisi: amɔ́lára',
    '👲🏼' => 'Ɔkunrin Pɛlu Fila Shainisi: amɔ́lára díɛ̀',
    '👲🏽' => 'Ɔkunrin Pɛlu Fila Shainisi: amɔ́láwɔ̀ díɛ̀',
    '👲🏾' => 'Ɔkunrin Pɛlu Fila Shainisi: adúláwɔ̀ díɛ̀',
    '👲🏿' => 'Ɔkunrin Pɛlu Fila Shainisi: adúláwɔ̀',
    '🧕🏻' => 'obinrin tó wé gèlè: amɔ́lára',
    '🧕🏼' => 'obinrin tó wé gèlè: amɔ́lára díɛ̀',
    '🧕🏽' => 'obinrin tó wé gèlè: amɔ́láwɔ̀ díɛ̀',
    '🧕🏾' => 'obinrin tó wé gèlè: adúláwɔ̀ díɛ̀',
    '🧕🏿' => 'obinrin tó wé gèlè: adúláwɔ̀',
    '🤵🏻' => 'Ɔkunrin Pɛlu Kootu: amɔ́lára',
    '🤵🏼' => 'Ɔkunrin Pɛlu Kootu: amɔ́lára díɛ̀',
    '🤵🏽' => 'Ɔkunrin Pɛlu Kootu: amɔ́láwɔ̀ díɛ̀',
    '🤵🏾' => 'Ɔkunrin Pɛlu Kootu: adúláwɔ̀ díɛ̀',
    '🤵🏿' => 'Ɔkunrin Pɛlu Kootu: adúláwɔ̀',
    '👰🏻' => 'Iyawo Pɛlu Iboju: amɔ́lára',
    '👰🏼' => 'Iyawo Pɛlu Iboju: amɔ́lára díɛ̀',
    '👰🏽' => 'Iyawo Pɛlu Iboju: amɔ́láwɔ̀ díɛ̀',
    '👰🏾' => 'Iyawo Pɛlu Iboju: adúláwɔ̀ díɛ̀',
    '👰🏿' => 'Iyawo Pɛlu Iboju: adúláwɔ̀',
    '🤰🏻' => 'obinrin alaboyun: amɔ́lára',
    '🤰🏼' => 'obinrin alaboyun: amɔ́lára díɛ̀',
    '🤰🏽' => 'obinrin alaboyun: amɔ́láwɔ̀ díɛ̀',
    '🤰🏾' => 'obinrin alaboyun: adúláwɔ̀ díɛ̀',
    '🤰🏿' => 'obinrin alaboyun: adúláwɔ̀',
    '🫃🏻' => 'aláboyún ɔkùnrin: amɔ́lára',
    '🫃🏼' => 'aláboyún ɔkùnrin: amɔ́lára díɛ̀',
    '🫃🏽' => 'aláboyún ɔkùnrin: amɔ́láwɔ̀ díɛ̀',
    '🫃🏾' => 'aláboyún ɔkùnrin: adúláwɔ̀ díɛ̀',
    '🫃🏿' => 'aláboyún ɔkùnrin: adúláwɔ̀',
    '🫄🏻' => 'aláboyún: amɔ́lára',
    '🫄🏼' => 'aláboyún: amɔ́lára díɛ̀',
    '🫄🏽' => 'aláboyún: amɔ́láwɔ̀ díɛ̀',
    '🫄🏾' => 'aláboyún: adúláwɔ̀ díɛ̀',
    '🫄🏿' => 'aláboyún: adúláwɔ̀',
    '🤱🏻' => 'ìfɔ́mɔlɔ́yàn: amɔ́lára',
    '🤱🏼' => 'ìfɔ́mɔlɔ́yàn: amɔ́lára díɛ̀',
    '🤱🏽' => 'ìfɔ́mɔlɔ́yàn: amɔ́láwɔ̀ díɛ̀',
    '🤱🏾' => 'ìfɔ́mɔlɔ́yàn: adúláwɔ̀ díɛ̀',
    '🤱🏿' => 'ìfɔ́mɔlɔ́yàn: adúláwɔ̀',
    '👼🏻' => 'ángɛli ìkókó: amɔ́lára',
    '👼🏼' => 'ángɛli ìkókó: amɔ́lára díɛ̀',
    '👼🏽' => 'ángɛli ìkókó: amɔ́láwɔ̀ díɛ̀',
    '👼🏾' => 'ángɛli ìkókó: adúláwɔ̀ díɛ̀',
    '👼🏿' => 'ángɛli ìkókó: adúláwɔ̀',
    '🎅🏻' => 'Baba Keresi: amɔ́lára',
    '🎅🏼' => 'Baba Keresi: amɔ́lára díɛ̀',
    '🎅🏽' => 'Baba Keresi: amɔ́láwɔ̀ díɛ̀',
    '🎅🏾' => 'Baba Keresi: adúláwɔ̀ díɛ̀',
    '🎅🏿' => 'Baba Keresi: adúláwɔ̀',
    '🤶🏻' => 'Arabinrin Keresi: amɔ́lára',
    '🤶🏼' => 'Arabinrin Keresi: amɔ́lára díɛ̀',
    '🤶🏽' => 'Arabinrin Keresi: amɔ́láwɔ̀ díɛ̀',
    '🤶🏾' => 'Arabinrin Keresi: adúláwɔ̀ díɛ̀',
    '🤶🏿' => 'Arabinrin Keresi: adúláwɔ̀',
    '🦸🏻' => 'akɔni alágbára: amɔ́lára',
    '🦸🏼' => 'akɔni alágbára: amɔ́lára díɛ̀',
    '🦸🏽' => 'akɔni alágbára: amɔ́láwɔ̀ díɛ̀',
    '🦸🏾' => 'akɔni alágbára: adúláwɔ̀ díɛ̀',
    '🦸🏿' => 'akɔni alágbára: adúláwɔ̀',
    '🦹🏻' => 'alátakɔ̀ alágbára: amɔ́lára',
    '🦹🏼' => 'alátakɔ̀ alágbára: amɔ́lára díɛ̀',
    '🦹🏽' => 'alátakɔ̀ alágbára: amɔ́láwɔ̀ díɛ̀',
    '🦹🏾' => 'alátakɔ̀ alágbára: adúláwɔ̀ díɛ̀',
    '🦹🏿' => 'alátakɔ̀ alágbára: adúláwɔ̀',
    '🧙🏻' => 'onídán: amɔ́lára',
    '🧙🏼' => 'onídán: amɔ́lára díɛ̀',
    '🧙🏽' => 'onídán: amɔ́láwɔ̀ díɛ̀',
    '🧙🏾' => 'onídán: adúláwɔ̀ díɛ̀',
    '🧙🏿' => 'onídán: adúláwɔ̀',
    '🧚🏻' => 'Iwin: amɔ́lára',
    '🧚🏼' => 'Iwin: amɔ́lára díɛ̀',
    '🧚🏽' => 'Iwin: amɔ́láwɔ̀ díɛ̀',
    '🧚🏾' => 'Iwin: adúláwɔ̀ díɛ̀',
    '🧚🏿' => 'Iwin: adúláwɔ̀',
    '🧛🏻' => 'Fánpáyà: amɔ́lára',
    '🧛🏼' => 'Fánpáyà: amɔ́lára díɛ̀',
    '🧛🏽' => 'Fánpáyà: amɔ́láwɔ̀ díɛ̀',
    '🧛🏾' => 'Fánpáyà: adúláwɔ̀ díɛ̀',
    '🧛🏿' => 'Fánpáyà: adúláwɔ̀',
    '🧜🏻' => 'Yemɔja ènìyàn: amɔ́lára',
    '🧜🏼' => 'Yemɔja ènìyàn: amɔ́lára díɛ̀',
    '🧜🏽' => 'Yemɔja ènìyàn: amɔ́láwɔ̀ díɛ̀',
    '🧜🏾' => 'Yemɔja ènìyàn: adúláwɔ̀ díɛ̀',
    '🧜🏿' => 'Yemɔja ènìyàn: adúláwɔ̀',
    '🧝🏻' => 'Egbére: amɔ́lára',
    '🧝🏼' => 'Egbére: amɔ́lára díɛ̀',
    '🧝🏽' => 'Egbére: amɔ́láwɔ̀ díɛ̀',
    '🧝🏾' => 'Egbére: adúláwɔ̀ díɛ̀',
    '🧝🏿' => 'Egbére: adúláwɔ̀',
    '💆🏻' => 'ɛni N gba Ifɔwɔwɔnilara: amɔ́lára',
    '💆🏼' => 'ɛni N gba Ifɔwɔwɔnilara: amɔ́lára díɛ̀',
    '💆🏽' => 'ɛni N gba Ifɔwɔwɔnilara: amɔ́láwɔ̀ díɛ̀',
    '💆🏾' => 'ɛni N gba Ifɔwɔwɔnilara: adúláwɔ̀ díɛ̀',
    '💆🏿' => 'ɛni N gba Ifɔwɔwɔnilara: adúláwɔ̀',
    '💇🏻' => 'Ɛni N Gɛrun: amɔ́lára',
    '💇🏼' => 'Ɛni N Gɛrun: amɔ́lára díɛ̀',
    '💇🏽' => 'Ɛni N Gɛrun: amɔ́láwɔ̀ díɛ̀',
    '💇🏾' => 'Ɛni N Gɛrun: adúláwɔ̀ díɛ̀',
    '💇🏿' => 'Ɛni N Gɛrun: adúláwɔ̀',
    '🚶🏻' => 'Ɛni N Rin: amɔ́lára',
    '🚶🏼' => 'Ɛni N Rin: amɔ́lára díɛ̀',
    '🚶🏽' => 'Ɛni N Rin: amɔ́láwɔ̀ díɛ̀',
    '🚶🏾' => 'Ɛni N Rin: adúláwɔ̀ díɛ̀',
    '🚶🏿' => 'Ɛni N Rin: adúláwɔ̀',
    '🧍🏻' => 'ènìyàn dídúró: amɔ́lára',
    '🧍🏼' => 'ènìyàn dídúró: amɔ́lára díɛ̀',
    '🧍🏽' => 'ènìyàn dídúró: amɔ́láwɔ̀ díɛ̀',
    '🧍🏾' => 'ènìyàn dídúró: adúláwɔ̀ díɛ̀',
    '🧍🏿' => 'ènìyàn dídúró: adúláwɔ̀',
    '🧎🏻' => 'ènìyàn kíkúnlɛ̀: amɔ́lára',
    '🧎🏼' => 'ènìyàn kíkúnlɛ̀: amɔ́lára díɛ̀',
    '🧎🏽' => 'ènìyàn kíkúnlɛ̀: amɔ́láwɔ̀ díɛ̀',
    '🧎🏾' => 'ènìyàn kíkúnlɛ̀: adúláwɔ̀ díɛ̀',
    '🧎🏿' => 'ènìyàn kíkúnlɛ̀: adúláwɔ̀',
    '🏃🏻' => 'Ɛni N Sare: amɔ́lára',
    '🏃🏼' => 'Ɛni N Sare: amɔ́lára díɛ̀',
    '🏃🏽' => 'Ɛni N Sare: amɔ́láwɔ̀ díɛ̀',
    '🏃🏾' => 'Ɛni N Sare: adúláwɔ̀ díɛ̀',
    '🏃🏿' => 'Ɛni N Sare: adúláwɔ̀',
    '💃🏻' => 'Obinrin Ti Njo: amɔ́lára',
    '💃🏼' => 'Obinrin Ti Njo: amɔ́lára díɛ̀',
    '💃🏽' => 'Obinrin Ti Njo: amɔ́láwɔ̀ díɛ̀',
    '💃🏾' => 'Obinrin Ti Njo: adúláwɔ̀ díɛ̀',
    '💃🏿' => 'Obinrin Ti Njo: adúláwɔ̀',
    '🕺🏻' => 'Ɔkunrin Ti Njo: amɔ́lára',
    '🕺🏼' => 'Ɔkunrin Ti Njo: amɔ́lára díɛ̀',
    '🕺🏽' => 'Ɔkunrin Ti Njo: amɔ́láwɔ̀ díɛ̀',
    '🕺🏾' => 'Ɔkunrin Ti Njo: adúláwɔ̀ díɛ̀',
    '🕺🏿' => 'Ɔkunrin Ti Njo: adúláwɔ̀',
    '🕴🏻' => 'ɔkùnrin nínu kóòtú òwò: amɔ́lára',
    '🕴🏼' => 'ɔkùnrin nínu kóòtú òwò: amɔ́lára díɛ̀',
    '🕴🏽' => 'ɔkùnrin nínu kóòtú òwò: amɔ́láwɔ̀ díɛ̀',
    '🕴🏾' => 'ɔkùnrin nínu kóòtú òwò: adúláwɔ̀ díɛ̀',
    '🕴🏿' => 'ɔkùnrin nínu kóòtú òwò: adúláwɔ̀',
    '👯🏻' => 'awɔn eniyan eleti ehoro: amɔ́lára',
    '👯🏼' => 'awɔn eniyan eleti ehoro: amɔ́lára díɛ̀',
    '👯🏽' => 'awɔn eniyan eleti ehoro: amɔ́láwɔ̀ díɛ̀',
    '👯🏾' => 'awɔn eniyan eleti ehoro: adúláwɔ̀ díɛ̀',
    '👯🏿' => 'awɔn eniyan eleti ehoro: adúláwɔ̀',
    '🧖🏻' => 'Ènìyàn nínú Ìyàrá tó n gbóná: amɔ́lára',
    '🧖🏼' => 'Ènìyàn nínú Ìyàrá tó n gbóná: amɔ́lára díɛ̀',
    '🧖🏽' => 'Ènìyàn nínú Ìyàrá tó n gbóná: amɔ́láwɔ̀ díɛ̀',
    '🧖🏾' => 'Ènìyàn nínú Ìyàrá tó n gbóná: adúláwɔ̀ díɛ̀',
    '🧖🏿' => 'Ènìyàn nínú Ìyàrá tó n gbóná: adúláwɔ̀',
    '🧗🏻' => 'Ènìyàn tó n gòkè: amɔ́lára',
    '🧗🏼' => 'Ènìyàn tó n gòkè: amɔ́lára díɛ̀',
    '🧗🏽' => 'Ènìyàn tó n gòkè: amɔ́láwɔ̀ díɛ̀',
    '🧗🏾' => 'Ènìyàn tó n gòkè: adúláwɔ̀ díɛ̀',
    '🧗🏿' => 'Ènìyàn tó n gòkè: adúláwɔ̀',
    '🏇🏻' => 'Ereje Ɛlɛsin: amɔ́lára',
    '🏇🏼' => 'Ereje Ɛlɛsin: amɔ́lára díɛ̀',
    '🏇🏽' => 'Ereje Ɛlɛsin: amɔ́láwɔ̀ díɛ̀',
    '🏇🏾' => 'Ereje Ɛlɛsin: adúláwɔ̀ díɛ̀',
    '🏇🏿' => 'Ereje Ɛlɛsin: adúláwɔ̀',
    '🏂🏻' => 'Ishere Ori Yiyin: amɔ́lára',
    '🏂🏼' => 'Ishere Ori Yiyin: amɔ́lára díɛ̀',
    '🏂🏽' => 'Ishere Ori Yiyin: amɔ́láwɔ̀ díɛ̀',
    '🏂🏾' => 'Ishere Ori Yiyin: adúláwɔ̀ díɛ̀',
    '🏂🏿' => 'Ishere Ori Yiyin: adúláwɔ̀',
    '🏌🏻' => 'ɛni gɔ́ɔ̀fù: amɔ́lára',
    '🏌🏼' => 'ɛni gɔ́ɔ̀fù: amɔ́lára díɛ̀',
    '🏌🏽' => 'ɛni gɔ́ɔ̀fù: amɔ́láwɔ̀ díɛ̀',
    '🏌🏾' => 'ɛni gɔ́ɔ̀fù: adúláwɔ̀ díɛ̀',
    '🏌🏿' => 'ɛni gɔ́ɔ̀fù: adúláwɔ̀',
    '🏄🏻' => 'Ɛni N Gun Iji: amɔ́lára',
    '🏄🏼' => 'Ɛni N Gun Iji: amɔ́lára díɛ̀',
    '🏄🏽' => 'Ɛni N Gun Iji: amɔ́láwɔ̀ díɛ̀',
    '🏄🏾' => 'Ɛni N Gun Iji: adúláwɔ̀ díɛ̀',
    '🏄🏿' => 'Ɛni N Gun Iji: adúláwɔ̀',
    '🚣🏻' => 'Ɛni N wa Ɔkɔ: amɔ́lára',
    '🚣🏼' => 'Ɛni N wa Ɔkɔ: amɔ́lára díɛ̀',
    '🚣🏽' => 'Ɛni N wa Ɔkɔ: amɔ́láwɔ̀ díɛ̀',
    '🚣🏾' => 'Ɛni N wa Ɔkɔ: adúláwɔ̀ díɛ̀',
    '🚣🏿' => 'Ɛni N wa Ɔkɔ: adúláwɔ̀',
    '🏊🏻' => 'Ɛni tí ń wɛdò: amɔ́lára',
    '🏊🏼' => 'Ɛni tí ń wɛdò: amɔ́lára díɛ̀',
    '🏊🏽' => 'Ɛni tí ń wɛdò: amɔ́láwɔ̀ díɛ̀',
    '🏊🏾' => 'Ɛni tí ń wɛdò: adúláwɔ̀ díɛ̀',
    '🏊🏿' => 'Ɛni tí ń wɛdò: adúláwɔ̀',
    '⛹🏻' => 'ɛni tà boun bɔ́ɔ̀lù: amɔ́lára',
    '⛹🏼' => 'ɛni tà boun bɔ́ɔ̀lù: amɔ́lára díɛ̀',
    '⛹🏽' => 'ɛni tà boun bɔ́ɔ̀lù: amɔ́láwɔ̀ díɛ̀',
    '⛹🏾' => 'ɛni tà boun bɔ́ɔ̀lù: adúláwɔ̀ díɛ̀',
    '⛹🏿' => 'ɛni tà boun bɔ́ɔ̀lù: adúláwɔ̀',
    '🏋🏻' => 'ɛni fa ìwɔ̀n sókè: amɔ́lára',
    '🏋🏼' => 'ɛni fa ìwɔ̀n sókè: amɔ́lára díɛ̀',
    '🏋🏽' => 'ɛni fa ìwɔ̀n sókè: amɔ́láwɔ̀ díɛ̀',
    '🏋🏾' => 'ɛni fa ìwɔ̀n sókè: adúláwɔ̀ díɛ̀',
    '🏋🏿' => 'ɛni fa ìwɔ̀n sókè: adúláwɔ̀',
    '🚴🏻' => 'Ɛni N Gun Kɛkɛ: amɔ́lára',
    '🚴🏼' => 'Ɛni N Gun Kɛkɛ: amɔ́lára díɛ̀',
    '🚴🏽' => 'Ɛni N Gun Kɛkɛ: amɔ́láwɔ̀ díɛ̀',
    '🚴🏾' => 'Ɛni N Gun Kɛkɛ: adúláwɔ̀ díɛ̀',
    '🚴🏿' => 'Ɛni N Gun Kɛkɛ: adúláwɔ̀',
    '🚵🏻' => 'Ɛni N Gun Kɛkɛ Gun Apata: amɔ́lára',
    '🚵🏼' => 'Ɛni N Gun Kɛkɛ Gun Apata: amɔ́lára díɛ̀',
    '🚵🏽' => 'Ɛni N Gun Kɛkɛ Gun Apata: amɔ́láwɔ̀ díɛ̀',
    '🚵🏾' => 'Ɛni N Gun Kɛkɛ Gun Apata: adúláwɔ̀ díɛ̀',
    '🚵🏿' => 'Ɛni N Gun Kɛkɛ Gun Apata: adúláwɔ̀',
    '🤸🏻' => 'Ɛni Kawɔ Tilɛ Kɛsɛ Soke: amɔ́lára',
    '🤸🏼' => 'Ɛni Kawɔ Tilɛ Kɛsɛ Soke: amɔ́lára díɛ̀',
    '🤸🏽' => 'Ɛni Kawɔ Tilɛ Kɛsɛ Soke: amɔ́láwɔ̀ díɛ̀',
    '🤸🏾' => 'Ɛni Kawɔ Tilɛ Kɛsɛ Soke: adúláwɔ̀ díɛ̀',
    '🤸🏿' => 'Ɛni Kawɔ Tilɛ Kɛsɛ Soke: adúláwɔ̀',
    '🤼🏻' => 'Awɔn Onigidigbo: amɔ́lára',
    '🤼🏼' => 'Awɔn Onigidigbo: amɔ́lára díɛ̀',
    '🤼🏽' => 'Awɔn Onigidigbo: amɔ́láwɔ̀ díɛ̀',
    '🤼🏾' => 'Awɔn Onigidigbo: adúláwɔ̀ díɛ̀',
    '🤼🏿' => 'Awɔn Onigidigbo: adúláwɔ̀',
    '🤽🏻' => 'Ɛni N shere Olomi: amɔ́lára',
    '🤽🏼' => 'Ɛni N shere Olomi: amɔ́lára díɛ̀',
    '🤽🏽' => 'Ɛni N shere Olomi: amɔ́láwɔ̀ díɛ̀',
    '🤽🏾' => 'Ɛni N shere Olomi: adúláwɔ̀ díɛ̀',
    '🤽🏿' => 'Ɛni N shere Olomi: adúláwɔ̀',
    '🤾🏻' => 'Ɛni N Shere Bɔɔlu Ɔlɔwɔ: amɔ́lára',
    '🤾🏼' => 'Ɛni N Shere Bɔɔlu Ɔlɔwɔ: amɔ́lára díɛ̀',
    '🤾🏽' => 'Ɛni N Shere Bɔɔlu Ɔlɔwɔ: amɔ́láwɔ̀ díɛ̀',
    '🤾🏾' => 'Ɛni N Shere Bɔɔlu Ɔlɔwɔ: adúláwɔ̀ díɛ̀',
    '🤾🏿' => 'Ɛni N Shere Bɔɔlu Ɔlɔwɔ: adúláwɔ̀',
    '🤹🏻' => 'Ɛni N ju Nnkan soke: amɔ́lára',
    '🤹🏼' => 'Ɛni N ju Nnkan soke: amɔ́lára díɛ̀',
    '🤹🏽' => 'Ɛni N ju Nnkan soke: amɔ́láwɔ̀ díɛ̀',
    '🤹🏾' => 'Ɛni N ju Nnkan soke: adúláwɔ̀ díɛ̀',
    '🤹🏿' => 'Ɛni N ju Nnkan soke: adúláwɔ̀',
    '🧘🏻' => 'Ènìyàn nípò ìgbàgbé: amɔ́lára',
    '🧘🏼' => 'Ènìyàn nípò ìgbàgbé: amɔ́lára díɛ̀',
    '🧘🏽' => 'Ènìyàn nípò ìgbàgbé: amɔ́láwɔ̀ díɛ̀',
    '🧘🏾' => 'Ènìyàn nípò ìgbàgbé: adúláwɔ̀ díɛ̀',
    '🧘🏿' => 'Ènìyàn nípò ìgbàgbé: adúláwɔ̀',
    '🛀🏻' => 'Ɛni Nwɛ: amɔ́lára',
    '🛀🏼' => 'Ɛni Nwɛ: amɔ́lára díɛ̀',
    '🛀🏽' => 'Ɛni Nwɛ: amɔ́láwɔ̀ díɛ̀',
    '🛀🏾' => 'Ɛni Nwɛ: adúláwɔ̀ díɛ̀',
    '🛀🏿' => 'Ɛni Nwɛ: adúláwɔ̀',
    '🛌🏻' => 'Ɛniyan Nibusun: amɔ́lára',
    '🛌🏼' => 'Ɛniyan Nibusun: amɔ́lára díɛ̀',
    '🛌🏽' => 'Ɛniyan Nibusun: amɔ́láwɔ̀ díɛ̀',
    '🛌🏾' => 'Ɛniyan Nibusun: adúláwɔ̀ díɛ̀',
    '🛌🏿' => 'Ɛniyan Nibusun: adúláwɔ̀',
    '👭🏻' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára',
    '👭🏼' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀',
    '👭🏽' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀',
    '👭🏾' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀',
    '👭🏿' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀',
    '👫🏻' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára',
    '👫🏼' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀',
    '👫🏽' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀',
    '👫🏾' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀',
    '👫🏿' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀',
    '👬🏻' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára',
    '👬🏼' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́lára díɛ̀',
    '👬🏽' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: amɔ́láwɔ̀ díɛ̀',
    '👬🏾' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀ díɛ̀',
    '👬🏿' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu: adúláwɔ̀',
    '💏🏻' => 'Ifɛnuko: amɔ́lára',
    '💏🏼' => 'Ifɛnuko: amɔ́lára díɛ̀',
    '💏🏽' => 'Ifɛnuko: amɔ́láwɔ̀ díɛ̀',
    '💏🏾' => 'Ifɛnuko: adúláwɔ̀ díɛ̀',
    '💏🏿' => 'Ifɛnuko: adúláwɔ̀',
    '💑🏻' => 'Lɔkɔlaya Pɛlu ɔkan: amɔ́lára',
    '💑🏼' => 'Lɔkɔlaya Pɛlu ɔkan: amɔ́lára díɛ̀',
    '💑🏽' => 'Lɔkɔlaya Pɛlu ɔkan: amɔ́láwɔ̀ díɛ̀',
    '💑🏾' => 'Lɔkɔlaya Pɛlu ɔkan: adúláwɔ̀ díɛ̀',
    '💑🏿' => 'Lɔkɔlaya Pɛlu ɔkan: adúláwɔ̀',
    '🇦🇨' => 'filaagi: Erékùsù Ascension',
    '🇦🇩' => 'filaagi: Ààndórà',
    '🇦🇪' => 'filaagi: Ɛmirate ti Awɔn Arabu',
    '🇦🇫' => 'filaagi: Àfùgànístánì',
    '🇦🇬' => 'filaagi: Ààntígúà àti Báríbúdà',
    '🇦🇮' => 'filaagi: Ààngúlílà',
    '🇦🇱' => 'filaagi: Àlùbàníánì',
    '🇦🇲' => 'filaagi: Améníà',
    '🇦🇴' => 'filaagi: Ààngólà',
    '🇦🇶' => 'filaagi: Antakítíkà',
    '🇦🇷' => 'filaagi: Agentínà',
    '🇦🇸' => 'filaagi: Sámóánì ti Orílɛ́ède Àméríkà',
    '🇦🇹' => 'filaagi: Asítíríà',
    '🇦🇺' => 'filaagi: Austrálíà',
    '🇦🇼' => 'filaagi: Árúbà',
    '🇦🇽' => 'filaagi: Àwɔn Erékùsù ti Aland',
    '🇦🇿' => 'filaagi: Asɛ́bájánì',
    '🇧🇦' => 'filaagi: Bɔ̀síníà àti Ɛtisɛgófínà',
    '🇧🇧' => 'filaagi: Bábádósì',
    '🇧🇩' => 'filaagi: Bángáládésì',
    '🇧🇪' => 'filaagi: Bégíɔ́mù',
    '🇧🇫' => 'filaagi: Bùùkíná Fasò',
    '🇧🇬' => 'filaagi: Bùùgáríà',
    '🇧🇭' => 'filaagi: Báránì',
    '🇧🇮' => 'filaagi: Bùùrúndì',
    '🇧🇯' => 'filaagi: Bɛ̀nɛ̀',
    '🇧🇱' => 'filaagi: Ìlú Bátílɛ́mì',
    '🇧🇲' => 'filaagi: Bémúdà',
    '🇧🇳' => 'filaagi: Búrúnɛ́lì',
    '🇧🇴' => 'filaagi: Bɔ̀lífíyà',
    '🇧🇶' => 'filaagi: Kàríbíánì ti Nɛ́dálándì',
    '🇧🇷' => 'filaagi: Bàràsílì',
    '🇧🇸' => 'filaagi: Bàhámásì',
    '🇧🇹' => 'filaagi: Bútánì',
    '🇧🇻' => 'filaagi: Erékùsù Bouvet',
    '🇧🇼' => 'filaagi: Bɔ̀tìsúwánà',
    '🇧🇾' => 'filaagi: Bélárúsì',
    '🇧🇿' => 'filaagi: Bèlísɛ̀',
    '🇨🇦' => 'filaagi: Kánádà',
    '🇨🇨' => 'filaagi: Erékùsù Cocos (Keeling)',
    '🇨🇩' => 'filaagi: Kóńgò – Kinshasa',
    '🇨🇫' => 'filaagi: Àrin gùngun Áfíríkà',
    '🇨🇬' => 'filaagi: Kóńgò – Brazaville',
    '🇨🇭' => 'filaagi: Súwísìlanìdì',
    '🇨🇮' => 'filaagi: Kóútè forà',
    '🇨🇰' => 'filaagi: Etíokun Kùúkù',
    '🇨🇱' => 'filaagi: Shílè',
    '🇨🇲' => 'filaagi: Kamerúúnì',
    '🇨🇳' => 'filaagi: Sháínà',
    '🇨🇴' => 'filaagi: Kòlómíbìa',
    '🇨🇵' => 'filaagi: Erékùsù Clipperston',
    '🇨🇶' => 'filaagi: Sáàkì',
    '🇨🇷' => 'filaagi: Kuusita Ríkà',
    '🇨🇺' => 'filaagi: Kúbà',
    '🇨🇻' => 'filaagi: Etíokun Kápé féndè',
    '🇨🇼' => 'filaagi: Curaçao',
    '🇨🇽' => 'filaagi: Erékùsù Christmas',
    '🇨🇾' => 'filaagi: Kúrúsì',
    '🇨🇿' => 'filaagi: Shɛ́ɛ́kì',
    '🇩🇪' => 'filaagi: Jámánì',
    '🇩🇬' => 'filaagi: Diego Gashia',
    '🇩🇯' => 'filaagi: Díbɔ́ótì',
    '🇩🇰' => 'filaagi: Dɛ́mákì',
    '🇩🇲' => 'filaagi: Dòmíníkà',
    '🇩🇴' => 'filaagi: Dòmíníkánì',
    '🇩🇿' => 'filaagi: Àlùgèríánì',
    '🇪🇦' => 'filaagi: Seuta àti Melilla',
    '🇪🇨' => 'filaagi: Ekuádò',
    '🇪🇪' => 'filaagi: Esitonia',
    '🇪🇬' => 'filaagi: Égípítì',
    '🇪🇭' => 'filaagi: Ìwɔ̀òòrùn Sàhárà',
    '🇪🇷' => 'filaagi: Eritira',
    '🇪🇸' => 'filaagi: Sípéìnì',
    '🇪🇹' => 'filaagi: Etopia',
    '🇪🇺' => 'filaagi: Àpapɔ̀ Yúróòpù',
    '🇫🇮' => 'filaagi: Filandi',
    '🇫🇯' => 'filaagi: Fíjì',
    '🇫🇰' => 'filaagi: Etikun Fakalandi',
    '🇫🇲' => 'filaagi: Makoronesia',
    '🇫🇴' => 'filaagi: Àwɔn Erékùsù ti Faroe',
    '🇫🇷' => 'filaagi: Faranse',
    '🇬🇦' => 'filaagi: Gabon',
    '🇬🇧' => 'filaagi: Gɛ̀ɛ́sì',
    '🇬🇩' => 'filaagi: Genada',
    '🇬🇪' => 'filaagi: Gɔgia',
    '🇬🇫' => 'filaagi: Firenshi Guana',
    '🇬🇬' => 'filaagi: Guernsey',
    '🇬🇭' => 'filaagi: Gana',
    '🇬🇮' => 'filaagi: Gibaratara',
    '🇬🇱' => 'filaagi: Gerelandi',
    '🇬🇲' => 'filaagi: Gambia',
    '🇬🇳' => 'filaagi: Gene',
    '🇬🇵' => 'filaagi: Gadelope',
    '🇬🇶' => 'filaagi: Ekutoria Gini',
    '🇬🇷' => 'filaagi: Gíríìsì',
    '🇬🇸' => 'filaagi: Gúúsù Georgia àti Gúúsù Àwɔn Erékùsù Sandwich',
    '🇬🇹' => 'filaagi: Guatemálà',
    '🇬🇺' => 'filaagi: Guamu',
    '🇬🇼' => 'filaagi: Gene-Busau',
    '🇬🇾' => 'filaagi: Guyana',
    '🇭🇰' => 'filaagi: Agbègbè Ìshàkóso Ìshúná Hong Kong Tí Shánà Ń Darí',
    '🇭🇲' => 'filaagi: Erékùsù Heard àti Erékùsù McDonald',
    '🇭🇳' => 'filaagi: Hondurasi',
    '🇭🇷' => 'filaagi: Kòróátíà',
    '🇭🇹' => 'filaagi: Haati',
    '🇭🇺' => 'filaagi: Hungari',
    '🇮🇨' => 'filaagi: Ɛrékùsù Kánárì',
    '🇮🇩' => 'filaagi: Indonéshíà',
    '🇮🇪' => 'filaagi: Ailandi',
    '🇮🇱' => 'filaagi: Iserɛli',
    '🇮🇲' => 'filaagi: Erékùshù ilɛ̀ Man',
    '🇮🇳' => 'filaagi: Íńdíà',
    '🇮🇴' => 'filaagi: Etíkun Índíánì ti Ìlú Bírítísì',
    '🇮🇶' => 'filaagi: Iraki',
    '🇮🇷' => 'filaagi: Irani',
    '🇮🇸' => 'filaagi: Ashilandi',
    '🇮🇹' => 'filaagi: Itáli',
    '🇯🇪' => 'filaagi: Jɛsì',
    '🇯🇲' => 'filaagi: Jamaika',
    '🇯🇴' => 'filaagi: Jɔdani',
    '🇯🇵' => 'filaagi: Japani',
    '🇰🇪' => 'filaagi: Kenya',
    '🇰🇬' => 'filaagi: Kurishisitani',
    '🇰🇭' => 'filaagi: Kàmùbódíà',
    '🇰🇮' => 'filaagi: Kiribati',
    '🇰🇲' => 'filaagi: Kòmòrósì',
    '🇰🇳' => 'filaagi: Kiiti ati Neefi',
    '🇰🇵' => 'filaagi: Guusu Kɔria',
    '🇰🇷' => 'filaagi: Ariwa Kɔria',
    '🇰🇼' => 'filaagi: Kuweti',
    '🇰🇾' => 'filaagi: Etíokun Kámánì',
    '🇰🇿' => 'filaagi: Kashashatani',
    '🇱🇦' => 'filaagi: Laosi',
    '🇱🇧' => 'filaagi: Lebanoni',
    '🇱🇨' => 'filaagi: Lushia',
    '🇱🇮' => 'filaagi: Lɛshitɛnisiteni',
    '🇱🇰' => 'filaagi: Siri Lanka',
    '🇱🇷' => 'filaagi: Laberia',
    '🇱🇸' => 'filaagi: Lesoto',
    '🇱🇹' => 'filaagi: Lituania',
    '🇱🇺' => 'filaagi: Lusemogi',
    '🇱🇻' => 'filaagi: Latifia',
    '🇱🇾' => 'filaagi: Libiya',
    '🇲🇦' => 'filaagi: Moroko',
    '🇲🇨' => 'filaagi: Monako',
    '🇲🇩' => 'filaagi: Modofia',
    '🇲🇪' => 'filaagi: Montenégrò',
    '🇲🇫' => 'filaagi: Ìlú Màtìnì',
    '🇲🇬' => 'filaagi: Madasika',
    '🇲🇭' => 'filaagi: Etikun Máshali',
    '🇲🇰' => 'filaagi: Àríwá Macedonia',
    '🇲🇱' => 'filaagi: Mali',
    '🇲🇲' => 'filaagi: Manamari',
    '🇲🇳' => 'filaagi: Mogolia',
    '🇲🇴' => 'filaagi: Agbègbè Ìshàkóso Pàtàkì Macao',
    '🇲🇵' => 'filaagi: Etikun Guusu Mariana',
    '🇲🇶' => 'filaagi: Matinikuwi',
    '🇲🇷' => 'filaagi: Maritania',
    '🇲🇸' => 'filaagi: Motserati',
    '🇲🇹' => 'filaagi: Malata',
    '🇲🇺' => 'filaagi: Maritiusi',
    '🇲🇻' => 'filaagi: Maladifi',
    '🇲🇼' => 'filaagi: Malawi',
    '🇲🇽' => 'filaagi: Mesiko',
    '🇲🇾' => 'filaagi: Malasia',
    '🇲🇿' => 'filaagi: Moshamibiku',
    '🇳🇦' => 'filaagi: Namibia',
    '🇳🇨' => 'filaagi: Kaledonia Titun',
    '🇳🇪' => 'filaagi: Nàìjá',
    '🇳🇫' => 'filaagi: Erékùsù Nɔ́úfókì',
    '🇳🇬' => 'filaagi: Nàìjíríà',
    '🇳🇮' => 'filaagi: Nikaragua',
    '🇳🇱' => 'filaagi: Nedalandi',
    '🇳🇴' => 'filaagi: Nɔɔwii',
    '🇳🇵' => 'filaagi: Nepa',
    '🇳🇷' => 'filaagi: Nauru',
    '🇳🇺' => 'filaagi: Niue',
    '🇳🇿' => 'filaagi: Shilandi Titun',
    '🇴🇲' => 'filaagi: Ɔɔma',
    '🇵🇦' => 'filaagi: Paramá',
    '🇵🇪' => 'filaagi: Pèérù',
    '🇵🇫' => 'filaagi: Firenshi Polinesia',
    '🇵🇬' => 'filaagi: Paapu ti Giini',
    '🇵🇭' => 'filaagi: Filipini',
    '🇵🇰' => 'filaagi: Pakisitan',
    '🇵🇱' => 'filaagi: Polandi',
    '🇵🇲' => 'filaagi: Pɛɛri ati mikuloni',
    '🇵🇳' => 'filaagi: Pikarini',
    '🇵🇷' => 'filaagi: Pɔto Riko',
    '🇵🇸' => 'filaagi: Agbègbè ara Palɛsítínì',
    '🇵🇹' => 'filaagi: Pɔ́túgà',
    '🇵🇼' => 'filaagi: Paalu',
    '🇵🇾' => 'filaagi: Paraguye',
    '🇶🇦' => 'filaagi: Kota',
    '🇷🇪' => 'filaagi: Riuniyan',
    '🇷🇴' => 'filaagi: Romaniya',
    '🇷🇸' => 'filaagi: Sɛ́bíà',
    '🇷🇺' => 'filaagi: Rɔshia',
    '🇷🇼' => 'filaagi: Ruwanda',
    '🇸🇦' => 'filaagi: Saudi Arabia',
    '🇸🇧' => 'filaagi: Etikun Solomoni',
    '🇸🇨' => 'filaagi: Sheshɛlɛsi',
    '🇸🇩' => 'filaagi: Sudani',
    '🇸🇪' => 'filaagi: Swidini',
    '🇸🇬' => 'filaagi: Singapo',
    '🇸🇭' => 'filaagi: Hɛlena',
    '🇸🇮' => 'filaagi: Silofania',
    '🇸🇯' => 'filaagi: Sífábáàdì àti Jánì Máyɛ̀nì',
    '🇸🇰' => 'filaagi: Silofakia',
    '🇸🇱' => 'filaagi: Siria looni',
    '🇸🇲' => 'filaagi: Sani Marino',
    '🇸🇳' => 'filaagi: Sɛnɛga',
    '🇸🇴' => 'filaagi: Sòmálíà',
    '🇸🇷' => 'filaagi: Surinami',
    '🇸🇸' => 'filaagi: Gúúsù Sudan',
    '🇸🇹' => 'filaagi: Sao tomi ati piriishipi',
    '🇸🇻' => 'filaagi: Ɛɛsáfádò',
    '🇸🇽' => 'filaagi: Síntì Mátɛ́ɛ̀nì',
    '🇸🇾' => 'filaagi: Siria',
    '🇸🇿' => 'filaagi: Sashiland',
    '🇹🇦' => 'filaagi: Tristan da Kunha',
    '🇹🇨' => 'filaagi: Tɔɔki ati Etikun Kakɔsi',
    '🇹🇩' => 'filaagi: Shààdì',
    '🇹🇫' => 'filaagi: Agbègbè Gúúsù Faranshé',
    '🇹🇬' => 'filaagi: Togo',
    '🇹🇭' => 'filaagi: Tailandi',
    '🇹🇯' => 'filaagi: Takisitani',
    '🇹🇰' => 'filaagi: Tokelau',
    '🇹🇱' => 'filaagi: Tímɔ̀ Lɛsiti',
    '🇹🇲' => 'filaagi: Tɔ́kìmɛ́nísítànì',
    '🇹🇳' => 'filaagi: Tunishia',
    '🇹🇴' => 'filaagi: Tonga',
    '🇹🇷' => 'filaagi: Tɔɔki',
    '🇹🇹' => 'filaagi: Tirinida ati Tobaga',
    '🇹🇻' => 'filaagi: Tufalu',
    '🇹🇼' => 'filaagi: Taiwani',
    '🇹🇿' => 'filaagi: Tàǹsáníà',
    '🇺🇦' => 'filaagi: Ukarini',
    '🇺🇬' => 'filaagi: Uganda',
    '🇺🇲' => 'filaagi: Àwɔn Erékùsù Kékèké Agbègbè US',
    '🇺🇳' => 'filaagi: Ìshɔ̀kan àgbáyé',
    '🇺🇸' => 'filaagi: Amɛrikà',
    '🇺🇾' => 'filaagi: Úrúgúwè',
    '🇺🇿' => 'filaagi: Nshibɛkisitani',
    '🇻🇦' => 'filaagi: Ìlú Vatican',
    '🇻🇨' => 'filaagi: Fisɛnnti ati Genadina',
    '🇻🇪' => 'filaagi: Fɛnɛshuɛla',
    '🇻🇬' => 'filaagi: Etíkun Fágínì ti ìlú Bírítísì',
    '🇻🇮' => 'filaagi: Etikun Fagini ti Amɛrika',
    '🇻🇳' => 'filaagi: Fɛtinami',
    '🇻🇺' => 'filaagi: Faniatu',
    '🇼🇫' => 'filaagi: Wali ati futuna',
    '🇼🇸' => 'filaagi: Samɔ',
    '🇽🇰' => 'filaagi: Kòsófò',
    '🇾🇪' => 'filaagi: Yemeni',
    '🇾🇹' => 'filaagi: Mayote',
    '🇿🇦' => 'filaagi: Gúúshù Áfíríkà',
    '🇿🇲' => 'filaagi: Shamibia',
    '🇿🇼' => 'filaagi: Shimibabe',
    '🔟' => 'Keyacap: 10',
    '🏻' => 'amɔ́lára',
    '🏼' => 'amɔ́lára díɛ̀',
    '🏽' => 'amɔ́láwɔ̀ díɛ̀',
    '🏾' => 'adúláwɔ̀ díɛ̀',
    '🏿' => 'adúláwɔ̀',
    '😀' => 'Ojú tó rɛ́rìn',
    '😃' => 'Ojú tó rɛ́rìn Pɛ̀lú Ɛnu Lílà sílɛ̀',
    '😄' => 'ojú tó ń rɛ́rìń músɛ́ pɛ̀lú ɛnu lílà sílɛ̀ àti ɛyinjú tó ń rkrìń músɛ́',
    '😁' => 'Ojú tó fɛyín pɛ̀lú Ɛyinjú tó rɛ́rìn músɛ́',
    '😆' => 'ojú tó ń rɛ́rìń músɛ́ pɛ̀lú ɛnu lílà sílɛ̀ àti òógùn tútù',
    '😅' => 'ojú tó ń rɛ́rìń pɛ̀lú ɛnu lílà sílɛ̀ àti òógùn',
    '🤣' => 'Yíyí ní ilɛ̀nlɛ̀ tún rɛ́rìn',
    '😂' => 'Ojú pɛ̀lú ɛkún ayɔ̀',
    '🙂' => 'Oju Ti O N Rɛrin Mushɛn',
    '🙃' => 'Oju Ti O Rɔ walɛ',
    '🫠' => 'Oju Ti O tɛ̀',
    '😉' => 'Ojú tó shɛ́jù',
    '😊' => 'Ojú tó rɛ́rìn Músɛ́ Pɛ̀lú Ɛyinjú tó rɛ́rìn Músɛ́',
    '😇' => 'Oju Ɛrin Ati Bawo',
    '🥰' => 'ojú erin pelu okan',
    '😍' => 'Oju Ti O N Rɛrin Pɛlu awɔn oju Ɔkan',
    '🤩' => 'Pípa pè̩lú ìràwɔ̀',
    '😘' => 'Oju Ti O N Fɛ Ifɛnuko',
    '😗' => 'Ojú tó Fɛnuko ɛnu',
    '☺' => 'ojú tó ń rɛ́rìń músɛ́',
    '😚' => 'Oju Ti O N Fɛnuko Pɛlu Awɔn Oju didi',
    '😙' => 'Ojú tó Fɛnuko ɛnu Pɛ̀lú Ɛyinjú tɔ rɛ́rìn Músɛ́',
    '🥲' => 'ojú ɛ̀rín pɛ̀lú ɛkún',
    '😋' => 'Oju Ti O N jɛ Ounjɛ Aladidun',
    '😛' => 'Oju Ti Ahɔn Ti O Yɔ Sita',
    '😜' => 'ojú pɛ̀lú ahɔ́n lílà sílɛ̀ àti ɛyinjú tí ń shɛ́jú',
    '🤪' => 'Ojú ashiwèrè',
    '😝' => 'ojú pɛ̀lú ahɔ́n lílà sílɛ̀ àti ɛyinjú tó padé',
    '🤑' => 'Oju Ɛnu owo',
    '🤗' => 'oju Ti O fanimɔra',
    '🤭' => 'Ojú tá fɔwɔ́ bo ɛnu',
    '🫢' => 'ojú sísí lɛ̀ àti owo lori enu',
    '🫣' => 'ojú pɛ̀lú títɔpinpin',
    '🤫' => 'Ojú tó sùpò̩',
    '🤔' => 'Ojú tó Ronú',
    '🫡' => 'ojú bíbɔ̀wɔ́',
    '🤐' => 'Oju Ɛni Ti A Tipa',
    '🤨' => 'Ìrun ojú ta gbé sókè',
    '😐' => 'Ojú Ìbíìbí',
    '😑' => 'Oju Ti Ko Fanimɔra',
    '😶' => 'Ojú tí kò ní Ɛnu',
    '🫥' => 'ojú ìlà tótótó',
    '😏' => 'Oju Ɛrin Abosi',
    '😒' => 'Oju Aifanimɔra',
    '🙄' => 'Ojú Pɛ̀lú Ɛyinjú tó yín',
    '😬' => 'Oju Ifaro',
    '🤥' => 'Oju Irɔ',
    '🫨' => 'ojú gbígbɔ̀n',
    '😌' => 'Oju Itura',
    '😔' => 'Oju Ironu',
    '😪' => 'Oju Iloorun',
    '🤤' => 'oju adatɔ',
    '😴' => 'Oju Ti O N Sun',
    '🫩' => 'ojú pɛ̀lú ìsàlɛ̀ ojú tó wú',
    '😷' => 'Oju Pɛlu Iboju Ishoogun',
    '🤒' => 'oju pɛlu oshuwɔn igbona',
    '🤕' => 'Oju Pɛlu Ori ti a de Lɔja',
    '🤢' => 'Oju Ailera',
    '🤮' => 'Èébì ajɛmɔ́jú',
    '🤧' => 'Oju Sinsin',
    '🥵' => 'ojú gbígbóná',
    '🥶' => 'ojú tútú',
    '🥴' => 'ojú to wópɔ̀',
    '😵' => 'Oju Itoogbe',
    '🤯' => 'Orí tó bú gbàmù',
    '🤠' => 'Oju Fila Adaran',
    '🥳' => 'ojú patí',
    '🥸' => 'ojú ìsápamɔ́',
    '😎' => 'Oju Ti O N Rɛrin Pɛlu Digi Oju',
    '🤓' => 'Oju Ɔmɔwe Ti O Jafafa',
    '🧐' => 'Ojú tó súnkì',
    '😕' => 'Oju Iporuru',
    '🫤' => 'ojú pɛ̀lú ɛnu ɛ̀gbɛ́',
    '😟' => 'Oju Idamu',
    '🙁' => 'Oju Ifajuro Diɛ',
    '☹' => 'ojú tó fajúro',
    '😮' => 'Oju Pɛlu Ɛnu Lila',
    '😯' => 'Oju Idakɛjɛ',
    '😲' => 'ojú ìyalɛnu',
    '😳' => 'Oju Idunnu',
    '🫪' => 'ojú tó ti dìdàkudà',
    '🥺' => 'ojú tónbɛ̀bɛ̀',
    '🥹' => 'ojú tón mu ɛkún dúró',
    '😦' => 'Oju Ti o Faro Pɛlu Ɛnu lila silɛ',
    '😧' => 'ojú ìrora',
    '😨' => 'Oju Ɛru',
    '😰' => 'ojú pɛ̀lú ɛnu lílà sílɛ̀ àti òógùn tútù',
    '😥' => 'Oju Ijakulɛ Shugbɔn Itura',
    '😢' => 'Oju Ɛkun',
    '😭' => 'Oju Ti n Sunkun Gidi',
    '😱' => 'Oju Fifi Ɛru han an',
    '😖' => 'Oju Itiju',
    '😣' => 'Oju Ifarada',
    '😞' => 'ojú ìjakulɛ̀',
    '😓' => 'Oju Pɛlu Ilaagun Tutu',
    '😩' => 'Oju Ti o Rɛ̀',
    '😫' => 'Oju Rirɛ',
    '🥱' => 'ojú tón yán',
    '😤' => 'Oju Pɛlu Ooru Nimu',
    '😡' => 'Oju Iyaahan',
    '😠' => 'Oju Ibinu',
    '🤬' => 'Àmì ojú tó rékɔjá ɛnu',
    '😈' => 'Oju Ɛrin Pɛlu Awɔn Iwo',
    '👿' => 'Oju Ibinu Pɛlu Awɔn Iwo',
    '💀' => 'Ipakɔ',
    '☠' => 'ìpàkɔ́ àti àwɔn egun àgbélébù',
    '💩' => 'Okiti Igbɛ',
    '🤡' => 'ojú apanilɛrin',
    '👹' => 'Omiran Ajɛniyan',
    '👺' => 'abàmì aràrá',
    '👻' => 'òkú',
    '👽' => 'àjòjì',
    '👾' => 'Àjòjì Abami',
    '🤖' => 'Oju Shigidi',
    '😺' => 'Oju Arɛrin Ologbo Pɛlu Ɛnu Yiya',
    '😸' => 'Oju Ibinu Ologbo Pɛlu Awɔn Oju Arɛrin',
    '😹' => 'Oju Ologbo Pɛlu Ɛkun Ayɔ',
    '😻' => 'Oju Arɛrin Ologbo Pɛlu Oju-ɔkan',
    '😼' => 'Oju Ologbo Pɛlu Ɛrin Afinishɛsin',
    '😽' => 'Oju Ologbo Afɛnukonu',
    '🙀' => 'Oju Ologbo Ti o Rɛ',
    '😿' => 'Oju Ɛkun Ologbo',
    '😾' => 'Oju Ete Ologbo',
    '🙈' => 'Ɔbɔ Mari Ibi',
    '🙉' => 'Ɔbɔ Magbɔ Ibi',
    '🙊' => 'Ɔbɔ Masɔ ibi',
    '💌' => 'Lɛta Ifɛ',
    '💘' => 'Ɔkan Ti o Ni Ɔfa',
    '💝' => 'Ɔkan Pɛlu Riboni',
    '💖' => 'Ɔkan Didan',
    '💗' => 'Ɔkan Didagba',
    '💓' => 'Ɔkan Ti O N Mi',
    '💞' => 'Ɔkan Ti O N Yi',
    '💕' => 'Awɔn Ɔkan Meji',
    '💟' => 'Ɔshɔ Ɔkan',
    '❣' => 'àmì ìyanú ɔkàn tó wúwo',
    '💔' => 'Ibanujɛ Ɔkan',
    '❤' => 'ɔkàn pupa',
    '🩷' => 'ɔkàn pinki',
    '🧡' => 'ɔlɔkàn omi ɔsàn',
    '💛' => 'Ɔkan Awɔ Ofeefe',
    '💚' => 'Ɔkan Awɔ Ewe',
    '💙' => 'Ɔkan Bulu',
    '🩵' => 'okàn buluu díè',
    '💜' => 'Ɔkan Awɔ Pɔpu',
    '🤎' => 'ɔkàn awo igi',
    '🖤' => 'Ɔkàn Dúdú',
    '🩶' => 'ɔkan eerú',
    '🤍' => 'ɔkàn funfun',
    '💋' => 'Aami Ifɛnuko',
    '💯' => 'koko ɔgɔrun',
    '💢' => 'Àmì Ibinu',
    '🫯' => 'ìjà inu ìkùukùu',
    '💥' => 'Ikɔlu',
    '💫' => 'Itoogbe',
    '💦' => 'Ilaagun Ti N kan',
    '💨' => 'N Salɔ',
    '🕳' => 'ihò',
    '💬' => 'Bàlúnù Ɔ̀rɔ̀ Sísɔ',
    '🗨' => 'bàlúnù ɔ̀rɔ̀ sísɔ òsì',
    '🗯' => 'bàlúnù ɔ̀rɔ̀ sísɔ ɔ̀tún',
    '💭' => 'Bàlúnù Ero',
    '💤' => 'Zzz',
    '👋' => 'N Juwɔ',
    '🤚' => 'Na Ɛhin Ɔwɔ Soke',
    '🖐' => 'nawɔ́ sókè pɛ̀lú ìyàka',
    '✋' => 'Ɔwɔ Nina Soke',
    '🖖' => 'Kiki Ibɛri Funni',
    '🫱' => 'ɔwɔ́ ɔ̀tún',
    '🫲' => 'ɔwɔ́ òsì',
    '🫳' => 'àtɛ́lɛ̀wɔ́ ìsàlɛ̀',
    '🫴' => 'àtɛ́lɛwɔ́ òkè',
    '🫷' => 'títi ɔwɔ́ sɔ́sì',
    '🫸' => 'títi ɔwɔ́ sɔ́tun',
    '👌' => 'Ɔwɔ ODARA',
    '🤌' => 'ìka kíkákò',
    '🤏' => 'ìka kíká',
    '✌' => 'asheyɔrí ɔwɔ́',
    '🤞' => 'Igbekalera',
    '🫰' => 'ɔwɔ́ pɛ̀lú ìka kɛ́keré àti ìka ńlá ní pípapɔ̀',
    '🤟' => 'ìfɔwɔ́júwè mo ní ìfɛ́',
    '🤘' => 'Aami Awɔn Iwo',
    '🤙' => 'Ɔwɔ Ipeni',
    '👈' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Osi',
    '👉' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Apa Ɔtun',
    '👆' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Oke',
    '🖕' => 'ìka àárín',
    '👇' => 'Ɛyin Ɔwɔ Ti O Tɔka Si Isalɛ',
    '☝' => 'ìka kékeré tí ń tɔ́ka sókè',
    '🫵' => 'títɔ́ka sí olùwòran',
    '👍' => 'Atanpako Loke',
    '👎' => 'Atanpako Nisalɛ',
    '✊' => 'Ɛshɛ Ti a Na Soke',
    '👊' => 'Ɛshɛ Ti o Nbɔ',
    '🤛' => 'Ɛsɛ ti O Kɔju sosi',
    '🤜' => 'Ɛsɛ ti O Kɔju sɔtun',
    '👏' => 'N Patɛwɔ',
    '🙌' => 'Ina Awɔn Ɔwɔ',
    '🫶' => 'ɔwɔ́ ɔkàn',
    '👐' => 'Awɔn Ɔwɔ Shishi',
    '🤲' => 'àtɛ́lɛ́ɔwɔ́ papɔ̀',
    '🤝' => 'Ìbɔwɔ́',
    '🙏' => 'Ika Awɔn Ɔwɔ',
    '✍' => 'ńkɔ́wé',
    '💅' => 'Ikun Eekanna',
    '🤳' => 'Yiya Ara ɛni',
    '💪' => 'Aya Fifɛ',
    '🦾' => 'apá ishɛ̀',
    '🦿' => 'ese ise',
    '🦵' => 'ese',
    '🦶' => 'ɛsɛ̀',
    '👂' => 'Etí',
    '🦻' => 'etí pɛ̀lú ohun ìgbɔ́ràn',
    '👃' => 'Imu',
    '🧠' => 'ɔpɔlɔ',
    '🫀' => 'ɔ̀kan alára',
    '🫁' => 'ɛ̀yà èémí',
    '🦷' => 'eyín',
    '🦴' => 'eegun',
    '👀' => 'Awɔn Ojú',
    '👁' => 'eyinjú',
    '👅' => 'Ahɔn',
    '👄' => 'Ɛnu',
    '🫦' => 'ètè gígé',
    '👶' => 'ìkókó',
    '🧒' => 'ɔmɔ',
    '👦' => 'ɔmɔkùnrin',
    '👧' => 'ɔmɔbìrin',
    '🧑' => 'àgbà',
    '👱' => 'Eniyan Onirun funfun',
    '👨' => 'Ɔkùnrin',
    '🧔' => 'apárí',
    '👩' => 'Obìnrin',
    '🧓' => 'àgbàlagbà',
    '👴' => 'Agbalagba Ɔkunrin',
    '👵' => 'Agbalagba Obinrin',
    '🙍' => 'Ɛni N Bojujɛ',
    '🙎' => 'Ɛni Yahɔn sita',
    '🙅' => 'Ɛni Nsɔ RARA',
    '🙆' => 'Ɛni Nsɔ O DARA',
    '💁' => 'Ɛni N Tɔka Ɔwɔ',
    '🙋' => 'Ɛni N Nawɔ Soke',
    '🧏' => 'odi',
    '🙇' => 'Ɛni N Tɛriba',
    '🤦' => 'Ɛni Fɔwɔ Boju',
    '🤷' => 'Ɛni N Gunpa',
    '👮' => 'Ɔlɔpa',
    '🕵' => 'ɔ̀tɛlèmúyé',
    '💂' => 'Olushɔ',
    '🥷' => 'nínjà',
    '👷' => 'Oshishɛ Ikɔle',
    '🫅' => 'ènìyàn pɛ̀lú adé',
    '🤴' => 'Ɔmɔkunrin Alade',
    '👸' => 'Ɔmɔbinrin Alade',
    '👳' => 'Ɛni wɔ Lawani',
    '👲' => 'Ɔkunrin Pɛlu Fila Shainisi',
    '🧕' => 'obinrin tó wé gèlè',
    '🤵' => 'Ɔkunrin Pɛlu Kootu',
    '👰' => 'Iyawo Pɛlu Iboju',
    '🤰' => 'obinrin alaboyun',
    '🫃' => 'aláboyún ɔkùnrin',
    '🫄' => 'aláboyún',
    '🤱' => 'ìfɔ́mɔlɔ́yàn',
    '👼' => 'ángɛli ìkókó',
    '🎅' => 'Baba Keresi',
    '🤶' => 'Arabinrin Keresi',
    '🦸' => 'akɔni alágbára',
    '🦹' => 'alátakɔ̀ alágbára',
    '🧙' => 'onídán',
    '🧚' => 'Iwin',
    '🧛' => 'Fánpáyà',
    '🧜' => 'Yemɔja ènìyàn',
    '🧝' => 'Egbére',
    '🧞' => 'Ànjɔ̀nnú',
    '🧟' => 'Ɛbɔra',
    '🧌' => 'iwin nlá',
    '🫈' => 'ɛ̀dá onírun',
    '💆' => 'ɛni N gba Ifɔwɔwɔnilara',
    '💇' => 'Ɛni N Gɛrun',
    '🚶' => 'Ɛni N Rin',
    '🧍' => 'ènìyàn dídúró',
    '🧎' => 'ènìyàn kíkúnlɛ̀',
    '🏃' => 'Ɛni N Sare',
    '💃' => 'Obinrin Ti Njo',
    '🕺' => 'Ɔkunrin Ti Njo',
    '🕴' => 'ɔkùnrin nínu kóòtú òwò',
    '👯' => 'awɔn eniyan eleti ehoro',
    '🧖' => 'Ènìyàn nínú Ìyàrá tó n gbóná',
    '🧗' => 'Ènìyàn tó n gòkè',
    '🤺' => 'Ɛni N Ja Pɛlu Ida',
    '🏇' => 'Ereje Ɛlɛsin',
    '⛷' => 'ɛni n síkì',
    '🏂' => 'Ishere Ori Yiyin',
    '🏌' => 'ɛni gɔ́ɔ̀fù',
    '🏄' => 'Ɛni N Gun Iji',
    '🚣' => 'Ɛni N wa Ɔkɔ',
    '🏊' => 'Ɛni tí ń wɛdò',
    '⛹' => 'ɛni tà boun bɔ́ɔ̀lù',
    '🏋' => 'ɛni fa ìwɔ̀n sókè',
    '🚴' => 'Ɛni N Gun Kɛkɛ',
    '🚵' => 'Ɛni N Gun Kɛkɛ Gun Apata',
    '🤸' => 'Ɛni Kawɔ Tilɛ Kɛsɛ Soke',
    '🤼' => 'Awɔn Onigidigbo',
    '🤽' => 'Ɛni N shere Olomi',
    '🤾' => 'Ɛni N Shere Bɔɔlu Ɔlɔwɔ',
    '🤹' => 'Ɛni N ju Nnkan soke',
    '🧘' => 'Ènìyàn nípò ìgbàgbé',
    '🛀' => 'Ɛni Nwɛ',
    '🛌' => 'Ɛniyan Nibusun',
    '👭' => 'Obinrin Meji Ti O Dɔwɔ Ara Wɔn Mu',
    '👫' => 'Ɔkunrin Ati Obirin Ti O Dɔwɔ Ara Wɔn Mu',
    '👬' => 'Ɔkunrin Meji Ti O Dɔwɔ Ara Wɔn Mu',
    '💏' => 'Ifɛnuko',
    '💑' => 'Lɔkɔlaya Pɛlu ɔkan',
    '🗣' => 'orí tí ń sɔ̀rɔ̀',
    '👤' => 'Bujade Ni Biribiri',
    '👥' => 'Awɔn Ibujade Ni Biribiri',
    '🫂' => 'àwɔn ènìyàn tóndìmɔ́ra',
    '👪' => 'Ɛbí',
    '👣' => 'Ipa ɛsɛ',
    '🫆' => 'ìtɛ̀ka',
    '🦰' => 'irun pupa',
    '🦱' => 'irun rírɔ̀',
    '🦳' => 'irun funfun',
    '🦲' => 'orí pípá',
    '🐵' => 'Oju Ɔbɔ',
    '🐒' => 'Ɔ̀bɔ',
    '🦍' => 'Inaki',
    '🦧' => 'oraguta',
    '🐶' => 'Ojú ajá',
    '🐕' => 'Ajá',
    '🦮' => 'ajá ìtóni',
    '🐩' => 'Ajá kékeré',
    '🐺' => 'Ikooko',
    '🦊' => 'Kɔlɔkɔlɔ',
    '🦝' => 'rakumi',
    '🐱' => 'Ojú olóńgbò',
    '🐈' => 'Olóńgbò',
    '🦁' => 'Kiniun',
    '🐯' => 'Oju Ɛkùn',
    '🐅' => 'Ɛkùn',
    '🐆' => 'Àmɔ̀tɛ́kùn',
    '🐴' => 'Oju Ɛshin',
    '🫎' => 'ɛmɔ́',
    '🫏' => 'kɛ́tɛ́kɛ́tɛ́',
    '🐎' => 'Ɛshin',
    '🦄' => 'Oju Ɛshin Oniwo',
    '🦓' => 'kɛ́tɛ́kɛ́tɛ́ abìla',
    '🦌' => 'Agbɔnrin',
    '🦬' => 'bison',
    '🐮' => 'Oju Maalu',
    '🐂' => 'Ɛgbɔrɔ maalu',
    '🐃' => 'Ɛfɔn Omi',
    '🐄' => 'Maalu',
    '🐷' => 'Oju Ɛlɛdɛ',
    '🐖' => 'Ɛlɛdɛ',
    '🐗' => 'Biari',
    '🐽' => 'Imu Ɛlɛdɛ',
    '🐏' => 'Agbo',
    '🐑' => 'abo àgùntàn',
    '🐐' => 'Ewúrɛ́',
    '🐪' => 'Kɛtɛkɛtɛ',
    '🐫' => 'Kɛtɛkɛtɛ Onike-Meji',
    '🦙' => 'llama',
    '🦒' => 'àgùfɔn',
    '🐘' => 'Erin',
    '🦣' => 'mamotì',
    '🦏' => 'Ɛranko Imado',
    '🦛' => 'hipopotámɔ́ɔ̀sì',
    '🐭' => 'Ɔju Eku',
    '🐁' => 'Eku',
    '🐀' => 'Ekute',
    '🐹' => 'Oju Eku Oko',
    '🐰' => 'Oju Ehoro',
    '🐇' => 'Ehoro',
    '🐿' => 'eku ńlá',
    '🦫' => 'bifa',
    '🦔' => 'hedgehog',
    '🦇' => 'Adan',
    '🐻' => 'Oju Biari',
    '🐨' => 'Koala',
    '🐼' => 'Oju Panda',
    '🦥' => 'àsɛ́wó',
    '🦦' => 'ota',
    '🦨' => 'Vote òkété igbó',
    '🦘' => 'kangaròó',
    '🦡' => 'bájà',
    '🐾' => 'Apa Eekan',
    '🦃' => 'Tólòtólò',
    '🐔' => 'Adìyɛ',
    '🐓' => 'Akukɔ',
    '🐣' => 'Ɔmɔ Adiyɛ Pipa',
    '🐤' => 'Ɔmɔ Adiyɛ',
    '🐥' => 'Ɔmɔ Adiyɛ ti now Iwaju',
    '🐦' => 'Ɛyɛ',
    '🐧' => 'Ɛyɛ Oko',
    '🕊' => 'àdàbà',
    '🦅' => 'Àshá',
    '🦆' => 'Pɛ́pɛ́yɛ',
    '🦢' => 'ɛyɛ swan',
    '🦉' => 'Owiwi',
    '🦤' => 'ɛyɛ dodo',
    '🪶' => 'ìyɛ́',
    '🦩' => 'Vote ɛyɛ flamingò',
    '🦚' => 'ɔ̀kín',
    '🦜' => 'àparò',
    '🪽' => 'iye',
    '🪿' => 'tòlotòló',
    '🐸' => 'ɔ̀pɔ̀lɔ́',
    '🐊' => 'Ɔni',
    '🐢' => 'Adaba',
    '🦎' => 'Aláǹgba',
    '🐍' => 'Ejò',
    '🐲' => 'Oju Dragoni',
    '🐉' => 'Drágónì',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'Ɛja Nla Atutɔ',
    '🐋' => 'Ɛja Nla',
    '🐬' => 'Dɔfini',
    '🫍' => 'òbéjé',
    '🦭' => 'alákàsà',
    '🐟' => 'Ɛja',
    '🐠' => 'Ɛja oorùn',
    '🐡' => 'Ɛja Awura',
    '🦈' => 'Sháàkì',
    '🐙' => 'Ɛja ɛlɛsɛ mɛjɔ',
    '🐚' => 'Onikaraun Pinpin',
    '🪸' => 'kórà',
    '🪼' => 'ɛ̀ja jɛ́lì',
    '🦀' => 'Alákàn',
    '🦞' => 'akàn',
    '🦐' => 'Ede',
    '🦑' => 'Sikidi',
    '🦪' => 'alákàn ńlá',
    '🐌' => 'Ìgbín',
    '🦋' => 'Labalaba',
    '🐛' => 'Ìyanjú Àshìshe',
    '🐜' => 'Kokoro',
    '🐝' => 'Oyin',
    '🪲' => 'bítù',
    '🐞' => 'Yigbɛ-yigbɛ',
    '🦗' => 'tata gígùn',
    '🪳' => 'ayán',
    '🕷' => 'aláõtakùn',
    '🕸' => 'ìtakùnaláõtakùn',
    '🦂' => 'Àkekè',
    '🦟' => 'ɛ̀fɔ́n',
    '🪰' => 'eshinshin',
    '🪱' => 'ekòló',
    '🦠' => 'maikirobu',
    '💐' => 'Àsè',
    '🌸' => 'Iruwe Shɛri',
    '💮' => 'Ododo Funfun',
    '🪷' => 'lotosi',
    '🏵' => 'Ohun Odòdó ɔshɔ',
    '🌹' => 'Ododo',
    '🥀' => 'ododo witi',
    '🌺' => 'Ododo Ibisikɔsi',
    '🌻' => 'Ìtàná',
    '🌼' => 'Iruwe',
    '🌷' => 'Tulipu',
    '🪻' => 'hayasinti',
    '🌱' => 'Ihoro eso',
    '🪴' => 'eso pootù',
    '🌲' => 'Igi Aruwe',
    '🌳' => 'Igi Igbo',
    '🌴' => 'Ɔpɛ',
    '🌵' => 'Igi Ɔrɔ́',
    '🌾' => 'Idi Ti Irɛsi',
    '🌿' => 'Egbo Igi',
    '☘' => 'shámrɔkì',
    '🍀' => 'Ahoro Elewe Merin',
    '🍁' => 'Ewe Mapulu',
    '🍂' => 'Irawe',
    '🍃' => 'Ewe Ti N Fanka Ninu Iji',
    '🪹' => 'ibi ìyéeyin òfìfo',
    '🪺' => 'ibi ìyéeyin pɛ̀lú ɛyin',
    '🍄' => 'Olu',
    '🪾' => 'igi tí kò léwɛ́',
    '🍇' => 'Girapu',
    '🍈' => 'Ɛ̀gúsí',
    '🍉' => 'Eso Bara',
    '🍊' => 'Tanjarini',
    '🍋' => 'Orombo-wɛwɛ Chiffon',
    '🍌' => 'Ɔ̀gɛ̀dɛ̀',
    '🍍' => 'Ɔpɛ-oyinbo',
    '🥭' => 'mángò',
    '🍎' => 'Apu Pupa',
    '🍏' => 'Apu Alawɔ Ewe',
    '🍐' => 'Píà',
    '🍑' => 'Píísì',
    '🍒' => 'Shɛɛri',
    '🍓' => 'Eso dundun',
    '🫐' => 'bɛ́rì búlù',
    '🥝' => 'Eso Kiwi',
    '🍅' => 'Timati',
    '🫒' => 'Olifi',
    '🥥' => 'àgbɔn',
    '🥑' => 'Afokado',
    '🍆' => 'Igba',
    '🥔' => 'Ànàmɔ́',
    '🥕' => 'Kárɔ̀tì',
    '🌽' => 'Agbado',
    '🌶' => 'ata gbígbónɔ̀',
    '🫑' => 'tàtàsé',
    '🥒' => 'Kùkúmbà',
    '🥬' => 'ɛ̀fɔ́',
    '🥦' => 'ewé ɛlɛ́fɔ̀ɔ́',
    '🧄' => 'gálíìkì',
    '🧅' => 'àlùbɔ́sà',
    '🥜' => 'Ɛpa',
    '🫘' => 'ɛ̀wà',
    '🌰' => 'Kóró inú èso búránù',
    '🫚' => 'jínjà',
    '🫛' => 'eap',
    '🫜' => 'ohun ɔ̀gbìn onígbòǹgbɔ̀',
    '🍞' => 'Búrɛ́dì',
    '🥐' => 'Kurosanti',
    '🥖' => 'Burɛdi Baguette',
    '🫓' => 'búrɛ́ɛ̀dì pɛlɛpɛ',
    '🥨' => 'pretzel',
    '🥯' => 'bágɛ́lì',
    '🥞' => 'Atike Ikunju',
    '🧇' => 'wáfù',
    '🧀' => 'Waara Wedge',
    '🍖' => 'Ɛran Ara Egungun',
    '🍗' => 'Ɛsɛ Adiyɛ',
    '🥩' => 'ìgé ɛran',
    '🥓' => 'Ɛran Ɛlɛdɛ',
    '🍔' => 'Hamburger',
    '🍟' => 'Ounjɛ Ipanu Didun',
    '🍕' => 'Písà',
    '🌭' => 'Hot Dog',
    '🥪' => 'búrɛ́dì alákànpɔ̀',
    '🌮' => 'Taco',
    '🌯' => 'Burito',
    '🫔' => 'tamalé',
    '🥙' => 'Burɛdi Afunpɔ Pɛlɛbɛ',
    '🧆' => 'faláfɛ́l]i',
    '🥚' => 'Ɛyin',
    '🍳' => 'Dídáná',
    '🥘' => 'Paanu Ijɛun kekere',
    '🍲' => 'Ikoko Ounjɛ',
    '🫕' => 'fóndù',
    '🥣' => 'abɔ́ pɛ̀lú shíbí',
    '🥗' => 'Saladi Elewe',
    '🍿' => 'Gúgúrú',
    '🧈' => 'bɔ́tà',
    '🧂' => 'iyɔ̀',
    '🥫' => 'ónjɛ inú agolo',
    '🍱' => 'Apoti Bento',
    '🍘' => 'Biskit Irɛsi',
    '🍙' => 'Irɛsi Roboto',
    '🍚' => 'Irɛsi Sise',
    '🍛' => 'irɛsi kɔri',
    '🍜' => 'Abɔ ibɔhun',
    '🍝' => 'Spagɛti',
    '🍠' => 'Anamɔ dindin',
    '🍢' => 'Oden',
    '🍣' => 'Sushi',
    '🍤' => 'Ede Dindin',
    '🍥' => 'Eja dindin Pɛlu Swirl',
    '🥮' => 'àkàrà òsùpá',
    '🍡' => 'Dango',
    '🥟' => 'ìgbɛ́',
    '🥠' => 'kúkì fortune',
    '🥡' => 'àpótí àgbéjáde',
    '🍦' => 'Wara Didi Rirɔ',
    '🍧' => 'Yinyin Gige',
    '🍨' => 'Wara Didi',
    '🍩' => 'Dónɔ́ɔ̀tì',
    '🍪' => 'Kuki',
    '🎂' => 'Àkàrà òyìnbó ɔjɔ́ìbí',
    '🍰' => 'Akara kekere',
    '🧁' => 'akara oyinbo',
    '🥧' => 'róbótó',
    '🍫' => 'Shokoleti Didi',
    '🍬' => 'Kandi',
    '🍭' => 'Suuti Onigi',
    '🍮' => 'Kɔ́sítàdì',
    '🍯' => 'Koko Oyin',
    '🍼' => 'Igo Ikoko',
    '🥛' => 'Ife Wara',
    '☕' => 'Tii Gbigbona',
    '🫖' => 'pɔ́ɔ̀tù tíì',
    '🍵' => 'Ife Tii laini Ɔwɔ',
    '🍶' => 'Sake',
    '🍾' => 'Igo Olori Yiyɔ',
    '🍷' => 'Gilasi Waini',
    '🍸' => 'Gilasi Ounjɛ Amulumala',
    '🍹' => 'Ohun Mimu Akoko Oorun',
    '🍺' => 'Imuti',
    '🍻' => 'Imuti Dídún',
    '🥂' => 'Gilasi Didun',
    '🥃' => 'Gilasi Tɔnbila',
    '🫗' => 'nǹkan olómi dídà',
    '🥤' => 'ife pɛ̀lú sírɔ̀',
    '🧋' => 'tíì bɔ́bù',
    '🧃' => 'àpótí ohun mímu',
    '🧉' => 'ɛgbɛ́',
    '🧊' => 'omi dídì',
    '🥢' => 'igi ìjɛun',
    '🍽' => 'fɔ́ɔ̀kì àti ɔ̀bɛ pɛ̀lú àwo',
    '🍴' => 'Fɔki Ati Ɔbɛ',
    '🥄' => 'Shíbí',
    '🔪' => 'ɔbɛ iyara-idana',
    '🫙' => 'ife nla',
    '🏺' => 'Amphora',
    '🌍' => 'Gulobu To N Shafihan Uropu-Afirika',
    '🌎' => 'Gulobu To N Shafihan Amɛrika',
    '🌏' => 'Gulobu To N Shafihan Ashia-Ɔsiteria',
    '🌐' => 'Gulobu Pɛlu Mɛridiani',
    '🗺' => 'máàpù àgbáyé',
    '🗾' => 'Maapu Ti Japanu',
    '🧭' => 'atɔ́nà',
    '🏔' => 'òkè yìnyín',
    '⛰' => 'òkè',
    '🛘' => 'ìyɛ̀gɛ̀rɛ̀ ilɛ̀',
    '🌋' => 'Ifɛ-ilɛ',
    '🗻' => 'Oke Fuji',
    '🏕' => 'pípàgɔ́',
    '🏖' => 'ɔ̀sà pɛ̀lú agbòrùn',
    '🏜' => 'ashálɛ̀',
    '🏝' => 'erékùshù ashálɛ̀',
    '🏞' => 'páàkì orílɛ̀',
    '🏟' => 'pápá ìsheré',
    '🏛' => 'ilé tó kílásíkà',
    '🏗' => 'ishɛ́ ɔnà ilé',
    '🧱' => 'bíríkì',
    '🪨' => 'àpáta',
    '🪵' => 'igi',
    '🛖' => 'abà',
    '🏘' => 'àwɔn ilé',
    '🏚' => 'ilé àìdára',
    '🏠' => 'Ilé',
    '🏡' => 'Ile Pelu Ɔgba',
    '🏢' => 'Ile Ibi-ishɛ',
    '🏣' => 'Ile-ishɛ Ifiweranshɛ Japani',
    '🏤' => 'Àpótí ÌfìwéRánshɛ́',
    '🏥' => 'Ile-iwosan',
    '🏦' => 'Ile-ifowopamɔsi',
    '🏨' => 'Ilé ìtura',
    '🏩' => 'Ilé ìtura Ifɛ',
    '🏪' => 'Ibi Itura',
    '🏫' => 'Ilé ìwé',
    '🏬' => 'ɛka itaja',
    '🏭' => 'Ilé-ishɛ́',
    '🏯' => 'Ile Nla Japanisi',
    '🏰' => 'Ile Nla',
    '💒' => 'Ìgbéyàwó',
    '🗼' => 'Ile Ishɔ Tokiyo',
    '🗽' => 'Ere Ominira',
    '⛪' => 'Shɔɔshi',
    '🕌' => 'Mɔ́sháláshí',
    '🛕' => 'ilé ìjɔ́sìn Hindu',
    '🕍' => 'Sínágɔ́gù',
    '⛩' => 'ilé òrìshà shíntò',
    '🕋' => 'Kaaba',
    '⛲' => 'Orísun omi',
    '⛺' => 'Àgɔ́',
    '🌁' => 'Ojuju',
    '🌃' => 'Ashalɛ Pɛlu Awɔn Irawɔ',
    '🏙' => 'fífɛ̀ìlú',
    '🌄' => 'Lila Oorun Lori Awɔn Oke',
    '🌅' => 'Ìlà oòrùn',
    '🌆' => 'Iwo Ilu Ni Ashalɛ',
    '🌇' => 'Ìwɔ̀ oòrùn',
    '🌉' => 'Afara Ni Ashalɛ',
    '♨' => 'omi àtilɛ̀wá',
    '🎠' => 'Ɛshin Aladun',
    '🛝' => 'ibi eré',
    '🎡' => 'Kɛ̀kɛ́ Ferris',
    '🎢' => 'Kɛkɛ Olobiri',
    '💈' => 'Opo Onigbajamɔ',
    '🎪' => 'Aba Ere-idaraya',
    '🚂' => 'Yiyi',
    '🚃' => 'Ɔkɔ Oju-irin',
    '🚄' => 'Ɔkɔ oju-irin Alare',
    '🚅' => 'Ɔkɔ oju-irin Alare Pɛlu Imu Ɔta',
    '🚆' => 'Shèdánilɛ́kɔ̀ɔ́',
    '🚇' => 'Àjà ilɛ̀',
    '🚈' => 'Ɔkɔ oju-irin kekere',
    '🚉' => 'Ibudo',
    '🚊' => 'Tiramu',
    '🚝' => 'Oju irin kan',
    '🚞' => 'Reluwe Oloke',
    '🚋' => 'Ɔkɔ Tiramu',
    '🚌' => 'Ɔkɔ Akero',
    '🚍' => 'Ɔkɔ Akero Ti Nbɔ',
    '🚎' => 'Ɔkɔ Akero Oniwiwɔ',
    '🚐' => 'Ɔkɔ Akero Kekere',
    '🚑' => 'Ɔkɔ Alaisan',
    '🚒' => 'Ɛnjini Onina',
    '🚓' => 'Ɔkɔ Ɔlɔpa',
    '🚔' => 'Ɔkɔ Ɔlɔpa Ti Nbɔ',
    '🚕' => 'Taasi',
    '🚖' => 'Taasi Ti Nbɔ',
    '🚗' => 'Ɔko',
    '🚘' => 'Ɔkɔ Ti Nbɔ',
    '🚙' => 'Ɔkɔ Agbafɛ Daradara',
    '🛻' => 'ɔkɔ̀ ńlá fún gbígbé nǹkan',
    '🚚' => 'Ɔkɔ Akɛru',
    '🚛' => 'Ɔkɔ Nla Akɛru',
    '🚜' => 'Katakata',
    '🏎' => 'ɔkɔ̀ ìdíje eré',
    '🏍' => 'alùpùpù',
    '🛵' => 'alupupu onimɔto',
    '🦽' => 'aga ìgbérìn ɔlɔ́wɔ́',
    '🦼' => 'àga ìgbérìn oníná',
    '🛺' => 'ɛ̀rɔ ríìkì',
    '🚲' => 'Kɛ̀kɛ́',
    '🛴' => 'alupupu kekere',
    '🛹' => 'bɔ́ɔ̀dù ti síkéètì',
    '🛼' => 'síkéètì ti ó s;are',
    '🚏' => 'Ibudokɔ',
    '🛣' => 'ojú ɔ̀nà ɔkɔ̀',
    '🛤' => 'ɔ̀nà ojú-irin',
    '🛢' => 'àgbá epo',
    '⛽' => 'pɔ̀mpù epo',
    '🛞' => 'keke',
    '🚨' => 'Ina Ɔkɔ Ɔlɔpa',
    '🚥' => 'Ina Adariko Onidubu',
    '🚦' => 'Ina Adariko Olopo',
    '🛑' => 'Aami Idaduro',
    '🚧' => 'Ishɛ́ ɔnà',
    '⚓' => 'Ìdákòró',
    '🛟' => 'ríngì',
    '⛵' => 'Ɔkɔ kekere',
    '🛶' => 'obele',
    '🚤' => 'Ɔkɔ omi alare',
    '🛳' => 'ɔkɔ̀ ojú omi ńlá èrò',
    '⛴' => 'ferí',
    '🛥' => 'ɔkɔ̀ ojú omi tó ń lo ɛ̀rɔ',
    '🚢' => 'Ɔkɔ̀ ojú omi ńlá',
    '✈' => 'bàlú òfurufú',
    '🛩' => 'bàlú òfurufú kékeré',
    '🛫' => 'Ibi Idagbere Baalu',
    '🛬' => 'Ibi Ikaabɔ Baalu',
    '🪂' => 'páráshútì',
    '💺' => 'Ìjòkó',
    '🚁' => 'Ɛlikɔputa',
    '🚟' => 'Ɔkɔ oju irin Oloke',
    '🚠' => 'Ɔkɔ oniwaya Ori-oke',
    '🚡' => 'Tramway Eriali',
    '🛰' => 'alátagbà',
    '🚀' => 'Rɔ́kɛ̀tì',
    '🛸' => 'àwɔ kékeré tí ń fò',
    '🛎' => 'agogo alágbágbɛ́rùn ilé ìtura',
    '🧳' => 'ɛrù',
    '⌛' => 'Gilasiakoko',
    '⏳' => 'Gilasiakoko Pɛlu Iyɛpɛ Ti N fɛ',
    '⌚' => 'Ago',
    '⏰' => 'Ago Itaniji',
    '⏱' => 'ago aláfɔwɔ́yí',
    '⏲' => 'ago adíwɔ̀n àkókò',
    '🕰' => 'ago àgbélɛ̀',
    '🕛' => 'Ago Mejila',
    '🕧' => 'Ago Mejila Aabɔ',
    '🕐' => 'Ago Kan an',
    '🕜' => 'Ago kan an aabɔ',
    '🕑' => 'Ago Meji',
    '🕝' => 'Ago Meji Aaabɔ',
    '🕒' => 'Ago Mɛta',
    '🕞' => 'Ago Mɛta Aabɔ',
    '🕓' => 'Ago Mɛrin',
    '🕟' => 'Ago Merin Aabɔ',
    '🕔' => 'Ago Marun un',
    '🕠' => 'Ago Marun un Aabɔ',
    '🕕' => 'Ago Mɛfa',
    '🕡' => 'Ago Mɛfa Aabɔ',
    '🕖' => 'Ago Meje',
    '🕢' => 'Ago Meje Aabɔ',
    '🕗' => 'Ago Mɛjɔ',
    '🕣' => 'Ago Mejɔ Aabɔ',
    '🕘' => 'Ago Mɛsan an',
    '🕤' => 'Ago Mɛsan an Aabɔ',
    '🕙' => 'Ago Mɛwa',
    '🕥' => 'Ago Mɛwa Aabɔ',
    '🕚' => 'Ago Mɔkanla',
    '🕦' => 'Ago Mɔkanla Aabɔ',
    '🌑' => 'Òshùpá Tuntun',
    '🌒' => 'Yíyɔ́ Ààbɔ̀ Oshùpá',
    '🌓' => 'Oshùpá Ìlàrin Àkɔ́kɔ́',
    '🌔' => 'Yíyɔ́ Kíkún Oshùpá',
    '🌕' => 'Ɛ̀kúnrɛ́rɛ́ Òshùpá',
    '🌖' => 'Títàn Kíkún Oshùpá',
    '🌗' => 'Oshùpá Ìlàrin Ìgbɛ̀yìn',
    '🌘' => 'Títàn Ààbɔ̀ Oshùpá',
    '🌙' => 'Ààbɔ̀ Oshùpá',
    '🌚' => 'Oju Òshùpá Tuntun',
    '🌛' => 'Oshùpá Ìlàrin Àkɔ́kɔ́ Pɛ̀lú Ojú',
    '🌜' => 'Oshùpá Ìlàrin Ìgbɛ̀yìn Pɛ̀lú Ojú',
    '🌡' => 'òshùwɔ̀n ìgbóná',
    '☀' => 'òrùn',
    '🌝' => 'Ɛ̀kúnrɛ́rɛ́ Òshùpá Pɛ̀lú Ojú',
    '🌞' => 'Oorun Pɛlu Oju',
    '🪐' => 'plánɛ́tì oiringì',
    '⭐' => 'Irawɔ Alaabɔ Funfun',
    '🌟' => 'Irawɔ Titan',
    '🌠' => 'Irawɔ Yiyɔ',
    '🌌' => 'Ɔna Oniwara',
    '☁' => 'òfurufú',
    '⛅' => 'Oorun Lɛhin Ofurufu',
    '⛈' => 'òfurufú pɛ̀lú shísháná àti òjò',
    '🌤' => 'òòrùn lɛ́yìn òfurufú kékeré',
    '🌥' => 'òòrùn lɛ́yìn òfurufú tó tóbi',
    '🌦' => 'òòrùn lɛ́yìn òfurufú òjò',
    '🌧' => 'òfurufú pɛ̀lú òjò',
    '🌨' => 'òfurufú pɛ̀lú yìnyín',
    '🌩' => 'òfurufú pɛlu shísháná',
    '🌪' => 'ìjì tó le',
    '🌫' => 'kùrukùru',
    '🌬' => 'ojú atɛ́gùn',
    '🌀' => 'Ɛfuufu',
    '🌈' => 'òshùmarè',
    '🌂' => 'Agboorun Toti',
    '☂' => 'agbòrùn',
    '☔' => 'Agboorun Pɛlu Omi Ojo Kikan',
    '⛱' => 'agbòrùn ní ilɛ̀',
    '⚡' => 'Agbara Ina Giga',
    '❄' => 'ìdìjɔ òjò yìnyín',
    '☃' => 'ɔkùnrin yìnyín',
    '⛄' => 'Ɔkunrin yinyin Laini Yinyin',
    '☄' => 'kamɛ́tì',
    '🔥' => 'Iná',
    '💧' => 'Drɔ́púlɛ́ɛ̀tì',
    '🌊' => 'Iji Omi',
    '🎃' => 'Jack-o-Atupa',
    '🎄' => 'Igi Keresimesi',
    '🎆' => 'Ishɛ́iná',
    '🎇' => 'Olutan',
    '🧨' => 'olufa iná',
    '✨' => 'Awɔn Titan',
    '🎈' => 'Bàlúùnù',
    '🎉' => 'Ariwo Ayɛye',
    '🎊' => 'Bɔɔlu Kɔnfɛti',
    '🎋' => 'Igi Tanabata',
    '🎍' => 'Ɛshɔ Ɔpɛ oyinbo',
    '🎎' => 'Awɔn Ere Japanisi',
    '🎏' => 'Olugekere Capu',
    '🎐' => 'Idun Iji',
    '🎑' => 'Wiwo Ayɛyɛ Oshupa',
    '🧧' => 'akolɛ́tàsí pupa',
    '🎀' => 'Ríbìnnì',
    '🎁' => 'Ɛbun Didi',
    '🎗' => 'ríbínì ìránilétí',
    '🎟' => 'àwɔn ìwɔlé ìgbaniwɔlé',
    '🎫' => 'Iwe Iwɔle',
    '🎖' => 'fàdákà ológun',
    '🏆' => 'Ife',
    '🏅' => 'Fadaka Ere idaraya',
    '🥇' => 'Fadaka Ipo Akɔkɔ',
    '🥈' => 'Fadaka Ipo Ekeji',
    '🥉' => 'Fadaka Ipo Ɛkɛta',
    '⚽' => 'Bɔɔlu Afɛsɛgba',
    '⚾' => 'Bɔ́ɔ̀lùòkè',
    '🥎' => 'bɔ́ɔ̀lu olowo',
    '🏀' => 'Bɔ́ɔ̀lùalágbɔ̀n',
    '🏐' => 'Folliboolu',
    '🏈' => 'Bɔɔlu Amɛrika',
    '🏉' => 'Bɔɔlu Rɔgibi',
    '🎾' => 'Tɛnisi',
    '🥏' => 'disiki fifo',
    '🎳' => 'Bolin',
    '🏏' => 'eré bɔ́ɔ̀lù afi pátákó gbá',
    '🏑' => 'Hɔki Papa',
    '🏒' => 'Hɔki Yinyin',
    '🥍' => 'lákúrósè',
    '🏓' => 'Bɔɔlu Ori Tabili',
    '🏸' => 'Badimitin',
    '🥊' => 'gilofu ikanshɛ',
    '🥋' => 'Ashɔ Ere Itapa',
    '🥅' => 'àwɔ̀n góòlù',
    '⛳' => 'Asia Ninu Iho',
    '⛸' => 'yìnyín síkétì',
    '🎣' => 'Opo Ipɛja',
    '🤿' => 'iboju fifo',
    '🎽' => 'Shɛɛti Isare',
    '🎿' => 'Awɔn Siki',
    '🛷' => 'sílɛ́dì',
    '🥌' => 'òkúta ìwɔ́',
    '🎯' => 'Igba Taara',
    '🪀' => 'yóyò',
    '🪁' => 'káìtì',
    '🔫' => 'ibɔn ilewɔ',
    '🎱' => 'Bɔɔlu Odo 8',
    '🔮' => 'bɔɔlu aworawɔ',
    '🪄' => 'idán',
    '🎮' => 'Ere-idaraya Fidio',
    '🕹' => 'ìdarí eré',
    '🎰' => 'Ɛrɔ Ifisi',
    '🎲' => 'Ere-idaraya Ludo',
    '🧩' => 'ohun àdìtú',
    '🧸' => 'ekùn ifi',
    '🪅' => 'pinátà',
    '🪩' => 'bɔ́ɔ̀lu onijigí',
    '🪆' => 'dɔ́lù ìsimi',
    '♠' => 'ìpín káàdì sípèdì',
    '♥' => 'ìpín káàdì ɔkàn',
    '♦' => 'ìpín káàdì díámɔ́ndì',
    '♣' => 'ìpín káàdì ewé',
    '♟' => 'pɔ́nì Shɛ́ɛ̀sì',
    '🃏' => 'Joka',
    '🀄' => 'Dragoni Pupa Mahjong',
    '🎴' => 'Káàdì ìsheré Olódòdó',
    '🎭' => 'Eré oríìtàgé',
    '🖼' => 'àwɔrán inú férémù',
    '🎨' => 'Pɛpɛ Oshere',
    '🧵' => 'òwú',
    '🪡' => 'òwú ìránshɔ',
    '🧶' => 'asɔ',
    '🪢' => 'ìsopɔ̀',
    '👓' => 'Dígí',
    '🕶' => 'gíláásì òrùn',
    '🥽' => 'gɔ́gú',
    '🥼' => 'ashɔ ilé ìshàyɛ̀wò',
    '🦺' => 'ashɔ àbò',
    '👔' => 'Okùnɔrùn',
    '👕' => 'Shɛ́ɛ̀tì',
    '👖' => 'Jinsi',
    '🧣' => 'síkáfù',
    '🧤' => 'ìbɔ̀wɔ́',
    '🧥' => 'kóòtù',
    '🧦' => 'ìbɔ̀sɛ̀',
    '👗' => 'Ashɔ',
    '👘' => 'Kimono',
    '🥻' => 'sari',
    '🩱' => 'aso ìwɛ̀',
    '🩲' => 'ashɔ kékeré',
    '🩳' => 'ashɔ pɛ́npé',
    '👙' => 'Pata obinrin',
    '👚' => 'Awɔn Ashɔ Obinrin',
    '🪭' => 'fáànì ɔlɔ́wɔ́',
    '👛' => 'Pɔɔsi',
    '👜' => 'Ìpamɔ́wɔ́',
    '👝' => 'Baagi Ipamɔwɔ',
    '🛍' => 'àwɔn àpamɔ́wɔ́ ɔjà',
    '🎒' => 'Baagi Ile-ɛkɔ Agbekɛyin',
    '🩴' => 'salubata tongi',
    '👞' => 'Bata Ɔkunrin',
    '👟' => 'Bata Isare',
    '🥾' => 'bóòtì ìgokè',
    '🥿' => 'bàtà pɛlɛbɛ',
    '👠' => 'Bata Gogoro',
    '👡' => 'Bata Obinrin pɛlɛbɛ',
    '🩰' => 'bàtà ijó',
    '👢' => 'Buutu Obinrin',
    '🪮' => 'ɛ̀sɔ́ irun',
    '👑' => 'Ade',
    '👒' => 'Haati Obinrin',
    '🎩' => 'Haati Oke',
    '🎓' => 'Fila Asheyɔri',
    '🧢' => 'fìla billed',
    '🪖' => 'ìbòrí ológun',
    '⛑' => 'koto òshìshɛ́ ìrànwɔ́',
    '📿' => 'Ilɛkɛ Adura',
    '💄' => 'Ikun-ete',
    '💍' => 'Dún',
    '💎' => 'Okuta Iyebiye',
    '🔇' => 'Gbohungbohun ti ko Sɔrɔ',
    '🔈' => 'Gbohungbohun ti Ohun rɛ wa Labɛ',
    '🔉' => 'Gbohungbohun ti Ohun rɛ wa Laarin',
    '🔊' => 'Gbohungbohun ti Ohun rɛ lɔSoke',
    '📢' => 'Gbohùngbohùn',
    '📣' => 'ɛ̀rɔ gbohùngbohùn ńlá',
    '📯' => 'gbohùngbohùn ifiranshɛ',
    '🔔' => 'agago',
    '🔕' => 'agogo pɛlu idinku',
    '🎼' => 'akɔsilɛ orin',
    '🎵' => 'ɔ̀rɔ̀ orin',
    '🎶' => 'nóòtì orin',
    '🎙' => 'maikurofóònù sítúdíò',
    '🎚' => 'ìpele yíyò̩',
    '🎛' => 'kókó ibìdárí',
    '🎤' => 'ɛ̀rɔ gbohùngbohùn kékeré',
    '🎧' => 'ɛ̀rɔ àdágbórinsétí',
    '📻' => 'rédíò',
    '🎷' => 'ipè',
    '🎺' => 'kakaaki',
    '🪊' => 'kàkàkí',
    '🪗' => 'akodíà',
    '🎸' => 'jìtá',
    '🎹' => 'duuru orin',
    '🎻' => 'faolini',
    '🪕' => 'bánjò',
    '🥁' => 'Ìlù',
    '🪘' => 'ilu gigun',
    '🪇' => 'marakasi',
    '🪈' => 'fèrè',
    '🪉' => 'háàpù',
    '📱' => 'fóònù alágbèéká',
    '📲' => 'fóònù alágbèéká pɛ̀lú ofà',
    '☎' => 'tɛlifóònù',
    '📞' => 'olùgbà fóònù',
    '📟' => 'ɛ̀rɔ atanilólobó',
    '📠' => 'ɛ̀rɔ fákìsì',
    '🔋' => 'bátìrì',
    '🪫' => 'batírì kékeré',
    '🔌' => 'pulɔgi onina',
    '💻' => 'kɔ̀ǹpútà àgbélétan',
    '🖥' => 'kɔ̀npútà a-gbé-lórí-tábílì',
    '🖨' => 'pínríntà',
    '⌨' => 'kííbɔɔ̀dù',
    '🖱' => 'máòsì kɔ̀npútà',
    '🖲' => 'òntè̩ afinimɔ̀nà',
    '💽' => 'dísìkì kɔ̀ǹpútà',
    '💾' => 'dísìkì fílɔ̀pì',
    '💿' => 'àwo aká-ɔ̀rɔ̀ aláfojúrí',
    '📀' => 'dvd',
    '🧮' => 'abakuɔ́sì',
    '🎥' => 'kamɛra fíìmù',
    '🎞' => 'àwɔn férémù fíìmù',
    '📽' => 'è̩rɔ agbéwòrán jáde',
    '🎬' => 'pataki alapade',
    '📺' => 'àmóhùnmáwòrán',
    '📷' => 'kámɛ́rà',
    '📸' => 'kámɛ́rà pɛlu filashi',
    '📹' => 'ayàwòrán fídíò',
    '📼' => 'awɔn kaadi ododo ishere',
    '🔍' => 'gilasi itɔka-osi amohun tobi',
    '🔎' => 'gilasi itɔka-ɔtun amohun tobi',
    '🕯' => 'kándúùlù',
    '💡' => 'gólòbù iná',
    '🔦' => 'iná fílásì',
    '🏮' => 'atupa iwe pupa',
    '🪔' => 'àtùpà díya',
    '📔' => 'àfikɔ̀wé pɛ̀lú ɛ̀yìn ɔlɔ́ɔ̀shó',
    '📕' => 'ìwé tó padé',
    '📖' => 'iwe shi silɛ',
    '📗' => 'iwe alawɔ ewe',
    '📘' => 'iwe alawɔ bulu',
    '📙' => 'iwe alawɔ ɔsan',
    '📚' => 'àwɔn ìwé',
    '📓' => 'àfikɔ̀wé',
    '📒' => 'lé̩jà',
    '📃' => 'oju-iwe pɛlu lilɔ',
    '📜' => 'gbéjáde',
    '📄' => 'oju-iwe wa loke',
    '📰' => 'ìwé ìròyìn',
    '🗞' => 'ìwé ìròyìn aláyípɔ̀',
    '📑' => 'àmì ìwé àwɔn táàbù',
    '🔖' => 'àmì ìwé',
    '🏷' => 'àkɔ́lé',
    '🪙' => 'koínì',
    '💰' => 'apo owo',
    '🪎' => 'àpótí ìshura',
    '💴' => 'owo yen',
    '💵' => 'owo dɔla',
    '💶' => 'owo uro',
    '💷' => 'owo pɔun',
    '💸' => 'owo pɛlu awɔn iyɛ',
    '💳' => 'káàdì ìsɔdowó',
    '🧾' => 'ìwé owó',
    '💹' => 'àtɛ n pɔsi pɛlu yɛn',
    '✉' => 'àpò ìwé',
    '📧' => 'í-meèlì',
    '📨' => 'apo iwe ti o nbɔ',
    '📩' => 'apo iwe pelu ɔfa',
    '📤' => 'tire àpótí ìgbɔ́rɔ̀jáde',
    '📥' => 'tire àpótí àgbàwɔ́lé',
    '📦' => 'shí àkójɔpɔ̀',
    '📫' => 'àpótíméèlì ti a tipa pɛlu asia nina soke',
    '📪' => 'àpótíméèlì ti a tipa pɛlu asia nina walɛ',
    '📬' => 'àpótíméèlì ti a shi pɛlu asia nina soke',
    '📭' => 'àpótíméèlì ti a shi pɛlu asia nina wale',
    '📮' => 'apoti ifigba iwe iranshɛ',
    '🗳' => 'àpótí ìdìbò pɛ̀lú ìwé ìdìbò',
    '✏' => 'pɛ́nsùlù',
    '✒' => 'góngó dúdú',
    '🖋' => 'gègé orísun',
    '🖊' => 'gègé pɛlu rogodo',
    '🖌' => 'búró̩sì ìkùndà',
    '🖍' => 'kereyɔ́nù',
    '📝' => 'mɛ́mò',
    '💼' => 'àpamɔ́wɔ́',
    '📁' => 'fódà fáìlì',
    '📂' => 'fódà fáìlì ti o shi',
    '🗂' => 'ohun èlò ìpínyà àtòjɔ atɔ́ka-ɔ̀rɔ̀ káàdì',
    '📅' => 'kàlɛ́ndà',
    '📆' => 'kàlɛ́ndà ti a ya',
    '🗒' => 'nóòtì páàdì alákápò̩',
    '🗓' => 'kàlɛ́ndà alákápɔ̀',
    '📇' => 'káàdì àtòjɔ atɔ́kà-ɔ̀rɔ̀',
    '📈' => 'àtɛ n pɔsi',
    '📉' => 'àtɛ n dinku',
    '📊' => 'pɛpɛ ìwe àwòrán àfihàn',
    '📋' => 'aka ɔlɔ́pɔ̀n',
    '📌' => 'abɛ́rɛ́ohunyíyà',
    '📍' => 'abɛ́rɛ́ohunyíyà roboto',
    '📎' => 'àfimúwèépɔ̀',
    '🖇' => 'àsopɔ̀ ìfimúwèépɔ̀',
    '📏' => 'rula gbɔɔrɔ',
    '📐' => 'rula onigun mɛta',
    '✂' => 'sísɔ́ɔ̀sì',
    '🗃' => 'àpótí káàdì fún fáìlì',
    '🗄' => 'àpótí fáàlì',
    '🗑' => 'apɛ̀rɛ̀ ìdalè̩sí',
    '🔒' => 'ti tìí',
    '🔓' => 'ti síi',
    '🔏' => 'ti tìí pɛlu pɛni',
    '🔐' => 'ti tìí pɛlu kɔkɔrɔ',
    '🔑' => 'kɔ́kɔ́rɔ́',
    '🗝' => 'kó̩kɔ́ró̩ àtijó̩',
    '🔨' => 'oòlù',
    '🪓' => 'àáké',
    '⛏' => 'sà',
    '⚒' => 'òòlù àti ìsà',
    '🛠' => 'òòlù àti irinshɛ́ afagbára dè',
    '🗡' => 'dágà',
    '⚔' => 'idà alágbèélèbú',
    '💣' => 'Bɔmbu',
    '🪃' => 'ipadawa',
    '🏹' => 'ɔkɔ ati ɔfa',
    '🛡' => 'ohun èlò àbò',
    '🪚' => 'sɔ́ɔ̀ káfíntà',
    '🔧' => 'oolu',
    '🪛' => 'elo ìtú ìdè',
    '🔩' => 'nɔti ati botu',
    '⚙' => 'gíà',
    '🗜' => 'gbámú',
    '⚖' => 'ìwɔ̀ntúnwɔ̀nsí síkélì',
    '🦯' => 'egba funfun',
    '🔗' => 'ìtɔ́kasí',
    '⛓' => 'àwɔn she̩kɛ́shɛkɛ̀',
    '🪝' => 'ako',
    '🧰' => 'nńkan èlo',
    '🧲' => 'lílɛ̀ mɔ́',
    '🪜' => 'àkàbà',
    '🪏' => 'shɔ́bìrì',
    '⚗' => 'àlɛ́mbìk',
    '🧪' => 'tubu ayewo',
    '🧫' => 'ounje',
    '🧬' => 'dínà',
    '🔬' => 'maikirosikopu',
    '🔭' => 'tɛlisikopu',
    '📡' => 'eria satalaiti',
    '💉' => 'abɛrɛ',
    '🩸' => 'ita ɛ̀jɛ̀',
    '💊' => 'pili',
    '🩹' => 'bándeèjì',
    '🩼' => 'igi ifirin',
    '🩺' => 'sitesitosikoop]u',
    '🩻' => 'aworan ayewo',
    '🚪' => 'Ìlɛ̀kùn',
    '🛗' => 'ohun ìgbésókè',
    '🪞' => 'jígí',
    '🪟' => 'fèrèsé',
    '🛏' => 'ibùsùn',
    '🛋' => 'ìjókò àti àtùpà',
    '🪑' => 'àga',
    '🚽' => 'Ilé ìgbɛ́',
    '🪠' => 'ohun iti',
    '🚿' => 'Ìwɛ̀',
    '🛁' => 'Àgbá ìwɛ̀',
    '🪤' => 'pánpɛ́ ɛmɔ́',
    '🪒' => 'ɔ̀bɛ́',
    '🧴' => 'ìgò ìpára',
    '🧷' => 'àbɛ́rɛ́ ààbò',
    '🧹' => 'ìgbálɛ̀',
    '🧺' => 'apɛ̀rɛ̀',
    '🧻' => 'bɛ́bà kíkà',
    '🪣' => 'bɔ́kɛ́ɛ̀tì',
    '🧼' => 'ɔshɛ',
    '🫧' => 'àwɔn bɔ́bù',
    '🪥' => 'búrɔ̀ɔ́shì ìfɔnu',
    '🧽' => 'kàyìnkàyìn',
    '🧯' => 'ohun ìpaná',
    '🛒' => 'Àtɛ Iraja',
    '🚬' => 'siga',
    '⚰' => 'pósí',
    '🪦' => 'okutaori',
    '⚱' => 'igbá ìsìnkú',
    '🧿' => 'amuleti ti nasari',
    '🪬' => 'mámúsà',
    '🗿' => 'moai',
    '🪧' => 'ohun ìkéde',
    '🪪' => 'káàdì ìdánimoɔ̀',
    '🏧' => 'Aami ATM',
    '🚮' => 'idoti ninu aami idɔti',
    '🚰' => 'omi asheegbe kiri',
    '♿' => 'àmì kɛkɛ ɛni-ɛsɛ-ndun',
    '🚹' => 'iyara awɔn ɔkunrin',
    '🚺' => 'iyara awɔn obinrin',
    '🚻' => 'iléìyàgbɛ́',
    '🚼' => 'àmì ɔmɔ',
    '🚾' => 'iléìyàgbɛ́ olomi',
    '🛂' => 'ishakoso aworan ori',
    '🛃' => 'awɔn ashɔbode',
    '🛄' => 'igba ɛru ɛni',
    '🛅' => 'fifi ɛru silɛ',
    '⚠' => 'ìkìlɔ̀',
    '🚸' => 'awɔn ɔmɔde n sɔda',
    '⛔' => 'kosi iwɔle',
    '🚫' => 'kosaye',
    '🚳' => 'kosi awɔn kɛkɛ',
    '🚭' => 'kosi mimu siga',
    '🚯' => 'kosi idahun-silɛ',
    '🚱' => 'omi ti kosheemu',
    '🚷' => 'kosi olufɛsɛrin',
    '📵' => 'kosi awɔn foonu alagbeka',
    '🔞' => 'kosi eniyan labɛ ejidinlogun',
    '☢' => 'rédíòátífù',
    '☣' => 'ewu ajɛmɔ́nìyàn',
    '⬆' => 'àmì òkè ìtó̩sɔ́nà o̩lɔ́fà',
    '↗' => 'àmì òkè ìtó̩sɔ́nà o̩lɔ́fà apá ɔ̀tún',
    '➡' => 'àmì ìtó̩sɔ́nà o̩lɔ́fà apá ɔ̀tún',
    '↘' => 'àmì ilɛ̀ ìtó̩sɔ́nà o̩lɔ́fà apá ɔ̀tún',
    '⬇' => 'àmì ilɛ̀ ìtó̩sɔ́nà o̩lɔ́fà',
    '↙' => 'àmì ilɛ̀ ìtó̩sɔ́nà o̩lɔ́fà apá òsì',
    '⬅' => 'àmì ìtó̩sɔ́nà o̩lɔ́fà apá òsì',
    '↖' => 'àmì òkè ìtó̩sɔ́nà o̩lɔ́fà apá òsì',
    '↕' => 'ɔfà tòkètilɛ̀',
    '↔' => 'àmì ìtó̩sɔ́nà o̩lɔ́fà tɔ̀tún-tòsì',
    '↩' => 'àmì ìtó̩sɔ́nà o̩lɔ́fà apá ɔ̀tún onígun',
    '↪' => 'àmì ìtó̩sɔ́nà o̩lɔ́fà apá òsì onígun',
    '⤴' => 'àmì ìtó̩sɔ́nà o̩lɔ́fà apá ɔ̀tún onígun òkè',
    '⤵' => 'àmì ìtó̩sɔ́nà o̩lɔ́fà apá ɔ̀tún onígun ìsàlɛ̀',
    '🔃' => 'awɔn ɔfa yiyi ɔna ago',
    '🔄' => 'bɔtini awɔn ɔfa yiyi lodi sɔna ago',
    '🔙' => 'Ɔfa ƐYIN',
    '🔚' => 'Ɔfa IPARI',
    '🔛' => 'Ɔfa LORI!',
    '🔜' => 'Ɔfa LAIPƐ',
    '🔝' => 'Ɔfa LOKE',
    '🛐' => 'ibi ijɔsin',
    '⚛' => 'àmì átɔ́mù',
    '🕉' => 'om',
    '✡' => 'ìràwɔ̀ Dáfídì',
    '☸' => 'kɛ̀ké̩ è̩sìn dáámà',
    '☯' => 'yínì yángì',
    '✝' => 'àgbélèbú látíìnì',
    '☦' => 'àgbélèbú àtijó',
    '☪' => 'ìràwɔ̀ àti òshùpá tí kò tí yɔ tán',
    '☮' => 'àmì àláàáfíà',
    '🕎' => 'menorah',
    '🔯' => 'irawɔ totooto oni-mɛfa',
    '🪯' => 'kandá',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Gemini',
    '♋' => 'Cancer',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Scorpius',
    '♐' => 'Sagittarius',
    '♑' => 'Capricorn',
    '♒' => 'Aquarius',
    '♓' => 'Pisces',
    '⛎' => 'Ophiuchus',
    '🔀' => 'yiyɔ bɔtini tiraki',
    '🔁' => 'atunshe bɔtini',
    '🔂' => 'atunshe bɔtini ɛlɛyɔ',
    '▶' => 'bɔ́tínì píílè',
    '⏩' => 'mu bɔtini sare lɔwaju',
    '⏭' => 'bɔ́tìnì tírákì tó kàn',
    '⏯' => 'bó̩tìnìpíílè tàbí ìdúró',
    '◀' => 'Bɔ́tínì ìdápadà',
    '⏪' => 'mu bɔtini sare rɛhin',
    '⏮' => 'Tíráàkì tó ké̩yìn',
    '🔼' => 'bɔtini oke',
    '⏫' => 'bɔtini imusoke kia',
    '🔽' => 'bɔtini isalɛ',
    '⏬' => 'bɔtini imussalɛ kia',
    '⏸' => 'bɔ́tínì ìdánudúró fúngbà díɛ̀',
    '⏹' => 'bɔ́tínì ìdànudúró',
    '⏺' => 'bɔ́tínì agbohùnsílɛ̀',
    '⏏' => 'bó̩tínì àtɛ̀jáde',
    '🎦' => 'sinima',
    '🔅' => 'bɔtini baibai',
    '🔆' => 'bɔtini titan',
    '📶' => 'àwɔn òpó antɛna',
    '🛜' => 'aini okun ina',
    '📳' => 'moodu gbigbɔn',
    '📴' => 'pipa ɛ̀rɔ ìbánisɔ̀rɔ̀ alágbèéká',
    '♀' => 'àmí obìnrin',
    '♂' => 'àmì ɔkùnrin',
    '⚧' => 'ami ìyíeda',
    '✖' => 'ìsɔdipúpò̩ tó nípɔn x',
    '➕' => 'aami àròpɔ̀ nla',
    '➖' => 'aami ayɔkuro nla',
    '➗' => 'aami gige nla',
    '🟰' => 'ami jíje nlá',
    '♾' => 'ailopin',
    '‼' => 'àmì ìyanu oníbejì',
    '⁉' => 'àmì ìyanu oníbéèrè',
    '❓' => 'àmì ìbéèrè ìdàkodò',
    '❔' => 'aami ibeere funfun',
    '❕' => 'aami iyalɛnu funfun',
    '❗' => 'àmì ìyàlɛ́nu ìdàkodò',
    '〰' => 'dáàshì onísàn omi',
    '💱' => 'pashiparɔ owo',
    '💲' => 'aami dɔla nla',
    '⚕' => 'àmì egbògiogùn',
    '♻' => 'àmì àtúnrɔ',
    '⚜' => 'fleur-de-lis',
    '🔱' => 'aami apɛɛrɛ trident',
    '📛' => 'orúkɔ àmì',
    '🔰' => 'Àmì Japanisi fun olubɛre',
    '⭕' => 'roboto wiwo nla',
    '✅' => 'maaki ishayewo funfun nla',
    '☑' => 'àyɛ̀wò àpótí ìdìbò',
    '✔' => 'fínnífínní',
    '❌' => 'aami idabu',
    '❎' => 'bɔtini aami idabu',
    '➰' => 'iho wɔlɔwɔlo',
    '➿' => 'iho wɔlɔwɔlo meji',
    '〽' => 'ara máàkì ti a ti tɔwó̩bɔ̀',
    '✳' => 'àmì àkíyèsí onígbá-mé̩jɔ',
    '✴' => 'àmì àkíyèsí onígun-mé̩jɔ',
    '❇' => 'dán',
    '™' => 'àmì ìdánimɔ̀ iléeshɛ́',
    '🫟' => 'fɔ́nká',
    '🔠' => 'shafikun latini ɔ̀rɔ̀ gbólóhùn ńlá',
    '🔡' => 'shafikun latini ɔ̀rɔ̀ gbólóhùn kékeré',
    '🔢' => 'shafikun awɔn nɔnba',
    '🔣' => 'shafikun awɔn àmì',
    '🔤' => 'shafikun awɔn lɛta latini',
    '🅰' => 'Bɔ́tìnì A (irúfé̩ ɛ̀jɛ̀)',
    '🆎' => 'Bɔtini AB (irufɛ ɛjɛ)',
    '🅱' => 'Bɔ́tìnì B(irúfé̩ ɛ̀jɛ̀)',
    '🆑' => 'Bɔtini CL',
    '🆒' => 'Bɔtini KUULU',
    '🆓' => 'Bɔtini ƆFƐ',
    'ℹ' => 'àlàyé',
    '🆔' => 'Bɔtini ID',
    'Ⓜ' => 'M òdo',
    '🆕' => 'Bɔtini TUNTUN',
    '🆖' => 'Bɔtini NG',
    '🅾' => 'Bɔ́tìnì O (irúfé̩ èjè)',
    '🆗' => 'Bɔtini DARA',
    '🅿' => 'bó̩tìnì P',
    '🆘' => 'Bɔtini SOS',
    '🆙' => 'Oke! Bɔ̀tìnì',
    '🆚' => 'Bɔtini VS',
    '🈁' => 'Bɔtini Japanisi "nibi"',
    '🈂' => 'Bɔ́tìnì Japanísì "ìdíyelé fún owó ɔ̀yà"',
    '🈷' => 'Bó̩tìnì Japanisi "owó ìdíyelé oshoòshù"',
    '🈶' => 'Bɔtini Japanisi "kosi lɔfɛ"',
    '🈯' => 'Bɔtini Japanisi "nipamɔ"',
    '🉐' => 'Bɔtini Japanisi "idunadura"',
    '🈹' => 'Bɔtini Japanisi "ɛdinwo"',
    '🈚' => 'Bɔtini Japanisi "lɔ́fɛ̀é̩"',
    '🈲' => 'Bɔtini Japanisi "shediwɔ"',
    '🉑' => 'Bɔtini "itɛwɔgba" Japanisi',
    '🈸' => 'Bɔtini "ohun elo" Japanisi',
    '🈴' => 'Bɔtini "gbendeke iyege" Japanisi',
    '🈳' => 'Bɔtini "aaye" Japanisi',
    '㊗' => 'Bó̩tìnì "kú oríre" Japanisi',
    '㊙' => 'Bó̩tìnì "àshírí"Japanisi',
    '🈺' => 'Bɔtini "shi fun okowo" Japanisi',
    '🈵' => 'Bɔtini "kosi aaye" Japanisi',
    '🔴' => 'Rogodo Aláwɔ̀ pupa',
    '🟠' => 'osan saku',
    '🟡' => 'saku yelo',
    '🟢' => 'saku girini',
    '🔵' => 'Rogodo Búlúù',
    '🟣' => 'pɔ́pù rogodo',
    '🟤' => 'rogodo aláwɔ igi',
    '⚫' => 'Rogodo Aláwɔ̀ dúdú',
    '⚪' => 'Rogodo Funfun',
    '🟥' => 'síkúwɛ́ɛ̀ pupa',
    '🟧' => 'síkúwɛ́ɛ̀ orénjì',
    '🟨' => 'síkúwɛ́ɛ̀ yɛ́lɔ̀',
    '🟩' => 'síkúwɛ́ɛ̀ aláwɔ̀ ewé',
    '🟦' => 'síkúwɛ́ɛ̀ búlúù',
    '🟪' => 'síkúwɛ́ɛ̀ pɔ́pù',
    '🟫' => 'síkúwɛ́ɛ̀ aláwɔ̀ igi',
    '⬛' => 'onigunmɛrin dudu nla',
    '⬜' => 'onigunmɛrin funfun nla',
    '◼' => 'ilà onígun mé̩rin aláàárín dúdú',
    '◻' => 'ilà onígun mé̩rin aláàárín funfun',
    '◾' => 'onigunmɛrin idaji-kekere dudu',
    '◽' => 'onigunmɛrin idaji-kekere funfun',
    '▪' => 'kékeré onígun mɛ́rin dúdú',
    '▫' => 'kékeré onígun mɛ́rin funfun',
    '🔶' => 'diamɔndi alawɔ oronbo nla',
    '🔷' => 'diamɔndi alawɔ bulu nla',
    '🔸' => 'diamɔndi alawɔ oronbo kekere',
    '🔹' => 'diamɔndi alawɔ bulu kekere',
    '🔺' => 'Alawɔ Pupa Onigun Mɛta Toka Soke',
    '🔻' => 'Alawɔ Pupa Onigun Mɛta Toka Sisalɛ',
    '💠' => 'Diamɔndi Pɛlu Dɔti Kan',
    '🔘' => 'Bɔ́tìnnì Rédíò',
    '🔳' => 'Bɔtini Onigunmɛrin Funfun',
    '🔲' => 'Bɔtini Onigunmɛrin Dudu',
    '🏁' => 'asia péńpé onílà',
    '🚩' => 'asia onigun mɛta',
    '🎌' => 'Awɔn Asia Onidabu',
    '🏴' => 'asia dudu',
    '🏳' => 'àsíá funfun',
];
