<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 1–2-teri turi 3-teri turi',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 1–2-teri turi 4-teri turi',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 1–2-teri turi 5-teri turi',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 1–2-teri turi 6-teri turi',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 3-teri turi 1–2-teri turi',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 3-teri turi 4-teri turi',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 3-teri turi 5-teri turi',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 3-teri turi 6-teri turi',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 4-teri turi 1–2-teri turi',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 4-teri turi 3-teri turi',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 4-teri turi 5-teri turi',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 4-teri turi 6-teri turi',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 5-teri turi 1–2-teri turi',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 5-teri turi 3-teri turi',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 5-teri turi 4-teri turi',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 5-teri turi 6-teri turi',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 6-teri turi 1–2-teri turi',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 6-teri turi 3-teri turi',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 6-teri turi 4-teri turi',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'bo‘sa olish: voyaga yetgan voyaga yetgan 6-teri turi 5-teri turi',
    '👨🏻‍❤‍💋‍👨🏻' => 'bo‘sa olish: erkak erkak 1–2-teri turi',
    '👨🏻‍❤‍💋‍👨🏼' => 'bo‘sa olish: erkak erkak 1–2-teri turi 3-teri turi',
    '👨🏻‍❤‍💋‍👨🏽' => 'bo‘sa olish: erkak erkak 1–2-teri turi 4-teri turi',
    '👨🏻‍❤‍💋‍👨🏾' => 'bo‘sa olish: erkak erkak 1–2-teri turi 5-teri turi',
    '👨🏻‍❤‍💋‍👨🏿' => 'bo‘sa olish: erkak erkak 1–2-teri turi 6-teri turi',
    '👨🏼‍❤‍💋‍👨🏻' => 'bo‘sa olish: erkak erkak 3-teri turi 1–2-teri turi',
    '👨🏼‍❤‍💋‍👨🏼' => 'bo‘sa olish: erkak erkak 3-teri turi',
    '👨🏼‍❤‍💋‍👨🏽' => 'bo‘sa olish: erkak erkak 3-teri turi 4-teri turi',
    '👨🏼‍❤‍💋‍👨🏾' => 'bo‘sa olish: erkak erkak 3-teri turi 5-teri turi',
    '👨🏼‍❤‍💋‍👨🏿' => 'bo‘sa olish: erkak erkak 3-teri turi 6-teri turi',
    '👨🏽‍❤‍💋‍👨🏻' => 'bo‘sa olish: erkak erkak 4-teri turi 1–2-teri turi',
    '👨🏽‍❤‍💋‍👨🏼' => 'bo‘sa olish: erkak erkak 4-teri turi 3-teri turi',
    '👨🏽‍❤‍💋‍👨🏽' => 'bo‘sa olish: erkak erkak 4-teri turi',
    '👨🏽‍❤‍💋‍👨🏾' => 'bo‘sa olish: erkak erkak 4-teri turi 5-teri turi',
    '👨🏽‍❤‍💋‍👨🏿' => 'bo‘sa olish: erkak erkak 4-teri turi 6-teri turi',
    '👨🏾‍❤‍💋‍👨🏻' => 'bo‘sa olish: erkak erkak 5-teri turi 1–2-teri turi',
    '👨🏾‍❤‍💋‍👨🏼' => 'bo‘sa olish: erkak erkak 5-teri turi 3-teri turi',
    '👨🏾‍❤‍💋‍👨🏽' => 'bo‘sa olish: erkak erkak 5-teri turi 4-teri turi',
    '👨🏾‍❤‍💋‍👨🏾' => 'bo‘sa olish: erkak erkak 5-teri turi',
    '👨🏾‍❤‍💋‍👨🏿' => 'bo‘sa olish: erkak erkak 5-teri turi 6-teri turi',
    '👨🏿‍❤‍💋‍👨🏻' => 'bo‘sa olish: erkak erkak 6-teri turi 1–2-teri turi',
    '👨🏿‍❤‍💋‍👨🏼' => 'bo‘sa olish: erkak erkak 6-teri turi 3-teri turi',
    '👨🏿‍❤‍💋‍👨🏽' => 'bo‘sa olish: erkak erkak 6-teri turi 4-teri turi',
    '👨🏿‍❤‍💋‍👨🏾' => 'bo‘sa olish: erkak erkak 6-teri turi 5-teri turi',
    '👨🏿‍❤‍💋‍👨🏿' => 'bo‘sa olish: erkak erkak 6-teri turi',
    '👩🏻‍❤‍💋‍👨🏻' => 'bo‘sa olish: ayol erkak 1–2-teri turi',
    '👩🏻‍❤‍💋‍👨🏼' => 'bo‘sa olish: ayol erkak 1–2-teri turi 3-teri turi',
    '👩🏻‍❤‍💋‍👨🏽' => 'bo‘sa olish: ayol erkak 1–2-teri turi 4-teri turi',
    '👩🏻‍❤‍💋‍👨🏾' => 'bo‘sa olish: ayol erkak 1–2-teri turi 5-teri turi',
    '👩🏻‍❤‍💋‍👨🏿' => 'bo‘sa olish: ayol erkak 1–2-teri turi 6-teri turi',
    '👩🏼‍❤‍💋‍👨🏻' => 'bo‘sa olish: ayol erkak 3-teri turi 1–2-teri turi',
    '👩🏼‍❤‍💋‍👨🏼' => 'bo‘sa olish: ayol erkak 3-teri turi',
    '👩🏼‍❤‍💋‍👨🏽' => 'bo‘sa olish: ayol erkak 3-teri turi 4-teri turi',
    '👩🏼‍❤‍💋‍👨🏾' => 'bo‘sa olish: ayol erkak 3-teri turi 5-teri turi',
    '👩🏼‍❤‍💋‍👨🏿' => 'bo‘sa olish: ayol erkak 3-teri turi 6-teri turi',
    '👩🏽‍❤‍💋‍👨🏻' => 'bo‘sa olish: ayol erkak 4-teri turi 1–2-teri turi',
    '👩🏽‍❤‍💋‍👨🏼' => 'bo‘sa olish: ayol erkak 4-teri turi 3-teri turi',
    '👩🏽‍❤‍💋‍👨🏽' => 'bo‘sa olish: ayol erkak 4-teri turi',
    '👩🏽‍❤‍💋‍👨🏾' => 'bo‘sa olish: ayol erkak 4-teri turi 5-teri turi',
    '👩🏽‍❤‍💋‍👨🏿' => 'bo‘sa olish: ayol erkak 4-teri turi 6-teri turi',
    '👩🏾‍❤‍💋‍👨🏻' => 'bo‘sa olish: ayol erkak 5-teri turi 1–2-teri turi',
    '👩🏾‍❤‍💋‍👨🏼' => 'bo‘sa olish: ayol erkak 5-teri turi 3-teri turi',
    '👩🏾‍❤‍💋‍👨🏽' => 'bo‘sa olish: ayol erkak 5-teri turi 4-teri turi',
    '👩🏾‍❤‍💋‍👨🏾' => 'bo‘sa olish: ayol erkak 5-teri turi',
    '👩🏾‍❤‍💋‍👨🏿' => 'bo‘sa olish: ayol erkak 5-teri turi 6-teri turi',
    '👩🏿‍❤‍💋‍👨🏻' => 'bo‘sa olish: ayol erkak 6-teri turi 1–2-teri turi',
    '👩🏿‍❤‍💋‍👨🏼' => 'bo‘sa olish: ayol erkak 6-teri turi 3-teri turi',
    '👩🏿‍❤‍💋‍👨🏽' => 'bo‘sa olish: ayol erkak 6-teri turi 4-teri turi',
    '👩🏿‍❤‍💋‍👨🏾' => 'bo‘sa olish: ayol erkak 6-teri turi 5-teri turi',
    '👩🏿‍❤‍💋‍👨🏿' => 'bo‘sa olish: ayol erkak 6-teri turi',
    '👩🏻‍❤‍💋‍👩🏻' => 'bo‘sa olish: ayol ayol 1–2-teri turi',
    '👩🏻‍❤‍💋‍👩🏼' => 'bo‘sa olish: ayol ayol 1–2-teri turi 3-teri turi',
    '👩🏻‍❤‍💋‍👩🏽' => 'bo‘sa olish: ayol ayol 1–2-teri turi 4-teri turi',
    '👩🏻‍❤‍💋‍👩🏾' => 'bo‘sa olish: ayol ayol 1–2-teri turi 5-teri turi',
    '👩🏻‍❤‍💋‍👩🏿' => 'bo‘sa olish: ayol ayol 1–2-teri turi 6-teri turi',
    '👩🏼‍❤‍💋‍👩🏻' => 'bo‘sa olish: ayol ayol 3-teri turi 1–2-teri turi',
    '👩🏼‍❤‍💋‍👩🏼' => 'bo‘sa olish: ayol ayol 3-teri turi',
    '👩🏼‍❤‍💋‍👩🏽' => 'bo‘sa olish: ayol ayol 3-teri turi 4-teri turi',
    '👩🏼‍❤‍💋‍👩🏾' => 'bo‘sa olish: ayol ayol 3-teri turi 5-teri turi',
    '👩🏼‍❤‍💋‍👩🏿' => 'bo‘sa olish: ayol ayol 3-teri turi 6-teri turi',
    '👩🏽‍❤‍💋‍👩🏻' => 'bo‘sa olish: ayol ayol 4-teri turi 1–2-teri turi',
    '👩🏽‍❤‍💋‍👩🏼' => 'bo‘sa olish: ayol ayol 4-teri turi 3-teri turi',
    '👩🏽‍❤‍💋‍👩🏽' => 'bo‘sa olish: ayol ayol 4-teri turi',
    '👩🏽‍❤‍💋‍👩🏾' => 'bo‘sa olish: ayol ayol 4-teri turi 5-teri turi',
    '👩🏽‍❤‍💋‍👩🏿' => 'bo‘sa olish: ayol ayol 4-teri turi 6-teri turi',
    '👩🏾‍❤‍💋‍👩🏻' => 'bo‘sa olish: ayol ayol 5-teri turi 1–2-teri turi',
    '👩🏾‍❤‍💋‍👩🏼' => 'bo‘sa olish: ayol ayol 5-teri turi 3-teri turi',
    '👩🏾‍❤‍💋‍👩🏽' => 'bo‘sa olish: ayol ayol 5-teri turi 4-teri turi',
    '👩🏾‍❤‍💋‍👩🏾' => 'bo‘sa olish: ayol ayol 5-teri turi',
    '👩🏾‍❤‍💋‍👩🏿' => 'bo‘sa olish: ayol ayol 5-teri turi 6-teri turi',
    '👩🏿‍❤‍💋‍👩🏻' => 'bo‘sa olish: ayol ayol 6-teri turi 1–2-teri turi',
    '👩🏿‍❤‍💋‍👩🏼' => 'bo‘sa olish: ayol ayol 6-teri turi 3-teri turi',
    '👩🏿‍❤‍💋‍👩🏽' => 'bo‘sa olish: ayol ayol 6-teri turi 4-teri turi',
    '👩🏿‍❤‍💋‍👩🏾' => 'bo‘sa olish: ayol ayol 6-teri turi 5-teri turi',
    '👩🏿‍❤‍💋‍👩🏿' => 'bo‘sa olish: ayol ayol 6-teri turi',
    '🧑🏻‍🫯‍🧑🏼' => 'kurashchilar: 1–2-teri turi 3-teri turi',
    '🧑🏻‍🫯‍🧑🏽' => 'kurashchilar: 1–2-teri turi 4-teri turi',
    '🧑🏻‍🫯‍🧑🏾' => 'kurashchilar: 1–2-teri turi 5-teri turi',
    '🧑🏻‍🫯‍🧑🏿' => 'kurashchilar: 1–2-teri turi 6-teri turi',
    '🧑🏼‍🫯‍🧑🏻' => 'kurashchilar: 3-teri turi 1–2-teri turi',
    '🧑🏼‍🫯‍🧑🏽' => 'kurashchilar: 3-teri turi 4-teri turi',
    '🧑🏼‍🫯‍🧑🏾' => 'kurashchilar: 3-teri turi 5-teri turi',
    '🧑🏼‍🫯‍🧑🏿' => 'kurashchilar: 3-teri turi 6-teri turi',
    '🧑🏽‍🫯‍🧑🏻' => 'kurashchilar: 4-teri turi 1–2-teri turi',
    '🧑🏽‍🫯‍🧑🏼' => 'kurashchilar: 4-teri turi 3-teri turi',
    '🧑🏽‍🫯‍🧑🏾' => 'kurashchilar: 4-teri turi 5-teri turi',
    '🧑🏽‍🫯‍🧑🏿' => 'kurashchilar: 4-teri turi 6-teri turi',
    '🧑🏾‍🫯‍🧑🏻' => 'kurashchilar: 5-teri turi 1–2-teri turi',
    '🧑🏾‍🫯‍🧑🏼' => 'kurashchilar: 5-teri turi 3-teri turi',
    '🧑🏾‍🫯‍🧑🏽' => 'kurashchilar: 5-teri turi 4-teri turi',
    '🧑🏾‍🫯‍🧑🏿' => 'kurashchilar: 5-teri turi 6-teri turi',
    '🧑🏿‍🫯‍🧑🏻' => 'kurashchilar: 6-teri turi 1–2-teri turi',
    '🧑🏿‍🫯‍🧑🏼' => 'kurashchilar: 6-teri turi 3-teri turi',
    '🧑🏿‍🫯‍🧑🏽' => 'kurashchilar: 6-teri turi 4-teri turi',
    '🧑🏿‍🫯‍🧑🏾' => 'kurashchilar: 6-teri turi 5-teri turi',
    '🧑🏻‍❤‍🧑🏼' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 1–2-teri turi 3-teri turi',
    '🧑🏻‍❤‍🧑🏽' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 1–2-teri turi 4-teri turi',
    '🧑🏻‍❤‍🧑🏾' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 1–2-teri turi 5-teri turi',
    '🧑🏻‍❤‍🧑🏿' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 1–2-teri turi 6-teri turi',
    '🧑🏼‍❤‍🧑🏻' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 3-teri turi 1–2-teri turi',
    '🧑🏼‍❤‍🧑🏽' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 3-teri turi 4-teri turi',
    '🧑🏼‍❤‍🧑🏾' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 3-teri turi 5-teri turi',
    '🧑🏼‍❤‍🧑🏿' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 3-teri turi 6-teri turi',
    '🧑🏽‍❤‍🧑🏻' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 4-teri turi 1–2-teri turi',
    '🧑🏽‍❤‍🧑🏼' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 4-teri turi 3-teri turi',
    '🧑🏽‍❤‍🧑🏾' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 4-teri turi 5-teri turi',
    '🧑🏽‍❤‍🧑🏿' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 4-teri turi 6-teri turi',
    '🧑🏾‍❤‍🧑🏻' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 5-teri turi 1–2-teri turi',
    '🧑🏾‍❤‍🧑🏼' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 5-teri turi 3-teri turi',
    '🧑🏾‍❤‍🧑🏽' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 5-teri turi 4-teri turi',
    '🧑🏾‍❤‍🧑🏿' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 5-teri turi 6-teri turi',
    '🧑🏿‍❤‍🧑🏻' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 6-teri turi 1–2-teri turi',
    '🧑🏿‍❤‍🧑🏼' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 6-teri turi 3-teri turi',
    '🧑🏿‍❤‍🧑🏽' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 6-teri turi 4-teri turi',
    '🧑🏿‍❤‍🧑🏾' => 'juftlik va yurak: voyaga yetgan voyaga yetgan 6-teri turi 5-teri turi',
    '🧑🏻‍🐰‍🧑🏼' => 'quyon quloqli odamlar: 1–2-teri turi 3-teri turi',
    '🧑🏻‍🐰‍🧑🏽' => 'quyon quloqli odamlar: 1–2-teri turi 4-teri turi',
    '🧑🏻‍🐰‍🧑🏾' => 'quyon quloqli odamlar: 1–2-teri turi 5-teri turi',
    '🧑🏻‍🐰‍🧑🏿' => 'quyon quloqli odamlar: 1–2-teri turi 6-teri turi',
    '🧑🏼‍🐰‍🧑🏻' => 'quyon quloqli odamlar: 3-teri turi 1–2-teri turi',
    '🧑🏼‍🐰‍🧑🏽' => 'quyon quloqli odamlar: 3-teri turi 4-teri turi',
    '🧑🏼‍🐰‍🧑🏾' => 'quyon quloqli odamlar: 3-teri turi 5-teri turi',
    '🧑🏼‍🐰‍🧑🏿' => 'quyon quloqli odamlar: 3-teri turi 6-teri turi',
    '🧑🏽‍🐰‍🧑🏻' => 'quyon quloqli odamlar: 4-teri turi 1–2-teri turi',
    '🧑🏽‍🐰‍🧑🏼' => 'quyon quloqli odamlar: 4-teri turi 3-teri turi',
    '🧑🏽‍🐰‍🧑🏾' => 'quyon quloqli odamlar: 4-teri turi 5-teri turi',
    '🧑🏽‍🐰‍🧑🏿' => 'quyon quloqli odamlar: 4-teri turi 6-teri turi',
    '🧑🏾‍🐰‍🧑🏻' => 'quyon quloqli odamlar: 5-teri turi 1–2-teri turi',
    '🧑🏾‍🐰‍🧑🏼' => 'quyon quloqli odamlar: 5-teri turi 3-teri turi',
    '🧑🏾‍🐰‍🧑🏽' => 'quyon quloqli odamlar: 5-teri turi 4-teri turi',
    '🧑🏾‍🐰‍🧑🏿' => 'quyon quloqli odamlar: 5-teri turi 6-teri turi',
    '🧑🏿‍🐰‍🧑🏻' => 'quyon quloqli odamlar: 6-teri turi 1–2-teri turi',
    '🧑🏿‍🐰‍🧑🏼' => 'quyon quloqli odamlar: 6-teri turi 3-teri turi',
    '🧑🏿‍🐰‍🧑🏽' => 'quyon quloqli odamlar: 6-teri turi 4-teri turi',
    '🧑🏿‍🐰‍🧑🏾' => 'quyon quloqli odamlar: 6-teri turi 5-teri turi',
    '👨🏻‍🫯‍👨🏼' => 'kurashayotgan erkak: 1–2-teri turi 3-teri turi',
    '👨🏻‍🫯‍👨🏽' => 'kurashayotgan erkak: 1–2-teri turi 4-teri turi',
    '👨🏻‍🫯‍👨🏾' => 'kurashayotgan erkak: 1–2-teri turi 5-teri turi',
    '👨🏻‍🫯‍👨🏿' => 'kurashayotgan erkak: 1–2-teri turi 6-teri turi',
    '👨🏼‍🫯‍👨🏻' => 'kurashayotgan erkak: 3-teri turi 1–2-teri turi',
    '👨🏼‍🫯‍👨🏽' => 'kurashayotgan erkak: 3-teri turi 4-teri turi',
    '👨🏼‍🫯‍👨🏾' => 'kurashayotgan erkak: 3-teri turi 5-teri turi',
    '👨🏼‍🫯‍👨🏿' => 'kurashayotgan erkak: 3-teri turi 6-teri turi',
    '👨🏽‍🫯‍👨🏻' => 'kurashayotgan erkak: 4-teri turi 1–2-teri turi',
    '👨🏽‍🫯‍👨🏼' => 'kurashayotgan erkak: 4-teri turi 3-teri turi',
    '👨🏽‍🫯‍👨🏾' => 'kurashayotgan erkak: 4-teri turi 5-teri turi',
    '👨🏽‍🫯‍👨🏿' => 'kurashayotgan erkak: 4-teri turi 6-teri turi',
    '👨🏾‍🫯‍👨🏻' => 'kurashayotgan erkak: 5-teri turi 1–2-teri turi',
    '👨🏾‍🫯‍👨🏼' => 'kurashayotgan erkak: 5-teri turi 3-teri turi',
    '👨🏾‍🫯‍👨🏽' => 'kurashayotgan erkak: 5-teri turi 4-teri turi',
    '👨🏾‍🫯‍👨🏿' => 'kurashayotgan erkak: 5-teri turi 6-teri turi',
    '👨🏿‍🫯‍👨🏻' => 'kurashayotgan erkak: 6-teri turi 1–2-teri turi',
    '👨🏿‍🫯‍👨🏼' => 'kurashayotgan erkak: 6-teri turi 3-teri turi',
    '👨🏿‍🫯‍👨🏽' => 'kurashayotgan erkak: 6-teri turi 4-teri turi',
    '👨🏿‍🫯‍👨🏾' => 'kurashayotgan erkak: 6-teri turi 5-teri turi',
    '👨🏻‍❤‍👨🏻' => 'juftlik va yurak: erkak erkak 1–2-teri turi',
    '👨🏻‍❤‍👨🏼' => 'juftlik va yurak: erkak erkak 1–2-teri turi 3-teri turi',
    '👨🏻‍❤‍👨🏽' => 'juftlik va yurak: erkak erkak 1–2-teri turi 4-teri turi',
    '👨🏻‍❤‍👨🏾' => 'juftlik va yurak: erkak erkak 1–2-teri turi 5-teri turi',
    '👨🏻‍❤‍👨🏿' => 'juftlik va yurak: erkak erkak 1–2-teri turi 6-teri turi',
    '👨🏼‍❤‍👨🏻' => 'juftlik va yurak: erkak erkak 3-teri turi 1–2-teri turi',
    '👨🏼‍❤‍👨🏼' => 'juftlik va yurak: erkak erkak 3-teri turi',
    '👨🏼‍❤‍👨🏽' => 'juftlik va yurak: erkak erkak 3-teri turi 4-teri turi',
    '👨🏼‍❤‍👨🏾' => 'juftlik va yurak: erkak erkak 3-teri turi 5-teri turi',
    '👨🏼‍❤‍👨🏿' => 'juftlik va yurak: erkak erkak 3-teri turi 6-teri turi',
    '👨🏽‍❤‍👨🏻' => 'juftlik va yurak: erkak erkak 4-teri turi 1–2-teri turi',
    '👨🏽‍❤‍👨🏼' => 'juftlik va yurak: erkak erkak 4-teri turi 3-teri turi',
    '👨🏽‍❤‍👨🏽' => 'juftlik va yurak: erkak erkak 4-teri turi',
    '👨🏽‍❤‍👨🏾' => 'juftlik va yurak: erkak erkak 4-teri turi 5-teri turi',
    '👨🏽‍❤‍👨🏿' => 'juftlik va yurak: erkak erkak 4-teri turi 6-teri turi',
    '👨🏾‍❤‍👨🏻' => 'juftlik va yurak: erkak erkak 5-teri turi 1–2-teri turi',
    '👨🏾‍❤‍👨🏼' => 'juftlik va yurak: erkak erkak 5-teri turi 3-teri turi',
    '👨🏾‍❤‍👨🏽' => 'juftlik va yurak: erkak erkak 5-teri turi 4-teri turi',
    '👨🏾‍❤‍👨🏾' => 'juftlik va yurak: erkak erkak 5-teri turi',
    '👨🏾‍❤‍👨🏿' => 'juftlik va yurak: erkak erkak 5-teri turi 6-teri turi',
    '👨🏿‍❤‍👨🏻' => 'juftlik va yurak: erkak erkak 6-teri turi 1–2-teri turi',
    '👨🏿‍❤‍👨🏼' => 'juftlik va yurak: erkak erkak 6-teri turi 3-teri turi',
    '👨🏿‍❤‍👨🏽' => 'juftlik va yurak: erkak erkak 6-teri turi 4-teri turi',
    '👨🏿‍❤‍👨🏾' => 'juftlik va yurak: erkak erkak 6-teri turi 5-teri turi',
    '👨🏿‍❤‍👨🏿' => 'juftlik va yurak: erkak erkak 6-teri turi',
    '👨🏻‍🐰‍👨🏼' => 'quyon quloqli erkaklar: 1–2-teri turi 3-teri turi',
    '👨🏻‍🐰‍👨🏽' => 'quyon quloqli erkaklar: 1–2-teri turi 4-teri turi',
    '👨🏻‍🐰‍👨🏾' => 'quyon quloqli erkaklar: 1–2-teri turi 5-teri turi',
    '👨🏻‍🐰‍👨🏿' => 'quyon quloqli erkaklar: 1–2-teri turi 6-teri turi',
    '👨🏼‍🐰‍👨🏻' => 'quyon quloqli erkaklar: 3-teri turi 1–2-teri turi',
    '👨🏼‍🐰‍👨🏽' => 'quyon quloqli erkaklar: 3-teri turi 4-teri turi',
    '👨🏼‍🐰‍👨🏾' => 'quyon quloqli erkaklar: 3-teri turi 5-teri turi',
    '👨🏼‍🐰‍👨🏿' => 'quyon quloqli erkaklar: 3-teri turi 6-teri turi',
    '👨🏽‍🐰‍👨🏻' => 'quyon quloqli erkaklar: 4-teri turi 1–2-teri turi',
    '👨🏽‍🐰‍👨🏼' => 'quyon quloqli erkaklar: 4-teri turi 3-teri turi',
    '👨🏽‍🐰‍👨🏾' => 'quyon quloqli erkaklar: 4-teri turi 5-teri turi',
    '👨🏽‍🐰‍👨🏿' => 'quyon quloqli erkaklar: 4-teri turi 6-teri turi',
    '👨🏾‍🐰‍👨🏻' => 'quyon quloqli erkaklar: 5-teri turi 1–2-teri turi',
    '👨🏾‍🐰‍👨🏼' => 'quyon quloqli erkaklar: 5-teri turi 3-teri turi',
    '👨🏾‍🐰‍👨🏽' => 'quyon quloqli erkaklar: 5-teri turi 4-teri turi',
    '👨🏾‍🐰‍👨🏿' => 'quyon quloqli erkaklar: 5-teri turi 6-teri turi',
    '👨🏿‍🐰‍👨🏻' => 'quyon quloqli erkaklar: 6-teri turi 1–2-teri turi',
    '👨🏿‍🐰‍👨🏼' => 'quyon quloqli erkaklar: 6-teri turi 3-teri turi',
    '👨🏿‍🐰‍👨🏽' => 'quyon quloqli erkaklar: 6-teri turi 4-teri turi',
    '👨🏿‍🐰‍👨🏾' => 'quyon quloqli erkaklar: 6-teri turi 5-teri turi',
    '👩🏻‍🫯‍👩🏼' => 'kurashayotgan ayol: 1–2-teri turi 3-teri turi',
    '👩🏻‍🫯‍👩🏽' => 'kurashayotgan ayol: 1–2-teri turi 4-teri turi',
    '👩🏻‍🫯‍👩🏾' => 'kurashayotgan ayol: 1–2-teri turi 5-teri turi',
    '👩🏻‍🫯‍👩🏿' => 'kurashayotgan ayol: 1–2-teri turi 6-teri turi',
    '👩🏼‍🫯‍👩🏻' => 'kurashayotgan ayol: 3-teri turi 1–2-teri turi',
    '👩🏼‍🫯‍👩🏽' => 'kurashayotgan ayol: 3-teri turi 4-teri turi',
    '👩🏼‍🫯‍👩🏾' => 'kurashayotgan ayol: 3-teri turi 5-teri turi',
    '👩🏼‍🫯‍👩🏿' => 'kurashayotgan ayol: 3-teri turi 6-teri turi',
    '👩🏽‍🫯‍👩🏻' => 'kurashayotgan ayol: 4-teri turi 1–2-teri turi',
    '👩🏽‍🫯‍👩🏼' => 'kurashayotgan ayol: 4-teri turi 3-teri turi',
    '👩🏽‍🫯‍👩🏾' => 'kurashayotgan ayol: 4-teri turi 5-teri turi',
    '👩🏽‍🫯‍👩🏿' => 'kurashayotgan ayol: 4-teri turi 6-teri turi',
    '👩🏾‍🫯‍👩🏻' => 'kurashayotgan ayol: 5-teri turi 1–2-teri turi',
    '👩🏾‍🫯‍👩🏼' => 'kurashayotgan ayol: 5-teri turi 3-teri turi',
    '👩🏾‍🫯‍👩🏽' => 'kurashayotgan ayol: 5-teri turi 4-teri turi',
    '👩🏾‍🫯‍👩🏿' => 'kurashayotgan ayol: 5-teri turi 6-teri turi',
    '👩🏿‍🫯‍👩🏻' => 'kurashayotgan ayol: 6-teri turi 1–2-teri turi',
    '👩🏿‍🫯‍👩🏼' => 'kurashayotgan ayol: 6-teri turi 3-teri turi',
    '👩🏿‍🫯‍👩🏽' => 'kurashayotgan ayol: 6-teri turi 4-teri turi',
    '👩🏿‍🫯‍👩🏾' => 'kurashayotgan ayol: 6-teri turi 5-teri turi',
    '👩🏻‍❤‍👨🏻' => 'juftlik va yurak: ayol erkak 1–2-teri turi',
    '👩🏻‍❤‍👨🏼' => 'juftlik va yurak: ayol erkak 1–2-teri turi 3-teri turi',
    '👩🏻‍❤‍👨🏽' => 'juftlik va yurak: ayol erkak 1–2-teri turi 4-teri turi',
    '👩🏻‍❤‍👨🏾' => 'juftlik va yurak: ayol erkak 1–2-teri turi 5-teri turi',
    '👩🏻‍❤‍👨🏿' => 'juftlik va yurak: ayol erkak 1–2-teri turi 6-teri turi',
    '👩🏼‍❤‍👨🏻' => 'juftlik va yurak: ayol erkak 3-teri turi 1–2-teri turi',
    '👩🏼‍❤‍👨🏼' => 'juftlik va yurak: ayol erkak 3-teri turi',
    '👩🏼‍❤‍👨🏽' => 'juftlik va yurak: ayol erkak 3-teri turi 4-teri turi',
    '👩🏼‍❤‍👨🏾' => 'juftlik va yurak: ayol erkak 3-teri turi 5-teri turi',
    '👩🏼‍❤‍👨🏿' => 'juftlik va yurak: ayol erkak 3-teri turi 6-teri turi',
    '👩🏽‍❤‍👨🏻' => 'juftlik va yurak: ayol erkak 4-teri turi 1–2-teri turi',
    '👩🏽‍❤‍👨🏼' => 'juftlik va yurak: ayol erkak 4-teri turi 3-teri turi',
    '👩🏽‍❤‍👨🏽' => 'juftlik va yurak: ayol erkak 4-teri turi',
    '👩🏽‍❤‍👨🏾' => 'juftlik va yurak: ayol erkak 4-teri turi 5-teri turi',
    '👩🏽‍❤‍👨🏿' => 'juftlik va yurak: ayol erkak 4-teri turi 6-teri turi',
    '👩🏾‍❤‍👨🏻' => 'juftlik va yurak: ayol erkak 5-teri turi 1–2-teri turi',
    '👩🏾‍❤‍👨🏼' => 'juftlik va yurak: ayol erkak 5-teri turi 3-teri turi',
    '👩🏾‍❤‍👨🏽' => 'juftlik va yurak: ayol erkak 5-teri turi 4-teri turi',
    '👩🏾‍❤‍👨🏾' => 'juftlik va yurak: ayol erkak 5-teri turi',
    '👩🏾‍❤‍👨🏿' => 'juftlik va yurak: ayol erkak 5-teri turi 6-teri turi',
    '👩🏿‍❤‍👨🏻' => 'juftlik va yurak: ayol erkak 6-teri turi 1–2-teri turi',
    '👩🏿‍❤‍👨🏼' => 'juftlik va yurak: ayol erkak 6-teri turi 3-teri turi',
    '👩🏿‍❤‍👨🏽' => 'juftlik va yurak: ayol erkak 6-teri turi 4-teri turi',
    '👩🏿‍❤‍👨🏾' => 'juftlik va yurak: ayol erkak 6-teri turi 5-teri turi',
    '👩🏿‍❤‍👨🏿' => 'juftlik va yurak: ayol erkak 6-teri turi',
    '👩🏻‍❤‍👩🏻' => 'juftlik va yurak: ayol ayol 1–2-teri turi',
    '👩🏻‍❤‍👩🏼' => 'juftlik va yurak: ayol ayol 1–2-teri turi 3-teri turi',
    '👩🏻‍❤‍👩🏽' => 'juftlik va yurak: ayol ayol 1–2-teri turi 4-teri turi',
    '👩🏻‍❤‍👩🏾' => 'juftlik va yurak: ayol ayol 1–2-teri turi 5-teri turi',
    '👩🏻‍❤‍👩🏿' => 'juftlik va yurak: ayol ayol 1–2-teri turi 6-teri turi',
    '👩🏼‍❤‍👩🏻' => 'juftlik va yurak: ayol ayol 3-teri turi 1–2-teri turi',
    '👩🏼‍❤‍👩🏼' => 'juftlik va yurak: ayol ayol 3-teri turi',
    '👩🏼‍❤‍👩🏽' => 'juftlik va yurak: ayol ayol 3-teri turi 4-teri turi',
    '👩🏼‍❤‍👩🏾' => 'juftlik va yurak: ayol ayol 3-teri turi 5-teri turi',
    '👩🏼‍❤‍👩🏿' => 'juftlik va yurak: ayol ayol 3-teri turi 6-teri turi',
    '👩🏽‍❤‍👩🏻' => 'juftlik va yurak: ayol ayol 4-teri turi 1–2-teri turi',
    '👩🏽‍❤‍👩🏼' => 'juftlik va yurak: ayol ayol 4-teri turi 3-teri turi',
    '👩🏽‍❤‍👩🏽' => 'juftlik va yurak: ayol ayol 4-teri turi',
    '👩🏽‍❤‍👩🏾' => 'juftlik va yurak: ayol ayol 4-teri turi 5-teri turi',
    '👩🏽‍❤‍👩🏿' => 'juftlik va yurak: ayol ayol 4-teri turi 6-teri turi',
    '👩🏾‍❤‍👩🏻' => 'juftlik va yurak: ayol ayol 5-teri turi 1–2-teri turi',
    '👩🏾‍❤‍👩🏼' => 'juftlik va yurak: ayol ayol 5-teri turi 3-teri turi',
    '👩🏾‍❤‍👩🏽' => 'juftlik va yurak: ayol ayol 5-teri turi 4-teri turi',
    '👩🏾‍❤‍👩🏾' => 'juftlik va yurak: ayol ayol 5-teri turi',
    '👩🏾‍❤‍👩🏿' => 'juftlik va yurak: ayol ayol 5-teri turi 6-teri turi',
    '👩🏿‍❤‍👩🏻' => 'juftlik va yurak: ayol ayol 6-teri turi 1–2-teri turi',
    '👩🏿‍❤‍👩🏼' => 'juftlik va yurak: ayol ayol 6-teri turi 3-teri turi',
    '👩🏿‍❤‍👩🏽' => 'juftlik va yurak: ayol ayol 6-teri turi 4-teri turi',
    '👩🏿‍❤‍👩🏾' => 'juftlik va yurak: ayol ayol 6-teri turi 5-teri turi',
    '👩🏿‍❤‍👩🏿' => 'juftlik va yurak: ayol ayol 6-teri turi',
    '👩🏻‍🐰‍👩🏼' => 'quyon quloqli ayollar: 1–2-teri turi 3-teri turi',
    '👩🏻‍🐰‍👩🏽' => 'quyon quloqli ayollar: 1–2-teri turi 4-teri turi',
    '👩🏻‍🐰‍👩🏾' => 'quyon quloqli ayollar: 1–2-teri turi 5-teri turi',
    '👩🏻‍🐰‍👩🏿' => 'quyon quloqli ayollar: 1–2-teri turi 6-teri turi',
    '👩🏼‍🐰‍👩🏻' => 'quyon quloqli ayollar: 3-teri turi 1–2-teri turi',
    '👩🏼‍🐰‍👩🏽' => 'quyon quloqli ayollar: 3-teri turi 4-teri turi',
    '👩🏼‍🐰‍👩🏾' => 'quyon quloqli ayollar: 3-teri turi 5-teri turi',
    '👩🏼‍🐰‍👩🏿' => 'quyon quloqli ayollar: 3-teri turi 6-teri turi',
    '👩🏽‍🐰‍👩🏻' => 'quyon quloqli ayollar: 4-teri turi 1–2-teri turi',
    '👩🏽‍🐰‍👩🏼' => 'quyon quloqli ayollar: 4-teri turi 3-teri turi',
    '👩🏽‍🐰‍👩🏾' => 'quyon quloqli ayollar: 4-teri turi 5-teri turi',
    '👩🏽‍🐰‍👩🏿' => 'quyon quloqli ayollar: 4-teri turi 6-teri turi',
    '👩🏾‍🐰‍👩🏻' => 'quyon quloqli ayollar: 5-teri turi 1–2-teri turi',
    '👩🏾‍🐰‍👩🏼' => 'quyon quloqli ayollar: 5-teri turi 3-teri turi',
    '👩🏾‍🐰‍👩🏽' => 'quyon quloqli ayollar: 5-teri turi 4-teri turi',
    '👩🏾‍🐰‍👩🏿' => 'quyon quloqli ayollar: 5-teri turi 6-teri turi',
    '👩🏿‍🐰‍👩🏻' => 'quyon quloqli ayollar: 6-teri turi 1–2-teri turi',
    '👩🏿‍🐰‍👩🏼' => 'quyon quloqli ayollar: 6-teri turi 3-teri turi',
    '👩🏿‍🐰‍👩🏽' => 'quyon quloqli ayollar: 6-teri turi 4-teri turi',
    '👩🏿‍🐰‍👩🏾' => 'quyon quloqli ayollar: 6-teri turi 5-teri turi',
    '🧑🏻‍🤝‍🧑🏻' => 'qoʻl ushlashib turgan odamlar: 1–2-teri turi',
    '🧑🏻‍🤝‍🧑🏼' => 'qoʻl ushlashib turgan odamlar: 1–2-teri turi 3-teri turi',
    '🧑🏻‍🤝‍🧑🏽' => 'qoʻl ushlashib turgan odamlar: 1–2-teri turi 4-teri turi',
    '🧑🏻‍🤝‍🧑🏾' => 'qoʻl ushlashib turgan odamlar: 1–2-teri turi 5-teri turi',
    '🧑🏻‍🤝‍🧑🏿' => 'qoʻl ushlashib turgan odamlar: 1–2-teri turi 6-teri turi',
    '🧑🏼‍🤝‍🧑🏻' => 'qoʻl ushlashib turgan odamlar: 3-teri turi 1–2-teri turi',
    '🧑🏼‍🤝‍🧑🏼' => 'qoʻl ushlashib turgan odamlar: 3-teri turi',
    '🧑🏼‍🤝‍🧑🏽' => 'qoʻl ushlashib turgan odamlar: 3-teri turi 4-teri turi',
    '🧑🏼‍🤝‍🧑🏾' => 'qoʻl ushlashib turgan odamlar: 3-teri turi 5-teri turi',
    '🧑🏼‍🤝‍🧑🏿' => 'qoʻl ushlashib turgan odamlar: 3-teri turi 6-teri turi',
    '🧑🏽‍🤝‍🧑🏻' => 'qoʻl ushlashib turgan odamlar: 4-teri turi 1–2-teri turi',
    '🧑🏽‍🤝‍🧑🏼' => 'qoʻl ushlashib turgan odamlar: 4-teri turi 3-teri turi',
    '🧑🏽‍🤝‍🧑🏽' => 'qoʻl ushlashib turgan odamlar: 4-teri turi',
    '🧑🏽‍🤝‍🧑🏾' => 'qoʻl ushlashib turgan odamlar: 4-teri turi 5-teri turi',
    '🧑🏽‍🤝‍🧑🏿' => 'qoʻl ushlashib turgan odamlar: 4-teri turi 6-teri turi',
    '🧑🏾‍🤝‍🧑🏻' => 'qoʻl ushlashib turgan odamlar: 5-teri turi 1–2-teri turi',
    '🧑🏾‍🤝‍🧑🏼' => 'qoʻl ushlashib turgan odamlar: 5-teri turi 3-teri turi',
    '🧑🏾‍🤝‍🧑🏽' => 'qoʻl ushlashib turgan odamlar: 5-teri turi 4-teri turi',
    '🧑🏾‍🤝‍🧑🏾' => 'qoʻl ushlashib turgan odamlar: 5-teri turi',
    '🧑🏾‍🤝‍🧑🏿' => 'qoʻl ushlashib turgan odamlar: 5-teri turi 6-teri turi',
    '🧑🏿‍🤝‍🧑🏻' => 'qoʻl ushlashib turgan odamlar: 6-teri turi 1–2-teri turi',
    '🧑🏿‍🤝‍🧑🏼' => 'qoʻl ushlashib turgan odamlar: 6-teri turi 3-teri turi',
    '🧑🏿‍🤝‍🧑🏽' => 'qoʻl ushlashib turgan odamlar: 6-teri turi 4-teri turi',
    '🧑🏿‍🤝‍🧑🏾' => 'qoʻl ushlashib turgan odamlar: 6-teri turi 5-teri turi',
    '🧑🏿‍🤝‍🧑🏿' => 'qoʻl ushlashib turgan odamlar: 6-teri turi',
    '👩🏻‍🤝‍👩🏼' => 'qoʻl ushlashgan ayollar: 1–2-teri turi 3-teri turi',
    '👩🏻‍🤝‍👩🏽' => 'qoʻl ushlashgan ayollar: 1–2-teri turi 4-teri turi',
    '👩🏻‍🤝‍👩🏾' => 'qoʻl ushlashgan ayollar: 1–2-teri turi 5-teri turi',
    '👩🏻‍🤝‍👩🏿' => 'qoʻl ushlashgan ayollar: 1–2-teri turi 6-teri turi',
    '👩🏼‍🤝‍👩🏻' => 'qoʻl ushlashgan ayollar: 3-teri turi 1–2-teri turi',
    '👩🏼‍🤝‍👩🏽' => 'qoʻl ushlashgan ayollar: 3-teri turi 4-teri turi',
    '👩🏼‍🤝‍👩🏾' => 'qoʻl ushlashgan ayollar: 3-teri turi 5-teri turi',
    '👩🏼‍🤝‍👩🏿' => 'qoʻl ushlashgan ayollar: 3-teri turi 6-teri turi',
    '👩🏽‍🤝‍👩🏻' => 'qoʻl ushlashgan ayollar: 4-teri turi 1–2-teri turi',
    '👩🏽‍🤝‍👩🏼' => 'qoʻl ushlashgan ayollar: 4-teri turi 3-teri turi',
    '👩🏽‍🤝‍👩🏾' => 'qoʻl ushlashgan ayollar: 4-teri turi 5-teri turi',
    '👩🏽‍🤝‍👩🏿' => 'qoʻl ushlashgan ayollar: 4-teri turi 6-teri turi',
    '👩🏾‍🤝‍👩🏻' => 'qoʻl ushlashgan ayollar: 5-teri turi 1–2-teri turi',
    '👩🏾‍🤝‍👩🏼' => 'qoʻl ushlashgan ayollar: 5-teri turi 3-teri turi',
    '👩🏾‍🤝‍👩🏽' => 'qoʻl ushlashgan ayollar: 5-teri turi 4-teri turi',
    '👩🏾‍🤝‍👩🏿' => 'qoʻl ushlashgan ayollar: 5-teri turi 6-teri turi',
    '👩🏿‍🤝‍👩🏻' => 'qoʻl ushlashgan ayollar: 6-teri turi 1–2-teri turi',
    '👩🏿‍🤝‍👩🏼' => 'qoʻl ushlashgan ayollar: 6-teri turi 3-teri turi',
    '👩🏿‍🤝‍👩🏽' => 'qoʻl ushlashgan ayollar: 6-teri turi 4-teri turi',
    '👩🏿‍🤝‍👩🏾' => 'qoʻl ushlashgan ayollar: 6-teri turi 5-teri turi',
    '👩🏻‍🤝‍👨🏼' => 'qoʻl ushlashgan ayol va erkak: 1–2-teri turi 3-teri turi',
    '👩🏻‍🤝‍👨🏽' => 'qoʻl ushlashgan ayol va erkak: 1–2-teri turi 4-teri turi',
    '👩🏻‍🤝‍👨🏾' => 'qoʻl ushlashgan ayol va erkak: 1–2-teri turi 5-teri turi',
    '👩🏻‍🤝‍👨🏿' => 'qoʻl ushlashgan ayol va erkak: 1–2-teri turi 6-teri turi',
    '👩🏼‍🤝‍👨🏻' => 'qoʻl ushlashgan ayol va erkak: 3-teri turi 1–2-teri turi',
    '👩🏼‍🤝‍👨🏽' => 'qoʻl ushlashgan ayol va erkak: 3-teri turi 4-teri turi',
    '👩🏼‍🤝‍👨🏾' => 'qoʻl ushlashgan ayol va erkak: 3-teri turi 5-teri turi',
    '👩🏼‍🤝‍👨🏿' => 'qoʻl ushlashgan ayol va erkak: 3-teri turi 6-teri turi',
    '👩🏽‍🤝‍👨🏻' => 'qoʻl ushlashgan ayol va erkak: 4-teri turi 1–2-teri turi',
    '👩🏽‍🤝‍👨🏼' => 'qoʻl ushlashgan ayol va erkak: 4-teri turi 3-teri turi',
    '👩🏽‍🤝‍👨🏾' => 'qoʻl ushlashgan ayol va erkak: 4-teri turi 5-teri turi',
    '👩🏽‍🤝‍👨🏿' => 'qoʻl ushlashgan ayol va erkak: 4-teri turi 6-teri turi',
    '👩🏾‍🤝‍👨🏻' => 'qoʻl ushlashgan ayol va erkak: 5-teri turi 1–2-teri turi',
    '👩🏾‍🤝‍👨🏼' => 'qoʻl ushlashgan ayol va erkak: 5-teri turi 3-teri turi',
    '👩🏾‍🤝‍👨🏽' => 'qoʻl ushlashgan ayol va erkak: 5-teri turi 4-teri turi',
    '👩🏾‍🤝‍👨🏿' => 'qoʻl ushlashgan ayol va erkak: 5-teri turi 6-teri turi',
    '👩🏿‍🤝‍👨🏻' => 'qoʻl ushlashgan ayol va erkak: 6-teri turi 1–2-teri turi',
    '👩🏿‍🤝‍👨🏼' => 'qoʻl ushlashgan ayol va erkak: 6-teri turi 3-teri turi',
    '👩🏿‍🤝‍👨🏽' => 'qoʻl ushlashgan ayol va erkak: 6-teri turi 4-teri turi',
    '👩🏿‍🤝‍👨🏾' => 'qoʻl ushlashgan ayol va erkak: 6-teri turi 5-teri turi',
    '👨🏻‍🤝‍👨🏼' => 'qoʻl ushlashgan erkaklar: 1–2-teri turi 3-teri turi',
    '👨🏻‍🤝‍👨🏽' => 'qoʻl ushlashgan erkaklar: 1–2-teri turi 4-teri turi',
    '👨🏻‍🤝‍👨🏾' => 'qoʻl ushlashgan erkaklar: 1–2-teri turi 5-teri turi',
    '👨🏻‍🤝‍👨🏿' => 'qoʻl ushlashgan erkaklar: 1–2-teri turi 6-teri turi',
    '👨🏼‍🤝‍👨🏻' => 'qoʻl ushlashgan erkaklar: 3-teri turi 1–2-teri turi',
    '👨🏼‍🤝‍👨🏽' => 'qoʻl ushlashgan erkaklar: 3-teri turi 4-teri turi',
    '👨🏼‍🤝‍👨🏾' => 'qoʻl ushlashgan erkaklar: 3-teri turi 5-teri turi',
    '👨🏼‍🤝‍👨🏿' => 'qoʻl ushlashgan erkaklar: 3-teri turi 6-teri turi',
    '👨🏽‍🤝‍👨🏻' => 'qoʻl ushlashgan erkaklar: 4-teri turi 1–2-teri turi',
    '👨🏽‍🤝‍👨🏼' => 'qoʻl ushlashgan erkaklar: 4-teri turi 3-teri turi',
    '👨🏽‍🤝‍👨🏾' => 'qoʻl ushlashgan erkaklar: 4-teri turi 5-teri turi',
    '👨🏽‍🤝‍👨🏿' => 'qoʻl ushlashgan erkaklar: 4-teri turi 6-teri turi',
    '👨🏾‍🤝‍👨🏻' => 'qoʻl ushlashgan erkaklar: 5-teri turi 1–2-teri turi',
    '👨🏾‍🤝‍👨🏼' => 'qoʻl ushlashgan erkaklar: 5-teri turi 3-teri turi',
    '👨🏾‍🤝‍👨🏽' => 'qoʻl ushlashgan erkaklar: 5-teri turi 4-teri turi',
    '👨🏾‍🤝‍👨🏿' => 'qoʻl ushlashgan erkaklar: 5-teri turi 6-teri turi',
    '👨🏿‍🤝‍👨🏻' => 'qoʻl ushlashgan erkaklar: 6-teri turi 1–2-teri turi',
    '👨🏿‍🤝‍👨🏼' => 'qoʻl ushlashgan erkaklar: 6-teri turi 3-teri turi',
    '👨🏿‍🤝‍👨🏽' => 'qoʻl ushlashgan erkaklar: 6-teri turi 4-teri turi',
    '👨🏿‍🤝‍👨🏾' => 'qoʻl ushlashgan erkaklar: 6-teri turi 5-teri turi',
    '👩‍❤‍💋‍👨' => 'bo‘sa olish: ayol erkak',
    '👨‍❤‍💋‍👨' => 'bo‘sa olish: erkak erkak',
    '👩‍❤‍💋‍👩' => 'bo‘sa olish: ayol ayol',
    '👨‍👩‍👧‍👦' => 'oila: erkak ayol qiz bola o‘g‘il bola',
    '👨‍👩‍👦‍👦' => 'oila: erkak ayol o‘g‘il bola o‘g‘il bola',
    '👨‍👩‍👧‍👧' => 'oila: erkak ayol qiz bola qiz bola',
    '👨‍👨‍👧‍👦' => 'oila: erkak erkak qiz bola o‘g‘il bola',
    '👨‍👨‍👦‍👦' => 'oila: erkak erkak o‘g‘il bola o‘g‘il bola',
    '👨‍👨‍👧‍👧' => 'oila: erkak erkak qiz bola qiz bola',
    '👩‍👩‍👧‍👦' => 'oila: ayol ayol qiz bola o‘g‘il bola',
    '👩‍👩‍👦‍👦' => 'oila: ayol ayol o‘g‘il bola o‘g‘il bola',
    '👩‍👩‍👧‍👧' => 'oila: ayol ayol qiz bola qiz bola',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'bayroq: Angliya',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'bayroq: Shotlandiya',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'bayroq: Uels',
    '🧑‍🧑‍🧒‍🧒' => 'oila: ikkita kattalar, ikkita bola',
    '🚶🏻‍♀‍➡' => 'yurayotgan ayol: 1–2-teri turi o‘ngga qaragan',
    '🚶🏼‍♀‍➡' => 'yurayotgan ayol: 3-teri turi o‘ngga qaragan',
    '🚶🏽‍♀‍➡' => 'yurayotgan ayol: 4-teri turi o‘ngga qaragan',
    '🚶🏾‍♀‍➡' => 'yurayotgan ayol: 5-teri turi o‘ngga qaragan',
    '🚶🏿‍♀‍➡' => 'yurayotgan ayol: 6-teri turi o‘ngga qaragan',
    '🚶🏻‍♂‍➡' => 'yurayotgan erkak: 1–2-teri turi o‘ngga qaragan',
    '🚶🏼‍♂‍➡' => 'yurayotgan erkak: 3-teri turi o‘ngga qaragan',
    '🚶🏽‍♂‍➡' => 'yurayotgan erkak: 4-teri turi o‘ngga qaragan',
    '🚶🏾‍♂‍➡' => 'yurayotgan erkak: 5-teri turi o‘ngga qaragan',
    '🚶🏿‍♂‍➡' => 'yurayotgan erkak: 6-teri turi o‘ngga qaragan',
    '🧎🏻‍♀‍➡' => 'tiz choʻkkan ayol: 1–2-teri turi o‘ngga qaragan',
    '🧎🏼‍♀‍➡' => 'tiz choʻkkan ayol: 3-teri turi o‘ngga qaragan',
    '🧎🏽‍♀‍➡' => 'tiz choʻkkan ayol: 4-teri turi o‘ngga qaragan',
    '🧎🏾‍♀‍➡' => 'tiz choʻkkan ayol: 5-teri turi o‘ngga qaragan',
    '🧎🏿‍♀‍➡' => 'tiz choʻkkan ayol: 6-teri turi o‘ngga qaragan',
    '🧎🏻‍♂‍➡' => 'tiz choʻkkan erkak: 1–2-teri turi o‘ngga qaragan',
    '🧎🏼‍♂‍➡' => 'tiz choʻkkan erkak: 3-teri turi o‘ngga qaragan',
    '🧎🏽‍♂‍➡' => 'tiz choʻkkan erkak: 4-teri turi o‘ngga qaragan',
    '🧎🏾‍♂‍➡' => 'tiz choʻkkan erkak: 5-teri turi o‘ngga qaragan',
    '🧎🏿‍♂‍➡' => 'tiz choʻkkan erkak: 6-teri turi o‘ngga qaragan',
    '🧑🏻‍🦯‍➡' => 'hassali odam: 1–2-teri turi o‘ngga qaragan',
    '🧑🏼‍🦯‍➡' => 'hassali odam: 3-teri turi o‘ngga qaragan',
    '🧑🏽‍🦯‍➡' => 'hassali odam: 4-teri turi o‘ngga qaragan',
    '🧑🏾‍🦯‍➡' => 'hassali odam: 5-teri turi o‘ngga qaragan',
    '🧑🏿‍🦯‍➡' => 'hassali odam: 6-teri turi o‘ngga qaragan',
    '👨🏻‍🦯‍➡' => 'hassali kishi: 1–2-teri turi o‘ngga qaragan',
    '👨🏼‍🦯‍➡' => 'hassali kishi: 3-teri turi o‘ngga qaragan',
    '👨🏽‍🦯‍➡' => 'hassali kishi: 4-teri turi o‘ngga qaragan',
    '👨🏾‍🦯‍➡' => 'hassali kishi: 5-teri turi o‘ngga qaragan',
    '👨🏿‍🦯‍➡' => 'hassali kishi: 6-teri turi o‘ngga qaragan',
    '👩🏻‍🦯‍➡' => 'hassali ayol: 1–2-teri turi o‘ngga qaragan',
    '👩🏼‍🦯‍➡' => 'hassali ayol: 3-teri turi o‘ngga qaragan',
    '👩🏽‍🦯‍➡' => 'hassali ayol: 4-teri turi o‘ngga qaragan',
    '👩🏾‍🦯‍➡' => 'hassali ayol: 5-teri turi o‘ngga qaragan',
    '👩🏿‍🦯‍➡' => 'hassali ayol: 6-teri turi o‘ngga qaragan',
    '🧑🏻‍🦼‍➡' => 'motorli nogironlar aravachasidagi odam: 1–2-teri turi o‘ngga qaragan',
    '🧑🏼‍🦼‍➡' => 'motorli nogironlar aravachasidagi odam: 3-teri turi o‘ngga qaragan',
    '🧑🏽‍🦼‍➡' => 'motorli nogironlar aravachasidagi odam: 4-teri turi o‘ngga qaragan',
    '🧑🏾‍🦼‍➡' => 'motorli nogironlar aravachasidagi odam: 5-teri turi o‘ngga qaragan',
    '🧑🏿‍🦼‍➡' => 'motorli nogironlar aravachasidagi odam: 6-teri turi o‘ngga qaragan',
    '👨🏻‍🦼‍➡' => 'motorli nogironlik aravachasidagi erkak: 1–2-teri turi o‘ngga qaragan',
    '👨🏼‍🦼‍➡' => 'motorli nogironlik aravachasidagi erkak: 3-teri turi o‘ngga qaragan',
    '👨🏽‍🦼‍➡' => 'motorli nogironlik aravachasidagi erkak: 4-teri turi o‘ngga qaragan',
    '👨🏾‍🦼‍➡' => 'motorli nogironlik aravachasidagi erkak: 5-teri turi o‘ngga qaragan',
    '👨🏿‍🦼‍➡' => 'motorli nogironlik aravachasidagi erkak: 6-teri turi o‘ngga qaragan',
    '👩🏻‍🦼‍➡' => 'motorli nogironlik aravachasidagi ayol: 1–2-teri turi o‘ngga qaragan',
    '👩🏼‍🦼‍➡' => 'motorli nogironlik aravachasidagi ayol: 3-teri turi o‘ngga qaragan',
    '👩🏽‍🦼‍➡' => 'motorli nogironlik aravachasidagi ayol: 4-teri turi o‘ngga qaragan',
    '👩🏾‍🦼‍➡' => 'motorli nogironlik aravachasidagi ayol: 5-teri turi o‘ngga qaragan',
    '👩🏿‍🦼‍➡' => 'motorli nogironlik aravachasidagi ayol: 6-teri turi o‘ngga qaragan',
    '🧑🏻‍🦽‍➡' => 'nogironlar aravachasidagi odam: 1–2-teri turi o‘ngga qaragan',
    '🧑🏼‍🦽‍➡' => 'nogironlar aravachasidagi odam: 3-teri turi o‘ngga qaragan',
    '🧑🏽‍🦽‍➡' => 'nogironlar aravachasidagi odam: 4-teri turi o‘ngga qaragan',
    '🧑🏾‍🦽‍➡' => 'nogironlar aravachasidagi odam: 5-teri turi o‘ngga qaragan',
    '🧑🏿‍🦽‍➡' => 'nogironlar aravachasidagi odam: 6-teri turi o‘ngga qaragan',
    '👨🏻‍🦽‍➡' => 'nogironlik aravachasidagi erkak: 1–2-teri turi o‘ngga qaragan',
    '👨🏼‍🦽‍➡' => 'nogironlik aravachasidagi erkak: 3-teri turi o‘ngga qaragan',
    '👨🏽‍🦽‍➡' => 'nogironlik aravachasidagi erkak: 4-teri turi o‘ngga qaragan',
    '👨🏾‍🦽‍➡' => 'nogironlik aravachasidagi erkak: 5-teri turi o‘ngga qaragan',
    '👨🏿‍🦽‍➡' => 'nogironlik aravachasidagi erkak: 6-teri turi o‘ngga qaragan',
    '👩🏻‍🦽‍➡' => 'nogironlik aravachasidagi ayol: 1–2-teri turi o‘ngga qaragan',
    '👩🏼‍🦽‍➡' => 'nogironlik aravachasidagi ayol: 3-teri turi o‘ngga qaragan',
    '👩🏽‍🦽‍➡' => 'nogironlik aravachasidagi ayol: 4-teri turi o‘ngga qaragan',
    '👩🏾‍🦽‍➡' => 'nogironlik aravachasidagi ayol: 5-teri turi o‘ngga qaragan',
    '👩🏿‍🦽‍➡' => 'nogironlik aravachasidagi ayol: 6-teri turi o‘ngga qaragan',
    '🏃🏻‍♀‍➡' => 'yugurayotgan ayol: 1–2-teri turi o‘ngga qaragan',
    '🏃🏼‍♀‍➡' => 'yugurayotgan ayol: 3-teri turi o‘ngga qaragan',
    '🏃🏽‍♀‍➡' => 'yugurayotgan ayol: 4-teri turi o‘ngga qaragan',
    '🏃🏾‍♀‍➡' => 'yugurayotgan ayol: 5-teri turi o‘ngga qaragan',
    '🏃🏿‍♀‍➡' => 'yugurayotgan ayol: 6-teri turi o‘ngga qaragan',
    '🏃🏻‍♂‍➡' => 'yugurayotgan erkak: 1–2-teri turi o‘ngga qaragan',
    '🏃🏼‍♂‍➡' => 'yugurayotgan erkak: 3-teri turi o‘ngga qaragan',
    '🏃🏽‍♂‍➡' => 'yugurayotgan erkak: 4-teri turi o‘ngga qaragan',
    '🏃🏾‍♂‍➡' => 'yugurayotgan erkak: 5-teri turi o‘ngga qaragan',
    '🏃🏿‍♂‍➡' => 'yugurayotgan erkak: 6-teri turi o‘ngga qaragan',
    '🫱🏻‍🫲🏼' => 'qo‘l siqish: 1–2-teri turi 3-teri turi',
    '🫱🏻‍🫲🏽' => 'qo‘l siqish: 1–2-teri turi 4-teri turi',
    '🫱🏻‍🫲🏾' => 'qo‘l siqish: 1–2-teri turi 5-teri turi',
    '🫱🏻‍🫲🏿' => 'qo‘l siqish: 1–2-teri turi 6-teri turi',
    '🫱🏼‍🫲🏻' => 'qo‘l siqish: 3-teri turi 1–2-teri turi',
    '🫱🏼‍🫲🏽' => 'qo‘l siqish: 3-teri turi 4-teri turi',
    '🫱🏼‍🫲🏾' => 'qo‘l siqish: 3-teri turi 5-teri turi',
    '🫱🏼‍🫲🏿' => 'qo‘l siqish: 3-teri turi 6-teri turi',
    '🫱🏽‍🫲🏻' => 'qo‘l siqish: 4-teri turi 1–2-teri turi',
    '🫱🏽‍🫲🏼' => 'qo‘l siqish: 4-teri turi 3-teri turi',
    '🫱🏽‍🫲🏾' => 'qo‘l siqish: 4-teri turi 5-teri turi',
    '🫱🏽‍🫲🏿' => 'qo‘l siqish: 4-teri turi 6-teri turi',
    '🫱🏾‍🫲🏻' => 'qo‘l siqish: 5-teri turi 1–2-teri turi',
    '🫱🏾‍🫲🏼' => 'qo‘l siqish: 5-teri turi 3-teri turi',
    '🫱🏾‍🫲🏽' => 'qo‘l siqish: 5-teri turi 4-teri turi',
    '🫱🏾‍🫲🏿' => 'qo‘l siqish: 5-teri turi 6-teri turi',
    '🫱🏿‍🫲🏻' => 'qo‘l siqish: 6-teri turi 1–2-teri turi',
    '🫱🏿‍🫲🏼' => 'qo‘l siqish: 6-teri turi 3-teri turi',
    '🫱🏿‍🫲🏽' => 'qo‘l siqish: 6-teri turi 4-teri turi',
    '🫱🏿‍🫲🏾' => 'qo‘l siqish: 6-teri turi 5-teri turi',
    '🚶‍♀‍➡' => 'yurayotgan ayol: o‘ngga qaragan',
    '🚶‍♂‍➡' => 'yurayotgan erkak: o‘ngga qaragan',
    '🧎‍♀‍➡' => 'tiz choʻkkan ayol: o‘ngga qaragan',
    '🧎‍♂‍➡' => 'tiz choʻkkan erkak: o‘ngga qaragan',
    '🧑‍🦯‍➡' => 'hassali odam: o‘ngga qaragan',
    '👨‍🦯‍➡' => 'hassali kishi: o‘ngga qaragan',
    '👩‍🦯‍➡' => 'hassali ayol: o‘ngga qaragan',
    '🧑‍🦼‍➡' => 'motorli nogironlar aravachasidagi odam: o‘ngga qaragan',
    '👨‍🦼‍➡' => 'motorli nogironlik aravachasidagi erkak: o‘ngga qaragan',
    '👩‍🦼‍➡' => 'motorli nogironlik aravachasidagi ayol: o‘ngga qaragan',
    '🧑‍🦽‍➡' => 'nogironlar aravachasidagi odam: o‘ngga qaragan',
    '👨‍🦽‍➡' => 'nogironlik aravachasidagi erkak: o‘ngga qaragan',
    '👩‍🦽‍➡' => 'nogironlik aravachasidagi ayol: o‘ngga qaragan',
    '🏃‍♀‍➡' => 'yugurayotgan ayol: o‘ngga qaragan',
    '🏃‍♂‍➡' => 'yugurayotgan erkak: o‘ngga qaragan',
    '👩‍❤‍👨' => 'juftlik va yurak: ayol erkak',
    '👨‍❤‍👨' => 'juftlik va yurak: erkak erkak',
    '👩‍❤‍👩' => 'juftlik va yurak: ayol ayol',
    '👨‍👩‍👦' => 'oila: erkak ayol o‘g‘il bola',
    '👨‍👩‍👧' => 'oila: erkak ayol qiz bola',
    '👨‍👨‍👦' => 'oila: erkak erkak o‘g‘il bola',
    '👨‍👨‍👧' => 'oila: erkak erkak qiz bola',
    '👩‍👩‍👦' => 'oila: ayol ayol o‘g‘il bola',
    '👩‍👩‍👧' => 'oila: ayol ayol qiz bola',
    '👨‍👦‍👦' => 'oila: erkak o‘g‘il bola o‘g‘il bola',
    '👨‍👧‍👦' => 'oila: erkak qiz bola o‘g‘il bola',
    '👨‍👧‍👧' => 'oila: erkak qiz bola qiz bola',
    '👩‍👦‍👦' => 'oila: ayol o‘g‘il bola o‘g‘il bola',
    '👩‍👧‍👦' => 'oila: ayol qiz bola o‘g‘il bola',
    '👩‍👧‍👧' => 'oila: ayol qiz bola qiz bola',
    '🧑‍🤝‍🧑' => 'qoʻl ushlashib turgan odamlar',
    '🧑‍🧑‍🧒' => 'oila: ikkita kattalar, bola',
    '🧑‍🧒‍🧒' => 'oila: bitta katta odam, ikki bola',
    '🧑🏻‍🦰' => 'voyaga yetgan: 1–2-teri turi malla soch',
    '🧑🏼‍🦰' => 'voyaga yetgan: 3-teri turi malla soch',
    '🧑🏽‍🦰' => 'voyaga yetgan: 4-teri turi malla soch',
    '🧑🏾‍🦰' => 'voyaga yetgan: 5-teri turi malla soch',
    '🧑🏿‍🦰' => 'voyaga yetgan: 6-teri turi malla soch',
    '🧑🏻‍🦱' => 'voyaga yetgan: 1–2-teri turi jingalak soch',
    '🧑🏼‍🦱' => 'voyaga yetgan: 3-teri turi jingalak soch',
    '🧑🏽‍🦱' => 'voyaga yetgan: 4-teri turi jingalak soch',
    '🧑🏾‍🦱' => 'voyaga yetgan: 5-teri turi jingalak soch',
    '🧑🏿‍🦱' => 'voyaga yetgan: 6-teri turi jingalak soch',
    '🧑🏻‍🦳' => 'voyaga yetgan: 1–2-teri turi oqargan soch',
    '🧑🏼‍🦳' => 'voyaga yetgan: 3-teri turi oqargan soch',
    '🧑🏽‍🦳' => 'voyaga yetgan: 4-teri turi oqargan soch',
    '🧑🏾‍🦳' => 'voyaga yetgan: 5-teri turi oqargan soch',
    '🧑🏿‍🦳' => 'voyaga yetgan: 6-teri turi oqargan soch',
    '🧑🏻‍🦲' => 'voyaga yetgan: 1–2-teri turi kal',
    '🧑🏼‍🦲' => 'voyaga yetgan: 3-teri turi kal',
    '🧑🏽‍🦲' => 'voyaga yetgan: 4-teri turi kal',
    '🧑🏾‍🦲' => 'voyaga yetgan: 5-teri turi kal',
    '🧑🏿‍🦲' => 'voyaga yetgan: 6-teri turi kal',
    '🧑🏻‍🩰' => 'baletchi: 1–2-teri turi',
    '🧑🏼‍🩰' => 'baletchi: 3-teri turi',
    '🧑🏽‍🩰' => 'baletchi: 4-teri turi',
    '🧑🏾‍🩰' => 'baletchi: 5-teri turi',
    '🧑🏿‍🩰' => 'baletchi: 6-teri turi',
    '🧔🏻‍♂' => 'soqolli erkak: 1–2-teri turi',
    '🧔🏼‍♂' => 'soqolli erkak: 3-teri turi',
    '🧔🏽‍♂' => 'soqolli erkak: 4-teri turi',
    '🧔🏾‍♂' => 'soqolli erkak: 5-teri turi',
    '🧔🏿‍♂' => 'soqolli erkak: 6-teri turi',
    '👱🏻‍♂' => 'erkak: 1–2-teri turi mallasoch',
    '👱🏼‍♂' => 'erkak: 3-teri turi mallasoch',
    '👱🏽‍♂' => 'erkak: 4-teri turi mallasoch',
    '👱🏾‍♂' => 'erkak: 5-teri turi mallasoch',
    '👱🏿‍♂' => 'erkak: 6-teri turi mallasoch',
    '👨🏻‍🦰' => 'erkak: 1–2-teri turi malla soch',
    '👨🏼‍🦰' => 'erkak: 3-teri turi malla soch',
    '👨🏽‍🦰' => 'erkak: 4-teri turi malla soch',
    '👨🏾‍🦰' => 'erkak: 5-teri turi malla soch',
    '👨🏿‍🦰' => 'erkak: 6-teri turi malla soch',
    '👨🏻‍🦱' => 'erkak: 1–2-teri turi jingalak soch',
    '👨🏼‍🦱' => 'erkak: 3-teri turi jingalak soch',
    '👨🏽‍🦱' => 'erkak: 4-teri turi jingalak soch',
    '👨🏾‍🦱' => 'erkak: 5-teri turi jingalak soch',
    '👨🏿‍🦱' => 'erkak: 6-teri turi jingalak soch',
    '👨🏻‍🦳' => 'erkak: 1–2-teri turi oqargan soch',
    '👨🏼‍🦳' => 'erkak: 3-teri turi oqargan soch',
    '👨🏽‍🦳' => 'erkak: 4-teri turi oqargan soch',
    '👨🏾‍🦳' => 'erkak: 5-teri turi oqargan soch',
    '👨🏿‍🦳' => 'erkak: 6-teri turi oqargan soch',
    '👨🏻‍🦲' => 'erkak: 1–2-teri turi kal',
    '👨🏼‍🦲' => 'erkak: 3-teri turi kal',
    '👨🏽‍🦲' => 'erkak: 4-teri turi kal',
    '👨🏾‍🦲' => 'erkak: 5-teri turi kal',
    '👨🏿‍🦲' => 'erkak: 6-teri turi kal',
    '🧔🏻‍♀' => 'soqolli ayol: 1–2-teri turi',
    '🧔🏼‍♀' => 'soqolli ayol: 3-teri turi',
    '🧔🏽‍♀' => 'soqolli ayol: 4-teri turi',
    '🧔🏾‍♀' => 'soqolli ayol: 5-teri turi',
    '🧔🏿‍♀' => 'soqolli ayol: 6-teri turi',
    '👱🏻‍♀' => 'ayol: 1–2-teri turi mallasoch',
    '👱🏼‍♀' => 'ayol: 3-teri turi mallasoch',
    '👱🏽‍♀' => 'ayol: 4-teri turi mallasoch',
    '👱🏾‍♀' => 'ayol: 5-teri turi mallasoch',
    '👱🏿‍♀' => 'ayol: 6-teri turi mallasoch',
    '👩🏻‍🦰' => 'ayol: 1–2-teri turi malla soch',
    '👩🏼‍🦰' => 'ayol: 3-teri turi malla soch',
    '👩🏽‍🦰' => 'ayol: 4-teri turi malla soch',
    '👩🏾‍🦰' => 'ayol: 5-teri turi malla soch',
    '👩🏿‍🦰' => 'ayol: 6-teri turi malla soch',
    '👩🏻‍🦱' => 'ayol: 1–2-teri turi jingalak soch',
    '👩🏼‍🦱' => 'ayol: 3-teri turi jingalak soch',
    '👩🏽‍🦱' => 'ayol: 4-teri turi jingalak soch',
    '👩🏾‍🦱' => 'ayol: 5-teri turi jingalak soch',
    '👩🏿‍🦱' => 'ayol: 6-teri turi jingalak soch',
    '👩🏻‍🦳' => 'ayol: 1–2-teri turi oqargan soch',
    '👩🏼‍🦳' => 'ayol: 3-teri turi oqargan soch',
    '👩🏽‍🦳' => 'ayol: 4-teri turi oqargan soch',
    '👩🏾‍🦳' => 'ayol: 5-teri turi oqargan soch',
    '👩🏿‍🦳' => 'ayol: 6-teri turi oqargan soch',
    '👩🏻‍🦲' => 'ayol: 1–2-teri turi kal',
    '👩🏼‍🦲' => 'ayol: 3-teri turi kal',
    '👩🏽‍🦲' => 'ayol: 4-teri turi kal',
    '👩🏾‍🦲' => 'ayol: 5-teri turi kal',
    '👩🏿‍🦲' => 'ayol: 6-teri turi kal',
    '🙍🏻‍♂' => 'xo‘mraygan erkak: 1–2-teri turi',
    '🙍🏼‍♂' => 'xo‘mraygan erkak: 3-teri turi',
    '🙍🏽‍♂' => 'xo‘mraygan erkak: 4-teri turi',
    '🙍🏾‍♂' => 'xo‘mraygan erkak: 5-teri turi',
    '🙍🏿‍♂' => 'xo‘mraygan erkak: 6-teri turi',
    '🙍🏻‍♀' => 'xo‘mraygan ayol: 1–2-teri turi',
    '🙍🏼‍♀' => 'xo‘mraygan ayol: 3-teri turi',
    '🙍🏽‍♀' => 'xo‘mraygan ayol: 4-teri turi',
    '🙍🏾‍♀' => 'xo‘mraygan ayol: 5-teri turi',
    '🙍🏿‍♀' => 'xo‘mraygan ayol: 6-teri turi',
    '🙎🏻‍♂' => 'arazlagan erkak: 1–2-teri turi',
    '🙎🏼‍♂' => 'arazlagan erkak: 3-teri turi',
    '🙎🏽‍♂' => 'arazlagan erkak: 4-teri turi',
    '🙎🏾‍♂' => 'arazlagan erkak: 5-teri turi',
    '🙎🏿‍♂' => 'arazlagan erkak: 6-teri turi',
    '🙎🏻‍♀' => 'arazlagan ayol: 1–2-teri turi',
    '🙎🏼‍♀' => 'arazlagan ayol: 3-teri turi',
    '🙎🏽‍♀' => 'arazlagan ayol: 4-teri turi',
    '🙎🏾‍♀' => 'arazlagan ayol: 5-teri turi',
    '🙎🏿‍♀' => 'arazlagan ayol: 6-teri turi',
    '🙅🏻‍♂' => 'erkak yo‘q demoqda: 1–2-teri turi',
    '🙅🏼‍♂' => 'erkak yo‘q demoqda: 3-teri turi',
    '🙅🏽‍♂' => 'erkak yo‘q demoqda: 4-teri turi',
    '🙅🏾‍♂' => 'erkak yo‘q demoqda: 5-teri turi',
    '🙅🏿‍♂' => 'erkak yo‘q demoqda: 6-teri turi',
    '🙅🏻‍♀' => 'ayol yo‘q demoqda: 1–2-teri turi',
    '🙅🏼‍♀' => 'ayol yo‘q demoqda: 3-teri turi',
    '🙅🏽‍♀' => 'ayol yo‘q demoqda: 4-teri turi',
    '🙅🏾‍♀' => 'ayol yo‘q demoqda: 5-teri turi',
    '🙅🏿‍♀' => 'ayol yo‘q demoqda: 6-teri turi',
    '🙆🏻‍♂' => 'erkak ha demoqda: 1–2-teri turi',
    '🙆🏼‍♂' => 'erkak ha demoqda: 3-teri turi',
    '🙆🏽‍♂' => 'erkak ha demoqda: 4-teri turi',
    '🙆🏾‍♂' => 'erkak ha demoqda: 5-teri turi',
    '🙆🏿‍♂' => 'erkak ha demoqda: 6-teri turi',
    '🙆🏻‍♀' => 'ayol ha demoqda: 1–2-teri turi',
    '🙆🏼‍♀' => 'ayol ha demoqda: 3-teri turi',
    '🙆🏽‍♀' => 'ayol ha demoqda: 4-teri turi',
    '🙆🏾‍♀' => 'ayol ha demoqda: 5-teri turi',
    '🙆🏿‍♀' => 'ayol ha demoqda: 6-teri turi',
    '💁🏻‍♂' => 'erkak qo‘l cho‘zmoqda: 1–2-teri turi',
    '💁🏼‍♂' => 'erkak qo‘l cho‘zmoqda: 3-teri turi',
    '💁🏽‍♂' => 'erkak qo‘l cho‘zmoqda: 4-teri turi',
    '💁🏾‍♂' => 'erkak qo‘l cho‘zmoqda: 5-teri turi',
    '💁🏿‍♂' => 'erkak qo‘l cho‘zmoqda: 6-teri turi',
    '💁🏻‍♀' => 'ayol qo‘l cho‘zmoqda: 1–2-teri turi',
    '💁🏼‍♀' => 'ayol qo‘l cho‘zmoqda: 3-teri turi',
    '💁🏽‍♀' => 'ayol qo‘l cho‘zmoqda: 4-teri turi',
    '💁🏾‍♀' => 'ayol qo‘l cho‘zmoqda: 5-teri turi',
    '💁🏿‍♀' => 'ayol qo‘l cho‘zmoqda: 6-teri turi',
    '🙋🏻‍♂' => 'erkak qo‘l ko‘tarmoqda: 1–2-teri turi',
    '🙋🏼‍♂' => 'erkak qo‘l ko‘tarmoqda: 3-teri turi',
    '🙋🏽‍♂' => 'erkak qo‘l ko‘tarmoqda: 4-teri turi',
    '🙋🏾‍♂' => 'erkak qo‘l ko‘tarmoqda: 5-teri turi',
    '🙋🏿‍♂' => 'erkak qo‘l ko‘tarmoqda: 6-teri turi',
    '🙋🏻‍♀' => 'ayol qo‘l ko‘tarmoqda: 1–2-teri turi',
    '🙋🏼‍♀' => 'ayol qo‘l ko‘tarmoqda: 3-teri turi',
    '🙋🏽‍♀' => 'ayol qo‘l ko‘tarmoqda: 4-teri turi',
    '🙋🏾‍♀' => 'ayol qo‘l ko‘tarmoqda: 5-teri turi',
    '🙋🏿‍♀' => 'ayol qo‘l ko‘tarmoqda: 6-teri turi',
    '🧏🏻‍♂' => 'kar erkak: 1–2-teri turi',
    '🧏🏼‍♂' => 'kar erkak: 3-teri turi',
    '🧏🏽‍♂' => 'kar erkak: 4-teri turi',
    '🧏🏾‍♂' => 'kar erkak: 5-teri turi',
    '🧏🏿‍♂' => 'kar erkak: 6-teri turi',
    '🧏🏻‍♀' => 'kar ayol: 1–2-teri turi',
    '🧏🏼‍♀' => 'kar ayol: 3-teri turi',
    '🧏🏽‍♀' => 'kar ayol: 4-teri turi',
    '🧏🏾‍♀' => 'kar ayol: 5-teri turi',
    '🧏🏿‍♀' => 'kar ayol: 6-teri turi',
    '🙇🏻‍♂' => 'erkak ta’zim qilmoqda: 1–2-teri turi',
    '🙇🏼‍♂' => 'erkak ta’zim qilmoqda: 3-teri turi',
    '🙇🏽‍♂' => 'erkak ta’zim qilmoqda: 4-teri turi',
    '🙇🏾‍♂' => 'erkak ta’zim qilmoqda: 5-teri turi',
    '🙇🏿‍♂' => 'erkak ta’zim qilmoqda: 6-teri turi',
    '🙇🏻‍♀' => 'ayol ta’zim qilmoqda: 1–2-teri turi',
    '🙇🏼‍♀' => 'ayol ta’zim qilmoqda: 3-teri turi',
    '🙇🏽‍♀' => 'ayol ta’zim qilmoqda: 4-teri turi',
    '🙇🏾‍♀' => 'ayol ta’zim qilmoqda: 5-teri turi',
    '🙇🏿‍♀' => 'ayol ta’zim qilmoqda: 6-teri turi',
    '🤦🏻‍♂' => 'erkak yuzini berkitmoqda: 1–2-teri turi',
    '🤦🏼‍♂' => 'erkak yuzini berkitmoqda: 3-teri turi',
    '🤦🏽‍♂' => 'erkak yuzini berkitmoqda: 4-teri turi',
    '🤦🏾‍♂' => 'erkak yuzini berkitmoqda: 5-teri turi',
    '🤦🏿‍♂' => 'erkak yuzini berkitmoqda: 6-teri turi',
    '🤦🏻‍♀' => 'ayol yuzini berkitmoqda: 1–2-teri turi',
    '🤦🏼‍♀' => 'ayol yuzini berkitmoqda: 3-teri turi',
    '🤦🏽‍♀' => 'ayol yuzini berkitmoqda: 4-teri turi',
    '🤦🏾‍♀' => 'ayol yuzini berkitmoqda: 5-teri turi',
    '🤦🏿‍♀' => 'ayol yuzini berkitmoqda: 6-teri turi',
    '🤷🏻‍♂' => 'erkak yelka qismoqda: 1–2-teri turi',
    '🤷🏼‍♂' => 'erkak yelka qismoqda: 3-teri turi',
    '🤷🏽‍♂' => 'erkak yelka qismoqda: 4-teri turi',
    '🤷🏾‍♂' => 'erkak yelka qismoqda: 5-teri turi',
    '🤷🏿‍♂' => 'erkak yelka qismoqda: 6-teri turi',
    '🤷🏻‍♀' => 'ayol yelka qismoqda: 1–2-teri turi',
    '🤷🏼‍♀' => 'ayol yelka qismoqda: 3-teri turi',
    '🤷🏽‍♀' => 'ayol yelka qismoqda: 4-teri turi',
    '🤷🏾‍♀' => 'ayol yelka qismoqda: 5-teri turi',
    '🤷🏿‍♀' => 'ayol yelka qismoqda: 6-teri turi',
    '🧑🏻‍⚕' => 'tibbiyot xodimi: 1–2-teri turi',
    '🧑🏼‍⚕' => 'tibbiyot xodimi: 3-teri turi',
    '🧑🏽‍⚕' => 'tibbiyot xodimi: 4-teri turi',
    '🧑🏾‍⚕' => 'tibbiyot xodimi: 5-teri turi',
    '🧑🏿‍⚕' => 'tibbiyot xodimi: 6-teri turi',
    '👨🏻‍⚕' => 'erkak shifokor: 1–2-teri turi',
    '👨🏼‍⚕' => 'erkak shifokor: 3-teri turi',
    '👨🏽‍⚕' => 'erkak shifokor: 4-teri turi',
    '👨🏾‍⚕' => 'erkak shifokor: 5-teri turi',
    '👨🏿‍⚕' => 'erkak shifokor: 6-teri turi',
    '👩🏻‍⚕' => 'ayol shifokor: 1–2-teri turi',
    '👩🏼‍⚕' => 'ayol shifokor: 3-teri turi',
    '👩🏽‍⚕' => 'ayol shifokor: 4-teri turi',
    '👩🏾‍⚕' => 'ayol shifokor: 5-teri turi',
    '👩🏿‍⚕' => 'ayol shifokor: 6-teri turi',
    '🧑🏻‍🎓' => 'talaba: 1–2-teri turi',
    '🧑🏼‍🎓' => 'talaba: 3-teri turi',
    '🧑🏽‍🎓' => 'talaba: 4-teri turi',
    '🧑🏾‍🎓' => 'talaba: 5-teri turi',
    '🧑🏿‍🎓' => 'talaba: 6-teri turi',
    '👨🏻‍🎓' => 'erkak talaba: 1–2-teri turi',
    '👨🏼‍🎓' => 'erkak talaba: 3-teri turi',
    '👨🏽‍🎓' => 'erkak talaba: 4-teri turi',
    '👨🏾‍🎓' => 'erkak talaba: 5-teri turi',
    '👨🏿‍🎓' => 'erkak talaba: 6-teri turi',
    '👩🏻‍🎓' => 'ayol talaba: 1–2-teri turi',
    '👩🏼‍🎓' => 'ayol talaba: 3-teri turi',
    '👩🏽‍🎓' => 'ayol talaba: 4-teri turi',
    '👩🏾‍🎓' => 'ayol talaba: 5-teri turi',
    '👩🏿‍🎓' => 'ayol talaba: 6-teri turi',
    '🧑🏻‍🏫' => 'oʻqituvchi: 1–2-teri turi',
    '🧑🏼‍🏫' => 'oʻqituvchi: 3-teri turi',
    '🧑🏽‍🏫' => 'oʻqituvchi: 4-teri turi',
    '🧑🏾‍🏫' => 'oʻqituvchi: 5-teri turi',
    '🧑🏿‍🏫' => 'oʻqituvchi: 6-teri turi',
    '👨🏻‍🏫' => 'erkak o‘qituvchi: 1–2-teri turi',
    '👨🏼‍🏫' => 'erkak o‘qituvchi: 3-teri turi',
    '👨🏽‍🏫' => 'erkak o‘qituvchi: 4-teri turi',
    '👨🏾‍🏫' => 'erkak o‘qituvchi: 5-teri turi',
    '👨🏿‍🏫' => 'erkak o‘qituvchi: 6-teri turi',
    '👩🏻‍🏫' => 'ayol o‘qituvchi: 1–2-teri turi',
    '👩🏼‍🏫' => 'ayol o‘qituvchi: 3-teri turi',
    '👩🏽‍🏫' => 'ayol o‘qituvchi: 4-teri turi',
    '👩🏾‍🏫' => 'ayol o‘qituvchi: 5-teri turi',
    '👩🏿‍🏫' => 'ayol o‘qituvchi: 6-teri turi',
    '🧑🏻‍⚖' => 'sudya: 1–2-teri turi',
    '🧑🏼‍⚖' => 'sudya: 3-teri turi',
    '🧑🏽‍⚖' => 'sudya: 4-teri turi',
    '🧑🏾‍⚖' => 'sudya: 5-teri turi',
    '🧑🏿‍⚖' => 'sudya: 6-teri turi',
    '👨🏻‍⚖' => 'erkak sudya: 1–2-teri turi',
    '👨🏼‍⚖' => 'erkak sudya: 3-teri turi',
    '👨🏽‍⚖' => 'erkak sudya: 4-teri turi',
    '👨🏾‍⚖' => 'erkak sudya: 5-teri turi',
    '👨🏿‍⚖' => 'erkak sudya: 6-teri turi',
    '👩🏻‍⚖' => 'ayol sudya: 1–2-teri turi',
    '👩🏼‍⚖' => 'ayol sudya: 3-teri turi',
    '👩🏽‍⚖' => 'ayol sudya: 4-teri turi',
    '👩🏾‍⚖' => 'ayol sudya: 5-teri turi',
    '👩🏿‍⚖' => 'ayol sudya: 6-teri turi',
    '🧑🏻‍🌾' => 'fermer: 1–2-teri turi',
    '🧑🏼‍🌾' => 'fermer: 3-teri turi',
    '🧑🏽‍🌾' => 'fermer: 4-teri turi',
    '🧑🏾‍🌾' => 'fermer: 5-teri turi',
    '🧑🏿‍🌾' => 'fermer: 6-teri turi',
    '👨🏻‍🌾' => 'erkak fermer: 1–2-teri turi',
    '👨🏼‍🌾' => 'erkak fermer: 3-teri turi',
    '👨🏽‍🌾' => 'erkak fermer: 4-teri turi',
    '👨🏾‍🌾' => 'erkak fermer: 5-teri turi',
    '👨🏿‍🌾' => 'erkak fermer: 6-teri turi',
    '👩🏻‍🌾' => 'ayol fermer: 1–2-teri turi',
    '👩🏼‍🌾' => 'ayol fermer: 3-teri turi',
    '👩🏽‍🌾' => 'ayol fermer: 4-teri turi',
    '👩🏾‍🌾' => 'ayol fermer: 5-teri turi',
    '👩🏿‍🌾' => 'ayol fermer: 6-teri turi',
    '🧑🏻‍🍳' => 'oshpaz: 1–2-teri turi',
    '🧑🏼‍🍳' => 'oshpaz: 3-teri turi',
    '🧑🏽‍🍳' => 'oshpaz: 4-teri turi',
    '🧑🏾‍🍳' => 'oshpaz: 5-teri turi',
    '🧑🏿‍🍳' => 'oshpaz: 6-teri turi',
    '👨🏻‍🍳' => 'erkak oshpaz: 1–2-teri turi',
    '👨🏼‍🍳' => 'erkak oshpaz: 3-teri turi',
    '👨🏽‍🍳' => 'erkak oshpaz: 4-teri turi',
    '👨🏾‍🍳' => 'erkak oshpaz: 5-teri turi',
    '👨🏿‍🍳' => 'erkak oshpaz: 6-teri turi',
    '👩🏻‍🍳' => 'ayol oshpaz: 1–2-teri turi',
    '👩🏼‍🍳' => 'ayol oshpaz: 3-teri turi',
    '👩🏽‍🍳' => 'ayol oshpaz: 4-teri turi',
    '👩🏾‍🍳' => 'ayol oshpaz: 5-teri turi',
    '👩🏿‍🍳' => 'ayol oshpaz: 6-teri turi',
    '🧑🏻‍🔧' => 'mexanik: 1–2-teri turi',
    '🧑🏼‍🔧' => 'mexanik: 3-teri turi',
    '🧑🏽‍🔧' => 'mexanik: 4-teri turi',
    '🧑🏾‍🔧' => 'mexanik: 5-teri turi',
    '🧑🏿‍🔧' => 'mexanik: 6-teri turi',
    '👨🏻‍🔧' => 'erkak mexanik: 1–2-teri turi',
    '👨🏼‍🔧' => 'erkak mexanik: 3-teri turi',
    '👨🏽‍🔧' => 'erkak mexanik: 4-teri turi',
    '👨🏾‍🔧' => 'erkak mexanik: 5-teri turi',
    '👨🏿‍🔧' => 'erkak mexanik: 6-teri turi',
    '👩🏻‍🔧' => 'ayol mexanik: 1–2-teri turi',
    '👩🏼‍🔧' => 'ayol mexanik: 3-teri turi',
    '👩🏽‍🔧' => 'ayol mexanik: 4-teri turi',
    '👩🏾‍🔧' => 'ayol mexanik: 5-teri turi',
    '👩🏿‍🔧' => 'ayol mexanik: 6-teri turi',
    '🧑🏻‍🏭' => 'zavod ishchisi: 1–2-teri turi',
    '🧑🏼‍🏭' => 'zavod ishchisi: 3-teri turi',
    '🧑🏽‍🏭' => 'zavod ishchisi: 4-teri turi',
    '🧑🏾‍🏭' => 'zavod ishchisi: 5-teri turi',
    '🧑🏿‍🏭' => 'zavod ishchisi: 6-teri turi',
    '👨🏻‍🏭' => 'erkak zavod ishchisi: 1–2-teri turi',
    '👨🏼‍🏭' => 'erkak zavod ishchisi: 3-teri turi',
    '👨🏽‍🏭' => 'erkak zavod ishchisi: 4-teri turi',
    '👨🏾‍🏭' => 'erkak zavod ishchisi: 5-teri turi',
    '👨🏿‍🏭' => 'erkak zavod ishchisi: 6-teri turi',
    '👩🏻‍🏭' => 'ayol zavod ishchisi: 1–2-teri turi',
    '👩🏼‍🏭' => 'ayol zavod ishchisi: 3-teri turi',
    '👩🏽‍🏭' => 'ayol zavod ishchisi: 4-teri turi',
    '👩🏾‍🏭' => 'ayol zavod ishchisi: 5-teri turi',
    '👩🏿‍🏭' => 'ayol zavod ishchisi: 6-teri turi',
    '🧑🏻‍💼' => 'ofis xodimi: 1–2-teri turi',
    '🧑🏼‍💼' => 'ofis xodimi: 3-teri turi',
    '🧑🏽‍💼' => 'ofis xodimi: 4-teri turi',
    '🧑🏾‍💼' => 'ofis xodimi: 5-teri turi',
    '🧑🏿‍💼' => 'ofis xodimi: 6-teri turi',
    '👨🏻‍💼' => 'erkak ofis xodimi: 1–2-teri turi',
    '👨🏼‍💼' => 'erkak ofis xodimi: 3-teri turi',
    '👨🏽‍💼' => 'erkak ofis xodimi: 4-teri turi',
    '👨🏾‍💼' => 'erkak ofis xodimi: 5-teri turi',
    '👨🏿‍💼' => 'erkak ofis xodimi: 6-teri turi',
    '👩🏻‍💼' => 'ayol ofis xodimi: 1–2-teri turi',
    '👩🏼‍💼' => 'ayol ofis xodimi: 3-teri turi',
    '👩🏽‍💼' => 'ayol ofis xodimi: 4-teri turi',
    '👩🏾‍💼' => 'ayol ofis xodimi: 5-teri turi',
    '👩🏿‍💼' => 'ayol ofis xodimi: 6-teri turi',
    '🧑🏻‍🔬' => 'olim: 1–2-teri turi',
    '🧑🏼‍🔬' => 'olim: 3-teri turi',
    '🧑🏽‍🔬' => 'olim: 4-teri turi',
    '🧑🏾‍🔬' => 'olim: 5-teri turi',
    '🧑🏿‍🔬' => 'olim: 6-teri turi',
    '👨🏻‍🔬' => 'erkak olim: 1–2-teri turi',
    '👨🏼‍🔬' => 'erkak olim: 3-teri turi',
    '👨🏽‍🔬' => 'erkak olim: 4-teri turi',
    '👨🏾‍🔬' => 'erkak olim: 5-teri turi',
    '👨🏿‍🔬' => 'erkak olim: 6-teri turi',
    '👩🏻‍🔬' => 'ayol olim: 1–2-teri turi',
    '👩🏼‍🔬' => 'ayol olim: 3-teri turi',
    '👩🏽‍🔬' => 'ayol olim: 4-teri turi',
    '👩🏾‍🔬' => 'ayol olim: 5-teri turi',
    '👩🏿‍🔬' => 'ayol olim: 6-teri turi',
    '🧑🏻‍💻' => 'texnolog: 1–2-teri turi',
    '🧑🏼‍💻' => 'texnolog: 3-teri turi',
    '🧑🏽‍💻' => 'texnolog: 4-teri turi',
    '🧑🏾‍💻' => 'texnolog: 5-teri turi',
    '🧑🏿‍💻' => 'texnolog: 6-teri turi',
    '👨🏻‍💻' => 'erkak texnolog: 1–2-teri turi',
    '👨🏼‍💻' => 'erkak texnolog: 3-teri turi',
    '👨🏽‍💻' => 'erkak texnolog: 4-teri turi',
    '👨🏾‍💻' => 'erkak texnolog: 5-teri turi',
    '👨🏿‍💻' => 'erkak texnolog: 6-teri turi',
    '👩🏻‍💻' => 'ayol texnolog: 1–2-teri turi',
    '👩🏼‍💻' => 'ayol texnolog: 3-teri turi',
    '👩🏽‍💻' => 'ayol texnolog: 4-teri turi',
    '👩🏾‍💻' => 'ayol texnolog: 5-teri turi',
    '👩🏿‍💻' => 'ayol texnolog: 6-teri turi',
    '🧑🏻‍🎤' => 'qoʻshiqchi: 1–2-teri turi',
    '🧑🏼‍🎤' => 'qoʻshiqchi: 3-teri turi',
    '🧑🏽‍🎤' => 'qoʻshiqchi: 4-teri turi',
    '🧑🏾‍🎤' => 'qoʻshiqchi: 5-teri turi',
    '🧑🏿‍🎤' => 'qoʻshiqchi: 6-teri turi',
    '👨🏻‍🎤' => 'erkak qo‘shiqchi: 1–2-teri turi',
    '👨🏼‍🎤' => 'erkak qo‘shiqchi: 3-teri turi',
    '👨🏽‍🎤' => 'erkak qo‘shiqchi: 4-teri turi',
    '👨🏾‍🎤' => 'erkak qo‘shiqchi: 5-teri turi',
    '👨🏿‍🎤' => 'erkak qo‘shiqchi: 6-teri turi',
    '👩🏻‍🎤' => 'ayol qo‘shiqchi: 1–2-teri turi',
    '👩🏼‍🎤' => 'ayol qo‘shiqchi: 3-teri turi',
    '👩🏽‍🎤' => 'ayol qo‘shiqchi: 4-teri turi',
    '👩🏾‍🎤' => 'ayol qo‘shiqchi: 5-teri turi',
    '👩🏿‍🎤' => 'ayol qo‘shiqchi: 6-teri turi',
    '🧑🏻‍🎨' => 'rassom: 1–2-teri turi',
    '🧑🏼‍🎨' => 'rassom: 3-teri turi',
    '🧑🏽‍🎨' => 'rassom: 4-teri turi',
    '🧑🏾‍🎨' => 'rassom: 5-teri turi',
    '🧑🏿‍🎨' => 'rassom: 6-teri turi',
    '👨🏻‍🎨' => 'erkak rassom: 1–2-teri turi',
    '👨🏼‍🎨' => 'erkak rassom: 3-teri turi',
    '👨🏽‍🎨' => 'erkak rassom: 4-teri turi',
    '👨🏾‍🎨' => 'erkak rassom: 5-teri turi',
    '👨🏿‍🎨' => 'erkak rassom: 6-teri turi',
    '👩🏻‍🎨' => 'ayol rassom: 1–2-teri turi',
    '👩🏼‍🎨' => 'ayol rassom: 3-teri turi',
    '👩🏽‍🎨' => 'ayol rassom: 4-teri turi',
    '👩🏾‍🎨' => 'ayol rassom: 5-teri turi',
    '👩🏿‍🎨' => 'ayol rassom: 6-teri turi',
    '🧑🏻‍✈' => 'uchuvchi: 1–2-teri turi',
    '🧑🏼‍✈' => 'uchuvchi: 3-teri turi',
    '🧑🏽‍✈' => 'uchuvchi: 4-teri turi',
    '🧑🏾‍✈' => 'uchuvchi: 5-teri turi',
    '🧑🏿‍✈' => 'uchuvchi: 6-teri turi',
    '👨🏻‍✈' => 'erkak uchuvchi: 1–2-teri turi',
    '👨🏼‍✈' => 'erkak uchuvchi: 3-teri turi',
    '👨🏽‍✈' => 'erkak uchuvchi: 4-teri turi',
    '👨🏾‍✈' => 'erkak uchuvchi: 5-teri turi',
    '👨🏿‍✈' => 'erkak uchuvchi: 6-teri turi',
    '👩🏻‍✈' => 'ayol uchuvchi: 1–2-teri turi',
    '👩🏼‍✈' => 'ayol uchuvchi: 3-teri turi',
    '👩🏽‍✈' => 'ayol uchuvchi: 4-teri turi',
    '👩🏾‍✈' => 'ayol uchuvchi: 5-teri turi',
    '👩🏿‍✈' => 'ayol uchuvchi: 6-teri turi',
    '🧑🏻‍🚀' => 'astronavt: 1–2-teri turi',
    '🧑🏼‍🚀' => 'astronavt: 3-teri turi',
    '🧑🏽‍🚀' => 'astronavt: 4-teri turi',
    '🧑🏾‍🚀' => 'astronavt: 5-teri turi',
    '🧑🏿‍🚀' => 'astronavt: 6-teri turi',
    '👨🏻‍🚀' => 'erkak kosmonavt: 1–2-teri turi',
    '👨🏼‍🚀' => 'erkak kosmonavt: 3-teri turi',
    '👨🏽‍🚀' => 'erkak kosmonavt: 4-teri turi',
    '👨🏾‍🚀' => 'erkak kosmonavt: 5-teri turi',
    '👨🏿‍🚀' => 'erkak kosmonavt: 6-teri turi',
    '👩🏻‍🚀' => 'ayol kosmonavt: 1–2-teri turi',
    '👩🏼‍🚀' => 'ayol kosmonavt: 3-teri turi',
    '👩🏽‍🚀' => 'ayol kosmonavt: 4-teri turi',
    '👩🏾‍🚀' => 'ayol kosmonavt: 5-teri turi',
    '👩🏿‍🚀' => 'ayol kosmonavt: 6-teri turi',
    '🧑🏻‍🚒' => 'oʻt oʻchiruvchi: 1–2-teri turi',
    '🧑🏼‍🚒' => 'oʻt oʻchiruvchi: 3-teri turi',
    '🧑🏽‍🚒' => 'oʻt oʻchiruvchi: 4-teri turi',
    '🧑🏾‍🚒' => 'oʻt oʻchiruvchi: 5-teri turi',
    '🧑🏿‍🚒' => 'oʻt oʻchiruvchi: 6-teri turi',
    '👨🏻‍🚒' => 'erkak o‘t o‘chiruvchi: 1–2-teri turi',
    '👨🏼‍🚒' => 'erkak o‘t o‘chiruvchi: 3-teri turi',
    '👨🏽‍🚒' => 'erkak o‘t o‘chiruvchi: 4-teri turi',
    '👨🏾‍🚒' => 'erkak o‘t o‘chiruvchi: 5-teri turi',
    '👨🏿‍🚒' => 'erkak o‘t o‘chiruvchi: 6-teri turi',
    '👩🏻‍🚒' => 'ayol o‘t o‘chiruvchi: 1–2-teri turi',
    '👩🏼‍🚒' => 'ayol o‘t o‘chiruvchi: 3-teri turi',
    '👩🏽‍🚒' => 'ayol o‘t o‘chiruvchi: 4-teri turi',
    '👩🏾‍🚒' => 'ayol o‘t o‘chiruvchi: 5-teri turi',
    '👩🏿‍🚒' => 'ayol o‘t o‘chiruvchi: 6-teri turi',
    '👮🏻‍♂' => 'erkak politsiyachi: 1–2-teri turi',
    '👮🏼‍♂' => 'erkak politsiyachi: 3-teri turi',
    '👮🏽‍♂' => 'erkak politsiyachi: 4-teri turi',
    '👮🏾‍♂' => 'erkak politsiyachi: 5-teri turi',
    '👮🏿‍♂' => 'erkak politsiyachi: 6-teri turi',
    '👮🏻‍♀' => 'ayol politsiyachi: 1–2-teri turi',
    '👮🏼‍♀' => 'ayol politsiyachi: 3-teri turi',
    '👮🏽‍♀' => 'ayol politsiyachi: 4-teri turi',
    '👮🏾‍♀' => 'ayol politsiyachi: 5-teri turi',
    '👮🏿‍♀' => 'ayol politsiyachi: 6-teri turi',
    '🕵🏻‍♂' => 'erkak izquvar: 1–2-teri turi',
    '🕵🏼‍♂' => 'erkak izquvar: 3-teri turi',
    '🕵🏽‍♂' => 'erkak izquvar: 4-teri turi',
    '🕵🏾‍♂' => 'erkak izquvar: 5-teri turi',
    '🕵🏿‍♂' => 'erkak izquvar: 6-teri turi',
    '🕵🏻‍♀' => 'ayol izquvar: 1–2-teri turi',
    '🕵🏼‍♀' => 'ayol izquvar: 3-teri turi',
    '🕵🏽‍♀' => 'ayol izquvar: 4-teri turi',
    '🕵🏾‍♀' => 'ayol izquvar: 5-teri turi',
    '🕵🏿‍♀' => 'ayol izquvar: 6-teri turi',
    '💂🏻‍♂' => 'erkak qo‘riqchi: 1–2-teri turi',
    '💂🏼‍♂' => 'erkak qo‘riqchi: 3-teri turi',
    '💂🏽‍♂' => 'erkak qo‘riqchi: 4-teri turi',
    '💂🏾‍♂' => 'erkak qo‘riqchi: 5-teri turi',
    '💂🏿‍♂' => 'erkak qo‘riqchi: 6-teri turi',
    '💂🏻‍♀' => 'ayol qo‘riqchi: 1–2-teri turi',
    '💂🏼‍♀' => 'ayol qo‘riqchi: 3-teri turi',
    '💂🏽‍♀' => 'ayol qo‘riqchi: 4-teri turi',
    '💂🏾‍♀' => 'ayol qo‘riqchi: 5-teri turi',
    '💂🏿‍♀' => 'ayol qo‘riqchi: 6-teri turi',
    '👷🏻‍♂' => 'erkak quruvchi: 1–2-teri turi',
    '👷🏼‍♂' => 'erkak quruvchi: 3-teri turi',
    '👷🏽‍♂' => 'erkak quruvchi: 4-teri turi',
    '👷🏾‍♂' => 'erkak quruvchi: 5-teri turi',
    '👷🏿‍♂' => 'erkak quruvchi: 6-teri turi',
    '👷🏻‍♀' => 'ayol quruvchi: 1–2-teri turi',
    '👷🏼‍♀' => 'ayol quruvchi: 3-teri turi',
    '👷🏽‍♀' => 'ayol quruvchi: 4-teri turi',
    '👷🏾‍♀' => 'ayol quruvchi: 5-teri turi',
    '👷🏿‍♀' => 'ayol quruvchi: 6-teri turi',
    '👳🏻‍♂' => 'sallali erkak: 1–2-teri turi',
    '👳🏼‍♂' => 'sallali erkak: 3-teri turi',
    '👳🏽‍♂' => 'sallali erkak: 4-teri turi',
    '👳🏾‍♂' => 'sallali erkak: 5-teri turi',
    '👳🏿‍♂' => 'sallali erkak: 6-teri turi',
    '👳🏻‍♀' => 'sallali ayol: 1–2-teri turi',
    '👳🏼‍♀' => 'sallali ayol: 3-teri turi',
    '👳🏽‍♀' => 'sallali ayol: 4-teri turi',
    '👳🏾‍♀' => 'sallali ayol: 5-teri turi',
    '👳🏿‍♀' => 'sallali ayol: 6-teri turi',
    '🤵🏻‍♂' => 'smoking kiygan kishi: 1–2-teri turi',
    '🤵🏼‍♂' => 'smoking kiygan kishi: 3-teri turi',
    '🤵🏽‍♂' => 'smoking kiygan kishi: 4-teri turi',
    '🤵🏾‍♂' => 'smoking kiygan kishi: 5-teri turi',
    '🤵🏿‍♂' => 'smoking kiygan kishi: 6-teri turi',
    '🤵🏻‍♀' => 'smoking kiygan ayol: 1–2-teri turi',
    '🤵🏼‍♀' => 'smoking kiygan ayol: 3-teri turi',
    '🤵🏽‍♀' => 'smoking kiygan ayol: 4-teri turi',
    '🤵🏾‍♀' => 'smoking kiygan ayol: 5-teri turi',
    '🤵🏿‍♀' => 'smoking kiygan ayol: 6-teri turi',
    '👰🏻‍♂' => 'xarir parda taqib olgan erkak: 1–2-teri turi',
    '👰🏼‍♂' => 'xarir parda taqib olgan erkak: 3-teri turi',
    '👰🏽‍♂' => 'xarir parda taqib olgan erkak: 4-teri turi',
    '👰🏾‍♂' => 'xarir parda taqib olgan erkak: 5-teri turi',
    '👰🏿‍♂' => 'xarir parda taqib olgan erkak: 6-teri turi',
    '👰🏻‍♀' => 'xarir parda taqib olgan ayol: 1–2-teri turi',
    '👰🏼‍♀' => 'xarir parda taqib olgan ayol: 3-teri turi',
    '👰🏽‍♀' => 'xarir parda taqib olgan ayol: 4-teri turi',
    '👰🏾‍♀' => 'xarir parda taqib olgan ayol: 5-teri turi',
    '👰🏿‍♀' => 'xarir parda taqib olgan ayol: 6-teri turi',
    '👩🏻‍🍼' => 'chaqaloq emizayotgan ayol: 1–2-teri turi',
    '👩🏼‍🍼' => 'chaqaloq emizayotgan ayol: 3-teri turi',
    '👩🏽‍🍼' => 'chaqaloq emizayotgan ayol: 4-teri turi',
    '👩🏾‍🍼' => 'chaqaloq emizayotgan ayol: 5-teri turi',
    '👩🏿‍🍼' => 'chaqaloq emizayotgan ayol: 6-teri turi',
    '👨🏻‍🍼' => 'chaqaloq emizayotgan erkak: 1–2-teri turi',
    '👨🏼‍🍼' => 'chaqaloq emizayotgan erkak: 3-teri turi',
    '👨🏽‍🍼' => 'chaqaloq emizayotgan erkak: 4-teri turi',
    '👨🏾‍🍼' => 'chaqaloq emizayotgan erkak: 5-teri turi',
    '👨🏿‍🍼' => 'chaqaloq emizayotgan erkak: 6-teri turi',
    '🧑🏻‍🍼' => 'chaqaloq emizayotgan kishi: 1–2-teri turi',
    '🧑🏼‍🍼' => 'chaqaloq emizayotgan kishi: 3-teri turi',
    '🧑🏽‍🍼' => 'chaqaloq emizayotgan kishi: 4-teri turi',
    '🧑🏾‍🍼' => 'chaqaloq emizayotgan kishi: 5-teri turi',
    '🧑🏿‍🍼' => 'chaqaloq emizayotgan kishi: 6-teri turi',
    '🧑🏻‍🎄' => 'miks-klauz: 1–2-teri turi',
    '🧑🏼‍🎄' => 'miks-klauz: 3-teri turi',
    '🧑🏽‍🎄' => 'miks-klauz: 4-teri turi',
    '🧑🏾‍🎄' => 'miks-klauz: 5-teri turi',
    '🧑🏿‍🎄' => 'miks-klauz: 6-teri turi',
    '🦸🏻‍♂' => 'erkak qahramon: 1–2-teri turi',
    '🦸🏼‍♂' => 'erkak qahramon: 3-teri turi',
    '🦸🏽‍♂' => 'erkak qahramon: 4-teri turi',
    '🦸🏾‍♂' => 'erkak qahramon: 5-teri turi',
    '🦸🏿‍♂' => 'erkak qahramon: 6-teri turi',
    '🦸🏻‍♀' => 'ayol superqahramon: 1–2-teri turi',
    '🦸🏼‍♀' => 'ayol superqahramon: 3-teri turi',
    '🦸🏽‍♀' => 'ayol superqahramon: 4-teri turi',
    '🦸🏾‍♀' => 'ayol superqahramon: 5-teri turi',
    '🦸🏿‍♀' => 'ayol superqahramon: 6-teri turi',
    '🦹🏻‍♂' => 'salbiy erkak superqahramon: 1–2-teri turi',
    '🦹🏼‍♂' => 'salbiy erkak superqahramon: 3-teri turi',
    '🦹🏽‍♂' => 'salbiy erkak superqahramon: 4-teri turi',
    '🦹🏾‍♂' => 'salbiy erkak superqahramon: 5-teri turi',
    '🦹🏿‍♂' => 'salbiy erkak superqahramon: 6-teri turi',
    '🦹🏻‍♀' => 'salbiy ayol superqahramon: 1–2-teri turi',
    '🦹🏼‍♀' => 'salbiy ayol superqahramon: 3-teri turi',
    '🦹🏽‍♀' => 'salbiy ayol superqahramon: 4-teri turi',
    '🦹🏾‍♀' => 'salbiy ayol superqahramon: 5-teri turi',
    '🦹🏿‍♀' => 'salbiy ayol superqahramon: 6-teri turi',
    '🧙🏻‍♂' => 'erkak sehrgar: 1–2-teri turi',
    '🧙🏼‍♂' => 'erkak sehrgar: 3-teri turi',
    '🧙🏽‍♂' => 'erkak sehrgar: 4-teri turi',
    '🧙🏾‍♂' => 'erkak sehrgar: 5-teri turi',
    '🧙🏿‍♂' => 'erkak sehrgar: 6-teri turi',
    '🧙🏻‍♀' => 'ayol sehrgar: 1–2-teri turi',
    '🧙🏼‍♀' => 'ayol sehrgar: 3-teri turi',
    '🧙🏽‍♀' => 'ayol sehrgar: 4-teri turi',
    '🧙🏾‍♀' => 'ayol sehrgar: 5-teri turi',
    '🧙🏿‍♀' => 'ayol sehrgar: 6-teri turi',
    '🧚🏻‍♂' => 'erkak pari: 1–2-teri turi',
    '🧚🏼‍♂' => 'erkak pari: 3-teri turi',
    '🧚🏽‍♂' => 'erkak pari: 4-teri turi',
    '🧚🏾‍♂' => 'erkak pari: 5-teri turi',
    '🧚🏿‍♂' => 'erkak pari: 6-teri turi',
    '🧚🏻‍♀' => 'ayol pari: 1–2-teri turi',
    '🧚🏼‍♀' => 'ayol pari: 3-teri turi',
    '🧚🏽‍♀' => 'ayol pari: 4-teri turi',
    '🧚🏾‍♀' => 'ayol pari: 5-teri turi',
    '🧚🏿‍♀' => 'ayol pari: 6-teri turi',
    '🧛🏻‍♂' => 'erkak vampir: 1–2-teri turi',
    '🧛🏼‍♂' => 'erkak vampir: 3-teri turi',
    '🧛🏽‍♂' => 'erkak vampir: 4-teri turi',
    '🧛🏾‍♂' => 'erkak vampir: 5-teri turi',
    '🧛🏿‍♂' => 'erkak vampir: 6-teri turi',
    '🧛🏻‍♀' => 'ayol vampir: 1–2-teri turi',
    '🧛🏼‍♀' => 'ayol vampir: 3-teri turi',
    '🧛🏽‍♀' => 'ayol vampir: 4-teri turi',
    '🧛🏾‍♀' => 'ayol vampir: 5-teri turi',
    '🧛🏿‍♀' => 'ayol vampir: 6-teri turi',
    '🧜🏻‍♂' => 'triton: 1–2-teri turi',
    '🧜🏼‍♂' => 'triton: 3-teri turi',
    '🧜🏽‍♂' => 'triton: 4-teri turi',
    '🧜🏾‍♂' => 'triton: 5-teri turi',
    '🧜🏿‍♂' => 'triton: 6-teri turi',
    '🧜🏻‍♀' => 'ayol suv parisi: 1–2-teri turi',
    '🧜🏼‍♀' => 'ayol suv parisi: 3-teri turi',
    '🧜🏽‍♀' => 'ayol suv parisi: 4-teri turi',
    '🧜🏾‍♀' => 'ayol suv parisi: 5-teri turi',
    '🧜🏿‍♀' => 'ayol suv parisi: 6-teri turi',
    '🧝🏻‍♂' => 'erkak elf: 1–2-teri turi',
    '🧝🏼‍♂' => 'erkak elf: 3-teri turi',
    '🧝🏽‍♂' => 'erkak elf: 4-teri turi',
    '🧝🏾‍♂' => 'erkak elf: 5-teri turi',
    '🧝🏿‍♂' => 'erkak elf: 6-teri turi',
    '🧝🏻‍♀' => 'ayol elf: 1–2-teri turi',
    '🧝🏼‍♀' => 'ayol elf: 3-teri turi',
    '🧝🏽‍♀' => 'ayol elf: 4-teri turi',
    '🧝🏾‍♀' => 'ayol elf: 5-teri turi',
    '🧝🏿‍♀' => 'ayol elf: 6-teri turi',
    '💆🏻‍♂' => 'erkak yuziga massaj olmoqda: 1–2-teri turi',
    '💆🏼‍♂' => 'erkak yuziga massaj olmoqda: 3-teri turi',
    '💆🏽‍♂' => 'erkak yuziga massaj olmoqda: 4-teri turi',
    '💆🏾‍♂' => 'erkak yuziga massaj olmoqda: 5-teri turi',
    '💆🏿‍♂' => 'erkak yuziga massaj olmoqda: 6-teri turi',
    '💆🏻‍♀' => 'ayol yuziga massaj olmoqda: 1–2-teri turi',
    '💆🏼‍♀' => 'ayol yuziga massaj olmoqda: 3-teri turi',
    '💆🏽‍♀' => 'ayol yuziga massaj olmoqda: 4-teri turi',
    '💆🏾‍♀' => 'ayol yuziga massaj olmoqda: 5-teri turi',
    '💆🏿‍♀' => 'ayol yuziga massaj olmoqda: 6-teri turi',
    '💇🏻‍♂' => 'erkak soch kaltalatmoqda: 1–2-teri turi',
    '💇🏼‍♂' => 'erkak soch kaltalatmoqda: 3-teri turi',
    '💇🏽‍♂' => 'erkak soch kaltalatmoqda: 4-teri turi',
    '💇🏾‍♂' => 'erkak soch kaltalatmoqda: 5-teri turi',
    '💇🏿‍♂' => 'erkak soch kaltalatmoqda: 6-teri turi',
    '💇🏻‍♀' => 'ayol soch kaltalatmoqda: 1–2-teri turi',
    '💇🏼‍♀' => 'ayol soch kaltalatmoqda: 3-teri turi',
    '💇🏽‍♀' => 'ayol soch kaltalatmoqda: 4-teri turi',
    '💇🏾‍♀' => 'ayol soch kaltalatmoqda: 5-teri turi',
    '💇🏿‍♀' => 'ayol soch kaltalatmoqda: 6-teri turi',
    '🚶🏻‍♂' => 'yurayotgan erkak: 1–2-teri turi',
    '🚶🏼‍♂' => 'yurayotgan erkak: 3-teri turi',
    '🚶🏽‍♂' => 'yurayotgan erkak: 4-teri turi',
    '🚶🏾‍♂' => 'yurayotgan erkak: 5-teri turi',
    '🚶🏿‍♂' => 'yurayotgan erkak: 6-teri turi',
    '🚶🏻‍♀' => 'yurayotgan ayol: 1–2-teri turi',
    '🚶🏼‍♀' => 'yurayotgan ayol: 3-teri turi',
    '🚶🏽‍♀' => 'yurayotgan ayol: 4-teri turi',
    '🚶🏾‍♀' => 'yurayotgan ayol: 5-teri turi',
    '🚶🏿‍♀' => 'yurayotgan ayol: 6-teri turi',
    '🚶🏻‍➡' => 'piyoda odam: 1–2-teri turi o‘ngga qaragan',
    '🚶🏼‍➡' => 'piyoda odam: 3-teri turi o‘ngga qaragan',
    '🚶🏽‍➡' => 'piyoda odam: 4-teri turi o‘ngga qaragan',
    '🚶🏾‍➡' => 'piyoda odam: 5-teri turi o‘ngga qaragan',
    '🚶🏿‍➡' => 'piyoda odam: 6-teri turi o‘ngga qaragan',
    '🧍🏻‍♂' => 'tik turgan erkak: 1–2-teri turi',
    '🧍🏼‍♂' => 'tik turgan erkak: 3-teri turi',
    '🧍🏽‍♂' => 'tik turgan erkak: 4-teri turi',
    '🧍🏾‍♂' => 'tik turgan erkak: 5-teri turi',
    '🧍🏿‍♂' => 'tik turgan erkak: 6-teri turi',
    '🧍🏻‍♀' => 'tik turgan ayol: 1–2-teri turi',
    '🧍🏼‍♀' => 'tik turgan ayol: 3-teri turi',
    '🧍🏽‍♀' => 'tik turgan ayol: 4-teri turi',
    '🧍🏾‍♀' => 'tik turgan ayol: 5-teri turi',
    '🧍🏿‍♀' => 'tik turgan ayol: 6-teri turi',
    '🧎🏻‍♂' => 'tiz choʻkkan erkak: 1–2-teri turi',
    '🧎🏼‍♂' => 'tiz choʻkkan erkak: 3-teri turi',
    '🧎🏽‍♂' => 'tiz choʻkkan erkak: 4-teri turi',
    '🧎🏾‍♂' => 'tiz choʻkkan erkak: 5-teri turi',
    '🧎🏿‍♂' => 'tiz choʻkkan erkak: 6-teri turi',
    '🧎🏻‍♀' => 'tiz choʻkkan ayol: 1–2-teri turi',
    '🧎🏼‍♀' => 'tiz choʻkkan ayol: 3-teri turi',
    '🧎🏽‍♀' => 'tiz choʻkkan ayol: 4-teri turi',
    '🧎🏾‍♀' => 'tiz choʻkkan ayol: 5-teri turi',
    '🧎🏿‍♀' => 'tiz choʻkkan ayol: 6-teri turi',
    '🧎🏻‍➡' => 'tiz choʻkkan odam: 1–2-teri turi o‘ngga qaragan',
    '🧎🏼‍➡' => 'tiz choʻkkan odam: 3-teri turi o‘ngga qaragan',
    '🧎🏽‍➡' => 'tiz choʻkkan odam: 4-teri turi o‘ngga qaragan',
    '🧎🏾‍➡' => 'tiz choʻkkan odam: 5-teri turi o‘ngga qaragan',
    '🧎🏿‍➡' => 'tiz choʻkkan odam: 6-teri turi o‘ngga qaragan',
    '🧑🏻‍🦯' => 'hassali odam: 1–2-teri turi',
    '🧑🏼‍🦯' => 'hassali odam: 3-teri turi',
    '🧑🏽‍🦯' => 'hassali odam: 4-teri turi',
    '🧑🏾‍🦯' => 'hassali odam: 5-teri turi',
    '🧑🏿‍🦯' => 'hassali odam: 6-teri turi',
    '👨🏻‍🦯' => 'hassali kishi: 1–2-teri turi',
    '👨🏼‍🦯' => 'hassali kishi: 3-teri turi',
    '👨🏽‍🦯' => 'hassali kishi: 4-teri turi',
    '👨🏾‍🦯' => 'hassali kishi: 5-teri turi',
    '👨🏿‍🦯' => 'hassali kishi: 6-teri turi',
    '👩🏻‍🦯' => 'hassali ayol: 1–2-teri turi',
    '👩🏼‍🦯' => 'hassali ayol: 3-teri turi',
    '👩🏽‍🦯' => 'hassali ayol: 4-teri turi',
    '👩🏾‍🦯' => 'hassali ayol: 5-teri turi',
    '👩🏿‍🦯' => 'hassali ayol: 6-teri turi',
    '🧑🏻‍🦼' => 'motorli nogironlar aravachasidagi odam: 1–2-teri turi',
    '🧑🏼‍🦼' => 'motorli nogironlar aravachasidagi odam: 3-teri turi',
    '🧑🏽‍🦼' => 'motorli nogironlar aravachasidagi odam: 4-teri turi',
    '🧑🏾‍🦼' => 'motorli nogironlar aravachasidagi odam: 5-teri turi',
    '🧑🏿‍🦼' => 'motorli nogironlar aravachasidagi odam: 6-teri turi',
    '👨🏻‍🦼' => 'motorli nogironlik aravachasidagi erkak: 1–2-teri turi',
    '👨🏼‍🦼' => 'motorli nogironlik aravachasidagi erkak: 3-teri turi',
    '👨🏽‍🦼' => 'motorli nogironlik aravachasidagi erkak: 4-teri turi',
    '👨🏾‍🦼' => 'motorli nogironlik aravachasidagi erkak: 5-teri turi',
    '👨🏿‍🦼' => 'motorli nogironlik aravachasidagi erkak: 6-teri turi',
    '👩🏻‍🦼' => 'motorli nogironlik aravachasidagi ayol: 1–2-teri turi',
    '👩🏼‍🦼' => 'motorli nogironlik aravachasidagi ayol: 3-teri turi',
    '👩🏽‍🦼' => 'motorli nogironlik aravachasidagi ayol: 4-teri turi',
    '👩🏾‍🦼' => 'motorli nogironlik aravachasidagi ayol: 5-teri turi',
    '👩🏿‍🦼' => 'motorli nogironlik aravachasidagi ayol: 6-teri turi',
    '🧑🏻‍🦽' => 'nogironlar aravachasidagi odam: 1–2-teri turi',
    '🧑🏼‍🦽' => 'nogironlar aravachasidagi odam: 3-teri turi',
    '🧑🏽‍🦽' => 'nogironlar aravachasidagi odam: 4-teri turi',
    '🧑🏾‍🦽' => 'nogironlar aravachasidagi odam: 5-teri turi',
    '🧑🏿‍🦽' => 'nogironlar aravachasidagi odam: 6-teri turi',
    '👨🏻‍🦽' => 'nogironlik aravachasidagi erkak: 1–2-teri turi',
    '👨🏼‍🦽' => 'nogironlik aravachasidagi erkak: 3-teri turi',
    '👨🏽‍🦽' => 'nogironlik aravachasidagi erkak: 4-teri turi',
    '👨🏾‍🦽' => 'nogironlik aravachasidagi erkak: 5-teri turi',
    '👨🏿‍🦽' => 'nogironlik aravachasidagi erkak: 6-teri turi',
    '👩🏻‍🦽' => 'nogironlik aravachasidagi ayol: 1–2-teri turi',
    '👩🏼‍🦽' => 'nogironlik aravachasidagi ayol: 3-teri turi',
    '👩🏽‍🦽' => 'nogironlik aravachasidagi ayol: 4-teri turi',
    '👩🏾‍🦽' => 'nogironlik aravachasidagi ayol: 5-teri turi',
    '👩🏿‍🦽' => 'nogironlik aravachasidagi ayol: 6-teri turi',
    '🏃🏻‍♂' => 'yugurayotgan erkak: 1–2-teri turi',
    '🏃🏼‍♂' => 'yugurayotgan erkak: 3-teri turi',
    '🏃🏽‍♂' => 'yugurayotgan erkak: 4-teri turi',
    '🏃🏾‍♂' => 'yugurayotgan erkak: 5-teri turi',
    '🏃🏿‍♂' => 'yugurayotgan erkak: 6-teri turi',
    '🏃🏻‍♀' => 'yugurayotgan ayol: 1–2-teri turi',
    '🏃🏼‍♀' => 'yugurayotgan ayol: 3-teri turi',
    '🏃🏽‍♀' => 'yugurayotgan ayol: 4-teri turi',
    '🏃🏾‍♀' => 'yugurayotgan ayol: 5-teri turi',
    '🏃🏿‍♀' => 'yugurayotgan ayol: 6-teri turi',
    '🏃🏻‍➡' => 'yuguruvchi: 1–2-teri turi o‘ngga qaragan',
    '🏃🏼‍➡' => 'yuguruvchi: 3-teri turi o‘ngga qaragan',
    '🏃🏽‍➡' => 'yuguruvchi: 4-teri turi o‘ngga qaragan',
    '🏃🏾‍➡' => 'yuguruvchi: 5-teri turi o‘ngga qaragan',
    '🏃🏿‍➡' => 'yuguruvchi: 6-teri turi o‘ngga qaragan',
    '👯🏻‍♀' => 'quyon quloqli ayollar: 1–2-teri turi',
    '👯🏼‍♀' => 'quyon quloqli ayollar: 3-teri turi',
    '👯🏽‍♀' => 'quyon quloqli ayollar: 4-teri turi',
    '👯🏾‍♀' => 'quyon quloqli ayollar: 5-teri turi',
    '👯🏿‍♀' => 'quyon quloqli ayollar: 6-teri turi',
    '👯🏻‍♂' => 'quyon quloqli erkaklar: 1–2-teri turi',
    '👯🏼‍♂' => 'quyon quloqli erkaklar: 3-teri turi',
    '👯🏽‍♂' => 'quyon quloqli erkaklar: 4-teri turi',
    '👯🏾‍♂' => 'quyon quloqli erkaklar: 5-teri turi',
    '👯🏿‍♂' => 'quyon quloqli erkaklar: 6-teri turi',
    '🧖🏻‍♂' => 'hammomdagi erkak: 1–2-teri turi',
    '🧖🏼‍♂' => 'hammomdagi erkak: 3-teri turi',
    '🧖🏽‍♂' => 'hammomdagi erkak: 4-teri turi',
    '🧖🏾‍♂' => 'hammomdagi erkak: 5-teri turi',
    '🧖🏿‍♂' => 'hammomdagi erkak: 6-teri turi',
    '🧖🏻‍♀' => 'hammomdagi ayol: 1–2-teri turi',
    '🧖🏼‍♀' => 'hammomdagi ayol: 3-teri turi',
    '🧖🏽‍♀' => 'hammomdagi ayol: 4-teri turi',
    '🧖🏾‍♀' => 'hammomdagi ayol: 5-teri turi',
    '🧖🏿‍♀' => 'hammomdagi ayol: 6-teri turi',
    '🧗🏻‍♂' => 'cho‘qqiga chiqayotgan erkak: 1–2-teri turi',
    '🧗🏼‍♂' => 'cho‘qqiga chiqayotgan erkak: 3-teri turi',
    '🧗🏽‍♂' => 'cho‘qqiga chiqayotgan erkak: 4-teri turi',
    '🧗🏾‍♂' => 'cho‘qqiga chiqayotgan erkak: 5-teri turi',
    '🧗🏿‍♂' => 'cho‘qqiga chiqayotgan erkak: 6-teri turi',
    '🧗🏻‍♀' => 'cho‘qqiga chiqayotgan ayol: 1–2-teri turi',
    '🧗🏼‍♀' => 'cho‘qqiga chiqayotgan ayol: 3-teri turi',
    '🧗🏽‍♀' => 'cho‘qqiga chiqayotgan ayol: 4-teri turi',
    '🧗🏾‍♀' => 'cho‘qqiga chiqayotgan ayol: 5-teri turi',
    '🧗🏿‍♀' => 'cho‘qqiga chiqayotgan ayol: 6-teri turi',
    '🏌🏻‍♂' => 'erkak golf o‘ynamoqda: 1–2-teri turi',
    '🏌🏼‍♂' => 'erkak golf o‘ynamoqda: 3-teri turi',
    '🏌🏽‍♂' => 'erkak golf o‘ynamoqda: 4-teri turi',
    '🏌🏾‍♂' => 'erkak golf o‘ynamoqda: 5-teri turi',
    '🏌🏿‍♂' => 'erkak golf o‘ynamoqda: 6-teri turi',
    '🏌🏻‍♀' => 'ayol golf o‘ynamoqda: 1–2-teri turi',
    '🏌🏼‍♀' => 'ayol golf o‘ynamoqda: 3-teri turi',
    '🏌🏽‍♀' => 'ayol golf o‘ynamoqda: 4-teri turi',
    '🏌🏾‍♀' => 'ayol golf o‘ynamoqda: 5-teri turi',
    '🏌🏿‍♀' => 'ayol golf o‘ynamoqda: 6-teri turi',
    '🏄🏻‍♂' => 'erkak serfing qilmoqda: 1–2-teri turi',
    '🏄🏼‍♂' => 'erkak serfing qilmoqda: 3-teri turi',
    '🏄🏽‍♂' => 'erkak serfing qilmoqda: 4-teri turi',
    '🏄🏾‍♂' => 'erkak serfing qilmoqda: 5-teri turi',
    '🏄🏿‍♂' => 'erkak serfing qilmoqda: 6-teri turi',
    '🏄🏻‍♀' => 'ayol serfing qilmoqda: 1–2-teri turi',
    '🏄🏼‍♀' => 'ayol serfing qilmoqda: 3-teri turi',
    '🏄🏽‍♀' => 'ayol serfing qilmoqda: 4-teri turi',
    '🏄🏾‍♀' => 'ayol serfing qilmoqda: 5-teri turi',
    '🏄🏿‍♀' => 'ayol serfing qilmoqda: 6-teri turi',
    '🚣🏻‍♂' => 'erkak eshkak eshmoqda: 1–2-teri turi',
    '🚣🏼‍♂' => 'erkak eshkak eshmoqda: 3-teri turi',
    '🚣🏽‍♂' => 'erkak eshkak eshmoqda: 4-teri turi',
    '🚣🏾‍♂' => 'erkak eshkak eshmoqda: 5-teri turi',
    '🚣🏿‍♂' => 'erkak eshkak eshmoqda: 6-teri turi',
    '🚣🏻‍♀' => 'ayol eshkak eshmoqda: 1–2-teri turi',
    '🚣🏼‍♀' => 'ayol eshkak eshmoqda: 3-teri turi',
    '🚣🏽‍♀' => 'ayol eshkak eshmoqda: 4-teri turi',
    '🚣🏾‍♀' => 'ayol eshkak eshmoqda: 5-teri turi',
    '🚣🏿‍♀' => 'ayol eshkak eshmoqda: 6-teri turi',
    '🏊🏻‍♂' => 'suzayotgan erkak: 1–2-teri turi',
    '🏊🏼‍♂' => 'suzayotgan erkak: 3-teri turi',
    '🏊🏽‍♂' => 'suzayotgan erkak: 4-teri turi',
    '🏊🏾‍♂' => 'suzayotgan erkak: 5-teri turi',
    '🏊🏿‍♂' => 'suzayotgan erkak: 6-teri turi',
    '🏊🏻‍♀' => 'suzayotgan ayol: 1–2-teri turi',
    '🏊🏼‍♀' => 'suzayotgan ayol: 3-teri turi',
    '🏊🏽‍♀' => 'suzayotgan ayol: 4-teri turi',
    '🏊🏾‍♀' => 'suzayotgan ayol: 5-teri turi',
    '🏊🏿‍♀' => 'suzayotgan ayol: 6-teri turi',
    '⛹🏻‍♂' => 'koptokli erkak: 1–2-teri turi',
    '⛹🏼‍♂' => 'koptokli erkak: 3-teri turi',
    '⛹🏽‍♂' => 'koptokli erkak: 4-teri turi',
    '⛹🏾‍♂' => 'koptokli erkak: 5-teri turi',
    '⛹🏿‍♂' => 'koptokli erkak: 6-teri turi',
    '⛹🏻‍♀' => 'koptokli ayol: 1–2-teri turi',
    '⛹🏼‍♀' => 'koptokli ayol: 3-teri turi',
    '⛹🏽‍♀' => 'koptokli ayol: 4-teri turi',
    '⛹🏾‍♀' => 'koptokli ayol: 5-teri turi',
    '⛹🏿‍♀' => 'koptokli ayol: 6-teri turi',
    '🏋🏻‍♂' => 'erkak shtanga ko‘tarmoqda: 1–2-teri turi',
    '🏋🏼‍♂' => 'erkak shtanga ko‘tarmoqda: 3-teri turi',
    '🏋🏽‍♂' => 'erkak shtanga ko‘tarmoqda: 4-teri turi',
    '🏋🏾‍♂' => 'erkak shtanga ko‘tarmoqda: 5-teri turi',
    '🏋🏿‍♂' => 'erkak shtanga ko‘tarmoqda: 6-teri turi',
    '🏋🏻‍♀' => 'ayol shtanga ko‘tarmoqda: 1–2-teri turi',
    '🏋🏼‍♀' => 'ayol shtanga ko‘tarmoqda: 3-teri turi',
    '🏋🏽‍♀' => 'ayol shtanga ko‘tarmoqda: 4-teri turi',
    '🏋🏾‍♀' => 'ayol shtanga ko‘tarmoqda: 5-teri turi',
    '🏋🏿‍♀' => 'ayol shtanga ko‘tarmoqda: 6-teri turi',
    '🚴🏻‍♂' => 'erkak velosipedda: 1–2-teri turi',
    '🚴🏼‍♂' => 'erkak velosipedda: 3-teri turi',
    '🚴🏽‍♂' => 'erkak velosipedda: 4-teri turi',
    '🚴🏾‍♂' => 'erkak velosipedda: 5-teri turi',
    '🚴🏿‍♂' => 'erkak velosipedda: 6-teri turi',
    '🚴🏻‍♀' => 'ayol velosipedda: 1–2-teri turi',
    '🚴🏼‍♀' => 'ayol velosipedda: 3-teri turi',
    '🚴🏽‍♀' => 'ayol velosipedda: 4-teri turi',
    '🚴🏾‍♀' => 'ayol velosipedda: 5-teri turi',
    '🚴🏿‍♀' => 'ayol velosipedda: 6-teri turi',
    '🚵🏻‍♂' => 'erkak tog‘da velosipedda: 1–2-teri turi',
    '🚵🏼‍♂' => 'erkak tog‘da velosipedda: 3-teri turi',
    '🚵🏽‍♂' => 'erkak tog‘da velosipedda: 4-teri turi',
    '🚵🏾‍♂' => 'erkak tog‘da velosipedda: 5-teri turi',
    '🚵🏿‍♂' => 'erkak tog‘da velosipedda: 6-teri turi',
    '🚵🏻‍♀' => 'ayol tog‘da velosipedda: 1–2-teri turi',
    '🚵🏼‍♀' => 'ayol tog‘da velosipedda: 3-teri turi',
    '🚵🏽‍♀' => 'ayol tog‘da velosipedda: 4-teri turi',
    '🚵🏾‍♀' => 'ayol tog‘da velosipedda: 5-teri turi',
    '🚵🏿‍♀' => 'ayol tog‘da velosipedda: 6-teri turi',
    '🤸🏻‍♂' => 'erkak o‘mbaloq oshmoqda: 1–2-teri turi',
    '🤸🏼‍♂' => 'erkak o‘mbaloq oshmoqda: 3-teri turi',
    '🤸🏽‍♂' => 'erkak o‘mbaloq oshmoqda: 4-teri turi',
    '🤸🏾‍♂' => 'erkak o‘mbaloq oshmoqda: 5-teri turi',
    '🤸🏿‍♂' => 'erkak o‘mbaloq oshmoqda: 6-teri turi',
    '🤸🏻‍♀' => 'ayol o‘mbaloq oshmoqda: 1–2-teri turi',
    '🤸🏼‍♀' => 'ayol o‘mbaloq oshmoqda: 3-teri turi',
    '🤸🏽‍♀' => 'ayol o‘mbaloq oshmoqda: 4-teri turi',
    '🤸🏾‍♀' => 'ayol o‘mbaloq oshmoqda: 5-teri turi',
    '🤸🏿‍♀' => 'ayol o‘mbaloq oshmoqda: 6-teri turi',
    '🤼🏻‍♀' => 'kurashayotgan ayol: 1–2-teri turi',
    '🤼🏼‍♀' => 'kurashayotgan ayol: 3-teri turi',
    '🤼🏽‍♀' => 'kurashayotgan ayol: 4-teri turi',
    '🤼🏾‍♀' => 'kurashayotgan ayol: 5-teri turi',
    '🤼🏿‍♀' => 'kurashayotgan ayol: 6-teri turi',
    '🤼🏻‍♂' => 'kurashayotgan erkak: 1–2-teri turi',
    '🤼🏼‍♂' => 'kurashayotgan erkak: 3-teri turi',
    '🤼🏽‍♂' => 'kurashayotgan erkak: 4-teri turi',
    '🤼🏾‍♂' => 'kurashayotgan erkak: 5-teri turi',
    '🤼🏿‍♂' => 'kurashayotgan erkak: 6-teri turi',
    '🤽🏻‍♂' => 'erkak suv polosi o‘ynamoqda: 1–2-teri turi',
    '🤽🏼‍♂' => 'erkak suv polosi o‘ynamoqda: 3-teri turi',
    '🤽🏽‍♂' => 'erkak suv polosi o‘ynamoqda: 4-teri turi',
    '🤽🏾‍♂' => 'erkak suv polosi o‘ynamoqda: 5-teri turi',
    '🤽🏿‍♂' => 'erkak suv polosi o‘ynamoqda: 6-teri turi',
    '🤽🏻‍♀' => 'ayol suv polosi o‘ynamoqda: 1–2-teri turi',
    '🤽🏼‍♀' => 'ayol suv polosi o‘ynamoqda: 3-teri turi',
    '🤽🏽‍♀' => 'ayol suv polosi o‘ynamoqda: 4-teri turi',
    '🤽🏾‍♀' => 'ayol suv polosi o‘ynamoqda: 5-teri turi',
    '🤽🏿‍♀' => 'ayol suv polosi o‘ynamoqda: 6-teri turi',
    '🤾🏻‍♂' => 'erkak gandbol o‘ynamoqda: 1–2-teri turi',
    '🤾🏼‍♂' => 'erkak gandbol o‘ynamoqda: 3-teri turi',
    '🤾🏽‍♂' => 'erkak gandbol o‘ynamoqda: 4-teri turi',
    '🤾🏾‍♂' => 'erkak gandbol o‘ynamoqda: 5-teri turi',
    '🤾🏿‍♂' => 'erkak gandbol o‘ynamoqda: 6-teri turi',
    '🤾🏻‍♀' => 'ayol gandbol o‘ynamoqda: 1–2-teri turi',
    '🤾🏼‍♀' => 'ayol gandbol o‘ynamoqda: 3-teri turi',
    '🤾🏽‍♀' => 'ayol gandbol o‘ynamoqda: 4-teri turi',
    '🤾🏾‍♀' => 'ayol gandbol o‘ynamoqda: 5-teri turi',
    '🤾🏿‍♀' => 'ayol gandbol o‘ynamoqda: 6-teri turi',
    '🤹🏻‍♂' => 'erkak jonglyorlik qilmoqda: 1–2-teri turi',
    '🤹🏼‍♂' => 'erkak jonglyorlik qilmoqda: 3-teri turi',
    '🤹🏽‍♂' => 'erkak jonglyorlik qilmoqda: 4-teri turi',
    '🤹🏾‍♂' => 'erkak jonglyorlik qilmoqda: 5-teri turi',
    '🤹🏿‍♂' => 'erkak jonglyorlik qilmoqda: 6-teri turi',
    '🤹🏻‍♀' => 'ayol jonglyorlik qilmoqda: 1–2-teri turi',
    '🤹🏼‍♀' => 'ayol jonglyorlik qilmoqda: 3-teri turi',
    '🤹🏽‍♀' => 'ayol jonglyorlik qilmoqda: 4-teri turi',
    '🤹🏾‍♀' => 'ayol jonglyorlik qilmoqda: 5-teri turi',
    '🤹🏿‍♀' => 'ayol jonglyorlik qilmoqda: 6-teri turi',
    '🧘🏻‍♂' => 'lotus holatidagi erkak: 1–2-teri turi',
    '🧘🏼‍♂' => 'lotus holatidagi erkak: 3-teri turi',
    '🧘🏽‍♂' => 'lotus holatidagi erkak: 4-teri turi',
    '🧘🏾‍♂' => 'lotus holatidagi erkak: 5-teri turi',
    '🧘🏿‍♂' => 'lotus holatidagi erkak: 6-teri turi',
    '🧘🏻‍♀' => 'lotus holatidagi ayol: 1–2-teri turi',
    '🧘🏼‍♀' => 'lotus holatidagi ayol: 3-teri turi',
    '🧘🏽‍♀' => 'lotus holatidagi ayol: 4-teri turi',
    '🧘🏾‍♀' => 'lotus holatidagi ayol: 5-teri turi',
    '🧘🏿‍♀' => 'lotus holatidagi ayol: 6-teri turi',
    '🧑‍🦰' => 'voyaga yetgan: malla soch',
    '🧑‍🦱' => 'voyaga yetgan: jingalak soch',
    '🧑‍🦳' => 'voyaga yetgan: oqargan soch',
    '🧑‍🦲' => 'voyaga yetgan: kal',
    '👨‍🦰' => 'erkak: malla soch',
    '👨‍🦱' => 'erkak: jingalak soch',
    '👨‍🦳' => 'erkak: oqargan soch',
    '👨‍🦲' => 'erkak: kal',
    '👩‍🦰' => 'ayol: malla soch',
    '👩‍🦱' => 'ayol: jingalak soch',
    '👩‍🦳' => 'ayol: oqargan soch',
    '👩‍🦲' => 'ayol: kal',
    '🚶‍➡' => 'piyoda odam: o‘ngga qaragan',
    '🧎‍➡' => 'tiz choʻkkan odam: o‘ngga qaragan',
    '🏃‍➡' => 'yuguruvchi: o‘ngga qaragan',
    '👨‍👦' => 'oila: erkak o‘g‘il bola',
    '👨‍👧' => 'oila: erkak qiz bola',
    '👩‍👦' => 'oila: ayol o‘g‘il bola',
    '👩‍👧' => 'oila: ayol qiz bola',
    '😶‍🌫' => 'bulutdagi yuz',
    '😮‍💨' => 'nafas chiqarayotgan yuz',
    '🙂‍↕' => 'vertikal yo‘nalishda tebranayotgan yuz',
    '😵‍💫' => 'spiral koʻzli yuz',
    '❤‍🔥' => 'olovdagi yurak',
    '❤‍🩹' => 'yurakka malham',
    '👁‍🗨' => 'nutq pufagida ko‘z',
    '🧔‍♂' => 'soqolli erkak',
    '👱‍♂' => 'erkak: mallasoch',
    '🧔‍♀' => 'soqolli ayol',
    '👱‍♀' => 'ayol: mallasoch',
    '🙍‍♂' => 'xo‘mraygan erkak',
    '🙍‍♀' => 'xo‘mraygan ayol',
    '🙎‍♂' => 'arazlagan erkak',
    '🙎‍♀' => 'arazlagan ayol',
    '🙅‍♂' => 'erkak yo‘q demoqda',
    '🙅‍♀' => 'ayol yo‘q demoqda',
    '🙆‍♂' => 'erkak ha demoqda',
    '🙆‍♀' => 'ayol ha demoqda',
    '💁‍♂' => 'erkak qo‘l cho‘zmoqda',
    '💁‍♀' => 'ayol qo‘l cho‘zmoqda',
    '🙋‍♂' => 'erkak qo‘l ko‘tarmoqda',
    '🙋‍♀' => 'ayol qo‘l ko‘tarmoqda',
    '🧏‍♂' => 'kar erkak',
    '🧏‍♀' => 'kar ayol',
    '🙇‍♂' => 'erkak ta’zim qilmoqda',
    '🙇‍♀' => 'ayol ta’zim qilmoqda',
    '🤦‍♂' => 'erkak yuzini berkitmoqda',
    '🤦‍♀' => 'ayol yuzini berkitmoqda',
    '🤷‍♂' => 'erkak yelka qismoqda',
    '🤷‍♀' => 'ayol yelka qismoqda',
    '🧑‍⚕' => 'tibbiyot xodimi',
    '👨‍⚕' => 'erkak shifokor',
    '👩‍⚕' => 'ayol shifokor',
    '🧑‍🎓' => 'talaba',
    '👨‍🎓' => 'erkak talaba',
    '👩‍🎓' => 'ayol talaba',
    '🧑‍🏫' => 'oʻqituvchi',
    '👨‍🏫' => 'erkak o‘qituvchi',
    '👩‍🏫' => 'ayol o‘qituvchi',
    '🧑‍⚖' => 'sudya',
    '👨‍⚖' => 'erkak sudya',
    '👩‍⚖' => 'ayol sudya',
    '🧑‍🌾' => 'fermer',
    '👨‍🌾' => 'erkak fermer',
    '👩‍🌾' => 'ayol fermer',
    '🧑‍🍳' => 'oshpaz',
    '👨‍🍳' => 'erkak oshpaz',
    '👩‍🍳' => 'ayol oshpaz',
    '🧑‍🔧' => 'mexanik',
    '👨‍🔧' => 'erkak mexanik',
    '👩‍🔧' => 'ayol mexanik',
    '🧑‍🏭' => 'zavod ishchisi',
    '👨‍🏭' => 'erkak zavod ishchisi',
    '👩‍🏭' => 'ayol zavod ishchisi',
    '🧑‍💼' => 'ofis xodimi',
    '👨‍💼' => 'erkak ofis xodimi',
    '👩‍💼' => 'ayol ofis xodimi',
    '🧑‍🔬' => 'olim',
    '👨‍🔬' => 'erkak olim',
    '👩‍🔬' => 'ayol olim',
    '🧑‍💻' => 'texnolog',
    '👨‍💻' => 'erkak texnolog',
    '👩‍💻' => 'ayol texnolog',
    '🧑‍🎤' => 'qoʻshiqchi',
    '👨‍🎤' => 'erkak qo‘shiqchi',
    '👩‍🎤' => 'ayol qo‘shiqchi',
    '🧑‍🎨' => 'rassom',
    '👨‍🎨' => 'erkak rassom',
    '👩‍🎨' => 'ayol rassom',
    '🧑‍✈' => 'uchuvchi',
    '👨‍✈' => 'erkak uchuvchi',
    '👩‍✈' => 'ayol uchuvchi',
    '🧑‍🚀' => 'astronavt',
    '👨‍🚀' => 'erkak kosmonavt',
    '👩‍🚀' => 'ayol kosmonavt',
    '🧑‍🚒' => 'oʻt oʻchiruvchi',
    '👨‍🚒' => 'erkak o‘t o‘chiruvchi',
    '👩‍🚒' => 'ayol o‘t o‘chiruvchi',
    '👮‍♂' => 'erkak politsiyachi',
    '👮‍♀' => 'ayol politsiyachi',
    '🕵‍♂' => 'erkak izquvar',
    '🕵‍♀' => 'ayol izquvar',
    '💂‍♂' => 'erkak qo‘riqchi',
    '💂‍♀' => 'ayol qo‘riqchi',
    '👷‍♂' => 'erkak quruvchi',
    '👷‍♀' => 'ayol quruvchi',
    '👳‍♂' => 'sallali erkak',
    '👳‍♀' => 'sallali ayol',
    '🤵‍♂' => 'smoking kiygan kishi',
    '🤵‍♀' => 'smoking kiygan ayol',
    '👰‍♂' => 'xarir parda taqib olgan erkak',
    '👰‍♀' => 'xarir parda taqib olgan ayol',
    '👩‍🍼' => 'chaqaloq emizayotgan ayol',
    '👨‍🍼' => 'chaqaloq emizayotgan erkak',
    '🧑‍🍼' => 'chaqaloq emizayotgan kishi',
    '🧑‍🎄' => 'miks-klauz',
    '🦸‍♂' => 'erkak qahramon',
    '🦸‍♀' => 'ayol superqahramon',
    '🦹‍♂' => 'salbiy erkak superqahramon',
    '🦹‍♀' => 'salbiy ayol superqahramon',
    '🧙‍♂' => 'erkak sehrgar',
    '🧙‍♀' => 'ayol sehrgar',
    '🧚‍♂' => 'erkak pari',
    '🧚‍♀' => 'ayol pari',
    '🧛‍♂' => 'erkak vampir',
    '🧛‍♀' => 'ayol vampir',
    '🧜‍♂' => 'triton',
    '🧜‍♀' => 'ayol suv parisi',
    '🧝‍♂' => 'erkak elf',
    '🧝‍♀' => 'ayol elf',
    '🧞‍♂' => 'erkak jin',
    '🧞‍♀' => 'ayol jin',
    '🧟‍♂' => 'erkak zombi',
    '🧟‍♀' => 'ayol zombi',
    '💆‍♂' => 'erkak yuziga massaj olmoqda',
    '💆‍♀' => 'ayol yuziga massaj olmoqda',
    '💇‍♂' => 'erkak soch kaltalatmoqda',
    '💇‍♀' => 'ayol soch kaltalatmoqda',
    '🚶‍♂' => 'yurayotgan erkak',
    '🚶‍♀' => 'yurayotgan ayol',
    '🧍‍♂' => 'tik turgan erkak',
    '🧍‍♀' => 'tik turgan ayol',
    '🧎‍♂' => 'tiz choʻkkan erkak',
    '🧎‍♀' => 'tiz choʻkkan ayol',
    '🧑‍🦯' => 'hassali odam',
    '👨‍🦯' => 'hassali kishi',
    '👩‍🦯' => 'hassali ayol',
    '🧑‍🦼' => 'motorli nogironlar aravachasidagi odam',
    '👨‍🦼' => 'motorli nogironlik aravachasidagi erkak',
    '👩‍🦼' => 'motorli nogironlik aravachasidagi ayol',
    '🧑‍🦽' => 'nogironlar aravachasidagi odam',
    '👨‍🦽' => 'nogironlik aravachasidagi erkak',
    '👩‍🦽' => 'nogironlik aravachasidagi ayol',
    '🏃‍♂' => 'yugurayotgan erkak',
    '🏃‍♀' => 'yugurayotgan ayol',
    '🧑‍🩰' => 'baletchi',
    '👯‍♂' => 'quyon quloqli erkaklar',
    '👯‍♀' => 'quyon quloqli ayollar',
    '🧖‍♂' => 'hammomdagi erkak',
    '🧖‍♀' => 'hammomdagi ayol',
    '🧗‍♂' => 'cho‘qqiga chiqayotgan erkak',
    '🧗‍♀' => 'cho‘qqiga chiqayotgan ayol',
    '🏌‍♂' => 'erkak golf o‘ynamoqda',
    '🏌‍♀' => 'ayol golf o‘ynamoqda',
    '🏄‍♂' => 'erkak serfing qilmoqda',
    '🏄‍♀' => 'ayol serfing qilmoqda',
    '🚣‍♂' => 'erkak eshkak eshmoqda',
    '🚣‍♀' => 'ayol eshkak eshmoqda',
    '🏊‍♂' => 'suzayotgan erkak',
    '🏊‍♀' => 'suzayotgan ayol',
    '⛹‍♂' => 'koptokli erkak',
    '⛹‍♀' => 'koptokli ayol',
    '🏋‍♂' => 'erkak shtanga ko‘tarmoqda',
    '🏋‍♀' => 'ayol shtanga ko‘tarmoqda',
    '🚴‍♂' => 'erkak velosipedda',
    '🚴‍♀' => 'ayol velosipedda',
    '🚵‍♂' => 'erkak tog‘da velosipedda',
    '🚵‍♀' => 'ayol tog‘da velosipedda',
    '🤸‍♂' => 'erkak o‘mbaloq oshmoqda',
    '🤸‍♀' => 'ayol o‘mbaloq oshmoqda',
    '🤼‍♂' => 'kurashayotgan erkak',
    '🤼‍♀' => 'kurashayotgan ayol',
    '🤽‍♂' => 'erkak suv polosi o‘ynamoqda',
    '🤽‍♀' => 'ayol suv polosi o‘ynamoqda',
    '🤾‍♂' => 'erkak gandbol o‘ynamoqda',
    '🤾‍♀' => 'ayol gandbol o‘ynamoqda',
    '🤹‍♂' => 'erkak jonglyorlik qilmoqda',
    '🤹‍♀' => 'ayol jonglyorlik qilmoqda',
    '🧘‍♂' => 'lotus holatidagi erkak',
    '🧘‍♀' => 'lotus holatidagi ayol',
    '🧑‍🧒' => 'oila: bitta katta odam, bir bola',
    '🐕‍🦺' => 'xizmat iti',
    '🐈‍⬛' => 'qora mushuk',
    '🐻‍❄' => 'qutb ayig‘i',
    '🐦‍⬛' => 'qora qush',
    '🐦‍🔥' => 'qaqnus',
    '🍋‍🟩' => 'laym',
    '🍄‍🟫' => 'qoʻngʻir qoʻziqorin',
    '⛓‍💥' => 'uzilgan zanjir',
    '🏳‍🌈' => 'kamalak bayroq',
    '🏳‍⚧' => 'moviy, pushti va oq bayroq',
    '🏴‍☠' => 'dengiz qaroqchilari bayrog‘i',
    '👋🏻' => 'shapaloq: 1–2-teri turi',
    '👋🏼' => 'shapaloq: 3-teri turi',
    '👋🏽' => 'shapaloq: 4-teri turi',
    '👋🏾' => 'shapaloq: 5-teri turi',
    '👋🏿' => 'shapaloq: 6-teri turi',
    '🤚🏻' => 'ko‘tarilgan kaft: 1–2-teri turi',
    '🤚🏼' => 'ko‘tarilgan kaft: 3-teri turi',
    '🤚🏽' => 'ko‘tarilgan kaft: 4-teri turi',
    '🤚🏾' => 'ko‘tarilgan kaft: 5-teri turi',
    '🤚🏿' => 'ko‘tarilgan kaft: 6-teri turi',
    '🖐🏻' => 'barmoqlari yoyilgan qoʻl: 1–2-teri turi',
    '🖐🏼' => 'barmoqlari yoyilgan qoʻl: 3-teri turi',
    '🖐🏽' => 'barmoqlari yoyilgan qoʻl: 4-teri turi',
    '🖐🏾' => 'barmoqlari yoyilgan qoʻl: 5-teri turi',
    '🖐🏿' => 'barmoqlari yoyilgan qoʻl: 6-teri turi',
    '✋🏻' => 'ko‘tarilgan qo‘l: 1–2-teri turi',
    '✋🏼' => 'ko‘tarilgan qo‘l: 3-teri turi',
    '✋🏽' => 'ko‘tarilgan qo‘l: 4-teri turi',
    '✋🏾' => 'ko‘tarilgan qo‘l: 5-teri turi',
    '✋🏿' => 'ko‘tarilgan qo‘l: 6-teri turi',
    '🖖🏻' => 'vulkan salyuti: 1–2-teri turi',
    '🖖🏼' => 'vulkan salyuti: 3-teri turi',
    '🖖🏽' => 'vulkan salyuti: 4-teri turi',
    '🖖🏾' => 'vulkan salyuti: 5-teri turi',
    '🖖🏿' => 'vulkan salyuti: 6-teri turi',
    '🫱🏻' => 'oʻng qoʻl: 1–2-teri turi',
    '🫱🏼' => 'oʻng qoʻl: 3-teri turi',
    '🫱🏽' => 'oʻng qoʻl: 4-teri turi',
    '🫱🏾' => 'oʻng qoʻl: 5-teri turi',
    '🫱🏿' => 'oʻng qoʻl: 6-teri turi',
    '🫲🏻' => 'chap qoʻl: 1–2-teri turi',
    '🫲🏼' => 'chap qoʻl: 3-teri turi',
    '🫲🏽' => 'chap qoʻl: 4-teri turi',
    '🫲🏾' => 'chap qoʻl: 5-teri turi',
    '🫲🏿' => 'chap qoʻl: 6-teri turi',
    '🫳🏻' => 'kafti pastga qaragan qoʻl: 1–2-teri turi',
    '🫳🏼' => 'kafti pastga qaragan qoʻl: 3-teri turi',
    '🫳🏽' => 'kafti pastga qaragan qoʻl: 4-teri turi',
    '🫳🏾' => 'kafti pastga qaragan qoʻl: 5-teri turi',
    '🫳🏿' => 'kafti pastga qaragan qoʻl: 6-teri turi',
    '🫴🏻' => 'kafti yuqoriga qaragan qoʻl: 1–2-teri turi',
    '🫴🏼' => 'kafti yuqoriga qaragan qoʻl: 3-teri turi',
    '🫴🏽' => 'kafti yuqoriga qaragan qoʻl: 4-teri turi',
    '🫴🏾' => 'kafti yuqoriga qaragan qoʻl: 5-teri turi',
    '🫴🏿' => 'kafti yuqoriga qaragan qoʻl: 6-teri turi',
    '🫷🏻' => 'kafti chapga qaragan qoʻl: 1–2-teri turi',
    '🫷🏼' => 'kafti chapga qaragan qoʻl: 3-teri turi',
    '🫷🏽' => 'kafti chapga qaragan qoʻl: 4-teri turi',
    '🫷🏾' => 'kafti chapga qaragan qoʻl: 5-teri turi',
    '🫷🏿' => 'kafti chapga qaragan qoʻl: 6-teri turi',
    '🫸🏻' => 'kafti oʻngga qaragan qoʻl: 1–2-teri turi',
    '🫸🏼' => 'kafti oʻngga qaragan qoʻl: 3-teri turi',
    '🫸🏽' => 'kafti oʻngga qaragan qoʻl: 4-teri turi',
    '🫸🏾' => 'kafti oʻngga qaragan qoʻl: 5-teri turi',
    '🫸🏿' => 'kafti oʻngga qaragan qoʻl: 6-teri turi',
    '👌🏻' => 'qo‘lda qilingan ok: 1–2-teri turi',
    '👌🏼' => 'qo‘lda qilingan ok: 3-teri turi',
    '👌🏽' => 'qo‘lda qilingan ok: 4-teri turi',
    '👌🏾' => 'qo‘lda qilingan ok: 5-teri turi',
    '👌🏿' => 'qo‘lda qilingan ok: 6-teri turi',
    '🤌🏻' => 'chimdilgan barmoqlar: 1–2-teri turi',
    '🤌🏼' => 'chimdilgan barmoqlar: 3-teri turi',
    '🤌🏽' => 'chimdilgan barmoqlar: 4-teri turi',
    '🤌🏾' => 'chimdilgan barmoqlar: 5-teri turi',
    '🤌🏿' => 'chimdilgan barmoqlar: 6-teri turi',
    '🤏🏻' => 'chimduvchi qoʻl: 1–2-teri turi',
    '🤏🏼' => 'chimduvchi qoʻl: 3-teri turi',
    '🤏🏽' => 'chimduvchi qoʻl: 4-teri turi',
    '🤏🏾' => 'chimduvchi qoʻl: 5-teri turi',
    '🤏🏿' => 'chimduvchi qoʻl: 6-teri turi',
    '✌🏻' => 'v harfini ko‘rsatib turgan qo‘l: 1–2-teri turi',
    '✌🏼' => 'v harfini ko‘rsatib turgan qo‘l: 3-teri turi',
    '✌🏽' => 'v harfini ko‘rsatib turgan qo‘l: 4-teri turi',
    '✌🏾' => 'v harfini ko‘rsatib turgan qo‘l: 5-teri turi',
    '✌🏿' => 'v harfini ko‘rsatib turgan qo‘l: 6-teri turi',
    '🤞🏻' => 'kesishgan barmoqlar: 1–2-teri turi',
    '🤞🏼' => 'kesishgan barmoqlar: 3-teri turi',
    '🤞🏽' => 'kesishgan barmoqlar: 4-teri turi',
    '🤞🏾' => 'kesishgan barmoqlar: 5-teri turi',
    '🤞🏿' => 'kesishgan barmoqlar: 6-teri turi',
    '🫰🏻' => 'bosh va koʻrsatkich barmoqlar kesishgan qoʻl: 1–2-teri turi',
    '🫰🏼' => 'bosh va koʻrsatkich barmoqlar kesishgan qoʻl: 3-teri turi',
    '🫰🏽' => 'bosh va koʻrsatkich barmoqlar kesishgan qoʻl: 4-teri turi',
    '🫰🏾' => 'bosh va koʻrsatkich barmoqlar kesishgan qoʻl: 5-teri turi',
    '🫰🏿' => 'bosh va koʻrsatkich barmoqlar kesishgan qoʻl: 6-teri turi',
    '🤟🏻' => 'sevaman degan ishora: 1–2-teri turi',
    '🤟🏼' => 'sevaman degan ishora: 3-teri turi',
    '🤟🏽' => 'sevaman degan ishora: 4-teri turi',
    '🤟🏾' => 'sevaman degan ishora: 5-teri turi',
    '🤟🏿' => 'sevaman degan ishora: 6-teri turi',
    '🤘🏻' => 'shox belgisi: 1–2-teri turi',
    '🤘🏼' => 'shox belgisi: 3-teri turi',
    '🤘🏽' => 'shox belgisi: 4-teri turi',
    '🤘🏾' => 'shox belgisi: 5-teri turi',
    '🤘🏿' => 'shox belgisi: 6-teri turi',
    '🤙🏻' => 'menga telefon qil: 1–2-teri turi',
    '🤙🏼' => 'menga telefon qil: 3-teri turi',
    '🤙🏽' => 'menga telefon qil: 4-teri turi',
    '🤙🏾' => 'menga telefon qil: 5-teri turi',
    '🤙🏿' => 'menga telefon qil: 6-teri turi',
    '👈🏻' => 'ko‘rsatkich barmoq chapga: 1–2-teri turi',
    '👈🏼' => 'ko‘rsatkich barmoq chapga: 3-teri turi',
    '👈🏽' => 'ko‘rsatkich barmoq chapga: 4-teri turi',
    '👈🏾' => 'ko‘rsatkich barmoq chapga: 5-teri turi',
    '👈🏿' => 'ko‘rsatkich barmoq chapga: 6-teri turi',
    '👉🏻' => 'ko‘rsatkich barmoq oʻngga: 1–2-teri turi',
    '👉🏼' => 'ko‘rsatkich barmoq oʻngga: 3-teri turi',
    '👉🏽' => 'ko‘rsatkich barmoq oʻngga: 4-teri turi',
    '👉🏾' => 'ko‘rsatkich barmoq oʻngga: 5-teri turi',
    '👉🏿' => 'ko‘rsatkich barmoq oʻngga: 6-teri turi',
    '👆🏻' => 'ko‘rsatkich barmoq tepaga: 1–2-teri turi',
    '👆🏼' => 'ko‘rsatkich barmoq tepaga: 3-teri turi',
    '👆🏽' => 'ko‘rsatkich barmoq tepaga: 4-teri turi',
    '👆🏾' => 'ko‘rsatkich barmoq tepaga: 5-teri turi',
    '👆🏿' => 'ko‘rsatkich barmoq tepaga: 6-teri turi',
    '🖕🏻' => 'o‘rta barmoq: 1–2-teri turi',
    '🖕🏼' => 'o‘rta barmoq: 3-teri turi',
    '🖕🏽' => 'o‘rta barmoq: 4-teri turi',
    '🖕🏾' => 'o‘rta barmoq: 5-teri turi',
    '🖕🏿' => 'o‘rta barmoq: 6-teri turi',
    '👇🏻' => 'ko‘rsatkich barmoq pastga: 1–2-teri turi',
    '👇🏼' => 'ko‘rsatkich barmoq pastga: 3-teri turi',
    '👇🏽' => 'ko‘rsatkich barmoq pastga: 4-teri turi',
    '👇🏾' => 'ko‘rsatkich barmoq pastga: 5-teri turi',
    '👇🏿' => 'ko‘rsatkich barmoq pastga: 6-teri turi',
    '☝🏻' => 'ko‘rsatkich barmoq tepada: 1–2-teri turi',
    '☝🏼' => 'ko‘rsatkich barmoq tepada: 3-teri turi',
    '☝🏽' => 'ko‘rsatkich barmoq tepada: 4-teri turi',
    '☝🏾' => 'ko‘rsatkich barmoq tepada: 5-teri turi',
    '☝🏿' => 'ko‘rsatkich barmoq tepada: 6-teri turi',
    '🫵🏻' => 'tomoshabinga qaragan koʻrsatkich barmoq: 1–2-teri turi',
    '🫵🏼' => 'tomoshabinga qaragan koʻrsatkich barmoq: 3-teri turi',
    '🫵🏽' => 'tomoshabinga qaragan koʻrsatkich barmoq: 4-teri turi',
    '🫵🏾' => 'tomoshabinga qaragan koʻrsatkich barmoq: 5-teri turi',
    '🫵🏿' => 'tomoshabinga qaragan koʻrsatkich barmoq: 6-teri turi',
    '👍🏻' => 'tepaga qaragan bosh barmoq: 1–2-teri turi',
    '👍🏼' => 'tepaga qaragan bosh barmoq: 3-teri turi',
    '👍🏽' => 'tepaga qaragan bosh barmoq: 4-teri turi',
    '👍🏾' => 'tepaga qaragan bosh barmoq: 5-teri turi',
    '👍🏿' => 'tepaga qaragan bosh barmoq: 6-teri turi',
    '👎🏻' => 'pastga qaragan bosh barmoq: 1–2-teri turi',
    '👎🏼' => 'pastga qaragan bosh barmoq: 3-teri turi',
    '👎🏽' => 'pastga qaragan bosh barmoq: 4-teri turi',
    '👎🏾' => 'pastga qaragan bosh barmoq: 5-teri turi',
    '👎🏿' => 'pastga qaragan bosh barmoq: 6-teri turi',
    '✊🏻' => 'ko‘tarilgan musht: 1–2-teri turi',
    '✊🏼' => 'ko‘tarilgan musht: 3-teri turi',
    '✊🏽' => 'ko‘tarilgan musht: 4-teri turi',
    '✊🏾' => 'ko‘tarilgan musht: 5-teri turi',
    '✊🏿' => 'ko‘tarilgan musht: 6-teri turi',
    '👊🏻' => 'yaqinlashayotgan musht: 1–2-teri turi',
    '👊🏼' => 'yaqinlashayotgan musht: 3-teri turi',
    '👊🏽' => 'yaqinlashayotgan musht: 4-teri turi',
    '👊🏾' => 'yaqinlashayotgan musht: 5-teri turi',
    '👊🏿' => 'yaqinlashayotgan musht: 6-teri turi',
    '🤛🏻' => 'chapga qaragan musht: 1–2-teri turi',
    '🤛🏼' => 'chapga qaragan musht: 3-teri turi',
    '🤛🏽' => 'chapga qaragan musht: 4-teri turi',
    '🤛🏾' => 'chapga qaragan musht: 5-teri turi',
    '🤛🏿' => 'chapga qaragan musht: 6-teri turi',
    '🤜🏻' => 'o‘ngga qaragan musht: 1–2-teri turi',
    '🤜🏼' => 'o‘ngga qaragan musht: 3-teri turi',
    '🤜🏽' => 'o‘ngga qaragan musht: 4-teri turi',
    '🤜🏾' => 'o‘ngga qaragan musht: 5-teri turi',
    '🤜🏿' => 'o‘ngga qaragan musht: 6-teri turi',
    '👏🏻' => 'chapak: 1–2-teri turi',
    '👏🏼' => 'chapak: 3-teri turi',
    '👏🏽' => 'chapak: 4-teri turi',
    '👏🏾' => 'chapak: 5-teri turi',
    '👏🏿' => 'chapak: 6-teri turi',
    '🙌🏻' => 'qo‘llarini ko‘targan odam: 1–2-teri turi',
    '🙌🏼' => 'qo‘llarini ko‘targan odam: 3-teri turi',
    '🙌🏽' => 'qo‘llarini ko‘targan odam: 4-teri turi',
    '🙌🏾' => 'qo‘llarini ko‘targan odam: 5-teri turi',
    '🙌🏿' => 'qo‘llarini ko‘targan odam: 6-teri turi',
    '🫶🏻' => 'qoʻlda yurak: 1–2-teri turi',
    '🫶🏼' => 'qoʻlda yurak: 3-teri turi',
    '🫶🏽' => 'qoʻlda yurak: 4-teri turi',
    '🫶🏾' => 'qoʻlda yurak: 5-teri turi',
    '🫶🏿' => 'qoʻlda yurak: 6-teri turi',
    '👐🏻' => 'ochiq qo‘llar: 1–2-teri turi',
    '👐🏼' => 'ochiq qo‘llar: 3-teri turi',
    '👐🏽' => 'ochiq qo‘llar: 4-teri turi',
    '👐🏾' => 'ochiq qo‘llar: 5-teri turi',
    '👐🏿' => 'ochiq qo‘llar: 6-teri turi',
    '🤲🏻' => 'kaftlar ochiq: 1–2-teri turi',
    '🤲🏼' => 'kaftlar ochiq: 3-teri turi',
    '🤲🏽' => 'kaftlar ochiq: 4-teri turi',
    '🤲🏾' => 'kaftlar ochiq: 5-teri turi',
    '🤲🏿' => 'kaftlar ochiq: 6-teri turi',
    '🤝🏻' => 'qo‘l siqish: 1–2-teri turi',
    '🤝🏼' => 'qo‘l siqish: 3-teri turi',
    '🤝🏽' => 'qo‘l siqish: 4-teri turi',
    '🤝🏾' => 'qo‘l siqish: 5-teri turi',
    '🤝🏿' => 'qo‘l siqish: 6-teri turi',
    '🙏🏻' => 'qovushtirilgan qo‘llar: 1–2-teri turi',
    '🙏🏼' => 'qovushtirilgan qo‘llar: 3-teri turi',
    '🙏🏽' => 'qovushtirilgan qo‘llar: 4-teri turi',
    '🙏🏾' => 'qovushtirilgan qo‘llar: 5-teri turi',
    '🙏🏿' => 'qovushtirilgan qo‘llar: 6-teri turi',
    '✍🏻' => 'yozayotgan qo‘l: 1–2-teri turi',
    '✍🏼' => 'yozayotgan qo‘l: 3-teri turi',
    '✍🏽' => 'yozayotgan qo‘l: 4-teri turi',
    '✍🏾' => 'yozayotgan qo‘l: 5-teri turi',
    '✍🏿' => 'yozayotgan qo‘l: 6-teri turi',
    '💅🏻' => 'tirnoq uchun lok: 1–2-teri turi',
    '💅🏼' => 'tirnoq uchun lok: 3-teri turi',
    '💅🏽' => 'tirnoq uchun lok: 4-teri turi',
    '💅🏾' => 'tirnoq uchun lok: 5-teri turi',
    '💅🏿' => 'tirnoq uchun lok: 6-teri turi',
    '🤳🏻' => 'selfi: 1–2-teri turi',
    '🤳🏼' => 'selfi: 3-teri turi',
    '🤳🏽' => 'selfi: 4-teri turi',
    '🤳🏾' => 'selfi: 5-teri turi',
    '🤳🏿' => 'selfi: 6-teri turi',
    '💪🏻' => 'baquvvat muskullar: 1–2-teri turi',
    '💪🏼' => 'baquvvat muskullar: 3-teri turi',
    '💪🏽' => 'baquvvat muskullar: 4-teri turi',
    '💪🏾' => 'baquvvat muskullar: 5-teri turi',
    '💪🏿' => 'baquvvat muskullar: 6-teri turi',
    '🦵🏻' => 'oyoq: 1–2-teri turi',
    '🦵🏼' => 'oyoq: 3-teri turi',
    '🦵🏽' => 'oyoq: 4-teri turi',
    '🦵🏾' => 'oyoq: 5-teri turi',
    '🦵🏿' => 'oyoq: 6-teri turi',
    '🦶🏻' => 'toʼpiq: 1–2-teri turi',
    '🦶🏼' => 'toʼpiq: 3-teri turi',
    '🦶🏽' => 'toʼpiq: 4-teri turi',
    '🦶🏾' => 'toʼpiq: 5-teri turi',
    '🦶🏿' => 'toʼpiq: 6-teri turi',
    '👂🏻' => 'quloq: 1–2-teri turi',
    '👂🏼' => 'quloq: 3-teri turi',
    '👂🏽' => 'quloq: 4-teri turi',
    '👂🏾' => 'quloq: 5-teri turi',
    '👂🏿' => 'quloq: 6-teri turi',
    '🦻🏻' => 'eshitish qurilmasi taqilgan quloq: 1–2-teri turi',
    '🦻🏼' => 'eshitish qurilmasi taqilgan quloq: 3-teri turi',
    '🦻🏽' => 'eshitish qurilmasi taqilgan quloq: 4-teri turi',
    '🦻🏾' => 'eshitish qurilmasi taqilgan quloq: 5-teri turi',
    '🦻🏿' => 'eshitish qurilmasi taqilgan quloq: 6-teri turi',
    '👃🏻' => 'burun: 1–2-teri turi',
    '👃🏼' => 'burun: 3-teri turi',
    '👃🏽' => 'burun: 4-teri turi',
    '👃🏾' => 'burun: 5-teri turi',
    '👃🏿' => 'burun: 6-teri turi',
    '👶🏻' => 'chaqaloq: 1–2-teri turi',
    '👶🏼' => 'chaqaloq: 3-teri turi',
    '👶🏽' => 'chaqaloq: 4-teri turi',
    '👶🏾' => 'chaqaloq: 5-teri turi',
    '👶🏿' => 'chaqaloq: 6-teri turi',
    '🧒🏻' => 'bola: 1–2-teri turi',
    '🧒🏼' => 'bola: 3-teri turi',
    '🧒🏽' => 'bola: 4-teri turi',
    '🧒🏾' => 'bola: 5-teri turi',
    '🧒🏿' => 'bola: 6-teri turi',
    '👦🏻' => 'o‘g‘il bola: 1–2-teri turi',
    '👦🏼' => 'o‘g‘il bola: 3-teri turi',
    '👦🏽' => 'o‘g‘il bola: 4-teri turi',
    '👦🏾' => 'o‘g‘il bola: 5-teri turi',
    '👦🏿' => 'o‘g‘il bola: 6-teri turi',
    '👧🏻' => 'qiz bola: 1–2-teri turi',
    '👧🏼' => 'qiz bola: 3-teri turi',
    '👧🏽' => 'qiz bola: 4-teri turi',
    '👧🏾' => 'qiz bola: 5-teri turi',
    '👧🏿' => 'qiz bola: 6-teri turi',
    '🧑🏻' => 'voyaga yetgan: 1–2-teri turi',
    '🧑🏼' => 'voyaga yetgan: 3-teri turi',
    '🧑🏽' => 'voyaga yetgan: 4-teri turi',
    '🧑🏾' => 'voyaga yetgan: 5-teri turi',
    '🧑🏿' => 'voyaga yetgan: 6-teri turi',
    '👱🏻' => 'shaxs: 1–2-teri turi mallasoch',
    '👱🏼' => 'shaxs: 3-teri turi mallasoch',
    '👱🏽' => 'shaxs: 4-teri turi mallasoch',
    '👱🏾' => 'shaxs: 5-teri turi mallasoch',
    '👱🏿' => 'shaxs: 6-teri turi mallasoch',
    '👨🏻' => 'erkak: 1–2-teri turi',
    '👨🏼' => 'erkak: 3-teri turi',
    '👨🏽' => 'erkak: 4-teri turi',
    '👨🏾' => 'erkak: 5-teri turi',
    '👨🏿' => 'erkak: 6-teri turi',
    '🧔🏻' => 'erkak: 1–2-teri turi soqolli',
    '🧔🏼' => 'erkak: 3-teri turi soqolli',
    '🧔🏽' => 'erkak: 4-teri turi soqolli',
    '🧔🏾' => 'erkak: 5-teri turi soqolli',
    '🧔🏿' => 'erkak: 6-teri turi soqolli',
    '👩🏻' => 'ayol: 1–2-teri turi',
    '👩🏼' => 'ayol: 3-teri turi',
    '👩🏽' => 'ayol: 4-teri turi',
    '👩🏾' => 'ayol: 5-teri turi',
    '👩🏿' => 'ayol: 6-teri turi',
    '🧓🏻' => 'qari odam: 1–2-teri turi',
    '🧓🏼' => 'qari odam: 3-teri turi',
    '🧓🏽' => 'qari odam: 4-teri turi',
    '🧓🏾' => 'qari odam: 5-teri turi',
    '🧓🏿' => 'qari odam: 6-teri turi',
    '👴🏻' => 'chol: 1–2-teri turi',
    '👴🏼' => 'chol: 3-teri turi',
    '👴🏽' => 'chol: 4-teri turi',
    '👴🏾' => 'chol: 5-teri turi',
    '👴🏿' => 'chol: 6-teri turi',
    '👵🏻' => 'kampir: 1–2-teri turi',
    '👵🏼' => 'kampir: 3-teri turi',
    '👵🏽' => 'kampir: 4-teri turi',
    '👵🏾' => 'kampir: 5-teri turi',
    '👵🏿' => 'kampir: 6-teri turi',
    '🙍🏻' => 'xo‘mraygan odam: 1–2-teri turi',
    '🙍🏼' => 'xo‘mraygan odam: 3-teri turi',
    '🙍🏽' => 'xo‘mraygan odam: 4-teri turi',
    '🙍🏾' => 'xo‘mraygan odam: 5-teri turi',
    '🙍🏿' => 'xo‘mraygan odam: 6-teri turi',
    '🙎🏻' => 'norozi odam: 1–2-teri turi',
    '🙎🏼' => 'norozi odam: 3-teri turi',
    '🙎🏽' => 'norozi odam: 4-teri turi',
    '🙎🏾' => 'norozi odam: 5-teri turi',
    '🙎🏿' => 'norozi odam: 6-teri turi',
    '🙅🏻' => 'yo‘q ishorasi: 1–2-teri turi',
    '🙅🏼' => 'yo‘q ishorasi: 3-teri turi',
    '🙅🏽' => 'yo‘q ishorasi: 4-teri turi',
    '🙅🏾' => 'yo‘q ishorasi: 5-teri turi',
    '🙅🏿' => 'yo‘q ishorasi: 6-teri turi',
    '🙆🏻' => 'ok ishorasi: 1–2-teri turi',
    '🙆🏼' => 'ok ishorasi: 3-teri turi',
    '🙆🏽' => 'ok ishorasi: 4-teri turi',
    '🙆🏾' => 'ok ishorasi: 5-teri turi',
    '🙆🏿' => 'ok ishorasi: 6-teri turi',
    '💁🏻' => 'ma’lumotxona xodimi: 1–2-teri turi',
    '💁🏼' => 'ma’lumotxona xodimi: 3-teri turi',
    '💁🏽' => 'ma’lumotxona xodimi: 4-teri turi',
    '💁🏾' => 'ma’lumotxona xodimi: 5-teri turi',
    '💁🏿' => 'ma’lumotxona xodimi: 6-teri turi',
    '🙋🏻' => 'qo‘lini ko‘tarib turgan xursand odam: 1–2-teri turi',
    '🙋🏼' => 'qo‘lini ko‘tarib turgan xursand odam: 3-teri turi',
    '🙋🏽' => 'qo‘lini ko‘tarib turgan xursand odam: 4-teri turi',
    '🙋🏾' => 'qo‘lini ko‘tarib turgan xursand odam: 5-teri turi',
    '🙋🏿' => 'qo‘lini ko‘tarib turgan xursand odam: 6-teri turi',
    '🧏🏻' => 'kar odam: 1–2-teri turi',
    '🧏🏼' => 'kar odam: 3-teri turi',
    '🧏🏽' => 'kar odam: 4-teri turi',
    '🧏🏾' => 'kar odam: 5-teri turi',
    '🧏🏿' => 'kar odam: 6-teri turi',
    '🙇🏻' => 'ta’zim qilayotgan odam: 1–2-teri turi',
    '🙇🏼' => 'ta’zim qilayotgan odam: 3-teri turi',
    '🙇🏽' => 'ta’zim qilayotgan odam: 4-teri turi',
    '🙇🏾' => 'ta’zim qilayotgan odam: 5-teri turi',
    '🙇🏿' => 'ta’zim qilayotgan odam: 6-teri turi',
    '🤦🏻' => 'boshqa gapim yo‘q: 1–2-teri turi',
    '🤦🏼' => 'boshqa gapim yo‘q: 3-teri turi',
    '🤦🏽' => 'boshqa gapim yo‘q: 4-teri turi',
    '🤦🏾' => 'boshqa gapim yo‘q: 5-teri turi',
    '🤦🏿' => 'boshqa gapim yo‘q: 6-teri turi',
    '🤷🏻' => 'bilmayman ishorasi: 1–2-teri turi',
    '🤷🏼' => 'bilmayman ishorasi: 3-teri turi',
    '🤷🏽' => 'bilmayman ishorasi: 4-teri turi',
    '🤷🏾' => 'bilmayman ishorasi: 5-teri turi',
    '🤷🏿' => 'bilmayman ishorasi: 6-teri turi',
    '👮🏻' => 'politsiya xodimi: 1–2-teri turi',
    '👮🏼' => 'politsiya xodimi: 3-teri turi',
    '👮🏽' => 'politsiya xodimi: 4-teri turi',
    '👮🏾' => 'politsiya xodimi: 5-teri turi',
    '👮🏿' => 'politsiya xodimi: 6-teri turi',
    '🕵🏻' => 'izquvar: 1–2-teri turi',
    '🕵🏼' => 'izquvar: 3-teri turi',
    '🕵🏽' => 'izquvar: 4-teri turi',
    '🕵🏾' => 'izquvar: 5-teri turi',
    '🕵🏿' => 'izquvar: 6-teri turi',
    '💂🏻' => 'qo‘riqchi: 1–2-teri turi',
    '💂🏼' => 'qo‘riqchi: 3-teri turi',
    '💂🏽' => 'qo‘riqchi: 4-teri turi',
    '💂🏾' => 'qo‘riqchi: 5-teri turi',
    '💂🏿' => 'qo‘riqchi: 6-teri turi',
    '🥷🏻' => 'ninza: 1–2-teri turi',
    '🥷🏼' => 'ninza: 3-teri turi',
    '🥷🏽' => 'ninza: 4-teri turi',
    '🥷🏾' => 'ninza: 5-teri turi',
    '🥷🏿' => 'ninza: 6-teri turi',
    '👷🏻' => 'quruvchi: 1–2-teri turi',
    '👷🏼' => 'quruvchi: 3-teri turi',
    '👷🏽' => 'quruvchi: 4-teri turi',
    '👷🏾' => 'quruvchi: 5-teri turi',
    '👷🏿' => 'quruvchi: 6-teri turi',
    '🫅🏻' => 'tojli odam: 1–2-teri turi',
    '🫅🏼' => 'tojli odam: 3-teri turi',
    '🫅🏽' => 'tojli odam: 4-teri turi',
    '🫅🏾' => 'tojli odam: 5-teri turi',
    '🫅🏿' => 'tojli odam: 6-teri turi',
    '🤴🏻' => 'shahzoda: 1–2-teri turi',
    '🤴🏼' => 'shahzoda: 3-teri turi',
    '🤴🏽' => 'shahzoda: 4-teri turi',
    '🤴🏾' => 'shahzoda: 5-teri turi',
    '🤴🏿' => 'shahzoda: 6-teri turi',
    '👸🏻' => 'malika: 1–2-teri turi',
    '👸🏼' => 'malika: 3-teri turi',
    '👸🏽' => 'malika: 4-teri turi',
    '👸🏾' => 'malika: 5-teri turi',
    '👸🏿' => 'malika: 6-teri turi',
    '👳🏻' => 'salla kiygan erkak: 1–2-teri turi',
    '👳🏼' => 'salla kiygan erkak: 3-teri turi',
    '👳🏽' => 'salla kiygan erkak: 4-teri turi',
    '👳🏾' => 'salla kiygan erkak: 5-teri turi',
    '👳🏿' => 'salla kiygan erkak: 6-teri turi',
    '👲🏻' => 'xitoy bosh kiyimini kiygan kishi: 1–2-teri turi',
    '👲🏼' => 'xitoy bosh kiyimini kiygan kishi: 3-teri turi',
    '👲🏽' => 'xitoy bosh kiyimini kiygan kishi: 4-teri turi',
    '👲🏾' => 'xitoy bosh kiyimini kiygan kishi: 5-teri turi',
    '👲🏿' => 'xitoy bosh kiyimini kiygan kishi: 6-teri turi',
    '🧕🏻' => 'ro‘mol o‘ragan ayol: 1–2-teri turi',
    '🧕🏼' => 'ro‘mol o‘ragan ayol: 3-teri turi',
    '🧕🏽' => 'ro‘mol o‘ragan ayol: 4-teri turi',
    '🧕🏾' => 'ro‘mol o‘ragan ayol: 5-teri turi',
    '🧕🏿' => 'ro‘mol o‘ragan ayol: 6-teri turi',
    '🤵🏻' => 'smoking kiygan odam: 1–2-teri turi',
    '🤵🏼' => 'smoking kiygan odam: 3-teri turi',
    '🤵🏽' => 'smoking kiygan odam: 4-teri turi',
    '🤵🏾' => 'smoking kiygan odam: 5-teri turi',
    '🤵🏿' => 'smoking kiygan odam: 6-teri turi',
    '👰🏻' => 'nikoh kiyimidagi odam: 1–2-teri turi',
    '👰🏼' => 'nikoh kiyimidagi odam: 3-teri turi',
    '👰🏽' => 'nikoh kiyimidagi odam: 4-teri turi',
    '👰🏾' => 'nikoh kiyimidagi odam: 5-teri turi',
    '👰🏿' => 'nikoh kiyimidagi odam: 6-teri turi',
    '🤰🏻' => 'homilador ayol: 1–2-teri turi',
    '🤰🏼' => 'homilador ayol: 3-teri turi',
    '🤰🏽' => 'homilador ayol: 4-teri turi',
    '🤰🏾' => 'homilador ayol: 5-teri turi',
    '🤰🏿' => 'homilador ayol: 6-teri turi',
    '🫃🏻' => 'homilador erkak: 1–2-teri turi',
    '🫃🏼' => 'homilador erkak: 3-teri turi',
    '🫃🏽' => 'homilador erkak: 4-teri turi',
    '🫃🏾' => 'homilador erkak: 5-teri turi',
    '🫃🏿' => 'homilador erkak: 6-teri turi',
    '🫄🏻' => 'homilador odam: 1–2-teri turi',
    '🫄🏼' => 'homilador odam: 3-teri turi',
    '🫄🏽' => 'homilador odam: 4-teri turi',
    '🫄🏾' => 'homilador odam: 5-teri turi',
    '🫄🏿' => 'homilador odam: 6-teri turi',
    '🤱🏻' => 'emizish: 1–2-teri turi',
    '🤱🏼' => 'emizish: 3-teri turi',
    '🤱🏽' => 'emizish: 4-teri turi',
    '🤱🏾' => 'emizish: 5-teri turi',
    '🤱🏿' => 'emizish: 6-teri turi',
    '👼🏻' => 'chaqaloq farishta: 1–2-teri turi',
    '👼🏼' => 'chaqaloq farishta: 3-teri turi',
    '👼🏽' => 'chaqaloq farishta: 4-teri turi',
    '👼🏾' => 'chaqaloq farishta: 5-teri turi',
    '👼🏿' => 'chaqaloq farishta: 6-teri turi',
    '🎅🏻' => 'santa-klaus: 1–2-teri turi',
    '🎅🏼' => 'santa-klaus: 3-teri turi',
    '🎅🏽' => 'santa-klaus: 4-teri turi',
    '🎅🏾' => 'santa-klaus: 5-teri turi',
    '🎅🏿' => 'santa-klaus: 6-teri turi',
    '🤶🏻' => 'qorqiz: 1–2-teri turi',
    '🤶🏼' => 'qorqiz: 3-teri turi',
    '🤶🏽' => 'qorqiz: 4-teri turi',
    '🤶🏾' => 'qorqiz: 5-teri turi',
    '🤶🏿' => 'qorqiz: 6-teri turi',
    '🦸🏻' => 'superqahramon: 1–2-teri turi',
    '🦸🏼' => 'superqahramon: 3-teri turi',
    '🦸🏽' => 'superqahramon: 4-teri turi',
    '🦸🏾' => 'superqahramon: 5-teri turi',
    '🦸🏿' => 'superqahramon: 6-teri turi',
    '🦹🏻' => 'salbiy superqahramon: 1–2-teri turi',
    '🦹🏼' => 'salbiy superqahramon: 3-teri turi',
    '🦹🏽' => 'salbiy superqahramon: 4-teri turi',
    '🦹🏾' => 'salbiy superqahramon: 5-teri turi',
    '🦹🏿' => 'salbiy superqahramon: 6-teri turi',
    '🧙🏻' => 'sehrgar: 1–2-teri turi',
    '🧙🏼' => 'sehrgar: 3-teri turi',
    '🧙🏽' => 'sehrgar: 4-teri turi',
    '🧙🏾' => 'sehrgar: 5-teri turi',
    '🧙🏿' => 'sehrgar: 6-teri turi',
    '🧚🏻' => 'pari: 1–2-teri turi',
    '🧚🏼' => 'pari: 3-teri turi',
    '🧚🏽' => 'pari: 4-teri turi',
    '🧚🏾' => 'pari: 5-teri turi',
    '🧚🏿' => 'pari: 6-teri turi',
    '🧛🏻' => 'vampir: 1–2-teri turi',
    '🧛🏼' => 'vampir: 3-teri turi',
    '🧛🏽' => 'vampir: 4-teri turi',
    '🧛🏾' => 'vampir: 5-teri turi',
    '🧛🏿' => 'vampir: 6-teri turi',
    '🧜🏻' => 'suv parisi: 1–2-teri turi',
    '🧜🏼' => 'suv parisi: 3-teri turi',
    '🧜🏽' => 'suv parisi: 4-teri turi',
    '🧜🏾' => 'suv parisi: 5-teri turi',
    '🧜🏿' => 'suv parisi: 6-teri turi',
    '🧝🏻' => 'elf: 1–2-teri turi',
    '🧝🏼' => 'elf: 3-teri turi',
    '🧝🏽' => 'elf: 4-teri turi',
    '🧝🏾' => 'elf: 5-teri turi',
    '🧝🏿' => 'elf: 6-teri turi',
    '💆🏻' => 'yuzni uqalash: 1–2-teri turi',
    '💆🏼' => 'yuzni uqalash: 3-teri turi',
    '💆🏽' => 'yuzni uqalash: 4-teri turi',
    '💆🏾' => 'yuzni uqalash: 5-teri turi',
    '💆🏿' => 'yuzni uqalash: 6-teri turi',
    '💇🏻' => 'soch qisqartirish: 1–2-teri turi',
    '💇🏼' => 'soch qisqartirish: 3-teri turi',
    '💇🏽' => 'soch qisqartirish: 4-teri turi',
    '💇🏾' => 'soch qisqartirish: 5-teri turi',
    '💇🏿' => 'soch qisqartirish: 6-teri turi',
    '🚶🏻' => 'piyoda odam: 1–2-teri turi',
    '🚶🏼' => 'piyoda odam: 3-teri turi',
    '🚶🏽' => 'piyoda odam: 4-teri turi',
    '🚶🏾' => 'piyoda odam: 5-teri turi',
    '🚶🏿' => 'piyoda odam: 6-teri turi',
    '🧍🏻' => 'tik turgan odam: 1–2-teri turi',
    '🧍🏼' => 'tik turgan odam: 3-teri turi',
    '🧍🏽' => 'tik turgan odam: 4-teri turi',
    '🧍🏾' => 'tik turgan odam: 5-teri turi',
    '🧍🏿' => 'tik turgan odam: 6-teri turi',
    '🧎🏻' => 'tiz choʻkkan odam: 1–2-teri turi',
    '🧎🏼' => 'tiz choʻkkan odam: 3-teri turi',
    '🧎🏽' => 'tiz choʻkkan odam: 4-teri turi',
    '🧎🏾' => 'tiz choʻkkan odam: 5-teri turi',
    '🧎🏿' => 'tiz choʻkkan odam: 6-teri turi',
    '🏃🏻' => 'yuguruvchi: 1–2-teri turi',
    '🏃🏼' => 'yuguruvchi: 3-teri turi',
    '🏃🏽' => 'yuguruvchi: 4-teri turi',
    '🏃🏾' => 'yuguruvchi: 5-teri turi',
    '🏃🏿' => 'yuguruvchi: 6-teri turi',
    '💃🏻' => 'raqqosa: 1–2-teri turi',
    '💃🏼' => 'raqqosa: 3-teri turi',
    '💃🏽' => 'raqqosa: 4-teri turi',
    '💃🏾' => 'raqqosa: 5-teri turi',
    '💃🏿' => 'raqqosa: 6-teri turi',
    '🕺🏻' => 'raqs tushayotgan erkak: 1–2-teri turi',
    '🕺🏼' => 'raqs tushayotgan erkak: 3-teri turi',
    '🕺🏽' => 'raqs tushayotgan erkak: 4-teri turi',
    '🕺🏾' => 'raqs tushayotgan erkak: 5-teri turi',
    '🕺🏿' => 'raqs tushayotgan erkak: 6-teri turi',
    '🕴🏻' => 'kostyum kiygan muallaq holatdagi kishi: 1–2-teri turi',
    '🕴🏼' => 'kostyum kiygan muallaq holatdagi kishi: 3-teri turi',
    '🕴🏽' => 'kostyum kiygan muallaq holatdagi kishi: 4-teri turi',
    '🕴🏾' => 'kostyum kiygan muallaq holatdagi kishi: 5-teri turi',
    '🕴🏿' => 'kostyum kiygan muallaq holatdagi kishi: 6-teri turi',
    '👯🏻' => 'quyon quloqli odamlar: 1–2-teri turi',
    '👯🏼' => 'quyon quloqli odamlar: 3-teri turi',
    '👯🏽' => 'quyon quloqli odamlar: 4-teri turi',
    '👯🏾' => 'quyon quloqli odamlar: 5-teri turi',
    '👯🏿' => 'quyon quloqli odamlar: 6-teri turi',
    '🧖🏻' => 'hammomdagi odam: 1–2-teri turi',
    '🧖🏼' => 'hammomdagi odam: 3-teri turi',
    '🧖🏽' => 'hammomdagi odam: 4-teri turi',
    '🧖🏾' => 'hammomdagi odam: 5-teri turi',
    '🧖🏿' => 'hammomdagi odam: 6-teri turi',
    '🧗🏻' => 'cho‘qqiga chiqayotgan odam: 1–2-teri turi',
    '🧗🏼' => 'cho‘qqiga chiqayotgan odam: 3-teri turi',
    '🧗🏽' => 'cho‘qqiga chiqayotgan odam: 4-teri turi',
    '🧗🏾' => 'cho‘qqiga chiqayotgan odam: 5-teri turi',
    '🧗🏿' => 'cho‘qqiga chiqayotgan odam: 6-teri turi',
    '🏇🏻' => 'otchopar: 1–2-teri turi',
    '🏇🏼' => 'otchopar: 3-teri turi',
    '🏇🏽' => 'otchopar: 4-teri turi',
    '🏇🏾' => 'otchopar: 5-teri turi',
    '🏇🏿' => 'otchopar: 6-teri turi',
    '🏂🏻' => 'snoubordchi: 1–2-teri turi',
    '🏂🏼' => 'snoubordchi: 3-teri turi',
    '🏂🏽' => 'snoubordchi: 4-teri turi',
    '🏂🏾' => 'snoubordchi: 5-teri turi',
    '🏂🏿' => 'snoubordchi: 6-teri turi',
    '🏌🏻' => 'golf o‘ynovchi: 1–2-teri turi',
    '🏌🏼' => 'golf o‘ynovchi: 3-teri turi',
    '🏌🏽' => 'golf o‘ynovchi: 4-teri turi',
    '🏌🏾' => 'golf o‘ynovchi: 5-teri turi',
    '🏌🏿' => 'golf o‘ynovchi: 6-teri turi',
    '🏄🏻' => 'serfingchi: 1–2-teri turi',
    '🏄🏼' => 'serfingchi: 3-teri turi',
    '🏄🏽' => 'serfingchi: 4-teri turi',
    '🏄🏾' => 'serfingchi: 5-teri turi',
    '🏄🏿' => 'serfingchi: 6-teri turi',
    '🚣🏻' => 'qayiq: 1–2-teri turi',
    '🚣🏼' => 'qayiq: 3-teri turi',
    '🚣🏽' => 'qayiq: 4-teri turi',
    '🚣🏾' => 'qayiq: 5-teri turi',
    '🚣🏿' => 'qayiq: 6-teri turi',
    '🏊🏻' => 'suzuvchi: 1–2-teri turi',
    '🏊🏼' => 'suzuvchi: 3-teri turi',
    '🏊🏽' => 'suzuvchi: 4-teri turi',
    '🏊🏾' => 'suzuvchi: 5-teri turi',
    '🏊🏿' => 'suzuvchi: 6-teri turi',
    '⛹🏻' => 'odam va to‘p: 1–2-teri turi',
    '⛹🏼' => 'odam va to‘p: 3-teri turi',
    '⛹🏽' => 'odam va to‘p: 4-teri turi',
    '⛹🏾' => 'odam va to‘p: 5-teri turi',
    '⛹🏿' => 'odam va to‘p: 6-teri turi',
    '🏋🏻' => 'og‘ir atletikachi: 1–2-teri turi',
    '🏋🏼' => 'og‘ir atletikachi: 3-teri turi',
    '🏋🏽' => 'og‘ir atletikachi: 4-teri turi',
    '🏋🏾' => 'og‘ir atletikachi: 5-teri turi',
    '🏋🏿' => 'og‘ir atletikachi: 6-teri turi',
    '🚴🏻' => 'velosipedchi: 1–2-teri turi',
    '🚴🏼' => 'velosipedchi: 3-teri turi',
    '🚴🏽' => 'velosipedchi: 4-teri turi',
    '🚴🏾' => 'velosipedchi: 5-teri turi',
    '🚴🏿' => 'velosipedchi: 6-teri turi',
    '🚵🏻' => 'tog‘ velosipedchisi: 1–2-teri turi',
    '🚵🏼' => 'tog‘ velosipedchisi: 3-teri turi',
    '🚵🏽' => 'tog‘ velosipedchisi: 4-teri turi',
    '🚵🏾' => 'tog‘ velosipedchisi: 5-teri turi',
    '🚵🏿' => 'tog‘ velosipedchisi: 6-teri turi',
    '🤸🏻' => 'akrobatik mashq: 1–2-teri turi',
    '🤸🏼' => 'akrobatik mashq: 3-teri turi',
    '🤸🏽' => 'akrobatik mashq: 4-teri turi',
    '🤸🏾' => 'akrobatik mashq: 5-teri turi',
    '🤸🏿' => 'akrobatik mashq: 6-teri turi',
    '🤼🏻' => 'kurashchilar: 1–2-teri turi',
    '🤼🏼' => 'kurashchilar: 3-teri turi',
    '🤼🏽' => 'kurashchilar: 4-teri turi',
    '🤼🏾' => 'kurashchilar: 5-teri turi',
    '🤼🏿' => 'kurashchilar: 6-teri turi',
    '🤽🏻' => 'suv polosi: 1–2-teri turi',
    '🤽🏼' => 'suv polosi: 3-teri turi',
    '🤽🏽' => 'suv polosi: 4-teri turi',
    '🤽🏾' => 'suv polosi: 5-teri turi',
    '🤽🏿' => 'suv polosi: 6-teri turi',
    '🤾🏻' => 'gandbol: 1–2-teri turi',
    '🤾🏼' => 'gandbol: 3-teri turi',
    '🤾🏽' => 'gandbol: 4-teri turi',
    '🤾🏾' => 'gandbol: 5-teri turi',
    '🤾🏿' => 'gandbol: 6-teri turi',
    '🤹🏻' => 'jonglyor: 1–2-teri turi',
    '🤹🏼' => 'jonglyor: 3-teri turi',
    '🤹🏽' => 'jonglyor: 4-teri turi',
    '🤹🏾' => 'jonglyor: 5-teri turi',
    '🤹🏿' => 'jonglyor: 6-teri turi',
    '🧘🏻' => 'lotus holatidagi odam: 1–2-teri turi',
    '🧘🏼' => 'lotus holatidagi odam: 3-teri turi',
    '🧘🏽' => 'lotus holatidagi odam: 4-teri turi',
    '🧘🏾' => 'lotus holatidagi odam: 5-teri turi',
    '🧘🏿' => 'lotus holatidagi odam: 6-teri turi',
    '🛀🏻' => 'hammom qilayotgan kishi: 1–2-teri turi',
    '🛀🏼' => 'hammom qilayotgan kishi: 3-teri turi',
    '🛀🏽' => 'hammom qilayotgan kishi: 4-teri turi',
    '🛀🏾' => 'hammom qilayotgan kishi: 5-teri turi',
    '🛀🏿' => 'hammom qilayotgan kishi: 6-teri turi',
    '🛌🏻' => 'karavotda yotgan kishi: 1–2-teri turi',
    '🛌🏼' => 'karavotda yotgan kishi: 3-teri turi',
    '🛌🏽' => 'karavotda yotgan kishi: 4-teri turi',
    '🛌🏾' => 'karavotda yotgan kishi: 5-teri turi',
    '🛌🏿' => 'karavotda yotgan kishi: 6-teri turi',
    '👭🏻' => 'qoʻl ushlashgan ayollar: 1–2-teri turi',
    '👭🏼' => 'qoʻl ushlashgan ayollar: 3-teri turi',
    '👭🏽' => 'qoʻl ushlashgan ayollar: 4-teri turi',
    '👭🏾' => 'qoʻl ushlashgan ayollar: 5-teri turi',
    '👭🏿' => 'qoʻl ushlashgan ayollar: 6-teri turi',
    '👫🏻' => 'qoʻl ushlashgan ayol va erkak: 1–2-teri turi',
    '👫🏼' => 'qoʻl ushlashgan ayol va erkak: 3-teri turi',
    '👫🏽' => 'qoʻl ushlashgan ayol va erkak: 4-teri turi',
    '👫🏾' => 'qoʻl ushlashgan ayol va erkak: 5-teri turi',
    '👫🏿' => 'qoʻl ushlashgan ayol va erkak: 6-teri turi',
    '👬🏻' => 'qoʻl ushlashgan erkaklar: 1–2-teri turi',
    '👬🏼' => 'qoʻl ushlashgan erkaklar: 3-teri turi',
    '👬🏽' => 'qoʻl ushlashgan erkaklar: 4-teri turi',
    '👬🏾' => 'qoʻl ushlashgan erkaklar: 5-teri turi',
    '👬🏿' => 'qoʻl ushlashgan erkaklar: 6-teri turi',
    '💏🏻' => 'bo‘sa olish: 1–2-teri turi',
    '💏🏼' => 'bo‘sa olish: 3-teri turi',
    '💏🏽' => 'bo‘sa olish: 4-teri turi',
    '💏🏾' => 'bo‘sa olish: 5-teri turi',
    '💏🏿' => 'bo‘sa olish: 6-teri turi',
    '💑🏻' => 'juftlik va yurak: 1–2-teri turi',
    '💑🏼' => 'juftlik va yurak: 3-teri turi',
    '💑🏽' => 'juftlik va yurak: 4-teri turi',
    '💑🏾' => 'juftlik va yurak: 5-teri turi',
    '💑🏿' => 'juftlik va yurak: 6-teri turi',
    '🇦🇨' => 'bayroq: Me’roj oroli',
    '🇦🇩' => 'bayroq: Andorra',
    '🇦🇪' => 'bayroq: Birlashgan Arab Amirliklari',
    '🇦🇫' => 'bayroq: Afgʻoniston',
    '🇦🇬' => 'bayroq: Antigua va Barbuda',
    '🇦🇮' => 'bayroq: Angilya',
    '🇦🇱' => 'bayroq: Albaniya',
    '🇦🇲' => 'bayroq: Armaniston',
    '🇦🇴' => 'bayroq: Angola',
    '🇦🇶' => 'bayroq: Antarktida',
    '🇦🇷' => 'bayroq: Argentina',
    '🇦🇸' => 'bayroq: Amerika Samoasi',
    '🇦🇹' => 'bayroq: Avstriya',
    '🇦🇺' => 'bayroq: Avstraliya',
    '🇦🇼' => 'bayroq: Aruba',
    '🇦🇽' => 'bayroq: Aland orollari',
    '🇦🇿' => 'bayroq: Ozarbayjon',
    '🇧🇦' => 'bayroq: Bosniya va Gertsegovina',
    '🇧🇧' => 'bayroq: Barbados',
    '🇧🇩' => 'bayroq: Bangladesh',
    '🇧🇪' => 'bayroq: Belgiya',
    '🇧🇫' => 'bayroq: Burkina-Faso',
    '🇧🇬' => 'bayroq: Bolgariya',
    '🇧🇭' => 'bayroq: Bahrayn',
    '🇧🇮' => 'bayroq: Burundi',
    '🇧🇯' => 'bayroq: Benin',
    '🇧🇱' => 'bayroq: Sen-Bartelemi',
    '🇧🇲' => 'bayroq: Bermuda orollari',
    '🇧🇳' => 'bayroq: Bruney',
    '🇧🇴' => 'bayroq: Boliviya',
    '🇧🇶' => 'bayroq: Boneyr, Sint-Estatius va Saba',
    '🇧🇷' => 'bayroq: Braziliya',
    '🇧🇸' => 'bayroq: Bagama orollari',
    '🇧🇹' => 'bayroq: Butan',
    '🇧🇻' => 'bayroq: Buve oroli',
    '🇧🇼' => 'bayroq: Botsvana',
    '🇧🇾' => 'bayroq: Belarus',
    '🇧🇿' => 'bayroq: Beliz',
    '🇨🇦' => 'bayroq: Kanada',
    '🇨🇨' => 'bayroq: Kokos (Kiling) orollari',
    '🇨🇩' => 'bayroq: Kongo – Kinshasa',
    '🇨🇫' => 'bayroq: Markaziy Afrika Respublikasi',
    '🇨🇬' => 'bayroq: Kongo – Brazzavil',
    '🇨🇭' => 'bayroq: Shveytsariya',
    '🇨🇮' => 'bayroq: Kot-d’Ivuar',
    '🇨🇰' => 'bayroq: Kuk orollari',
    '🇨🇱' => 'bayroq: Chili',
    '🇨🇲' => 'bayroq: Kamerun',
    '🇨🇳' => 'bayroq: Xitoy',
    '🇨🇴' => 'bayroq: Kolumbiya',
    '🇨🇵' => 'bayroq: Klipperton oroli',
    '🇨🇶' => 'bayroq: Sark',
    '🇨🇷' => 'bayroq: Kosta-Rika',
    '🇨🇺' => 'bayroq: Kuba',
    '🇨🇻' => 'bayroq: Kabo-Verde',
    '🇨🇼' => 'bayroq: Kyurasao',
    '🇨🇽' => 'bayroq: Rojdestvo oroli',
    '🇨🇾' => 'bayroq: Kipr',
    '🇨🇿' => 'bayroq: Chexiya',
    '🇩🇪' => 'bayroq: Germaniya',
    '🇩🇬' => 'bayroq: Diyego-Garsiya',
    '🇩🇯' => 'bayroq: Jibuti',
    '🇩🇰' => 'bayroq: Daniya',
    '🇩🇲' => 'bayroq: Dominika',
    '🇩🇴' => 'bayroq: Dominikan Respublikasi',
    '🇩🇿' => 'bayroq: Jazoir',
    '🇪🇦' => 'bayroq: Seuta va Melilya',
    '🇪🇨' => 'bayroq: Ekvador',
    '🇪🇪' => 'bayroq: Estoniya',
    '🇪🇬' => 'bayroq: Misr',
    '🇪🇭' => 'bayroq: G‘arbiy Sahroi Kabir',
    '🇪🇷' => 'bayroq: Eritreya',
    '🇪🇸' => 'bayroq: Ispaniya',
    '🇪🇹' => 'bayroq: Efiopiya',
    '🇪🇺' => 'bayroq: Yevropa Ittifoqi',
    '🇫🇮' => 'bayroq: Finlandiya',
    '🇫🇯' => 'bayroq: Fiji',
    '🇫🇰' => 'bayroq: Folklend orollari',
    '🇫🇲' => 'bayroq: Mikroneziya',
    '🇫🇴' => 'bayroq: Farer orollari',
    '🇫🇷' => 'bayroq: Fransiya',
    '🇬🇦' => 'bayroq: Gabon',
    '🇬🇧' => 'bayroq: Buyuk Britaniya',
    '🇬🇩' => 'bayroq: Grenada',
    '🇬🇪' => 'bayroq: Gruziya',
    '🇬🇫' => 'bayroq: Fransuz Gvianasi',
    '🇬🇬' => 'bayroq: Gernsi',
    '🇬🇭' => 'bayroq: Gana',
    '🇬🇮' => 'bayroq: Gibraltar',
    '🇬🇱' => 'bayroq: Grenlandiya',
    '🇬🇲' => 'bayroq: Gambiya',
    '🇬🇳' => 'bayroq: Gvineya',
    '🇬🇵' => 'bayroq: Gvadelupe',
    '🇬🇶' => 'bayroq: Ekvatorial Gvineya',
    '🇬🇷' => 'bayroq: Gretsiya',
    '🇬🇸' => 'bayroq: Janubiy Georgiya va Janubiy Sendvich orollari',
    '🇬🇹' => 'bayroq: Gvatemala',
    '🇬🇺' => 'bayroq: Guam',
    '🇬🇼' => 'bayroq: Gvineya-Bisau',
    '🇬🇾' => 'bayroq: Gayana',
    '🇭🇰' => 'bayroq: Gonkong (Xitoy MMH)',
    '🇭🇲' => 'bayroq: Xerd va Makdonald orollari',
    '🇭🇳' => 'bayroq: Gonduras',
    '🇭🇷' => 'bayroq: Xorvatiya',
    '🇭🇹' => 'bayroq: Gaiti',
    '🇭🇺' => 'bayroq: Vengriya',
    '🇮🇨' => 'bayroq: Kanar orollari',
    '🇮🇩' => 'bayroq: Indoneziya',
    '🇮🇪' => 'bayroq: Irlandiya',
    '🇮🇱' => 'bayroq: Isroil',
    '🇮🇲' => 'bayroq: Men oroli',
    '🇮🇳' => 'bayroq: Hindiston',
    '🇮🇴' => 'bayroq: Britaniyaning Hind okeanidagi hududi',
    '🇮🇶' => 'bayroq: Iroq',
    '🇮🇷' => 'bayroq: Eron',
    '🇮🇸' => 'bayroq: Islandiya',
    '🇮🇹' => 'bayroq: Italiya',
    '🇯🇪' => 'bayroq: Jersi',
    '🇯🇲' => 'bayroq: Yamayka',
    '🇯🇴' => 'bayroq: Iordaniya',
    '🇯🇵' => 'bayroq: Yaponiya',
    '🇰🇪' => 'bayroq: Keniya',
    '🇰🇬' => 'bayroq: Qirgʻiziston',
    '🇰🇭' => 'bayroq: Kambodja',
    '🇰🇮' => 'bayroq: Kiribati',
    '🇰🇲' => 'bayroq: Komor orollari',
    '🇰🇳' => 'bayroq: Sent-Kits va Nevis',
    '🇰🇵' => 'bayroq: Shimoliy Koreya',
    '🇰🇷' => 'bayroq: Janubiy Koreya',
    '🇰🇼' => 'bayroq: Quvayt',
    '🇰🇾' => 'bayroq: Kayman orollari',
    '🇰🇿' => 'bayroq: Qozogʻiston',
    '🇱🇦' => 'bayroq: Laos',
    '🇱🇧' => 'bayroq: Livan',
    '🇱🇨' => 'bayroq: Sent-Lyusiya',
    '🇱🇮' => 'bayroq: Lixtenshteyn',
    '🇱🇰' => 'bayroq: Shri-Lanka',
    '🇱🇷' => 'bayroq: Liberiya',
    '🇱🇸' => 'bayroq: Lesoto',
    '🇱🇹' => 'bayroq: Litva',
    '🇱🇺' => 'bayroq: Lyuksemburg',
    '🇱🇻' => 'bayroq: Latviya',
    '🇱🇾' => 'bayroq: Liviya',
    '🇲🇦' => 'bayroq: Marokash',
    '🇲🇨' => 'bayroq: Monako',
    '🇲🇩' => 'bayroq: Moldova',
    '🇲🇪' => 'bayroq: Chernogoriya',
    '🇲🇫' => 'bayroq: Sent-Martin',
    '🇲🇬' => 'bayroq: Madagaskar',
    '🇲🇭' => 'bayroq: Marshall orollari',
    '🇲🇰' => 'bayroq: Shimoliy Makedoniya',
    '🇲🇱' => 'bayroq: Mali',
    '🇲🇲' => 'bayroq: Myanma (Birma)',
    '🇲🇳' => 'bayroq: Mongoliya',
    '🇲🇴' => 'bayroq: Makao (Xitoy MMH)',
    '🇲🇵' => 'bayroq: Shimoliy Mariana orollari',
    '🇲🇶' => 'bayroq: Martinika',
    '🇲🇷' => 'bayroq: Mavritaniya',
    '🇲🇸' => 'bayroq: Montserrat',
    '🇲🇹' => 'bayroq: Malta',
    '🇲🇺' => 'bayroq: Mavrikiy',
    '🇲🇻' => 'bayroq: Maldiv orollari',
    '🇲🇼' => 'bayroq: Malavi',
    '🇲🇽' => 'bayroq: Meksika',
    '🇲🇾' => 'bayroq: Malayziya',
    '🇲🇿' => 'bayroq: Mozambik',
    '🇳🇦' => 'bayroq: Namibiya',
    '🇳🇨' => 'bayroq: Yangi Kaledoniya',
    '🇳🇪' => 'bayroq: Niger',
    '🇳🇫' => 'bayroq: Norfolk oroli',
    '🇳🇬' => 'bayroq: Nigeriya',
    '🇳🇮' => 'bayroq: Nikaragua',
    '🇳🇱' => 'bayroq: Niderlandiya',
    '🇳🇴' => 'bayroq: Norvegiya',
    '🇳🇵' => 'bayroq: Nepal',
    '🇳🇷' => 'bayroq: Nauru',
    '🇳🇺' => 'bayroq: Niue',
    '🇳🇿' => 'bayroq: Yangi Zelandiya',
    '🇴🇲' => 'bayroq: Ummon',
    '🇵🇦' => 'bayroq: Panama',
    '🇵🇪' => 'bayroq: Peru',
    '🇵🇫' => 'bayroq: Fransuz Polineziyasi',
    '🇵🇬' => 'bayroq: Papua – Yangi Gvineya',
    '🇵🇭' => 'bayroq: Filippin',
    '🇵🇰' => 'bayroq: Pokiston',
    '🇵🇱' => 'bayroq: Polsha',
    '🇵🇲' => 'bayroq: Sen-Pyer va Mikelon',
    '🇵🇳' => 'bayroq: Pitkern orollari',
    '🇵🇷' => 'bayroq: Puerto-Riko',
    '🇵🇸' => 'bayroq: Falastin hududlari',
    '🇵🇹' => 'bayroq: Portugaliya',
    '🇵🇼' => 'bayroq: Palau',
    '🇵🇾' => 'bayroq: Paragvay',
    '🇶🇦' => 'bayroq: Qatar',
    '🇷🇪' => 'bayroq: Reyunion',
    '🇷🇴' => 'bayroq: Ruminiya',
    '🇷🇸' => 'bayroq: Serbiya',
    '🇷🇺' => 'bayroq: Rossiya',
    '🇷🇼' => 'bayroq: Ruanda',
    '🇸🇦' => 'bayroq: Saudiya Arabistoni',
    '🇸🇧' => 'bayroq: Solomon orollari',
    '🇸🇨' => 'bayroq: Seyshel orollari',
    '🇸🇩' => 'bayroq: Sudan',
    '🇸🇪' => 'bayroq: Shvetsiya',
    '🇸🇬' => 'bayroq: Singapur',
    '🇸🇭' => 'bayroq: Muqaddas Yelena oroli',
    '🇸🇮' => 'bayroq: Sloveniya',
    '🇸🇯' => 'bayroq: Shpitsbergen va Yan-Mayen',
    '🇸🇰' => 'bayroq: Slovakiya',
    '🇸🇱' => 'bayroq: Syerra-Leone',
    '🇸🇲' => 'bayroq: San-Marino',
    '🇸🇳' => 'bayroq: Senegal',
    '🇸🇴' => 'bayroq: Somali',
    '🇸🇷' => 'bayroq: Surinam',
    '🇸🇸' => 'bayroq: Janubiy Sudan',
    '🇸🇹' => 'bayroq: San-Tome va Prinsipi',
    '🇸🇻' => 'bayroq: Salvador',
    '🇸🇽' => 'bayroq: Sint-Marten',
    '🇸🇾' => 'bayroq: Suriya',
    '🇸🇿' => 'bayroq: Svazilend',
    '🇹🇦' => 'bayroq: Tristan-da-Kunya',
    '🇹🇨' => 'bayroq: Turks va Kaykos orollari',
    '🇹🇩' => 'bayroq: Chad',
    '🇹🇫' => 'bayroq: Fransuz Janubiy hududlari',
    '🇹🇬' => 'bayroq: Togo',
    '🇹🇭' => 'bayroq: Tailand',
    '🇹🇯' => 'bayroq: Tojikiston',
    '🇹🇰' => 'bayroq: Tokelau',
    '🇹🇱' => 'bayroq: Timor-Leste',
    '🇹🇲' => 'bayroq: Turkmaniston',
    '🇹🇳' => 'bayroq: Tunis',
    '🇹🇴' => 'bayroq: Tonga',
    '🇹🇷' => 'bayroq: Turkiya',
    '🇹🇹' => 'bayroq: Trinidad va Tobago',
    '🇹🇻' => 'bayroq: Tuvalu',
    '🇹🇼' => 'bayroq: Tayvan',
    '🇹🇿' => 'bayroq: Tanzaniya',
    '🇺🇦' => 'bayroq: Ukraina',
    '🇺🇬' => 'bayroq: Uganda',
    '🇺🇲' => 'bayroq: AQSH yondosh orollari',
    '🇺🇳' => 'bayroq: Birlashgan Millatlar Tashkiloti',
    '🇺🇸' => 'bayroq: Amerika Qo‘shma Shtatlari',
    '🇺🇾' => 'bayroq: Urugvay',
    '🇺🇿' => 'bayroq: Oʻzbekiston',
    '🇻🇦' => 'bayroq: Vatikan',
    '🇻🇨' => 'bayroq: Sent-Vinsent va Grenadin',
    '🇻🇪' => 'bayroq: Venesuela',
    '🇻🇬' => 'bayroq: Britaniya Virgin orollari',
    '🇻🇮' => 'bayroq: AQSH Virgin orollari',
    '🇻🇳' => 'bayroq: Vyetnam',
    '🇻🇺' => 'bayroq: Vanuatu',
    '🇼🇫' => 'bayroq: Uollis va Futuna',
    '🇼🇸' => 'bayroq: Samoa',
    '🇽🇰' => 'bayroq: Kosovo',
    '🇾🇪' => 'bayroq: Yaman',
    '🇾🇹' => 'bayroq: Mayotta',
    '🇿🇦' => 'bayroq: Janubiy Afrika Respublikasi',
    '🇿🇲' => 'bayroq: Zambiya',
    '🇿🇼' => 'bayroq: Zimbabve',
    '🔟' => 'tugma qalpog‘i: 10',
    '🏻' => '1–2-teri turi',
    '🏼' => '3-teri turi',
    '🏽' => '4-teri turi',
    '🏾' => '5-teri turi',
    '🏿' => '6-teri turi',
    '😀' => 'tirjaygan yuz',
    '😃' => 'og‘zini katta ochib kulayotgan yuz',
    '😄' => 'tabassum, og‘iz ochiq, ko‘zlar qisilgan',
    '😁' => 'tirjaygan yuz, qisilgan ko‘zlar',
    '😆' => 'og‘zini katta ochib kulayotgan yuz va qattiq yumilgan ko‘zlar',
    '😅' => 'og‘zini katta ochib kulayotgan yuz va sovuq ter',
    '🤣' => 'qotib kulayotgan',
    '😂' => 'quvonch ko‘z yoshlari',
    '🙂' => 'yengilgina kulayotgan yuz',
    '🙃' => 'to‘ntarilgan yuz',
    '🫠' => 'erib ketayotgan yuz',
    '😉' => 'ko‘z qisish',
    '😊' => 'tabassum va kulib turgan ko‘zlar',
    '😇' => 'tabassum, bosh ustida gardish',
    '🥰' => 'yurakchalari bor jilmaygan yuz',
    '😍' => 'tabassum va yurak shaklidagi ko‘zlar',
    '🤩' => 'ko‘zlarda yulduzcha',
    '😘' => 'bo‘sa yuborayotgan yuz',
    '😗' => 'bo‘sa olayotgan yuz',
    '☺' => 'kulayotgan yuz',
    '😚' => 'bo‘sa olayotgan yuz va yumilgan ko‘zlar',
    '😙' => 'bo‘sa olayotgan yuz va kulayotgan ko‘zlar',
    '🥲' => 'koʻz yoshi bilan jilmaygan yuz',
    '😋' => 'mazali taomni tatib ko‘rgan til',
    '😛' => 'tilini chiqarib turgan yuz',
    '😜' => 'tilini chiqarib turgan va ko‘zi qisilgan yuz',
    '🤪' => 'ahmoq yuz',
    '😝' => 'tilini chiqarib turgan va ko‘zlari qattiq qisilgan yuz',
    '🤑' => 'og‘zi pul yuz',
    '🤗' => 'quchayotgan yuz',
    '🤭' => 'og‘izni qo‘l bilan yopish',
    '🫢' => 'ogʻzini qoʻli bilan yopgan yuz',
    '🫣' => 'moʻralayotgan yuz',
    '🤫' => 'ts-s-s',
    '🤔' => 'o‘ylayotgan yuz',
    '🫡' => 'salomlashayotgan yuz',
    '🤐' => 'og‘zi qulflangan yuz',
    '🤨' => 'qosh chimirilgan yuz',
    '😐' => 'his-tuyg‘usiz',
    '😑' => 'his-tuyg‘usiz yuz',
    '😶' => 'og‘izsiz yuz',
    '🫥' => 'nuqta chiziqli yuz',
    '😏' => 'istehzoli yuz',
    '😒' => 'qoniqmagan yuz',
    '🙄' => 'ko‘zlarini aylantirayotgan yuz',
    '😬' => 'afti burishgan',
    '🤥' => 'aldayotgan',
    '🫨' => 'qaltiragan yuz',
    '😌' => 'xotirjam yuz',
    '😔' => 'g‘amgin yuz',
    '😪' => 'uyqusiragan yuz',
    '🤤' => 'so‘lagi oqayotgan',
    '😴' => 'uxlayotgan yuz',
    '🫩' => 'ko‘zlar tagi shishgan yuz',
    '😷' => 'tibbiy niqob taqqan yuz',
    '🤒' => 'harorat o‘lchagich tutgan yuz',
    '🤕' => 'boshi bint bilan o‘ralgan yuz',
    '🤢' => 'ko‘ngli ayniyotgan',
    '🤮' => 'qusish',
    '🤧' => 'aksirayotgan',
    '🥵' => 'isitma',
    '🥶' => 'sovqotish',
    '🥴' => 'boshi aylangan',
    '😵' => 'boshi aylanayotgan yuz',
    '🤯' => 'miya portlashi',
    '🤠' => 'kovboyning boshi',
    '🥳' => 'ziyofatda',
    '🥸' => 'niqoblangan yuz',
    '😎' => 'ko‘zoynak taqqan hamda kulayotgan yuz',
    '🤓' => 'aqlli yuz',
    '🧐' => 'monokl bilan',
    '😕' => 'xijolat bo‘lgan yuz',
    '🫤' => 'diagonal ogʻizli yuz',
    '😟' => 'xavotir olayotgan yuz',
    '🙁' => 'ozroq arazlagan yuz',
    '☹' => 'arazlagan yuz',
    '😮' => 'og‘zi katta ochiq yuz',
    '😯' => 'hayratlanayotgan yuz',
    '😲' => 'hayratlangan yuz',
    '😳' => 'yuzi qizargan',
    '🫪' => 'qiyshiq yuz',
    '🥺' => 'yalingan yuz',
    '🥹' => 'koʻz yoshi oqayotgan yuz',
    '😦' => 'og‘zini katta ochgan, qovog‘i solingan yuz',
    '😧' => 'g‘am-tashvishli yuz',
    '😨' => 'qo‘rqqan yuz',
    '😰' => 'og‘zi ochiq va sovuq terga botgan yuz',
    '😥' => 'hafsalasi pir bo‘lgan yuz',
    '😢' => 'yig‘layotgan yuz',
    '😭' => 'xo‘ngrab yig‘layotgan yuz',
    '😱' => 'qo‘rquvdan qichqirayotgan yuz',
    '😖' => 'xijolatli yuz',
    '😣' => 'o‘jarlik',
    '😞' => 'ko‘ngli qolgan yuz',
    '😓' => 'sovuq ter chiqayotgan yuz',
    '😩' => 'xorg‘in yuz',
    '😫' => 'charchagan yuz',
    '🥱' => 'esnayotgan yuz',
    '😤' => 'burnidan tutun chiqayotgan yuz',
    '😡' => 'norozi qiyofa',
    '😠' => 'jahli chiqqan yuz',
    '🤬' => 'senzura',
    '😈' => 'kulayotgan shayton',
    '👿' => 'shayton',
    '💀' => 'bosh suyagi',
    '☠' => 'bosh suyagi va suyaklar',
    '💩' => 'tezak uyumi',
    '🤡' => 'masxaraboz',
    '👹' => 'yovuz maxluq',
    '👺' => 'ajina',
    '👻' => 'arvoh',
    '👽' => 'o‘zga sayyoralik',
    '👾' => 'o‘zga sayyoralik maxluq',
    '🤖' => 'robot qiyofa',
    '😺' => 'og‘zi ochiq holatda kulayotgan mushuk',
    '😸' => 'tirjaygan holda kulayotgan mushuk',
    '😹' => 'koʻzidan yosh chiqib kulayotgan mushuk',
    '😻' => 'ko‘zlari yurak shaklida kulib turgan mushuk',
    '😼' => 'lab burib jilmaygan mushuk',
    '😽' => 'boʻsa olayotgan mushuk',
    '🙀' => 'charchagan mushuk',
    '😿' => 'yigʻlayotgan mushuk',
    '😾' => 'dargʻazab mushuk',
    '🙈' => 'yomonlikni ko‘rmaydigan maymun',
    '🙉' => 'yomonlikni eshitmaydigan maymun',
    '🙊' => 'yomonlikni gapirmaydigan maymun',
    '💌' => 'sevgi xati',
    '💘' => 'yurak va kamon o‘qi',
    '💝' => 'yurak va lenta',
    '💖' => 'chaqnayotgan yurak',
    '💗' => 'kattalashayotgan yurak',
    '💓' => 'urayotgan yurak',
    '💞' => 'aylanayotgan yuraklar',
    '💕' => 'ikkita yurak',
    '💟' => 'yurak bezagi',
    '❣' => 'yurak shaklidagi undov belgisi',
    '💔' => 'singan yurak',
    '❤' => 'qizil yurak',
    '🩷' => 'pushti yurak',
    '🧡' => 'apelsinrang yurak',
    '💛' => 'sariq yurak',
    '💚' => 'yashil yurak',
    '💙' => 'ko‘k yurak',
    '🩵' => 'och koʻk yurak',
    '💜' => 'binafsharang yurak',
    '🤎' => 'jigarrang yurak',
    '🖤' => 'qora yurak',
    '🩶' => 'kulrang yurak',
    '🤍' => 'oq yurak',
    '💋' => 'bo‘sa tamg‘asi',
    '💯' => 'yuz ball',
    '💢' => 'jahl belgisi',
    '🫯' => 'janjal',
    '💥' => 'to‘qnashuv',
    '💫' => 'bosh aylanishi',
    '💦' => 'ter tomchilari',
    '💨' => 'chaqqon',
    '🕳' => 'teshik',
    '💬' => 'nutq pufagi',
    '🗨' => 'chap nutq pufakchasi',
    '🗯' => 'o‘ng burchakli pufakcha',
    '💭' => 'xayol buluti',
    '💤' => 'xurrak',
    '👋' => 'shapaloq',
    '🤚' => 'ko‘tarilgan kaft',
    '🖐' => 'barmoqlari yoyilgan qoʻl',
    '✋' => 'ko‘tarilgan qo‘l',
    '🖖' => 'vulkan salyuti',
    '🫱' => 'oʻng qoʻl',
    '🫲' => 'chap qoʻl',
    '🫳' => 'kafti pastga qaragan qoʻl',
    '🫴' => 'kafti yuqoriga qaragan qoʻl',
    '🫷' => 'kafti chapga qaragan qoʻl',
    '🫸' => 'kafti oʻngga qaragan qoʻl',
    '👌' => 'qo‘lda qilingan ok',
    '🤌' => 'chimdilgan barmoqlar',
    '🤏' => 'chimduvchi qoʻl',
    '✌' => 'v harfini ko‘rsatib turgan qo‘l',
    '🤞' => 'kesishgan barmoqlar',
    '🫰' => 'bosh va koʻrsatkich barmoqlar kesishgan qoʻl',
    '🤟' => 'sevaman degan ishora',
    '🤘' => 'shox belgisi',
    '🤙' => 'menga telefon qil',
    '👈' => 'ko‘rsatkich barmoq chapga',
    '👉' => 'ko‘rsatkich barmoq oʻngga',
    '👆' => 'ko‘rsatkich barmoq tepaga',
    '🖕' => 'o‘rta barmoq',
    '👇' => 'ko‘rsatkich barmoq pastga',
    '☝' => 'ko‘rsatkich barmoq tepada',
    '🫵' => 'tomoshabinga qaragan koʻrsatkich barmoq',
    '👍' => 'tepaga qaragan bosh barmoq',
    '👎' => 'pastga qaragan bosh barmoq',
    '✊' => 'ko‘tarilgan musht',
    '👊' => 'yaqinlashayotgan musht',
    '🤛' => 'chapga qaragan musht',
    '🤜' => 'o‘ngga qaragan musht',
    '👏' => 'chapak',
    '🙌' => 'qo‘llarini ko‘targan odam',
    '🫶' => 'qoʻlda yurak',
    '👐' => 'ochiq qo‘llar',
    '🤲' => 'kaftlar ochiq',
    '🤝' => 'qo‘l siqish',
    '🙏' => 'qovushtirilgan qo‘llar',
    '✍' => 'yozayotgan qo‘l',
    '💅' => 'tirnoq uchun lok',
    '🤳' => 'selfi',
    '💪' => 'baquvvat muskullar',
    '🦾' => 'mexanik qoʻl',
    '🦿' => 'mexanik oyoq',
    '🦵' => 'oyoq',
    '🦶' => 'toʼpiq',
    '👂' => 'quloq',
    '🦻' => 'eshitish qurilmasi taqilgan quloq',
    '👃' => 'burun',
    '🧠' => 'miya',
    '🫀' => 'yurak',
    '🫁' => 'oʻpka',
    '🦷' => 'tish',
    '🦴' => 'suyak',
    '👀' => 'ko‘zlar',
    '👁' => 'ko‘z',
    '👅' => 'til',
    '👄' => 'og‘iz',
    '🫦' => 'tishlangan lab',
    '👶' => 'chaqaloq',
    '🧒' => 'bola',
    '👦' => 'o‘g‘il bola',
    '👧' => 'qiz bola',
    '🧑' => 'voyaga yetgan',
    '👱' => 'shaxs: mallasoch',
    '👨' => 'erkak',
    '🧔' => 'erkak: soqolli',
    '👩' => 'ayol',
    '🧓' => 'qari odam',
    '👴' => 'chol',
    '👵' => 'kampir',
    '🙍' => 'xo‘mraygan odam',
    '🙎' => 'norozi odam',
    '🙅' => 'yo‘q ishorasi',
    '🙆' => 'ok ishorasi',
    '💁' => 'ma’lumotxona xodimi',
    '🙋' => 'qo‘lini ko‘tarib turgan xursand odam',
    '🧏' => 'kar odam',
    '🙇' => 'ta’zim qilayotgan odam',
    '🤦' => 'boshqa gapim yo‘q',
    '🤷' => 'bilmayman ishorasi',
    '👮' => 'politsiya xodimi',
    '🕵' => 'izquvar',
    '💂' => 'qo‘riqchi',
    '🥷' => 'ninza',
    '👷' => 'quruvchi',
    '🫅' => 'tojli odam',
    '🤴' => 'shahzoda',
    '👸' => 'malika',
    '👳' => 'salla kiygan erkak',
    '👲' => 'xitoy bosh kiyimini kiygan kishi',
    '🧕' => 'ro‘mol o‘ragan ayol',
    '🤵' => 'smoking kiygan odam',
    '👰' => 'nikoh kiyimidagi odam',
    '🤰' => 'homilador ayol',
    '🫃' => 'homilador erkak',
    '🫄' => 'homilador odam',
    '🤱' => 'emizish',
    '👼' => 'chaqaloq farishta',
    '🎅' => 'santa-klaus',
    '🤶' => 'qorqiz',
    '🦸' => 'superqahramon',
    '🦹' => 'salbiy superqahramon',
    '🧙' => 'sehrgar',
    '🧚' => 'pari',
    '🧛' => 'vampir',
    '🧜' => 'suv parisi',
    '🧝' => 'elf',
    '🧞' => 'jin',
    '🧟' => 'zombi',
    '🧌' => 'troll',
    '🫈' => 'serjun maxluq',
    '💆' => 'yuzni uqalash',
    '💇' => 'soch qisqartirish',
    '🚶' => 'piyoda odam',
    '🧍' => 'tik turgan odam',
    '🧎' => 'tiz choʻkkan odam',
    '🏃' => 'yuguruvchi',
    '💃' => 'raqqosa',
    '🕺' => 'raqs tushayotgan erkak',
    '🕴' => 'kostyum kiygan muallaq holatdagi kishi',
    '👯' => 'quyon quloqli odamlar',
    '🧖' => 'hammomdagi odam',
    '🧗' => 'cho‘qqiga chiqayotgan odam',
    '🤺' => 'qilichboz',
    '🏇' => 'otchopar',
    '⛷' => 'chang‘ichi',
    '🏂' => 'snoubordchi',
    '🏌' => 'golf o‘ynovchi',
    '🏄' => 'serfingchi',
    '🚣' => 'qayiq',
    '🏊' => 'suzuvchi',
    '⛹' => 'odam va to‘p',
    '🏋' => 'og‘ir atletikachi',
    '🚴' => 'velosipedchi',
    '🚵' => 'tog‘ velosipedchisi',
    '🤸' => 'akrobatik mashq',
    '🤼' => 'kurashchilar',
    '🤽' => 'suv polosi',
    '🤾' => 'gandbol',
    '🤹' => 'jonglyor',
    '🧘' => 'lotus holatidagi odam',
    '🛀' => 'hammom qilayotgan kishi',
    '🛌' => 'karavotda yotgan kishi',
    '👭' => 'qoʻl ushlashgan ayollar',
    '👫' => 'qoʻl ushlashgan ayol va erkak',
    '👬' => 'qoʻl ushlashgan erkaklar',
    '💏' => 'bo‘sa olish',
    '💑' => 'juftlik va yurak',
    '🗣' => 'gapirayotgan bosh',
    '👤' => 'kontur suratli byust',
    '👥' => 'kontur suratli byustlar',
    '🫂' => 'quchoqlashayotgan odamlar',
    '👪' => 'oila',
    '👣' => 'oyoq izlari',
    '🫆' => 'barmoq izi',
    '🦰' => 'malla soch',
    '🦱' => 'jingalak soch',
    '🦳' => 'oqargan soch',
    '🦲' => 'kal',
    '🐵' => 'maymun qiyofasi',
    '🐒' => 'maymun',
    '🦍' => 'gorilla',
    '🦧' => 'orangutan',
    '🐶' => 'kuchuk qiyofasi',
    '🐕' => 'kuchuk',
    '🦮' => 'boshlovchi it',
    '🐩' => 'pudel',
    '🐺' => 'boʻri',
    '🦊' => 'tulki',
    '🦝' => 'yenot',
    '🐱' => 'mushuk qiyofasi',
    '🐈' => 'mushuk',
    '🦁' => 'sher',
    '🐯' => 'yo‘lbars qiyofasi',
    '🐅' => 'yo‘lbars',
    '🐆' => 'qoplon',
    '🐴' => 'ot qiyofasi',
    '🫎' => 'bugʻu',
    '🫏' => 'eshak',
    '🐎' => 'ot',
    '🦄' => 'yakkashox',
    '🦓' => 'zebra',
    '🦌' => 'kiyik',
    '🦬' => 'bizon',
    '🐮' => 'sigir qiyofasi',
    '🐂' => 'ho‘kiz',
    '🐃' => 'buyvol',
    '🐄' => 'sigir',
    '🐷' => 'cho‘chqa qiyofasi',
    '🐖' => 'cho‘chqa',
    '🐗' => 'to‘ng‘iz',
    '🐽' => 'cho‘chqa burni',
    '🐏' => 'qo‘chqor',
    '🐑' => 'sovliq',
    '🐐' => 'echki',
    '🐪' => 'tuya',
    '🐫' => 'ikki o‘rkachli tuya',
    '🦙' => 'lama',
    '🦒' => 'jirafa',
    '🐘' => 'fil',
    '🦣' => 'mamont',
    '🦏' => 'karkidon',
    '🦛' => 'gippopotam',
    '🐭' => 'sichqon qiyofasi',
    '🐁' => 'sichqon',
    '🐀' => 'kalamush',
    '🐹' => 'oʻgmaxon',
    '🐰' => 'quyon qiyofasi',
    '🐇' => 'quyon',
    '🐿' => 'burunduq',
    '🦫' => 'suv qunduzi',
    '🦔' => 'tipratikan',
    '🦇' => 'ko‘rshapalak',
    '🐻' => 'ayiq',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'yalqov',
    '🦦' => 'qunduz',
    '🦨' => 'skuns',
    '🦘' => 'kenguru',
    '🦡' => 'bo‘rsiq',
    '🐾' => 'panja izlari',
    '🦃' => 'kurka',
    '🐔' => 'tovuq',
    '🐓' => 'xo‘roz',
    '🐣' => 'tuxumdan chiqayotgan jo‘ja',
    '🐤' => 'jo‘ja',
    '🐥' => 'oldiga qarab turgan jo‘ja',
    '🐦' => 'qush',
    '🐧' => 'pingvin',
    '🕊' => 'kabutar',
    '🦅' => 'burgut',
    '🦆' => 'o‘rdak',
    '🦢' => 'oqqush',
    '🦉' => 'boyqush',
    '🦤' => 'Mavrikiya dronti',
    '🪶' => 'pat',
    '🦩' => 'flamingo',
    '🦚' => 'tovus',
    '🦜' => 'to‘ti',
    '🪽' => 'qanot',
    '🪿' => 'gʻoz',
    '🐸' => 'baqa',
    '🐊' => 'timsoh',
    '🐢' => 'toshbaqa',
    '🦎' => 'kaltakesak',
    '🐍' => 'ilon',
    '🐲' => 'ajdar qiyofasi',
    '🐉' => 'ajdar',
    '🦕' => 'zauropod',
    '🦖' => 'T-Reks',
    '🐳' => 'favvora hosil qilayotgan kit',
    '🐋' => 'kit',
    '🐬' => 'delfin',
    '🫍' => 'orka',
    '🦭' => 'dengiz mushugi',
    '🐟' => 'baliq',
    '🐠' => 'tropik baliq',
    '🐡' => 'qorni katta baliq',
    '🦈' => 'akula',
    '🐙' => 'sakkizoyoq',
    '🐚' => 'spiral qobiq',
    '🪸' => 'marjon',
    '🪼' => 'meduza',
    '🦀' => 'qisqichbaqa',
    '🦞' => 'omar',
    '🦐' => 'mayda qisqichbaqa',
    '🦑' => 'kalmar',
    '🦪' => 'chigʻanoq',
    '🐌' => 'shilliqqurt',
    '🦋' => 'kapalak',
    '🐛' => 'taxtakana',
    '🐜' => 'chumoli',
    '🐝' => 'asalari',
    '🪲' => 'qoʻngʻiz',
    '🐞' => 'xonqizi',
    '🦗' => 'qora chigirtka',
    '🪳' => 'suvarak',
    '🕷' => 'o‘rgimchak',
    '🕸' => 'o‘rgimchak to‘ri',
    '🦂' => 'chayon',
    '🦟' => 'chivin',
    '🪰' => 'pashsha',
    '🪱' => 'qurt',
    '🦠' => 'mikrob',
    '💐' => 'guldasta',
    '🌸' => 'gilos guli',
    '💮' => 'oq gul',
    '🪷' => 'nilufar gul',
    '🏵' => 'to‘pbarggul',
    '🌹' => 'atirgul',
    '🥀' => 'so‘nayotgan gul',
    '🌺' => 'xitoy atirguli',
    '🌻' => 'kungaboqar',
    '🌼' => 'gul',
    '🌷' => 'lola',
    '🪻' => 'sumbul',
    '🌱' => 'ko‘chat',
    '🪴' => 'tuvakdagi oʻsimlik',
    '🌲' => 'archa',
    '🌳' => 'bargli daraxt',
    '🌴' => 'palma daraxti',
    '🌵' => 'kaktus',
    '🌾' => 'sholi poyasi',
    '🌿' => 'o‘simlik',
    '☘' => 'sebarga',
    '🍀' => 'to‘rt yaproqli beda bargi',
    '🍁' => 'zarang bargi',
    '🍂' => 'xazon bargi',
    '🍃' => 'shamolda uchayotgan barg',
    '🪹' => 'boʻsh in',
    '🪺' => 'tuxumlar bor in',
    '🍄' => 'qo‘ziqorin',
    '🪾' => 'bargsiz daraxt',
    '🍇' => 'uzum',
    '🍈' => 'qovun',
    '🍉' => 'tarvuz',
    '🍊' => 'mandarin',
    '🍋' => 'limon',
    '🍌' => 'banan',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'qizil olma',
    '🍏' => 'yashil olma',
    '🍐' => 'nok',
    '🍑' => 'shaftoli',
    '🍒' => 'gilos',
    '🍓' => 'qulupnay',
    '🫐' => 'chernika',
    '🥝' => 'kivi',
    '🍅' => 'pomidor',
    '🫒' => 'zaytun',
    '🥥' => 'kokos',
    '🥑' => 'avokado',
    '🍆' => 'baqlajon',
    '🥔' => 'kartoshka',
    '🥕' => 'sabzi',
    '🌽' => 'makkajo‘xori',
    '🌶' => 'achchiq qalampir',
    '🫑' => 'bolgar qalampiri',
    '🥒' => 'bodring',
    '🥬' => 'salat bargi',
    '🥦' => 'brokkoli',
    '🧄' => 'sarimsoq',
    '🧅' => 'piyoz',
    '🥜' => 'yeryong‘oq',
    '🫘' => 'loviya',
    '🌰' => 'kashtan yong‘og‘i',
    '🫚' => 'zanjabil ildizi',
    '🫛' => 'yashil loviya',
    '🫜' => 'ildiz shaklidagi sabzavotlar',
    '🍞' => 'non',
    '🥐' => 'kruassan',
    '🥖' => 'baget',
    '🫓' => 'malda non',
    '🥨' => 'kulcha',
    '🥯' => 'shirmoy teshik kulcha',
    '🥞' => 'blinchik',
    '🧇' => 'vafli',
    '🧀' => 'pishloq bo‘lagi',
    '🍖' => 'suyakdagi go‘sht',
    '🍗' => 'parranda oyog‘i',
    '🥩' => 'go‘sht bo‘lagi',
    '🥓' => 'bekon',
    '🍔' => 'gamburger',
    '🍟' => 'qovurilgan fri-kartoshka',
    '🍕' => 'pitsa',
    '🌭' => 'xot-dog',
    '🥪' => 'sendvich',
    '🌮' => 'tako',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'shaurma',
    '🧆' => 'falafel',
    '🥚' => 'tuxum',
    '🍳' => 'taom tayyorlash',
    '🥘' => 'bir tova qovurdoq',
    '🍲' => 'bir qozon ovqat',
    '🫕' => 'fondyu',
    '🥣' => 'kosa bilan qoshiq',
    '🥗' => 'sabzavotli salat',
    '🍿' => 'popkorn',
    '🧈' => 'sariyogʻ',
    '🧂' => 'tuzdon',
    '🥫' => 'konserva',
    '🍱' => 'xonachali taom qutisi',
    '🍘' => 'guruchli pishiriq',
    '🍙' => 'yumaloqlangan guruch',
    '🍚' => 'pishirilgan guruch',
    '🍛' => 'guruchli karri',
    '🍜' => 'qaynoq lag‘mon',
    '🍝' => 'spagetti',
    '🍠' => 'jigarli batat',
    '🍢' => 'sixdagi dengiz taomi',
    '🍣' => 'sushi',
    '🍤' => 'qovurilgan mayda qisqichbaqa',
    '🍥' => 'girdob ko‘rinishidagi baliqli tort',
    '🥮' => 'oyli pirog',
    '🍡' => 'dango',
    '🥟' => 'chuchvara',
    '🥠' => 'taqdir pechenyesi',
    '🥡' => 'taom olib ketish uchun quti',
    '🍦' => 'yumshoq muzqaymoq',
    '🍧' => 'qirilgan muz',
    '🍨' => 'muzqaymoq',
    '🍩' => 'ponchik',
    '🍪' => 'pishiriq',
    '🎂' => 'tort',
    '🍰' => 'tort bo‘lagi',
    '🧁' => 'kapkeyk',
    '🥧' => 'pirog',
    '🍫' => 'shokolad bo‘lagi',
    '🍬' => 'konfet',
    '🍭' => 'obakidandon',
    '🍮' => 'shirin krem',
    '🍯' => 'asal idishi',
    '🍼' => 'chaqaloqlar idishi',
    '🥛' => 'bir stakan sut',
    '☕' => 'qaynoq ichimlik',
    '🫖' => 'choynak',
    '🍵' => 'piyola',
    '🍶' => 'ko‘za va piyola',
    '🍾' => 'tiqinli shisha idish',
    '🍷' => 'vino qadahi',
    '🍸' => 'kokteyl qadahi',
    '🍹' => 'tropik ichimlik',
    '🍺' => 'pivo krujkasi',
    '🍻' => 'urishtirilayotgan pivo krujkalari',
    '🥂' => 'qadah urishtirish',
    '🥃' => 'viski qadahi',
    '🫗' => 'to‘kilayotgan suyuqlik',
    '🥤' => 'stakan bilan cho‘p',
    '🧋' => 'koʻpikli choy',
    '🧃' => 'ichimlik qutisi',
    '🧉' => 'mate',
    '🧊' => 'muz',
    '🥢' => 'tayoqcha',
    '🍽' => 'sanchqi, pichoq va likopcha',
    '🍴' => 'sanchqi va pichoq',
    '🥄' => 'qoshiq',
    '🔪' => 'pichoq',
    '🫙' => 'banka',
    '🏺' => 'ko‘za',
    '🌍' => 'globusda yevropa va afrika qit’asi',
    '🌎' => 'globusda amerika qit’asi',
    '🌏' => 'globusda osiyo va avstraliya qit’asi',
    '🌐' => 'meridian chiziqli globus',
    '🗺' => 'dunyo xaritasi',
    '🗾' => 'yaponiya xaritasi',
    '🧭' => 'kompas',
    '🏔' => 'qor qoplagan tog‘',
    '⛰' => 'tog‘',
    '🛘' => 'ko‘chki',
    '🌋' => 'vulqon',
    '🗻' => 'fuji tog‘i',
    '🏕' => 'tabiat qo‘ynida dam',
    '🏖' => 'qirg‘oq va soyabon',
    '🏜' => 'sahro',
    '🏝' => 'cho‘l orol',
    '🏞' => 'istirohat bog‘i',
    '🏟' => 'stadion',
    '🏛' => 'qadimiy bino',
    '🏗' => 'bino qurilishi',
    '🧱' => 'g‘ishtin',
    '🪨' => 'tosh',
    '🪵' => 'yogʻoch',
    '🛖' => 'kulba',
    '🏘' => 'uylar',
    '🏚' => 'tashlandiq uy',
    '🏠' => 'uy',
    '🏡' => 'hovli',
    '🏢' => 'ofis binosi',
    '🏣' => 'yaponcha pochtampt',
    '🏤' => 'pochtampt',
    '🏥' => 'shifoxona',
    '🏦' => 'bank',
    '🏨' => 'mehmonxona',
    '🏩' => 'sevgi mehmonxonasi',
    '🏪' => 'navbatchi do‘kon',
    '🏫' => 'maktab',
    '🏬' => 'univermag',
    '🏭' => 'zavod',
    '🏯' => 'yapon qasri',
    '🏰' => 'qasr',
    '💒' => 'nikoh to‘yi',
    '🗼' => 'tokio teleminorasi',
    '🗽' => 'ozodlik haykali',
    '⛪' => 'cherkov',
    '🕌' => 'masjid',
    '🛕' => 'hindu ibodatxonasi',
    '🕍' => 'sinagog',
    '⛩' => 'shinto shrin',
    '🕋' => 'kabatulloh',
    '⛲' => 'fontan',
    '⛺' => 'chodir',
    '🌁' => 'tumanli',
    '🌃' => 'yulduzli tun',
    '🏙' => 'shahar manzarasi',
    '🌄' => 'tog‘lar ortidan quyosh chiqishi',
    '🌅' => 'quyosh chiqishi',
    '🌆' => 'kunbotar mahaldagi shahar manzarasi',
    '🌇' => 'quyosh botishi',
    '🌉' => 'tundagi ko‘prik',
    '♨' => 'issiq buloq',
    '🎠' => 'karusel oti',
    '🛝' => 'bolalar maydonchasidagi sirpanchiq',
    '🎡' => 'charxpalak',
    '🎢' => 'g‘ildiratma hayinchak',
    '💈' => 'sartaroshlar ustuni',
    '🎪' => 'sirk chodiri',
    '🚂' => 'lokomotiv',
    '🚃' => 'temiryo‘l vagoni',
    '🚄' => 'tezyurar poyezd',
    '🚅' => 'oldi uchli tezyurar poyezd',
    '🚆' => 'poyezd',
    '🚇' => 'metro',
    '🚈' => 'tor izli temiryo‘l',
    '🚉' => 'bekat',
    '🚊' => 'tramvay',
    '🚝' => 'bir izli temiryo‘l',
    '🚞' => 'to‘g‘ temiryo‘li',
    '🚋' => 'tramvay vagoni',
    '🚌' => 'avtobus',
    '🚍' => 'yaqinlashayotgan avtobus',
    '🚎' => 'trolleybus',
    '🚐' => 'minibus',
    '🚑' => 'tez yordam mashinasi',
    '🚒' => 'o‘t o‘chirish mashinasi',
    '🚓' => 'politsiya mashinasi',
    '🚔' => 'yaqinlashayotgan politsiya mashinasi',
    '🚕' => 'taksi',
    '🚖' => 'yaqinlashayotgan taksi',
    '🚗' => 'avtomobil',
    '🚘' => 'yaqinlashayotgan avtomobil',
    '🚙' => 'hordiq chiqarish avtomobili',
    '🛻' => 'yuk mashinasi',
    '🚚' => 'yetkazib beruvchi yuk mashinasi',
    '🚛' => 'tirkamali yuk mashinasi',
    '🚜' => 'traktor',
    '🏎' => 'poyga mashinasi',
    '🏍' => 'mototsikl',
    '🛵' => 'moped',
    '🦽' => 'nogironlik aravachasi',
    '🦼' => 'motorli nogironlik aravachasi',
    '🛺' => 'avtoriksha',
    '🚲' => 'velosiped',
    '🛴' => 'samokat',
    '🛹' => 'skeytbord',
    '🛼' => 'gʻildirakli konki',
    '🚏' => 'avtobus bekati',
    '🛣' => 'avtomobil yo‘li',
    '🛤' => 'temiryo‘l',
    '🛢' => 'neft bochkasi',
    '⛽' => 'yonilg‘i nasosi',
    '🛞' => 'gʻildirak',
    '🚨' => 'politsiya mashinasi mayog‘i',
    '🚥' => 'yotiq svetofor',
    '🚦' => 'tik svetofor',
    '🛑' => 'stop belgisi',
    '🚧' => 'qurilish',
    '⚓' => 'langar',
    '🛟' => 'qutqaruv chambaragi',
    '⛵' => 'yelkanli kema',
    '🛶' => 'kanoe',
    '🚤' => 'tezyurar qayiq',
    '🛳' => 'yo‘lovchi kemasi',
    '⛴' => 'parom',
    '🛥' => 'motorli qayiq',
    '🚢' => 'kema',
    '✈' => 'samolyot',
    '🛩' => 'kichik samolyot',
    '🛫' => 'samolyot jo‘nab ketishi',
    '🛬' => 'samolyot qo‘nishi',
    '🪂' => 'parashyut',
    '💺' => 'o‘rindiq',
    '🚁' => 'vertolyot',
    '🚟' => 'osma temiryo‘l',
    '🚠' => 'tog‘ dor yo‘li',
    '🚡' => 'havo tramvayi',
    '🛰' => 'sun’iy yo‘ldosh',
    '🚀' => 'raketa',
    '🛸' => 'uchar likopcha',
    '🛎' => 'pochtachi qo‘ng‘irog‘i',
    '🧳' => 'jomadon',
    '⌛' => 'toʻlgan qumsoat',
    '⏳' => 'qum tushayotgan qumsoat',
    '⌚' => 'qo‘l soati',
    '⏰' => 'uyg‘otadigan soat',
    '⏱' => 'sekundomer',
    '⏲' => 'taymer soat',
    '🕰' => 'tosh soat',
    '🕛' => 'soat o‘n ikki',
    '🕧' => 'soat o‘n ikki yarim',
    '🕐' => 'soat bir',
    '🕜' => 'bir yarim',
    '🕑' => 'soat ikki',
    '🕝' => 'ikki yarim',
    '🕒' => 'soat uch',
    '🕞' => 'uch yarim',
    '🕓' => 'soat to‘rt',
    '🕟' => 'to‘rt yarim',
    '🕔' => 'soat besh',
    '🕠' => 'besh yarim',
    '🕕' => 'soat olti',
    '🕡' => 'olti yarim',
    '🕖' => 'soat yetti',
    '🕢' => 'yetti yarim',
    '🕗' => 'soat sakkiz',
    '🕣' => 'sakkiz yarim',
    '🕘' => 'soat to‘qqiz',
    '🕤' => 'to‘qqiz yarim',
    '🕙' => 'soat o‘n',
    '🕥' => 'o‘n yarim',
    '🕚' => 'soat o‘n bir',
    '🕦' => 'o‘n bir yarim',
    '🌑' => 'yangi oy',
    '🌒' => 'kattalashib boruvchi yarim oy',
    '🌓' => 'birinchi chorakdagi oy',
    '🌔' => 'kattalashib boruvchi qavariq oy',
    '🌕' => 'to‘lin oy',
    '🌖' => 'kichiklashib borayotgan qavariq oy',
    '🌗' => 'oxirgi chorakdagi oy',
    '🌘' => 'kichiklashib borayotgan yarim oy',
    '🌙' => 'oy',
    '🌚' => 'yangi oy qiyofasi',
    '🌛' => 'birinchi chorakdagi oy qiyofasi',
    '🌜' => 'oxirgi chorakdagi oy qiyofasi',
    '🌡' => 'termometr',
    '☀' => 'quyosh',
    '🌝' => 'to‘lin oy qiyofali',
    '🌞' => 'quyosh qiyofasi',
    '🪐' => 'halqali sayyora',
    '⭐' => 'oq o‘rtacha yulduz',
    '🌟' => 'porlayotgan yulduz',
    '🌠' => 'uchayotgan yulduz',
    '🌌' => 'somon yo‘li',
    '☁' => 'bulut',
    '⛅' => 'bulut ortidagi quyosh',
    '⛈' => 'bulut, chaqmoq va yomg‘ir',
    '🌤' => 'kichik bulut ortidagi quyosh',
    '🌥' => 'bulutlar ortidagi quyosh',
    '🌦' => 'yomg‘irli bulutlar ortidagi quyosh',
    '🌧' => 'yomg‘irli bulut',
    '🌨' => 'qor yog‘ayotgan bulut',
    '🌩' => 'chaqmoq chaqayotgan bulut',
    '🌪' => 'quyun',
    '🌫' => 'tuman',
    '🌬' => 'shamol qiyofasi',
    '🌀' => 'siklon',
    '🌈' => 'kamalak',
    '🌂' => 'yopiq soyabon',
    '☂' => 'soyabon',
    '☔' => 'yomg‘ir tomchilari va soyabon',
    '⛱' => 'qumga qadalgan soyabon',
    '⚡' => 'yuqori kuchlanish',
    '❄' => 'qor parchasi',
    '☃' => 'qorbobo va qor',
    '⛄' => 'qorbobo',
    '☄' => 'kometa',
    '🔥' => 'olov',
    '💧' => 'tomchi',
    '🌊' => 'suv to‘lqini',
    '🎃' => 'shamchiroqli oshqovoq',
    '🎄' => 'yangi yil archasi',
    '🎆' => 'mushakbozlik',
    '🎇' => 'bengal olovi',
    '🧨' => 'bang‘illoq',
    '✨' => 'uchqunlar',
    '🎈' => 'shar',
    '🎉' => 'paqildoq',
    '🎊' => 'konfetti',
    '🎋' => 'tanabata daraxti',
    '🎍' => 'qarag‘ay bezagi',
    '🎎' => 'yapon qo‘g‘irchoqlari',
    '🎏' => 'zog‘orabaliq shaklidagi vimpel',
    '🎐' => 'shamol qo‘ng‘irog‘i',
    '🎑' => 'oy marosimi',
    '🧧' => 'qizil xatjild',
    '🎀' => 'lenta',
    '🎁' => 'o‘ralgan sovg‘a',
    '🎗' => 'eslatma lentasi',
    '🎟' => 'kirish chiptalari',
    '🎫' => 'chipta',
    '🎖' => 'harbiy medal',
    '🏆' => 'kubok',
    '🏅' => 'sport medali',
    '🥇' => 'oltin medal',
    '🥈' => 'kumush medal',
    '🥉' => 'bronza medal',
    '⚽' => 'futbol to‘pi',
    '⚾' => 'beysbol',
    '🥎' => 'softbol',
    '🏀' => 'basketbol',
    '🏐' => 'voleybol',
    '🏈' => 'amerikancha futbol',
    '🏉' => 'regbi',
    '🎾' => 'tennis',
    '🥏' => 'uchar disk',
    '🎳' => 'bouling',
    '🏏' => 'kriket oʻyini',
    '🏑' => 'xokkey maydoni',
    '🏒' => 'xokkey tayog‘i va diski',
    '🥍' => 'lakross',
    '🏓' => 'stol tennisi',
    '🏸' => 'badminton',
    '🥊' => 'boks qo‘lqopi',
    '🥋' => 'sport kimonosi',
    '🥅' => 'sportga oid darvoza',
    '⛳' => 'teshikka o‘rnatilgan bayroq',
    '⛸' => 'konki',
    '🎣' => 'qarmoq',
    '🤿' => 'shoʻngʻish niqobi',
    '🎽' => 'yugurish futbolkasi',
    '🎿' => 'chang‘i',
    '🛷' => 'chana',
    '🥌' => 'kyorling',
    '🎯' => 'mo‘ljalni urish',
    '🪀' => 'yo-yo',
    '🪁' => 'varrak',
    '🔫' => 'suvli pistolet',
    '🎱' => 'billiard',
    '🔮' => 'kristall shar',
    '🪄' => 'sehrli tayoqcha',
    '🎮' => 'video o‘yin',
    '🕹' => 'joystik',
    '🎰' => 'o‘yin avtomati',
    '🎲' => 'shoshqol toshi',
    '🧩' => 'pazl qismi',
    '🧸' => 'baxmal ayiqcha',
    '🪅' => 'pinyata',
    '🪩' => 'oyna toʻp',
    '🪆' => 'matryoshka',
    '♠' => 'qarg‘a kartasi',
    '♥' => 'tappon kartasi',
    '♦' => 'g‘ishtin kartasi',
    '♣' => 'chillik kartasi',
    '♟' => 'piyoda',
    '🃏' => 'o‘yin kartasidagi joker',
    '🀄' => 'majong toshidagi qizil ajdar',
    '🎴' => 'gulli o‘yin kartalari',
    '🎭' => 'teatr niqoblari',
    '🖼' => 'ramkali surat',
    '🎨' => 'palitra',
    '🧵' => 'g‘altak',
    '🪡' => 'tikuv ignasi',
    '🧶' => 'o‘ram',
    '🪢' => 'tugun',
    '👓' => 'ko‘zoynak',
    '🕶' => 'quyoshdan himoyalaydigan ko‘zoynak',
    '🥽' => 'himoya ko‘zoynagi',
    '🥼' => 'laboratoriya xalati',
    '🦺' => 'qutqaruv kamzuli',
    '👔' => 'bo‘yinbog‘',
    '👕' => 'futbolka',
    '👖' => 'jinsi shim',
    '🧣' => 'sharf',
    '🧤' => 'qo‘lqop',
    '🧥' => 'palto',
    '🧦' => 'paypoq',
    '👗' => 'libos',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'yaxlit choʻmilish kiyimi',
    '🩲' => 'trusik',
    '🩳' => 'kalta ishton',
    '👙' => 'bikini',
    '👚' => 'ayollar kiyimi',
    '🪭' => 'yelpigʻich',
    '👛' => 'hamyon',
    '👜' => 'ayollar qo‘l sumkasi',
    '👝' => 'kichik sumka',
    '🛍' => 'xarid sumkalari',
    '🎒' => 'ryukzak',
    '🩴' => 'tasmali sandal',
    '👞' => 'erkaklar tuflisi',
    '👟' => 'krossovka',
    '🥾' => 'tog‘ poyafzali',
    '🥿' => 'baletka',
    '👠' => 'baland poshnali tufli',
    '👡' => 'ayollar shippagi',
    '🩰' => 'balet poyafzali',
    '👢' => 'ayollar etigi',
    '🪮' => 'soch toʻgʻnagʻichi',
    '👑' => 'toj',
    '👒' => 'ayollar shlyapasi',
    '🎩' => 'silindr shlyapa',
    '🎓' => 'akademik bosh kiyim',
    '🧢' => 'beysbolka',
    '🪖' => 'harbiy kaska',
    '⛑' => 'oq xochli dubulg‘a',
    '📿' => 'tasbeh',
    '💄' => 'lab bo‘yog‘i',
    '💍' => 'uzuk',
    '💎' => 'qimmatbaho tosh',
    '🔇' => 'ovozsiz',
    '🔈' => 'karnay',
    '🔉' => 'ovozli',
    '🔊' => 'baland ovoz',
    '📢' => 'e’lon qiluvchi karnay',
    '📣' => 'megafon',
    '📯' => 'shoxsimon nay',
    '🔔' => 'qo‘ng‘iroq',
    '🔕' => 'taqiqlovchi chizig‘i bor qo‘ng‘iroq',
    '🎼' => 'musiqa kaliti',
    '🎵' => 'musiqiy nota',
    '🎶' => 'musiqiy notalar',
    '🎙' => 'studiya mikrofoni',
    '🎚' => 'daraja slayderi',
    '🎛' => 'ovoz boshqarish paneli',
    '🎤' => 'mikrofon',
    '🎧' => 'quloqlik',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'truba',
    '🪊' => 'trombon',
    '🪗' => 'akkordeon',
    '🎸' => 'gitara',
    '🎹' => 'musiqiy klaviatura',
    '🎻' => 'skripka',
    '🪕' => 'banjo',
    '🥁' => 'baraban',
    '🪘' => 'uzun nogʻora',
    '🪇' => 'marakas',
    '🪈' => 'nay',
    '🪉' => 'arfa',
    '📱' => 'mobil telefon',
    '📲' => 'mobil telefon va strelka',
    '☎' => 'telefon',
    '📞' => 'telefon go‘shagi',
    '📟' => 'peyjer',
    '📠' => 'faks apparati',
    '🔋' => 'batareya',
    '🪫' => 'batareya kam',
    '🔌' => 'elektr kabel sanchqisi',
    '💻' => 'noutbuk',
    '🖥' => 'ish stoli kompyuteri',
    '🖨' => 'printer',
    '⌨' => 'klaviatura',
    '🖱' => 'kompyuter sichqonchasi',
    '🖲' => 'trekbol',
    '💽' => 'mini-disk',
    '💾' => 'disketa',
    '💿' => 'optik disk',
    '📀' => 'dvd',
    '🧮' => 'cho‘t',
    '🎥' => 'kinokamera',
    '🎞' => 'film kadri',
    '📽' => 'film proyektori',
    '🎬' => 'klaper taxtasi',
    '📺' => 'televizor',
    '📷' => 'kamera',
    '📸' => 'chaqmoqli kamera',
    '📹' => 'videokamera',
    '📼' => 'videokasseta',
    '🔍' => 'chapga qiyshaygan lupa',
    '🔎' => 'oʻngga qiyshaygan lupa',
    '🕯' => 'sham',
    '💡' => 'elektr lampasi',
    '🔦' => 'fonar',
    '🏮' => 'qizil qog‘ozli lampa',
    '🪔' => 'moychiroq',
    '📔' => 'bezakli muqovali daftar',
    '📕' => 'yopiq kitob',
    '📖' => 'ochiq kitob',
    '📗' => 'yashil kitob',
    '📘' => 'ko‘k kitob',
    '📙' => 'to‘q sariq kitob',
    '📚' => 'kitoblar',
    '📓' => 'noutbook',
    '📒' => 'ro‘yxatga olish kitobi',
    '📃' => 'gajakli sahifa',
    '📜' => 'o‘ralgan xat',
    '📄' => 'oldiga qarab turgan sahifa',
    '📰' => 'gazeta',
    '🗞' => 'o‘ralgan gazeta',
    '📑' => 'sahifalardagi xatcho‘p',
    '🔖' => 'xatcho‘p',
    '🏷' => 'yorliq',
    '🪙' => 'tanga',
    '💰' => 'pul xalta',
    '🪎' => 'xazina sandigʻi',
    '💴' => 'iyena banknotasi',
    '💵' => 'dollar banknotasi',
    '💶' => 'yevro banknotasi',
    '💷' => 'funt sterling banknotasi',
    '💸' => 'qanoti bor pul dastasi',
    '💳' => 'kredit karta',
    '🧾' => 'chek',
    '💹' => 'o‘sayotgan iyena diagrammasi',
    '✉' => 'konvert',
    '📧' => 'e-pochta',
    '📨' => 'kiruvchi konvert',
    '📩' => 'strelkali konvert',
    '📤' => 'chiquvchi xat qutisi',
    '📥' => 'kiruvchi xat qutisi',
    '📦' => 'qadoq',
    '📫' => 'bayroqchasi ko‘tarilgan yopiq pochta qutisi',
    '📪' => 'pastga qaragan yopiq pochta qutisi',
    '📬' => 'yuqoriga qaragan ochiq pochta qutisi',
    '📭' => 'pastga qaragan bayroqli pochta qutisi',
    '📮' => 'pochta qutisi',
    '🗳' => 'quti va saylov byulleteni',
    '✏' => 'qalam',
    '✒' => 'qora pero',
    '🖋' => 'peroli ruchka',
    '🖊' => 'ruchka',
    '🖌' => 'mo‘yqalam',
    '🖍' => 'rangli qalam',
    '📝' => 'qayd',
    '💼' => 'portfel',
    '📁' => 'fayl jildi',
    '📂' => 'ochiq fayl jildi',
    '🗂' => 'fayllarni ajratuvchi',
    '📅' => 'taqvim',
    '📆' => 'yirtiladigan taqvim',
    '🗒' => 'spiralli yon daftarcha',
    '🗓' => 'ilma taqvim',
    '📇' => 'kartoteka',
    '📈' => 'o‘sish trendi diagrammasi',
    '📉' => 'pasayish trendi diagrammasi',
    '📊' => 'ustunli diagramma',
    '📋' => 'qisqichli doska',
    '📌' => 'bosma mix',
    '📍' => 'yumaloq bosma mix',
    '📎' => 'qistirgich',
    '🖇' => 'ulangan qistirgichlar',
    '📏' => 'chizg‘ich',
    '📐' => 'uchburchak chizg‘ich',
    '✂' => 'qaychi',
    '🗃' => 'fayl qutisi',
    '🗄' => 'fayllar javoni',
    '🗑' => 'qog‘oz chiqitdoni',
    '🔒' => 'qulflangan',
    '🔓' => 'ochiq qulf',
    '🔏' => 'qulf va ruchka',
    '🔐' => 'qulf va kalit',
    '🔑' => 'kalit',
    '🗝' => 'qadimiy kalit',
    '🔨' => 'bolg‘a',
    '🪓' => 'bolta',
    '⛏' => 'uchli bolg‘a',
    '⚒' => 'bolg‘a va uchli bolg‘a',
    '🛠' => 'bolg‘a va gayka kaliti',
    '🗡' => 'xanjar',
    '⚔' => 'kesishgan qilichlar',
    '💣' => 'bomba',
    '🪃' => 'bumerang',
    '🏹' => 'kamon va o‘q',
    '🛡' => 'qalqon',
    '🪚' => 'duradgorlik arrasi',
    '🔧' => 'gayka kaliti',
    '🪛' => 'otvertka',
    '🔩' => 'gayka va murvat',
    '⚙' => 'tishli g‘ildirak',
    '🗜' => 'kompressor',
    '⚖' => 'tarozi',
    '🦯' => 'hassa',
    '🔗' => 'havola',
    '⛓' => 'zanjirlar',
    '🪝' => 'ilgak',
    '🧰' => 'asbob-uskuna qutisi',
    '🧲' => 'magnit',
    '🪜' => 'narvon',
    '🪏' => 'kurakcha',
    '⚗' => 'haydash kimyoviy shishasi',
    '🧪' => 'probirka',
    '🧫' => 'petri idishi',
    '🧬' => 'dnk',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'sun’iy yo‘ldoshli antenna',
    '💉' => 'shprits',
    '🩸' => 'qon tomchisi',
    '💊' => 'hapdori',
    '🩹' => 'plastir',
    '🩼' => 'qoʻltiqtayoq',
    '🩺' => 'stetoskop',
    '🩻' => 'rentgen',
    '🚪' => 'eshik',
    '🛗' => 'lift',
    '🪞' => 'oyna',
    '🪟' => 'deraza',
    '🛏' => 'karavot',
    '🛋' => 'divan va lampa',
    '🪑' => 'stul',
    '🚽' => 'tualet',
    '🪠' => 'tortgich',
    '🚿' => 'dush',
    '🛁' => 'vanna',
    '🪤' => 'sichqon tutgich',
    '🪒' => 'ustara',
    '🧴' => 'losyon shishasi',
    '🧷' => 'to‘g‘nag‘ich',
    '🧹' => 'supurgi',
    '🧺' => 'savat',
    '🧻' => 'qog‘oz o‘rami',
    '🪣' => 'chelak',
    '🧼' => 'sovun',
    '🫧' => 'pufak',
    '🪥' => 'tish choʻtkasi',
    '🧽' => 'yuvgich',
    '🧯' => 'o‘to‘chirgich',
    '🛒' => 'xarid savatchasi',
    '🚬' => 'chekish',
    '⚰' => 'tobut',
    '🪦' => 'qabr toshi',
    '⚱' => 'dafn ko‘zasi',
    '🧿' => 'nazar tumori',
    '🪬' => 'xamsa',
    '🗿' => 'moai',
    '🪧' => 'plakat',
    '🪪' => 'ID karta',
    '🏧' => 'bankomat',
    '🚮' => 'axlatni o‘z joyiga tashlash',
    '🚰' => 'ichimlik suvi',
    '♿' => 'nogironlar aravachasi',
    '🚹' => 'erkaklar xonasi',
    '🚺' => 'ayollar xonasi',
    '🚻' => 'pardoz-andoz xonasi',
    '🚼' => 'chaqaloq belgisi',
    '🚾' => 'hojatxona',
    '🛂' => 'pasport nazorati',
    '🛃' => 'bojxona',
    '🛄' => 'yuklarni olish joyi',
    '🛅' => 'saqlash xonasida qoldirilgan yuk',
    '⚠' => 'ogohlantirish',
    '🚸' => 'bolalar o‘tish joyi',
    '⛔' => 'kirish mumkin emas',
    '🚫' => 'to‘xtab turish taqiqlanadi',
    '🚳' => 'velosipedda harakatlanish taqiqlanadi',
    '🚭' => 'chekish taqiqlanadi',
    '🚯' => 'axlat tashlash taqiqlanadi',
    '🚱' => 'ichib bo‘lmaydigan suv',
    '🚷' => 'piyodalar harakatlanishi mumkin emas',
    '📵' => 'telefon mumkin emas',
    '🔞' => '18 yoshdan kichiklarga taqiqlangan',
    '☢' => 'radioaktiv',
    '☣' => 'biologik xavf',
    '⬆' => 'yuqoriga strelka',
    '↗' => 'o‘ng-yuqoriga strelka',
    '➡' => 'oʻngga strelka',
    '↘' => 'o‘ng-pastga strelka',
    '⬇' => 'pastga strelka',
    '↙' => 'past-chapga strelka',
    '⬅' => 'chapga strelka',
    '↖' => 'chap yuqoriga strelka',
    '↕' => 'tepa-pastga strelka',
    '↔' => 'chapga-o‘ngga strelka',
    '↩' => 'o‘ngdan chapga qayrilish',
    '↪' => 'chapdan o‘ngga qayrilish',
    '⤴' => 'o‘ngdan yuqoriga qayrilish',
    '⤵' => 'o‘ngdan pastga qayrilish',
    '🔃' => 'soat mili yo‘nalishi bo‘yicha',
    '🔄' => 'soat millariga qarshi yo‘nalish',
    '🔙' => 'orqaga yo‘nalish',
    '🔚' => 'berk chizig‘i',
    '🔛' => 'efirda chizig‘i',
    '🔜' => 'tez orada chizig‘i',
    '🔝' => 'tepaga chizig‘i',
    '🛐' => 'ibodatxona',
    '⚛' => 'atom belgisi',
    '🕉' => 'om',
    '✡' => 'dovud yulduzi',
    '☸' => 'dharma g‘ildiragi',
    '☯' => 'yin yang',
    '✝' => 'lotin xoch',
    '☦' => 'pravoslav xoch',
    '☪' => 'yulduz va yarim oy',
    '☮' => 'tinchlik ramzi',
    '🕎' => 'yadaim',
    '🔯' => 'nuqtali olti qirrali yulduz',
    '🪯' => 'kxanda',
    '♈' => 'qo‘y burji',
    '♉' => 'sigir burji',
    '♊' => 'egizaklar burji',
    '♋' => 'qisqichbaqa burji',
    '♌' => 'arslon burji',
    '♍' => 'sunbula burji',
    '♎' => 'tarozi burji',
    '♏' => 'chayon burji',
    '♐' => 'o‘qotar burji',
    '♑' => 'tog‘ echkisi burji',
    '♒' => 'qovg‘a burji',
    '♓' => 'baliq burji',
    '⛎' => 'ilon tashuvchi',
    '🔀' => 'tasodifiy tartibda belgisi',
    '🔁' => 'takrorlash tugmasi',
    '🔂' => 'bittasini takrorlash tugmasi',
    '▶' => 'ijro tugmasi',
    '⏩' => 'oldinga o‘tkazish tugmasi',
    '⏭' => 'keyingi qo‘shiq tugmasi',
    '⏯' => 'ijro yoki pauza tugmasi',
    '◀' => 'orqaga o‘tkazish tugmasi',
    '⏪' => 'tez orqaga o‘tkazish tugmasi',
    '⏮' => 'oldingi qo‘shiq tugmasi',
    '🔼' => 'yuqoriga tugmasi',
    '⏫' => 'tez yuqoriga tugmasi',
    '🔽' => 'pastga tugmasi',
    '⏬' => 'tez pastga tugmasi',
    '⏸' => 'pauza tugmasi',
    '⏹' => 'to‘xtatish tugmasi',
    '⏺' => 'ovoz yozish tugmasi',
    '⏏' => 'chiqarish tugmasi',
    '🎦' => 'kinoteatr',
    '🔅' => 'xiralik tugmasi',
    '🔆' => 'yorqinlik tugmasi',
    '📶' => 'antenna ko‘rsatkichlari',
    '🛜' => 'simsiz',
    '📳' => 'tebranish rejimi',
    '📴' => 'telefon o‘chiq beligisi',
    '♀' => 'ayol belgisi',
    '♂' => 'erkak belgisi',
    '⚧' => 'transseksuallik belgisi',
    '✖' => 'koʻpaytiruv',
    '➕' => 'qoʻshuv',
    '➖' => 'ayiruv',
    '➗' => 'boʻluv',
    '🟰' => 'tenglik belgisi',
    '♾' => 'cheksizlik',
    '‼' => 'juft undov belgisi',
    '⁉' => 'undov soʻroq belgisi',
    '❓' => 'qizil soʻroq belgisi',
    '❔' => 'oq soʻroq belgisi',
    '❕' => 'oq undov belgisi',
    '❗' => 'qizil undov belgisi',
    '〰' => 'to‘lqinli chiziq',
    '💱' => 'pul birligini almashtirish',
    '💲' => 'katta dollar belgisi',
    '⚕' => 'tibbiy ramz',
    '♻' => 'qayta ishlash belgisi',
    '⚜' => 'gulsapsar',
    '🔱' => 'uch shoxli nayza',
    '📛' => 'ism yoziladigan nishon',
    '🔰' => 'boshlovchi yaponcha belgi',
    '⭕' => 'boʻsh qizil doira',
    '✅' => 'belgilash tugmasi belgisi',
    '☑' => 'belgilangan belgilash maydonchasi',
    '✔' => 'belgilash belgisi',
    '❌' => 'krest belgisi',
    '❎' => 'krest belgili tugma',
    '➰' => 'jingalak halqa',
    '➿' => 'qo‘sh jingalak halqa',
    '〽' => 'ovoz almashinuvi belgisi',
    '✳' => 'sakkiz qirrali yulduz',
    '✴' => 'sakkiz burchakli yulduz',
    '❇' => 'uchqun',
    '™' => 'savdo belgisi',
    '🫟' => 'sachratish',
    '🔠' => 'katta lotin harflarini kiritish',
    '🔡' => 'kichik lotin harflarini kiritish',
    '🔢' => 'raqam kiritish',
    '🔣' => 'belgi kiritish',
    '🔤' => 'lotin harflarini kiritish',
    '🅰' => 'a tugmasi',
    '🆎' => 'ab tugmasi',
    '🅱' => 'b tugmasi',
    '🆑' => 'kvadrat ichidagi cl harflari',
    '🆒' => 'kvadrat ichidagi salqinlik, gap yo‘q so‘zi',
    '🆓' => 'kvadrat ichidagi bo‘sh, tekin so‘zi',
    'ℹ' => 'axborot manbasi',
    '🆔' => 'kvadrat ichidagi id harflari',
    'Ⓜ' => 'aylana ichidagi m harfi',
    '🆕' => 'kvadrat ichidagi yangi so‘zi',
    '🆖' => 'kvadrat ichidagi ng harflari',
    '🅾' => 'o tugmasi',
    '🆗' => 'kvadrat ichidagi ok tugmasi',
    '🅿' => 'p tugmasi',
    '🆘' => 'kvadrat ichidagi sos so‘zi',
    '🆙' => 'tepaga tugmasi',
    '🆚' => 'kvadrat ichidagi raqib sifatida so‘zi',
    '🈁' => 'kvadrat ichidagi katakanadagi koko so‘zi',
    '🈂' => 'kvadrat ichidagi katakana sa morasi',
    '🈷' => 'kvadrat ichidagi oy iyeroglifi',
    '🈶' => 'kvadrat ichidagi mavjudlik iyeroglifi',
    '🈯' => 'kvadrat ichidagi barmoq iyeroglifi',
    '🉐' => 'aylana ichidagi afzallik iyeroglifi',
    '🈹' => 'kvadrat ichidagi bo‘lish iyeroglifi',
    '🈚' => 'kvadrat ichidagi inkor iyeroglifi',
    '🈲' => 'kvadrat ichidagi taqiqlash iyeroglifi',
    '🉑' => 'aylana ichidagi qabul qilish iyeroglifi',
    '🈸' => 'kvadrat ichidagi tatbiq qilish iyeroglifi',
    '🈴' => 'kvadrat ichidagi birgalik iyeroglifi',
    '🈳' => 'kvadrat ichidagi bo‘shliq iyeroglifi',
    '㊗' => 'aylana ichidagi bayram iyeroglifi',
    '㊙' => 'yaponcha “maxfiy” belgisi',
    '🈺' => 'yaponcha “biznes uchun ochiq” belgisi',
    '🈵' => 'yaponcha “vakansiya yoʻq” belgisi',
    '🔴' => 'qizil doira',
    '🟠' => 'sabzirang doira',
    '🟡' => 'sariq doira',
    '🟢' => 'yashil doira',
    '🔵' => 'ko‘k doira',
    '🟣' => 'binafsharang doira',
    '🟤' => 'jigarrang doira',
    '⚫' => 'qora doira',
    '⚪' => 'oq doira',
    '🟥' => 'qizil kvadrat',
    '🟧' => 'apelsinrang kvadrat',
    '🟨' => 'sariq kvadrat',
    '🟩' => 'yashil kvadrat',
    '🟦' => 'koʻk kvadrat',
    '🟪' => 'binafsharang kvadrat',
    '🟫' => 'jigarrang kvadrat',
    '⬛' => 'katta qora kvadrat',
    '⬜' => 'katta oq kvadrat',
    '◼' => 'o‘rtacha qora kvadrat',
    '◻' => 'o‘rtacha oq kvadrat',
    '◾' => 'kichikroq qora kvadrat',
    '◽' => 'kichikroq oq kvadrat',
    '▪' => 'kichik qora kvadrat',
    '▫' => 'kichik oq kvadrat',
    '🔶' => 'katta to‘q sariq romb',
    '🔷' => 'katta ko‘k romb',
    '🔸' => 'kichik to‘q sariq romb',
    '🔹' => 'kichik ko‘k romb',
    '🔺' => 'tepaga qaragan qizil uchburchak',
    '🔻' => 'pastga qaragan qizil uchburchak',
    '💠' => 'nuqtali romb',
    '🔘' => 'radio tugma',
    '🔳' => 'oq kvadrat katak',
    '🔲' => 'qora kvadrat katak',
    '🏁' => 'katak-katak bayroq',
    '🚩' => 'uchburchak bayroq',
    '🎌' => 'bir-birini kesib o‘tgan bayroqlar',
    '🏴' => 'hilpiragan qora bayroq',
    '🏳' => 'hilpiragan oq bayroq',
];
