<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'بوسہ: شخص، شخص، جلد کی ہلکی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'بوسہ: شخص، شخص، جلد کی ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'بوسہ: شخص، شخص، جلد کی ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'بوسہ: شخص، شخص، جلد کی ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'بوسہ: شخص، شخص، جلد کی درمیانی -ہلکی رنگت، اور جلد کی ہلکی رنگت',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'بوسہ: شخص، شخص، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'بوسہ: شخص، شخص، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'بوسہ: شخص، شخص، جلد کی درمیانی -ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'بوسہ: شخص، شخص، جلد کی درمیانی رنگت، اور جلد کی ہلکی رنگت',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'بوسہ: شخص، شخص، جلد کی درمیانی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'بوسہ: شخص، شخص، جلد کی درمیانی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'بوسہ: شخص، شخص، جلد کی درمیانی رنگت، اور جلد کی سیاہ رنگت',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'بوسہ: شخص، شخص، جلد کی درمیانی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'بوسہ: شخص، شخص، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'بوسہ: شخص، شخص، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'بوسہ: شخص، شخص، جلد کی درمیانی سیاہ رنگت، اور جلد کی سیاہ رنگت',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'بوسہ: شخص، شخص، جلد کی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'بوسہ: شخص، شخص، جلد کی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'بوسہ: شخص، شخص، جلد کی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'بوسہ: شخص، شخص، جلد کی سیاہ رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏻‍❤‍💋‍👨🏻' => 'بوسہ: مرد، مرد، اور جلد کی ہلکی رنگت',
    '👨🏻‍❤‍💋‍👨🏼' => 'بوسہ: مرد، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏻‍❤‍💋‍👨🏽' => 'بوسہ: مرد، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👨🏻‍❤‍💋‍👨🏾' => 'بوسہ: مرد، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏻‍❤‍💋‍👨🏿' => 'بوسہ: مرد، مرد، جلد کی ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👨🏼‍❤‍💋‍👨🏻' => 'بوسہ: مرد، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی ہلکی رنگت',
    '👨🏼‍❤‍💋‍👨🏼' => 'بوسہ: مرد، مرد، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏼‍❤‍💋‍👨🏽' => 'بوسہ: مرد، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👨🏼‍❤‍💋‍👨🏾' => 'بوسہ: مرد، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏼‍❤‍💋‍👨🏿' => 'بوسہ: مرد، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👨🏽‍❤‍💋‍👨🏻' => 'بوسہ: مرد، مرد، جلد کی درمیانی رنگت، اور جلد کی ہلکی رنگت',
    '👨🏽‍❤‍💋‍👨🏼' => 'بوسہ: مرد، مرد، جلد کی درمیانی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍❤‍💋‍👨🏽' => 'بوسہ: مرد، مرد، اور جلد کی درمیانی رنگت',
    '👨🏽‍❤‍💋‍👨🏾' => 'بوسہ: مرد، مرد، جلد کی درمیانی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏽‍❤‍💋‍👨🏿' => 'بوسہ: مرد، مرد، جلد کی درمیانی رنگت، اور جلد کی سیاہ رنگت',
    '👨🏾‍❤‍💋‍👨🏻' => 'بوسہ: مرد، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👨🏾‍❤‍💋‍👨🏼' => 'بوسہ: مرد، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏾‍❤‍💋‍👨🏽' => 'بوسہ: مرد، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👨🏾‍❤‍💋‍👨🏾' => 'بوسہ: مرد، مرد، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏾‍❤‍💋‍👨🏿' => 'بوسہ: مرد، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی سیاہ رنگت',
    '👨🏿‍❤‍💋‍👨🏻' => 'بوسہ: مرد، مرد، جلد کی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👨🏿‍❤‍💋‍👨🏼' => 'بوسہ: مرد، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏿‍❤‍💋‍👨🏽' => 'بوسہ: مرد، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👨🏿‍❤‍💋‍👨🏾' => 'بوسہ: مرد، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍❤‍💋‍👨🏿' => 'بوسہ: مرد، مرد، اور جلد کی سیاہ رنگت',
    '👩🏻‍❤‍💋‍👨🏻' => 'بوسہ: عورت، مرد، اور جلد کی ہلکی رنگت',
    '👩🏻‍❤‍💋‍👨🏼' => 'بوسہ: عورت، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏻‍❤‍💋‍👨🏽' => 'بوسہ: عورت، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👩🏻‍❤‍💋‍👨🏾' => 'بوسہ: عورت، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍❤‍💋‍👨🏿' => 'بوسہ: عورت، مرد، جلد کی ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏼‍❤‍💋‍👨🏻' => 'بوسہ: عورت، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی ہلکی رنگت',
    '👩🏼‍❤‍💋‍👨🏼' => 'بوسہ: عورت، مرد، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏼‍❤‍💋‍👨🏽' => 'بوسہ: عورت، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👩🏼‍❤‍💋‍👨🏾' => 'بوسہ: عورت، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏼‍❤‍💋‍👨🏿' => 'بوسہ: عورت، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏽‍❤‍💋‍👨🏻' => 'بوسہ: عورت، مرد، جلد کی درمیانی رنگت، اور جلد کی ہلکی رنگت',
    '👩🏽‍❤‍💋‍👨🏼' => 'بوسہ: عورت، مرد، جلد کی درمیانی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍❤‍💋‍👨🏽' => 'بوسہ: عورت، مرد، اور جلد کی درمیانی رنگت',
    '👩🏽‍❤‍💋‍👨🏾' => 'بوسہ: عورت، مرد، جلد کی درمیانی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏽‍❤‍💋‍👨🏿' => 'بوسہ: عورت، مرد، جلد کی درمیانی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏾‍❤‍💋‍👨🏻' => 'بوسہ: عورت، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👩🏾‍❤‍💋‍👨🏼' => 'بوسہ: عورت، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏾‍❤‍💋‍👨🏽' => 'بوسہ: عورت، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👩🏾‍❤‍💋‍👨🏾' => 'بوسہ: عورت، مرد، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏾‍❤‍💋‍👨🏿' => 'بوسہ: عورت، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی سیاہ رنگت',
    '👩🏿‍❤‍💋‍👨🏻' => 'بوسہ: عورت، مرد، جلد کی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👩🏿‍❤‍💋‍👨🏼' => 'بوسہ: عورت، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏿‍❤‍💋‍👨🏽' => 'بوسہ: عورت، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👩🏿‍❤‍💋‍👨🏾' => 'بوسہ: عورت، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍❤‍💋‍👨🏿' => 'بوسہ: عورت، مرد، اور جلد کی سیاہ رنگت',
    '👩🏻‍❤‍💋‍👩🏻' => 'بوسہ: عورت، عورت، اور جلد کی ہلکی رنگت',
    '👩🏻‍❤‍💋‍👩🏼' => 'بوسہ: عورت، عورت، جلد کی ہلکی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏻‍❤‍💋‍👩🏽' => 'بوسہ: عورت، عورت، جلد کی ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👩🏻‍❤‍💋‍👩🏾' => 'بوسہ: عورت، عورت، جلد کی ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍❤‍💋‍👩🏿' => 'بوسہ: عورت، عورت، جلد کی ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏼‍❤‍💋‍👩🏻' => 'بوسہ: عورت، عورت، جلد کی درمیانی -ہلکی رنگت، اور جلد کی ہلکی رنگت',
    '👩🏼‍❤‍💋‍👩🏼' => 'بوسہ: عورت، عورت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏼‍❤‍💋‍👩🏽' => 'بوسہ: عورت، عورت، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👩🏼‍❤‍💋‍👩🏾' => 'بوسہ: عورت، عورت، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏼‍❤‍💋‍👩🏿' => 'بوسہ: عورت، عورت، جلد کی درمیانی -ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏽‍❤‍💋‍👩🏻' => 'بوسہ: عورت، عورت، جلد کی درمیانی رنگت، اور جلد کی ہلکی رنگت',
    '👩🏽‍❤‍💋‍👩🏼' => 'بوسہ: عورت، عورت، جلد کی درمیانی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍❤‍💋‍👩🏽' => 'بوسہ: عورت، عورت، اور جلد کی درمیانی رنگت',
    '👩🏽‍❤‍💋‍👩🏾' => 'بوسہ: عورت، عورت، جلد کی درمیانی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏽‍❤‍💋‍👩🏿' => 'بوسہ: عورت، عورت، جلد کی درمیانی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏾‍❤‍💋‍👩🏻' => 'بوسہ: عورت، عورت، جلد کی درمیانی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👩🏾‍❤‍💋‍👩🏼' => 'بوسہ: عورت، عورت، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏾‍❤‍💋‍👩🏽' => 'بوسہ: عورت، عورت، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👩🏾‍❤‍💋‍👩🏾' => 'بوسہ: عورت، عورت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏾‍❤‍💋‍👩🏿' => 'بوسہ: عورت، عورت، جلد کی درمیانی سیاہ رنگت، اور جلد کی سیاہ رنگت',
    '👩🏿‍❤‍💋‍👩🏻' => 'بوسہ: عورت، عورت، جلد کی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👩🏿‍❤‍💋‍👩🏼' => 'بوسہ: عورت، عورت، جلد کی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏿‍❤‍💋‍👩🏽' => 'بوسہ: عورت، عورت، جلد کی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👩🏿‍❤‍💋‍👩🏾' => 'بوسہ: عورت، عورت، جلد کی سیاہ رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍❤‍💋‍👩🏿' => 'بوسہ: عورت، عورت، اور جلد کی سیاہ رنگت',
    '🧑🏻‍🫯‍🧑🏼' => 'پہلوان: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏻‍🫯‍🧑🏽' => 'پہلوان: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '🧑🏻‍🫯‍🧑🏾' => 'پہلوان: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏻‍🫯‍🧑🏿' => 'پہلوان: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '🧑🏼‍🫯‍🧑🏻' => 'پہلوان: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '🧑🏼‍🫯‍🧑🏽' => 'پہلوان: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '🧑🏼‍🫯‍🧑🏾' => 'پہلوان: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏼‍🫯‍🧑🏿' => 'پہلوان: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '🧑🏽‍🫯‍🧑🏻' => 'پہلوان: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '🧑🏽‍🫯‍🧑🏼' => 'پہلوان: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🫯‍🧑🏾' => 'پہلوان: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏽‍🫯‍🧑🏿' => 'پہلوان: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '🧑🏾‍🫯‍🧑🏻' => 'پہلوان: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '🧑🏾‍🫯‍🧑🏼' => 'پہلوان: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏾‍🫯‍🧑🏽' => 'پہلوان: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '🧑🏾‍🫯‍🧑🏿' => 'پہلوان: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '🧑🏿‍🫯‍🧑🏻' => 'پہلوان: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '🧑🏿‍🫯‍🧑🏼' => 'پہلوان: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏿‍🫯‍🧑🏽' => 'پہلوان: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '🧑🏿‍🫯‍🧑🏾' => 'پہلوان: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏻‍❤‍🧑🏼' => 'دل اور جوڑا: شخص، شخص، جلد کی ہلکی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏻‍❤‍🧑🏽' => 'دل اور جوڑا: شخص، شخص، جلد کی ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '🧑🏻‍❤‍🧑🏾' => 'دل اور جوڑا: شخص، شخص، جلد کی ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏻‍❤‍🧑🏿' => 'دل اور جوڑا: شخص، شخص، جلد کی ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '🧑🏼‍❤‍🧑🏻' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی -ہلکی رنگت، اور جلد کی ہلکی رنگت',
    '🧑🏼‍❤‍🧑🏽' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '🧑🏼‍❤‍🧑🏾' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏼‍❤‍🧑🏿' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی -ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '🧑🏽‍❤‍🧑🏻' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی رنگت، اور جلد کی ہلکی رنگت',
    '🧑🏽‍❤‍🧑🏼' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍❤‍🧑🏾' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏽‍❤‍🧑🏿' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی رنگت، اور جلد کی سیاہ رنگت',
    '🧑🏾‍❤‍🧑🏻' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '🧑🏾‍❤‍🧑🏼' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏾‍❤‍🧑🏽' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '🧑🏾‍❤‍🧑🏿' => 'دل اور جوڑا: شخص، شخص، جلد کی درمیانی سیاہ رنگت، اور جلد کی سیاہ رنگت',
    '🧑🏿‍❤‍🧑🏻' => 'دل اور جوڑا: شخص، شخص، جلد کی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '🧑🏿‍❤‍🧑🏼' => 'دل اور جوڑا: شخص، شخص، جلد کی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏿‍❤‍🧑🏽' => 'دل اور جوڑا: شخص، شخص، جلد کی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '🧑🏿‍❤‍🧑🏾' => 'دل اور جوڑا: شخص، شخص، جلد کی سیاہ رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏻‍🐰‍🧑🏼' => 'پارٹی کرتی عورتیں: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏻‍🐰‍🧑🏽' => 'پارٹی کرتی عورتیں: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '🧑🏻‍🐰‍🧑🏾' => 'پارٹی کرتی عورتیں: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏻‍🐰‍🧑🏿' => 'پارٹی کرتی عورتیں: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '🧑🏼‍🐰‍🧑🏻' => 'پارٹی کرتی عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '🧑🏼‍🐰‍🧑🏽' => 'پارٹی کرتی عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '🧑🏼‍🐰‍🧑🏾' => 'پارٹی کرتی عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏼‍🐰‍🧑🏿' => 'پارٹی کرتی عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '🧑🏽‍🐰‍🧑🏻' => 'پارٹی کرتی عورتیں: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '🧑🏽‍🐰‍🧑🏼' => 'پارٹی کرتی عورتیں: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🐰‍🧑🏾' => 'پارٹی کرتی عورتیں: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏽‍🐰‍🧑🏿' => 'پارٹی کرتی عورتیں: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '🧑🏾‍🐰‍🧑🏻' => 'پارٹی کرتی عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '🧑🏾‍🐰‍🧑🏼' => 'پارٹی کرتی عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏾‍🐰‍🧑🏽' => 'پارٹی کرتی عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '🧑🏾‍🐰‍🧑🏿' => 'پارٹی کرتی عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '🧑🏿‍🐰‍🧑🏻' => 'پارٹی کرتی عورتیں: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '🧑🏿‍🐰‍🧑🏼' => 'پارٹی کرتی عورتیں: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏿‍🐰‍🧑🏽' => 'پارٹی کرتی عورتیں: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '🧑🏿‍🐰‍🧑🏾' => 'پارٹی کرتی عورتیں: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏻‍🫯‍👨🏼' => 'مردوں کی کشتی: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏻‍🫯‍👨🏽' => 'مردوں کی کشتی: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👨🏻‍🫯‍👨🏾' => 'مردوں کی کشتی: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏻‍🫯‍👨🏿' => 'مردوں کی کشتی: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👨🏼‍🫯‍👨🏻' => 'مردوں کی کشتی: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '👨🏼‍🫯‍👨🏽' => 'مردوں کی کشتی: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👨🏼‍🫯‍👨🏾' => 'مردوں کی کشتی: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏼‍🫯‍👨🏿' => 'مردوں کی کشتی: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👨🏽‍🫯‍👨🏻' => 'مردوں کی کشتی: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '👨🏽‍🫯‍👨🏼' => 'مردوں کی کشتی: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🫯‍👨🏾' => 'مردوں کی کشتی: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏽‍🫯‍👨🏿' => 'مردوں کی کشتی: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '👨🏾‍🫯‍👨🏻' => 'مردوں کی کشتی: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👨🏾‍🫯‍👨🏼' => 'مردوں کی کشتی: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏾‍🫯‍👨🏽' => 'مردوں کی کشتی: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👨🏾‍🫯‍👨🏿' => 'مردوں کی کشتی: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '👨🏿‍🫯‍👨🏻' => 'مردوں کی کشتی: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👨🏿‍🫯‍👨🏼' => 'مردوں کی کشتی: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏿‍🫯‍👨🏽' => 'مردوں کی کشتی: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👨🏿‍🫯‍👨🏾' => 'مردوں کی کشتی: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏻‍❤‍👨🏻' => 'دل اور جوڑا: مرد، مرد، اور جلد کی ہلکی رنگت',
    '👨🏻‍❤‍👨🏼' => 'دل اور جوڑا: مرد، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏻‍❤‍👨🏽' => 'دل اور جوڑا: مرد، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👨🏻‍❤‍👨🏾' => 'دل اور جوڑا: مرد، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏻‍❤‍👨🏿' => 'دل اور جوڑا: مرد، مرد، جلد کی ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👨🏼‍❤‍👨🏻' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی ہلکی رنگت',
    '👨🏼‍❤‍👨🏼' => 'دل اور جوڑا: مرد، مرد، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏼‍❤‍👨🏽' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👨🏼‍❤‍👨🏾' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏼‍❤‍👨🏿' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👨🏽‍❤‍👨🏻' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی رنگت، اور جلد کی ہلکی رنگت',
    '👨🏽‍❤‍👨🏼' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍❤‍👨🏽' => 'دل اور جوڑا: مرد، مرد، اور جلد کی درمیانی رنگت',
    '👨🏽‍❤‍👨🏾' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏽‍❤‍👨🏿' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی رنگت، اور جلد کی سیاہ رنگت',
    '👨🏾‍❤‍👨🏻' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👨🏾‍❤‍👨🏼' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏾‍❤‍👨🏽' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👨🏾‍❤‍👨🏾' => 'دل اور جوڑا: مرد، مرد، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏾‍❤‍👨🏿' => 'دل اور جوڑا: مرد، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی سیاہ رنگت',
    '👨🏿‍❤‍👨🏻' => 'دل اور جوڑا: مرد، مرد، جلد کی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👨🏿‍❤‍👨🏼' => 'دل اور جوڑا: مرد، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏿‍❤‍👨🏽' => 'دل اور جوڑا: مرد، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👨🏿‍❤‍👨🏾' => 'دل اور جوڑا: مرد، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍❤‍👨🏿' => 'دل اور جوڑا: مرد، مرد، اور جلد کی سیاہ رنگت',
    '👨🏻‍🐰‍👨🏼' => 'ڈانس کرتے ہوئے مرد: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏻‍🐰‍👨🏽' => 'ڈانس کرتے ہوئے مرد: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👨🏻‍🐰‍👨🏾' => 'ڈانس کرتے ہوئے مرد: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏻‍🐰‍👨🏿' => 'ڈانس کرتے ہوئے مرد: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👨🏼‍🐰‍👨🏻' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '👨🏼‍🐰‍👨🏽' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👨🏼‍🐰‍👨🏾' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏼‍🐰‍👨🏿' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👨🏽‍🐰‍👨🏻' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '👨🏽‍🐰‍👨🏼' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🐰‍👨🏾' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏽‍🐰‍👨🏿' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '👨🏾‍🐰‍👨🏻' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👨🏾‍🐰‍👨🏼' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏾‍🐰‍👨🏽' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👨🏾‍🐰‍👨🏿' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '👨🏿‍🐰‍👨🏻' => 'ڈانس کرتے ہوئے مرد: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👨🏿‍🐰‍👨🏼' => 'ڈانس کرتے ہوئے مرد: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏿‍🐰‍👨🏽' => 'ڈانس کرتے ہوئے مرد: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👨🏿‍🐰‍👨🏾' => 'ڈانس کرتے ہوئے مرد: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍🫯‍👩🏼' => 'عورتوں کی کشتی: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏻‍🫯‍👩🏽' => 'عورتوں کی کشتی: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👩🏻‍🫯‍👩🏾' => 'عورتوں کی کشتی: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍🫯‍👩🏿' => 'عورتوں کی کشتی: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👩🏼‍🫯‍👩🏻' => 'عورتوں کی کشتی: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '👩🏼‍🫯‍👩🏽' => 'عورتوں کی کشتی: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👩🏼‍🫯‍👩🏾' => 'عورتوں کی کشتی: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏼‍🫯‍👩🏿' => 'عورتوں کی کشتی: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👩🏽‍🫯‍👩🏻' => 'عورتوں کی کشتی: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '👩🏽‍🫯‍👩🏼' => 'عورتوں کی کشتی: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🫯‍👩🏾' => 'عورتوں کی کشتی: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏽‍🫯‍👩🏿' => 'عورتوں کی کشتی: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '👩🏾‍🫯‍👩🏻' => 'عورتوں کی کشتی: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👩🏾‍🫯‍👩🏼' => 'عورتوں کی کشتی: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏾‍🫯‍👩🏽' => 'عورتوں کی کشتی: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👩🏾‍🫯‍👩🏿' => 'عورتوں کی کشتی: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '👩🏿‍🫯‍👩🏻' => 'عورتوں کی کشتی: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👩🏿‍🫯‍👩🏼' => 'عورتوں کی کشتی: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏿‍🫯‍👩🏽' => 'عورتوں کی کشتی: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👩🏿‍🫯‍👩🏾' => 'عورتوں کی کشتی: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍❤‍👨🏻' => 'دل اور جوڑا: عورت، مرد، اور جلد کی ہلکی رنگت',
    '👩🏻‍❤‍👨🏼' => 'دل اور جوڑا: عورت، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏻‍❤‍👨🏽' => 'دل اور جوڑا: عورت، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👩🏻‍❤‍👨🏾' => 'دل اور جوڑا: عورت، مرد، جلد کی ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍❤‍👨🏿' => 'دل اور جوڑا: عورت، مرد، جلد کی ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏼‍❤‍👨🏻' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی ہلکی رنگت',
    '👩🏼‍❤‍👨🏼' => 'دل اور جوڑا: عورت، مرد، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏼‍❤‍👨🏽' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👩🏼‍❤‍👨🏾' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏼‍❤‍👨🏿' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی -ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏽‍❤‍👨🏻' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی رنگت، اور جلد کی ہلکی رنگت',
    '👩🏽‍❤‍👨🏼' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍❤‍👨🏽' => 'دل اور جوڑا: عورت، مرد، اور جلد کی درمیانی رنگت',
    '👩🏽‍❤‍👨🏾' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏽‍❤‍👨🏿' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏾‍❤‍👨🏻' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👩🏾‍❤‍👨🏼' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏾‍❤‍👨🏽' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👩🏾‍❤‍👨🏾' => 'دل اور جوڑا: عورت، مرد، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏾‍❤‍👨🏿' => 'دل اور جوڑا: عورت، مرد، جلد کی درمیانی سیاہ رنگت، اور جلد کی سیاہ رنگت',
    '👩🏿‍❤‍👨🏻' => 'دل اور جوڑا: عورت، مرد، جلد کی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👩🏿‍❤‍👨🏼' => 'دل اور جوڑا: عورت، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏿‍❤‍👨🏽' => 'دل اور جوڑا: عورت، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👩🏿‍❤‍👨🏾' => 'دل اور جوڑا: عورت، مرد، جلد کی سیاہ رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍❤‍👨🏿' => 'دل اور جوڑا: عورت، مرد، اور جلد کی سیاہ رنگت',
    '👩🏻‍❤‍👩🏻' => 'دل اور جوڑا: عورت، عورت، اور جلد کی ہلکی رنگت',
    '👩🏻‍❤‍👩🏼' => 'دل اور جوڑا: عورت، عورت، جلد کی ہلکی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏻‍❤‍👩🏽' => 'دل اور جوڑا: عورت، عورت، جلد کی ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👩🏻‍❤‍👩🏾' => 'دل اور جوڑا: عورت، عورت، جلد کی ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍❤‍👩🏿' => 'دل اور جوڑا: عورت، عورت، جلد کی ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏼‍❤‍👩🏻' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی -ہلکی رنگت، اور جلد کی ہلکی رنگت',
    '👩🏼‍❤‍👩🏼' => 'دل اور جوڑا: عورت، عورت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏼‍❤‍👩🏽' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی رنگت',
    '👩🏼‍❤‍👩🏾' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی -ہلکی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏼‍❤‍👩🏿' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی -ہلکی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏽‍❤‍👩🏻' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی رنگت، اور جلد کی ہلکی رنگت',
    '👩🏽‍❤‍👩🏼' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍❤‍👩🏽' => 'دل اور جوڑا: عورت، عورت، اور جلد کی درمیانی رنگت',
    '👩🏽‍❤‍👩🏾' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏽‍❤‍👩🏿' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی رنگت، اور جلد کی سیاہ رنگت',
    '👩🏾‍❤‍👩🏻' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👩🏾‍❤‍👩🏼' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏾‍❤‍👩🏽' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👩🏾‍❤‍👩🏾' => 'دل اور جوڑا: عورت، عورت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏾‍❤‍👩🏿' => 'دل اور جوڑا: عورت، عورت، جلد کی درمیانی سیاہ رنگت، اور جلد کی سیاہ رنگت',
    '👩🏿‍❤‍👩🏻' => 'دل اور جوڑا: عورت، عورت، جلد کی سیاہ رنگت، اور جلد کی ہلکی رنگت',
    '👩🏿‍❤‍👩🏼' => 'دل اور جوڑا: عورت، عورت، جلد کی سیاہ رنگت، اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏿‍❤‍👩🏽' => 'دل اور جوڑا: عورت، عورت، جلد کی سیاہ رنگت، اور جلد کی درمیانی رنگت',
    '👩🏿‍❤‍👩🏾' => 'دل اور جوڑا: عورت، عورت، جلد کی سیاہ رنگت، اور جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍❤‍👩🏿' => 'دل اور جوڑا: عورت، عورت، اور جلد کی سیاہ رنگت',
    '👩🏻‍🐰‍👩🏼' => 'ڈانس کرتی ہوئی عورتیں: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏻‍🐰‍👩🏽' => 'ڈانس کرتی ہوئی عورتیں: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👩🏻‍🐰‍👩🏾' => 'ڈانس کرتی ہوئی عورتیں: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍🐰‍👩🏿' => 'ڈانس کرتی ہوئی عورتیں: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👩🏼‍🐰‍👩🏻' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '👩🏼‍🐰‍👩🏽' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👩🏼‍🐰‍👩🏾' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏼‍🐰‍👩🏿' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👩🏽‍🐰‍👩🏻' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '👩🏽‍🐰‍👩🏼' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🐰‍👩🏾' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏽‍🐰‍👩🏿' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '👩🏾‍🐰‍👩🏻' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👩🏾‍🐰‍👩🏼' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏾‍🐰‍👩🏽' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👩🏾‍🐰‍👩🏿' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '👩🏿‍🐰‍👩🏻' => 'ڈانس کرتی ہوئی عورتیں: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👩🏿‍🐰‍👩🏼' => 'ڈانس کرتی ہوئی عورتیں: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏿‍🐰‍👩🏽' => 'ڈانس کرتی ہوئی عورتیں: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👩🏿‍🐰‍👩🏾' => 'ڈانس کرتی ہوئی عورتیں: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏻‍🤝‍🧑🏻' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی ہلکی رنگت',
    '🧑🏻‍🤝‍🧑🏼' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏻‍🤝‍🧑🏽' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '🧑🏻‍🤝‍🧑🏾' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏻‍🤝‍🧑🏿' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '🧑🏼‍🤝‍🧑🏻' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '🧑🏼‍🤝‍🧑🏼' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏼‍🤝‍🧑🏽' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '🧑🏼‍🤝‍🧑🏾' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏼‍🤝‍🧑🏿' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '🧑🏽‍🤝‍🧑🏻' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '🧑🏽‍🤝‍🧑🏼' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🤝‍🧑🏽' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی رنگت',
    '🧑🏽‍🤝‍🧑🏾' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏽‍🤝‍🧑🏿' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '🧑🏾‍🤝‍🧑🏻' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '🧑🏾‍🤝‍🧑🏼' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏾‍🤝‍🧑🏽' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '🧑🏾‍🤝‍🧑🏾' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی سیاہ رنگت',
    '🧑🏾‍🤝‍🧑🏿' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '🧑🏿‍🤝‍🧑🏻' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '🧑🏿‍🤝‍🧑🏼' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🧑🏿‍🤝‍🧑🏽' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '🧑🏿‍🤝‍🧑🏾' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🤝‍🧑🏿' => 'ہاتھ پکڑے ہوئے لوگ: جلد کی سیاہ رنگت',
    '👩🏻‍🤝‍👩🏼' => 'ہاتھ تھامے دو عورتیں: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏻‍🤝‍👩🏽' => 'ہاتھ تھامے دو عورتیں: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👩🏻‍🤝‍👩🏾' => 'ہاتھ تھامے دو عورتیں: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍🤝‍👩🏿' => 'ہاتھ تھامے دو عورتیں: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👩🏼‍🤝‍👩🏻' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '👩🏼‍🤝‍👩🏽' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👩🏼‍🤝‍👩🏾' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏼‍🤝‍👩🏿' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👩🏽‍🤝‍👩🏻' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '👩🏽‍🤝‍👩🏼' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🤝‍👩🏾' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏽‍🤝‍👩🏿' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '👩🏾‍🤝‍👩🏻' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👩🏾‍🤝‍👩🏼' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏾‍🤝‍👩🏽' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👩🏾‍🤝‍👩🏿' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '👩🏿‍🤝‍👩🏻' => 'ہاتھ تھامے دو عورتیں: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👩🏿‍🤝‍👩🏼' => 'ہاتھ تھامے دو عورتیں: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏿‍🤝‍👩🏽' => 'ہاتھ تھامے دو عورتیں: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👩🏿‍🤝‍👩🏾' => 'ہاتھ تھامے دو عورتیں: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍🤝‍👨🏼' => 'ہاتھ تھامے مرد اور عورت: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏻‍🤝‍👨🏽' => 'ہاتھ تھامے مرد اور عورت: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👩🏻‍🤝‍👨🏾' => 'ہاتھ تھامے مرد اور عورت: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏻‍🤝‍👨🏿' => 'ہاتھ تھامے مرد اور عورت: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👩🏼‍🤝‍👨🏻' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '👩🏼‍🤝‍👨🏽' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👩🏼‍🤝‍👨🏾' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏼‍🤝‍👨🏿' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👩🏽‍🤝‍👨🏻' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '👩🏽‍🤝‍👨🏼' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🤝‍👨🏾' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩🏽‍🤝‍👨🏿' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '👩🏾‍🤝‍👨🏻' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👩🏾‍🤝‍👨🏼' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏾‍🤝‍👨🏽' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👩🏾‍🤝‍👨🏿' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '👩🏿‍🤝‍👨🏻' => 'ہاتھ تھامے مرد اور عورت: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👩🏿‍🤝‍👨🏼' => 'ہاتھ تھامے مرد اور عورت: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👩🏿‍🤝‍👨🏽' => 'ہاتھ تھامے مرد اور عورت: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👩🏿‍🤝‍👨🏾' => 'ہاتھ تھامے مرد اور عورت: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏻‍🤝‍👨🏼' => 'ہاتھ تھامے دو مرد: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏻‍🤝‍👨🏽' => 'ہاتھ تھامے دو مرد: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👨🏻‍🤝‍👨🏾' => 'ہاتھ تھامے دو مرد: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏻‍🤝‍👨🏿' => 'ہاتھ تھامے دو مرد: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👨🏼‍🤝‍👨🏻' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '👨🏼‍🤝‍👨🏽' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '👨🏼‍🤝‍👨🏾' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏼‍🤝‍👨🏿' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '👨🏽‍🤝‍👨🏻' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '👨🏽‍🤝‍👨🏼' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🤝‍👨🏾' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👨🏽‍🤝‍👨🏿' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '👨🏾‍🤝‍👨🏻' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👨🏾‍🤝‍👨🏼' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏾‍🤝‍👨🏽' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👨🏾‍🤝‍👨🏿' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '👨🏿‍🤝‍👨🏻' => 'ہاتھ تھامے دو مرد: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '👨🏿‍🤝‍👨🏼' => 'ہاتھ تھامے دو مرد: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '👨🏿‍🤝‍👨🏽' => 'ہاتھ تھامے دو مرد: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '👨🏿‍🤝‍👨🏾' => 'ہاتھ تھامے دو مرد: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '👩‍❤‍💋‍👨' => 'بوسہ: عورت اور مرد',
    '👨‍❤‍💋‍👨' => 'بوسہ: مرد اور مرد',
    '👩‍❤‍💋‍👩' => 'بوسہ: عورت اور عورت',
    '👨‍👩‍👧‍👦' => 'خاندان: مرد، عورت، لڑکی، اور لڑکا',
    '👨‍👩‍👦‍👦' => 'خاندان: مرد، عورت، لڑکا، اور لڑکا',
    '👨‍👩‍👧‍👧' => 'خاندان: مرد، عورت، لڑکی، اور لڑکی',
    '👨‍👨‍👧‍👦' => 'خاندان: مرد، مرد، لڑکی، اور لڑکا',
    '👨‍👨‍👦‍👦' => 'خاندان: مرد، مرد، لڑکا، اور لڑکا',
    '👨‍👨‍👧‍👧' => 'خاندان: مرد، مرد، لڑکی، اور لڑکی',
    '👩‍👩‍👧‍👦' => 'خاندان: عورت، عورت، لڑکی، اور لڑکا',
    '👩‍👩‍👦‍👦' => 'خاندان: عورت، عورت، لڑکا، اور لڑکا',
    '👩‍👩‍👧‍👧' => 'خاندان: عورت، عورت، لڑکی، اور لڑکی',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'پرچم: انگلینڈ',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'پرچم: اسکاٹ لینڈ',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'پرچم: ویلز',
    '🧑‍🧑‍🧒‍🧒' => 'خاندان: بالغ، بالغ، بچہ، بچہ',
    '🚶🏻‍♀‍➡' => 'پیدل چلتی ہوئی عورت: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏼‍♀‍➡' => 'پیدل چلتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏽‍♀‍➡' => 'پیدل چلتی ہوئی عورت: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏾‍♀‍➡' => 'پیدل چلتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏿‍♀‍➡' => 'پیدل چلتی ہوئی عورت: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏻‍♂‍➡' => 'پیدل چلتا ہوا مرد: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏼‍♂‍➡' => 'پیدل چلتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏽‍♂‍➡' => 'پیدل چلتا ہوا مرد: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏾‍♂‍➡' => 'پیدل چلتا ہوا مرد: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏿‍♂‍➡' => 'پیدل چلتا ہوا مرد: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏻‍♀‍➡' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏼‍♀‍➡' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏽‍♀‍➡' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏾‍♀‍➡' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏿‍♀‍➡' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏻‍♂‍➡' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏼‍♂‍➡' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏽‍♂‍➡' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏾‍♂‍➡' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏿‍♂‍➡' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏻‍🦯‍➡' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏼‍🦯‍➡' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏽‍🦯‍➡' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏾‍🦯‍➡' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏿‍🦯‍➡' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👨🏻‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👨🏼‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👨🏽‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '👨🏾‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👨🏿‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👩🏻‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👩🏼‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👩🏽‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '👩🏾‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👩🏿‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏻‍🦼‍➡' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏼‍🦼‍➡' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏽‍🦼‍➡' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏾‍🦼‍➡' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏿‍🦼‍➡' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👨🏻‍🦼‍➡' => 'برقی وہیل چئیر میں مرد: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👨🏼‍🦼‍➡' => 'برقی وہیل چئیر میں مرد: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👨🏽‍🦼‍➡' => 'برقی وہیل چئیر میں مرد: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '👨🏾‍🦼‍➡' => 'برقی وہیل چئیر میں مرد: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👨🏿‍🦼‍➡' => 'برقی وہیل چئیر میں مرد: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👩🏻‍🦼‍➡' => 'برقی وہیل چئیر میں عورت: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👩🏼‍🦼‍➡' => 'برقی وہیل چئیر میں عورت: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👩🏽‍🦼‍➡' => 'برقی وہیل چئیر میں عورت: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '👩🏾‍🦼‍➡' => 'برقی وہیل چئیر میں عورت: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👩🏿‍🦼‍➡' => 'برقی وہیل چئیر میں عورت: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏻‍🦽‍➡' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏼‍🦽‍➡' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏽‍🦽‍➡' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏾‍🦽‍➡' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏿‍🦽‍➡' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👨🏻‍🦽‍➡' => 'دستی وہیل چئیر میں مرد: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👨🏼‍🦽‍➡' => 'دستی وہیل چئیر میں مرد: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👨🏽‍🦽‍➡' => 'دستی وہیل چئیر میں مرد: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '👨🏾‍🦽‍➡' => 'دستی وہیل چئیر میں مرد: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👨🏿‍🦽‍➡' => 'دستی وہیل چئیر میں مرد: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👩🏻‍🦽‍➡' => 'دستی وہیل چئیر میں عورت: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👩🏼‍🦽‍➡' => 'دستی وہیل چئیر میں عورت: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '👩🏽‍🦽‍➡' => 'دستی وہیل چئیر میں عورت: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '👩🏾‍🦽‍➡' => 'دستی وہیل چئیر میں عورت: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👩🏿‍🦽‍➡' => 'دستی وہیل چئیر میں عورت: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏻‍♀‍➡' => 'دوڑتی ہوئی عورت: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏼‍♀‍➡' => 'دوڑتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏽‍♀‍➡' => 'دوڑتی ہوئی عورت: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏾‍♀‍➡' => 'دوڑتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏿‍♀‍➡' => 'دوڑتی ہوئی عورت: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏻‍♂‍➡' => 'دوڑتا ہوا مرد: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏼‍♂‍➡' => 'دوڑتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏽‍♂‍➡' => 'دوڑتا ہوا مرد: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏾‍♂‍➡' => 'دوڑتا ہوا مرد: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏿‍♂‍➡' => 'دوڑتا ہوا مرد: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🫱🏻‍🫲🏼' => 'ہاتھ ملانا: جلد کی ہلکی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🫱🏻‍🫲🏽' => 'ہاتھ ملانا: جلد کی ہلکی رنگت اور جلد کی درمیانی رنگت',
    '🫱🏻‍🫲🏾' => 'ہاتھ ملانا: جلد کی ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🫱🏻‍🫲🏿' => 'ہاتھ ملانا: جلد کی ہلکی رنگت اور جلد کی سیاہ رنگت',
    '🫱🏼‍🫲🏻' => 'ہاتھ ملانا: جلد کی درمیانی -ہلکی رنگت اور جلد کی ہلکی رنگت',
    '🫱🏼‍🫲🏽' => 'ہاتھ ملانا: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی رنگت',
    '🫱🏼‍🫲🏾' => 'ہاتھ ملانا: جلد کی درمیانی -ہلکی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🫱🏼‍🫲🏿' => 'ہاتھ ملانا: جلد کی درمیانی -ہلکی رنگت اور جلد کی سیاہ رنگت',
    '🫱🏽‍🫲🏻' => 'ہاتھ ملانا: جلد کی درمیانی رنگت اور جلد کی ہلکی رنگت',
    '🫱🏽‍🫲🏼' => 'ہاتھ ملانا: جلد کی درمیانی رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🫱🏽‍🫲🏾' => 'ہاتھ ملانا: جلد کی درمیانی رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🫱🏽‍🫲🏿' => 'ہاتھ ملانا: جلد کی درمیانی رنگت اور جلد کی سیاہ رنگت',
    '🫱🏾‍🫲🏻' => 'ہاتھ ملانا: جلد کی درمیانی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '🫱🏾‍🫲🏼' => 'ہاتھ ملانا: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🫱🏾‍🫲🏽' => 'ہاتھ ملانا: جلد کی درمیانی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '🫱🏾‍🫲🏿' => 'ہاتھ ملانا: جلد کی درمیانی سیاہ رنگت اور جلد کی سیاہ رنگت',
    '🫱🏿‍🫲🏻' => 'ہاتھ ملانا: جلد کی سیاہ رنگت اور جلد کی ہلکی رنگت',
    '🫱🏿‍🫲🏼' => 'ہاتھ ملانا: جلد کی سیاہ رنگت اور جلد کی درمیانی -ہلکی رنگت',
    '🫱🏿‍🫲🏽' => 'ہاتھ ملانا: جلد کی سیاہ رنگت اور جلد کی درمیانی رنگت',
    '🫱🏿‍🫲🏾' => 'ہاتھ ملانا: جلد کی سیاہ رنگت اور جلد کی درمیانی سیاہ رنگت',
    '🚶‍♀‍➡' => 'پیدل چلتی ہوئی عورت: دائیں طرف دیکھنے والا',
    '🚶‍♂‍➡' => 'پیدل چلتا ہوا مرد: دائیں طرف دیکھنے والا',
    '🧎‍♀‍➡' => 'گھٹنوں کے بل بیٹھی عورت: دائیں طرف دیکھنے والا',
    '🧎‍♂‍➡' => 'گھٹنوں کے بل بیٹھا مرد: دائیں طرف دیکھنے والا',
    '🧑‍🦯‍➡' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: دائیں طرف دیکھنے والا',
    '👨‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ مرد: دائیں طرف دیکھنے والا',
    '👩‍🦯‍➡' => 'نابینا افراد والی چھڑی کے ساتھ عورت: دائیں طرف دیکھنے والا',
    '🧑‍🦼‍➡' => 'برقی وہیل چئیر میں بیٹھا فرد: دائیں طرف دیکھنے والا',
    '👨‍🦼‍➡' => 'برقی وہیل چئیر میں مرد: دائیں طرف دیکھنے والا',
    '👩‍🦼‍➡' => 'برقی وہیل چئیر میں عورت: دائیں طرف دیکھنے والا',
    '🧑‍🦽‍➡' => 'دستی وہیل چیئر میں بیٹھا فرد: دائیں طرف دیکھنے والا',
    '👨‍🦽‍➡' => 'دستی وہیل چئیر میں مرد: دائیں طرف دیکھنے والا',
    '👩‍🦽‍➡' => 'دستی وہیل چئیر میں عورت: دائیں طرف دیکھنے والا',
    '🏃‍♀‍➡' => 'دوڑتی ہوئی عورت: دائیں طرف دیکھنے والا',
    '🏃‍♂‍➡' => 'دوڑتا ہوا مرد: دائیں طرف دیکھنے والا',
    '👩‍❤‍👨' => 'دل اور جوڑا: عورت اور مرد',
    '👨‍❤‍👨' => 'دل اور جوڑا: مرد اور مرد',
    '👩‍❤‍👩' => 'دل اور جوڑا: عورت اور عورت',
    '👨‍👩‍👦' => 'خاندان: مرد، عورت، اور لڑکا',
    '👨‍👩‍👧' => 'خاندان: مرد، عورت، اور لڑکی',
    '👨‍👨‍👦' => 'خاندان: مرد، مرد، اور لڑکا',
    '👨‍👨‍👧' => 'خاندان: مرد، مرد، اور لڑکی',
    '👩‍👩‍👦' => 'خاندان: عورت، عورت، اور لڑکا',
    '👩‍👩‍👧' => 'خاندان: عورت، عورت، اور لڑکی',
    '👨‍👦‍👦' => 'خاندان: مرد، لڑکا، اور لڑکا',
    '👨‍👧‍👦' => 'خاندان: مرد، لڑکی، اور لڑکا',
    '👨‍👧‍👧' => 'خاندان: مرد، لڑکی، اور لڑکی',
    '👩‍👦‍👦' => 'خاندان: عورت، لڑکا، اور لڑکا',
    '👩‍👧‍👦' => 'خاندان: عورت، لڑکی، اور لڑکا',
    '👩‍👧‍👧' => 'خاندان: عورت، لڑکی، اور لڑکی',
    '🧑‍🤝‍🧑' => 'ہاتھ پکڑے ہوئے لوگ',
    '🧑‍🧑‍🧒' => 'خاندان: بالغ، بالغ، بچہ',
    '🧑‍🧒‍🧒' => 'خاندان: بالغ، بچہ، بچہ',
    '🧑🏻‍🦰' => 'شخص: جلد کی ہلکی رنگت اور سرخ بال',
    '🧑🏼‍🦰' => 'شخص: جلد کی درمیانی -ہلکی رنگت اور سرخ بال',
    '🧑🏽‍🦰' => 'شخص: جلد کی درمیانی رنگت اور سرخ بال',
    '🧑🏾‍🦰' => 'شخص: جلد کی درمیانی سیاہ رنگت اور سرخ بال',
    '🧑🏿‍🦰' => 'شخص: جلد کی سیاہ رنگت اور سرخ بال',
    '🧑🏻‍🦱' => 'شخص: جلد کی ہلکی رنگت اور گھنگھریالے بال',
    '🧑🏼‍🦱' => 'شخص: جلد کی درمیانی -ہلکی رنگت اور گھنگھریالے بال',
    '🧑🏽‍🦱' => 'شخص: جلد کی درمیانی رنگت اور گھنگھریالے بال',
    '🧑🏾‍🦱' => 'شخص: جلد کی درمیانی سیاہ رنگت اور گھنگھریالے بال',
    '🧑🏿‍🦱' => 'شخص: جلد کی سیاہ رنگت اور گھنگھریالے بال',
    '🧑🏻‍🦳' => 'شخص: جلد کی ہلکی رنگت اور سفید بال',
    '🧑🏼‍🦳' => 'شخص: جلد کی درمیانی -ہلکی رنگت اور سفید بال',
    '🧑🏽‍🦳' => 'شخص: جلد کی درمیانی رنگت اور سفید بال',
    '🧑🏾‍🦳' => 'شخص: جلد کی درمیانی سیاہ رنگت اور سفید بال',
    '🧑🏿‍🦳' => 'شخص: جلد کی سیاہ رنگت اور سفید بال',
    '🧑🏻‍🦲' => 'شخص: جلد کی ہلکی رنگت اور گنجا',
    '🧑🏼‍🦲' => 'شخص: جلد کی درمیانی -ہلکی رنگت اور گنجا',
    '🧑🏽‍🦲' => 'شخص: جلد کی درمیانی رنگت اور گنجا',
    '🧑🏾‍🦲' => 'شخص: جلد کی درمیانی سیاہ رنگت اور گنجا',
    '🧑🏿‍🦲' => 'شخص: جلد کی سیاہ رنگت اور گنجا',
    '🧑🏻‍🩰' => 'بیلے ڈانسر: جلد کی ہلکی رنگت',
    '🧑🏼‍🩰' => 'بیلے ڈانسر: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🩰' => 'بیلے ڈانسر: جلد کی درمیانی رنگت',
    '🧑🏾‍🩰' => 'بیلے ڈانسر: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🩰' => 'بیلے ڈانسر: جلد کی سیاہ رنگت',
    '🧔🏻‍♂' => 'مرد: جلد کی ہلکی رنگت اور داڑھی',
    '🧔🏼‍♂' => 'مرد: جلد کی درمیانی -ہلکی رنگت اور داڑھی',
    '🧔🏽‍♂' => 'مرد: جلد کی درمیانی رنگت اور داڑھی',
    '🧔🏾‍♂' => 'مرد: جلد کی درمیانی سیاہ رنگت اور داڑھی',
    '🧔🏿‍♂' => 'مرد: جلد کی سیاہ رنگت اور داڑھی',
    '👱🏻‍♂' => 'سنہرے بالوں والا مرد: جلد کی ہلکی رنگت',
    '👱🏼‍♂' => 'سنہرے بالوں والا مرد: جلد کی درمیانی -ہلکی رنگت',
    '👱🏽‍♂' => 'سنہرے بالوں والا مرد: جلد کی درمیانی رنگت',
    '👱🏾‍♂' => 'سنہرے بالوں والا مرد: جلد کی درمیانی سیاہ رنگت',
    '👱🏿‍♂' => 'سنہرے بالوں والا مرد: جلد کی سیاہ رنگت',
    '👨🏻‍🦰' => 'مرد: جلد کی ہلکی رنگت اور سرخ بال',
    '👨🏼‍🦰' => 'مرد: جلد کی درمیانی -ہلکی رنگت اور سرخ بال',
    '👨🏽‍🦰' => 'مرد: جلد کی درمیانی رنگت اور سرخ بال',
    '👨🏾‍🦰' => 'مرد: جلد کی درمیانی سیاہ رنگت اور سرخ بال',
    '👨🏿‍🦰' => 'مرد: جلد کی سیاہ رنگت اور سرخ بال',
    '👨🏻‍🦱' => 'مرد: جلد کی ہلکی رنگت اور گھنگھریالے بال',
    '👨🏼‍🦱' => 'مرد: جلد کی درمیانی -ہلکی رنگت اور گھنگھریالے بال',
    '👨🏽‍🦱' => 'مرد: جلد کی درمیانی رنگت اور گھنگھریالے بال',
    '👨🏾‍🦱' => 'مرد: جلد کی درمیانی سیاہ رنگت اور گھنگھریالے بال',
    '👨🏿‍🦱' => 'مرد: جلد کی سیاہ رنگت اور گھنگھریالے بال',
    '👨🏻‍🦳' => 'مرد: جلد کی ہلکی رنگت اور سفید بال',
    '👨🏼‍🦳' => 'مرد: جلد کی درمیانی -ہلکی رنگت اور سفید بال',
    '👨🏽‍🦳' => 'مرد: جلد کی درمیانی رنگت اور سفید بال',
    '👨🏾‍🦳' => 'مرد: جلد کی درمیانی سیاہ رنگت اور سفید بال',
    '👨🏿‍🦳' => 'مرد: جلد کی سیاہ رنگت اور سفید بال',
    '👨🏻‍🦲' => 'مرد: جلد کی ہلکی رنگت اور گنجا',
    '👨🏼‍🦲' => 'مرد: جلد کی درمیانی -ہلکی رنگت اور گنجا',
    '👨🏽‍🦲' => 'مرد: جلد کی درمیانی رنگت اور گنجا',
    '👨🏾‍🦲' => 'مرد: جلد کی درمیانی سیاہ رنگت اور گنجا',
    '👨🏿‍🦲' => 'مرد: جلد کی سیاہ رنگت اور گنجا',
    '🧔🏻‍♀' => 'عورت: جلد کی ہلکی رنگت اور داڑھی',
    '🧔🏼‍♀' => 'عورت: جلد کی درمیانی -ہلکی رنگت اور داڑھی',
    '🧔🏽‍♀' => 'عورت: جلد کی درمیانی رنگت اور داڑھی',
    '🧔🏾‍♀' => 'عورت: جلد کی درمیانی سیاہ رنگت اور داڑھی',
    '🧔🏿‍♀' => 'عورت: جلد کی سیاہ رنگت اور داڑھی',
    '👱🏻‍♀' => 'سنہرے بالوں والی عورت: جلد کی ہلکی رنگت',
    '👱🏼‍♀' => 'سنہرے بالوں والی عورت: جلد کی درمیانی -ہلکی رنگت',
    '👱🏽‍♀' => 'سنہرے بالوں والی عورت: جلد کی درمیانی رنگت',
    '👱🏾‍♀' => 'سنہرے بالوں والی عورت: جلد کی درمیانی سیاہ رنگت',
    '👱🏿‍♀' => 'سنہرے بالوں والی عورت: جلد کی سیاہ رنگت',
    '👩🏻‍🦰' => 'عورت: جلد کی ہلکی رنگت اور سرخ بال',
    '👩🏼‍🦰' => 'عورت: جلد کی درمیانی -ہلکی رنگت اور سرخ بال',
    '👩🏽‍🦰' => 'عورت: جلد کی درمیانی رنگت اور سرخ بال',
    '👩🏾‍🦰' => 'عورت: جلد کی درمیانی سیاہ رنگت اور سرخ بال',
    '👩🏿‍🦰' => 'عورت: جلد کی سیاہ رنگت اور سرخ بال',
    '👩🏻‍🦱' => 'عورت: جلد کی ہلکی رنگت اور گھنگھریالے بال',
    '👩🏼‍🦱' => 'عورت: جلد کی درمیانی -ہلکی رنگت اور گھنگھریالے بال',
    '👩🏽‍🦱' => 'عورت: جلد کی درمیانی رنگت اور گھنگھریالے بال',
    '👩🏾‍🦱' => 'عورت: جلد کی درمیانی سیاہ رنگت اور گھنگھریالے بال',
    '👩🏿‍🦱' => 'عورت: جلد کی سیاہ رنگت اور گھنگھریالے بال',
    '👩🏻‍🦳' => 'عورت: جلد کی ہلکی رنگت اور سفید بال',
    '👩🏼‍🦳' => 'عورت: جلد کی درمیانی -ہلکی رنگت اور سفید بال',
    '👩🏽‍🦳' => 'عورت: جلد کی درمیانی رنگت اور سفید بال',
    '👩🏾‍🦳' => 'عورت: جلد کی درمیانی سیاہ رنگت اور سفید بال',
    '👩🏿‍🦳' => 'عورت: جلد کی سیاہ رنگت اور سفید بال',
    '👩🏻‍🦲' => 'عورت: جلد کی ہلکی رنگت اور گنجا',
    '👩🏼‍🦲' => 'عورت: جلد کی درمیانی -ہلکی رنگت اور گنجا',
    '👩🏽‍🦲' => 'عورت: جلد کی درمیانی رنگت اور گنجا',
    '👩🏾‍🦲' => 'عورت: جلد کی درمیانی سیاہ رنگت اور گنجا',
    '👩🏿‍🦲' => 'عورت: جلد کی سیاہ رنگت اور گنجا',
    '🙍🏻‍♂' => 'گھورتا ہوا مرد: جلد کی ہلکی رنگت',
    '🙍🏼‍♂' => 'گھورتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🙍🏽‍♂' => 'گھورتا ہوا مرد: جلد کی درمیانی رنگت',
    '🙍🏾‍♂' => 'گھورتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🙍🏿‍♂' => 'گھورتا ہوا مرد: جلد کی سیاہ رنگت',
    '🙍🏻‍♀' => 'گھورتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🙍🏼‍♀' => 'گھورتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🙍🏽‍♀' => 'گھورتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🙍🏾‍♀' => 'گھورتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🙍🏿‍♀' => 'گھورتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🙎🏻‍♂' => 'منہ بسورتا ہوا مرد: جلد کی ہلکی رنگت',
    '🙎🏼‍♂' => 'منہ بسورتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🙎🏽‍♂' => 'منہ بسورتا ہوا مرد: جلد کی درمیانی رنگت',
    '🙎🏾‍♂' => 'منہ بسورتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🙎🏿‍♂' => 'منہ بسورتا ہوا مرد: جلد کی سیاہ رنگت',
    '🙎🏻‍♀' => 'منہ بسورتی ہوا عورت: جلد کی ہلکی رنگت',
    '🙎🏼‍♀' => 'منہ بسورتی ہوا عورت: جلد کی درمیانی -ہلکی رنگت',
    '🙎🏽‍♀' => 'منہ بسورتی ہوا عورت: جلد کی درمیانی رنگت',
    '🙎🏾‍♀' => 'منہ بسورتی ہوا عورت: جلد کی درمیانی سیاہ رنگت',
    '🙎🏿‍♀' => 'منہ بسورتی ہوا عورت: جلد کی سیاہ رنگت',
    '🙅🏻‍♂' => 'ٹھیک نہیں ہونے کا اشارہ کرتا ہوا مرد: جلد کی ہلکی رنگت',
    '🙅🏼‍♂' => 'ٹھیک نہیں ہونے کا اشارہ کرتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🙅🏽‍♂' => 'ٹھیک نہیں ہونے کا اشارہ کرتا ہوا مرد: جلد کی درمیانی رنگت',
    '🙅🏾‍♂' => 'ٹھیک نہیں ہونے کا اشارہ کرتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🙅🏿‍♂' => 'ٹھیک نہیں ہونے کا اشارہ کرتا ہوا مرد: جلد کی سیاہ رنگت',
    '🙅🏻‍♀' => 'ٹھیک نہیں ہونے کا اشارہ کرتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🙅🏼‍♀' => 'ٹھیک نہیں ہونے کا اشارہ کرتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🙅🏽‍♀' => 'ٹھیک نہیں ہونے کا اشارہ کرتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🙅🏾‍♀' => 'ٹھیک نہیں ہونے کا اشارہ کرتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🙅🏿‍♀' => 'ٹھیک نہیں ہونے کا اشارہ کرتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🙆🏻‍♂' => 'ٹھیک ہے کا اشارہ کرتا ہوا مرد: جلد کی ہلکی رنگت',
    '🙆🏼‍♂' => 'ٹھیک ہے کا اشارہ کرتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🙆🏽‍♂' => 'ٹھیک ہے کا اشارہ کرتا ہوا مرد: جلد کی درمیانی رنگت',
    '🙆🏾‍♂' => 'ٹھیک ہے کا اشارہ کرتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🙆🏿‍♂' => 'ٹھیک ہے کا اشارہ کرتا ہوا مرد: جلد کی سیاہ رنگت',
    '🙆🏻‍♀' => 'ٹھیک ہے کا اشارہ کرتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🙆🏼‍♀' => 'ٹھیک ہے کا اشارہ کرتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🙆🏽‍♀' => 'ٹھیک ہے کا اشارہ کرتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🙆🏾‍♀' => 'ٹھیک ہے کا اشارہ کرتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🙆🏿‍♀' => 'ٹھیک ہے کا اشارہ کرتی ہوئی عورت: جلد کی سیاہ رنگت',
    '💁🏻‍♂' => 'تجویز دیتا ہوا مرد: جلد کی ہلکی رنگت',
    '💁🏼‍♂' => 'تجویز دیتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '💁🏽‍♂' => 'تجویز دیتا ہوا مرد: جلد کی درمیانی رنگت',
    '💁🏾‍♂' => 'تجویز دیتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '💁🏿‍♂' => 'تجویز دیتا ہوا مرد: جلد کی سیاہ رنگت',
    '💁🏻‍♀' => 'تجویز دیتی ہوئی عورت: جلد کی ہلکی رنگت',
    '💁🏼‍♀' => 'تجویز دیتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '💁🏽‍♀' => 'تجویز دیتی ہوئی عورت: جلد کی درمیانی رنگت',
    '💁🏾‍♀' => 'تجویز دیتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '💁🏿‍♀' => 'تجویز دیتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🙋🏻‍♂' => 'ہاتھ اٹھاتا ہوا مرد: جلد کی ہلکی رنگت',
    '🙋🏼‍♂' => 'ہاتھ اٹھاتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🙋🏽‍♂' => 'ہاتھ اٹھاتا ہوا مرد: جلد کی درمیانی رنگت',
    '🙋🏾‍♂' => 'ہاتھ اٹھاتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🙋🏿‍♂' => 'ہاتھ اٹھاتا ہوا مرد: جلد کی سیاہ رنگت',
    '🙋🏻‍♀' => 'ہاتھ اٹھاتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🙋🏼‍♀' => 'ہاتھ اٹھاتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🙋🏽‍♀' => 'ہاتھ اٹھاتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🙋🏾‍♀' => 'ہاتھ اٹھاتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🙋🏿‍♀' => 'ہاتھ اٹھاتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🧏🏻‍♂' => 'سماعت سے محروم مرد: جلد کی ہلکی رنگت',
    '🧏🏼‍♂' => 'سماعت سے محروم مرد: جلد کی درمیانی -ہلکی رنگت',
    '🧏🏽‍♂' => 'سماعت سے محروم مرد: جلد کی درمیانی رنگت',
    '🧏🏾‍♂' => 'سماعت سے محروم مرد: جلد کی درمیانی سیاہ رنگت',
    '🧏🏿‍♂' => 'سماعت سے محروم مرد: جلد کی سیاہ رنگت',
    '🧏🏻‍♀' => 'بہری عورت: جلد کی ہلکی رنگت',
    '🧏🏼‍♀' => 'بہری عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧏🏽‍♀' => 'بہری عورت: جلد کی درمیانی رنگت',
    '🧏🏾‍♀' => 'بہری عورت: جلد کی درمیانی سیاہ رنگت',
    '🧏🏿‍♀' => 'بہری عورت: جلد کی سیاہ رنگت',
    '🙇🏻‍♂' => 'بہت زیادہ جھکا ہوا مرد: جلد کی ہلکی رنگت',
    '🙇🏼‍♂' => 'بہت زیادہ جھکا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🙇🏽‍♂' => 'بہت زیادہ جھکا ہوا مرد: جلد کی درمیانی رنگت',
    '🙇🏾‍♂' => 'بہت زیادہ جھکا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🙇🏿‍♂' => 'بہت زیادہ جھکا ہوا مرد: جلد کی سیاہ رنگت',
    '🙇🏻‍♀' => 'بہت زیادہ جھکی ہوئی عورت: جلد کی ہلکی رنگت',
    '🙇🏼‍♀' => 'بہت زیادہ جھکی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🙇🏽‍♀' => 'بہت زیادہ جھکی ہوئی عورت: جلد کی درمیانی رنگت',
    '🙇🏾‍♀' => 'بہت زیادہ جھکی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🙇🏿‍♀' => 'بہت زیادہ جھکی ہوئی عورت: جلد کی سیاہ رنگت',
    '🤦🏻‍♂' => 'شرمندگی ظاہر کرتا ہوا مرد: جلد کی ہلکی رنگت',
    '🤦🏼‍♂' => 'شرمندگی ظاہر کرتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🤦🏽‍♂' => 'شرمندگی ظاہر کرتا ہوا مرد: جلد کی درمیانی رنگت',
    '🤦🏾‍♂' => 'شرمندگی ظاہر کرتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🤦🏿‍♂' => 'شرمندگی ظاہر کرتا ہوا مرد: جلد کی سیاہ رنگت',
    '🤦🏻‍♀' => 'شرمندگی ظاہر کرتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🤦🏼‍♀' => 'شرمندگی ظاہر کرتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🤦🏽‍♀' => 'شرمندگی ظاہر کرتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🤦🏾‍♀' => 'شرمندگی ظاہر کرتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🤦🏿‍♀' => 'شرمندگی ظاہر کرتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🤷🏻‍♂' => 'کندھے اچکاتا ہوا مرد: جلد کی ہلکی رنگت',
    '🤷🏼‍♂' => 'کندھے اچکاتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🤷🏽‍♂' => 'کندھے اچکاتا ہوا مرد: جلد کی درمیانی رنگت',
    '🤷🏾‍♂' => 'کندھے اچکاتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🤷🏿‍♂' => 'کندھے اچکاتا ہوا مرد: جلد کی سیاہ رنگت',
    '🤷🏻‍♀' => 'کندھے اچکاتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🤷🏼‍♀' => 'کندھے اچکاتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🤷🏽‍♀' => 'کندھے اچکاتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🤷🏾‍♀' => 'کندھے اچکاتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🤷🏿‍♀' => 'کندھے اچکاتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🧑🏻‍⚕' => 'ہیلتھ ورکر: جلد کی ہلکی رنگت',
    '🧑🏼‍⚕' => 'ہیلتھ ورکر: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍⚕' => 'ہیلتھ ورکر: جلد کی درمیانی رنگت',
    '🧑🏾‍⚕' => 'ہیلتھ ورکر: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍⚕' => 'ہیلتھ ورکر: جلد کی سیاہ رنگت',
    '👨🏻‍⚕' => 'مرد ہیلتھ ورکر: جلد کی ہلکی رنگت',
    '👨🏼‍⚕' => 'مرد ہیلتھ ورکر: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍⚕' => 'مرد ہیلتھ ورکر: جلد کی درمیانی رنگت',
    '👨🏾‍⚕' => 'مرد ہیلتھ ورکر: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍⚕' => 'مرد ہیلتھ ورکر: جلد کی سیاہ رنگت',
    '👩🏻‍⚕' => 'عورت ہیلتھ ورکر: جلد کی ہلکی رنگت',
    '👩🏼‍⚕' => 'عورت ہیلتھ ورکر: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍⚕' => 'عورت ہیلتھ ورکر: جلد کی درمیانی رنگت',
    '👩🏾‍⚕' => 'عورت ہیلتھ ورکر: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍⚕' => 'عورت ہیلتھ ورکر: جلد کی سیاہ رنگت',
    '🧑🏻‍🎓' => 'طالب علم: جلد کی ہلکی رنگت',
    '🧑🏼‍🎓' => 'طالب علم: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🎓' => 'طالب علم: جلد کی درمیانی رنگت',
    '🧑🏾‍🎓' => 'طالب علم: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🎓' => 'طالب علم: جلد کی سیاہ رنگت',
    '👨🏻‍🎓' => 'مرد طالب علم: جلد کی ہلکی رنگت',
    '👨🏼‍🎓' => 'مرد طالب علم: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🎓' => 'مرد طالب علم: جلد کی درمیانی رنگت',
    '👨🏾‍🎓' => 'مرد طالب علم: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🎓' => 'مرد طالب علم: جلد کی سیاہ رنگت',
    '👩🏻‍🎓' => 'عورت طالب علم: جلد کی ہلکی رنگت',
    '👩🏼‍🎓' => 'عورت طالب علم: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🎓' => 'عورت طالب علم: جلد کی درمیانی رنگت',
    '👩🏾‍🎓' => 'عورت طالب علم: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🎓' => 'عورت طالب علم: جلد کی سیاہ رنگت',
    '🧑🏻‍🏫' => 'استاد: جلد کی ہلکی رنگت',
    '🧑🏼‍🏫' => 'استاد: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🏫' => 'استاد: جلد کی درمیانی رنگت',
    '🧑🏾‍🏫' => 'استاد: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🏫' => 'استاد: جلد کی سیاہ رنگت',
    '👨🏻‍🏫' => 'مرد استاد: جلد کی ہلکی رنگت',
    '👨🏼‍🏫' => 'مرد استاد: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🏫' => 'مرد استاد: جلد کی درمیانی رنگت',
    '👨🏾‍🏫' => 'مرد استاد: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🏫' => 'مرد استاد: جلد کی سیاہ رنگت',
    '👩🏻‍🏫' => 'استانی: جلد کی ہلکی رنگت',
    '👩🏼‍🏫' => 'استانی: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🏫' => 'استانی: جلد کی درمیانی رنگت',
    '👩🏾‍🏫' => 'استانی: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🏫' => 'استانی: جلد کی سیاہ رنگت',
    '🧑🏻‍⚖' => 'جج: جلد کی ہلکی رنگت',
    '🧑🏼‍⚖' => 'جج: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍⚖' => 'جج: جلد کی درمیانی رنگت',
    '🧑🏾‍⚖' => 'جج: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍⚖' => 'جج: جلد کی سیاہ رنگت',
    '👨🏻‍⚖' => 'مرد جج: جلد کی ہلکی رنگت',
    '👨🏼‍⚖' => 'مرد جج: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍⚖' => 'مرد جج: جلد کی درمیانی رنگت',
    '👨🏾‍⚖' => 'مرد جج: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍⚖' => 'مرد جج: جلد کی سیاہ رنگت',
    '👩🏻‍⚖' => 'عورت جج: جلد کی ہلکی رنگت',
    '👩🏼‍⚖' => 'عورت جج: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍⚖' => 'عورت جج: جلد کی درمیانی رنگت',
    '👩🏾‍⚖' => 'عورت جج: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍⚖' => 'عورت جج: جلد کی سیاہ رنگت',
    '🧑🏻‍🌾' => 'کسان: جلد کی ہلکی رنگت',
    '🧑🏼‍🌾' => 'کسان: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🌾' => 'کسان: جلد کی درمیانی رنگت',
    '🧑🏾‍🌾' => 'کسان: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🌾' => 'کسان: جلد کی سیاہ رنگت',
    '👨🏻‍🌾' => 'مرد کاشت کار: جلد کی ہلکی رنگت',
    '👨🏼‍🌾' => 'مرد کاشت کار: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🌾' => 'مرد کاشت کار: جلد کی درمیانی رنگت',
    '👨🏾‍🌾' => 'مرد کاشت کار: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🌾' => 'مرد کاشت کار: جلد کی سیاہ رنگت',
    '👩🏻‍🌾' => 'عورت کاشت کار: جلد کی ہلکی رنگت',
    '👩🏼‍🌾' => 'عورت کاشت کار: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🌾' => 'عورت کاشت کار: جلد کی درمیانی رنگت',
    '👩🏾‍🌾' => 'عورت کاشت کار: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🌾' => 'عورت کاشت کار: جلد کی سیاہ رنگت',
    '🧑🏻‍🍳' => 'باورچی: جلد کی ہلکی رنگت',
    '🧑🏼‍🍳' => 'باورچی: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🍳' => 'باورچی: جلد کی درمیانی رنگت',
    '🧑🏾‍🍳' => 'باورچی: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🍳' => 'باورچی: جلد کی سیاہ رنگت',
    '👨🏻‍🍳' => 'مرد باورچی: جلد کی ہلکی رنگت',
    '👨🏼‍🍳' => 'مرد باورچی: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🍳' => 'مرد باورچی: جلد کی درمیانی رنگت',
    '👨🏾‍🍳' => 'مرد باورچی: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🍳' => 'مرد باورچی: جلد کی سیاہ رنگت',
    '👩🏻‍🍳' => 'عورت باورچی: جلد کی ہلکی رنگت',
    '👩🏼‍🍳' => 'عورت باورچی: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🍳' => 'عورت باورچی: جلد کی درمیانی رنگت',
    '👩🏾‍🍳' => 'عورت باورچی: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🍳' => 'عورت باورچی: جلد کی سیاہ رنگت',
    '🧑🏻‍🔧' => 'مکینک: جلد کی ہلکی رنگت',
    '🧑🏼‍🔧' => 'مکینک: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🔧' => 'مکینک: جلد کی درمیانی رنگت',
    '🧑🏾‍🔧' => 'مکینک: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🔧' => 'مکینک: جلد کی سیاہ رنگت',
    '👨🏻‍🔧' => 'مرد مکینک: جلد کی ہلکی رنگت',
    '👨🏼‍🔧' => 'مرد مکینک: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🔧' => 'مرد مکینک: جلد کی درمیانی رنگت',
    '👨🏾‍🔧' => 'مرد مکینک: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🔧' => 'مرد مکینک: جلد کی سیاہ رنگت',
    '👩🏻‍🔧' => 'عورت مکینک: جلد کی ہلکی رنگت',
    '👩🏼‍🔧' => 'عورت مکینک: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🔧' => 'عورت مکینک: جلد کی درمیانی رنگت',
    '👩🏾‍🔧' => 'عورت مکینک: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🔧' => 'عورت مکینک: جلد کی سیاہ رنگت',
    '🧑🏻‍🏭' => 'فیکٹری ورکر: جلد کی ہلکی رنگت',
    '🧑🏼‍🏭' => 'فیکٹری ورکر: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🏭' => 'فیکٹری ورکر: جلد کی درمیانی رنگت',
    '🧑🏾‍🏭' => 'فیکٹری ورکر: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🏭' => 'فیکٹری ورکر: جلد کی سیاہ رنگت',
    '👨🏻‍🏭' => 'مرد فیکٹری کارکن: جلد کی ہلکی رنگت',
    '👨🏼‍🏭' => 'مرد فیکٹری کارکن: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🏭' => 'مرد فیکٹری کارکن: جلد کی درمیانی رنگت',
    '👨🏾‍🏭' => 'مرد فیکٹری کارکن: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🏭' => 'مرد فیکٹری کارکن: جلد کی سیاہ رنگت',
    '👩🏻‍🏭' => 'عورت فیکٹری کارکن: جلد کی ہلکی رنگت',
    '👩🏼‍🏭' => 'عورت فیکٹری کارکن: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🏭' => 'عورت فیکٹری کارکن: جلد کی درمیانی رنگت',
    '👩🏾‍🏭' => 'عورت فیکٹری کارکن: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🏭' => 'عورت فیکٹری کارکن: جلد کی سیاہ رنگت',
    '🧑🏻‍💼' => 'آفس ورکر: جلد کی ہلکی رنگت',
    '🧑🏼‍💼' => 'آفس ورکر: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍💼' => 'آفس ورکر: جلد کی درمیانی رنگت',
    '🧑🏾‍💼' => 'آفس ورکر: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍💼' => 'آفس ورکر: جلد کی سیاہ رنگت',
    '👨🏻‍💼' => 'مرد دفتر کارکن: جلد کی ہلکی رنگت',
    '👨🏼‍💼' => 'مرد دفتر کارکن: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍💼' => 'مرد دفتر کارکن: جلد کی درمیانی رنگت',
    '👨🏾‍💼' => 'مرد دفتر کارکن: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍💼' => 'مرد دفتر کارکن: جلد کی سیاہ رنگت',
    '👩🏻‍💼' => 'عورت دفتر کارکن: جلد کی ہلکی رنگت',
    '👩🏼‍💼' => 'عورت دفتر کارکن: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍💼' => 'عورت دفتر کارکن: جلد کی درمیانی رنگت',
    '👩🏾‍💼' => 'عورت دفتر کارکن: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍💼' => 'عورت دفتر کارکن: جلد کی سیاہ رنگت',
    '🧑🏻‍🔬' => 'سائنسدان: جلد کی ہلکی رنگت',
    '🧑🏼‍🔬' => 'سائنسدان: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🔬' => 'سائنسدان: جلد کی درمیانی رنگت',
    '🧑🏾‍🔬' => 'سائنسدان: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🔬' => 'سائنسدان: جلد کی سیاہ رنگت',
    '👨🏻‍🔬' => 'مرد سائنسدان: جلد کی ہلکی رنگت',
    '👨🏼‍🔬' => 'مرد سائنسدان: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🔬' => 'مرد سائنسدان: جلد کی درمیانی رنگت',
    '👨🏾‍🔬' => 'مرد سائنسدان: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🔬' => 'مرد سائنسدان: جلد کی سیاہ رنگت',
    '👩🏻‍🔬' => 'عورت سائنسدان: جلد کی ہلکی رنگت',
    '👩🏼‍🔬' => 'عورت سائنسدان: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🔬' => 'عورت سائنسدان: جلد کی درمیانی رنگت',
    '👩🏾‍🔬' => 'عورت سائنسدان: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🔬' => 'عورت سائنسدان: جلد کی سیاہ رنگت',
    '🧑🏻‍💻' => 'ٹیکنالوجسٹ: جلد کی ہلکی رنگت',
    '🧑🏼‍💻' => 'ٹیکنالوجسٹ: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍💻' => 'ٹیکنالوجسٹ: جلد کی درمیانی رنگت',
    '🧑🏾‍💻' => 'ٹیکنالوجسٹ: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍💻' => 'ٹیکنالوجسٹ: جلد کی سیاہ رنگت',
    '👨🏻‍💻' => 'مرد ٹیکنولاجسٹ: جلد کی ہلکی رنگت',
    '👨🏼‍💻' => 'مرد ٹیکنولاجسٹ: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍💻' => 'مرد ٹیکنولاجسٹ: جلد کی درمیانی رنگت',
    '👨🏾‍💻' => 'مرد ٹیکنولاجسٹ: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍💻' => 'مرد ٹیکنولاجسٹ: جلد کی سیاہ رنگت',
    '👩🏻‍💻' => 'عورت ٹیکنولاجسٹ: جلد کی ہلکی رنگت',
    '👩🏼‍💻' => 'عورت ٹیکنولاجسٹ: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍💻' => 'عورت ٹیکنولاجسٹ: جلد کی درمیانی رنگت',
    '👩🏾‍💻' => 'عورت ٹیکنولاجسٹ: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍💻' => 'عورت ٹیکنولاجسٹ: جلد کی سیاہ رنگت',
    '🧑🏻‍🎤' => 'سنگر: جلد کی ہلکی رنگت',
    '🧑🏼‍🎤' => 'سنگر: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🎤' => 'سنگر: جلد کی درمیانی رنگت',
    '🧑🏾‍🎤' => 'سنگر: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🎤' => 'سنگر: جلد کی سیاہ رنگت',
    '👨🏻‍🎤' => 'گلوکار: جلد کی ہلکی رنگت',
    '👨🏼‍🎤' => 'گلوکار: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🎤' => 'گلوکار: جلد کی درمیانی رنگت',
    '👨🏾‍🎤' => 'گلوکار: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🎤' => 'گلوکار: جلد کی سیاہ رنگت',
    '👩🏻‍🎤' => 'گلوکارہ: جلد کی ہلکی رنگت',
    '👩🏼‍🎤' => 'گلوکارہ: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🎤' => 'گلوکارہ: جلد کی درمیانی رنگت',
    '👩🏾‍🎤' => 'گلوکارہ: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🎤' => 'گلوکارہ: جلد کی سیاہ رنگت',
    '🧑🏻‍🎨' => 'آرٹسٹ: جلد کی ہلکی رنگت',
    '🧑🏼‍🎨' => 'آرٹسٹ: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🎨' => 'آرٹسٹ: جلد کی درمیانی رنگت',
    '🧑🏾‍🎨' => 'آرٹسٹ: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🎨' => 'آرٹسٹ: جلد کی سیاہ رنگت',
    '👨🏻‍🎨' => 'فنکار: جلد کی ہلکی رنگت',
    '👨🏼‍🎨' => 'فنکار: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🎨' => 'فنکار: جلد کی درمیانی رنگت',
    '👨🏾‍🎨' => 'فنکار: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🎨' => 'فنکار: جلد کی سیاہ رنگت',
    '👩🏻‍🎨' => 'فنکارہ: جلد کی ہلکی رنگت',
    '👩🏼‍🎨' => 'فنکارہ: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🎨' => 'فنکارہ: جلد کی درمیانی رنگت',
    '👩🏾‍🎨' => 'فنکارہ: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🎨' => 'فنکارہ: جلد کی سیاہ رنگت',
    '🧑🏻‍✈' => 'پائیلٹ: جلد کی ہلکی رنگت',
    '🧑🏼‍✈' => 'پائیلٹ: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍✈' => 'پائیلٹ: جلد کی درمیانی رنگت',
    '🧑🏾‍✈' => 'پائیلٹ: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍✈' => 'پائیلٹ: جلد کی سیاہ رنگت',
    '👨🏻‍✈' => 'مرد پائلٹ: جلد کی ہلکی رنگت',
    '👨🏼‍✈' => 'مرد پائلٹ: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍✈' => 'مرد پائلٹ: جلد کی درمیانی رنگت',
    '👨🏾‍✈' => 'مرد پائلٹ: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍✈' => 'مرد پائلٹ: جلد کی سیاہ رنگت',
    '👩🏻‍✈' => 'عورت پائلٹ: جلد کی ہلکی رنگت',
    '👩🏼‍✈' => 'عورت پائلٹ: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍✈' => 'عورت پائلٹ: جلد کی درمیانی رنگت',
    '👩🏾‍✈' => 'عورت پائلٹ: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍✈' => 'عورت پائلٹ: جلد کی سیاہ رنگت',
    '🧑🏻‍🚀' => 'خلا باز: جلد کی ہلکی رنگت',
    '🧑🏼‍🚀' => 'خلا باز: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🚀' => 'خلا باز: جلد کی درمیانی رنگت',
    '🧑🏾‍🚀' => 'خلا باز: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🚀' => 'خلا باز: جلد کی سیاہ رنگت',
    '👨🏻‍🚀' => 'مرد خلاباز: جلد کی ہلکی رنگت',
    '👨🏼‍🚀' => 'مرد خلاباز: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🚀' => 'مرد خلاباز: جلد کی درمیانی رنگت',
    '👨🏾‍🚀' => 'مرد خلاباز: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🚀' => 'مرد خلاباز: جلد کی سیاہ رنگت',
    '👩🏻‍🚀' => 'عورت خلاباز: جلد کی ہلکی رنگت',
    '👩🏼‍🚀' => 'عورت خلاباز: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🚀' => 'عورت خلاباز: جلد کی درمیانی رنگت',
    '👩🏾‍🚀' => 'عورت خلاباز: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🚀' => 'عورت خلاباز: جلد کی سیاہ رنگت',
    '🧑🏻‍🚒' => 'فائر فائٹر: جلد کی ہلکی رنگت',
    '🧑🏼‍🚒' => 'فائر فائٹر: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🚒' => 'فائر فائٹر: جلد کی درمیانی رنگت',
    '🧑🏾‍🚒' => 'فائر فائٹر: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🚒' => 'فائر فائٹر: جلد کی سیاہ رنگت',
    '👨🏻‍🚒' => 'مرد فائر فائٹر: جلد کی ہلکی رنگت',
    '👨🏼‍🚒' => 'مرد فائر فائٹر: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🚒' => 'مرد فائر فائٹر: جلد کی درمیانی رنگت',
    '👨🏾‍🚒' => 'مرد فائر فائٹر: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🚒' => 'مرد فائر فائٹر: جلد کی سیاہ رنگت',
    '👩🏻‍🚒' => 'عورت فائر فائٹر: جلد کی ہلکی رنگت',
    '👩🏼‍🚒' => 'عورت فائر فائٹر: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🚒' => 'عورت فائر فائٹر: جلد کی درمیانی رنگت',
    '👩🏾‍🚒' => 'عورت فائر فائٹر: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🚒' => 'عورت فائر فائٹر: جلد کی سیاہ رنگت',
    '👮🏻‍♂' => 'مرد پولیس آفیسر: جلد کی ہلکی رنگت',
    '👮🏼‍♂' => 'مرد پولیس آفیسر: جلد کی درمیانی -ہلکی رنگت',
    '👮🏽‍♂' => 'مرد پولیس آفیسر: جلد کی درمیانی رنگت',
    '👮🏾‍♂' => 'مرد پولیس آفیسر: جلد کی درمیانی سیاہ رنگت',
    '👮🏿‍♂' => 'مرد پولیس آفیسر: جلد کی سیاہ رنگت',
    '👮🏻‍♀' => 'عورت پولیس آفیسر: جلد کی ہلکی رنگت',
    '👮🏼‍♀' => 'عورت پولیس آفیسر: جلد کی درمیانی -ہلکی رنگت',
    '👮🏽‍♀' => 'عورت پولیس آفیسر: جلد کی درمیانی رنگت',
    '👮🏾‍♀' => 'عورت پولیس آفیسر: جلد کی درمیانی سیاہ رنگت',
    '👮🏿‍♀' => 'عورت پولیس آفیسر: جلد کی سیاہ رنگت',
    '🕵🏻‍♂' => 'مرد جاسوس: جلد کی ہلکی رنگت',
    '🕵🏼‍♂' => 'مرد جاسوس: جلد کی درمیانی -ہلکی رنگت',
    '🕵🏽‍♂' => 'مرد جاسوس: جلد کی درمیانی رنگت',
    '🕵🏾‍♂' => 'مرد جاسوس: جلد کی درمیانی سیاہ رنگت',
    '🕵🏿‍♂' => 'مرد جاسوس: جلد کی سیاہ رنگت',
    '🕵🏻‍♀' => 'عورت جاسوس: جلد کی ہلکی رنگت',
    '🕵🏼‍♀' => 'عورت جاسوس: جلد کی درمیانی -ہلکی رنگت',
    '🕵🏽‍♀' => 'عورت جاسوس: جلد کی درمیانی رنگت',
    '🕵🏾‍♀' => 'عورت جاسوس: جلد کی درمیانی سیاہ رنگت',
    '🕵🏿‍♀' => 'عورت جاسوس: جلد کی سیاہ رنگت',
    '💂🏻‍♂' => 'مرد گارڈ: جلد کی ہلکی رنگت',
    '💂🏼‍♂' => 'مرد گارڈ: جلد کی درمیانی -ہلکی رنگت',
    '💂🏽‍♂' => 'مرد گارڈ: جلد کی درمیانی رنگت',
    '💂🏾‍♂' => 'مرد گارڈ: جلد کی درمیانی سیاہ رنگت',
    '💂🏿‍♂' => 'مرد گارڈ: جلد کی سیاہ رنگت',
    '💂🏻‍♀' => 'عورت گارڈ: جلد کی ہلکی رنگت',
    '💂🏼‍♀' => 'عورت گارڈ: جلد کی درمیانی -ہلکی رنگت',
    '💂🏽‍♀' => 'عورت گارڈ: جلد کی درمیانی رنگت',
    '💂🏾‍♀' => 'عورت گارڈ: جلد کی درمیانی سیاہ رنگت',
    '💂🏿‍♀' => 'عورت گارڈ: جلد کی سیاہ رنگت',
    '👷🏻‍♂' => 'مرد مزدور: جلد کی ہلکی رنگت',
    '👷🏼‍♂' => 'مرد مزدور: جلد کی درمیانی -ہلکی رنگت',
    '👷🏽‍♂' => 'مرد مزدور: جلد کی درمیانی رنگت',
    '👷🏾‍♂' => 'مرد مزدور: جلد کی درمیانی سیاہ رنگت',
    '👷🏿‍♂' => 'مرد مزدور: جلد کی سیاہ رنگت',
    '👷🏻‍♀' => 'عورت مزدور: جلد کی ہلکی رنگت',
    '👷🏼‍♀' => 'عورت مزدور: جلد کی درمیانی -ہلکی رنگت',
    '👷🏽‍♀' => 'عورت مزدور: جلد کی درمیانی رنگت',
    '👷🏾‍♀' => 'عورت مزدور: جلد کی درمیانی سیاہ رنگت',
    '👷🏿‍♀' => 'عورت مزدور: جلد کی سیاہ رنگت',
    '👳🏻‍♂' => 'پگڑی والا مرد: جلد کی ہلکی رنگت',
    '👳🏼‍♂' => 'پگڑی والا مرد: جلد کی درمیانی -ہلکی رنگت',
    '👳🏽‍♂' => 'پگڑی والا مرد: جلد کی درمیانی رنگت',
    '👳🏾‍♂' => 'پگڑی والا مرد: جلد کی درمیانی سیاہ رنگت',
    '👳🏿‍♂' => 'پگڑی والا مرد: جلد کی سیاہ رنگت',
    '👳🏻‍♀' => 'پگڑی والی عورت: جلد کی ہلکی رنگت',
    '👳🏼‍♀' => 'پگڑی والی عورت: جلد کی درمیانی -ہلکی رنگت',
    '👳🏽‍♀' => 'پگڑی والی عورت: جلد کی درمیانی رنگت',
    '👳🏾‍♀' => 'پگڑی والی عورت: جلد کی درمیانی سیاہ رنگت',
    '👳🏿‍♀' => 'پگڑی والی عورت: جلد کی سیاہ رنگت',
    '🤵🏻‍♂' => 'کوٹ پینٹ پہنا ہوا مرد: جلد کی ہلکی رنگت',
    '🤵🏼‍♂' => 'کوٹ پینٹ پہنا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🤵🏽‍♂' => 'کوٹ پینٹ پہنا ہوا مرد: جلد کی درمیانی رنگت',
    '🤵🏾‍♂' => 'کوٹ پینٹ پہنا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🤵🏿‍♂' => 'کوٹ پینٹ پہنا ہوا مرد: جلد کی سیاہ رنگت',
    '🤵🏻‍♀' => 'کوٹ پینٹ پہنی ہوئی عورت: جلد کی ہلکی رنگت',
    '🤵🏼‍♀' => 'کوٹ پینٹ پہنی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🤵🏽‍♀' => 'کوٹ پینٹ پہنی ہوئی عورت: جلد کی درمیانی رنگت',
    '🤵🏾‍♀' => 'کوٹ پینٹ پہنی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🤵🏿‍♀' => 'کوٹ پینٹ پہنی ہوئی عورت: جلد کی سیاہ رنگت',
    '👰🏻‍♂' => 'پردہ دار مرد: جلد کی ہلکی رنگت',
    '👰🏼‍♂' => 'پردہ دار مرد: جلد کی درمیانی -ہلکی رنگت',
    '👰🏽‍♂' => 'پردہ دار مرد: جلد کی درمیانی رنگت',
    '👰🏾‍♂' => 'پردہ دار مرد: جلد کی درمیانی سیاہ رنگت',
    '👰🏿‍♂' => 'پردہ دار مرد: جلد کی سیاہ رنگت',
    '👰🏻‍♀' => 'نقاب پوش عورت: جلد کی ہلکی رنگت',
    '👰🏼‍♀' => 'نقاب پوش عورت: جلد کی درمیانی -ہلکی رنگت',
    '👰🏽‍♀' => 'نقاب پوش عورت: جلد کی درمیانی رنگت',
    '👰🏾‍♀' => 'نقاب پوش عورت: جلد کی درمیانی سیاہ رنگت',
    '👰🏿‍♀' => 'نقاب پوش عورت: جلد کی سیاہ رنگت',
    '👩🏻‍🍼' => 'بچے کو دودھ پلاتی عورت: جلد کی ہلکی رنگت',
    '👩🏼‍🍼' => 'بچے کو دودھ پلاتی عورت: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🍼' => 'بچے کو دودھ پلاتی عورت: جلد کی درمیانی رنگت',
    '👩🏾‍🍼' => 'بچے کو دودھ پلاتی عورت: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🍼' => 'بچے کو دودھ پلاتی عورت: جلد کی سیاہ رنگت',
    '👨🏻‍🍼' => 'بچے کو دودھ پلاتا مرد: جلد کی ہلکی رنگت',
    '👨🏼‍🍼' => 'بچے کو دودھ پلاتا مرد: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🍼' => 'بچے کو دودھ پلاتا مرد: جلد کی درمیانی رنگت',
    '👨🏾‍🍼' => 'بچے کو دودھ پلاتا مرد: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🍼' => 'بچے کو دودھ پلاتا مرد: جلد کی سیاہ رنگت',
    '🧑🏻‍🍼' => 'بچے کو دودھ پلاتا شخص: جلد کی ہلکی رنگت',
    '🧑🏼‍🍼' => 'بچے کو دودھ پلاتا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🍼' => 'بچے کو دودھ پلاتا شخص: جلد کی درمیانی رنگت',
    '🧑🏾‍🍼' => 'بچے کو دودھ پلاتا شخص: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🍼' => 'بچے کو دودھ پلاتا شخص: جلد کی سیاہ رنگت',
    '🧑🏻‍🎄' => 'میکس کلاؤز: جلد کی ہلکی رنگت',
    '🧑🏼‍🎄' => 'میکس کلاؤز: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🎄' => 'میکس کلاؤز: جلد کی درمیانی رنگت',
    '🧑🏾‍🎄' => 'میکس کلاؤز: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🎄' => 'میکس کلاؤز: جلد کی سیاہ رنگت',
    '🦸🏻‍♂' => 'مرد سپر ہیرو: جلد کی ہلکی رنگت',
    '🦸🏼‍♂' => 'مرد سپر ہیرو: جلد کی درمیانی -ہلکی رنگت',
    '🦸🏽‍♂' => 'مرد سپر ہیرو: جلد کی درمیانی رنگت',
    '🦸🏾‍♂' => 'مرد سپر ہیرو: جلد کی درمیانی سیاہ رنگت',
    '🦸🏿‍♂' => 'مرد سپر ہیرو: جلد کی سیاہ رنگت',
    '🦸🏻‍♀' => 'خاتون سپر ہیرو: جلد کی ہلکی رنگت',
    '🦸🏼‍♀' => 'خاتون سپر ہیرو: جلد کی درمیانی -ہلکی رنگت',
    '🦸🏽‍♀' => 'خاتون سپر ہیرو: جلد کی درمیانی رنگت',
    '🦸🏾‍♀' => 'خاتون سپر ہیرو: جلد کی درمیانی سیاہ رنگت',
    '🦸🏿‍♀' => 'خاتون سپر ہیرو: جلد کی سیاہ رنگت',
    '🦹🏻‍♂' => 'مرد سپر ولن: جلد کی ہلکی رنگت',
    '🦹🏼‍♂' => 'مرد سپر ولن: جلد کی درمیانی -ہلکی رنگت',
    '🦹🏽‍♂' => 'مرد سپر ولن: جلد کی درمیانی رنگت',
    '🦹🏾‍♂' => 'مرد سپر ولن: جلد کی درمیانی سیاہ رنگت',
    '🦹🏿‍♂' => 'مرد سپر ولن: جلد کی سیاہ رنگت',
    '🦹🏻‍♀' => 'خاتون سپر ولن: جلد کی ہلکی رنگت',
    '🦹🏼‍♀' => 'خاتون سپر ولن: جلد کی درمیانی -ہلکی رنگت',
    '🦹🏽‍♀' => 'خاتون سپر ولن: جلد کی درمیانی رنگت',
    '🦹🏾‍♀' => 'خاتون سپر ولن: جلد کی درمیانی سیاہ رنگت',
    '🦹🏿‍♀' => 'خاتون سپر ولن: جلد کی سیاہ رنگت',
    '🧙🏻‍♂' => 'جادوگر آدمی: جلد کی ہلکی رنگت',
    '🧙🏼‍♂' => 'جادوگر آدمی: جلد کی درمیانی -ہلکی رنگت',
    '🧙🏽‍♂' => 'جادوگر آدمی: جلد کی درمیانی رنگت',
    '🧙🏾‍♂' => 'جادوگر آدمی: جلد کی درمیانی سیاہ رنگت',
    '🧙🏿‍♂' => 'جادوگر آدمی: جلد کی سیاہ رنگت',
    '🧙🏻‍♀' => 'جادوگر عورت: جلد کی ہلکی رنگت',
    '🧙🏼‍♀' => 'جادوگر عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧙🏽‍♀' => 'جادوگر عورت: جلد کی درمیانی رنگت',
    '🧙🏾‍♀' => 'جادوگر عورت: جلد کی درمیانی سیاہ رنگت',
    '🧙🏿‍♀' => 'جادوگر عورت: جلد کی سیاہ رنگت',
    '🧚🏻‍♂' => 'مرد پری: جلد کی ہلکی رنگت',
    '🧚🏼‍♂' => 'مرد پری: جلد کی درمیانی -ہلکی رنگت',
    '🧚🏽‍♂' => 'مرد پری: جلد کی درمیانی رنگت',
    '🧚🏾‍♂' => 'مرد پری: جلد کی درمیانی سیاہ رنگت',
    '🧚🏿‍♂' => 'مرد پری: جلد کی سیاہ رنگت',
    '🧚🏻‍♀' => 'پری عورت: جلد کی ہلکی رنگت',
    '🧚🏼‍♀' => 'پری عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧚🏽‍♀' => 'پری عورت: جلد کی درمیانی رنگت',
    '🧚🏾‍♀' => 'پری عورت: جلد کی درمیانی سیاہ رنگت',
    '🧚🏿‍♀' => 'پری عورت: جلد کی سیاہ رنگت',
    '🧛🏻‍♂' => 'خون خوار آدمی: جلد کی ہلکی رنگت',
    '🧛🏼‍♂' => 'خون خوار آدمی: جلد کی درمیانی -ہلکی رنگت',
    '🧛🏽‍♂' => 'خون خوار آدمی: جلد کی درمیانی رنگت',
    '🧛🏾‍♂' => 'خون خوار آدمی: جلد کی درمیانی سیاہ رنگت',
    '🧛🏿‍♂' => 'خون خوار آدمی: جلد کی سیاہ رنگت',
    '🧛🏻‍♀' => 'خون خوار عورت: جلد کی ہلکی رنگت',
    '🧛🏼‍♀' => 'خون خوار عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧛🏽‍♀' => 'خون خوار عورت: جلد کی درمیانی رنگت',
    '🧛🏾‍♀' => 'خون خوار عورت: جلد کی درمیانی سیاہ رنگت',
    '🧛🏿‍♀' => 'خون خوار عورت: جلد کی سیاہ رنگت',
    '🧜🏻‍♂' => 'جل مانس: جلد کی ہلکی رنگت',
    '🧜🏼‍♂' => 'جل مانس: جلد کی درمیانی -ہلکی رنگت',
    '🧜🏽‍♂' => 'جل مانس: جلد کی درمیانی رنگت',
    '🧜🏾‍♂' => 'جل مانس: جلد کی درمیانی سیاہ رنگت',
    '🧜🏿‍♂' => 'جل مانس: جلد کی سیاہ رنگت',
    '🧜🏻‍♀' => 'جل پری: جلد کی ہلکی رنگت',
    '🧜🏼‍♀' => 'جل پری: جلد کی درمیانی -ہلکی رنگت',
    '🧜🏽‍♀' => 'جل پری: جلد کی درمیانی رنگت',
    '🧜🏾‍♀' => 'جل پری: جلد کی درمیانی سیاہ رنگت',
    '🧜🏿‍♀' => 'جل پری: جلد کی سیاہ رنگت',
    '🧝🏻‍♂' => 'پریت آدمی: جلد کی ہلکی رنگت',
    '🧝🏼‍♂' => 'پریت آدمی: جلد کی درمیانی -ہلکی رنگت',
    '🧝🏽‍♂' => 'پریت آدمی: جلد کی درمیانی رنگت',
    '🧝🏾‍♂' => 'پریت آدمی: جلد کی درمیانی سیاہ رنگت',
    '🧝🏿‍♂' => 'پریت آدمی: جلد کی سیاہ رنگت',
    '🧝🏻‍♀' => 'پریت عورت: جلد کی ہلکی رنگت',
    '🧝🏼‍♀' => 'پریت عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧝🏽‍♀' => 'پریت عورت: جلد کی درمیانی رنگت',
    '🧝🏾‍♀' => 'پریت عورت: جلد کی درمیانی سیاہ رنگت',
    '🧝🏿‍♀' => 'پریت عورت: جلد کی سیاہ رنگت',
    '💆🏻‍♂' => 'چہرے کی مالش کراتا ہوا مرد: جلد کی ہلکی رنگت',
    '💆🏼‍♂' => 'چہرے کی مالش کراتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '💆🏽‍♂' => 'چہرے کی مالش کراتا ہوا مرد: جلد کی درمیانی رنگت',
    '💆🏾‍♂' => 'چہرے کی مالش کراتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '💆🏿‍♂' => 'چہرے کی مالش کراتا ہوا مرد: جلد کی سیاہ رنگت',
    '💆🏻‍♀' => 'چہرے کی مالش کراتی ہوئی عورت: جلد کی ہلکی رنگت',
    '💆🏼‍♀' => 'چہرے کی مالش کراتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '💆🏽‍♀' => 'چہرے کی مالش کراتی ہوئی عورت: جلد کی درمیانی رنگت',
    '💆🏾‍♀' => 'چہرے کی مالش کراتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '💆🏿‍♀' => 'چہرے کی مالش کراتی ہوئی عورت: جلد کی سیاہ رنگت',
    '💇🏻‍♂' => 'بال کٹواتا ہوا مرد: جلد کی ہلکی رنگت',
    '💇🏼‍♂' => 'بال کٹواتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '💇🏽‍♂' => 'بال کٹواتا ہوا مرد: جلد کی درمیانی رنگت',
    '💇🏾‍♂' => 'بال کٹواتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '💇🏿‍♂' => 'بال کٹواتا ہوا مرد: جلد کی سیاہ رنگت',
    '💇🏻‍♀' => 'بال کٹواتی ہوئی عورت: جلد کی ہلکی رنگت',
    '💇🏼‍♀' => 'بال کٹواتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '💇🏽‍♀' => 'بال کٹواتی ہوئی عورت: جلد کی درمیانی رنگت',
    '💇🏾‍♀' => 'بال کٹواتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '💇🏿‍♀' => 'بال کٹواتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🚶🏻‍♂' => 'پیدل چلتا ہوا مرد: جلد کی ہلکی رنگت',
    '🚶🏼‍♂' => 'پیدل چلتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🚶🏽‍♂' => 'پیدل چلتا ہوا مرد: جلد کی درمیانی رنگت',
    '🚶🏾‍♂' => 'پیدل چلتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🚶🏿‍♂' => 'پیدل چلتا ہوا مرد: جلد کی سیاہ رنگت',
    '🚶🏻‍♀' => 'پیدل چلتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🚶🏼‍♀' => 'پیدل چلتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🚶🏽‍♀' => 'پیدل چلتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🚶🏾‍♀' => 'پیدل چلتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🚶🏿‍♀' => 'پیدل چلتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🚶🏻‍➡' => 'پیدل چلتا شخص: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏼‍➡' => 'پیدل چلتا شخص: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏽‍➡' => 'پیدل چلتا شخص: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏾‍➡' => 'پیدل چلتا شخص: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🚶🏿‍➡' => 'پیدل چلتا شخص: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧍🏻‍♂' => 'کھڑا ہوا مرد: جلد کی ہلکی رنگت',
    '🧍🏼‍♂' => 'کھڑا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🧍🏽‍♂' => 'کھڑا ہوا مرد: جلد کی درمیانی رنگت',
    '🧍🏾‍♂' => 'کھڑا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🧍🏿‍♂' => 'کھڑا ہوا مرد: جلد کی سیاہ رنگت',
    '🧍🏻‍♀' => 'کھڑی ہوئی عورت: جلد کی ہلکی رنگت',
    '🧍🏼‍♀' => 'کھڑی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧍🏽‍♀' => 'کھڑی ہوئی عورت: جلد کی درمیانی رنگت',
    '🧍🏾‍♀' => 'کھڑی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🧍🏿‍♀' => 'کھڑی ہوئی عورت: جلد کی سیاہ رنگت',
    '🧎🏻‍♂' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی ہلکی رنگت',
    '🧎🏼‍♂' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🧎🏽‍♂' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی درمیانی رنگت',
    '🧎🏾‍♂' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی درمیانی سیاہ رنگت',
    '🧎🏿‍♂' => 'گھٹنوں کے بل بیٹھا مرد: جلد کی سیاہ رنگت',
    '🧎🏻‍♀' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی ہلکی رنگت',
    '🧎🏼‍♀' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧎🏽‍♀' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی درمیانی رنگت',
    '🧎🏾‍♀' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی درمیانی سیاہ رنگت',
    '🧎🏿‍♀' => 'گھٹنوں کے بل بیٹھی عورت: جلد کی سیاہ رنگت',
    '🧎🏻‍➡' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏼‍➡' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏽‍➡' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏾‍➡' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧎🏿‍➡' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🧑🏻‍🦯' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی ہلکی رنگت',
    '🧑🏼‍🦯' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🦯' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی درمیانی رنگت',
    '🧑🏾‍🦯' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🦯' => 'ٹٹولنے والی چھڑی کے ساتھ فرد: جلد کی سیاہ رنگت',
    '👨🏻‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی ہلکی رنگت',
    '👨🏼‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی درمیانی رنگت',
    '👨🏾‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ مرد: جلد کی سیاہ رنگت',
    '👩🏻‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی ہلکی رنگت',
    '👩🏼‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی درمیانی رنگت',
    '👩🏾‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ عورت: جلد کی سیاہ رنگت',
    '🧑🏻‍🦼' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی ہلکی رنگت',
    '🧑🏼‍🦼' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🦼' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی درمیانی رنگت',
    '🧑🏾‍🦼' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🦼' => 'برقی وہیل چئیر میں بیٹھا فرد: جلد کی سیاہ رنگت',
    '👨🏻‍🦼' => 'برقی وہیل چئیر میں مرد: جلد کی ہلکی رنگت',
    '👨🏼‍🦼' => 'برقی وہیل چئیر میں مرد: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🦼' => 'برقی وہیل چئیر میں مرد: جلد کی درمیانی رنگت',
    '👨🏾‍🦼' => 'برقی وہیل چئیر میں مرد: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🦼' => 'برقی وہیل چئیر میں مرد: جلد کی سیاہ رنگت',
    '👩🏻‍🦼' => 'برقی وہیل چئیر میں عورت: جلد کی ہلکی رنگت',
    '👩🏼‍🦼' => 'برقی وہیل چئیر میں عورت: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🦼' => 'برقی وہیل چئیر میں عورت: جلد کی درمیانی رنگت',
    '👩🏾‍🦼' => 'برقی وہیل چئیر میں عورت: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🦼' => 'برقی وہیل چئیر میں عورت: جلد کی سیاہ رنگت',
    '🧑🏻‍🦽' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی ہلکی رنگت',
    '🧑🏼‍🦽' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽‍🦽' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی درمیانی رنگت',
    '🧑🏾‍🦽' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿‍🦽' => 'دستی وہیل چیئر میں بیٹھا فرد: جلد کی سیاہ رنگت',
    '👨🏻‍🦽' => 'دستی وہیل چئیر میں مرد: جلد کی ہلکی رنگت',
    '👨🏼‍🦽' => 'دستی وہیل چئیر میں مرد: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽‍🦽' => 'دستی وہیل چئیر میں مرد: جلد کی درمیانی رنگت',
    '👨🏾‍🦽' => 'دستی وہیل چئیر میں مرد: جلد کی درمیانی سیاہ رنگت',
    '👨🏿‍🦽' => 'دستی وہیل چئیر میں مرد: جلد کی سیاہ رنگت',
    '👩🏻‍🦽' => 'دستی وہیل چئیر میں عورت: جلد کی ہلکی رنگت',
    '👩🏼‍🦽' => 'دستی وہیل چئیر میں عورت: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽‍🦽' => 'دستی وہیل چئیر میں عورت: جلد کی درمیانی رنگت',
    '👩🏾‍🦽' => 'دستی وہیل چئیر میں عورت: جلد کی درمیانی سیاہ رنگت',
    '👩🏿‍🦽' => 'دستی وہیل چئیر میں عورت: جلد کی سیاہ رنگت',
    '🏃🏻‍♂' => 'دوڑتا ہوا مرد: جلد کی ہلکی رنگت',
    '🏃🏼‍♂' => 'دوڑتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🏃🏽‍♂' => 'دوڑتا ہوا مرد: جلد کی درمیانی رنگت',
    '🏃🏾‍♂' => 'دوڑتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🏃🏿‍♂' => 'دوڑتا ہوا مرد: جلد کی سیاہ رنگت',
    '🏃🏻‍♀' => 'دوڑتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🏃🏼‍♀' => 'دوڑتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🏃🏽‍♀' => 'دوڑتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🏃🏾‍♀' => 'دوڑتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🏃🏿‍♀' => 'دوڑتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🏃🏻‍➡' => 'دوڑتا ہوا شخص: جلد کی ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏼‍➡' => 'دوڑتا ہوا شخص: جلد کی درمیانی -ہلکی رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏽‍➡' => 'دوڑتا ہوا شخص: جلد کی درمیانی رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏾‍➡' => 'دوڑتا ہوا شخص: جلد کی درمیانی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '🏃🏿‍➡' => 'دوڑتا ہوا شخص: جلد کی سیاہ رنگت اور دائیں طرف دیکھنے والا',
    '👯🏻‍♀' => 'ڈانس کرتی ہوئی عورتیں: جلد کی ہلکی رنگت',
    '👯🏼‍♀' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی -ہلکی رنگت',
    '👯🏽‍♀' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی رنگت',
    '👯🏾‍♀' => 'ڈانس کرتی ہوئی عورتیں: جلد کی درمیانی سیاہ رنگت',
    '👯🏿‍♀' => 'ڈانس کرتی ہوئی عورتیں: جلد کی سیاہ رنگت',
    '👯🏻‍♂' => 'ڈانس کرتے ہوئے مرد: جلد کی ہلکی رنگت',
    '👯🏼‍♂' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی -ہلکی رنگت',
    '👯🏽‍♂' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی رنگت',
    '👯🏾‍♂' => 'ڈانس کرتے ہوئے مرد: جلد کی درمیانی سیاہ رنگت',
    '👯🏿‍♂' => 'ڈانس کرتے ہوئے مرد: جلد کی سیاہ رنگت',
    '🧖🏻‍♂' => 'ایک مرد بھاپ سے بھرے کمرے میں: جلد کی ہلکی رنگت',
    '🧖🏼‍♂' => 'ایک مرد بھاپ سے بھرے کمرے میں: جلد کی درمیانی -ہلکی رنگت',
    '🧖🏽‍♂' => 'ایک مرد بھاپ سے بھرے کمرے میں: جلد کی درمیانی رنگت',
    '🧖🏾‍♂' => 'ایک مرد بھاپ سے بھرے کمرے میں: جلد کی درمیانی سیاہ رنگت',
    '🧖🏿‍♂' => 'ایک مرد بھاپ سے بھرے کمرے میں: جلد کی سیاہ رنگت',
    '🧖🏻‍♀' => 'ایک خاتون بھاپ سے بھرے کمرے میں: جلد کی ہلکی رنگت',
    '🧖🏼‍♀' => 'ایک خاتون بھاپ سے بھرے کمرے میں: جلد کی درمیانی -ہلکی رنگت',
    '🧖🏽‍♀' => 'ایک خاتون بھاپ سے بھرے کمرے میں: جلد کی درمیانی رنگت',
    '🧖🏾‍♀' => 'ایک خاتون بھاپ سے بھرے کمرے میں: جلد کی درمیانی سیاہ رنگت',
    '🧖🏿‍♀' => 'ایک خاتون بھاپ سے بھرے کمرے میں: جلد کی سیاہ رنگت',
    '🧗🏻‍♂' => 'چڑھتا ہوا آدمی: جلد کی ہلکی رنگت',
    '🧗🏼‍♂' => 'چڑھتا ہوا آدمی: جلد کی درمیانی -ہلکی رنگت',
    '🧗🏽‍♂' => 'چڑھتا ہوا آدمی: جلد کی درمیانی رنگت',
    '🧗🏾‍♂' => 'چڑھتا ہوا آدمی: جلد کی درمیانی سیاہ رنگت',
    '🧗🏿‍♂' => 'چڑھتا ہوا آدمی: جلد کی سیاہ رنگت',
    '🧗🏻‍♀' => 'چڑھتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🧗🏼‍♀' => 'چڑھتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧗🏽‍♀' => 'چڑھتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🧗🏾‍♀' => 'چڑھتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🧗🏿‍♀' => 'چڑھتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🏌🏻‍♂' => 'گالف کھیلتا ہوا مرد: جلد کی ہلکی رنگت',
    '🏌🏼‍♂' => 'گالف کھیلتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🏌🏽‍♂' => 'گالف کھیلتا ہوا مرد: جلد کی درمیانی رنگت',
    '🏌🏾‍♂' => 'گالف کھیلتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🏌🏿‍♂' => 'گالف کھیلتا ہوا مرد: جلد کی سیاہ رنگت',
    '🏌🏻‍♀' => 'گالف کھیلتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🏌🏼‍♀' => 'گالف کھیلتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🏌🏽‍♀' => 'گالف کھیلتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🏌🏾‍♀' => 'گالف کھیلتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🏌🏿‍♀' => 'گالف کھیلتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🏄🏻‍♂' => 'سرفنگ کرتا ہوا مرد: جلد کی ہلکی رنگت',
    '🏄🏼‍♂' => 'سرفنگ کرتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🏄🏽‍♂' => 'سرفنگ کرتا ہوا مرد: جلد کی درمیانی رنگت',
    '🏄🏾‍♂' => 'سرفنگ کرتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🏄🏿‍♂' => 'سرفنگ کرتا ہوا مرد: جلد کی سیاہ رنگت',
    '🏄🏻‍♀' => 'سرفنگ کرتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🏄🏼‍♀' => 'سرفنگ کرتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🏄🏽‍♀' => 'سرفنگ کرتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🏄🏾‍♀' => 'سرفنگ کرتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🏄🏿‍♀' => 'سرفنگ کرتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🚣🏻‍♂' => 'کشتی چلاتا ہوا مرد: جلد کی ہلکی رنگت',
    '🚣🏼‍♂' => 'کشتی چلاتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🚣🏽‍♂' => 'کشتی چلاتا ہوا مرد: جلد کی درمیانی رنگت',
    '🚣🏾‍♂' => 'کشتی چلاتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🚣🏿‍♂' => 'کشتی چلاتا ہوا مرد: جلد کی سیاہ رنگت',
    '🚣🏻‍♀' => 'کشتی چلاتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🚣🏼‍♀' => 'کشتی چلاتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🚣🏽‍♀' => 'کشتی چلاتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🚣🏾‍♀' => 'کشتی چلاتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🚣🏿‍♀' => 'کشتی چلاتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🏊🏻‍♂' => 'تیراکی کرتا ہوا مرد: جلد کی ہلکی رنگت',
    '🏊🏼‍♂' => 'تیراکی کرتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🏊🏽‍♂' => 'تیراکی کرتا ہوا مرد: جلد کی درمیانی رنگت',
    '🏊🏾‍♂' => 'تیراکی کرتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🏊🏿‍♂' => 'تیراکی کرتا ہوا مرد: جلد کی سیاہ رنگت',
    '🏊🏻‍♀' => 'تیراکی کرتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🏊🏼‍♀' => 'تیراکی کرتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🏊🏽‍♀' => 'تیراکی کرتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🏊🏾‍♀' => 'تیراکی کرتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🏊🏿‍♀' => 'تیراکی کرتی ہوئی عورت: جلد کی سیاہ رنگت',
    '⛹🏻‍♂' => 'بال سے کھیلتا ہوا مرد: جلد کی ہلکی رنگت',
    '⛹🏼‍♂' => 'بال سے کھیلتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '⛹🏽‍♂' => 'بال سے کھیلتا ہوا مرد: جلد کی درمیانی رنگت',
    '⛹🏾‍♂' => 'بال سے کھیلتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '⛹🏿‍♂' => 'بال سے کھیلتا ہوا مرد: جلد کی سیاہ رنگت',
    '⛹🏻‍♀' => 'بال سے کھیلتی ہوئی عورت: جلد کی ہلکی رنگت',
    '⛹🏼‍♀' => 'بال سے کھیلتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '⛹🏽‍♀' => 'بال سے کھیلتی ہوئی عورت: جلد کی درمیانی رنگت',
    '⛹🏾‍♀' => 'بال سے کھیلتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '⛹🏿‍♀' => 'بال سے کھیلتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🏋🏻‍♂' => 'وزن اٹھاتا ہوا مرد: جلد کی ہلکی رنگت',
    '🏋🏼‍♂' => 'وزن اٹھاتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🏋🏽‍♂' => 'وزن اٹھاتا ہوا مرد: جلد کی درمیانی رنگت',
    '🏋🏾‍♂' => 'وزن اٹھاتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🏋🏿‍♂' => 'وزن اٹھاتا ہوا مرد: جلد کی سیاہ رنگت',
    '🏋🏻‍♀' => 'وزن اٹھاتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🏋🏼‍♀' => 'وزن اٹھاتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🏋🏽‍♀' => 'وزن اٹھاتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🏋🏾‍♀' => 'وزن اٹھاتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🏋🏿‍♀' => 'وزن اٹھاتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🚴🏻‍♂' => 'سائیکل سوار مرد: جلد کی ہلکی رنگت',
    '🚴🏼‍♂' => 'سائیکل سوار مرد: جلد کی درمیانی -ہلکی رنگت',
    '🚴🏽‍♂' => 'سائیکل سوار مرد: جلد کی درمیانی رنگت',
    '🚴🏾‍♂' => 'سائیکل سوار مرد: جلد کی درمیانی سیاہ رنگت',
    '🚴🏿‍♂' => 'سائیکل سوار مرد: جلد کی سیاہ رنگت',
    '🚴🏻‍♀' => 'سائیکل سوار عورت: جلد کی ہلکی رنگت',
    '🚴🏼‍♀' => 'سائیکل سوار عورت: جلد کی درمیانی -ہلکی رنگت',
    '🚴🏽‍♀' => 'سائیکل سوار عورت: جلد کی درمیانی رنگت',
    '🚴🏾‍♀' => 'سائیکل سوار عورت: جلد کی درمیانی سیاہ رنگت',
    '🚴🏿‍♀' => 'سائیکل سوار عورت: جلد کی سیاہ رنگت',
    '🚵🏻‍♂' => 'ماؤنٹین بائیک پر سوار مرد: جلد کی ہلکی رنگت',
    '🚵🏼‍♂' => 'ماؤنٹین بائیک پر سوار مرد: جلد کی درمیانی -ہلکی رنگت',
    '🚵🏽‍♂' => 'ماؤنٹین بائیک پر سوار مرد: جلد کی درمیانی رنگت',
    '🚵🏾‍♂' => 'ماؤنٹین بائیک پر سوار مرد: جلد کی درمیانی سیاہ رنگت',
    '🚵🏿‍♂' => 'ماؤنٹین بائیک پر سوار مرد: جلد کی سیاہ رنگت',
    '🚵🏻‍♀' => 'ماؤنٹین بائیک پر سوار عورت: جلد کی ہلکی رنگت',
    '🚵🏼‍♀' => 'ماؤنٹین بائیک پر سوار عورت: جلد کی درمیانی -ہلکی رنگت',
    '🚵🏽‍♀' => 'ماؤنٹین بائیک پر سوار عورت: جلد کی درمیانی رنگت',
    '🚵🏾‍♀' => 'ماؤنٹین بائیک پر سوار عورت: جلد کی درمیانی سیاہ رنگت',
    '🚵🏿‍♀' => 'ماؤنٹین بائیک پر سوار عورت: جلد کی سیاہ رنگت',
    '🤸🏻‍♂' => 'قلابازی کھاتا ہوا مرد: جلد کی ہلکی رنگت',
    '🤸🏼‍♂' => 'قلابازی کھاتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🤸🏽‍♂' => 'قلابازی کھاتا ہوا مرد: جلد کی درمیانی رنگت',
    '🤸🏾‍♂' => 'قلابازی کھاتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🤸🏿‍♂' => 'قلابازی کھاتا ہوا مرد: جلد کی سیاہ رنگت',
    '🤸🏻‍♀' => 'قلابازی کھاتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🤸🏼‍♀' => 'قلابازی کھاتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🤸🏽‍♀' => 'قلابازی کھاتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🤸🏾‍♀' => 'قلابازی کھاتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🤸🏿‍♀' => 'قلابازی کھاتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🤼🏻‍♀' => 'عورتوں کی کشتی: جلد کی ہلکی رنگت',
    '🤼🏼‍♀' => 'عورتوں کی کشتی: جلد کی درمیانی -ہلکی رنگت',
    '🤼🏽‍♀' => 'عورتوں کی کشتی: جلد کی درمیانی رنگت',
    '🤼🏾‍♀' => 'عورتوں کی کشتی: جلد کی درمیانی سیاہ رنگت',
    '🤼🏿‍♀' => 'عورتوں کی کشتی: جلد کی سیاہ رنگت',
    '🤼🏻‍♂' => 'مردوں کی کشتی: جلد کی ہلکی رنگت',
    '🤼🏼‍♂' => 'مردوں کی کشتی: جلد کی درمیانی -ہلکی رنگت',
    '🤼🏽‍♂' => 'مردوں کی کشتی: جلد کی درمیانی رنگت',
    '🤼🏾‍♂' => 'مردوں کی کشتی: جلد کی درمیانی سیاہ رنگت',
    '🤼🏿‍♂' => 'مردوں کی کشتی: جلد کی سیاہ رنگت',
    '🤽🏻‍♂' => 'واٹر پولو کھیلتا ہوا مرد: جلد کی ہلکی رنگت',
    '🤽🏼‍♂' => 'واٹر پولو کھیلتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🤽🏽‍♂' => 'واٹر پولو کھیلتا ہوا مرد: جلد کی درمیانی رنگت',
    '🤽🏾‍♂' => 'واٹر پولو کھیلتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🤽🏿‍♂' => 'واٹر پولو کھیلتا ہوا مرد: جلد کی سیاہ رنگت',
    '🤽🏻‍♀' => 'واٹر پولو کھیلتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🤽🏼‍♀' => 'واٹر پولو کھیلتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🤽🏽‍♀' => 'واٹر پولو کھیلتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🤽🏾‍♀' => 'واٹر پولو کھیلتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🤽🏿‍♀' => 'واٹر پولو کھیلتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🤾🏻‍♂' => 'ہینڈ بال کھیلتا ہوا مرد: جلد کی ہلکی رنگت',
    '🤾🏼‍♂' => 'ہینڈ بال کھیلتا ہوا مرد: جلد کی درمیانی -ہلکی رنگت',
    '🤾🏽‍♂' => 'ہینڈ بال کھیلتا ہوا مرد: جلد کی درمیانی رنگت',
    '🤾🏾‍♂' => 'ہینڈ بال کھیلتا ہوا مرد: جلد کی درمیانی سیاہ رنگت',
    '🤾🏿‍♂' => 'ہینڈ بال کھیلتا ہوا مرد: جلد کی سیاہ رنگت',
    '🤾🏻‍♀' => 'ہینڈ بال کھیلتی ہوئی عورت: جلد کی ہلکی رنگت',
    '🤾🏼‍♀' => 'ہینڈ بال کھیلتی ہوئی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🤾🏽‍♀' => 'ہینڈ بال کھیلتی ہوئی عورت: جلد کی درمیانی رنگت',
    '🤾🏾‍♀' => 'ہینڈ بال کھیلتی ہوئی عورت: جلد کی درمیانی سیاہ رنگت',
    '🤾🏿‍♀' => 'ہینڈ بال کھیلتی ہوئی عورت: جلد کی سیاہ رنگت',
    '🤹🏻‍♂' => 'شعبدہ باز مرد: جلد کی ہلکی رنگت',
    '🤹🏼‍♂' => 'شعبدہ باز مرد: جلد کی درمیانی -ہلکی رنگت',
    '🤹🏽‍♂' => 'شعبدہ باز مرد: جلد کی درمیانی رنگت',
    '🤹🏾‍♂' => 'شعبدہ باز مرد: جلد کی درمیانی سیاہ رنگت',
    '🤹🏿‍♂' => 'شعبدہ باز مرد: جلد کی سیاہ رنگت',
    '🤹🏻‍♀' => 'شعبدہ باز عورت: جلد کی ہلکی رنگت',
    '🤹🏼‍♀' => 'شعبدہ باز عورت: جلد کی درمیانی -ہلکی رنگت',
    '🤹🏽‍♀' => 'شعبدہ باز عورت: جلد کی درمیانی رنگت',
    '🤹🏾‍♀' => 'شعبدہ باز عورت: جلد کی درمیانی سیاہ رنگت',
    '🤹🏿‍♀' => 'شعبدہ باز عورت: جلد کی سیاہ رنگت',
    '🧘🏻‍♂' => 'پالتی مار کر بیٹھا آدمی: جلد کی ہلکی رنگت',
    '🧘🏼‍♂' => 'پالتی مار کر بیٹھا آدمی: جلد کی درمیانی -ہلکی رنگت',
    '🧘🏽‍♂' => 'پالتی مار کر بیٹھا آدمی: جلد کی درمیانی رنگت',
    '🧘🏾‍♂' => 'پالتی مار کر بیٹھا آدمی: جلد کی درمیانی سیاہ رنگت',
    '🧘🏿‍♂' => 'پالتی مار کر بیٹھا آدمی: جلد کی سیاہ رنگت',
    '🧘🏻‍♀' => 'پالتی مار کر بیٹھی عورت: جلد کی ہلکی رنگت',
    '🧘🏼‍♀' => 'پالتی مار کر بیٹھی عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧘🏽‍♀' => 'پالتی مار کر بیٹھی عورت: جلد کی درمیانی رنگت',
    '🧘🏾‍♀' => 'پالتی مار کر بیٹھی عورت: جلد کی درمیانی سیاہ رنگت',
    '🧘🏿‍♀' => 'پالتی مار کر بیٹھی عورت: جلد کی سیاہ رنگت',
    '🧑‍🦰' => 'شخص: سرخ بال',
    '🧑‍🦱' => 'شخص: گھنگھریالے بال',
    '🧑‍🦳' => 'شخص: سفید بال',
    '🧑‍🦲' => 'شخص: گنجا',
    '👨‍🦰' => 'مرد: سرخ بال',
    '👨‍🦱' => 'مرد: گھنگھریالے بال',
    '👨‍🦳' => 'مرد: سفید بال',
    '👨‍🦲' => 'مرد: گنجا',
    '👩‍🦰' => 'عورت: سرخ بال',
    '👩‍🦱' => 'عورت: گھنگھریالے بال',
    '👩‍🦳' => 'عورت: سفید بال',
    '👩‍🦲' => 'عورت: گنجا',
    '🚶‍➡' => 'پیدل چلتا شخص: دائیں طرف دیکھنے والا',
    '🧎‍➡' => 'گھٹنوں کے بل بیٹھا شخص: دائیں طرف دیکھنے والا',
    '🏃‍➡' => 'دوڑتا ہوا شخص: دائیں طرف دیکھنے والا',
    '👨‍👦' => 'خاندان: مرد اور لڑکا',
    '👨‍👧' => 'خاندان: مرد اور لڑکی',
    '👩‍👦' => 'خاندان: عورت اور لڑکا',
    '👩‍👧' => 'خاندان: عورت اور لڑکی',
    '😶‍🌫' => 'بادلوں میں چہرہ',
    '😮‍💨' => 'سانس چھوڑتا چہرہ',
    '🙂‍↕' => 'ہاں میں اوپر نیچے سر ہلاتا ہوا',
    '😵‍💫' => 'مرغولہ آنکھوں والا چہرہ',
    '❤‍🔥' => 'جلتی آگ میں دل',
    '❤‍🩹' => 'شفا یاب ہوتا دل',
    '👁‍🗨' => 'دھمکی روکنے کی مہم',
    '🧔‍♂' => 'مرد: داڑھی',
    '👱‍♂' => 'سنہرے بالوں والا مرد',
    '🧔‍♀' => 'عورت: داڑھی',
    '👱‍♀' => 'سنہرے بالوں والی عورت',
    '🙍‍♂' => 'گھورتا ہوا مرد',
    '🙍‍♀' => 'گھورتی ہوئی عورت',
    '🙎‍♂' => 'منہ بسورتا ہوا مرد',
    '🙎‍♀' => 'منہ بسورتی ہوا عورت',
    '🙅‍♂' => 'ٹھیک نہیں ہونے کا اشارہ کرتا ہوا مرد',
    '🙅‍♀' => 'ٹھیک نہیں ہونے کا اشارہ کرتی ہوئی عورت',
    '🙆‍♂' => 'ٹھیک ہے کا اشارہ کرتا ہوا مرد',
    '🙆‍♀' => 'ٹھیک ہے کا اشارہ کرتی ہوئی عورت',
    '💁‍♂' => 'تجویز دیتا ہوا مرد',
    '💁‍♀' => 'تجویز دیتی ہوئی عورت',
    '🙋‍♂' => 'ہاتھ اٹھاتا ہوا مرد',
    '🙋‍♀' => 'ہاتھ اٹھاتی ہوئی عورت',
    '🧏‍♂' => 'سماعت سے محروم مرد',
    '🧏‍♀' => 'بہری عورت',
    '🙇‍♂' => 'بہت زیادہ جھکا ہوا مرد',
    '🙇‍♀' => 'بہت زیادہ جھکی ہوئی عورت',
    '🤦‍♂' => 'شرمندگی ظاہر کرتا ہوا مرد',
    '🤦‍♀' => 'شرمندگی ظاہر کرتی ہوئی عورت',
    '🤷‍♂' => 'کندھے اچکاتا ہوا مرد',
    '🤷‍♀' => 'کندھے اچکاتی ہوئی عورت',
    '🧑‍⚕' => 'ہیلتھ ورکر',
    '👨‍⚕' => 'مرد ہیلتھ ورکر',
    '👩‍⚕' => 'عورت ہیلتھ ورکر',
    '🧑‍🎓' => 'طالب علم',
    '👨‍🎓' => 'مرد طالب علم',
    '👩‍🎓' => 'عورت طالب علم',
    '🧑‍🏫' => 'استاد',
    '👨‍🏫' => 'مرد استاد',
    '👩‍🏫' => 'استانی',
    '🧑‍⚖' => 'جج',
    '👨‍⚖' => 'مرد جج',
    '👩‍⚖' => 'عورت جج',
    '🧑‍🌾' => 'کسان',
    '👨‍🌾' => 'مرد کاشت کار',
    '👩‍🌾' => 'عورت کاشت کار',
    '🧑‍🍳' => 'باورچی',
    '👨‍🍳' => 'مرد باورچی',
    '👩‍🍳' => 'عورت باورچی',
    '🧑‍🔧' => 'مکینک',
    '👨‍🔧' => 'مرد مکینک',
    '👩‍🔧' => 'عورت مکینک',
    '🧑‍🏭' => 'فیکٹری ورکر',
    '👨‍🏭' => 'مرد فیکٹری کارکن',
    '👩‍🏭' => 'عورت فیکٹری کارکن',
    '🧑‍💼' => 'آفس ورکر',
    '👨‍💼' => 'مرد دفتر کارکن',
    '👩‍💼' => 'عورت دفتر کارکن',
    '🧑‍🔬' => 'سائنسدان',
    '👨‍🔬' => 'مرد سائنسدان',
    '👩‍🔬' => 'عورت سائنسدان',
    '🧑‍💻' => 'ٹیکنالوجسٹ',
    '👨‍💻' => 'مرد ٹیکنولاجسٹ',
    '👩‍💻' => 'عورت ٹیکنولاجسٹ',
    '🧑‍🎤' => 'سنگر',
    '👨‍🎤' => 'گلوکار',
    '👩‍🎤' => 'گلوکارہ',
    '🧑‍🎨' => 'آرٹسٹ',
    '👨‍🎨' => 'فنکار',
    '👩‍🎨' => 'فنکارہ',
    '🧑‍✈' => 'پائیلٹ',
    '👨‍✈' => 'مرد پائلٹ',
    '👩‍✈' => 'عورت پائلٹ',
    '🧑‍🚀' => 'خلا باز',
    '👨‍🚀' => 'مرد خلاباز',
    '👩‍🚀' => 'عورت خلاباز',
    '🧑‍🚒' => 'فائر فائٹر',
    '👨‍🚒' => 'مرد فائر فائٹر',
    '👩‍🚒' => 'عورت فائر فائٹر',
    '👮‍♂' => 'مرد پولیس آفیسر',
    '👮‍♀' => 'عورت پولیس آفیسر',
    '🕵‍♂' => 'مرد جاسوس',
    '🕵‍♀' => 'عورت جاسوس',
    '💂‍♂' => 'مرد گارڈ',
    '💂‍♀' => 'عورت گارڈ',
    '👷‍♂' => 'مرد مزدور',
    '👷‍♀' => 'عورت مزدور',
    '👳‍♂' => 'پگڑی والا مرد',
    '👳‍♀' => 'پگڑی والی عورت',
    '🤵‍♂' => 'کوٹ پینٹ پہنا ہوا مرد',
    '🤵‍♀' => 'کوٹ پینٹ پہنی ہوئی عورت',
    '👰‍♂' => 'پردہ دار مرد',
    '👰‍♀' => 'نقاب پوش عورت',
    '👩‍🍼' => 'بچے کو دودھ پلاتی عورت',
    '👨‍🍼' => 'بچے کو دودھ پلاتا مرد',
    '🧑‍🍼' => 'بچے کو دودھ پلاتا شخص',
    '🧑‍🎄' => 'میکس کلاؤز',
    '🦸‍♂' => 'مرد سپر ہیرو',
    '🦸‍♀' => 'خاتون سپر ہیرو',
    '🦹‍♂' => 'مرد سپر ولن',
    '🦹‍♀' => 'خاتون سپر ولن',
    '🧙‍♂' => 'جادوگر آدمی',
    '🧙‍♀' => 'جادوگر عورت',
    '🧚‍♂' => 'مرد پری',
    '🧚‍♀' => 'پری عورت',
    '🧛‍♂' => 'خون خوار آدمی',
    '🧛‍♀' => 'خون خوار عورت',
    '🧜‍♂' => 'جل مانس',
    '🧜‍♀' => 'جل پری',
    '🧝‍♂' => 'پریت آدمی',
    '🧝‍♀' => 'پریت عورت',
    '🧞‍♂' => 'مرد جن',
    '🧞‍♀' => 'عورت جن',
    '🧟‍♂' => 'زندہ مردہ مرد',
    '🧟‍♀' => 'زندہ مردہ عورت',
    '💆‍♂' => 'چہرے کی مالش کراتا ہوا مرد',
    '💆‍♀' => 'چہرے کی مالش کراتی ہوئی عورت',
    '💇‍♂' => 'بال کٹواتا ہوا مرد',
    '💇‍♀' => 'بال کٹواتی ہوئی عورت',
    '🚶‍♂' => 'پیدل چلتا ہوا مرد',
    '🚶‍♀' => 'پیدل چلتی ہوئی عورت',
    '🧍‍♂' => 'کھڑا ہوا مرد',
    '🧍‍♀' => 'کھڑی ہوئی عورت',
    '🧎‍♂' => 'گھٹنوں کے بل بیٹھا مرد',
    '🧎‍♀' => 'گھٹنوں کے بل بیٹھی عورت',
    '🧑‍🦯' => 'ٹٹولنے والی چھڑی کے ساتھ فرد',
    '👨‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ مرد',
    '👩‍🦯' => 'نابینا افراد والی چھڑی کے ساتھ عورت',
    '🧑‍🦼' => 'برقی وہیل چئیر میں بیٹھا فرد',
    '👨‍🦼' => 'برقی وہیل چئیر میں مرد',
    '👩‍🦼' => 'برقی وہیل چئیر میں عورت',
    '🧑‍🦽' => 'دستی وہیل چیئر میں بیٹھا فرد',
    '👨‍🦽' => 'دستی وہیل چئیر میں مرد',
    '👩‍🦽' => 'دستی وہیل چئیر میں عورت',
    '🏃‍♂' => 'دوڑتا ہوا مرد',
    '🏃‍♀' => 'دوڑتی ہوئی عورت',
    '🧑‍🩰' => 'بیلے ڈانسر',
    '👯‍♂' => 'ڈانس کرتے ہوئے مرد',
    '👯‍♀' => 'ڈانس کرتی ہوئی عورتیں',
    '🧖‍♂' => 'ایک مرد بھاپ سے بھرے کمرے میں',
    '🧖‍♀' => 'ایک خاتون بھاپ سے بھرے کمرے میں',
    '🧗‍♂' => 'چڑھتا ہوا آدمی',
    '🧗‍♀' => 'چڑھتی ہوئی عورت',
    '🏌‍♂' => 'گالف کھیلتا ہوا مرد',
    '🏌‍♀' => 'گالف کھیلتی ہوئی عورت',
    '🏄‍♂' => 'سرفنگ کرتا ہوا مرد',
    '🏄‍♀' => 'سرفنگ کرتی ہوئی عورت',
    '🚣‍♂' => 'کشتی چلاتا ہوا مرد',
    '🚣‍♀' => 'کشتی چلاتی ہوئی عورت',
    '🏊‍♂' => 'تیراکی کرتا ہوا مرد',
    '🏊‍♀' => 'تیراکی کرتی ہوئی عورت',
    '⛹‍♂' => 'بال سے کھیلتا ہوا مرد',
    '⛹‍♀' => 'بال سے کھیلتی ہوئی عورت',
    '🏋‍♂' => 'وزن اٹھاتا ہوا مرد',
    '🏋‍♀' => 'وزن اٹھاتی ہوئی عورت',
    '🚴‍♂' => 'سائیکل سوار مرد',
    '🚴‍♀' => 'سائیکل سوار عورت',
    '🚵‍♂' => 'ماؤنٹین بائیک پر سوار مرد',
    '🚵‍♀' => 'ماؤنٹین بائیک پر سوار عورت',
    '🤸‍♂' => 'قلابازی کھاتا ہوا مرد',
    '🤸‍♀' => 'قلابازی کھاتی ہوئی عورت',
    '🤼‍♂' => 'مردوں کی کشتی',
    '🤼‍♀' => 'عورتوں کی کشتی',
    '🤽‍♂' => 'واٹر پولو کھیلتا ہوا مرد',
    '🤽‍♀' => 'واٹر پولو کھیلتی ہوئی عورت',
    '🤾‍♂' => 'ہینڈ بال کھیلتا ہوا مرد',
    '🤾‍♀' => 'ہینڈ بال کھیلتی ہوئی عورت',
    '🤹‍♂' => 'شعبدہ باز مرد',
    '🤹‍♀' => 'شعبدہ باز عورت',
    '🧘‍♂' => 'پالتی مار کر بیٹھا آدمی',
    '🧘‍♀' => 'پالتی مار کر بیٹھی عورت',
    '🧑‍🧒' => 'خاندان: بالغ، بچہ',
    '🐕‍🦺' => 'خدمتگار کتا',
    '🐈‍⬛' => 'کالی بلی',
    '🐻‍❄' => 'قطبی ریچھ',
    '🐦‍⬛' => 'سیاہ پرندہ',
    '🐦‍🔥' => 'فینکس',
    '🍋‍🟩' => 'لائم',
    '🍄‍🟫' => 'بھورے رنگ کا مشروم',
    '⛓‍💥' => 'ٹوٹی ہوئی زنجیر',
    '🏳‍🌈' => 'قوس قزح پرچم',
    '🏳‍⚧' => 'ٹرانزینڈر پرچم',
    '🏴‍☠' => 'قزاقوں کا جھنڈا',
    '👋🏻' => 'ہاتھ لہرانا: جلد کی ہلکی رنگت',
    '👋🏼' => 'ہاتھ لہرانا: جلد کی درمیانی -ہلکی رنگت',
    '👋🏽' => 'ہاتھ لہرانا: جلد کی درمیانی رنگت',
    '👋🏾' => 'ہاتھ لہرانا: جلد کی درمیانی سیاہ رنگت',
    '👋🏿' => 'ہاتھ لہرانا: جلد کی سیاہ رنگت',
    '🤚🏻' => 'کھڑے ہاتھ کی پشت: جلد کی ہلکی رنگت',
    '🤚🏼' => 'کھڑے ہاتھ کی پشت: جلد کی درمیانی -ہلکی رنگت',
    '🤚🏽' => 'کھڑے ہاتھ کی پشت: جلد کی درمیانی رنگت',
    '🤚🏾' => 'کھڑے ہاتھ کی پشت: جلد کی درمیانی سیاہ رنگت',
    '🤚🏿' => 'کھڑے ہاتھ کی پشت: جلد کی سیاہ رنگت',
    '🖐🏻' => 'پھیلی ہوئی انگلیوں کے ساتھ بلند ہاتھ: جلد کی ہلکی رنگت',
    '🖐🏼' => 'پھیلی ہوئی انگلیوں کے ساتھ بلند ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🖐🏽' => 'پھیلی ہوئی انگلیوں کے ساتھ بلند ہاتھ: جلد کی درمیانی رنگت',
    '🖐🏾' => 'پھیلی ہوئی انگلیوں کے ساتھ بلند ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🖐🏿' => 'پھیلی ہوئی انگلیوں کے ساتھ بلند ہاتھ: جلد کی سیاہ رنگت',
    '✋🏻' => 'بلند ہاتھ: جلد کی ہلکی رنگت',
    '✋🏼' => 'بلند ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '✋🏽' => 'بلند ہاتھ: جلد کی درمیانی رنگت',
    '✋🏾' => 'بلند ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '✋🏿' => 'بلند ہاتھ: جلد کی سیاہ رنگت',
    '🖖🏻' => 'وولکن سلیوٹ: جلد کی ہلکی رنگت',
    '🖖🏼' => 'وولکن سلیوٹ: جلد کی درمیانی -ہلکی رنگت',
    '🖖🏽' => 'وولکن سلیوٹ: جلد کی درمیانی رنگت',
    '🖖🏾' => 'وولکن سلیوٹ: جلد کی درمیانی سیاہ رنگت',
    '🖖🏿' => 'وولکن سلیوٹ: جلد کی سیاہ رنگت',
    '🫱🏻' => 'دائیں اشارہ کرتا ہاتھ: جلد کی ہلکی رنگت',
    '🫱🏼' => 'دائیں اشارہ کرتا ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🫱🏽' => 'دائیں اشارہ کرتا ہاتھ: جلد کی درمیانی رنگت',
    '🫱🏾' => 'دائیں اشارہ کرتا ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🫱🏿' => 'دائیں اشارہ کرتا ہاتھ: جلد کی سیاہ رنگت',
    '🫲🏻' => 'بائیں اشارہ کرتا ہاتھ: جلد کی ہلکی رنگت',
    '🫲🏼' => 'بائیں اشارہ کرتا ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🫲🏽' => 'بائیں اشارہ کرتا ہاتھ: جلد کی درمیانی رنگت',
    '🫲🏾' => 'بائیں اشارہ کرتا ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🫲🏿' => 'بائیں اشارہ کرتا ہاتھ: جلد کی سیاہ رنگت',
    '🫳🏻' => 'ہتھیلی نیچے کیے ہاتھ: جلد کی ہلکی رنگت',
    '🫳🏼' => 'ہتھیلی نیچے کیے ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🫳🏽' => 'ہتھیلی نیچے کیے ہاتھ: جلد کی درمیانی رنگت',
    '🫳🏾' => 'ہتھیلی نیچے کیے ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🫳🏿' => 'ہتھیلی نیچے کیے ہاتھ: جلد کی سیاہ رنگت',
    '🫴🏻' => 'ہتھیلی اوپر کیے ہاتھ: جلد کی ہلکی رنگت',
    '🫴🏼' => 'ہتھیلی اوپر کیے ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🫴🏽' => 'ہتھیلی اوپر کیے ہاتھ: جلد کی درمیانی رنگت',
    '🫴🏾' => 'ہتھیلی اوپر کیے ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🫴🏿' => 'ہتھیلی اوپر کیے ہاتھ: جلد کی سیاہ رنگت',
    '🫷🏻' => 'بائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی ہلکی رنگت',
    '🫷🏼' => 'بائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🫷🏽' => 'بائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی درمیانی رنگت',
    '🫷🏾' => 'بائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🫷🏿' => 'بائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی سیاہ رنگت',
    '🫸🏻' => 'دائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی ہلکی رنگت',
    '🫸🏼' => 'دائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🫸🏽' => 'دائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی درمیانی رنگت',
    '🫸🏾' => 'دائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🫸🏿' => 'دائیں طرف دھکیلتے ہوئے ہاتھ: جلد کی سیاہ رنگت',
    '👌🏻' => 'اوکے کا نشان بناتا ہاتھ: جلد کی ہلکی رنگت',
    '👌🏼' => 'اوکے کا نشان بناتا ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '👌🏽' => 'اوکے کا نشان بناتا ہاتھ: جلد کی درمیانی رنگت',
    '👌🏾' => 'اوکے کا نشان بناتا ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '👌🏿' => 'اوکے کا نشان بناتا ہاتھ: جلد کی سیاہ رنگت',
    '🤌🏻' => 'بھینچی ہوئی انگلیاں: جلد کی ہلکی رنگت',
    '🤌🏼' => 'بھینچی ہوئی انگلیاں: جلد کی درمیانی -ہلکی رنگت',
    '🤌🏽' => 'بھینچی ہوئی انگلیاں: جلد کی درمیانی رنگت',
    '🤌🏾' => 'بھینچی ہوئی انگلیاں: جلد کی درمیانی سیاہ رنگت',
    '🤌🏿' => 'بھینچی ہوئی انگلیاں: جلد کی سیاہ رنگت',
    '🤏🏻' => 'چٹکی لیتا ہوا ہاتھ: جلد کی ہلکی رنگت',
    '🤏🏼' => 'چٹکی لیتا ہوا ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🤏🏽' => 'چٹکی لیتا ہوا ہاتھ: جلد کی درمیانی رنگت',
    '🤏🏾' => 'چٹکی لیتا ہوا ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🤏🏿' => 'چٹکی لیتا ہوا ہاتھ: جلد کی سیاہ رنگت',
    '✌🏻' => 'فتح کا نشان بناتا ہاتھ: جلد کی ہلکی رنگت',
    '✌🏼' => 'فتح کا نشان بناتا ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '✌🏽' => 'فتح کا نشان بناتا ہاتھ: جلد کی درمیانی رنگت',
    '✌🏾' => 'فتح کا نشان بناتا ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '✌🏿' => 'فتح کا نشان بناتا ہاتھ: جلد کی سیاہ رنگت',
    '🤞🏻' => 'کراس بناتی انگلیاں: جلد کی ہلکی رنگت',
    '🤞🏼' => 'کراس بناتی انگلیاں: جلد کی درمیانی -ہلکی رنگت',
    '🤞🏽' => 'کراس بناتی انگلیاں: جلد کی درمیانی رنگت',
    '🤞🏾' => 'کراس بناتی انگلیاں: جلد کی درمیانی سیاہ رنگت',
    '🤞🏿' => 'کراس بناتی انگلیاں: جلد کی سیاہ رنگت',
    '🫰🏻' => 'شہادت کی انگلی اور انگوٹھہ کراس کیے ہوئے ہاتھ: جلد کی ہلکی رنگت',
    '🫰🏼' => 'شہادت کی انگلی اور انگوٹھہ کراس کیے ہوئے ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🫰🏽' => 'شہادت کی انگلی اور انگوٹھہ کراس کیے ہوئے ہاتھ: جلد کی درمیانی رنگت',
    '🫰🏾' => 'شہادت کی انگلی اور انگوٹھہ کراس کیے ہوئے ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🫰🏿' => 'شہادت کی انگلی اور انگوٹھہ کراس کیے ہوئے ہاتھ: جلد کی سیاہ رنگت',
    '🤟🏻' => 'آپ سے محبت کا اشارہ: جلد کی ہلکی رنگت',
    '🤟🏼' => 'آپ سے محبت کا اشارہ: جلد کی درمیانی -ہلکی رنگت',
    '🤟🏽' => 'آپ سے محبت کا اشارہ: جلد کی درمیانی رنگت',
    '🤟🏾' => 'آپ سے محبت کا اشارہ: جلد کی درمیانی سیاہ رنگت',
    '🤟🏿' => 'آپ سے محبت کا اشارہ: جلد کی سیاہ رنگت',
    '🤘🏻' => 'ہاتھ سے سینگوں کا نشان: جلد کی ہلکی رنگت',
    '🤘🏼' => 'ہاتھ سے سینگوں کا نشان: جلد کی درمیانی -ہلکی رنگت',
    '🤘🏽' => 'ہاتھ سے سینگوں کا نشان: جلد کی درمیانی رنگت',
    '🤘🏾' => 'ہاتھ سے سینگوں کا نشان: جلد کی درمیانی سیاہ رنگت',
    '🤘🏿' => 'ہاتھ سے سینگوں کا نشان: جلد کی سیاہ رنگت',
    '🤙🏻' => 'کال کرنے کا اشارہ: جلد کی ہلکی رنگت',
    '🤙🏼' => 'کال کرنے کا اشارہ: جلد کی درمیانی -ہلکی رنگت',
    '🤙🏽' => 'کال کرنے کا اشارہ: جلد کی درمیانی رنگت',
    '🤙🏾' => 'کال کرنے کا اشارہ: جلد کی درمیانی سیاہ رنگت',
    '🤙🏿' => 'کال کرنے کا اشارہ: جلد کی سیاہ رنگت',
    '👈🏻' => 'بائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی ہلکی رنگت',
    '👈🏼' => 'بائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی -ہلکی رنگت',
    '👈🏽' => 'بائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی رنگت',
    '👈🏾' => 'بائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی سیاہ رنگت',
    '👈🏿' => 'بائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی سیاہ رنگت',
    '👉🏻' => 'دائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی ہلکی رنگت',
    '👉🏼' => 'دائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی -ہلکی رنگت',
    '👉🏽' => 'دائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی رنگت',
    '👉🏾' => 'دائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی سیاہ رنگت',
    '👉🏿' => 'دائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی سیاہ رنگت',
    '👆🏻' => 'اوپر اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی ہلکی رنگت',
    '👆🏼' => 'اوپر اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی -ہلکی رنگت',
    '👆🏽' => 'اوپر اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی رنگت',
    '👆🏾' => 'اوپر اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی سیاہ رنگت',
    '👆🏿' => 'اوپر اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی سیاہ رنگت',
    '🖕🏻' => 'درمیانی انگلی: جلد کی ہلکی رنگت',
    '🖕🏼' => 'درمیانی انگلی: جلد کی درمیانی -ہلکی رنگت',
    '🖕🏽' => 'درمیانی انگلی: جلد کی درمیانی رنگت',
    '🖕🏾' => 'درمیانی انگلی: جلد کی درمیانی سیاہ رنگت',
    '🖕🏿' => 'درمیانی انگلی: جلد کی سیاہ رنگت',
    '👇🏻' => 'نیچے اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی ہلکی رنگت',
    '👇🏼' => 'نیچے اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی -ہلکی رنگت',
    '👇🏽' => 'نیچے اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی رنگت',
    '👇🏾' => 'نیچے اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی درمیانی سیاہ رنگت',
    '👇🏿' => 'نیچے اشارہ کرتی بیک ہینڈ شہادت کی انگلی: جلد کی سیاہ رنگت',
    '☝🏻' => 'اوپر اشارہ کرتی شہادت کی انگلی: جلد کی ہلکی رنگت',
    '☝🏼' => 'اوپر اشارہ کرتی شہادت کی انگلی: جلد کی درمیانی -ہلکی رنگت',
    '☝🏽' => 'اوپر اشارہ کرتی شہادت کی انگلی: جلد کی درمیانی رنگت',
    '☝🏾' => 'اوپر اشارہ کرتی شہادت کی انگلی: جلد کی درمیانی سیاہ رنگت',
    '☝🏿' => 'اوپر اشارہ کرتی شہادت کی انگلی: جلد کی سیاہ رنگت',
    '🫵🏻' => 'دیکھنے والے کی طرف اشارہ کرتی انگلی: جلد کی ہلکی رنگت',
    '🫵🏼' => 'دیکھنے والے کی طرف اشارہ کرتی انگلی: جلد کی درمیانی -ہلکی رنگت',
    '🫵🏽' => 'دیکھنے والے کی طرف اشارہ کرتی انگلی: جلد کی درمیانی رنگت',
    '🫵🏾' => 'دیکھنے والے کی طرف اشارہ کرتی انگلی: جلد کی درمیانی سیاہ رنگت',
    '🫵🏿' => 'دیکھنے والے کی طرف اشارہ کرتی انگلی: جلد کی سیاہ رنگت',
    '👍🏻' => 'سب اچھا کا نشان بناتا انگوٹھا: جلد کی ہلکی رنگت',
    '👍🏼' => 'سب اچھا کا نشان بناتا انگوٹھا: جلد کی درمیانی -ہلکی رنگت',
    '👍🏽' => 'سب اچھا کا نشان بناتا انگوٹھا: جلد کی درمیانی رنگت',
    '👍🏾' => 'سب اچھا کا نشان بناتا انگوٹھا: جلد کی درمیانی سیاہ رنگت',
    '👍🏿' => 'سب اچھا کا نشان بناتا انگوٹھا: جلد کی سیاہ رنگت',
    '👎🏻' => 'اچھا نہ ہونے کا نشان بناتا انگوٹھا: جلد کی ہلکی رنگت',
    '👎🏼' => 'اچھا نہ ہونے کا نشان بناتا انگوٹھا: جلد کی درمیانی -ہلکی رنگت',
    '👎🏽' => 'اچھا نہ ہونے کا نشان بناتا انگوٹھا: جلد کی درمیانی رنگت',
    '👎🏾' => 'اچھا نہ ہونے کا نشان بناتا انگوٹھا: جلد کی درمیانی سیاہ رنگت',
    '👎🏿' => 'اچھا نہ ہونے کا نشان بناتا انگوٹھا: جلد کی سیاہ رنگت',
    '✊🏻' => 'بلند مُٹھی: جلد کی ہلکی رنگت',
    '✊🏼' => 'بلند مُٹھی: جلد کی درمیانی -ہلکی رنگت',
    '✊🏽' => 'بلند مُٹھی: جلد کی درمیانی رنگت',
    '✊🏾' => 'بلند مُٹھی: جلد کی درمیانی سیاہ رنگت',
    '✊🏿' => 'بلند مُٹھی: جلد کی سیاہ رنگت',
    '👊🏻' => 'آتا ہوا مُکا: جلد کی ہلکی رنگت',
    '👊🏼' => 'آتا ہوا مُکا: جلد کی درمیانی -ہلکی رنگت',
    '👊🏽' => 'آتا ہوا مُکا: جلد کی درمیانی رنگت',
    '👊🏾' => 'آتا ہوا مُکا: جلد کی درمیانی سیاہ رنگت',
    '👊🏿' => 'آتا ہوا مُکا: جلد کی سیاہ رنگت',
    '🤛🏻' => 'بائیں سمت میں مکا: جلد کی ہلکی رنگت',
    '🤛🏼' => 'بائیں سمت میں مکا: جلد کی درمیانی -ہلکی رنگت',
    '🤛🏽' => 'بائیں سمت میں مکا: جلد کی درمیانی رنگت',
    '🤛🏾' => 'بائیں سمت میں مکا: جلد کی درمیانی سیاہ رنگت',
    '🤛🏿' => 'بائیں سمت میں مکا: جلد کی سیاہ رنگت',
    '🤜🏻' => 'دائیں سمت میں مکا: جلد کی ہلکی رنگت',
    '🤜🏼' => 'دائیں سمت میں مکا: جلد کی درمیانی -ہلکی رنگت',
    '🤜🏽' => 'دائیں سمت میں مکا: جلد کی درمیانی رنگت',
    '🤜🏾' => 'دائیں سمت میں مکا: جلد کی درمیانی سیاہ رنگت',
    '🤜🏿' => 'دائیں سمت میں مکا: جلد کی سیاہ رنگت',
    '👏🏻' => 'تالیاں بجاتے ہاتھ: جلد کی ہلکی رنگت',
    '👏🏼' => 'تالیاں بجاتے ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '👏🏽' => 'تالیاں بجاتے ہاتھ: جلد کی درمیانی رنگت',
    '👏🏾' => 'تالیاں بجاتے ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '👏🏿' => 'تالیاں بجاتے ہاتھ: جلد کی سیاہ رنگت',
    '🙌🏻' => 'ہاتھ بلند کیے ہوئے شخص: جلد کی ہلکی رنگت',
    '🙌🏼' => 'ہاتھ بلند کیے ہوئے شخص: جلد کی درمیانی -ہلکی رنگت',
    '🙌🏽' => 'ہاتھ بلند کیے ہوئے شخص: جلد کی درمیانی رنگت',
    '🙌🏾' => 'ہاتھ بلند کیے ہوئے شخص: جلد کی درمیانی سیاہ رنگت',
    '🙌🏿' => 'ہاتھ بلند کیے ہوئے شخص: جلد کی سیاہ رنگت',
    '🫶🏻' => 'ہاتھوں سے بنا دل: جلد کی ہلکی رنگت',
    '🫶🏼' => 'ہاتھوں سے بنا دل: جلد کی درمیانی -ہلکی رنگت',
    '🫶🏽' => 'ہاتھوں سے بنا دل: جلد کی درمیانی رنگت',
    '🫶🏾' => 'ہاتھوں سے بنا دل: جلد کی درمیانی سیاہ رنگت',
    '🫶🏿' => 'ہاتھوں سے بنا دل: جلد کی سیاہ رنگت',
    '👐🏻' => 'کھلے ہاتھ: جلد کی ہلکی رنگت',
    '👐🏼' => 'کھلے ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '👐🏽' => 'کھلے ہاتھ: جلد کی درمیانی رنگت',
    '👐🏾' => 'کھلے ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '👐🏿' => 'کھلے ہاتھ: جلد کی سیاہ رنگت',
    '🤲🏻' => 'ایک ساتھ ہتھیلیاں اٹھانا: جلد کی ہلکی رنگت',
    '🤲🏼' => 'ایک ساتھ ہتھیلیاں اٹھانا: جلد کی درمیانی -ہلکی رنگت',
    '🤲🏽' => 'ایک ساتھ ہتھیلیاں اٹھانا: جلد کی درمیانی رنگت',
    '🤲🏾' => 'ایک ساتھ ہتھیلیاں اٹھانا: جلد کی درمیانی سیاہ رنگت',
    '🤲🏿' => 'ایک ساتھ ہتھیلیاں اٹھانا: جلد کی سیاہ رنگت',
    '🤝🏻' => 'ہاتھ ملانا: جلد کی ہلکی رنگت',
    '🤝🏼' => 'ہاتھ ملانا: جلد کی درمیانی -ہلکی رنگت',
    '🤝🏽' => 'ہاتھ ملانا: جلد کی درمیانی رنگت',
    '🤝🏾' => 'ہاتھ ملانا: جلد کی درمیانی سیاہ رنگت',
    '🤝🏿' => 'ہاتھ ملانا: جلد کی سیاہ رنگت',
    '🙏🏻' => 'بندھے ہاتھ: جلد کی ہلکی رنگت',
    '🙏🏼' => 'بندھے ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🙏🏽' => 'بندھے ہاتھ: جلد کی درمیانی رنگت',
    '🙏🏾' => 'بندھے ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🙏🏿' => 'بندھے ہاتھ: جلد کی سیاہ رنگت',
    '✍🏻' => 'لکھتا ہوا ہاتھ: جلد کی ہلکی رنگت',
    '✍🏼' => 'لکھتا ہوا ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '✍🏽' => 'لکھتا ہوا ہاتھ: جلد کی درمیانی رنگت',
    '✍🏾' => 'لکھتا ہوا ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '✍🏿' => 'لکھتا ہوا ہاتھ: جلد کی سیاہ رنگت',
    '💅🏻' => 'نیل پالش: جلد کی ہلکی رنگت',
    '💅🏼' => 'نیل پالش: جلد کی درمیانی -ہلکی رنگت',
    '💅🏽' => 'نیل پالش: جلد کی درمیانی رنگت',
    '💅🏾' => 'نیل پالش: جلد کی درمیانی سیاہ رنگت',
    '💅🏿' => 'نیل پالش: جلد کی سیاہ رنگت',
    '🤳🏻' => 'سیلفی: جلد کی ہلکی رنگت',
    '🤳🏼' => 'سیلفی: جلد کی درمیانی -ہلکی رنگت',
    '🤳🏽' => 'سیلفی: جلد کی درمیانی رنگت',
    '🤳🏾' => 'سیلفی: جلد کی درمیانی سیاہ رنگت',
    '🤳🏿' => 'سیلفی: جلد کی سیاہ رنگت',
    '💪🏻' => 'بازوؤں کے ڈولے: جلد کی ہلکی رنگت',
    '💪🏼' => 'بازوؤں کے ڈولے: جلد کی درمیانی -ہلکی رنگت',
    '💪🏽' => 'بازوؤں کے ڈولے: جلد کی درمیانی رنگت',
    '💪🏾' => 'بازوؤں کے ڈولے: جلد کی درمیانی سیاہ رنگت',
    '💪🏿' => 'بازوؤں کے ڈولے: جلد کی سیاہ رنگت',
    '🦵🏻' => 'ٹانگ: جلد کی ہلکی رنگت',
    '🦵🏼' => 'ٹانگ: جلد کی درمیانی -ہلکی رنگت',
    '🦵🏽' => 'ٹانگ: جلد کی درمیانی رنگت',
    '🦵🏾' => 'ٹانگ: جلد کی درمیانی سیاہ رنگت',
    '🦵🏿' => 'ٹانگ: جلد کی سیاہ رنگت',
    '🦶🏻' => 'پاؤں: جلد کی ہلکی رنگت',
    '🦶🏼' => 'پاؤں: جلد کی درمیانی -ہلکی رنگت',
    '🦶🏽' => 'پاؤں: جلد کی درمیانی رنگت',
    '🦶🏾' => 'پاؤں: جلد کی درمیانی سیاہ رنگت',
    '🦶🏿' => 'پاؤں: جلد کی سیاہ رنگت',
    '👂🏻' => 'کان: جلد کی ہلکی رنگت',
    '👂🏼' => 'کان: جلد کی درمیانی -ہلکی رنگت',
    '👂🏽' => 'کان: جلد کی درمیانی رنگت',
    '👂🏾' => 'کان: جلد کی درمیانی سیاہ رنگت',
    '👂🏿' => 'کان: جلد کی سیاہ رنگت',
    '🦻🏻' => 'آلہ سماعت کے ساتھ کان: جلد کی ہلکی رنگت',
    '🦻🏼' => 'آلہ سماعت کے ساتھ کان: جلد کی درمیانی -ہلکی رنگت',
    '🦻🏽' => 'آلہ سماعت کے ساتھ کان: جلد کی درمیانی رنگت',
    '🦻🏾' => 'آلہ سماعت کے ساتھ کان: جلد کی درمیانی سیاہ رنگت',
    '🦻🏿' => 'آلہ سماعت کے ساتھ کان: جلد کی سیاہ رنگت',
    '👃🏻' => 'ناک: جلد کی ہلکی رنگت',
    '👃🏼' => 'ناک: جلد کی درمیانی -ہلکی رنگت',
    '👃🏽' => 'ناک: جلد کی درمیانی رنگت',
    '👃🏾' => 'ناک: جلد کی درمیانی سیاہ رنگت',
    '👃🏿' => 'ناک: جلد کی سیاہ رنگت',
    '👶🏻' => 'طفل: جلد کی ہلکی رنگت',
    '👶🏼' => 'طفل: جلد کی درمیانی -ہلکی رنگت',
    '👶🏽' => 'طفل: جلد کی درمیانی رنگت',
    '👶🏾' => 'طفل: جلد کی درمیانی سیاہ رنگت',
    '👶🏿' => 'طفل: جلد کی سیاہ رنگت',
    '🧒🏻' => 'بچہ: جلد کی ہلکی رنگت',
    '🧒🏼' => 'بچہ: جلد کی درمیانی -ہلکی رنگت',
    '🧒🏽' => 'بچہ: جلد کی درمیانی رنگت',
    '🧒🏾' => 'بچہ: جلد کی درمیانی سیاہ رنگت',
    '🧒🏿' => 'بچہ: جلد کی سیاہ رنگت',
    '👦🏻' => 'لڑکا: جلد کی ہلکی رنگت',
    '👦🏼' => 'لڑکا: جلد کی درمیانی -ہلکی رنگت',
    '👦🏽' => 'لڑکا: جلد کی درمیانی رنگت',
    '👦🏾' => 'لڑکا: جلد کی درمیانی سیاہ رنگت',
    '👦🏿' => 'لڑکا: جلد کی سیاہ رنگت',
    '👧🏻' => 'لڑکی: جلد کی ہلکی رنگت',
    '👧🏼' => 'لڑکی: جلد کی درمیانی -ہلکی رنگت',
    '👧🏽' => 'لڑکی: جلد کی درمیانی رنگت',
    '👧🏾' => 'لڑکی: جلد کی درمیانی سیاہ رنگت',
    '👧🏿' => 'لڑکی: جلد کی سیاہ رنگت',
    '🧑🏻' => 'شخص: جلد کی ہلکی رنگت',
    '🧑🏼' => 'شخص: جلد کی درمیانی -ہلکی رنگت',
    '🧑🏽' => 'شخص: جلد کی درمیانی رنگت',
    '🧑🏾' => 'شخص: جلد کی درمیانی سیاہ رنگت',
    '🧑🏿' => 'شخص: جلد کی سیاہ رنگت',
    '👱🏻' => 'سنہرے بالوں والا شخص: جلد کی ہلکی رنگت',
    '👱🏼' => 'سنہرے بالوں والا شخص: جلد کی درمیانی -ہلکی رنگت',
    '👱🏽' => 'سنہرے بالوں والا شخص: جلد کی درمیانی رنگت',
    '👱🏾' => 'سنہرے بالوں والا شخص: جلد کی درمیانی سیاہ رنگت',
    '👱🏿' => 'سنہرے بالوں والا شخص: جلد کی سیاہ رنگت',
    '👨🏻' => 'مرد: جلد کی ہلکی رنگت',
    '👨🏼' => 'مرد: جلد کی درمیانی -ہلکی رنگت',
    '👨🏽' => 'مرد: جلد کی درمیانی رنگت',
    '👨🏾' => 'مرد: جلد کی درمیانی سیاہ رنگت',
    '👨🏿' => 'مرد: جلد کی سیاہ رنگت',
    '🧔🏻' => 'داڑھی والا شخص: جلد کی ہلکی رنگت',
    '🧔🏼' => 'داڑھی والا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🧔🏽' => 'داڑھی والا شخص: جلد کی درمیانی رنگت',
    '🧔🏾' => 'داڑھی والا شخص: جلد کی درمیانی سیاہ رنگت',
    '🧔🏿' => 'داڑھی والا شخص: جلد کی سیاہ رنگت',
    '👩🏻' => 'عورت: جلد کی ہلکی رنگت',
    '👩🏼' => 'عورت: جلد کی درمیانی -ہلکی رنگت',
    '👩🏽' => 'عورت: جلد کی درمیانی رنگت',
    '👩🏾' => 'عورت: جلد کی درمیانی سیاہ رنگت',
    '👩🏿' => 'عورت: جلد کی سیاہ رنگت',
    '🧓🏻' => 'بوڑھا بالغ: جلد کی ہلکی رنگت',
    '🧓🏼' => 'بوڑھا بالغ: جلد کی درمیانی -ہلکی رنگت',
    '🧓🏽' => 'بوڑھا بالغ: جلد کی درمیانی رنگت',
    '🧓🏾' => 'بوڑھا بالغ: جلد کی درمیانی سیاہ رنگت',
    '🧓🏿' => 'بوڑھا بالغ: جلد کی سیاہ رنگت',
    '👴🏻' => 'بوڑھا آدمی: جلد کی ہلکی رنگت',
    '👴🏼' => 'بوڑھا آدمی: جلد کی درمیانی -ہلکی رنگت',
    '👴🏽' => 'بوڑھا آدمی: جلد کی درمیانی رنگت',
    '👴🏾' => 'بوڑھا آدمی: جلد کی درمیانی سیاہ رنگت',
    '👴🏿' => 'بوڑھا آدمی: جلد کی سیاہ رنگت',
    '👵🏻' => 'بوڑھی عورت: جلد کی ہلکی رنگت',
    '👵🏼' => 'بوڑھی عورت: جلد کی درمیانی -ہلکی رنگت',
    '👵🏽' => 'بوڑھی عورت: جلد کی درمیانی رنگت',
    '👵🏾' => 'بوڑھی عورت: جلد کی درمیانی سیاہ رنگت',
    '👵🏿' => 'بوڑھی عورت: جلد کی سیاہ رنگت',
    '🙍🏻' => 'تیوری چڑھائے شخص: جلد کی ہلکی رنگت',
    '🙍🏼' => 'تیوری چڑھائے شخص: جلد کی درمیانی -ہلکی رنگت',
    '🙍🏽' => 'تیوری چڑھائے شخص: جلد کی درمیانی رنگت',
    '🙍🏾' => 'تیوری چڑھائے شخص: جلد کی درمیانی سیاہ رنگت',
    '🙍🏿' => 'تیوری چڑھائے شخص: جلد کی سیاہ رنگت',
    '🙎🏻' => 'نا شاد شخص: جلد کی ہلکی رنگت',
    '🙎🏼' => 'نا شاد شخص: جلد کی درمیانی -ہلکی رنگت',
    '🙎🏽' => 'نا شاد شخص: جلد کی درمیانی رنگت',
    '🙎🏾' => 'نا شاد شخص: جلد کی درمیانی سیاہ رنگت',
    '🙎🏿' => 'نا شاد شخص: جلد کی سیاہ رنگت',
    '🙅🏻' => 'نہیں کا اشارہ: جلد کی ہلکی رنگت',
    '🙅🏼' => 'نہیں کا اشارہ: جلد کی درمیانی -ہلکی رنگت',
    '🙅🏽' => 'نہیں کا اشارہ: جلد کی درمیانی رنگت',
    '🙅🏾' => 'نہیں کا اشارہ: جلد کی درمیانی سیاہ رنگت',
    '🙅🏿' => 'نہیں کا اشارہ: جلد کی سیاہ رنگت',
    '🙆🏻' => 'ہاں کا اشارہ: جلد کی ہلکی رنگت',
    '🙆🏼' => 'ہاں کا اشارہ: جلد کی درمیانی -ہلکی رنگت',
    '🙆🏽' => 'ہاں کا اشارہ: جلد کی درمیانی رنگت',
    '🙆🏾' => 'ہاں کا اشارہ: جلد کی درمیانی سیاہ رنگت',
    '🙆🏿' => 'ہاں کا اشارہ: جلد کی سیاہ رنگت',
    '💁🏻' => 'معلوماتی ڈیسک والا بندہ: جلد کی ہلکی رنگت',
    '💁🏼' => 'معلوماتی ڈیسک والا بندہ: جلد کی درمیانی -ہلکی رنگت',
    '💁🏽' => 'معلوماتی ڈیسک والا بندہ: جلد کی درمیانی رنگت',
    '💁🏾' => 'معلوماتی ڈیسک والا بندہ: جلد کی درمیانی سیاہ رنگت',
    '💁🏿' => 'معلوماتی ڈیسک والا بندہ: جلد کی سیاہ رنگت',
    '🙋🏻' => 'ہاتھ بلند کیے خوش شخص: جلد کی ہلکی رنگت',
    '🙋🏼' => 'ہاتھ بلند کیے خوش شخص: جلد کی درمیانی -ہلکی رنگت',
    '🙋🏽' => 'ہاتھ بلند کیے خوش شخص: جلد کی درمیانی رنگت',
    '🙋🏾' => 'ہاتھ بلند کیے خوش شخص: جلد کی درمیانی سیاہ رنگت',
    '🙋🏿' => 'ہاتھ بلند کیے خوش شخص: جلد کی سیاہ رنگت',
    '🧏🏻' => 'سماعت سے محروم شخص: جلد کی ہلکی رنگت',
    '🧏🏼' => 'سماعت سے محروم شخص: جلد کی درمیانی -ہلکی رنگت',
    '🧏🏽' => 'سماعت سے محروم شخص: جلد کی درمیانی رنگت',
    '🧏🏾' => 'سماعت سے محروم شخص: جلد کی درمیانی سیاہ رنگت',
    '🧏🏿' => 'سماعت سے محروم شخص: جلد کی سیاہ رنگت',
    '🙇🏻' => 'جھکے ہوئے شخص: جلد کی ہلکی رنگت',
    '🙇🏼' => 'جھکے ہوئے شخص: جلد کی درمیانی -ہلکی رنگت',
    '🙇🏽' => 'جھکے ہوئے شخص: جلد کی درمیانی رنگت',
    '🙇🏾' => 'جھکے ہوئے شخص: جلد کی درمیانی سیاہ رنگت',
    '🙇🏿' => 'جھکے ہوئے شخص: جلد کی سیاہ رنگت',
    '🤦🏻' => 'پیشانی پر ہاتھ: جلد کی ہلکی رنگت',
    '🤦🏼' => 'پیشانی پر ہاتھ: جلد کی درمیانی -ہلکی رنگت',
    '🤦🏽' => 'پیشانی پر ہاتھ: جلد کی درمیانی رنگت',
    '🤦🏾' => 'پیشانی پر ہاتھ: جلد کی درمیانی سیاہ رنگت',
    '🤦🏿' => 'پیشانی پر ہاتھ: جلد کی سیاہ رنگت',
    '🤷🏻' => 'کندھے اچکانا: جلد کی ہلکی رنگت',
    '🤷🏼' => 'کندھے اچکانا: جلد کی درمیانی -ہلکی رنگت',
    '🤷🏽' => 'کندھے اچکانا: جلد کی درمیانی رنگت',
    '🤷🏾' => 'کندھے اچکانا: جلد کی درمیانی سیاہ رنگت',
    '🤷🏿' => 'کندھے اچکانا: جلد کی سیاہ رنگت',
    '👮🏻' => 'پولیس آفیسر: جلد کی ہلکی رنگت',
    '👮🏼' => 'پولیس آفیسر: جلد کی درمیانی -ہلکی رنگت',
    '👮🏽' => 'پولیس آفیسر: جلد کی درمیانی رنگت',
    '👮🏾' => 'پولیس آفیسر: جلد کی درمیانی سیاہ رنگت',
    '👮🏿' => 'پولیس آفیسر: جلد کی سیاہ رنگت',
    '🕵🏻' => 'جاسوس: جلد کی ہلکی رنگت',
    '🕵🏼' => 'جاسوس: جلد کی درمیانی -ہلکی رنگت',
    '🕵🏽' => 'جاسوس: جلد کی درمیانی رنگت',
    '🕵🏾' => 'جاسوس: جلد کی درمیانی سیاہ رنگت',
    '🕵🏿' => 'جاسوس: جلد کی سیاہ رنگت',
    '💂🏻' => 'گارڈ: جلد کی ہلکی رنگت',
    '💂🏼' => 'گارڈ: جلد کی درمیانی -ہلکی رنگت',
    '💂🏽' => 'گارڈ: جلد کی درمیانی رنگت',
    '💂🏾' => 'گارڈ: جلد کی درمیانی سیاہ رنگت',
    '💂🏿' => 'گارڈ: جلد کی سیاہ رنگت',
    '🥷🏻' => 'ننجا: جلد کی ہلکی رنگت',
    '🥷🏼' => 'ننجا: جلد کی درمیانی -ہلکی رنگت',
    '🥷🏽' => 'ننجا: جلد کی درمیانی رنگت',
    '🥷🏾' => 'ننجا: جلد کی درمیانی سیاہ رنگت',
    '🥷🏿' => 'ننجا: جلد کی سیاہ رنگت',
    '👷🏻' => 'بند آنکھوں والا مستری: جلد کی ہلکی رنگت',
    '👷🏼' => 'بند آنکھوں والا مستری: جلد کی درمیانی -ہلکی رنگت',
    '👷🏽' => 'بند آنکھوں والا مستری: جلد کی درمیانی رنگت',
    '👷🏾' => 'بند آنکھوں والا مستری: جلد کی درمیانی سیاہ رنگت',
    '👷🏿' => 'بند آنکھوں والا مستری: جلد کی سیاہ رنگت',
    '🫅🏻' => 'تاج پہنے شخص: جلد کی ہلکی رنگت',
    '🫅🏼' => 'تاج پہنے شخص: جلد کی درمیانی -ہلکی رنگت',
    '🫅🏽' => 'تاج پہنے شخص: جلد کی درمیانی رنگت',
    '🫅🏾' => 'تاج پہنے شخص: جلد کی درمیانی سیاہ رنگت',
    '🫅🏿' => 'تاج پہنے شخص: جلد کی سیاہ رنگت',
    '🤴🏻' => 'شہزادہ: جلد کی ہلکی رنگت',
    '🤴🏼' => 'شہزادہ: جلد کی درمیانی -ہلکی رنگت',
    '🤴🏽' => 'شہزادہ: جلد کی درمیانی رنگت',
    '🤴🏾' => 'شہزادہ: جلد کی درمیانی سیاہ رنگت',
    '🤴🏿' => 'شہزادہ: جلد کی سیاہ رنگت',
    '👸🏻' => 'شہزادی: جلد کی ہلکی رنگت',
    '👸🏼' => 'شہزادی: جلد کی درمیانی -ہلکی رنگت',
    '👸🏽' => 'شہزادی: جلد کی درمیانی رنگت',
    '👸🏾' => 'شہزادی: جلد کی درمیانی سیاہ رنگت',
    '👸🏿' => 'شہزادی: جلد کی سیاہ رنگت',
    '👳🏻' => 'پگڑی والا شخص: جلد کی ہلکی رنگت',
    '👳🏼' => 'پگڑی والا شخص: جلد کی درمیانی -ہلکی رنگت',
    '👳🏽' => 'پگڑی والا شخص: جلد کی درمیانی رنگت',
    '👳🏾' => 'پگڑی والا شخص: جلد کی درمیانی سیاہ رنگت',
    '👳🏿' => 'پگڑی والا شخص: جلد کی سیاہ رنگت',
    '👲🏻' => 'چینی ٹوپی والا شخص: جلد کی ہلکی رنگت',
    '👲🏼' => 'چینی ٹوپی والا شخص: جلد کی درمیانی -ہلکی رنگت',
    '👲🏽' => 'چینی ٹوپی والا شخص: جلد کی درمیانی رنگت',
    '👲🏾' => 'چینی ٹوپی والا شخص: جلد کی درمیانی سیاہ رنگت',
    '👲🏿' => 'چینی ٹوپی والا شخص: جلد کی سیاہ رنگت',
    '🧕🏻' => 'سر پر اسکارف پہنے عورت: جلد کی ہلکی رنگت',
    '🧕🏼' => 'سر پر اسکارف پہنے عورت: جلد کی درمیانی -ہلکی رنگت',
    '🧕🏽' => 'سر پر اسکارف پہنے عورت: جلد کی درمیانی رنگت',
    '🧕🏾' => 'سر پر اسکارف پہنے عورت: جلد کی درمیانی سیاہ رنگت',
    '🧕🏿' => 'سر پر اسکارف پہنے عورت: جلد کی سیاہ رنگت',
    '🤵🏻' => 'سوٹڈ بوٹڈ شخص: جلد کی ہلکی رنگت',
    '🤵🏼' => 'سوٹڈ بوٹڈ شخص: جلد کی درمیانی -ہلکی رنگت',
    '🤵🏽' => 'سوٹڈ بوٹڈ شخص: جلد کی درمیانی رنگت',
    '🤵🏾' => 'سوٹڈ بوٹڈ شخص: جلد کی درمیانی سیاہ رنگت',
    '🤵🏿' => 'سوٹڈ بوٹڈ شخص: جلد کی سیاہ رنگت',
    '👰🏻' => 'نقاب پوش شخص: جلد کی ہلکی رنگت',
    '👰🏼' => 'نقاب پوش شخص: جلد کی درمیانی -ہلکی رنگت',
    '👰🏽' => 'نقاب پوش شخص: جلد کی درمیانی رنگت',
    '👰🏾' => 'نقاب پوش شخص: جلد کی درمیانی سیاہ رنگت',
    '👰🏿' => 'نقاب پوش شخص: جلد کی سیاہ رنگت',
    '🤰🏻' => 'حاملہ عورت: جلد کی ہلکی رنگت',
    '🤰🏼' => 'حاملہ عورت: جلد کی درمیانی -ہلکی رنگت',
    '🤰🏽' => 'حاملہ عورت: جلد کی درمیانی رنگت',
    '🤰🏾' => 'حاملہ عورت: جلد کی درمیانی سیاہ رنگت',
    '🤰🏿' => 'حاملہ عورت: جلد کی سیاہ رنگت',
    '🫃🏻' => 'حاملہ مرد: جلد کی ہلکی رنگت',
    '🫃🏼' => 'حاملہ مرد: جلد کی درمیانی -ہلکی رنگت',
    '🫃🏽' => 'حاملہ مرد: جلد کی درمیانی رنگت',
    '🫃🏾' => 'حاملہ مرد: جلد کی درمیانی سیاہ رنگت',
    '🫃🏿' => 'حاملہ مرد: جلد کی سیاہ رنگت',
    '🫄🏻' => 'حاملہ شخص: جلد کی ہلکی رنگت',
    '🫄🏼' => 'حاملہ شخص: جلد کی درمیانی -ہلکی رنگت',
    '🫄🏽' => 'حاملہ شخص: جلد کی درمیانی رنگت',
    '🫄🏾' => 'حاملہ شخص: جلد کی درمیانی سیاہ رنگت',
    '🫄🏿' => 'حاملہ شخص: جلد کی سیاہ رنگت',
    '🤱🏻' => 'دودھ پلانا: جلد کی ہلکی رنگت',
    '🤱🏼' => 'دودھ پلانا: جلد کی درمیانی -ہلکی رنگت',
    '🤱🏽' => 'دودھ پلانا: جلد کی درمیانی رنگت',
    '🤱🏾' => 'دودھ پلانا: جلد کی درمیانی سیاہ رنگت',
    '🤱🏿' => 'دودھ پلانا: جلد کی سیاہ رنگت',
    '👼🏻' => 'بے بی فرشتہ: جلد کی ہلکی رنگت',
    '👼🏼' => 'بے بی فرشتہ: جلد کی درمیانی -ہلکی رنگت',
    '👼🏽' => 'بے بی فرشتہ: جلد کی درمیانی رنگت',
    '👼🏾' => 'بے بی فرشتہ: جلد کی درمیانی سیاہ رنگت',
    '👼🏿' => 'بے بی فرشتہ: جلد کی سیاہ رنگت',
    '🎅🏻' => 'سانتا کلاز: جلد کی ہلکی رنگت',
    '🎅🏼' => 'سانتا کلاز: جلد کی درمیانی -ہلکی رنگت',
    '🎅🏽' => 'سانتا کلاز: جلد کی درمیانی رنگت',
    '🎅🏾' => 'سانتا کلاز: جلد کی درمیانی سیاہ رنگت',
    '🎅🏿' => 'سانتا کلاز: جلد کی سیاہ رنگت',
    '🤶🏻' => 'مدر کرسمس: جلد کی ہلکی رنگت',
    '🤶🏼' => 'مدر کرسمس: جلد کی درمیانی -ہلکی رنگت',
    '🤶🏽' => 'مدر کرسمس: جلد کی درمیانی رنگت',
    '🤶🏾' => 'مدر کرسمس: جلد کی درمیانی سیاہ رنگت',
    '🤶🏿' => 'مدر کرسمس: جلد کی سیاہ رنگت',
    '🦸🏻' => 'سپر ہیرو: جلد کی ہلکی رنگت',
    '🦸🏼' => 'سپر ہیرو: جلد کی درمیانی -ہلکی رنگت',
    '🦸🏽' => 'سپر ہیرو: جلد کی درمیانی رنگت',
    '🦸🏾' => 'سپر ہیرو: جلد کی درمیانی سیاہ رنگت',
    '🦸🏿' => 'سپر ہیرو: جلد کی سیاہ رنگت',
    '🦹🏻' => 'سپر ولن: جلد کی ہلکی رنگت',
    '🦹🏼' => 'سپر ولن: جلد کی درمیانی -ہلکی رنگت',
    '🦹🏽' => 'سپر ولن: جلد کی درمیانی رنگت',
    '🦹🏾' => 'سپر ولن: جلد کی درمیانی سیاہ رنگت',
    '🦹🏿' => 'سپر ولن: جلد کی سیاہ رنگت',
    '🧙🏻' => 'جادوگر: جلد کی ہلکی رنگت',
    '🧙🏼' => 'جادوگر: جلد کی درمیانی -ہلکی رنگت',
    '🧙🏽' => 'جادوگر: جلد کی درمیانی رنگت',
    '🧙🏾' => 'جادوگر: جلد کی درمیانی سیاہ رنگت',
    '🧙🏿' => 'جادوگر: جلد کی سیاہ رنگت',
    '🧚🏻' => 'پری: جلد کی ہلکی رنگت',
    '🧚🏼' => 'پری: جلد کی درمیانی -ہلکی رنگت',
    '🧚🏽' => 'پری: جلد کی درمیانی رنگت',
    '🧚🏾' => 'پری: جلد کی درمیانی سیاہ رنگت',
    '🧚🏿' => 'پری: جلد کی سیاہ رنگت',
    '🧛🏻' => 'خون خوار: جلد کی ہلکی رنگت',
    '🧛🏼' => 'خون خوار: جلد کی درمیانی -ہلکی رنگت',
    '🧛🏽' => 'خون خوار: جلد کی درمیانی رنگت',
    '🧛🏾' => 'خون خوار: جلد کی درمیانی سیاہ رنگت',
    '🧛🏿' => 'خون خوار: جلد کی سیاہ رنگت',
    '🧜🏻' => 'پانی کے جاندار: جلد کی ہلکی رنگت',
    '🧜🏼' => 'پانی کے جاندار: جلد کی درمیانی -ہلکی رنگت',
    '🧜🏽' => 'پانی کے جاندار: جلد کی درمیانی رنگت',
    '🧜🏾' => 'پانی کے جاندار: جلد کی درمیانی سیاہ رنگت',
    '🧜🏿' => 'پانی کے جاندار: جلد کی سیاہ رنگت',
    '🧝🏻' => 'پریت: جلد کی ہلکی رنگت',
    '🧝🏼' => 'پریت: جلد کی درمیانی -ہلکی رنگت',
    '🧝🏽' => 'پریت: جلد کی درمیانی رنگت',
    '🧝🏾' => 'پریت: جلد کی درمیانی سیاہ رنگت',
    '🧝🏿' => 'پریت: جلد کی سیاہ رنگت',
    '💆🏻' => 'چہرے کا مساج: جلد کی ہلکی رنگت',
    '💆🏼' => 'چہرے کا مساج: جلد کی درمیانی -ہلکی رنگت',
    '💆🏽' => 'چہرے کا مساج: جلد کی درمیانی رنگت',
    '💆🏾' => 'چہرے کا مساج: جلد کی درمیانی سیاہ رنگت',
    '💆🏿' => 'چہرے کا مساج: جلد کی سیاہ رنگت',
    '💇🏻' => 'حجامت: جلد کی ہلکی رنگت',
    '💇🏼' => 'حجامت: جلد کی درمیانی -ہلکی رنگت',
    '💇🏽' => 'حجامت: جلد کی درمیانی رنگت',
    '💇🏾' => 'حجامت: جلد کی درمیانی سیاہ رنگت',
    '💇🏿' => 'حجامت: جلد کی سیاہ رنگت',
    '🚶🏻' => 'پیدل چلتا شخص: جلد کی ہلکی رنگت',
    '🚶🏼' => 'پیدل چلتا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🚶🏽' => 'پیدل چلتا شخص: جلد کی درمیانی رنگت',
    '🚶🏾' => 'پیدل چلتا شخص: جلد کی درمیانی سیاہ رنگت',
    '🚶🏿' => 'پیدل چلتا شخص: جلد کی سیاہ رنگت',
    '🧍🏻' => 'کھڑا ہوا شخص: جلد کی ہلکی رنگت',
    '🧍🏼' => 'کھڑا ہوا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🧍🏽' => 'کھڑا ہوا شخص: جلد کی درمیانی رنگت',
    '🧍🏾' => 'کھڑا ہوا شخص: جلد کی درمیانی سیاہ رنگت',
    '🧍🏿' => 'کھڑا ہوا شخص: جلد کی سیاہ رنگت',
    '🧎🏻' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی ہلکی رنگت',
    '🧎🏼' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🧎🏽' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی درمیانی رنگت',
    '🧎🏾' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی درمیانی سیاہ رنگت',
    '🧎🏿' => 'گھٹنوں کے بل بیٹھا شخص: جلد کی سیاہ رنگت',
    '🏃🏻' => 'دوڑتا ہوا شخص: جلد کی ہلکی رنگت',
    '🏃🏼' => 'دوڑتا ہوا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🏃🏽' => 'دوڑتا ہوا شخص: جلد کی درمیانی رنگت',
    '🏃🏾' => 'دوڑتا ہوا شخص: جلد کی درمیانی سیاہ رنگت',
    '🏃🏿' => 'دوڑتا ہوا شخص: جلد کی سیاہ رنگت',
    '💃🏻' => 'ڈانسر: جلد کی ہلکی رنگت',
    '💃🏼' => 'ڈانسر: جلد کی درمیانی -ہلکی رنگت',
    '💃🏽' => 'ڈانسر: جلد کی درمیانی رنگت',
    '💃🏾' => 'ڈانسر: جلد کی درمیانی سیاہ رنگت',
    '💃🏿' => 'ڈانسر: جلد کی سیاہ رنگت',
    '🕺🏻' => 'ناچتا ہوا شخص: جلد کی ہلکی رنگت',
    '🕺🏼' => 'ناچتا ہوا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🕺🏽' => 'ناچتا ہوا شخص: جلد کی درمیانی رنگت',
    '🕺🏾' => 'ناچتا ہوا شخص: جلد کی درمیانی سیاہ رنگت',
    '🕺🏿' => 'ناچتا ہوا شخص: جلد کی سیاہ رنگت',
    '🕴🏻' => 'بزنس سوٹ پہنے ہوا میں معلق شخص: جلد کی ہلکی رنگت',
    '🕴🏼' => 'بزنس سوٹ پہنے ہوا میں معلق شخص: جلد کی درمیانی -ہلکی رنگت',
    '🕴🏽' => 'بزنس سوٹ پہنے ہوا میں معلق شخص: جلد کی درمیانی رنگت',
    '🕴🏾' => 'بزنس سوٹ پہنے ہوا میں معلق شخص: جلد کی درمیانی سیاہ رنگت',
    '🕴🏿' => 'بزنس سوٹ پہنے ہوا میں معلق شخص: جلد کی سیاہ رنگت',
    '👯🏻' => 'پارٹی کرتی عورتیں: جلد کی ہلکی رنگت',
    '👯🏼' => 'پارٹی کرتی عورتیں: جلد کی درمیانی -ہلکی رنگت',
    '👯🏽' => 'پارٹی کرتی عورتیں: جلد کی درمیانی رنگت',
    '👯🏾' => 'پارٹی کرتی عورتیں: جلد کی درمیانی سیاہ رنگت',
    '👯🏿' => 'پارٹی کرتی عورتیں: جلد کی سیاہ رنگت',
    '🧖🏻' => 'ایک شخص بھاپ سے بھرے کمرے میں: جلد کی ہلکی رنگت',
    '🧖🏼' => 'ایک شخص بھاپ سے بھرے کمرے میں: جلد کی درمیانی -ہلکی رنگت',
    '🧖🏽' => 'ایک شخص بھاپ سے بھرے کمرے میں: جلد کی درمیانی رنگت',
    '🧖🏾' => 'ایک شخص بھاپ سے بھرے کمرے میں: جلد کی درمیانی سیاہ رنگت',
    '🧖🏿' => 'ایک شخص بھاپ سے بھرے کمرے میں: جلد کی سیاہ رنگت',
    '🧗🏻' => 'چڑھتا ہوا شخص: جلد کی ہلکی رنگت',
    '🧗🏼' => 'چڑھتا ہوا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🧗🏽' => 'چڑھتا ہوا شخص: جلد کی درمیانی رنگت',
    '🧗🏾' => 'چڑھتا ہوا شخص: جلد کی درمیانی سیاہ رنگت',
    '🧗🏿' => 'چڑھتا ہوا شخص: جلد کی سیاہ رنگت',
    '🏇🏻' => 'گھڑ دوڑ: جلد کی ہلکی رنگت',
    '🏇🏼' => 'گھڑ دوڑ: جلد کی درمیانی -ہلکی رنگت',
    '🏇🏽' => 'گھڑ دوڑ: جلد کی درمیانی رنگت',
    '🏇🏾' => 'گھڑ دوڑ: جلد کی درمیانی سیاہ رنگت',
    '🏇🏿' => 'گھڑ دوڑ: جلد کی سیاہ رنگت',
    '🏂🏻' => 'سنو بورڈر: جلد کی ہلکی رنگت',
    '🏂🏼' => 'سنو بورڈر: جلد کی درمیانی -ہلکی رنگت',
    '🏂🏽' => 'سنو بورڈر: جلد کی درمیانی رنگت',
    '🏂🏾' => 'سنو بورڈر: جلد کی درمیانی سیاہ رنگت',
    '🏂🏿' => 'سنو بورڈر: جلد کی سیاہ رنگت',
    '🏌🏻' => 'گالف کا کھلاڑی: جلد کی ہلکی رنگت',
    '🏌🏼' => 'گالف کا کھلاڑی: جلد کی درمیانی -ہلکی رنگت',
    '🏌🏽' => 'گالف کا کھلاڑی: جلد کی درمیانی رنگت',
    '🏌🏾' => 'گالف کا کھلاڑی: جلد کی درمیانی سیاہ رنگت',
    '🏌🏿' => 'گالف کا کھلاڑی: جلد کی سیاہ رنگت',
    '🏄🏻' => 'سرفر: جلد کی ہلکی رنگت',
    '🏄🏼' => 'سرفر: جلد کی درمیانی -ہلکی رنگت',
    '🏄🏽' => 'سرفر: جلد کی درمیانی رنگت',
    '🏄🏾' => 'سرفر: جلد کی درمیانی سیاہ رنگت',
    '🏄🏿' => 'سرفر: جلد کی سیاہ رنگت',
    '🚣🏻' => 'چپوؤں والی کشتی: جلد کی ہلکی رنگت',
    '🚣🏼' => 'چپوؤں والی کشتی: جلد کی درمیانی -ہلکی رنگت',
    '🚣🏽' => 'چپوؤں والی کشتی: جلد کی درمیانی رنگت',
    '🚣🏾' => 'چپوؤں والی کشتی: جلد کی درمیانی سیاہ رنگت',
    '🚣🏿' => 'چپوؤں والی کشتی: جلد کی سیاہ رنگت',
    '🏊🏻' => 'تیراک: جلد کی ہلکی رنگت',
    '🏊🏼' => 'تیراک: جلد کی درمیانی -ہلکی رنگت',
    '🏊🏽' => 'تیراک: جلد کی درمیانی رنگت',
    '🏊🏾' => 'تیراک: جلد کی درمیانی سیاہ رنگت',
    '🏊🏿' => 'تیراک: جلد کی سیاہ رنگت',
    '⛹🏻' => 'بال سے کھیلتا شخص: جلد کی ہلکی رنگت',
    '⛹🏼' => 'بال سے کھیلتا شخص: جلد کی درمیانی -ہلکی رنگت',
    '⛹🏽' => 'بال سے کھیلتا شخص: جلد کی درمیانی رنگت',
    '⛹🏾' => 'بال سے کھیلتا شخص: جلد کی درمیانی سیاہ رنگت',
    '⛹🏿' => 'بال سے کھیلتا شخص: جلد کی سیاہ رنگت',
    '🏋🏻' => 'وزن اٹھائے شخص: جلد کی ہلکی رنگت',
    '🏋🏼' => 'وزن اٹھائے شخص: جلد کی درمیانی -ہلکی رنگت',
    '🏋🏽' => 'وزن اٹھائے شخص: جلد کی درمیانی رنگت',
    '🏋🏾' => 'وزن اٹھائے شخص: جلد کی درمیانی سیاہ رنگت',
    '🏋🏿' => 'وزن اٹھائے شخص: جلد کی سیاہ رنگت',
    '🚴🏻' => 'سائیکل سوار: جلد کی ہلکی رنگت',
    '🚴🏼' => 'سائیکل سوار: جلد کی درمیانی -ہلکی رنگت',
    '🚴🏽' => 'سائیکل سوار: جلد کی درمیانی رنگت',
    '🚴🏾' => 'سائیکل سوار: جلد کی درمیانی سیاہ رنگت',
    '🚴🏿' => 'سائیکل سوار: جلد کی سیاہ رنگت',
    '🚵🏻' => 'ماؤنٹین بائیک: جلد کی ہلکی رنگت',
    '🚵🏼' => 'ماؤنٹین بائیک: جلد کی درمیانی -ہلکی رنگت',
    '🚵🏽' => 'ماؤنٹین بائیک: جلد کی درمیانی رنگت',
    '🚵🏾' => 'ماؤنٹین بائیک: جلد کی درمیانی سیاہ رنگت',
    '🚵🏿' => 'ماؤنٹین بائیک: جلد کی سیاہ رنگت',
    '🤸🏻' => 'قلابازی لگاتا شخص: جلد کی ہلکی رنگت',
    '🤸🏼' => 'قلابازی لگاتا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🤸🏽' => 'قلابازی لگاتا شخص: جلد کی درمیانی رنگت',
    '🤸🏾' => 'قلابازی لگاتا شخص: جلد کی درمیانی سیاہ رنگت',
    '🤸🏿' => 'قلابازی لگاتا شخص: جلد کی سیاہ رنگت',
    '🤼🏻' => 'پہلوان: جلد کی ہلکی رنگت',
    '🤼🏼' => 'پہلوان: جلد کی درمیانی -ہلکی رنگت',
    '🤼🏽' => 'پہلوان: جلد کی درمیانی رنگت',
    '🤼🏾' => 'پہلوان: جلد کی درمیانی سیاہ رنگت',
    '🤼🏿' => 'پہلوان: جلد کی سیاہ رنگت',
    '🤽🏻' => 'واٹر پولو: جلد کی ہلکی رنگت',
    '🤽🏼' => 'واٹر پولو: جلد کی درمیانی -ہلکی رنگت',
    '🤽🏽' => 'واٹر پولو: جلد کی درمیانی رنگت',
    '🤽🏾' => 'واٹر پولو: جلد کی درمیانی سیاہ رنگت',
    '🤽🏿' => 'واٹر پولو: جلد کی سیاہ رنگت',
    '🤾🏻' => 'ہینڈ بال: جلد کی ہلکی رنگت',
    '🤾🏼' => 'ہینڈ بال: جلد کی درمیانی -ہلکی رنگت',
    '🤾🏽' => 'ہینڈ بال: جلد کی درمیانی رنگت',
    '🤾🏾' => 'ہینڈ بال: جلد کی درمیانی سیاہ رنگت',
    '🤾🏿' => 'ہینڈ بال: جلد کی سیاہ رنگت',
    '🤹🏻' => 'شعبدہ بازی: جلد کی ہلکی رنگت',
    '🤹🏼' => 'شعبدہ بازی: جلد کی درمیانی -ہلکی رنگت',
    '🤹🏽' => 'شعبدہ بازی: جلد کی درمیانی رنگت',
    '🤹🏾' => 'شعبدہ بازی: جلد کی درمیانی سیاہ رنگت',
    '🤹🏿' => 'شعبدہ بازی: جلد کی سیاہ رنگت',
    '🧘🏻' => 'پالتی مار کر بیٹھا شخص: جلد کی ہلکی رنگت',
    '🧘🏼' => 'پالتی مار کر بیٹھا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🧘🏽' => 'پالتی مار کر بیٹھا شخص: جلد کی درمیانی رنگت',
    '🧘🏾' => 'پالتی مار کر بیٹھا شخص: جلد کی درمیانی سیاہ رنگت',
    '🧘🏿' => 'پالتی مار کر بیٹھا شخص: جلد کی سیاہ رنگت',
    '🛀🏻' => 'نہاتا ہوا شخص: جلد کی ہلکی رنگت',
    '🛀🏼' => 'نہاتا ہوا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🛀🏽' => 'نہاتا ہوا شخص: جلد کی درمیانی رنگت',
    '🛀🏾' => 'نہاتا ہوا شخص: جلد کی درمیانی سیاہ رنگت',
    '🛀🏿' => 'نہاتا ہوا شخص: جلد کی سیاہ رنگت',
    '🛌🏻' => 'بستر میں لیٹا شخص: جلد کی ہلکی رنگت',
    '🛌🏼' => 'بستر میں لیٹا شخص: جلد کی درمیانی -ہلکی رنگت',
    '🛌🏽' => 'بستر میں لیٹا شخص: جلد کی درمیانی رنگت',
    '🛌🏾' => 'بستر میں لیٹا شخص: جلد کی درمیانی سیاہ رنگت',
    '🛌🏿' => 'بستر میں لیٹا شخص: جلد کی سیاہ رنگت',
    '👭🏻' => 'ہاتھ تھامے دو عورتیں: جلد کی ہلکی رنگت',
    '👭🏼' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی -ہلکی رنگت',
    '👭🏽' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی رنگت',
    '👭🏾' => 'ہاتھ تھامے دو عورتیں: جلد کی درمیانی سیاہ رنگت',
    '👭🏿' => 'ہاتھ تھامے دو عورتیں: جلد کی سیاہ رنگت',
    '👫🏻' => 'ہاتھ تھامے مرد اور عورت: جلد کی ہلکی رنگت',
    '👫🏼' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی -ہلکی رنگت',
    '👫🏽' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی رنگت',
    '👫🏾' => 'ہاتھ تھامے مرد اور عورت: جلد کی درمیانی سیاہ رنگت',
    '👫🏿' => 'ہاتھ تھامے مرد اور عورت: جلد کی سیاہ رنگت',
    '👬🏻' => 'ہاتھ تھامے دو مرد: جلد کی ہلکی رنگت',
    '👬🏼' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی -ہلکی رنگت',
    '👬🏽' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی رنگت',
    '👬🏾' => 'ہاتھ تھامے دو مرد: جلد کی درمیانی سیاہ رنگت',
    '👬🏿' => 'ہاتھ تھامے دو مرد: جلد کی سیاہ رنگت',
    '💏🏻' => 'بوسہ: جلد کی ہلکی رنگت',
    '💏🏼' => 'بوسہ: جلد کی درمیانی -ہلکی رنگت',
    '💏🏽' => 'بوسہ: جلد کی درمیانی رنگت',
    '💏🏾' => 'بوسہ: جلد کی درمیانی سیاہ رنگت',
    '💏🏿' => 'بوسہ: جلد کی سیاہ رنگت',
    '💑🏻' => 'دل اور جوڑا: جلد کی ہلکی رنگت',
    '💑🏼' => 'دل اور جوڑا: جلد کی درمیانی -ہلکی رنگت',
    '💑🏽' => 'دل اور جوڑا: جلد کی درمیانی رنگت',
    '💑🏾' => 'دل اور جوڑا: جلد کی درمیانی سیاہ رنگت',
    '💑🏿' => 'دل اور جوڑا: جلد کی سیاہ رنگت',
    '🇦🇨' => 'پرچم: اسینشن آئلینڈ',
    '🇦🇩' => 'پرچم: انڈورا',
    '🇦🇪' => 'پرچم: متحدہ عرب امارات',
    '🇦🇫' => 'پرچم: افغانستان',
    '🇦🇬' => 'پرچم: انٹیگوا اور باربودا',
    '🇦🇮' => 'پرچم: انگوئیلا',
    '🇦🇱' => 'پرچم: البانیہ',
    '🇦🇲' => 'پرچم: آرمینیا',
    '🇦🇴' => 'پرچم: انگولا',
    '🇦🇶' => 'پرچم: انٹارکٹیکا',
    '🇦🇷' => 'پرچم: ارجنٹینا',
    '🇦🇸' => 'پرچم: امریکی ساموآ',
    '🇦🇹' => 'پرچم: آسٹریا',
    '🇦🇺' => 'پرچم: آسٹریلیا',
    '🇦🇼' => 'پرچم: اروبا',
    '🇦🇽' => 'پرچم: آلینڈ آئلینڈز',
    '🇦🇿' => 'پرچم: آذربائیجان',
    '🇧🇦' => 'پرچم: بوسنیا اور ہرزیگووینا',
    '🇧🇧' => 'پرچم: بارباڈوس',
    '🇧🇩' => 'پرچم: بنگلہ دیش',
    '🇧🇪' => 'پرچم: بیلجیم',
    '🇧🇫' => 'پرچم: برکینا فاسو',
    '🇧🇬' => 'پرچم: بلغاریہ',
    '🇧🇭' => 'پرچم: بحرین',
    '🇧🇮' => 'پرچم: برونڈی',
    '🇧🇯' => 'پرچم: بینن',
    '🇧🇱' => 'پرچم: سینٹ برتھلیمی',
    '🇧🇲' => 'پرچم: برمودا',
    '🇧🇳' => 'پرچم: برونائی',
    '🇧🇴' => 'پرچم: بولیویا',
    '🇧🇶' => 'پرچم: کریبیائی نیدرلینڈز',
    '🇧🇷' => 'پرچم: برازیل',
    '🇧🇸' => 'پرچم: بہاماس',
    '🇧🇹' => 'پرچم: بھوٹان',
    '🇧🇻' => 'پرچم: بؤویٹ آئلینڈ',
    '🇧🇼' => 'پرچم: بوتسوانا',
    '🇧🇾' => 'پرچم: بیلاروس',
    '🇧🇿' => 'پرچم: بیلائز',
    '🇨🇦' => 'پرچم: کینیڈا',
    '🇨🇨' => 'پرچم: کوکوس (کیلنگ) جزائر',
    '🇨🇩' => 'پرچم: کانگو - کنشاسا',
    '🇨🇫' => 'پرچم: وسط افریقی جمہوریہ',
    '🇨🇬' => 'پرچم: کانگو - برازاویلے',
    '🇨🇭' => 'پرچم: سوئٹزر لینڈ',
    '🇨🇮' => 'پرچم: کوٹ ڈی آئیوری',
    '🇨🇰' => 'پرچم: کک آئلینڈز',
    '🇨🇱' => 'پرچم: چلی',
    '🇨🇲' => 'پرچم: کیمرون',
    '🇨🇳' => 'پرچم: چین',
    '🇨🇴' => 'پرچم: کولمبیا',
    '🇨🇵' => 'پرچم: کلپرٹن آئلینڈ',
    '🇨🇶' => 'پرچم: سارک',
    '🇨🇷' => 'پرچم: کوسٹا ریکا',
    '🇨🇺' => 'پرچم: کیوبا',
    '🇨🇻' => 'پرچم: کیپ ورڈی',
    '🇨🇼' => 'پرچم: کیوراکاؤ',
    '🇨🇽' => 'پرچم: جزیرہ کرسمس',
    '🇨🇾' => 'پرچم: قبرص',
    '🇨🇿' => 'پرچم: چیکیا',
    '🇩🇪' => 'پرچم: جرمنی',
    '🇩🇬' => 'پرچم: ڈائجو گارسیا',
    '🇩🇯' => 'پرچم: جبوتی',
    '🇩🇰' => 'پرچم: ڈنمارک',
    '🇩🇲' => 'پرچم: ڈومنیکا',
    '🇩🇴' => 'پرچم: جمہوریہ ڈومينيکن',
    '🇩🇿' => 'پرچم: الجیریا',
    '🇪🇦' => 'پرچم: سیئوٹا اور میلیلا',
    '🇪🇨' => 'پرچم: ایکواڈور',
    '🇪🇪' => 'پرچم: اسٹونیا',
    '🇪🇬' => 'پرچم: مصر',
    '🇪🇭' => 'پرچم: مغربی صحارا',
    '🇪🇷' => 'پرچم: اریٹیریا',
    '🇪🇸' => 'پرچم: ہسپانیہ',
    '🇪🇹' => 'پرچم: ایتھوپیا',
    '🇪🇺' => 'پرچم: یوروپی یونین',
    '🇫🇮' => 'پرچم: فن لینڈ',
    '🇫🇯' => 'پرچم: فجی',
    '🇫🇰' => 'پرچم: فاکلینڈ جزائر',
    '🇫🇲' => 'پرچم: مائکرونیشیا',
    '🇫🇴' => 'پرچم: جزائر فارو',
    '🇫🇷' => 'پرچم: فرانس',
    '🇬🇦' => 'پرچم: گیبون',
    '🇬🇧' => 'پرچم: سلطنت متحدہ',
    '🇬🇩' => 'پرچم: گریناڈا',
    '🇬🇪' => 'پرچم: جارجیا',
    '🇬🇫' => 'پرچم: فرینچ گیانا',
    '🇬🇬' => 'پرچم: گوئرنسی',
    '🇬🇭' => 'پرچم: گھانا',
    '🇬🇮' => 'پرچم: جبل الطارق',
    '🇬🇱' => 'پرچم: گرین لینڈ',
    '🇬🇲' => 'پرچم: گیمبیا',
    '🇬🇳' => 'پرچم: گنی',
    '🇬🇵' => 'پرچم: گواڈیلوپ',
    '🇬🇶' => 'پرچم: استوائی گیانا',
    '🇬🇷' => 'پرچم: یونان',
    '🇬🇸' => 'پرچم: جنوبی جارجیا اور جنوبی سینڈوچ جزائر',
    '🇬🇹' => 'پرچم: گواٹے مالا',
    '🇬🇺' => 'پرچم: گوام',
    '🇬🇼' => 'پرچم: گنی بساؤ',
    '🇬🇾' => 'پرچم: گیانا',
    '🇭🇰' => 'پرچم: ہانگ کانگ SAR چین',
    '🇭🇲' => 'پرچم: ہیرڈ جزیرہ و میکڈولینڈ جزائر',
    '🇭🇳' => 'پرچم: ہونڈاروس',
    '🇭🇷' => 'پرچم: کروشیا',
    '🇭🇹' => 'پرچم: ہیٹی',
    '🇭🇺' => 'پرچم: ہنگری',
    '🇮🇨' => 'پرچم: کینری آئلینڈز',
    '🇮🇩' => 'پرچم: انڈونیشیا',
    '🇮🇪' => 'پرچم: آئرلینڈ',
    '🇮🇱' => 'پرچم: اسرائیل',
    '🇮🇲' => 'پرچم: آئل آف مین',
    '🇮🇳' => 'پرچم: بھارت',
    '🇮🇴' => 'پرچم: برطانوی بحر ہند کا علاقہ',
    '🇮🇶' => 'پرچم: عراق',
    '🇮🇷' => 'پرچم: ایران',
    '🇮🇸' => 'پرچم: آئس لینڈ',
    '🇮🇹' => 'پرچم: اٹلی',
    '🇯🇪' => 'پرچم: جرسی',
    '🇯🇲' => 'پرچم: جمائیکا',
    '🇯🇴' => 'پرچم: اردن',
    '🇯🇵' => 'پرچم: جاپان',
    '🇰🇪' => 'پرچم: کینیا',
    '🇰🇬' => 'پرچم: کرغزستان',
    '🇰🇭' => 'پرچم: کمبوڈیا',
    '🇰🇮' => 'پرچم: کریباتی',
    '🇰🇲' => 'پرچم: کوموروس',
    '🇰🇳' => 'پرچم: سینٹ کٹس اور نیویس',
    '🇰🇵' => 'پرچم: شمالی کوریا',
    '🇰🇷' => 'پرچم: جنوبی کوریا',
    '🇰🇼' => 'پرچم: کویت',
    '🇰🇾' => 'پرچم: کیمین آئلینڈز',
    '🇰🇿' => 'پرچم: قزاخستان',
    '🇱🇦' => 'پرچم: لاؤس',
    '🇱🇧' => 'پرچم: لبنان',
    '🇱🇨' => 'پرچم: سینٹ لوسیا',
    '🇱🇮' => 'پرچم: لیشٹنسٹائن',
    '🇱🇰' => 'پرچم: سری لنکا',
    '🇱🇷' => 'پرچم: لائبیریا',
    '🇱🇸' => 'پرچم: لیسوتھو',
    '🇱🇹' => 'پرچم: لیتھونیا',
    '🇱🇺' => 'پرچم: لکسمبرگ',
    '🇱🇻' => 'پرچم: لٹویا',
    '🇱🇾' => 'پرچم: لیبیا',
    '🇲🇦' => 'پرچم: مراکش',
    '🇲🇨' => 'پرچم: موناکو',
    '🇲🇩' => 'پرچم: مالدووا',
    '🇲🇪' => 'پرچم: مونٹے نیگرو',
    '🇲🇫' => 'پرچم: سینٹ مارٹن',
    '🇲🇬' => 'پرچم: مڈغاسکر',
    '🇲🇭' => 'پرچم: مارشل آئلینڈز',
    '🇲🇰' => 'پرچم: شمالی مقدونیہ',
    '🇲🇱' => 'پرچم: مالی',
    '🇲🇲' => 'پرچم: میانمار (برما)',
    '🇲🇳' => 'پرچم: منگولیا',
    '🇲🇴' => 'پرچم: مکاؤ SAR چین',
    '🇲🇵' => 'پرچم: شمالی ماریانا آئلینڈز',
    '🇲🇶' => 'پرچم: مارٹینک',
    '🇲🇷' => 'پرچم: موریطانیہ',
    '🇲🇸' => 'پرچم: مونٹسیراٹ',
    '🇲🇹' => 'پرچم: مالٹا',
    '🇲🇺' => 'پرچم: ماریشس',
    '🇲🇻' => 'پرچم: مالدیپ',
    '🇲🇼' => 'پرچم: ملاوی',
    '🇲🇽' => 'پرچم: میکسیکو',
    '🇲🇾' => 'پرچم: ملائشیا',
    '🇲🇿' => 'پرچم: موزمبیق',
    '🇳🇦' => 'پرچم: نامیبیا',
    '🇳🇨' => 'پرچم: نیو کلیڈونیا',
    '🇳🇪' => 'پرچم: نائجر',
    '🇳🇫' => 'پرچم: نارفوک آئلینڈ',
    '🇳🇬' => 'پرچم: نائجیریا',
    '🇳🇮' => 'پرچم: نکاراگووا',
    '🇳🇱' => 'پرچم: نیدر لینڈز',
    '🇳🇴' => 'پرچم: ناروے',
    '🇳🇵' => 'پرچم: نیپال',
    '🇳🇷' => 'پرچم: نؤرو',
    '🇳🇺' => 'پرچم: نیئو',
    '🇳🇿' => 'پرچم: نیوزی لینڈ',
    '🇴🇲' => 'پرچم: عمان',
    '🇵🇦' => 'پرچم: پانامہ',
    '🇵🇪' => 'پرچم: پیرو',
    '🇵🇫' => 'پرچم: فرانسیسی پولینیشیا',
    '🇵🇬' => 'پرچم: پاپوآ نیو گنی',
    '🇵🇭' => 'پرچم: فلپائن',
    '🇵🇰' => 'پرچم: پاکستان',
    '🇵🇱' => 'پرچم: پولینڈ',
    '🇵🇲' => 'پرچم: سینٹ پیئر اور میکلیئون',
    '🇵🇳' => 'پرچم: پٹکائرن جزائر',
    '🇵🇷' => 'پرچم: پیورٹو ریکو',
    '🇵🇸' => 'پرچم: فلسطینی خطے',
    '🇵🇹' => 'پرچم: پرتگال',
    '🇵🇼' => 'پرچم: پلاؤ',
    '🇵🇾' => 'پرچم: پیراگوئے',
    '🇶🇦' => 'پرچم: قطر',
    '🇷🇪' => 'پرچم: ری یونین',
    '🇷🇴' => 'پرچم: رومانیہ',
    '🇷🇸' => 'پرچم: سربیا',
    '🇷🇺' => 'پرچم: روس',
    '🇷🇼' => 'پرچم: روانڈا',
    '🇸🇦' => 'پرچم: سعودی عرب',
    '🇸🇧' => 'پرچم: سولومن آئلینڈز',
    '🇸🇨' => 'پرچم: سشلیز',
    '🇸🇩' => 'پرچم: سوڈان',
    '🇸🇪' => 'پرچم: سویڈن',
    '🇸🇬' => 'پرچم: سنگاپور',
    '🇸🇭' => 'پرچم: سینٹ ہیلینا',
    '🇸🇮' => 'پرچم: سلووینیا',
    '🇸🇯' => 'پرچم: سوالبرڈ اور جان ماین',
    '🇸🇰' => 'پرچم: سلوواکیہ',
    '🇸🇱' => 'پرچم: سیرالیون',
    '🇸🇲' => 'پرچم: سان مارینو',
    '🇸🇳' => 'پرچم: سینیگل',
    '🇸🇴' => 'پرچم: صومالیہ',
    '🇸🇷' => 'پرچم: سورینام',
    '🇸🇸' => 'پرچم: جنوبی سوڈان',
    '🇸🇹' => 'پرچم: ساؤ ٹومے اور پرنسپے',
    '🇸🇻' => 'پرچم: ال سلواڈور',
    '🇸🇽' => 'پرچم: سنٹ مارٹن',
    '🇸🇾' => 'پرچم: شام',
    '🇸🇿' => 'پرچم: سواتنی',
    '🇹🇦' => 'پرچم: ٹرسٹن ڈا کیونہا',
    '🇹🇨' => 'پرچم: ٹرکس اور کیکوس جزائر',
    '🇹🇩' => 'پرچم: چاڈ',
    '🇹🇫' => 'پرچم: فرانسیسی جنوبی خطے',
    '🇹🇬' => 'پرچم: ٹوگو',
    '🇹🇭' => 'پرچم: تھائی لینڈ',
    '🇹🇯' => 'پرچم: تاجکستان',
    '🇹🇰' => 'پرچم: ٹوکیلاؤ',
    '🇹🇱' => 'پرچم: تیمور لیسٹ',
    '🇹🇲' => 'پرچم: ترکمانستان',
    '🇹🇳' => 'پرچم: تونس',
    '🇹🇴' => 'پرچم: ٹونگا',
    '🇹🇷' => 'پرچم: ترکیہ',
    '🇹🇹' => 'پرچم: ترینیداد اور ٹوباگو',
    '🇹🇻' => 'پرچم: ٹووالو',
    '🇹🇼' => 'پرچم: تائیوان',
    '🇹🇿' => 'پرچم: تنزانیہ',
    '🇺🇦' => 'پرچم: یوکرین',
    '🇺🇬' => 'پرچم: یوگنڈا',
    '🇺🇲' => 'پرچم: امریکہ سے باہر کے چھوٹے جزائز',
    '🇺🇳' => 'پرچم: اقوام متحدہ',
    '🇺🇸' => 'پرچم: ریاست ہائے متحدہ امریکہ',
    '🇺🇾' => 'پرچم: یوروگوئے',
    '🇺🇿' => 'پرچم: ازبکستان',
    '🇻🇦' => 'پرچم: ویٹیکن سٹی',
    '🇻🇨' => 'پرچم: سینٹ ونسنٹ اور گرینیڈائنز',
    '🇻🇪' => 'پرچم: وینزوئیلا',
    '🇻🇬' => 'پرچم: برٹش ورجن آئلینڈز',
    '🇻🇮' => 'پرچم: امریکی ورجن آئلینڈز',
    '🇻🇳' => 'پرچم: ویتنام',
    '🇻🇺' => 'پرچم: وینوآٹو',
    '🇼🇫' => 'پرچم: ویلیز اور فیوٹیونا',
    '🇼🇸' => 'پرچم: ساموآ',
    '🇽🇰' => 'پرچم: کوسووو',
    '🇾🇪' => 'پرچم: یمن',
    '🇾🇹' => 'پرچم: مایوٹ',
    '🇿🇦' => 'پرچم: جنوبی افریقہ',
    '🇿🇲' => 'پرچم: زامبیا',
    '🇿🇼' => 'پرچم: زمبابوے',
    '🔟' => 'کی کیپ: 10',
    '🏻' => 'جلد کی ہلکی رنگت',
    '🏼' => 'جلد کی درمیانی -ہلکی رنگت',
    '🏽' => 'جلد کی درمیانی رنگت',
    '🏾' => 'جلد کی درمیانی سیاہ رنگت',
    '🏿' => 'جلد کی سیاہ رنگت',
    '😀' => 'کھل کے ہنستا چہرہ',
    '😃' => 'بڑی آنکھوں والا کھلے منہ والا مسکراتا چہرہ',
    '😄' => 'کھلے منہ اور مسکراتی آنکھوں والا مسکراتا چہرہ',
    '😁' => 'مسکراتی آنکھیں لیے ہنستا چہرہ',
    '😆' => 'کھلے منہ اور سختی سے بند آنکھوں والا مسکراتا چہرہ',
    '😅' => 'کھلے منہ اور ٹھنڈے پسینے والا مسکراتا چہرہ',
    '🤣' => 'ہنستے ہنستے لوٹ پوٹ ہونا',
    '😂' => 'خوشی کے آنسوؤں والا چہرہ',
    '🙂' => 'مدھم مسکراہٹ والا چہرہ',
    '🙃' => 'الٹا چہرہ',
    '🫠' => 'پگھلتا چہرہ',
    '😉' => 'آنکھ مارتا چہرہ',
    '😊' => 'مسکراتی آنکھوں والا مسکراتا چہرہ',
    '😇' => 'ہالہ لیے مسکراتا چہرہ',
    '🥰' => 'دلوں کے ساتھ مسکراتا چہرہ',
    '😍' => 'دل کی شکل کی آنکھوں والا مسکراتا چہرہ',
    '🤩' => 'ستارہ زدہ',
    '😘' => 'بوسہ اچھالتا چہرہ',
    '😗' => 'بوسہ لیتا چہرہ',
    '☺' => 'مسکراتا چہرہ',
    '😚' => 'بند آنکھوں کے ساتھ بوسہ لیتا چہرہ',
    '😙' => 'مسکراتی آنکھوں کے ساتھ بوسہ لیتا چہرہ',
    '🥲' => 'آنسو کے ساتھ مسکراتا چہرہ',
    '😋' => 'مزیدار کھانے کا ذائقہ دینے والا چہرہ',
    '😛' => 'زبان نکالے چہرہ',
    '😜' => 'زبان نکالے اور آنکھ مارتا چہرہ',
    '🤪' => 'پاگل پن والا چہرہ',
    '😝' => 'زبان نکالے اور سختی سے بند آنکھوں والا چہرہ',
    '🤑' => 'ڈالر کی زبان والا چہرہ',
    '🤗' => 'گلے ملتا چہرہ',
    '🤭' => 'منہ پر ہاتھ رکھا ہوا چہرہ',
    '🫢' => 'کھلی آنکھیں اور منہ پر ہاتھ رکھے ہوئے چہرہ',
    '🫣' => 'جھانکتی آنکھ والا چہرہ',
    '🤫' => 'خاموش رہنے کا اشارہ کرنے والہ چہرہ',
    '🤔' => 'سوچتا چہرہ',
    '🫡' => 'سلام کرتا ہوا چہرہ',
    '🤐' => 'منہ سیے ہوئے چہرہ',
    '🤨' => 'اٹھی ہوئی بھویں والا چہرہ',
    '😐' => 'غیر جانبدار چہرہ',
    '😑' => 'اظہار سے عاری چہرہ',
    '😶' => 'بغیر منہ والا چہرہ',
    '🫥' => 'نقطے دار لائن والا چہرہ',
    '😏' => 'طنزیہ مسکراہٹ والا چہرہ',
    '😒' => 'اداس چہرہ',
    '🙄' => 'گھومتی آنکھوں والا چہرہ',
    '😬' => 'مضحکہ خیز چہرہ',
    '🤥' => 'جھوٹ بولتا چہرہ',
    '🫨' => 'لرزتا ہوا چہرہ',
    '😌' => 'پُر سکون چہرہ',
    '😔' => 'سوچ میں ڈوبا چہرہ',
    '😪' => 'خوابیدہ چہرہ',
    '🤤' => 'رال ٹپکاتا چہرہ',
    '😴' => 'سوتا ہوا چہرہ',
    '🫩' => 'آنکھوں کے گرد حلقوں والا چہرہ',
    '😷' => 'طبی ماسک والا چہرہ',
    '🤒' => 'تھرمامیٹر لیے چہرہ',
    '🤕' => 'سر پر پٹی باندھے چہرہ',
    '🤢' => 'متلی کی کیفیت والا چہرہ',
    '🤮' => 'قے کرتا چہرہ',
    '🤧' => 'چھینکیں مارتا چہرہ',
    '🥵' => 'سرخ چہرہ',
    '🥶' => 'سرد چہرہ',
    '🥴' => 'اُلجھن کا شکار شہرہ',
    '😵' => 'چکراتا چہرہ',
    '🤯' => 'سر پھٹنا',
    '🤠' => 'کاؤ بوائے ہیٹ کے ساتھ چہرہ',
    '🥳' => 'پارٹی سے لطف اندوز ہوتا چہرہ',
    '🥸' => 'بہروپ چہرہ',
    '😎' => 'دھوپ کا چشمہ لگائے مسکراتا چہرہ',
    '🤓' => 'بیوقوفانہ چہرہ',
    '🧐' => 'ایک چشمہ پہنا ہوا چہرہ',
    '😕' => 'الجھن زدہ چہرہ',
    '🫤' => 'ترچھے منہ والا چہرہ',
    '😟' => 'پریشان چہرہ',
    '🙁' => 'ہلکا سا تیوری زدہ چہرہ',
    '☹' => 'تیوری زدہ چہرہ',
    '😮' => 'کھلے منہ والا چہرہ',
    '😯' => 'شدید حیرت زدہ چہرہ',
    '😲' => 'حیرت زدہ چہرہ',
    '😳' => 'شرمندگی سے سرخ چہرہ',
    '🫪' => 'بگڑا ہوا چہرہ',
    '🥺' => 'ملتجی چہرہ',
    '🥹' => 'آنسو روکے ہوئے چہرہ',
    '😦' => 'منہ کھولے تیوری چڑھاتا چہرہ',
    '😧' => 'تکلیف زدہ چہرہ',
    '😨' => 'خوفزدہ چہرہ',
    '😰' => 'کھلے منہ اور ٹھنڈے پسینے والا چہرہ',
    '😥' => 'مایوس لیکن پر سکون چہرہ',
    '😢' => 'روتا ہوا چہرہ',
    '😭' => 'زار و قطار روتا چہرہ',
    '😱' => 'خوف سے چلاتا چہرہ',
    '😖' => 'بے ترتیب چہرہ',
    '😣' => 'پُرعزم چہرہ',
    '😞' => 'مایوس چہرہ',
    '😓' => 'ٹھنڈے پسینے والا چہرہ',
    '😩' => 'اکتایا ہوا چہرہ',
    '😫' => 'تھکا ہوا چہرہ',
    '🥱' => 'جمائی لیتا چہرہ',
    '😤' => 'ناک سے دھواں نکالتا چہرہ',
    '😡' => 'نا شاد چہرہ',
    '😠' => 'غصے والا چہرہ',
    '🤬' => 'منہ پر علامات والا چہرہ',
    '😈' => 'شیطانی مسکراہٹ والا چہرہ',
    '👿' => 'شریر شیطان',
    '💀' => 'کھوپڑی',
    '☠' => 'کراس شدہ ہڈیوں کے ساتھ کھوپڑی',
    '💩' => 'گندگی کا ڈھیر',
    '🤡' => 'جوکر چہرہ',
    '👹' => 'شیطانی جن',
    '👺' => 'لمبی ناک اور مونچھوں والا دیو',
    '👻' => 'بھوت',
    '👽' => 'خلائی مخلوق',
    '👾' => 'خلائی دیو',
    '🤖' => 'روبوٹ',
    '😺' => 'کھلے منہ کے ساتھ مسکراتی بلی کا چہرہ',
    '😸' => 'مسکراتی آنکھوں والی کھل کے ہنستی بلی کا چہرہ',
    '😹' => 'خوشی کے آنسو لیے بلی کا چہرہ',
    '😻' => 'دل کی شکل والی آنکھوں کے ساتھ مسکراتی بلی کا چہرہ',
    '😼' => 'بلی کا طنزیہ مسکراہٹ والا چہرہ',
    '😽' => 'بند آنکھوں کے ساتھ بوسہ لیتا بلی کا چہرہ',
    '🙀' => 'تھکی ہوئی بلی',
    '😿' => 'روتی ہوئی بلی',
    '😾' => 'ناشاد بلی',
    '🙈' => 'ہاتھ سے آنکھیں چھپائے بندر',
    '🙉' => 'کانوں کو ہاتھ سے چھپائے بندر',
    '🙊' => 'منہ کو ہاتھوں سے بند کیے بندر',
    '💌' => 'محبت بھرا خط',
    '💘' => 'تیر پیوست ہوا دل',
    '💝' => 'ربن باندھے دل',
    '💖' => 'چمکتا دل',
    '💗' => 'بڑھتا ہوا دل',
    '💓' => 'دھڑکتا دل',
    '💞' => 'گھومتے دل',
    '💕' => 'دو دل',
    '💟' => 'دل کی ڈیکوریشن',
    '❣' => 'دلی اظہار',
    '💔' => 'ٹوٹا ہوا دل',
    '❤' => 'سرخ دل',
    '🩷' => 'گلابی دل',
    '🧡' => 'نارنجی دل',
    '💛' => 'پیلا دل',
    '💚' => 'سبز دل',
    '💙' => 'نیلا دل',
    '🩵' => 'ہلکا نیلا دل',
    '💜' => 'ارغوانی دل',
    '🤎' => 'بھورا دل',
    '🖤' => 'کالا دل',
    '🩶' => 'خاکستری دل',
    '🤍' => 'سفید دل',
    '💋' => 'بوسے کا نشان',
    '💯' => 'سو پوائنٹس',
    '💢' => 'غصے کی علامت',
    '🫯' => 'فائٹ کلاؤڈ',
    '💥' => 'تصادم',
    '💫' => 'سر چکرانا',
    '💦' => 'پسینے کے قطرے',
    '💨' => 'تیزی سے دوڑنا',
    '🕳' => 'سوراخ',
    '💬' => 'گفتگو غبارہ',
    '🗨' => 'گفتگو غبارہ بائیں',
    '🗯' => 'غصہ غبارہ دائیں',
    '💭' => 'سوچ غبارہ',
    '💤' => 'زززززز',
    '👋' => 'ہاتھ لہرانا',
    '🤚' => 'کھڑے ہاتھ کی پشت',
    '🖐' => 'پھیلی ہوئی انگلیوں کے ساتھ بلند ہاتھ',
    '✋' => 'بلند ہاتھ',
    '🖖' => 'وولکن سلیوٹ',
    '🫱' => 'دائیں اشارہ کرتا ہاتھ',
    '🫲' => 'بائیں اشارہ کرتا ہاتھ',
    '🫳' => 'ہتھیلی نیچے کیے ہاتھ',
    '🫴' => 'ہتھیلی اوپر کیے ہاتھ',
    '🫷' => 'بائیں طرف دھکیلتے ہوئے ہاتھ',
    '🫸' => 'دائیں طرف دھکیلتے ہوئے ہاتھ',
    '👌' => 'اوکے کا نشان بناتا ہاتھ',
    '🤌' => 'بھینچی ہوئی انگلیاں',
    '🤏' => 'چٹکی لیتا ہوا ہاتھ',
    '✌' => 'فتح کا نشان بناتا ہاتھ',
    '🤞' => 'کراس بناتی انگلیاں',
    '🫰' => 'شہادت کی انگلی اور انگوٹھہ کراس کیے ہوئے ہاتھ',
    '🤟' => 'آپ سے محبت کا اشارہ',
    '🤘' => 'ہاتھ سے سینگوں کا نشان',
    '🤙' => 'کال کرنے کا اشارہ',
    '👈' => 'بائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی',
    '👉' => 'دائیں اشارہ کرتی بیک ہینڈ شہادت کی انگلی',
    '👆' => 'اوپر اشارہ کرتی بیک ہینڈ شہادت کی انگلی',
    '🖕' => 'درمیانی انگلی',
    '👇' => 'نیچے اشارہ کرتی بیک ہینڈ شہادت کی انگلی',
    '☝' => 'اوپر اشارہ کرتی شہادت کی انگلی',
    '🫵' => 'دیکھنے والے کی طرف اشارہ کرتی انگلی',
    '👍' => 'سب اچھا کا نشان بناتا انگوٹھا',
    '👎' => 'اچھا نہ ہونے کا نشان بناتا انگوٹھا',
    '✊' => 'بلند مُٹھی',
    '👊' => 'آتا ہوا مُکا',
    '🤛' => 'بائیں سمت میں مکا',
    '🤜' => 'دائیں سمت میں مکا',
    '👏' => 'تالیاں بجاتے ہاتھ',
    '🙌' => 'ہاتھ بلند کیے ہوئے شخص',
    '🫶' => 'ہاتھوں سے بنا دل',
    '👐' => 'کھلے ہاتھ',
    '🤲' => 'ایک ساتھ ہتھیلیاں اٹھانا',
    '🤝' => 'ہاتھ ملانا',
    '🙏' => 'بندھے ہاتھ',
    '✍' => 'لکھتا ہوا ہاتھ',
    '💅' => 'نیل پالش',
    '🤳' => 'سیلفی',
    '💪' => 'بازوؤں کے ڈولے',
    '🦾' => 'مشینی بازو',
    '🦿' => 'مشینی ٹانگ',
    '🦵' => 'ٹانگ',
    '🦶' => 'پاؤں',
    '👂' => 'کان',
    '🦻' => 'آلہ سماعت کے ساتھ کان',
    '👃' => 'ناک',
    '🧠' => 'دماغ',
    '🫀' => 'دل کا عضو',
    '🫁' => 'پھیپھڑے',
    '🦷' => 'دانت',
    '🦴' => 'ہڈی',
    '👀' => 'آنکھیں',
    '👁' => 'آنکھ',
    '👅' => 'زبان',
    '👄' => 'منہ',
    '🫦' => 'کاٹتے ہونٹ',
    '👶' => 'طفل',
    '🧒' => 'بچہ',
    '👦' => 'لڑکا',
    '👧' => 'لڑکی',
    '🧑' => 'شخص',
    '👱' => 'سنہرے بالوں والا شخص',
    '👨' => 'مرد',
    '🧔' => 'داڑھی والا شخص',
    '👩' => 'عورت',
    '🧓' => 'بوڑھا بالغ',
    '👴' => 'بوڑھا آدمی',
    '👵' => 'بوڑھی عورت',
    '🙍' => 'تیوری چڑھائے شخص',
    '🙎' => 'نا شاد شخص',
    '🙅' => 'نہیں کا اشارہ',
    '🙆' => 'ہاں کا اشارہ',
    '💁' => 'معلوماتی ڈیسک والا بندہ',
    '🙋' => 'ہاتھ بلند کیے خوش شخص',
    '🧏' => 'سماعت سے محروم شخص',
    '🙇' => 'جھکے ہوئے شخص',
    '🤦' => 'پیشانی پر ہاتھ',
    '🤷' => 'کندھے اچکانا',
    '👮' => 'پولیس آفیسر',
    '🕵' => 'جاسوس',
    '💂' => 'گارڈ',
    '🥷' => 'ننجا',
    '👷' => 'بند آنکھوں والا مستری',
    '🫅' => 'تاج پہنے شخص',
    '🤴' => 'شہزادہ',
    '👸' => 'شہزادی',
    '👳' => 'پگڑی والا شخص',
    '👲' => 'چینی ٹوپی والا شخص',
    '🧕' => 'سر پر اسکارف پہنے عورت',
    '🤵' => 'سوٹڈ بوٹڈ شخص',
    '👰' => 'نقاب پوش شخص',
    '🤰' => 'حاملہ عورت',
    '🫃' => 'حاملہ مرد',
    '🫄' => 'حاملہ شخص',
    '🤱' => 'دودھ پلانا',
    '👼' => 'بے بی فرشتہ',
    '🎅' => 'سانتا کلاز',
    '🤶' => 'مدر کرسمس',
    '🦸' => 'سپر ہیرو',
    '🦹' => 'سپر ولن',
    '🧙' => 'جادوگر',
    '🧚' => 'پری',
    '🧛' => 'خون خوار',
    '🧜' => 'پانی کے جاندار',
    '🧝' => 'پریت',
    '🧞' => 'جن',
    '🧟' => 'زندہ مردہ',
    '🧌' => 'ٹرول',
    '🫈' => 'بالوں والی مخلوق',
    '💆' => 'چہرے کا مساج',
    '💇' => 'حجامت',
    '🚶' => 'پیدل چلتا شخص',
    '🧍' => 'کھڑا ہوا شخص',
    '🧎' => 'گھٹنوں کے بل بیٹھا شخص',
    '🏃' => 'دوڑتا ہوا شخص',
    '💃' => 'ڈانسر',
    '🕺' => 'ناچتا ہوا شخص',
    '🕴' => 'بزنس سوٹ پہنے ہوا میں معلق شخص',
    '👯' => 'پارٹی کرتی عورتیں',
    '🧖' => 'ایک شخص بھاپ سے بھرے کمرے میں',
    '🧗' => 'چڑھتا ہوا شخص',
    '🤺' => 'تلوار بازی',
    '🏇' => 'گھڑ دوڑ',
    '⛷' => 'اسکائر',
    '🏂' => 'سنو بورڈر',
    '🏌' => 'گالف کا کھلاڑی',
    '🏄' => 'سرفر',
    '🚣' => 'چپوؤں والی کشتی',
    '🏊' => 'تیراک',
    '⛹' => 'بال سے کھیلتا شخص',
    '🏋' => 'وزن اٹھائے شخص',
    '🚴' => 'سائیکل سوار',
    '🚵' => 'ماؤنٹین بائیک',
    '🤸' => 'قلابازی لگاتا شخص',
    '🤼' => 'پہلوان',
    '🤽' => 'واٹر پولو',
    '🤾' => 'ہینڈ بال',
    '🤹' => 'شعبدہ بازی',
    '🧘' => 'پالتی مار کر بیٹھا شخص',
    '🛀' => 'نہاتا ہوا شخص',
    '🛌' => 'بستر میں لیٹا شخص',
    '👭' => 'ہاتھ تھامے دو عورتیں',
    '👫' => 'ہاتھ تھامے مرد اور عورت',
    '👬' => 'ہاتھ تھامے دو مرد',
    '💏' => 'بوسہ',
    '💑' => 'دل اور جوڑا',
    '🗣' => 'بولتا سر',
    '👤' => 'آدمی کا خاکہ',
    '👥' => 'آدمیوں کے خاکے',
    '🫂' => 'گلے ملتے لوگ',
    '👪' => 'خاندان',
    '👣' => 'قدموں کے نشانات',
    '🫆' => 'انگلی کا نشان',
    '🦰' => 'سرخ بال',
    '🦱' => 'گھنگھریالے بال',
    '🦳' => 'سفید بال',
    '🦲' => 'گنجا',
    '🐵' => 'بندر کا چہرہ',
    '🐒' => 'بندر',
    '🦍' => 'گوریلا',
    '🦧' => 'انسان نما بندر',
    '🐶' => 'کتے کا چہرہ',
    '🐕' => 'کتا',
    '🦮' => 'رہنما کتا',
    '🐩' => 'پوڈل',
    '🐺' => 'بھیڑیا',
    '🦊' => 'لومڑی',
    '🦝' => 'راکون',
    '🐱' => 'بلی کا چہرہ',
    '🐈' => 'بلی',
    '🦁' => 'شیر کا چہرہ',
    '🐯' => 'ٹائیگر کا چہرہ',
    '🐅' => 'ٹائیگر',
    '🐆' => 'تیندوا',
    '🐴' => 'گھوڑے کا چہرہ',
    '🫎' => 'امریکی بارہ سنگا',
    '🫏' => 'گدھا',
    '🐎' => 'گھوڑا',
    '🦄' => 'یونیکارن',
    '🦓' => 'زیبرا',
    '🦌' => 'ہرن',
    '🦬' => 'ارنا بھینسا',
    '🐮' => 'گائے کا چہرہ',
    '🐂' => 'بیل',
    '🐃' => 'پانی کی بھینس',
    '🐄' => 'گائے',
    '🐷' => 'سور کا چہرہ',
    '🐖' => 'سور',
    '🐗' => 'جنگلی سور',
    '🐽' => 'سور کی ناک',
    '🐏' => 'نر بھیڑ',
    '🐑' => 'مادہ بھیڑ',
    '🐐' => 'بکری',
    '🐪' => 'اونٹ',
    '🐫' => 'دو کوہانوں والا اونٹ',
    '🦙' => 'لاما',
    '🦒' => 'زرافہ',
    '🐘' => 'ہاتھی',
    '🦣' => 'میمتھ',
    '🦏' => 'گینڈا',
    '🦛' => 'دریائی گھوڑا',
    '🐭' => 'چوہے کا چہرہ',
    '🐁' => 'سفید چوہا',
    '🐀' => 'چوہا',
    '🐹' => 'ہیمسٹر',
    '🐰' => 'خرگوش کا چہرہ',
    '🐇' => 'خرگوش',
    '🐿' => 'گلہری',
    '🦫' => 'سگ آبی',
    '🦔' => 'خار پشت',
    '🦇' => 'چمگادڑ',
    '🐻' => 'ریچھ کا چہرہ',
    '🐨' => 'کوآلا',
    '🐼' => 'پانڈا',
    '🦥' => 'سلاتھ',
    '🦦' => 'اود بلاؤ',
    '🦨' => 'سکنک',
    '🦘' => 'کینگرو',
    '🦡' => 'بجو',
    '🐾' => 'پنجوں کے نشانات',
    '🦃' => 'ٹرکی',
    '🐔' => 'چکن',
    '🐓' => 'مرغی',
    '🐣' => 'انڈے سے نکلتا چوزہ',
    '🐤' => 'بیبی چوزہ',
    '🐥' => 'سامنے دیکھتا بیبی چوزہ',
    '🐦' => 'پرنده',
    '🐧' => 'پنگوئن',
    '🕊' => 'فاختہ',
    '🦅' => 'عقاب',
    '🦆' => 'بطخ',
    '🦢' => 'راج ہنس',
    '🦉' => 'الو',
    '🦤' => 'ڈوڈو',
    '🪶' => 'پر',
    '🦩' => 'لم ٹنگو',
    '🦚' => 'مور',
    '🦜' => 'طوطا',
    '🪽' => 'پنکھ',
    '🪿' => 'ہنس',
    '🐸' => 'مینڈک',
    '🐊' => 'مگرمچھ',
    '🐢' => 'کچھوا',
    '🦎' => 'چھپکلی',
    '🐍' => 'سانپ',
    '🐲' => 'ڈریگن کا چہرہ',
    '🐉' => 'ڈریگن',
    '🦕' => 'سارپا',
    '🦖' => 'ٹی ریکس',
    '🐳' => 'پانی کا فوارہ نکالتی وہیل',
    '🐋' => 'وہیل',
    '🐬' => 'ڈولفن',
    '🫍' => 'اورکا',
    '🦭' => 'سیل',
    '🐟' => 'مچھلی',
    '🐠' => 'ٹراپکل مچھلی',
    '🐡' => 'بلو مچھلی',
    '🦈' => 'شارک',
    '🐙' => 'آکٹوپس',
    '🐚' => 'مرغولے دار شیل',
    '🪸' => 'مرجان',
    '🪼' => 'جیلی فش',
    '🦀' => 'کیکڑا',
    '🦞' => 'لوبسٹر',
    '🦐' => 'جھینگا',
    '🦑' => 'قیر ماہی',
    '🦪' => 'صدفہ',
    '🐌' => 'گھونگھا',
    '🦋' => 'تتلی',
    '🐛' => 'کن کھجورا',
    '🐜' => 'چیونٹی',
    '🐝' => 'شہد کی مکھی',
    '🪲' => 'بھونرا',
    '🐞' => 'کھٹمل',
    '🦗' => 'گرگٹ',
    '🪳' => 'لال بیگ',
    '🕷' => 'مکڑی',
    '🕸' => 'مکڑی کا جالا',
    '🦂' => 'بچھو',
    '🦟' => 'مچھر',
    '🪰' => 'مکھی',
    '🪱' => 'کیچوا',
    '🦠' => 'جرثومہ',
    '💐' => 'گلدستہ',
    '🌸' => 'چیری بلاسم',
    '💮' => 'سفید پھول',
    '🪷' => 'کنول',
    '🏵' => 'گلاب کا نقش',
    '🌹' => 'گلاب',
    '🥀' => 'مرجھایا ہوا پھول',
    '🌺' => 'گل خطمی',
    '🌻' => 'سورج مکھی کا پھول',
    '🌼' => 'شگوفہ',
    '🌷' => 'نرگس کا پھول',
    '🪻' => 'سنبل',
    '🌱' => 'ننھا پودا',
    '🪴' => 'گملے میں پودا',
    '🌲' => 'سدا بہار',
    '🌳' => 'پت جھڑ درخت',
    '🌴' => 'پام کا درخت',
    '🌵' => 'کیکٹس',
    '🌾' => 'چاولوں کا گٹھا',
    '🌿' => 'جڑی بوٹی',
    '☘' => 'تین پتی پھول',
    '🍀' => 'چار پتیوں والی گھاس',
    '🍁' => 'میپل کے پتے',
    '🍂' => 'گرے ہوئے پتے',
    '🍃' => 'ہوا میں پھڑپھڑاتے پتے',
    '🪹' => 'خالی گھونسلہ',
    '🪺' => 'انڈوں کے ساتھ گھونسلہ',
    '🍄' => 'کھمبی',
    '🪾' => 'بے برگ درخت',
    '🍇' => 'انگور',
    '🍈' => 'خربوزہ',
    '🍉' => 'تربوز',
    '🍊' => 'چھوٹا سنگترہ',
    '🍋' => 'لیموں',
    '🍌' => 'کیلا',
    '🍍' => 'انناس',
    '🥭' => 'آم',
    '🍎' => 'سرخ سیب',
    '🍏' => 'سبز سیب',
    '🍐' => 'ناشپاتی',
    '🍑' => 'آڑو',
    '🍒' => 'چیریاں',
    '🍓' => 'اسٹابری',
    '🫐' => 'بلو بیریز',
    '🥝' => 'کیوی فروٹ',
    '🍅' => 'ٹماٹر',
    '🫒' => 'زیتون',
    '🥥' => 'ناریل',
    '🥑' => 'ایوو کیڈو',
    '🍆' => 'بینگن',
    '🥔' => 'آلو',
    '🥕' => 'گاجر',
    '🌽' => 'چھلی',
    '🌶' => 'تیز مرچ',
    '🫑' => 'شملہ مرچ',
    '🥒' => 'کھیرا',
    '🥬' => 'ہرے پتوں والی سبزی',
    '🥦' => 'شاخ گوبھی',
    '🧄' => 'لہسن',
    '🧅' => 'پیاز',
    '🥜' => 'مونگ پھلی',
    '🫘' => 'پھلیاں',
    '🌰' => 'شاہ بلوط کا پھل',
    '🫚' => 'ادرک',
    '🫛' => 'مٹر کی پھلی',
    '🫜' => 'زیر زمین اگنے والی سبزی',
    '🍞' => 'ڈبل روٹی',
    '🥐' => 'ہلال نما روٹی',
    '🥖' => 'بیگٹ ڈبل روٹی',
    '🫓' => 'چپٹی روٹی',
    '🥨' => 'گانٹھ کی شکل کی بسکٹ',
    '🥯' => 'بیگل',
    '🥞' => 'پین کیکس',
    '🧇' => 'ویفل',
    '🧀' => 'پنیر کا ٹکڑا',
    '🍖' => 'ہڈی پر گوشت',
    '🍗' => 'چکن کی ٹانگ',
    '🥩' => 'گوشت کا ٹکڑا',
    '🥓' => 'سور کا نمکین گوشت',
    '🍔' => 'ہیم برگر',
    '🍟' => 'فرنچ فرائز',
    '🍕' => 'پزا',
    '🌭' => 'ہاٹ ڈاگ',
    '🥪' => 'سینڈوچ',
    '🌮' => 'مسالے بھرا پراٹھا',
    '🌯' => 'بریٹو',
    '🫔' => 'ٹمالے',
    '🥙' => 'بھری ہوئی چپاتی',
    '🧆' => 'فلافل',
    '🥚' => 'انڈا',
    '🍳' => 'پکتا ہوا انڈہ',
    '🥘' => 'کم گہرے پین میں خوراک',
    '🍲' => 'خوراک کا برتن',
    '🫕' => 'فانڈی',
    '🥣' => 'چمچ اور کٹورا',
    '🥗' => 'سبز سلاد',
    '🍿' => 'پاپ کارن',
    '🧈' => 'مکھن',
    '🧂' => 'نمک',
    '🥫' => 'ڈبہ بند کھانا',
    '🍱' => 'بنٹو باکس',
    '🍘' => 'چاولوں کے پاپڑ',
    '🍙' => 'چاولوں کے بالز',
    '🍚' => 'پکے ہوئے چاول',
    '🍛' => 'شوربے والے چاول',
    '🍜' => 'بھاپ نکالتا پیالہ',
    '🍝' => 'اسپیگٹی',
    '🍠' => 'بُھنا ہوا میٹھا آلو',
    '🍢' => 'اوڈن',
    '🍣' => 'سوشی',
    '🍤' => 'تلا ہوا شرمپ',
    '🍥' => 'بگولا بنا مچھلی کا کیک',
    '🥮' => 'چاند نما کیک',
    '🍡' => 'ڈینگو',
    '🥟' => 'پکوڑی',
    '🥠' => 'قسمت والا بسکٹ',
    '🥡' => 'پارسل کا ڈبہ',
    '🍦' => 'سافٹ آئس کریم',
    '🍧' => 'تراشیدہ برف',
    '🍨' => 'آئس کریم',
    '🍩' => 'ڈونٹ',
    '🍪' => 'کوکی',
    '🎂' => 'سالگرہ کا کیک',
    '🍰' => 'کیک کا ٹکڑا',
    '🧁' => 'کپ کیک',
    '🥧' => 'پائي',
    '🍫' => 'چاکلیٹ بار',
    '🍬' => 'کینڈی',
    '🍭' => 'لالی پاپ',
    '🍮' => 'کسٹرڈ',
    '🍯' => 'شہد کا برتن',
    '🍼' => 'فیڈر',
    '🥛' => 'دودھ کا گلاس',
    '☕' => 'گرم کافی',
    '🫖' => 'چائے کا برتن',
    '🍵' => 'ہینڈل کے بغیر چائے کا کپ',
    '🍶' => 'جاپانی شراب',
    '🍾' => 'کارک لگی بوتل',
    '🍷' => 'شراب کا گلاس',
    '🍸' => 'کاک ٹیل گلاس',
    '🍹' => 'ٹراپکل مشروب',
    '🍺' => 'بیئر کا مگ',
    '🍻' => 'ٹکراتے بیئر کے مگ',
    '🥂' => 'آپس میں ٹکراتے گلاس',
    '🥃' => 'وہسکی والا گلاس',
    '🫗' => 'مائع بہانا',
    '🥤' => 'کپ اور اسٹرا',
    '🧋' => 'بلبلوں والی چائے',
    '🧃' => 'مشروب کا ڈبہ',
    '🧉' => 'ہم پیالہ',
    '🧊' => 'برف کا ٹکڑا',
    '🥢' => 'چینی کانٹا',
    '🍽' => 'چھری کانٹے کے ساتھ پلیٹ',
    '🍴' => 'کانٹا اور چھری',
    '🥄' => 'چمچ',
    '🔪' => 'کچن کی چھری',
    '🫙' => 'مرتبان',
    '🏺' => 'ایمفورا',
    '🌍' => 'یورپ اور افریقہ کو دکھاتا گلوب',
    '🌎' => 'امریکہ کو دکھاتا گلوب',
    '🌏' => 'ایشیا اور آسٹریلیا کو دکھاتا گلوب',
    '🌐' => 'طول البلد کو دکھاتا گلوب',
    '🗺' => 'دنیا کا نقشہ',
    '🗾' => 'جاپان کا نقشہ',
    '🧭' => 'قُطب نُما',
    '🏔' => 'برف سے ڈھکا پہاڑ',
    '⛰' => 'پہاڑ',
    '🛘' => 'لینڈ سلائیڈ',
    '🌋' => 'آتش فشاں',
    '🗻' => 'ماؤنٹ فیوجی',
    '🏕' => 'پڑاؤ',
    '🏖' => 'ساحل اور چھتری',
    '🏜' => 'صحرا',
    '🏝' => 'صحرائی جزیرہ',
    '🏞' => 'نیشنل پارک',
    '🏟' => 'اسٹیڈیم',
    '🏛' => 'کلاسیکی عمارت',
    '🏗' => 'عمارت کی تعمیر',
    '🧱' => 'اینٹ',
    '🪨' => 'چٹان',
    '🪵' => 'لکڑی',
    '🛖' => 'جھونپڑی',
    '🏘' => 'مکانات',
    '🏚' => 'ویران گھر کی عمارت',
    '🏠' => 'مکان',
    '🏡' => 'باغ والا گھر',
    '🏢' => 'آفس کی عمارت',
    '🏣' => 'جاپانی پوسٹ آفس',
    '🏤' => 'پوسٹ آفس',
    '🏥' => 'اسپتال',
    '🏦' => 'بینک',
    '🏨' => 'ہوٹل',
    '🏩' => 'محبت کا ہوٹل',
    '🏪' => 'سہولت بخش اسٹور',
    '🏫' => 'اسکول',
    '🏬' => 'ڈپارٹمنٹ اسٹور',
    '🏭' => 'فیکٹری',
    '🏯' => 'جاپانی قلعہ',
    '🏰' => 'قلعہ',
    '💒' => 'شادی',
    '🗼' => 'ٹوکیو ٹاور',
    '🗽' => 'مجسمہ آزادی',
    '⛪' => 'گرجا گھر',
    '🕌' => 'مسجد',
    '🛕' => 'ہندو مندر',
    '🕍' => 'یہودیوں کی عبادت گاہ',
    '⛩' => 'شنٹو مزار',
    '🕋' => 'کعبہ',
    '⛲' => 'چشمہ',
    '⛺' => 'خیمہ',
    '🌁' => 'کُہر آلود',
    '🌃' => 'ستاروں بھری رات',
    '🏙' => 'اونچی عمارتیں',
    '🌄' => 'پہاڑوں پر طلوع آفتاب',
    '🌅' => 'طلوع آفتاب',
    '🌆' => 'شام کے وقت اونچی عمارتیں',
    '🌇' => 'غروبِ آفتاب',
    '🌉' => 'رات کے وقت پُل',
    '♨' => 'گرم ندی',
    '🎠' => 'گھومتے جھولے کا گھوڑا',
    '🛝' => 'کھیل کے میدان کی سلائیڈ',
    '🎡' => 'آسمانی جھولا',
    '🎢' => 'رولر کوسٹر',
    '💈' => 'حجام کا پول',
    '🎪' => 'سرکس کا ٹینٹ',
    '🚂' => 'ریل کا انجن',
    '🚃' => 'ریل گاڑی',
    '🚄' => 'تیز رفتار ٹرین',
    '🚅' => 'بلٹ کے ناک والی تیز رفتار ٹرین',
    '🚆' => 'ٹرین',
    '🚇' => 'میٹرو',
    '🚈' => 'لائٹ ریل',
    '🚉' => 'اسٹیشن',
    '🚊' => 'ٹرام',
    '🚝' => 'مونو ریل',
    '🚞' => 'ماؤنٹین ریلوے',
    '🚋' => 'ٹرام کار',
    '🚌' => 'بس',
    '🚍' => 'آتی ہوئی بس',
    '🚎' => 'ٹرالی بس',
    '🚐' => 'منی بس',
    '🚑' => 'ایمبولنس',
    '🚒' => 'فائر انجن',
    '🚓' => 'پولیس کار',
    '🚔' => 'آتی ہوئی پولیس کار',
    '🚕' => 'ٹیکسی',
    '🚖' => 'آتی ہوئی ٹیکسی',
    '🚗' => 'کار',
    '🚘' => 'آتی ہوئی کار',
    '🚙' => 'تفریحی گاڑی',
    '🛻' => 'پک اپ ٹرک',
    '🚚' => 'ڈلیوری ٹرک',
    '🚛' => 'جوڑ والی گاڑی',
    '🚜' => 'ٹریکٹر',
    '🏎' => 'ریس کی کار',
    '🏍' => 'موٹر سائیکل',
    '🛵' => 'موٹر والا سکوٹر',
    '🦽' => 'دستی وہیل چئیر',
    '🦼' => 'موٹر والی وہیل چئیر',
    '🛺' => 'آٹو رکشا',
    '🚲' => 'سائیکل',
    '🛴' => 'کک سکوٹر',
    '🛹' => 'اسکیٹنگ تختہ',
    '🛼' => 'رولر سکیٹ',
    '🚏' => 'بس اسٹاپ',
    '🛣' => 'موٹر وے',
    '🛤' => 'ریلوے ٹریک',
    '🛢' => 'تیل کا ڈرم',
    '⛽' => 'فیول پمپ',
    '🛞' => 'پہیہ',
    '🚨' => 'پولیس کار کی لائٹ',
    '🚥' => 'افقی ٹریفک لائٹ',
    '🚦' => 'عمودی ٹریفک لائٹ',
    '🛑' => 'رکنے کا نشان',
    '🚧' => 'تعمیر',
    '⚓' => 'اینکر',
    '🛟' => 'تیرنے والی گول ٹیوب',
    '⛵' => 'بادبانی کشتی',
    '🛶' => 'چھوٹی کشتی',
    '🚤' => 'انجن والی کشتی',
    '🛳' => 'مسافر بحری جہاز',
    '⛴' => 'فیری',
    '🛥' => 'موٹر بوٹ',
    '🚢' => 'بحری جہاز',
    '✈' => 'ہوائی جہاز',
    '🛩' => 'چھوٹا ہوائی جہاز',
    '🛫' => 'ہوائی جہاز کی روانگی',
    '🛬' => 'ہوائی جہاز کی آمد',
    '🪂' => 'پیراشوٹ',
    '💺' => 'سیٹ',
    '🚁' => 'ہیلی کاپٹر',
    '🚟' => 'معلق ریلوے',
    '🚠' => 'پہاڑی کیبل وے',
    '🚡' => 'ہوائی ٹرام وے',
    '🛰' => 'سیٹلائٹ',
    '🚀' => 'راکٹ',
    '🛸' => 'اڑن تشتری',
    '🛎' => 'بیل ہاپ بیل',
    '🧳' => 'سامان',
    '⌛' => 'ریت گھڑی',
    '⏳' => 'ریت گھڑی میں گرتی ہوئی ریت',
    '⌚' => 'گھڑی',
    '⏰' => 'الارم کلاک',
    '⏱' => 'اسٹاپ واچ',
    '⏲' => 'ٹائمر کلاک',
    '🕰' => 'مینٹل پیس کلاک',
    '🕛' => 'بارہ کا وقت',
    '🕧' => 'بارہ بج کر تیس منٹ',
    '🕐' => 'ایک بجے کا وقت',
    '🕜' => 'ایک بج کر تیس منٹ',
    '🕑' => 'دو بجے کا وقت',
    '🕝' => 'دو بج کر تیس منٹ',
    '🕒' => 'تین بجے کا وقت',
    '🕞' => 'تین بج کر تیس منٹ',
    '🕓' => 'چار بجے کا وقت',
    '🕟' => 'چار بج کر تیس منٹ',
    '🕔' => 'پانچ بجے کا وقت',
    '🕠' => 'پانچ بج کر تیس منٹ',
    '🕕' => 'چھ بجے کا وقت',
    '🕡' => 'چھ بج کر تیس منٹ',
    '🕖' => 'سات بجے کا وقت',
    '🕢' => 'سات بج کر تیس منٹ',
    '🕗' => 'آٹھ بجے کا وقت',
    '🕣' => 'آٹھ بج کر تیس منٹ',
    '🕘' => 'نو بجے کا وقت',
    '🕤' => 'نو بج کر تیس منٹ',
    '🕙' => 'دس بجے کا وقت',
    '🕥' => 'دس بج کر تیس منٹ',
    '🕚' => 'گیارہ بجے کا وقت',
    '🕦' => 'گیارہ بج کر تیس منٹ',
    '🌑' => 'نیا چاند',
    '🌒' => 'بڑھتا ہوا ہلال چاند',
    '🌓' => 'پہلے کوارٹر کا چاند',
    '🌔' => 'آدھے سے زیادہ بڑھتا ہوا چاند',
    '🌕' => 'مکمل چاند',
    '🌖' => 'گھٹتا ہوا آدھے سے زیادہ چاند',
    '🌗' => 'آخری کوارٹر کا چاند',
    '🌘' => 'گھٹتا ہوا ہلال چاند',
    '🌙' => 'ہلال چاند',
    '🌚' => 'نئے چاند کا چہرہ',
    '🌛' => 'پہلے کوارٹر کا چاند مع چہرہ',
    '🌜' => 'آخری کوارٹر کا چاند مع چہرہ',
    '🌡' => 'تھرمامیٹر',
    '☀' => 'سورج',
    '🌝' => 'چہرے والا پورا چاند',
    '🌞' => 'چہرے والا سورج',
    '🪐' => 'حلقہ دار سیارہ',
    '⭐' => 'ستارہ',
    '🌟' => 'چمکتا ستارہ',
    '🌠' => 'شہابِ ثاقب',
    '🌌' => 'کہکشاں',
    '☁' => 'بادل',
    '⛅' => 'بادلوں کے پیچھے چھپا سورج',
    '⛈' => 'گرج چمک اور بارش والے بادل',
    '🌤' => 'چھوٹے بادل کے پیچھے چھپا سورج',
    '🌥' => 'بڑے بادل کے پیچھے چھپا سورج',
    '🌦' => 'بارش کے بادل پیچھے چھپا سورج',
    '🌧' => 'بادل اور بارش',
    '🌨' => 'بادل اور برفباری',
    '🌩' => 'بادل اور گرج چمک',
    '🌪' => 'جھکڑ',
    '🌫' => 'کُہر',
    '🌬' => 'منہ سے ہوا نکالتا چہرہ',
    '🌀' => 'گرداب',
    '🌈' => 'قوس قزاح',
    '🌂' => 'بند چھتری',
    '☂' => 'چھتری',
    '☔' => 'بارش کے قطروں والی چھتری',
    '⛱' => 'زمین میں گڑی چھتری',
    '⚡' => 'ہائی وولٹیج',
    '❄' => 'برف کے گالے',
    '☃' => 'برف کا آدمی',
    '⛄' => 'برف کے بغیر برف کا آدمی',
    '☄' => 'قطبی ستارہ',
    '🔥' => 'آگ',
    '💧' => 'قطرہ',
    '🌊' => 'پانی کی لہر',
    '🎃' => 'کدو کی لالٹین',
    '🎄' => 'کرسمس کا درخت',
    '🎆' => 'آتشبازی',
    '🎇' => 'پھلجری',
    '🧨' => 'پٹاخہ',
    '✨' => 'چمکتے ستارے',
    '🎈' => 'غبارہ',
    '🎉' => 'پارٹی کے پٹاخے',
    '🎊' => 'رنگین کاغذ کے بالز',
    '🎋' => 'تنابتا درخت',
    '🎍' => 'پائن سے سجاوٹ',
    '🎎' => 'جاپانی گڑیاں',
    '🎏' => 'ہوائی جرابیں',
    '🎐' => 'ہوائی جھنکار',
    '🎑' => 'چاند کی رسم',
    '🧧' => 'سرخ لفافہ',
    '🎀' => 'ربن',
    '🎁' => 'کاغذ میں لپٹا تحفہ',
    '🎗' => 'یاددہانی کا ربن',
    '🎟' => 'داخلہ ٹکٹ',
    '🎫' => 'ٹکٹ',
    '🎖' => 'فوجی میڈل',
    '🏆' => 'ٹرافی',
    '🏅' => 'اسپورٹس میڈل',
    '🥇' => 'گولڈ میڈل',
    '🥈' => 'سلور میڈل',
    '🥉' => 'برونز میڈل',
    '⚽' => 'فٹبال',
    '⚾' => 'بیس بال',
    '🥎' => 'نرم گیند',
    '🏀' => 'باسکٹ بال',
    '🏐' => 'والی بال',
    '🏈' => 'امریکی فٹبال',
    '🏉' => 'رگبی فٹبال',
    '🎾' => 'ٹینس',
    '🥏' => 'اڑتی ہوئی ڈسک',
    '🎳' => 'باؤلنگ',
    '🏏' => 'کرکٹ',
    '🏑' => 'فیلڈ ہاکی',
    '🏒' => 'آئس ہاکی اسٹک اور پک',
    '🥍' => 'لکراس',
    '🏓' => 'ٹیبل ٹینس',
    '🏸' => 'بیڈمنٹن',
    '🥊' => 'باکسنگ کے دستانے',
    '🥋' => 'مارشل آرٹس کا یونیفارم',
    '🥅' => 'گول نیٹ',
    '⛳' => 'گڑھے میں جھنڈا',
    '⛸' => 'آئس اسٹیک',
    '🎣' => 'فشنگ پول',
    '🤿' => 'غوطہ خوری کا ماسک',
    '🎽' => 'دوڑنے کی شرٹ',
    '🎿' => 'اسکائیز',
    '🛷' => 'برف گاڑی',
    '🥌' => 'کرلنگ پتھر',
    '🎯' => 'براہ راست نشانہ',
    '🪀' => 'یو یو',
    '🪁' => 'پتنگ',
    '🔫' => 'پستول',
    '🎱' => 'بلیئرڈز',
    '🔮' => 'کرسٹل بال',
    '🪄' => 'جادوئی چھڑی',
    '🎮' => 'ویڈیو گیم',
    '🕹' => 'جوائے اسٹک',
    '🎰' => 'سلاٹ مشین',
    '🎲' => 'گیم ڈائی',
    '🧩' => 'جِگسا',
    '🧸' => 'کھلونا بھالو',
    '🪅' => 'پناٹا',
    '🪩' => 'آئینہ گیند',
    '🪆' => 'جادوئی گڑیاں',
    '♠' => 'حکم کا پتہ',
    '♥' => 'پان کا پتہ',
    '♦' => 'اینٹ کا پتہ',
    '♣' => 'چڑیا کا پتہ',
    '♟' => 'شطرنج کا پیادہ',
    '🃏' => 'جوکر',
    '🀄' => 'ماہجونگ ریڈ ڈریگن',
    '🎴' => 'جاپانی تاش کا کھیل',
    '🎭' => 'فنونِ لطیفہ',
    '🖼' => 'فریم میں جڑی تصویر',
    '🎨' => 'آرٹسٹ پیلٹ',
    '🧵' => 'دھاگہ',
    '🪡' => 'سلائی کی سوئی',
    '🧶' => 'اونی دھاگہ',
    '🪢' => 'گانٹھ',
    '👓' => 'چشمے',
    '🕶' => 'دھوپ چشمے',
    '🥽' => 'گاگل',
    '🥼' => 'لیب میں پہننے والا کوٹ',
    '🦺' => 'حفاظتی واسکٹ',
    '👔' => 'نیکٹائی',
    '👕' => 'ٹی شرٹ',
    '👖' => 'جینز',
    '🧣' => 'اسکارف',
    '🧤' => 'دستانے',
    '🧥' => 'کوٹ',
    '🧦' => 'جرابیں',
    '👗' => 'لباس',
    '👘' => 'خواتین کا روایتی جاپانی لباس',
    '🥻' => 'ساڑھی',
    '🩱' => 'وَن پیس تیراکی کا لباس',
    '🩲' => 'جانگھیا',
    '🩳' => 'نیکر',
    '👙' => 'بکنی',
    '👚' => 'عورتوں کے کپڑے',
    '🪭' => 'فولڈنگ دستی پنکھا',
    '👛' => 'پرس',
    '👜' => 'ہینڈ بیگ',
    '👝' => 'بیگ',
    '🛍' => 'شاپنگ بیگز',
    '🎒' => 'اسکول کا بستہ',
    '🩴' => 'تھونگ سینڈل',
    '👞' => 'مرد کا جوتا',
    '👟' => 'دوڑنے والا جوتا',
    '🥾' => 'ہائکنگ بوٹ',
    '🥿' => 'ہموار جوتا',
    '👠' => 'اونچی ایڑی والا جوتا',
    '👡' => 'عورت کی سینڈل',
    '🩰' => 'رقص کے جوتے',
    '👢' => 'عورت کا بوٹ',
    '🪮' => 'ہیئر پِک',
    '👑' => 'تاج',
    '👒' => 'عورت کا ہیٹ',
    '🎩' => 'اوپری ٹوپ',
    '🎓' => 'گریجوئیشن کیپ',
    '🧢' => 'بلڈ کیپ',
    '🪖' => 'ملٹری ہیلمٹ',
    '⛑' => 'سفید کراس والا ہیلمٹ',
    '📿' => 'تسبیح کے دانے',
    '💄' => 'لپ اسٹک',
    '💍' => 'انگوٹھی',
    '💎' => 'ہیرا',
    '🔇' => 'اسپیکر بند',
    '🔈' => 'دھیمی آواز نکالتے اسپیکر',
    '🔉' => 'اوسط آواز نکالتے اسپیکر',
    '🔊' => 'بلند آواز نکالتے اسپیکر',
    '📢' => 'لاؤڈ اسپیکر',
    '📣' => 'میگا فون',
    '📯' => 'پوسٹل ہارن',
    '🔔' => 'گھنٹی',
    '🔕' => 'گھنٹی پر سلیش',
    '🎼' => 'میوزیکل اسکور',
    '🎵' => 'میوزیکل نوٹ',
    '🎶' => 'میوزیکل نوٹس',
    '🎙' => 'اسٹوڈیو مائیکروفون',
    '🎚' => 'لیول سلائیڈر',
    '🎛' => 'کنٹرول کرنے والی نابز',
    '🎤' => 'مائیکروفون',
    '🎧' => 'ہیڈ فون',
    '📻' => 'ریڈیو',
    '🎷' => 'سیکسو فون',
    '🎺' => 'ٹرمپٹ',
    '🪊' => 'ٹرومبون',
    '🪗' => 'ارگن باجا',
    '🎸' => 'گٹار',
    '🎹' => 'میوزیکل کی بورڈ',
    '🎻' => 'وائلن',
    '🪕' => 'بینجو',
    '🥁' => 'ڈرم',
    '🪘' => 'لمبا ڈرم',
    '🪇' => 'مراکس',
    '🪈' => 'بانسری',
    '🪉' => 'بربط',
    '📱' => 'موبائل فون',
    '📲' => 'تیر کے نشان کے ساتھ موبائل فون',
    '☎' => 'ٹیلیفون',
    '📞' => 'ٹیلیفون کا ریسیور',
    '📟' => 'پیجر',
    '📠' => 'فیکس مشین',
    '🔋' => 'بیٹری',
    '🪫' => 'کم بیٹری',
    '🔌' => 'الیکٹرک پلگ',
    '💻' => 'لیپ ٹاپ کمپیوٹر',
    '🖥' => 'ڈیسک ٹاپ کمپیوٹر',
    '🖨' => 'پرنٹر',
    '⌨' => 'کی بورڈ',
    '🖱' => 'کمپیوٹر ماؤس',
    '🖲' => 'ٹریک بال',
    '💽' => 'کمپیوٹر ڈسک',
    '💾' => 'فلاپی ڈسک',
    '💿' => 'آپٹکل ڈسک',
    '📀' => 'ڈی وی ڈی',
    '🧮' => 'گِنتارا',
    '🎥' => 'مووی کیمرا',
    '🎞' => 'فلم کے فریم',
    '📽' => 'فلم پروجیکٹر',
    '🎬' => 'کلیپر بورڈ',
    '📺' => 'ٹیلی ویژن',
    '📷' => 'کیمرا',
    '📸' => 'فلیش والا کیمرا',
    '📹' => 'ویڈیو کیمرا',
    '📼' => 'ویڈیو کیسٹ',
    '🔍' => 'بائیں اشارہ کرتا محدب عدسہ',
    '🔎' => 'دائیں اشارہ کرتا محدب عدسہ',
    '🕯' => 'موم بتی',
    '💡' => 'لائٹ بلب',
    '🔦' => 'فلیش لائٹ',
    '🏮' => 'سرخ کاغذی لالٹین',
    '🪔' => 'دیا لیمپ',
    '📔' => 'سجاوٹی کوور والی نوٹ بک',
    '📕' => 'بند کتاب',
    '📖' => 'کھلی کتاب',
    '📗' => 'سبز کتاب',
    '📘' => 'نیلی کتاب',
    '📙' => 'نارنجی کتاب',
    '📚' => 'کتابیں',
    '📓' => 'نوٹ بک',
    '📒' => 'لیجر',
    '📃' => 'مڑا ہوا صفحہ',
    '📜' => 'اسکرول',
    '📄' => 'صفحے کا سامنے والا حصہ',
    '📰' => 'اخبار',
    '🗞' => 'رول کیا ہوا اخبار',
    '📑' => 'بُک مارک ٹیبز',
    '🔖' => 'بُک مارک',
    '🏷' => 'لیبل',
    '🪙' => 'سکہ',
    '💰' => 'پیسوں کا بیگ',
    '🪎' => 'ٹریژر چیسٹ',
    '💴' => 'ین بینک نوٹ',
    '💵' => 'ڈالر بینک نوٹ',
    '💶' => 'یورو بینک نوٹ',
    '💷' => 'پاؤنڈ بینک نوٹ',
    '💸' => 'پروں والے نوٹ',
    '💳' => 'کریڈٹ کارڈ',
    '🧾' => 'رسید',
    '💹' => 'ین کے ساتھ صعودی چارٹ',
    '✉' => 'لفافہ',
    '📧' => 'ای میل',
    '📨' => 'آتا ہوا لفافہ',
    '📩' => 'تیر کا نشان اور لفافہ',
    '📤' => 'آؤٹ باکس ٹرے',
    '📥' => 'ان باکس ٹرے',
    '📦' => 'پیکج',
    '📫' => 'بلند جھنڈے والا بند میل باکس',
    '📪' => 'جھکے ہوئے جھنڈے والا بند میل باکس',
    '📬' => 'بلند جھنڈے والا کھلا میل باکس',
    '📭' => 'جھکے ہوئے جھنڈے والا کھلا میل باکس',
    '📮' => 'پوسٹ باکس',
    '🗳' => 'بیلٹ کے ساتھ بیلٹ باکس',
    '✏' => 'پنسل',
    '✒' => 'سیاہ نب',
    '🖋' => 'فاؤنٹین پن',
    '🖊' => 'پن',
    '🖌' => 'پینٹ برش',
    '🖍' => 'کرے آن',
    '📝' => 'میمو',
    '💼' => 'بریف کیس',
    '📁' => 'فائل فولڈر',
    '📂' => 'کھلا فائل فولڈر',
    '🗂' => 'کارڈ انڈیکس کے تقسیم کار',
    '📅' => 'کیلنڈر',
    '📆' => 'ٹیئر آف کیلنڈر',
    '🗒' => 'سپائرل نوٹ بک',
    '🗓' => 'سپائرل کیلنڈر',
    '📇' => 'کارڈ انڈیکس',
    '📈' => 'صعودی چارٹ',
    '📉' => 'تنزلی چارٹ',
    '📊' => 'بار چارٹ',
    '📋' => 'کلپ بورڈ',
    '📌' => 'پُش پن',
    '📍' => 'گول پُش پن',
    '📎' => 'پیپر کلپ',
    '🖇' => 'جڑے ہوئے پیپر کلپس',
    '📏' => 'اسٹریٹ رولر',
    '📐' => 'تکونی رولر',
    '✂' => 'قینچی',
    '🗃' => 'کارڈ فائل باکس',
    '🗄' => 'فائل کیبنٹ',
    '🗑' => 'ردی کی ٹوکری',
    '🔒' => 'لاک',
    '🔓' => 'کھلا لاک',
    '🔏' => 'پن کے ساتھ لاک',
    '🔐' => 'چابی کے ساتھ بند لاک',
    '🔑' => 'چابی',
    '🗝' => 'پرانی چابی',
    '🔨' => 'ہتھوڑا',
    '🪓' => 'کلہاڑا',
    '⛏' => 'کدال',
    '⚒' => 'ہتھوڑا اور کدال',
    '🛠' => 'ہتھوڑا اور رینچ',
    '🗡' => 'خنجر',
    '⚔' => 'کراس کی شکل بناتی تلواریں',
    '💣' => 'بم',
    '🪃' => 'بومرینگ',
    '🏹' => 'تیر اور کمان',
    '🛡' => 'شیلڈ',
    '🪚' => 'بڑھئی کا آرا',
    '🔧' => 'رینچ',
    '🪛' => 'پیچ کس',
    '🔩' => 'نٹ اور بولٹ',
    '⚙' => 'گیئر',
    '🗜' => 'کلیمپ',
    '⚖' => 'برابر پلڑوں والا ترازو',
    '🦯' => 'نابینا افراد کیلئے چھڑی',
    '🔗' => 'لنک',
    '⛓' => 'زنجیریں',
    '🪝' => 'ہک',
    '🧰' => 'ٹُول بکس',
    '🧲' => 'مقناطیس',
    '🪜' => 'سیڑھی',
    '🪏' => 'بیلچہ',
    '⚗' => 'الیمبک',
    '🧪' => 'ٹیسٹ ٹیوب',
    '🧫' => 'پیٹری ڈش',
    '🧬' => 'ڈی این اے',
    '🔬' => 'مائیکروسکوپ',
    '🔭' => 'ٹیلی سکوپ',
    '📡' => 'سیٹلائٹ انٹینا',
    '💉' => 'سرنج',
    '🩸' => 'خون کا قطرہ',
    '💊' => 'گولی',
    '🩹' => 'چپکنے والی پٹی',
    '🩼' => 'بیساکھی',
    '🩺' => 'سٹیتھو سکوپ',
    '🩻' => 'ایکس رے',
    '🚪' => 'دروازہ',
    '🛗' => 'ایلیویٹر',
    '🪞' => 'آئینہ',
    '🪟' => 'کھڑکی',
    '🛏' => 'بستر',
    '🛋' => 'کاؤچ اور لیمپ',
    '🪑' => 'کرسی',
    '🚽' => 'بیت الخلا',
    '🪠' => 'پلنجر',
    '🚿' => 'شاور',
    '🛁' => 'نہانے کا ٹب',
    '🪤' => 'چوہے کا پھندہ',
    '🪒' => 'استرا',
    '🧴' => 'لوشن کی بوتل',
    '🧷' => 'حِفاظتی پِن',
    '🧹' => 'جھاڑو',
    '🧺' => 'ٹوکری',
    '🧻' => 'کاغذی رول',
    '🪣' => 'بالٹی',
    '🧼' => 'صابن',
    '🫧' => 'بلبلے',
    '🪥' => 'ٹوتھ برش',
    '🧽' => 'اسفنج',
    '🧯' => 'آگ بُجھانے والا آلہ',
    '🛒' => 'شاپنگ ٹرالی',
    '🚬' => 'سگریٹ نوشی',
    '⚰' => 'تابوت',
    '🪦' => 'کتبہ',
    '⚱' => 'مردے کی راکھ والا مرتبان',
    '🧿' => 'بری نظر کیلئے تعویز',
    '🪬' => 'حمسہ',
    '🗿' => 'موآئی',
    '🪧' => 'پلے کارڈ',
    '🪪' => 'شناختی کارڈ',
    '🏧' => 'اے ٹی ایم کی علامت',
    '🚮' => 'کوڑا ٹوکری میں کا سائن',
    '🚰' => 'پینے کا پانی',
    '♿' => 'وہیل چیئر',
    '🚹' => 'مردوں کا ٹوائلٹ',
    '🚺' => 'عورتوں کا ٹوائلٹ',
    '🚻' => 'ریسٹ روم',
    '🚼' => 'بے بی کی علامت',
    '🚾' => 'واش روم',
    '🛂' => 'پاسپورٹ کنٹرول',
    '🛃' => 'کسٹمز',
    '🛄' => 'سامان کا کلیم',
    '🛅' => 'چُھوٹا ہوا سامان',
    '⚠' => 'انتباہ',
    '🚸' => 'بچوں کے گزرنے کا سائن',
    '⛔' => 'داخلہ ممنوع',
    '🚫' => 'ممنوع',
    '🚳' => 'سائیکلیں ممنوع',
    '🚭' => 'سگریٹ نوشی منع ہے',
    '🚯' => 'کوڑا پھینکنا منع ہے',
    '🚱' => 'نا پینے والا پانی',
    '🚷' => 'پیدل چلنے والے ممنوع',
    '📵' => 'موبائل فون ممنوع',
    '🔞' => 'اٹھارہ سے کم عمر کی اجازت نہیں',
    '☢' => 'تابکاری',
    '☣' => 'زندگی کے لیے مضر',
    '⬆' => 'اوپر کا تیر',
    '↗' => 'اوپر دائیں تیر',
    '➡' => 'دائیں تیر',
    '↘' => 'نیچے دائیں تیر',
    '⬇' => 'نیچے کا تیر',
    '↙' => 'نیچے بائیں تیر',
    '⬅' => 'بائیں تیر',
    '↖' => 'اوپر بائیں تیر',
    '↕' => 'اوپر نیچے تیر',
    '↔' => 'دائیں بائیں تیر',
    '↩' => 'بائیں مڑتا ہوا دائیں تیر',
    '↪' => 'دائیں مڑتا ہوا بائیں تیر',
    '⤴' => 'اوپر مڑتا ہوا دائیں تیر',
    '⤵' => 'نیچے مڑتا ہوا دائیں تیر',
    '🔃' => 'گھڑی کی سمت میں عمودی تیر',
    '🔄' => 'گھڑی کی مخالف سمت میں تیر بٹن',
    '🔙' => 'واپسی تیر',
    '🔚' => 'اختتام تیر',
    '🔛' => 'آن! تیر',
    '🔜' => 'جلد تیر',
    '🔝' => 'بالا تیر',
    '🛐' => 'عبادت گاہ',
    '⚛' => 'ایٹم کی علامت',
    '🕉' => 'اوم',
    '✡' => 'داؤد کا ستارہ',
    '☸' => 'دھرم چکر',
    '☯' => 'ین یینگ',
    '✝' => 'لاطینی کراس',
    '☦' => 'روایتی مذہبی کراس',
    '☪' => 'ستارہ اور ہلال',
    '☮' => 'امن کا نشان',
    '🕎' => 'مینورہ',
    '🔯' => 'نکتہ دار چھ کونوں والا ستارہ',
    '🪯' => 'کھنڈا',
    '♈' => 'برج حمل',
    '♉' => 'برج ثور',
    '♊' => 'برج جوزا',
    '♋' => 'برج سرطان',
    '♌' => 'برج اسد',
    '♍' => 'برج سنبلہ',
    '♎' => 'برج میزان',
    '♏' => 'برج عقرب',
    '♐' => 'برج قوس',
    '♑' => 'برج جدی',
    '♒' => 'برج دلو',
    '♓' => 'برج حوت',
    '⛎' => 'برج حوا',
    '🔀' => 'ٹریکس کو شفل کرنے کا بٹن',
    '🔁' => 'دوہرانے کا بٹن',
    '🔂' => 'ایک دفعہ دوہرانے کا بٹن',
    '▶' => 'چلانے کا بٹن',
    '⏩' => 'تیز فارورڈ بٹن',
    '⏭' => 'اگلا ٹریک بٹن',
    '⏯' => 'چلانے یا روکنے کا بٹن',
    '◀' => 'پیچھے جانے کا بٹن',
    '⏪' => 'تیزی سے پیچھے جانے کا بٹن',
    '⏮' => 'آخری ٹریک کا بٹن',
    '🔼' => 'اوپر کا بٹن',
    '⏫' => 'تیزی سے اوپر کا بٹن',
    '🔽' => 'نیچے کا بٹن',
    '⏬' => 'تیزی سے نیچے کا بٹن',
    '⏸' => 'وقفہ ڈالنے کا بٹن',
    '⏹' => 'روکنے کا بٹن',
    '⏺' => 'ریکارڈ کا بٹن',
    '⏏' => 'نکالنے کا بٹن',
    '🎦' => 'سینما',
    '🔅' => 'دھیما کا بٹن',
    '🔆' => 'روشن کا بٹن',
    '📶' => 'انٹینا بارز',
    '🛜' => 'وائرلیس',
    '📳' => 'وائبریشن موڈ',
    '📴' => 'بند موبائل فون',
    '♀' => 'عورتوں کیلئے',
    '♂' => 'مردوں کیلئے',
    '⚧' => 'ہیجڑوں کی علامت',
    '✖' => 'ضرب',
    '➕' => 'جمع',
    '➖' => 'منفی',
    '➗' => 'تقسیم',
    '🟰' => 'برابر کا موٹا نشان',
    '♾' => 'لامحدود',
    '‼' => 'دوہری علامتِ ندائیہ',
    '⁉' => 'ندائیہ سوالیہ نشان',
    '❓' => 'سرخ سوالیہ نشان',
    '❔' => 'سفید سوالیہ نشان',
    '❕' => 'سفید ندائیہ نشان',
    '❗' => 'ندائیہ نشان',
    '〰' => 'لہردار ڈیش',
    '💱' => 'کرنسی کا تبادلہ',
    '💲' => 'بھاری ڈالر سائن',
    '⚕' => 'طبی علامت',
    '♻' => 'ری سائیکلنگ کا نشان',
    '⚜' => 'تین پتیوں والا للی',
    '🔱' => 'سہ شاخہ آلہ',
    '📛' => 'نام کا بیج',
    '🔰' => 'شروعات کرنے والے کا جاپانی نشان',
    '⭕' => 'کھوکھلا سرخ دائرہ',
    '✅' => 'سفید بھاری چیک کا نشان',
    '☑' => 'چیک کے نشان والا بیلٹ باکس',
    '✔' => 'بھاری چیک کا نشان',
    '❌' => 'کراس کا نشان',
    '❎' => 'کراس کے نشان کا بٹن',
    '➰' => 'کرل ہوئی رسی',
    '➿' => 'دوہری کرل ہوئی رسی',
    '〽' => 'باری کی تبدیلی کا نشان',
    '✳' => 'آٹھ کانٹوں والا اسٹیرسک',
    '✴' => 'آٹھ کونوں والا ستارہ',
    '❇' => 'چمک',
    '™' => 'تجارتی نشان',
    '🫟' => 'چھینٹے اڑانا',
    '🔠' => 'ان پٹ لاطینی بڑے حروف',
    '🔡' => 'ان پٹ لاطینی چھوٹے حروف',
    '🔢' => 'ان پٹ اعداد',
    '🔣' => 'ان پٹ علامات',
    '🔤' => 'ان پٹ لاطینی حروف',
    '🅰' => 'A بٹن (خون کی قسم)',
    '🆎' => 'AB بٹن (خون کی قسم)',
    '🅱' => 'B بٹن (خون کی قسم)',
    '🆑' => 'CL بٹن',
    '🆒' => 'کول بٹن',
    '🆓' => 'مفت بٹن',
    'ℹ' => 'معلومات',
    '🆔' => 'ID بٹن',
    'Ⓜ' => 'گول M',
    '🆕' => 'نیا بٹن',
    '🆖' => 'NG بٹن',
    '🅾' => 'O بٹن (خون کی قسم)',
    '🆗' => 'اوکے بٹن',
    '🅿' => 'P بٹن',
    '🆘' => 'SOS بٹن',
    '🆙' => 'اوپر! بٹن',
    '🆚' => 'VS بٹن',
    '🈁' => 'جاپانی "یہاں" بٹن',
    '🈂' => 'جاپانی "سروس چارج" بٹن',
    '🈷' => 'جاپانی "ماہانہ رقم" بٹن',
    '🈶' => 'جاپانی "مفت نہیں" بٹن',
    '🈯' => 'جاپانی "محفوظ" بٹن',
    '🉐' => 'جاپانی "سودا بازی " بٹن',
    '🈹' => 'جاپانی "رعایت" بٹن',
    '🈚' => 'جاپانی "مفت" بٹن',
    '🈲' => 'جاپانی "ممنوع" بٹن',
    '🉑' => 'جاپانی "قابل قبول" بٹن',
    '🈸' => 'جاپانی "اپلیکیشن" بٹن',
    '🈴' => 'جاپانی "پاس کرنے کا گریڈ" بٹن',
    '🈳' => 'جاپانی "خالی اسامی" علامت',
    '㊗' => 'جاپانی "مبارکباد" بٹن',
    '㊙' => 'جاپانی "خفیہ" بٹن',
    '🈺' => 'جاپانی "کاروبار کے لیے کھلا" بٹن',
    '🈵' => 'جاپانی "کوئی اسامی نہیں" علامت',
    '🔴' => 'سرخ دائرہ',
    '🟠' => 'نارنجی دائرہ',
    '🟡' => 'پیلا دائرہ',
    '🟢' => 'سبز دائرہ',
    '🔵' => 'نیلا دائرہ',
    '🟣' => 'ارغوانی دائرہ',
    '🟤' => 'بھورا دائرہ',
    '⚫' => 'کالا دائرہ',
    '⚪' => 'سفید دائرہ',
    '🟥' => 'سرخ چوکور',
    '🟧' => 'نارنجی چوکور',
    '🟨' => 'پیلا چوکور',
    '🟩' => 'سبز چوکور',
    '🟦' => 'نیلا چوکور',
    '🟪' => 'ارغوانی چوکور',
    '🟫' => 'بھورا چوکور',
    '⬛' => 'کالا بڑا چوکور',
    '⬜' => 'سفید بڑا چوکور',
    '◼' => 'کالا میڈیم چوکور',
    '◻' => 'سفید میڈیم چوکور',
    '◾' => 'کالا میڈیم چھوٹا چوکور',
    '◽' => 'سفید میڈِیم چھوٹا چوکور',
    '▪' => 'کالا چھوٹا چوکور',
    '▫' => 'سفید چھوٹا چوکور',
    '🔶' => 'بڑا نارنجی ہیرا',
    '🔷' => 'بڑا نیلا ہیرا',
    '🔸' => 'چھوٹا نارنجی ہیرا',
    '🔹' => 'چھوٹا نیلا ہیرا',
    '🔺' => 'اوپر اشارہ کرتی سرخ مثلث',
    '🔻' => 'نیچے اشارہ کرتی سرخ مثلث',
    '💠' => 'نکتے والا ہیرا',
    '🔘' => 'ریڈیو بٹن',
    '🔳' => 'سفید چوکور بٹن',
    '🔲' => 'سیاہ چوکور بٹن',
    '🏁' => 'خانوں والا جھنڈا',
    '🚩' => 'تکونی جھنڈا',
    '🎌' => 'کراس کی شکل میں جھنڈے',
    '🏴' => 'لہراتا کالا جھنڈا',
    '🏳' => 'لہراتا سفید جھنڈا',
];
