<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'ukuqabula: mdala, mdala, uhlobo-1-2, uhlobo-3',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'ukuqabula: mdala, mdala, uhlobo-1-2, uhlobo-4',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'ukuqabula: mdala, mdala, uhlobo-1-2, uhlobo-5',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'ukuqabula: mdala, mdala, uhlobo-1-2, uhlobo-6',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'ukuqabula: mdala, mdala, uhlobo-3, uhlobo-1-2',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'ukuqabula: mdala, mdala, uhlobo-3, uhlobo-4',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'ukuqabula: mdala, mdala, uhlobo-3, uhlobo-5',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'ukuqabula: mdala, mdala, uhlobo-3, uhlobo-6',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'ukuqabula: mdala, mdala, uhlobo-4, uhlobo-1-2',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'ukuqabula: mdala, mdala, uhlobo-4, uhlobo-3',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'ukuqabula: mdala, mdala, uhlobo-4, uhlobo-5',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'ukuqabula: mdala, mdala, uhlobo-4, uhlobo-6',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'ukuqabula: mdala, mdala, uhlobo-5, uhlobo-1-2',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'ukuqabula: mdala, mdala, uhlobo-5, uhlobo-3',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'ukuqabula: mdala, mdala, uhlobo-5, uhlobo-4',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'ukuqabula: mdala, mdala, uhlobo-5, uhlobo-6',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'ukuqabula: mdala, mdala, uhlobo-6, uhlobo-1-2',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'ukuqabula: mdala, mdala, uhlobo-6, uhlobo-3',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'ukuqabula: mdala, mdala, uhlobo-6, uhlobo-4',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'ukuqabula: mdala, mdala, uhlobo-6, uhlobo-5',
    '👨🏻‍❤‍💋‍👨🏻' => 'ukuqabula: indoda, indoda, uhlobo-1-2',
    '👨🏻‍❤‍💋‍👨🏼' => 'ukuqabula: indoda, indoda, uhlobo-1-2, uhlobo-3',
    '👨🏻‍❤‍💋‍👨🏽' => 'ukuqabula: indoda, indoda, uhlobo-1-2, uhlobo-4',
    '👨🏻‍❤‍💋‍👨🏾' => 'ukuqabula: indoda, indoda, uhlobo-1-2, uhlobo-5',
    '👨🏻‍❤‍💋‍👨🏿' => 'ukuqabula: indoda, indoda, uhlobo-1-2, uhlobo-6',
    '👨🏼‍❤‍💋‍👨🏻' => 'ukuqabula: indoda, indoda, uhlobo-3, uhlobo-1-2',
    '👨🏼‍❤‍💋‍👨🏼' => 'ukuqabula: indoda, indoda, uhlobo-3',
    '👨🏼‍❤‍💋‍👨🏽' => 'ukuqabula: indoda, indoda, uhlobo-3, uhlobo-4',
    '👨🏼‍❤‍💋‍👨🏾' => 'ukuqabula: indoda, indoda, uhlobo-3, uhlobo-5',
    '👨🏼‍❤‍💋‍👨🏿' => 'ukuqabula: indoda, indoda, uhlobo-3, uhlobo-6',
    '👨🏽‍❤‍💋‍👨🏻' => 'ukuqabula: indoda, indoda, uhlobo-4, uhlobo-1-2',
    '👨🏽‍❤‍💋‍👨🏼' => 'ukuqabula: indoda, indoda, uhlobo-4, uhlobo-3',
    '👨🏽‍❤‍💋‍👨🏽' => 'ukuqabula: indoda, indoda, uhlobo-4',
    '👨🏽‍❤‍💋‍👨🏾' => 'ukuqabula: indoda, indoda, uhlobo-4, uhlobo-5',
    '👨🏽‍❤‍💋‍👨🏿' => 'ukuqabula: indoda, indoda, uhlobo-4, uhlobo-6',
    '👨🏾‍❤‍💋‍👨🏻' => 'ukuqabula: indoda, indoda, uhlobo-5, uhlobo-1-2',
    '👨🏾‍❤‍💋‍👨🏼' => 'ukuqabula: indoda, indoda, uhlobo-5, uhlobo-3',
    '👨🏾‍❤‍💋‍👨🏽' => 'ukuqabula: indoda, indoda, uhlobo-5, uhlobo-4',
    '👨🏾‍❤‍💋‍👨🏾' => 'ukuqabula: indoda, indoda, uhlobo-5',
    '👨🏾‍❤‍💋‍👨🏿' => 'ukuqabula: indoda, indoda, uhlobo-5, uhlobo-6',
    '👨🏿‍❤‍💋‍👨🏻' => 'ukuqabula: indoda, indoda, uhlobo-6, uhlobo-1-2',
    '👨🏿‍❤‍💋‍👨🏼' => 'ukuqabula: indoda, indoda, uhlobo-6, uhlobo-3',
    '👨🏿‍❤‍💋‍👨🏽' => 'ukuqabula: indoda, indoda, uhlobo-6, uhlobo-4',
    '👨🏿‍❤‍💋‍👨🏾' => 'ukuqabula: indoda, indoda, uhlobo-6, uhlobo-5',
    '👨🏿‍❤‍💋‍👨🏿' => 'ukuqabula: indoda, indoda, uhlobo-6',
    '👩🏻‍❤‍💋‍👨🏻' => 'ukuqabula: umama, indoda, uhlobo-1-2',
    '👩🏻‍❤‍💋‍👨🏼' => 'ukuqabula: umama, indoda, uhlobo-1-2, uhlobo-3',
    '👩🏻‍❤‍💋‍👨🏽' => 'ukuqabula: umama, indoda, uhlobo-1-2, uhlobo-4',
    '👩🏻‍❤‍💋‍👨🏾' => 'ukuqabula: umama, indoda, uhlobo-1-2, uhlobo-5',
    '👩🏻‍❤‍💋‍👨🏿' => 'ukuqabula: umama, indoda, uhlobo-1-2, uhlobo-6',
    '👩🏼‍❤‍💋‍👨🏻' => 'ukuqabula: umama, indoda, uhlobo-3, uhlobo-1-2',
    '👩🏼‍❤‍💋‍👨🏼' => 'ukuqabula: umama, indoda, uhlobo-3',
    '👩🏼‍❤‍💋‍👨🏽' => 'ukuqabula: umama, indoda, uhlobo-3, uhlobo-4',
    '👩🏼‍❤‍💋‍👨🏾' => 'ukuqabula: umama, indoda, uhlobo-3, uhlobo-5',
    '👩🏼‍❤‍💋‍👨🏿' => 'ukuqabula: umama, indoda, uhlobo-3, uhlobo-6',
    '👩🏽‍❤‍💋‍👨🏻' => 'ukuqabula: umama, indoda, uhlobo-4, uhlobo-1-2',
    '👩🏽‍❤‍💋‍👨🏼' => 'ukuqabula: umama, indoda, uhlobo-4, uhlobo-3',
    '👩🏽‍❤‍💋‍👨🏽' => 'ukuqabula: umama, indoda, uhlobo-4',
    '👩🏽‍❤‍💋‍👨🏾' => 'ukuqabula: umama, indoda, uhlobo-4, uhlobo-5',
    '👩🏽‍❤‍💋‍👨🏿' => 'ukuqabula: umama, indoda, uhlobo-4, uhlobo-6',
    '👩🏾‍❤‍💋‍👨🏻' => 'ukuqabula: umama, indoda, uhlobo-5, uhlobo-1-2',
    '👩🏾‍❤‍💋‍👨🏼' => 'ukuqabula: umama, indoda, uhlobo-5, uhlobo-3',
    '👩🏾‍❤‍💋‍👨🏽' => 'ukuqabula: umama, indoda, uhlobo-5, uhlobo-4',
    '👩🏾‍❤‍💋‍👨🏾' => 'ukuqabula: umama, indoda, uhlobo-5',
    '👩🏾‍❤‍💋‍👨🏿' => 'ukuqabula: umama, indoda, uhlobo-5, uhlobo-6',
    '👩🏿‍❤‍💋‍👨🏻' => 'ukuqabula: umama, indoda, uhlobo-6, uhlobo-1-2',
    '👩🏿‍❤‍💋‍👨🏼' => 'ukuqabula: umama, indoda, uhlobo-6, uhlobo-3',
    '👩🏿‍❤‍💋‍👨🏽' => 'ukuqabula: umama, indoda, uhlobo-6, uhlobo-4',
    '👩🏿‍❤‍💋‍👨🏾' => 'ukuqabula: umama, indoda, uhlobo-6, uhlobo-5',
    '👩🏿‍❤‍💋‍👨🏿' => 'ukuqabula: umama, indoda, uhlobo-6',
    '👩🏻‍❤‍💋‍👩🏻' => 'ukuqabula: umama, umama, uhlobo-1-2',
    '👩🏻‍❤‍💋‍👩🏼' => 'ukuqabula: umama, umama, uhlobo-1-2, uhlobo-3',
    '👩🏻‍❤‍💋‍👩🏽' => 'ukuqabula: umama, umama, uhlobo-1-2, uhlobo-4',
    '👩🏻‍❤‍💋‍👩🏾' => 'ukuqabula: umama, umama, uhlobo-1-2, uhlobo-5',
    '👩🏻‍❤‍💋‍👩🏿' => 'ukuqabula: umama, umama, uhlobo-1-2, uhlobo-6',
    '👩🏼‍❤‍💋‍👩🏻' => 'ukuqabula: umama, umama, uhlobo-3, uhlobo-1-2',
    '👩🏼‍❤‍💋‍👩🏼' => 'ukuqabula: umama, umama, uhlobo-3',
    '👩🏼‍❤‍💋‍👩🏽' => 'ukuqabula: umama, umama, uhlobo-3, uhlobo-4',
    '👩🏼‍❤‍💋‍👩🏾' => 'ukuqabula: umama, umama, uhlobo-3, uhlobo-5',
    '👩🏼‍❤‍💋‍👩🏿' => 'ukuqabula: umama, umama, uhlobo-3, uhlobo-6',
    '👩🏽‍❤‍💋‍👩🏻' => 'ukuqabula: umama, umama, uhlobo-4, uhlobo-1-2',
    '👩🏽‍❤‍💋‍👩🏼' => 'ukuqabula: umama, umama, uhlobo-4, uhlobo-3',
    '👩🏽‍❤‍💋‍👩🏽' => 'ukuqabula: umama, umama, uhlobo-4',
    '👩🏽‍❤‍💋‍👩🏾' => 'ukuqabula: umama, umama, uhlobo-4, uhlobo-5',
    '👩🏽‍❤‍💋‍👩🏿' => 'ukuqabula: umama, umama, uhlobo-4, uhlobo-6',
    '👩🏾‍❤‍💋‍👩🏻' => 'ukuqabula: umama, umama, uhlobo-5, uhlobo-1-2',
    '👩🏾‍❤‍💋‍👩🏼' => 'ukuqabula: umama, umama, uhlobo-5, uhlobo-3',
    '👩🏾‍❤‍💋‍👩🏽' => 'ukuqabula: umama, umama, uhlobo-5, uhlobo-4',
    '👩🏾‍❤‍💋‍👩🏾' => 'ukuqabula: umama, umama, uhlobo-5',
    '👩🏾‍❤‍💋‍👩🏿' => 'ukuqabula: umama, umama, uhlobo-5, uhlobo-6',
    '👩🏿‍❤‍💋‍👩🏻' => 'ukuqabula: umama, umama, uhlobo-6, uhlobo-1-2',
    '👩🏿‍❤‍💋‍👩🏼' => 'ukuqabula: umama, umama, uhlobo-6, uhlobo-3',
    '👩🏿‍❤‍💋‍👩🏽' => 'ukuqabula: umama, umama, uhlobo-6, uhlobo-4',
    '👩🏿‍❤‍💋‍👩🏾' => 'ukuqabula: umama, umama, uhlobo-6, uhlobo-5',
    '👩🏿‍❤‍💋‍👩🏿' => 'ukuqabula: umama, umama, uhlobo-6',
    '🧑🏻‍🫯‍🧑🏼' => 'abashayi-sibhakela: uhlobo-1-2, uhlobo-3',
    '🧑🏻‍🫯‍🧑🏽' => 'abashayi-sibhakela: uhlobo-1-2, uhlobo-4',
    '🧑🏻‍🫯‍🧑🏾' => 'abashayi-sibhakela: uhlobo-1-2, uhlobo-5',
    '🧑🏻‍🫯‍🧑🏿' => 'abashayi-sibhakela: uhlobo-1-2, uhlobo-6',
    '🧑🏼‍🫯‍🧑🏻' => 'abashayi-sibhakela: uhlobo-3, uhlobo-1-2',
    '🧑🏼‍🫯‍🧑🏽' => 'abashayi-sibhakela: uhlobo-3, uhlobo-4',
    '🧑🏼‍🫯‍🧑🏾' => 'abashayi-sibhakela: uhlobo-3, uhlobo-5',
    '🧑🏼‍🫯‍🧑🏿' => 'abashayi-sibhakela: uhlobo-3, uhlobo-6',
    '🧑🏽‍🫯‍🧑🏻' => 'abashayi-sibhakela: uhlobo-4, uhlobo-1-2',
    '🧑🏽‍🫯‍🧑🏼' => 'abashayi-sibhakela: uhlobo-4, uhlobo-3',
    '🧑🏽‍🫯‍🧑🏾' => 'abashayi-sibhakela: uhlobo-4, uhlobo-5',
    '🧑🏽‍🫯‍🧑🏿' => 'abashayi-sibhakela: uhlobo-4, uhlobo-6',
    '🧑🏾‍🫯‍🧑🏻' => 'abashayi-sibhakela: uhlobo-5, uhlobo-1-2',
    '🧑🏾‍🫯‍🧑🏼' => 'abashayi-sibhakela: uhlobo-5, uhlobo-3',
    '🧑🏾‍🫯‍🧑🏽' => 'abashayi-sibhakela: uhlobo-5, uhlobo-4',
    '🧑🏾‍🫯‍🧑🏿' => 'abashayi-sibhakela: uhlobo-5, uhlobo-6',
    '🧑🏿‍🫯‍🧑🏻' => 'abashayi-sibhakela: uhlobo-6, uhlobo-1-2',
    '🧑🏿‍🫯‍🧑🏼' => 'abashayi-sibhakela: uhlobo-6, uhlobo-3',
    '🧑🏿‍🫯‍🧑🏽' => 'abashayi-sibhakela: uhlobo-6, uhlobo-4',
    '🧑🏿‍🫯‍🧑🏾' => 'abashayi-sibhakela: uhlobo-6, uhlobo-5',
    '🧑🏻‍❤‍🧑🏼' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-1-2, uhlobo-3',
    '🧑🏻‍❤‍🧑🏽' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-1-2, uhlobo-4',
    '🧑🏻‍❤‍🧑🏾' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-1-2, uhlobo-5',
    '🧑🏻‍❤‍🧑🏿' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-1-2, uhlobo-6',
    '🧑🏼‍❤‍🧑🏻' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-3, uhlobo-1-2',
    '🧑🏼‍❤‍🧑🏽' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-3, uhlobo-4',
    '🧑🏼‍❤‍🧑🏾' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-3, uhlobo-5',
    '🧑🏼‍❤‍🧑🏿' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-3, uhlobo-6',
    '🧑🏽‍❤‍🧑🏻' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-4, uhlobo-1-2',
    '🧑🏽‍❤‍🧑🏼' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-4, uhlobo-3',
    '🧑🏽‍❤‍🧑🏾' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-4, uhlobo-5',
    '🧑🏽‍❤‍🧑🏿' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-4, uhlobo-6',
    '🧑🏾‍❤‍🧑🏻' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-5, uhlobo-1-2',
    '🧑🏾‍❤‍🧑🏼' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-5, uhlobo-3',
    '🧑🏾‍❤‍🧑🏽' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-5, uhlobo-4',
    '🧑🏾‍❤‍🧑🏿' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-5, uhlobo-6',
    '🧑🏿‍❤‍🧑🏻' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-6, uhlobo-1-2',
    '🧑🏿‍❤‍🧑🏼' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-6, uhlobo-3',
    '🧑🏿‍❤‍🧑🏽' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-6, uhlobo-4',
    '🧑🏿‍❤‍🧑🏾' => 'izithandani ezinenhliziyo: mdala, mdala, uhlobo-6, uhlobo-5',
    '🧑🏻‍🐰‍🧑🏼' => 'abantu abasemcimbini: uhlobo-1-2, uhlobo-3',
    '🧑🏻‍🐰‍🧑🏽' => 'abantu abasemcimbini: uhlobo-1-2, uhlobo-4',
    '🧑🏻‍🐰‍🧑🏾' => 'abantu abasemcimbini: uhlobo-1-2, uhlobo-5',
    '🧑🏻‍🐰‍🧑🏿' => 'abantu abasemcimbini: uhlobo-1-2, uhlobo-6',
    '🧑🏼‍🐰‍🧑🏻' => 'abantu abasemcimbini: uhlobo-3, uhlobo-1-2',
    '🧑🏼‍🐰‍🧑🏽' => 'abantu abasemcimbini: uhlobo-3, uhlobo-4',
    '🧑🏼‍🐰‍🧑🏾' => 'abantu abasemcimbini: uhlobo-3, uhlobo-5',
    '🧑🏼‍🐰‍🧑🏿' => 'abantu abasemcimbini: uhlobo-3, uhlobo-6',
    '🧑🏽‍🐰‍🧑🏻' => 'abantu abasemcimbini: uhlobo-4, uhlobo-1-2',
    '🧑🏽‍🐰‍🧑🏼' => 'abantu abasemcimbini: uhlobo-4, uhlobo-3',
    '🧑🏽‍🐰‍🧑🏾' => 'abantu abasemcimbini: uhlobo-4, uhlobo-5',
    '🧑🏽‍🐰‍🧑🏿' => 'abantu abasemcimbini: uhlobo-4, uhlobo-6',
    '🧑🏾‍🐰‍🧑🏻' => 'abantu abasemcimbini: uhlobo-5, uhlobo-1-2',
    '🧑🏾‍🐰‍🧑🏼' => 'abantu abasemcimbini: uhlobo-5, uhlobo-3',
    '🧑🏾‍🐰‍🧑🏽' => 'abantu abasemcimbini: uhlobo-5, uhlobo-4',
    '🧑🏾‍🐰‍🧑🏿' => 'abantu abasemcimbini: uhlobo-5, uhlobo-6',
    '🧑🏿‍🐰‍🧑🏻' => 'abantu abasemcimbini: uhlobo-6, uhlobo-1-2',
    '🧑🏿‍🐰‍🧑🏼' => 'abantu abasemcimbini: uhlobo-6, uhlobo-3',
    '🧑🏿‍🐰‍🧑🏽' => 'abantu abasemcimbini: uhlobo-6, uhlobo-4',
    '🧑🏿‍🐰‍🧑🏾' => 'abantu abasemcimbini: uhlobo-6, uhlobo-5',
    '👨🏻‍🫯‍👨🏼' => 'abashayisibhakela besilisa: uhlobo-1-2, uhlobo-3',
    '👨🏻‍🫯‍👨🏽' => 'abashayisibhakela besilisa: uhlobo-1-2, uhlobo-4',
    '👨🏻‍🫯‍👨🏾' => 'abashayisibhakela besilisa: uhlobo-1-2, uhlobo-5',
    '👨🏻‍🫯‍👨🏿' => 'abashayisibhakela besilisa: uhlobo-1-2, uhlobo-6',
    '👨🏼‍🫯‍👨🏻' => 'abashayisibhakela besilisa: uhlobo-3, uhlobo-1-2',
    '👨🏼‍🫯‍👨🏽' => 'abashayisibhakela besilisa: uhlobo-3, uhlobo-4',
    '👨🏼‍🫯‍👨🏾' => 'abashayisibhakela besilisa: uhlobo-3, uhlobo-5',
    '👨🏼‍🫯‍👨🏿' => 'abashayisibhakela besilisa: uhlobo-3, uhlobo-6',
    '👨🏽‍🫯‍👨🏻' => 'abashayisibhakela besilisa: uhlobo-4, uhlobo-1-2',
    '👨🏽‍🫯‍👨🏼' => 'abashayisibhakela besilisa: uhlobo-4, uhlobo-3',
    '👨🏽‍🫯‍👨🏾' => 'abashayisibhakela besilisa: uhlobo-4, uhlobo-5',
    '👨🏽‍🫯‍👨🏿' => 'abashayisibhakela besilisa: uhlobo-4, uhlobo-6',
    '👨🏾‍🫯‍👨🏻' => 'abashayisibhakela besilisa: uhlobo-5, uhlobo-1-2',
    '👨🏾‍🫯‍👨🏼' => 'abashayisibhakela besilisa: uhlobo-5, uhlobo-3',
    '👨🏾‍🫯‍👨🏽' => 'abashayisibhakela besilisa: uhlobo-5, uhlobo-4',
    '👨🏾‍🫯‍👨🏿' => 'abashayisibhakela besilisa: uhlobo-5, uhlobo-6',
    '👨🏿‍🫯‍👨🏻' => 'abashayisibhakela besilisa: uhlobo-6, uhlobo-1-2',
    '👨🏿‍🫯‍👨🏼' => 'abashayisibhakela besilisa: uhlobo-6, uhlobo-3',
    '👨🏿‍🫯‍👨🏽' => 'abashayisibhakela besilisa: uhlobo-6, uhlobo-4',
    '👨🏿‍🫯‍👨🏾' => 'abashayisibhakela besilisa: uhlobo-6, uhlobo-5',
    '👨🏻‍❤‍👨🏻' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-1-2',
    '👨🏻‍❤‍👨🏼' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-1-2, uhlobo-3',
    '👨🏻‍❤‍👨🏽' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-1-2, uhlobo-4',
    '👨🏻‍❤‍👨🏾' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-1-2, uhlobo-5',
    '👨🏻‍❤‍👨🏿' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-1-2, uhlobo-6',
    '👨🏼‍❤‍👨🏻' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-3, uhlobo-1-2',
    '👨🏼‍❤‍👨🏼' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-3',
    '👨🏼‍❤‍👨🏽' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-3, uhlobo-4',
    '👨🏼‍❤‍👨🏾' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-3, uhlobo-5',
    '👨🏼‍❤‍👨🏿' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-3, uhlobo-6',
    '👨🏽‍❤‍👨🏻' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-4, uhlobo-1-2',
    '👨🏽‍❤‍👨🏼' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-4, uhlobo-3',
    '👨🏽‍❤‍👨🏽' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-4',
    '👨🏽‍❤‍👨🏾' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-4, uhlobo-5',
    '👨🏽‍❤‍👨🏿' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-4, uhlobo-6',
    '👨🏾‍❤‍👨🏻' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-5, uhlobo-1-2',
    '👨🏾‍❤‍👨🏼' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-5, uhlobo-3',
    '👨🏾‍❤‍👨🏽' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-5, uhlobo-4',
    '👨🏾‍❤‍👨🏾' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-5',
    '👨🏾‍❤‍👨🏿' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-5, uhlobo-6',
    '👨🏿‍❤‍👨🏻' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-6, uhlobo-1-2',
    '👨🏿‍❤‍👨🏼' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-6, uhlobo-3',
    '👨🏿‍❤‍👨🏽' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-6, uhlobo-4',
    '👨🏿‍❤‍👨🏾' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-6, uhlobo-5',
    '👨🏿‍❤‍👨🏿' => 'izithandani ezinenhliziyo: indoda, indoda, uhlobo-6',
    '👨🏻‍🐰‍👨🏼' => 'amadoda asemcimbini: uhlobo-1-2, uhlobo-3',
    '👨🏻‍🐰‍👨🏽' => 'amadoda asemcimbini: uhlobo-1-2, uhlobo-4',
    '👨🏻‍🐰‍👨🏾' => 'amadoda asemcimbini: uhlobo-1-2, uhlobo-5',
    '👨🏻‍🐰‍👨🏿' => 'amadoda asemcimbini: uhlobo-1-2, uhlobo-6',
    '👨🏼‍🐰‍👨🏻' => 'amadoda asemcimbini: uhlobo-3, uhlobo-1-2',
    '👨🏼‍🐰‍👨🏽' => 'amadoda asemcimbini: uhlobo-3, uhlobo-4',
    '👨🏼‍🐰‍👨🏾' => 'amadoda asemcimbini: uhlobo-3, uhlobo-5',
    '👨🏼‍🐰‍👨🏿' => 'amadoda asemcimbini: uhlobo-3, uhlobo-6',
    '👨🏽‍🐰‍👨🏻' => 'amadoda asemcimbini: uhlobo-4, uhlobo-1-2',
    '👨🏽‍🐰‍👨🏼' => 'amadoda asemcimbini: uhlobo-4, uhlobo-3',
    '👨🏽‍🐰‍👨🏾' => 'amadoda asemcimbini: uhlobo-4, uhlobo-5',
    '👨🏽‍🐰‍👨🏿' => 'amadoda asemcimbini: uhlobo-4, uhlobo-6',
    '👨🏾‍🐰‍👨🏻' => 'amadoda asemcimbini: uhlobo-5, uhlobo-1-2',
    '👨🏾‍🐰‍👨🏼' => 'amadoda asemcimbini: uhlobo-5, uhlobo-3',
    '👨🏾‍🐰‍👨🏽' => 'amadoda asemcimbini: uhlobo-5, uhlobo-4',
    '👨🏾‍🐰‍👨🏿' => 'amadoda asemcimbini: uhlobo-5, uhlobo-6',
    '👨🏿‍🐰‍👨🏻' => 'amadoda asemcimbini: uhlobo-6, uhlobo-1-2',
    '👨🏿‍🐰‍👨🏼' => 'amadoda asemcimbini: uhlobo-6, uhlobo-3',
    '👨🏿‍🐰‍👨🏽' => 'amadoda asemcimbini: uhlobo-6, uhlobo-4',
    '👨🏿‍🐰‍👨🏾' => 'amadoda asemcimbini: uhlobo-6, uhlobo-5',
    '👩🏻‍🫯‍👩🏼' => 'abashayisibhakela besimame: uhlobo-1-2, uhlobo-3',
    '👩🏻‍🫯‍👩🏽' => 'abashayisibhakela besimame: uhlobo-1-2, uhlobo-4',
    '👩🏻‍🫯‍👩🏾' => 'abashayisibhakela besimame: uhlobo-1-2, uhlobo-5',
    '👩🏻‍🫯‍👩🏿' => 'abashayisibhakela besimame: uhlobo-1-2, uhlobo-6',
    '👩🏼‍🫯‍👩🏻' => 'abashayisibhakela besimame: uhlobo-3, uhlobo-1-2',
    '👩🏼‍🫯‍👩🏽' => 'abashayisibhakela besimame: uhlobo-3, uhlobo-4',
    '👩🏼‍🫯‍👩🏾' => 'abashayisibhakela besimame: uhlobo-3, uhlobo-5',
    '👩🏼‍🫯‍👩🏿' => 'abashayisibhakela besimame: uhlobo-3, uhlobo-6',
    '👩🏽‍🫯‍👩🏻' => 'abashayisibhakela besimame: uhlobo-4, uhlobo-1-2',
    '👩🏽‍🫯‍👩🏼' => 'abashayisibhakela besimame: uhlobo-4, uhlobo-3',
    '👩🏽‍🫯‍👩🏾' => 'abashayisibhakela besimame: uhlobo-4, uhlobo-5',
    '👩🏽‍🫯‍👩🏿' => 'abashayisibhakela besimame: uhlobo-4, uhlobo-6',
    '👩🏾‍🫯‍👩🏻' => 'abashayisibhakela besimame: uhlobo-5, uhlobo-1-2',
    '👩🏾‍🫯‍👩🏼' => 'abashayisibhakela besimame: uhlobo-5, uhlobo-3',
    '👩🏾‍🫯‍👩🏽' => 'abashayisibhakela besimame: uhlobo-5, uhlobo-4',
    '👩🏾‍🫯‍👩🏿' => 'abashayisibhakela besimame: uhlobo-5, uhlobo-6',
    '👩🏿‍🫯‍👩🏻' => 'abashayisibhakela besimame: uhlobo-6, uhlobo-1-2',
    '👩🏿‍🫯‍👩🏼' => 'abashayisibhakela besimame: uhlobo-6, uhlobo-3',
    '👩🏿‍🫯‍👩🏽' => 'abashayisibhakela besimame: uhlobo-6, uhlobo-4',
    '👩🏿‍🫯‍👩🏾' => 'abashayisibhakela besimame: uhlobo-6, uhlobo-5',
    '👩🏻‍❤‍👨🏻' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-1-2',
    '👩🏻‍❤‍👨🏼' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-1-2, uhlobo-3',
    '👩🏻‍❤‍👨🏽' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-1-2, uhlobo-4',
    '👩🏻‍❤‍👨🏾' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-1-2, uhlobo-5',
    '👩🏻‍❤‍👨🏿' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-1-2, uhlobo-6',
    '👩🏼‍❤‍👨🏻' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-3, uhlobo-1-2',
    '👩🏼‍❤‍👨🏼' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-3',
    '👩🏼‍❤‍👨🏽' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-3, uhlobo-4',
    '👩🏼‍❤‍👨🏾' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-3, uhlobo-5',
    '👩🏼‍❤‍👨🏿' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-3, uhlobo-6',
    '👩🏽‍❤‍👨🏻' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-4, uhlobo-1-2',
    '👩🏽‍❤‍👨🏼' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-4, uhlobo-3',
    '👩🏽‍❤‍👨🏽' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-4',
    '👩🏽‍❤‍👨🏾' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-4, uhlobo-5',
    '👩🏽‍❤‍👨🏿' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-4, uhlobo-6',
    '👩🏾‍❤‍👨🏻' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-5, uhlobo-1-2',
    '👩🏾‍❤‍👨🏼' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-5, uhlobo-3',
    '👩🏾‍❤‍👨🏽' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-5, uhlobo-4',
    '👩🏾‍❤‍👨🏾' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-5',
    '👩🏾‍❤‍👨🏿' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-5, uhlobo-6',
    '👩🏿‍❤‍👨🏻' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-6, uhlobo-1-2',
    '👩🏿‍❤‍👨🏼' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-6, uhlobo-3',
    '👩🏿‍❤‍👨🏽' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-6, uhlobo-4',
    '👩🏿‍❤‍👨🏾' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-6, uhlobo-5',
    '👩🏿‍❤‍👨🏿' => 'izithandani ezinenhliziyo: umama, indoda, uhlobo-6',
    '👩🏻‍❤‍👩🏻' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-1-2',
    '👩🏻‍❤‍👩🏼' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-1-2, uhlobo-3',
    '👩🏻‍❤‍👩🏽' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-1-2, uhlobo-4',
    '👩🏻‍❤‍👩🏾' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-1-2, uhlobo-5',
    '👩🏻‍❤‍👩🏿' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-1-2, uhlobo-6',
    '👩🏼‍❤‍👩🏻' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-3, uhlobo-1-2',
    '👩🏼‍❤‍👩🏼' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-3',
    '👩🏼‍❤‍👩🏽' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-3, uhlobo-4',
    '👩🏼‍❤‍👩🏾' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-3, uhlobo-5',
    '👩🏼‍❤‍👩🏿' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-3, uhlobo-6',
    '👩🏽‍❤‍👩🏻' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-4, uhlobo-1-2',
    '👩🏽‍❤‍👩🏼' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-4, uhlobo-3',
    '👩🏽‍❤‍👩🏽' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-4',
    '👩🏽‍❤‍👩🏾' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-4, uhlobo-5',
    '👩🏽‍❤‍👩🏿' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-4, uhlobo-6',
    '👩🏾‍❤‍👩🏻' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-5, uhlobo-1-2',
    '👩🏾‍❤‍👩🏼' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-5, uhlobo-3',
    '👩🏾‍❤‍👩🏽' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-5, uhlobo-4',
    '👩🏾‍❤‍👩🏾' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-5',
    '👩🏾‍❤‍👩🏿' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-5, uhlobo-6',
    '👩🏿‍❤‍👩🏻' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-6, uhlobo-1-2',
    '👩🏿‍❤‍👩🏼' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-6, uhlobo-3',
    '👩🏿‍❤‍👩🏽' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-6, uhlobo-4',
    '👩🏿‍❤‍👩🏾' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-6, uhlobo-5',
    '👩🏿‍❤‍👩🏿' => 'izithandani ezinenhliziyo: umama, umama, uhlobo-6',
    '👩🏻‍🐰‍👩🏼' => 'abasemame abasemcimbini: uhlobo-1-2, uhlobo-3',
    '👩🏻‍🐰‍👩🏽' => 'abasemame abasemcimbini: uhlobo-1-2, uhlobo-4',
    '👩🏻‍🐰‍👩🏾' => 'abasemame abasemcimbini: uhlobo-1-2, uhlobo-5',
    '👩🏻‍🐰‍👩🏿' => 'abasemame abasemcimbini: uhlobo-1-2, uhlobo-6',
    '👩🏼‍🐰‍👩🏻' => 'abasemame abasemcimbini: uhlobo-3, uhlobo-1-2',
    '👩🏼‍🐰‍👩🏽' => 'abasemame abasemcimbini: uhlobo-3, uhlobo-4',
    '👩🏼‍🐰‍👩🏾' => 'abasemame abasemcimbini: uhlobo-3, uhlobo-5',
    '👩🏼‍🐰‍👩🏿' => 'abasemame abasemcimbini: uhlobo-3, uhlobo-6',
    '👩🏽‍🐰‍👩🏻' => 'abasemame abasemcimbini: uhlobo-4, uhlobo-1-2',
    '👩🏽‍🐰‍👩🏼' => 'abasemame abasemcimbini: uhlobo-4, uhlobo-3',
    '👩🏽‍🐰‍👩🏾' => 'abasemame abasemcimbini: uhlobo-4, uhlobo-5',
    '👩🏽‍🐰‍👩🏿' => 'abasemame abasemcimbini: uhlobo-4, uhlobo-6',
    '👩🏾‍🐰‍👩🏻' => 'abasemame abasemcimbini: uhlobo-5, uhlobo-1-2',
    '👩🏾‍🐰‍👩🏼' => 'abasemame abasemcimbini: uhlobo-5, uhlobo-3',
    '👩🏾‍🐰‍👩🏽' => 'abasemame abasemcimbini: uhlobo-5, uhlobo-4',
    '👩🏾‍🐰‍👩🏿' => 'abasemame abasemcimbini: uhlobo-5, uhlobo-6',
    '👩🏿‍🐰‍👩🏻' => 'abasemame abasemcimbini: uhlobo-6, uhlobo-1-2',
    '👩🏿‍🐰‍👩🏼' => 'abasemame abasemcimbini: uhlobo-6, uhlobo-3',
    '👩🏿‍🐰‍👩🏽' => 'abasemame abasemcimbini: uhlobo-6, uhlobo-4',
    '👩🏿‍🐰‍👩🏾' => 'abasemame abasemcimbini: uhlobo-6, uhlobo-5',
    '🧑🏻‍🤝‍🧑🏻' => 'Abantu ababambene ngezandla: uhlobo-1-2',
    '🧑🏻‍🤝‍🧑🏼' => 'Abantu ababambene ngezandla: uhlobo-1-2, uhlobo-3',
    '🧑🏻‍🤝‍🧑🏽' => 'Abantu ababambene ngezandla: uhlobo-1-2, uhlobo-4',
    '🧑🏻‍🤝‍🧑🏾' => 'Abantu ababambene ngezandla: uhlobo-1-2, uhlobo-5',
    '🧑🏻‍🤝‍🧑🏿' => 'Abantu ababambene ngezandla: uhlobo-1-2, uhlobo-6',
    '🧑🏼‍🤝‍🧑🏻' => 'Abantu ababambene ngezandla: uhlobo-3, uhlobo-1-2',
    '🧑🏼‍🤝‍🧑🏼' => 'Abantu ababambene ngezandla: uhlobo-3',
    '🧑🏼‍🤝‍🧑🏽' => 'Abantu ababambene ngezandla: uhlobo-3, uhlobo-4',
    '🧑🏼‍🤝‍🧑🏾' => 'Abantu ababambene ngezandla: uhlobo-3, uhlobo-5',
    '🧑🏼‍🤝‍🧑🏿' => 'Abantu ababambene ngezandla: uhlobo-3, uhlobo-6',
    '🧑🏽‍🤝‍🧑🏻' => 'Abantu ababambene ngezandla: uhlobo-4, uhlobo-1-2',
    '🧑🏽‍🤝‍🧑🏼' => 'Abantu ababambene ngezandla: uhlobo-4, uhlobo-3',
    '🧑🏽‍🤝‍🧑🏽' => 'Abantu ababambene ngezandla: uhlobo-4',
    '🧑🏽‍🤝‍🧑🏾' => 'Abantu ababambene ngezandla: uhlobo-4, uhlobo-5',
    '🧑🏽‍🤝‍🧑🏿' => 'Abantu ababambene ngezandla: uhlobo-4, uhlobo-6',
    '🧑🏾‍🤝‍🧑🏻' => 'Abantu ababambene ngezandla: uhlobo-5, uhlobo-1-2',
    '🧑🏾‍🤝‍🧑🏼' => 'Abantu ababambene ngezandla: uhlobo-5, uhlobo-3',
    '🧑🏾‍🤝‍🧑🏽' => 'Abantu ababambene ngezandla: uhlobo-5, uhlobo-4',
    '🧑🏾‍🤝‍🧑🏾' => 'Abantu ababambene ngezandla: uhlobo-5',
    '🧑🏾‍🤝‍🧑🏿' => 'Abantu ababambene ngezandla: uhlobo-5, uhlobo-6',
    '🧑🏿‍🤝‍🧑🏻' => 'Abantu ababambene ngezandla: uhlobo-6, uhlobo-1-2',
    '🧑🏿‍🤝‍🧑🏼' => 'Abantu ababambene ngezandla: uhlobo-6, uhlobo-3',
    '🧑🏿‍🤝‍🧑🏽' => 'Abantu ababambene ngezandla: uhlobo-6, uhlobo-4',
    '🧑🏿‍🤝‍🧑🏾' => 'Abantu ababambene ngezandla: uhlobo-6, uhlobo-5',
    '🧑🏿‍🤝‍🧑🏿' => 'Abantu ababambene ngezandla: uhlobo-6',
    '👩🏻‍🤝‍👩🏼' => 'abasimame ababambene ngesandla: uhlobo-1-2, uhlobo-3',
    '👩🏻‍🤝‍👩🏽' => 'abasimame ababambene ngesandla: uhlobo-1-2, uhlobo-4',
    '👩🏻‍🤝‍👩🏾' => 'abasimame ababambene ngesandla: uhlobo-1-2, uhlobo-5',
    '👩🏻‍🤝‍👩🏿' => 'abasimame ababambene ngesandla: uhlobo-1-2, uhlobo-6',
    '👩🏼‍🤝‍👩🏻' => 'abasimame ababambene ngesandla: uhlobo-3, uhlobo-1-2',
    '👩🏼‍🤝‍👩🏽' => 'abasimame ababambene ngesandla: uhlobo-3, uhlobo-4',
    '👩🏼‍🤝‍👩🏾' => 'abasimame ababambene ngesandla: uhlobo-3, uhlobo-5',
    '👩🏼‍🤝‍👩🏿' => 'abasimame ababambene ngesandla: uhlobo-3, uhlobo-6',
    '👩🏽‍🤝‍👩🏻' => 'abasimame ababambene ngesandla: uhlobo-4, uhlobo-1-2',
    '👩🏽‍🤝‍👩🏼' => 'abasimame ababambene ngesandla: uhlobo-4, uhlobo-3',
    '👩🏽‍🤝‍👩🏾' => 'abasimame ababambene ngesandla: uhlobo-4, uhlobo-5',
    '👩🏽‍🤝‍👩🏿' => 'abasimame ababambene ngesandla: uhlobo-4, uhlobo-6',
    '👩🏾‍🤝‍👩🏻' => 'abasimame ababambene ngesandla: uhlobo-5, uhlobo-1-2',
    '👩🏾‍🤝‍👩🏼' => 'abasimame ababambene ngesandla: uhlobo-5, uhlobo-3',
    '👩🏾‍🤝‍👩🏽' => 'abasimame ababambene ngesandla: uhlobo-5, uhlobo-4',
    '👩🏾‍🤝‍👩🏿' => 'abasimame ababambene ngesandla: uhlobo-5, uhlobo-6',
    '👩🏿‍🤝‍👩🏻' => 'abasimame ababambene ngesandla: uhlobo-6, uhlobo-1-2',
    '👩🏿‍🤝‍👩🏼' => 'abasimame ababambene ngesandla: uhlobo-6, uhlobo-3',
    '👩🏿‍🤝‍👩🏽' => 'abasimame ababambene ngesandla: uhlobo-6, uhlobo-4',
    '👩🏿‍🤝‍👩🏾' => 'abasimame ababambene ngesandla: uhlobo-6, uhlobo-5',
    '👩🏻‍🤝‍👨🏼' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-1-2, uhlobo-3',
    '👩🏻‍🤝‍👨🏽' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-1-2, uhlobo-4',
    '👩🏻‍🤝‍👨🏾' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-1-2, uhlobo-5',
    '👩🏻‍🤝‍👨🏿' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-1-2, uhlobo-6',
    '👩🏼‍🤝‍👨🏻' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-3, uhlobo-1-2',
    '👩🏼‍🤝‍👨🏽' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-3, uhlobo-4',
    '👩🏼‍🤝‍👨🏾' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-3, uhlobo-5',
    '👩🏼‍🤝‍👨🏿' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-3, uhlobo-6',
    '👩🏽‍🤝‍👨🏻' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-4, uhlobo-1-2',
    '👩🏽‍🤝‍👨🏼' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-4, uhlobo-3',
    '👩🏽‍🤝‍👨🏾' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-4, uhlobo-5',
    '👩🏽‍🤝‍👨🏿' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-4, uhlobo-6',
    '👩🏾‍🤝‍👨🏻' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-5, uhlobo-1-2',
    '👩🏾‍🤝‍👨🏼' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-5, uhlobo-3',
    '👩🏾‍🤝‍👨🏽' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-5, uhlobo-4',
    '👩🏾‍🤝‍👨🏿' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-5, uhlobo-6',
    '👩🏿‍🤝‍👨🏻' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-6, uhlobo-1-2',
    '👩🏿‍🤝‍👨🏼' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-6, uhlobo-3',
    '👩🏿‍🤝‍👨🏽' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-6, uhlobo-4',
    '👩🏿‍🤝‍👨🏾' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-6, uhlobo-5',
    '👨🏻‍🤝‍👨🏼' => 'amadoda amabili abambene ngesandla: uhlobo-1-2, uhlobo-3',
    '👨🏻‍🤝‍👨🏽' => 'amadoda amabili abambene ngesandla: uhlobo-1-2, uhlobo-4',
    '👨🏻‍🤝‍👨🏾' => 'amadoda amabili abambene ngesandla: uhlobo-1-2, uhlobo-5',
    '👨🏻‍🤝‍👨🏿' => 'amadoda amabili abambene ngesandla: uhlobo-1-2, uhlobo-6',
    '👨🏼‍🤝‍👨🏻' => 'amadoda amabili abambene ngesandla: uhlobo-3, uhlobo-1-2',
    '👨🏼‍🤝‍👨🏽' => 'amadoda amabili abambene ngesandla: uhlobo-3, uhlobo-4',
    '👨🏼‍🤝‍👨🏾' => 'amadoda amabili abambene ngesandla: uhlobo-3, uhlobo-5',
    '👨🏼‍🤝‍👨🏿' => 'amadoda amabili abambene ngesandla: uhlobo-3, uhlobo-6',
    '👨🏽‍🤝‍👨🏻' => 'amadoda amabili abambene ngesandla: uhlobo-4, uhlobo-1-2',
    '👨🏽‍🤝‍👨🏼' => 'amadoda amabili abambene ngesandla: uhlobo-4, uhlobo-3',
    '👨🏽‍🤝‍👨🏾' => 'amadoda amabili abambene ngesandla: uhlobo-4, uhlobo-5',
    '👨🏽‍🤝‍👨🏿' => 'amadoda amabili abambene ngesandla: uhlobo-4, uhlobo-6',
    '👨🏾‍🤝‍👨🏻' => 'amadoda amabili abambene ngesandla: uhlobo-5, uhlobo-1-2',
    '👨🏾‍🤝‍👨🏼' => 'amadoda amabili abambene ngesandla: uhlobo-5, uhlobo-3',
    '👨🏾‍🤝‍👨🏽' => 'amadoda amabili abambene ngesandla: uhlobo-5, uhlobo-4',
    '👨🏾‍🤝‍👨🏿' => 'amadoda amabili abambene ngesandla: uhlobo-5, uhlobo-6',
    '👨🏿‍🤝‍👨🏻' => 'amadoda amabili abambene ngesandla: uhlobo-6, uhlobo-1-2',
    '👨🏿‍🤝‍👨🏼' => 'amadoda amabili abambene ngesandla: uhlobo-6, uhlobo-3',
    '👨🏿‍🤝‍👨🏽' => 'amadoda amabili abambene ngesandla: uhlobo-6, uhlobo-4',
    '👨🏿‍🤝‍👨🏾' => 'amadoda amabili abambene ngesandla: uhlobo-6, uhlobo-5',
    '👩‍❤‍💋‍👨' => 'ukuqabula: umama, indoda',
    '👨‍❤‍💋‍👨' => 'ukuqabula: indoda, indoda',
    '👩‍❤‍💋‍👩' => 'ukuqabula: umama, umama',
    '👨‍👩‍👧‍👦' => 'umndeni: indoda, umama, intombazane, umfana',
    '👨‍👩‍👦‍👦' => 'umndeni: indoda, umama, umfana, umfana',
    '👨‍👩‍👧‍👧' => 'umndeni: indoda, umama, intombazane, intombazane',
    '👨‍👨‍👧‍👦' => 'umndeni: indoda, indoda, intombazane, umfana',
    '👨‍👨‍👦‍👦' => 'umndeni: indoda, indoda, umfana, umfana',
    '👨‍👨‍👧‍👧' => 'umndeni: indoda, indoda, intombazane, intombazane',
    '👩‍👩‍👧‍👦' => 'umndeni: umama, umama, intombazane, umfana',
    '👩‍👩‍👦‍👦' => 'umndeni: umama, umama, umfana, umfana',
    '👩‍👩‍👧‍👧' => 'umndeni: umama, umama, intombazane, intombazane',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'ifulegi: I-England',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'ifulegi: I-Scotland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'ifulegi: i-Wales',
    '🧑‍🧑‍🧒‍🧒' => 'family: adult, adult, child, child',
    '🫱🏻‍🫲🏼' => 'xhawula: uhlobo-1-2, uhlobo-3',
    '🫱🏻‍🫲🏽' => 'xhawula: uhlobo-1-2, uhlobo-4',
    '🫱🏻‍🫲🏾' => 'xhawula: uhlobo-1-2, uhlobo-5',
    '🫱🏻‍🫲🏿' => 'xhawula: uhlobo-1-2, uhlobo-6',
    '🫱🏼‍🫲🏻' => 'xhawula: uhlobo-3, uhlobo-1-2',
    '🫱🏼‍🫲🏽' => 'xhawula: uhlobo-3, uhlobo-4',
    '🫱🏼‍🫲🏾' => 'xhawula: uhlobo-3, uhlobo-5',
    '🫱🏼‍🫲🏿' => 'xhawula: uhlobo-3, uhlobo-6',
    '🫱🏽‍🫲🏻' => 'xhawula: uhlobo-4, uhlobo-1-2',
    '🫱🏽‍🫲🏼' => 'xhawula: uhlobo-4, uhlobo-3',
    '🫱🏽‍🫲🏾' => 'xhawula: uhlobo-4, uhlobo-5',
    '🫱🏽‍🫲🏿' => 'xhawula: uhlobo-4, uhlobo-6',
    '🫱🏾‍🫲🏻' => 'xhawula: uhlobo-5, uhlobo-1-2',
    '🫱🏾‍🫲🏼' => 'xhawula: uhlobo-5, uhlobo-3',
    '🫱🏾‍🫲🏽' => 'xhawula: uhlobo-5, uhlobo-4',
    '🫱🏾‍🫲🏿' => 'xhawula: uhlobo-5, uhlobo-6',
    '🫱🏿‍🫲🏻' => 'xhawula: uhlobo-6, uhlobo-1-2',
    '🫱🏿‍🫲🏼' => 'xhawula: uhlobo-6, uhlobo-3',
    '🫱🏿‍🫲🏽' => 'xhawula: uhlobo-6, uhlobo-4',
    '🫱🏿‍🫲🏾' => 'xhawula: uhlobo-6, uhlobo-5',
    '👩‍❤‍👨' => 'izithandani ezinenhliziyo: umama, indoda',
    '👨‍❤‍👨' => 'izithandani ezinenhliziyo: indoda, indoda',
    '👩‍❤‍👩' => 'izithandani ezinenhliziyo: umama, umama',
    '👨‍👩‍👦' => 'umndeni: indoda, umama, umfana',
    '👨‍👩‍👧' => 'umndeni: indoda, umama, intombazane',
    '👨‍👨‍👦' => 'umndeni: indoda, indoda, umfana',
    '👨‍👨‍👧' => 'umndeni: indoda, indoda, intombazane',
    '👩‍👩‍👦' => 'umndeni: umama, umama, umfana',
    '👩‍👩‍👧' => 'umndeni: umama, umama, intombazane',
    '👨‍👦‍👦' => 'umndeni: indoda, umfana, umfana',
    '👨‍👧‍👦' => 'umndeni: indoda, intombazane, umfana',
    '👨‍👧‍👧' => 'umndeni: indoda, intombazane, intombazane',
    '👩‍👦‍👦' => 'umndeni: umama, umfana, umfana',
    '👩‍👧‍👦' => 'umndeni: umama, intombazane, umfana',
    '👩‍👧‍👧' => 'umndeni: umama, intombazane, intombazane',
    '🧑‍🤝‍🧑' => 'Abantu ababambene ngezandla',
    '🧑‍🧑‍🧒' => 'umndeni: omdala, omdala, ingane, ingane',
    '🧑‍🧒‍🧒' => 'family: adult, child, child',
    '🧑🏻‍🦰' => 'mdala: uhlobo-1-2, izinwele ezibomvu',
    '🧑🏼‍🦰' => 'mdala: uhlobo-3, izinwele ezibomvu',
    '🧑🏽‍🦰' => 'mdala: uhlobo-4, izinwele ezibomvu',
    '🧑🏾‍🦰' => 'mdala: uhlobo-5, izinwele ezibomvu',
    '🧑🏿‍🦰' => 'mdala: uhlobo-6, izinwele ezibomvu',
    '🧑🏻‍🦱' => 'mdala: uhlobo-1-2, curly hair',
    '🧑🏼‍🦱' => 'mdala: uhlobo-3, curly hair',
    '🧑🏽‍🦱' => 'mdala: uhlobo-4, curly hair',
    '🧑🏾‍🦱' => 'mdala: uhlobo-5, curly hair',
    '🧑🏿‍🦱' => 'mdala: uhlobo-6, curly hair',
    '🧑🏻‍🦳' => 'mdala: uhlobo-1-2, izinwele ezimpunga',
    '🧑🏼‍🦳' => 'mdala: uhlobo-3, izinwele ezimpunga',
    '🧑🏽‍🦳' => 'mdala: uhlobo-4, izinwele ezimpunga',
    '🧑🏾‍🦳' => 'mdala: uhlobo-5, izinwele ezimpunga',
    '🧑🏿‍🦳' => 'mdala: uhlobo-6, izinwele ezimpunga',
    '🧑🏻‍🦲' => 'mdala: uhlobo-1-2, imbungculu',
    '🧑🏼‍🦲' => 'mdala: uhlobo-3, imbungculu',
    '🧑🏽‍🦲' => 'mdala: uhlobo-4, imbungculu',
    '🧑🏾‍🦲' => 'mdala: uhlobo-5, imbungculu',
    '🧑🏿‍🦲' => 'mdala: uhlobo-6, imbungculu',
    '🧑🏻‍🩰' => 'ballet dancer: uhlobo-1-2',
    '🧑🏼‍🩰' => 'ballet dancer: uhlobo-3',
    '🧑🏽‍🩰' => 'ballet dancer: uhlobo-4',
    '🧑🏾‍🩰' => 'ballet dancer: uhlobo-5',
    '🧑🏿‍🩰' => 'ballet dancer: uhlobo-6',
    '🧔🏻‍♂' => 'indoda enezindevu: uhlobo-1-2',
    '🧔🏼‍♂' => 'indoda enezindevu: uhlobo-3',
    '🧔🏽‍♂' => 'indoda enezindevu: uhlobo-4',
    '🧔🏾‍♂' => 'indoda enezindevu: uhlobo-5',
    '🧔🏿‍♂' => 'indoda enezindevu: uhlobo-6',
    '👱🏻‍♂' => 'indoda: uhlobo-1-2, izinwele ezimhlophe',
    '👱🏼‍♂' => 'indoda: uhlobo-3, izinwele ezimhlophe',
    '👱🏽‍♂' => 'indoda: uhlobo-4, izinwele ezimhlophe',
    '👱🏾‍♂' => 'indoda: uhlobo-5, izinwele ezimhlophe',
    '👱🏿‍♂' => 'indoda: uhlobo-6, izinwele ezimhlophe',
    '👨🏻‍🦰' => 'indoda: uhlobo-1-2, izinwele ezibomvu',
    '👨🏼‍🦰' => 'indoda: uhlobo-3, izinwele ezibomvu',
    '👨🏽‍🦰' => 'indoda: uhlobo-4, izinwele ezibomvu',
    '👨🏾‍🦰' => 'indoda: uhlobo-5, izinwele ezibomvu',
    '👨🏿‍🦰' => 'indoda: uhlobo-6, izinwele ezibomvu',
    '👨🏻‍🦱' => 'indoda: uhlobo-1-2, curly hair',
    '👨🏼‍🦱' => 'indoda: uhlobo-3, curly hair',
    '👨🏽‍🦱' => 'indoda: uhlobo-4, curly hair',
    '👨🏾‍🦱' => 'indoda: uhlobo-5, curly hair',
    '👨🏿‍🦱' => 'indoda: uhlobo-6, curly hair',
    '👨🏻‍🦳' => 'indoda: uhlobo-1-2, izinwele ezimpunga',
    '👨🏼‍🦳' => 'indoda: uhlobo-3, izinwele ezimpunga',
    '👨🏽‍🦳' => 'indoda: uhlobo-4, izinwele ezimpunga',
    '👨🏾‍🦳' => 'indoda: uhlobo-5, izinwele ezimpunga',
    '👨🏿‍🦳' => 'indoda: uhlobo-6, izinwele ezimpunga',
    '👨🏻‍🦲' => 'indoda: uhlobo-1-2, imbungculu',
    '👨🏼‍🦲' => 'indoda: uhlobo-3, imbungculu',
    '👨🏽‍🦲' => 'indoda: uhlobo-4, imbungculu',
    '👨🏾‍🦲' => 'indoda: uhlobo-5, imbungculu',
    '👨🏿‍🦲' => 'indoda: uhlobo-6, imbungculu',
    '🧔🏻‍♀' => 'umuntu wesimame : uhlobo-1-2, onezindevu',
    '🧔🏼‍♀' => 'umuntu wesimame : uhlobo-3, onezindevu',
    '🧔🏽‍♀' => 'umuntu wesimame : uhlobo-4, onezindevu',
    '🧔🏾‍♀' => 'umuntu wesimame : uhlobo-5, onezindevu',
    '🧔🏿‍♀' => 'umuntu wesimame : uhlobo-6, onezindevu',
    '👱🏻‍♀' => 'umama: uhlobo-1-2, izinwele ezimhlophe',
    '👱🏼‍♀' => 'umama: uhlobo-3, izinwele ezimhlophe',
    '👱🏽‍♀' => 'umama: uhlobo-4, izinwele ezimhlophe',
    '👱🏾‍♀' => 'umama: uhlobo-5, izinwele ezimhlophe',
    '👱🏿‍♀' => 'umama: uhlobo-6, izinwele ezimhlophe',
    '👩🏻‍🦰' => 'umama: uhlobo-1-2, izinwele ezibomvu',
    '👩🏼‍🦰' => 'umama: uhlobo-3, izinwele ezibomvu',
    '👩🏽‍🦰' => 'umama: uhlobo-4, izinwele ezibomvu',
    '👩🏾‍🦰' => 'umama: uhlobo-5, izinwele ezibomvu',
    '👩🏿‍🦰' => 'umama: uhlobo-6, izinwele ezibomvu',
    '👩🏻‍🦱' => 'umama: uhlobo-1-2, curly hair',
    '👩🏼‍🦱' => 'umama: uhlobo-3, curly hair',
    '👩🏽‍🦱' => 'umama: uhlobo-4, curly hair',
    '👩🏾‍🦱' => 'umama: uhlobo-5, curly hair',
    '👩🏿‍🦱' => 'umama: uhlobo-6, curly hair',
    '👩🏻‍🦳' => 'umama: uhlobo-1-2, izinwele ezimpunga',
    '👩🏼‍🦳' => 'umama: uhlobo-3, izinwele ezimpunga',
    '👩🏽‍🦳' => 'umama: uhlobo-4, izinwele ezimpunga',
    '👩🏾‍🦳' => 'umama: uhlobo-5, izinwele ezimpunga',
    '👩🏿‍🦳' => 'umama: uhlobo-6, izinwele ezimpunga',
    '👩🏻‍🦲' => 'umama: uhlobo-1-2, imbungculu',
    '👩🏼‍🦲' => 'umama: uhlobo-3, imbungculu',
    '👩🏽‍🦲' => 'umama: uhlobo-4, imbungculu',
    '👩🏾‍🦲' => 'umama: uhlobo-5, imbungculu',
    '👩🏿‍🦲' => 'umama: uhlobo-6, imbungculu',
    '🙍🏻‍♂' => 'indoda ehwaqabele: uhlobo-1-2',
    '🙍🏼‍♂' => 'indoda ehwaqabele: uhlobo-3',
    '🙍🏽‍♂' => 'indoda ehwaqabele: uhlobo-4',
    '🙍🏾‍♂' => 'indoda ehwaqabele: uhlobo-5',
    '🙍🏿‍♂' => 'indoda ehwaqabele: uhlobo-6',
    '🙍🏻‍♀' => 'owesimame ohwaqabele: uhlobo-1-2',
    '🙍🏼‍♀' => 'owesimame ohwaqabele: uhlobo-3',
    '🙍🏽‍♀' => 'owesimame ohwaqabele: uhlobo-4',
    '🙍🏾‍♀' => 'owesimame ohwaqabele: uhlobo-5',
    '🙍🏿‍♀' => 'owesimame ohwaqabele: uhlobo-6',
    '🙎🏻‍♂' => 'indoda edangele: uhlobo-1-2',
    '🙎🏼‍♂' => 'indoda edangele: uhlobo-3',
    '🙎🏽‍♂' => 'indoda edangele: uhlobo-4',
    '🙎🏾‍♂' => 'indoda edangele: uhlobo-5',
    '🙎🏿‍♂' => 'indoda edangele: uhlobo-6',
    '🙎🏻‍♀' => 'owesimame odangele: uhlobo-1-2',
    '🙎🏼‍♀' => 'owesimame odangele: uhlobo-3',
    '🙎🏽‍♀' => 'owesimame odangele: uhlobo-4',
    '🙎🏾‍♀' => 'owesimame odangele: uhlobo-5',
    '🙎🏿‍♀' => 'owesimame odangele: uhlobo-6',
    '🙅🏻‍♂' => 'indoda eveza ukuthi akulungile: uhlobo-1-2',
    '🙅🏼‍♂' => 'indoda eveza ukuthi akulungile: uhlobo-3',
    '🙅🏽‍♂' => 'indoda eveza ukuthi akulungile: uhlobo-4',
    '🙅🏾‍♂' => 'indoda eveza ukuthi akulungile: uhlobo-5',
    '🙅🏿‍♂' => 'indoda eveza ukuthi akulungile: uhlobo-6',
    '🙅🏻‍♀' => 'owesimame oveza ukuthi akulungile: uhlobo-1-2',
    '🙅🏼‍♀' => 'owesimame oveza ukuthi akulungile: uhlobo-3',
    '🙅🏽‍♀' => 'owesimame oveza ukuthi akulungile: uhlobo-4',
    '🙅🏾‍♀' => 'owesimame oveza ukuthi akulungile: uhlobo-5',
    '🙅🏿‍♀' => 'owesimame oveza ukuthi akulungile: uhlobo-6',
    '🙆🏻‍♂' => 'owesilisa oveza ukuthi kulungile: uhlobo-1-2',
    '🙆🏼‍♂' => 'owesilisa oveza ukuthi kulungile: uhlobo-3',
    '🙆🏽‍♂' => 'owesilisa oveza ukuthi kulungile: uhlobo-4',
    '🙆🏾‍♂' => 'owesilisa oveza ukuthi kulungile: uhlobo-5',
    '🙆🏿‍♂' => 'owesilisa oveza ukuthi kulungile: uhlobo-6',
    '🙆🏻‍♀' => 'owesimame oveza ukuthi kulungile: uhlobo-1-2',
    '🙆🏼‍♀' => 'owesimame oveza ukuthi kulungile: uhlobo-3',
    '🙆🏽‍♀' => 'owesimame oveza ukuthi kulungile: uhlobo-4',
    '🙆🏾‍♀' => 'owesimame oveza ukuthi kulungile: uhlobo-5',
    '🙆🏿‍♀' => 'owesimame oveza ukuthi kulungile: uhlobo-6',
    '💁🏻‍♂' => 'indoda ecela ngesandla: uhlobo-1-2',
    '💁🏼‍♂' => 'indoda ecela ngesandla: uhlobo-3',
    '💁🏽‍♂' => 'indoda ecela ngesandla: uhlobo-4',
    '💁🏾‍♂' => 'indoda ecela ngesandla: uhlobo-5',
    '💁🏿‍♂' => 'indoda ecela ngesandla: uhlobo-6',
    '💁🏻‍♀' => 'owesimame ocela ngesandla: uhlobo-1-2',
    '💁🏼‍♀' => 'owesimame ocela ngesandla: uhlobo-3',
    '💁🏽‍♀' => 'owesimame ocela ngesandla: uhlobo-4',
    '💁🏾‍♀' => 'owesimame ocela ngesandla: uhlobo-5',
    '💁🏿‍♀' => 'owesimame ocela ngesandla: uhlobo-6',
    '🙋🏻‍♂' => 'indoda ephakamise isandla: uhlobo-1-2',
    '🙋🏼‍♂' => 'indoda ephakamise isandla: uhlobo-3',
    '🙋🏽‍♂' => 'indoda ephakamise isandla: uhlobo-4',
    '🙋🏾‍♂' => 'indoda ephakamise isandla: uhlobo-5',
    '🙋🏿‍♂' => 'indoda ephakamise isandla: uhlobo-6',
    '🙋🏻‍♀' => 'owesimame ophakamise isandla: uhlobo-1-2',
    '🙋🏼‍♀' => 'owesimame ophakamise isandla: uhlobo-3',
    '🙋🏽‍♀' => 'owesimame ophakamise isandla: uhlobo-4',
    '🙋🏾‍♀' => 'owesimame ophakamise isandla: uhlobo-5',
    '🙋🏿‍♀' => 'owesimame ophakamise isandla: uhlobo-6',
    '🧏🏻‍♂' => 'indoda engezwa: uhlobo-1-2',
    '🧏🏼‍♂' => 'indoda engezwa: uhlobo-3',
    '🧏🏽‍♂' => 'indoda engezwa: uhlobo-4',
    '🧏🏾‍♂' => 'indoda engezwa: uhlobo-5',
    '🧏🏿‍♂' => 'indoda engezwa: uhlobo-6',
    '🧏🏻‍♀' => 'umama ongezwa: uhlobo-1-2',
    '🧏🏼‍♀' => 'umama ongezwa: uhlobo-3',
    '🧏🏽‍♀' => 'umama ongezwa: uhlobo-4',
    '🧏🏾‍♀' => 'umama ongezwa: uhlobo-5',
    '🧏🏿‍♀' => 'umama ongezwa: uhlobo-6',
    '🙇🏻‍♂' => 'indoda ethobe kakhulu: uhlobo-1-2',
    '🙇🏼‍♂' => 'indoda ethobe kakhulu: uhlobo-3',
    '🙇🏽‍♂' => 'indoda ethobe kakhulu: uhlobo-4',
    '🙇🏾‍♂' => 'indoda ethobe kakhulu: uhlobo-5',
    '🙇🏿‍♂' => 'indoda ethobe kakhulu: uhlobo-6',
    '🙇🏻‍♀' => 'owesimame othobe kakhulu: uhlobo-1-2',
    '🙇🏼‍♀' => 'owesimame othobe kakhulu: uhlobo-3',
    '🙇🏽‍♀' => 'owesimame othobe kakhulu: uhlobo-4',
    '🙇🏾‍♀' => 'owesimame othobe kakhulu: uhlobo-5',
    '🙇🏿‍♀' => 'owesimame othobe kakhulu: uhlobo-6',
    '🤦🏻‍♂' => 'ukuzifihla kowesilisa: uhlobo-1-2',
    '🤦🏼‍♂' => 'ukuzifihla kowesilisa: uhlobo-3',
    '🤦🏽‍♂' => 'ukuzifihla kowesilisa: uhlobo-4',
    '🤦🏾‍♂' => 'ukuzifihla kowesilisa: uhlobo-5',
    '🤦🏿‍♂' => 'ukuzifihla kowesilisa: uhlobo-6',
    '🤦🏻‍♀' => 'ukuzifihla kowesimame: uhlobo-1-2',
    '🤦🏼‍♀' => 'ukuzifihla kowesimame: uhlobo-3',
    '🤦🏽‍♀' => 'ukuzifihla kowesimame: uhlobo-4',
    '🤦🏾‍♀' => 'ukuzifihla kowesimame: uhlobo-5',
    '🤦🏿‍♀' => 'ukuzifihla kowesimame: uhlobo-6',
    '🤷🏻‍♂' => 'ukushukuza amahlombe kowesilisa: uhlobo-1-2',
    '🤷🏼‍♂' => 'ukushukuza amahlombe kowesilisa: uhlobo-3',
    '🤷🏽‍♂' => 'ukushukuza amahlombe kowesilisa: uhlobo-4',
    '🤷🏾‍♂' => 'ukushukuza amahlombe kowesilisa: uhlobo-5',
    '🤷🏿‍♂' => 'ukushukuza amahlombe kowesilisa: uhlobo-6',
    '🤷🏻‍♀' => 'ukushukuza amahlombe kowesimame: uhlobo-1-2',
    '🤷🏼‍♀' => 'ukushukuza amahlombe kowesimame: uhlobo-3',
    '🤷🏽‍♀' => 'ukushukuza amahlombe kowesimame: uhlobo-4',
    '🤷🏾‍♀' => 'ukushukuza amahlombe kowesimame: uhlobo-5',
    '🤷🏿‍♀' => 'ukushukuza amahlombe kowesimame: uhlobo-6',
    '🧑🏻‍⚕' => 'umsebenzi wezempilo: uhlobo-1-2',
    '🧑🏼‍⚕' => 'umsebenzi wezempilo: uhlobo-3',
    '🧑🏽‍⚕' => 'umsebenzi wezempilo: uhlobo-4',
    '🧑🏾‍⚕' => 'umsebenzi wezempilo: uhlobo-5',
    '🧑🏿‍⚕' => 'umsebenzi wezempilo: uhlobo-6',
    '👨🏻‍⚕' => 'unesi wesilisa: uhlobo-1-2',
    '👨🏼‍⚕' => 'unesi wesilisa: uhlobo-3',
    '👨🏽‍⚕' => 'unesi wesilisa: uhlobo-4',
    '👨🏾‍⚕' => 'unesi wesilisa: uhlobo-5',
    '👨🏿‍⚕' => 'unesi wesilisa: uhlobo-6',
    '👩🏻‍⚕' => 'unesi wesifazane: uhlobo-1-2',
    '👩🏼‍⚕' => 'unesi wesifazane: uhlobo-3',
    '👩🏽‍⚕' => 'unesi wesifazane: uhlobo-4',
    '👩🏾‍⚕' => 'unesi wesifazane: uhlobo-5',
    '👩🏿‍⚕' => 'unesi wesifazane: uhlobo-6',
    '🧑🏻‍🎓' => 'umfundi: uhlobo-1-2',
    '🧑🏼‍🎓' => 'umfundi: uhlobo-3',
    '🧑🏽‍🎓' => 'umfundi: uhlobo-4',
    '🧑🏾‍🎓' => 'umfundi: uhlobo-5',
    '🧑🏿‍🎓' => 'umfundi: uhlobo-6',
    '👨🏻‍🎓' => 'umfundi wesilisa: uhlobo-1-2',
    '👨🏼‍🎓' => 'umfundi wesilisa: uhlobo-3',
    '👨🏽‍🎓' => 'umfundi wesilisa: uhlobo-4',
    '👨🏾‍🎓' => 'umfundi wesilisa: uhlobo-5',
    '👨🏿‍🎓' => 'umfundi wesilisa: uhlobo-6',
    '👩🏻‍🎓' => 'umfundi wesifazane: uhlobo-1-2',
    '👩🏼‍🎓' => 'umfundi wesifazane: uhlobo-3',
    '👩🏽‍🎓' => 'umfundi wesifazane: uhlobo-4',
    '👩🏾‍🎓' => 'umfundi wesifazane: uhlobo-5',
    '👩🏿‍🎓' => 'umfundi wesifazane: uhlobo-6',
    '🧑🏻‍🏫' => 'uthisha: uhlobo-1-2',
    '🧑🏼‍🏫' => 'uthisha: uhlobo-3',
    '🧑🏽‍🏫' => 'uthisha: uhlobo-4',
    '🧑🏾‍🏫' => 'uthisha: uhlobo-5',
    '🧑🏿‍🏫' => 'uthisha: uhlobo-6',
    '👨🏻‍🏫' => 'uthisha wesilisa: uhlobo-1-2',
    '👨🏼‍🏫' => 'uthisha wesilisa: uhlobo-3',
    '👨🏽‍🏫' => 'uthisha wesilisa: uhlobo-4',
    '👨🏾‍🏫' => 'uthisha wesilisa: uhlobo-5',
    '👨🏿‍🏫' => 'uthisha wesilisa: uhlobo-6',
    '👩🏻‍🏫' => 'uthisha wesifazane: uhlobo-1-2',
    '👩🏼‍🏫' => 'uthisha wesifazane: uhlobo-3',
    '👩🏽‍🏫' => 'uthisha wesifazane: uhlobo-4',
    '👩🏾‍🏫' => 'uthisha wesifazane: uhlobo-5',
    '👩🏿‍🏫' => 'uthisha wesifazane: uhlobo-6',
    '🧑🏻‍⚖' => 'umahluleli: uhlobo-1-2',
    '🧑🏼‍⚖' => 'umahluleli: uhlobo-3',
    '🧑🏽‍⚖' => 'umahluleli: uhlobo-4',
    '🧑🏾‍⚖' => 'umahluleli: uhlobo-5',
    '🧑🏿‍⚖' => 'umahluleli: uhlobo-6',
    '👨🏻‍⚖' => 'ijaji lesilisa: uhlobo-1-2',
    '👨🏼‍⚖' => 'ijaji lesilisa: uhlobo-3',
    '👨🏽‍⚖' => 'ijaji lesilisa: uhlobo-4',
    '👨🏾‍⚖' => 'ijaji lesilisa: uhlobo-5',
    '👨🏿‍⚖' => 'ijaji lesilisa: uhlobo-6',
    '👩🏻‍⚖' => 'ijaji lesifazane: uhlobo-1-2',
    '👩🏼‍⚖' => 'ijaji lesifazane: uhlobo-3',
    '👩🏽‍⚖' => 'ijaji lesifazane: uhlobo-4',
    '👩🏾‍⚖' => 'ijaji lesifazane: uhlobo-5',
    '👩🏿‍⚖' => 'ijaji lesifazane: uhlobo-6',
    '🧑🏻‍🌾' => 'umlimi: uhlobo-1-2',
    '🧑🏼‍🌾' => 'umlimi: uhlobo-3',
    '🧑🏽‍🌾' => 'umlimi: uhlobo-4',
    '🧑🏾‍🌾' => 'umlimi: uhlobo-5',
    '🧑🏿‍🌾' => 'umlimi: uhlobo-6',
    '👨🏻‍🌾' => 'umlimi wesilisa: uhlobo-1-2',
    '👨🏼‍🌾' => 'umlimi wesilisa: uhlobo-3',
    '👨🏽‍🌾' => 'umlimi wesilisa: uhlobo-4',
    '👨🏾‍🌾' => 'umlimi wesilisa: uhlobo-5',
    '👨🏿‍🌾' => 'umlimi wesilisa: uhlobo-6',
    '👩🏻‍🌾' => 'umlimi wesimame: uhlobo-1-2',
    '👩🏼‍🌾' => 'umlimi wesimame: uhlobo-3',
    '👩🏽‍🌾' => 'umlimi wesimame: uhlobo-4',
    '👩🏾‍🌾' => 'umlimi wesimame: uhlobo-5',
    '👩🏿‍🌾' => 'umlimi wesimame: uhlobo-6',
    '🧑🏻‍🍳' => 'pheka: uhlobo-1-2',
    '🧑🏼‍🍳' => 'pheka: uhlobo-3',
    '🧑🏽‍🍳' => 'pheka: uhlobo-4',
    '🧑🏾‍🍳' => 'pheka: uhlobo-5',
    '🧑🏿‍🍳' => 'pheka: uhlobo-6',
    '👨🏻‍🍳' => 'umpheki wesilisa: uhlobo-1-2',
    '👨🏼‍🍳' => 'umpheki wesilisa: uhlobo-3',
    '👨🏽‍🍳' => 'umpheki wesilisa: uhlobo-4',
    '👨🏾‍🍳' => 'umpheki wesilisa: uhlobo-5',
    '👨🏿‍🍳' => 'umpheki wesilisa: uhlobo-6',
    '👩🏻‍🍳' => 'umpheki wesimame: uhlobo-1-2',
    '👩🏼‍🍳' => 'umpheki wesimame: uhlobo-3',
    '👩🏽‍🍳' => 'umpheki wesimame: uhlobo-4',
    '👩🏾‍🍳' => 'umpheki wesimame: uhlobo-5',
    '👩🏿‍🍳' => 'umpheki wesimame: uhlobo-6',
    '🧑🏻‍🔧' => 'umakhenikha: uhlobo-1-2',
    '🧑🏼‍🔧' => 'umakhenikha: uhlobo-3',
    '🧑🏽‍🔧' => 'umakhenikha: uhlobo-4',
    '🧑🏾‍🔧' => 'umakhenikha: uhlobo-5',
    '🧑🏿‍🔧' => 'umakhenikha: uhlobo-6',
    '👨🏻‍🔧' => 'umakhenikha wesilisa: uhlobo-1-2',
    '👨🏼‍🔧' => 'umakhenikha wesilisa: uhlobo-3',
    '👨🏽‍🔧' => 'umakhenikha wesilisa: uhlobo-4',
    '👨🏾‍🔧' => 'umakhenikha wesilisa: uhlobo-5',
    '👨🏿‍🔧' => 'umakhenikha wesilisa: uhlobo-6',
    '👩🏻‍🔧' => 'umakhenikha wesimame: uhlobo-1-2',
    '👩🏼‍🔧' => 'umakhenikha wesimame: uhlobo-3',
    '👩🏽‍🔧' => 'umakhenikha wesimame: uhlobo-4',
    '👩🏾‍🔧' => 'umakhenikha wesimame: uhlobo-5',
    '👩🏿‍🔧' => 'umakhenikha wesimame: uhlobo-6',
    '🧑🏻‍🏭' => 'umsebenzi wasefemini: uhlobo-1-2',
    '🧑🏼‍🏭' => 'umsebenzi wasefemini: uhlobo-3',
    '🧑🏽‍🏭' => 'umsebenzi wasefemini: uhlobo-4',
    '🧑🏾‍🏭' => 'umsebenzi wasefemini: uhlobo-5',
    '🧑🏿‍🏭' => 'umsebenzi wasefemini: uhlobo-6',
    '👨🏻‍🏭' => 'umsebenzi wasefemini wesilisa: uhlobo-1-2',
    '👨🏼‍🏭' => 'umsebenzi wasefemini wesilisa: uhlobo-3',
    '👨🏽‍🏭' => 'umsebenzi wasefemini wesilisa: uhlobo-4',
    '👨🏾‍🏭' => 'umsebenzi wasefemini wesilisa: uhlobo-5',
    '👨🏿‍🏭' => 'umsebenzi wasefemini wesilisa: uhlobo-6',
    '👩🏻‍🏭' => 'umsebenzi wasefemini wesifazane: uhlobo-1-2',
    '👩🏼‍🏭' => 'umsebenzi wasefemini wesifazane: uhlobo-3',
    '👩🏽‍🏭' => 'umsebenzi wasefemini wesifazane: uhlobo-4',
    '👩🏾‍🏭' => 'umsebenzi wasefemini wesifazane: uhlobo-5',
    '👩🏿‍🏭' => 'umsebenzi wasefemini wesifazane: uhlobo-6',
    '🧑🏻‍💼' => 'umsebenzi wase-ofisi: uhlobo-1-2',
    '🧑🏼‍💼' => 'umsebenzi wase-ofisi: uhlobo-3',
    '🧑🏽‍💼' => 'umsebenzi wase-ofisi: uhlobo-4',
    '🧑🏾‍💼' => 'umsebenzi wase-ofisi: uhlobo-5',
    '🧑🏿‍💼' => 'umsebenzi wase-ofisi: uhlobo-6',
    '👨🏻‍💼' => 'umsebenzi wasehhovisi wesilisa: uhlobo-1-2',
    '👨🏼‍💼' => 'umsebenzi wasehhovisi wesilisa: uhlobo-3',
    '👨🏽‍💼' => 'umsebenzi wasehhovisi wesilisa: uhlobo-4',
    '👨🏾‍💼' => 'umsebenzi wasehhovisi wesilisa: uhlobo-5',
    '👨🏿‍💼' => 'umsebenzi wasehhovisi wesilisa: uhlobo-6',
    '👩🏻‍💼' => 'umsebenzi wasehhovisi wesifazane: uhlobo-1-2',
    '👩🏼‍💼' => 'umsebenzi wasehhovisi wesifazane: uhlobo-3',
    '👩🏽‍💼' => 'umsebenzi wasehhovisi wesifazane: uhlobo-4',
    '👩🏾‍💼' => 'umsebenzi wasehhovisi wesifazane: uhlobo-5',
    '👩🏿‍💼' => 'umsebenzi wasehhovisi wesifazane: uhlobo-6',
    '🧑🏻‍🔬' => 'usosayensi: uhlobo-1-2',
    '🧑🏼‍🔬' => 'usosayensi: uhlobo-3',
    '🧑🏽‍🔬' => 'usosayensi: uhlobo-4',
    '🧑🏾‍🔬' => 'usosayensi: uhlobo-5',
    '🧑🏿‍🔬' => 'usosayensi: uhlobo-6',
    '👨🏻‍🔬' => 'usosayensi wesilisa: uhlobo-1-2',
    '👨🏼‍🔬' => 'usosayensi wesilisa: uhlobo-3',
    '👨🏽‍🔬' => 'usosayensi wesilisa: uhlobo-4',
    '👨🏾‍🔬' => 'usosayensi wesilisa: uhlobo-5',
    '👨🏿‍🔬' => 'usosayensi wesilisa: uhlobo-6',
    '👩🏻‍🔬' => 'usosayensi wesifazane: uhlobo-1-2',
    '👩🏼‍🔬' => 'usosayensi wesifazane: uhlobo-3',
    '👩🏽‍🔬' => 'usosayensi wesifazane: uhlobo-4',
    '👩🏾‍🔬' => 'usosayensi wesifazane: uhlobo-5',
    '👩🏿‍🔬' => 'usosayensi wesifazane: uhlobo-6',
    '🧑🏻‍💻' => 'umcwaningi wethekhnoloji: uhlobo-1-2',
    '🧑🏼‍💻' => 'umcwaningi wethekhnoloji: uhlobo-3',
    '🧑🏽‍💻' => 'umcwaningi wethekhnoloji: uhlobo-4',
    '🧑🏾‍💻' => 'umcwaningi wethekhnoloji: uhlobo-5',
    '🧑🏿‍💻' => 'umcwaningi wethekhnoloji: uhlobo-6',
    '👨🏻‍💻' => 'usochwepheshe wendoda: uhlobo-1-2',
    '👨🏼‍💻' => 'usochwepheshe wendoda: uhlobo-3',
    '👨🏽‍💻' => 'usochwepheshe wendoda: uhlobo-4',
    '👨🏾‍💻' => 'usochwepheshe wendoda: uhlobo-5',
    '👨🏿‍💻' => 'usochwepheshe wendoda: uhlobo-6',
    '👩🏻‍💻' => 'usochwepheshe wesifazane: uhlobo-1-2',
    '👩🏼‍💻' => 'usochwepheshe wesifazane: uhlobo-3',
    '👩🏽‍💻' => 'usochwepheshe wesifazane: uhlobo-4',
    '👩🏾‍💻' => 'usochwepheshe wesifazane: uhlobo-5',
    '👩🏿‍💻' => 'usochwepheshe wesifazane: uhlobo-6',
    '🧑🏻‍🎤' => 'umculi: uhlobo-1-2',
    '🧑🏼‍🎤' => 'umculi: uhlobo-3',
    '🧑🏽‍🎤' => 'umculi: uhlobo-4',
    '🧑🏾‍🎤' => 'umculi: uhlobo-5',
    '🧑🏿‍🎤' => 'umculi: uhlobo-6',
    '👨🏻‍🎤' => 'umculi wesilisa: uhlobo-1-2',
    '👨🏼‍🎤' => 'umculi wesilisa: uhlobo-3',
    '👨🏽‍🎤' => 'umculi wesilisa: uhlobo-4',
    '👨🏾‍🎤' => 'umculi wesilisa: uhlobo-5',
    '👨🏿‍🎤' => 'umculi wesilisa: uhlobo-6',
    '👩🏻‍🎤' => 'umculi wesimame: uhlobo-1-2',
    '👩🏼‍🎤' => 'umculi wesimame: uhlobo-3',
    '👩🏽‍🎤' => 'umculi wesimame: uhlobo-4',
    '👩🏾‍🎤' => 'umculi wesimame: uhlobo-5',
    '👩🏿‍🎤' => 'umculi wesimame: uhlobo-6',
    '🧑🏻‍🎨' => 'iciko: uhlobo-1-2',
    '🧑🏼‍🎨' => 'iciko: uhlobo-3',
    '🧑🏽‍🎨' => 'iciko: uhlobo-4',
    '🧑🏾‍🎨' => 'iciko: uhlobo-5',
    '🧑🏿‍🎨' => 'iciko: uhlobo-6',
    '👨🏻‍🎨' => 'umdwebi wesilisa: uhlobo-1-2',
    '👨🏼‍🎨' => 'umdwebi wesilisa: uhlobo-3',
    '👨🏽‍🎨' => 'umdwebi wesilisa: uhlobo-4',
    '👨🏾‍🎨' => 'umdwebi wesilisa: uhlobo-5',
    '👨🏿‍🎨' => 'umdwebi wesilisa: uhlobo-6',
    '👩🏻‍🎨' => 'umdwebi wesimame: uhlobo-1-2',
    '👩🏼‍🎨' => 'umdwebi wesimame: uhlobo-3',
    '👩🏽‍🎨' => 'umdwebi wesimame: uhlobo-4',
    '👩🏾‍🎨' => 'umdwebi wesimame: uhlobo-5',
    '👩🏿‍🎨' => 'umdwebi wesimame: uhlobo-6',
    '🧑🏻‍✈' => 'umshayeli webhanoyi: uhlobo-1-2',
    '🧑🏼‍✈' => 'umshayeli webhanoyi: uhlobo-3',
    '🧑🏽‍✈' => 'umshayeli webhanoyi: uhlobo-4',
    '🧑🏾‍✈' => 'umshayeli webhanoyi: uhlobo-5',
    '🧑🏿‍✈' => 'umshayeli webhanoyi: uhlobo-6',
    '👨🏻‍✈' => 'umqhubi webhanoyi wesilisa: uhlobo-1-2',
    '👨🏼‍✈' => 'umqhubi webhanoyi wesilisa: uhlobo-3',
    '👨🏽‍✈' => 'umqhubi webhanoyi wesilisa: uhlobo-4',
    '👨🏾‍✈' => 'umqhubi webhanoyi wesilisa: uhlobo-5',
    '👨🏿‍✈' => 'umqhubi webhanoyi wesilisa: uhlobo-6',
    '👩🏻‍✈' => 'umqhubi webhanoyi wesifazane: uhlobo-1-2',
    '👩🏼‍✈' => 'umqhubi webhanoyi wesifazane: uhlobo-3',
    '👩🏽‍✈' => 'umqhubi webhanoyi wesifazane: uhlobo-4',
    '👩🏾‍✈' => 'umqhubi webhanoyi wesifazane: uhlobo-5',
    '👩🏿‍✈' => 'umqhubi webhanoyi wesifazane: uhlobo-6',
    '🧑🏻‍🚀' => 'i-astronaut: uhlobo-1-2',
    '🧑🏼‍🚀' => 'i-astronaut: uhlobo-3',
    '🧑🏽‍🚀' => 'i-astronaut: uhlobo-4',
    '🧑🏾‍🚀' => 'i-astronaut: uhlobo-5',
    '🧑🏿‍🚀' => 'i-astronaut: uhlobo-6',
    '👨🏻‍🚀' => 'i-astronaut yesilisa: uhlobo-1-2',
    '👨🏼‍🚀' => 'i-astronaut yesilisa: uhlobo-3',
    '👨🏽‍🚀' => 'i-astronaut yesilisa: uhlobo-4',
    '👨🏾‍🚀' => 'i-astronaut yesilisa: uhlobo-5',
    '👨🏿‍🚀' => 'i-astronaut yesilisa: uhlobo-6',
    '👩🏻‍🚀' => 'i-astronaut yesifazane: uhlobo-1-2',
    '👩🏼‍🚀' => 'i-astronaut yesifazane: uhlobo-3',
    '👩🏽‍🚀' => 'i-astronaut yesifazane: uhlobo-4',
    '👩🏾‍🚀' => 'i-astronaut yesifazane: uhlobo-5',
    '👩🏿‍🚀' => 'i-astronaut yesifazane: uhlobo-6',
    '🧑🏻‍🚒' => 'isicishimlilo: uhlobo-1-2',
    '🧑🏼‍🚒' => 'isicishimlilo: uhlobo-3',
    '🧑🏽‍🚒' => 'isicishimlilo: uhlobo-4',
    '🧑🏾‍🚒' => 'isicishimlilo: uhlobo-5',
    '🧑🏿‍🚒' => 'isicishimlilo: uhlobo-6',
    '👨🏻‍🚒' => 'isicishamlilo sesilisa: uhlobo-1-2',
    '👨🏼‍🚒' => 'isicishamlilo sesilisa: uhlobo-3',
    '👨🏽‍🚒' => 'isicishamlilo sesilisa: uhlobo-4',
    '👨🏾‍🚒' => 'isicishamlilo sesilisa: uhlobo-5',
    '👨🏿‍🚒' => 'isicishamlilo sesilisa: uhlobo-6',
    '👩🏻‍🚒' => 'isicishamlilo sowesifazane: uhlobo-1-2',
    '👩🏼‍🚒' => 'isicishamlilo sowesifazane: uhlobo-3',
    '👩🏽‍🚒' => 'isicishamlilo sowesifazane: uhlobo-4',
    '👩🏾‍🚒' => 'isicishamlilo sowesifazane: uhlobo-5',
    '👩🏿‍🚒' => 'isicishamlilo sowesifazane: uhlobo-6',
    '👮🏻‍♂' => 'iphoyisa lesilisa: uhlobo-1-2',
    '👮🏼‍♂' => 'iphoyisa lesilisa: uhlobo-3',
    '👮🏽‍♂' => 'iphoyisa lesilisa: uhlobo-4',
    '👮🏾‍♂' => 'iphoyisa lesilisa: uhlobo-5',
    '👮🏿‍♂' => 'iphoyisa lesilisa: uhlobo-6',
    '👮🏻‍♀' => 'iphoyisa lesifazane: uhlobo-1-2',
    '👮🏼‍♀' => 'iphoyisa lesifazane: uhlobo-3',
    '👮🏽‍♀' => 'iphoyisa lesifazane: uhlobo-4',
    '👮🏾‍♀' => 'iphoyisa lesifazane: uhlobo-5',
    '👮🏿‍♀' => 'iphoyisa lesifazane: uhlobo-6',
    '🕵🏻‍♂' => 'umseshi wesilisa: uhlobo-1-2',
    '🕵🏼‍♂' => 'umseshi wesilisa: uhlobo-3',
    '🕵🏽‍♂' => 'umseshi wesilisa: uhlobo-4',
    '🕵🏾‍♂' => 'umseshi wesilisa: uhlobo-5',
    '🕵🏿‍♂' => 'umseshi wesilisa: uhlobo-6',
    '🕵🏻‍♀' => 'umseshi wesifazane: uhlobo-1-2',
    '🕵🏼‍♀' => 'umseshi wesifazane: uhlobo-3',
    '🕵🏽‍♀' => 'umseshi wesifazane: uhlobo-4',
    '🕵🏾‍♀' => 'umseshi wesifazane: uhlobo-5',
    '🕵🏿‍♀' => 'umseshi wesifazane: uhlobo-6',
    '💂🏻‍♂' => 'unogada wesilisa: uhlobo-1-2',
    '💂🏼‍♂' => 'unogada wesilisa: uhlobo-3',
    '💂🏽‍♂' => 'unogada wesilisa: uhlobo-4',
    '💂🏾‍♂' => 'unogada wesilisa: uhlobo-5',
    '💂🏿‍♂' => 'unogada wesilisa: uhlobo-6',
    '💂🏻‍♀' => 'unogada wesifazane: uhlobo-1-2',
    '💂🏼‍♀' => 'unogada wesifazane: uhlobo-3',
    '💂🏽‍♀' => 'unogada wesifazane: uhlobo-4',
    '💂🏾‍♀' => 'unogada wesifazane: uhlobo-5',
    '💂🏿‍♀' => 'unogada wesifazane: uhlobo-6',
    '👷🏻‍♂' => 'umsebenzi wenkontileka wesilisa: uhlobo-1-2',
    '👷🏼‍♂' => 'umsebenzi wenkontileka wesilisa: uhlobo-3',
    '👷🏽‍♂' => 'umsebenzi wenkontileka wesilisa: uhlobo-4',
    '👷🏾‍♂' => 'umsebenzi wenkontileka wesilisa: uhlobo-5',
    '👷🏿‍♂' => 'umsebenzi wenkontileka wesilisa: uhlobo-6',
    '👷🏻‍♀' => 'umsebenzi wenkontileka wesifazane: uhlobo-1-2',
    '👷🏼‍♀' => 'umsebenzi wenkontileka wesifazane: uhlobo-3',
    '👷🏽‍♀' => 'umsebenzi wenkontileka wesifazane: uhlobo-4',
    '👷🏾‍♀' => 'umsebenzi wenkontileka wesifazane: uhlobo-5',
    '👷🏿‍♀' => 'umsebenzi wenkontileka wesifazane: uhlobo-6',
    '👳🏻‍♂' => 'indoda egqoke ithalibhani: uhlobo-1-2',
    '👳🏼‍♂' => 'indoda egqoke ithalibhani: uhlobo-3',
    '👳🏽‍♂' => 'indoda egqoke ithalibhani: uhlobo-4',
    '👳🏾‍♂' => 'indoda egqoke ithalibhani: uhlobo-5',
    '👳🏿‍♂' => 'indoda egqoke ithalibhani: uhlobo-6',
    '👳🏻‍♀' => 'owesimame ogqoke ithalibhani: uhlobo-1-2',
    '👳🏼‍♀' => 'owesimame ogqoke ithalibhani: uhlobo-3',
    '👳🏽‍♀' => 'owesimame ogqoke ithalibhani: uhlobo-4',
    '👳🏾‍♀' => 'owesimame ogqoke ithalibhani: uhlobo-5',
    '👳🏿‍♀' => 'owesimame ogqoke ithalibhani: uhlobo-6',
    '🤵🏻‍♂' => 'indoda igqoke isudi: uhlobo-1-2',
    '🤵🏼‍♂' => 'indoda igqoke isudi: uhlobo-3',
    '🤵🏽‍♂' => 'indoda igqoke isudi: uhlobo-4',
    '🤵🏾‍♂' => 'indoda igqoke isudi: uhlobo-5',
    '🤵🏿‍♂' => 'indoda igqoke isudi: uhlobo-6',
    '🤵🏻‍♀' => 'owesifazane ugqoke isudi: uhlobo-1-2',
    '🤵🏼‍♀' => 'owesifazane ugqoke isudi: uhlobo-3',
    '🤵🏽‍♀' => 'owesifazane ugqoke isudi: uhlobo-4',
    '🤵🏾‍♀' => 'owesifazane ugqoke isudi: uhlobo-5',
    '🤵🏿‍♀' => 'owesifazane ugqoke isudi: uhlobo-6',
    '👰🏻‍♂' => 'indoda ifake iveyili: uhlobo-1-2',
    '👰🏼‍♂' => 'indoda ifake iveyili: uhlobo-3',
    '👰🏽‍♂' => 'indoda ifake iveyili: uhlobo-4',
    '👰🏾‍♂' => 'indoda ifake iveyili: uhlobo-5',
    '👰🏿‍♂' => 'indoda ifake iveyili: uhlobo-6',
    '👰🏻‍♀' => 'owesifazane ufake iveyili: uhlobo-1-2',
    '👰🏼‍♀' => 'owesifazane ufake iveyili: uhlobo-3',
    '👰🏽‍♀' => 'owesifazane ufake iveyili: uhlobo-4',
    '👰🏾‍♀' => 'owesifazane ufake iveyili: uhlobo-5',
    '👰🏿‍♀' => 'owesifazane ufake iveyili: uhlobo-6',
    '👩🏻‍🍼' => 'owesifazane uncelisa ingane: uhlobo-1-2',
    '👩🏼‍🍼' => 'owesifazane uncelisa ingane: uhlobo-3',
    '👩🏽‍🍼' => 'owesifazane uncelisa ingane: uhlobo-4',
    '👩🏾‍🍼' => 'owesifazane uncelisa ingane: uhlobo-5',
    '👩🏿‍🍼' => 'owesifazane uncelisa ingane: uhlobo-6',
    '👨🏻‍🍼' => 'indoda incelisa ingane: uhlobo-1-2',
    '👨🏼‍🍼' => 'indoda incelisa ingane: uhlobo-3',
    '👨🏽‍🍼' => 'indoda incelisa ingane: uhlobo-4',
    '👨🏾‍🍼' => 'indoda incelisa ingane: uhlobo-5',
    '👨🏿‍🍼' => 'indoda incelisa ingane: uhlobo-6',
    '🧑🏻‍🍼' => 'umuntu oncelisa ingane: uhlobo-1-2',
    '🧑🏼‍🍼' => 'umuntu oncelisa ingane: uhlobo-3',
    '🧑🏽‍🍼' => 'umuntu oncelisa ingane: uhlobo-4',
    '🧑🏾‍🍼' => 'umuntu oncelisa ingane: uhlobo-5',
    '🧑🏿‍🍼' => 'umuntu oncelisa ingane: uhlobo-6',
    '🧑🏻‍🎄' => 'u-mx claus: uhlobo-1-2',
    '🧑🏼‍🎄' => 'u-mx claus: uhlobo-3',
    '🧑🏽‍🎄' => 'u-mx claus: uhlobo-4',
    '🧑🏾‍🎄' => 'u-mx claus: uhlobo-5',
    '🧑🏿‍🎄' => 'u-mx claus: uhlobo-6',
    '🦸🏻‍♂' => 'man superhero: uhlobo-1-2',
    '🦸🏼‍♂' => 'man superhero: uhlobo-3',
    '🦸🏽‍♂' => 'man superhero: uhlobo-4',
    '🦸🏾‍♂' => 'man superhero: uhlobo-5',
    '🦸🏿‍♂' => 'man superhero: uhlobo-6',
    '🦸🏻‍♀' => 'woman superhero: uhlobo-1-2',
    '🦸🏼‍♀' => 'woman superhero: uhlobo-3',
    '🦸🏽‍♀' => 'woman superhero: uhlobo-4',
    '🦸🏾‍♀' => 'woman superhero: uhlobo-5',
    '🦸🏿‍♀' => 'woman superhero: uhlobo-6',
    '🦹🏻‍♂' => 'man supervillain: uhlobo-1-2',
    '🦹🏼‍♂' => 'man supervillain: uhlobo-3',
    '🦹🏽‍♂' => 'man supervillain: uhlobo-4',
    '🦹🏾‍♂' => 'man supervillain: uhlobo-5',
    '🦹🏿‍♂' => 'man supervillain: uhlobo-6',
    '🦹🏻‍♀' => 'woman supervillain: uhlobo-1-2',
    '🦹🏼‍♀' => 'woman supervillain: uhlobo-3',
    '🦹🏽‍♀' => 'woman supervillain: uhlobo-4',
    '🦹🏾‍♀' => 'woman supervillain: uhlobo-5',
    '🦹🏿‍♀' => 'woman supervillain: uhlobo-6',
    '🧙🏻‍♂' => 'i-mage yowesilisa: uhlobo-1-2',
    '🧙🏼‍♂' => 'i-mage yowesilisa: uhlobo-3',
    '🧙🏽‍♂' => 'i-mage yowesilisa: uhlobo-4',
    '🧙🏾‍♂' => 'i-mage yowesilisa: uhlobo-5',
    '🧙🏿‍♂' => 'i-mage yowesilisa: uhlobo-6',
    '🧙🏻‍♀' => 'i-mage yowesifazane: uhlobo-1-2',
    '🧙🏼‍♀' => 'i-mage yowesifazane: uhlobo-3',
    '🧙🏽‍♀' => 'i-mage yowesifazane: uhlobo-4',
    '🧙🏾‍♀' => 'i-mage yowesifazane: uhlobo-5',
    '🧙🏿‍♀' => 'i-mage yowesifazane: uhlobo-6',
    '🧚🏻‍♂' => 'ngelosi yesilisa: uhlobo-1-2',
    '🧚🏼‍♂' => 'ngelosi yesilisa: uhlobo-3',
    '🧚🏽‍♂' => 'ngelosi yesilisa: uhlobo-4',
    '🧚🏾‍♂' => 'ngelosi yesilisa: uhlobo-5',
    '🧚🏿‍♂' => 'ngelosi yesilisa: uhlobo-6',
    '🧚🏻‍♀' => 'ngelosi yesifazane: uhlobo-1-2',
    '🧚🏼‍♀' => 'ngelosi yesifazane: uhlobo-3',
    '🧚🏽‍♀' => 'ngelosi yesifazane: uhlobo-4',
    '🧚🏾‍♀' => 'ngelosi yesifazane: uhlobo-5',
    '🧚🏿‍♀' => 'ngelosi yesifazane: uhlobo-6',
    '🧛🏻‍♂' => 'ivemphaya lendoda: uhlobo-1-2',
    '🧛🏼‍♂' => 'ivemphaya lendoda: uhlobo-3',
    '🧛🏽‍♂' => 'ivemphaya lendoda: uhlobo-4',
    '🧛🏾‍♂' => 'ivemphaya lendoda: uhlobo-5',
    '🧛🏿‍♂' => 'ivemphaya lendoda: uhlobo-6',
    '🧛🏻‍♀' => 'ivemphaya lesifazane: uhlobo-1-2',
    '🧛🏼‍♀' => 'ivemphaya lesifazane: uhlobo-3',
    '🧛🏽‍♀' => 'ivemphaya lesifazane: uhlobo-4',
    '🧛🏾‍♀' => 'ivemphaya lesifazane: uhlobo-5',
    '🧛🏿‍♀' => 'ivemphaya lesifazane: uhlobo-6',
    '🧜🏻‍♂' => 'i-merman: uhlobo-1-2',
    '🧜🏼‍♂' => 'i-merman: uhlobo-3',
    '🧜🏽‍♂' => 'i-merman: uhlobo-4',
    '🧜🏾‍♂' => 'i-merman: uhlobo-5',
    '🧜🏿‍♂' => 'i-merman: uhlobo-6',
    '🧜🏻‍♀' => 'i-mermaid: uhlobo-1-2',
    '🧜🏼‍♀' => 'i-mermaid: uhlobo-3',
    '🧜🏽‍♀' => 'i-mermaid: uhlobo-4',
    '🧜🏾‍♀' => 'i-mermaid: uhlobo-5',
    '🧜🏿‍♀' => 'i-mermaid: uhlobo-6',
    '🧝🏻‍♂' => 'i-elf yesilisa: uhlobo-1-2',
    '🧝🏼‍♂' => 'i-elf yesilisa: uhlobo-3',
    '🧝🏽‍♂' => 'i-elf yesilisa: uhlobo-4',
    '🧝🏾‍♂' => 'i-elf yesilisa: uhlobo-5',
    '🧝🏿‍♂' => 'i-elf yesilisa: uhlobo-6',
    '🧝🏻‍♀' => 'i-elf yesifazane: uhlobo-1-2',
    '🧝🏼‍♀' => 'i-elf yesifazane: uhlobo-3',
    '🧝🏽‍♀' => 'i-elf yesifazane: uhlobo-4',
    '🧝🏾‍♀' => 'i-elf yesifazane: uhlobo-5',
    '🧝🏿‍♀' => 'i-elf yesifazane: uhlobo-6',
    '💆🏻‍♂' => 'indoda ethola imasaji ebusweni: uhlobo-1-2',
    '💆🏼‍♂' => 'indoda ethola imasaji ebusweni: uhlobo-3',
    '💆🏽‍♂' => 'indoda ethola imasaji ebusweni: uhlobo-4',
    '💆🏾‍♂' => 'indoda ethola imasaji ebusweni: uhlobo-5',
    '💆🏿‍♂' => 'indoda ethola imasaji ebusweni: uhlobo-6',
    '💆🏻‍♀' => 'owesimame othola imasaji ebusweni: uhlobo-1-2',
    '💆🏼‍♀' => 'owesimame othola imasaji ebusweni: uhlobo-3',
    '💆🏽‍♀' => 'owesimame othola imasaji ebusweni: uhlobo-4',
    '💆🏾‍♀' => 'owesimame othola imasaji ebusweni: uhlobo-5',
    '💆🏿‍♀' => 'owesimame othola imasaji ebusweni: uhlobo-6',
    '💇🏻‍♂' => 'indoda egundayo: uhlobo-1-2',
    '💇🏼‍♂' => 'indoda egundayo: uhlobo-3',
    '💇🏽‍♂' => 'indoda egundayo: uhlobo-4',
    '💇🏾‍♂' => 'indoda egundayo: uhlobo-5',
    '💇🏿‍♂' => 'indoda egundayo: uhlobo-6',
    '💇🏻‍♀' => 'owesimame ogundayo: uhlobo-1-2',
    '💇🏼‍♀' => 'owesimame ogundayo: uhlobo-3',
    '💇🏽‍♀' => 'owesimame ogundayo: uhlobo-4',
    '💇🏾‍♀' => 'owesimame ogundayo: uhlobo-5',
    '💇🏿‍♀' => 'owesimame ogundayo: uhlobo-6',
    '🚶🏻‍♂' => 'indoda ehambayo: uhlobo-1-2',
    '🚶🏼‍♂' => 'indoda ehambayo: uhlobo-3',
    '🚶🏽‍♂' => 'indoda ehambayo: uhlobo-4',
    '🚶🏾‍♂' => 'indoda ehambayo: uhlobo-5',
    '🚶🏿‍♂' => 'indoda ehambayo: uhlobo-6',
    '🚶🏻‍♀' => 'owesimame ohambayo: uhlobo-1-2',
    '🚶🏼‍♀' => 'owesimame ohambayo: uhlobo-3',
    '🚶🏽‍♀' => 'owesimame ohambayo: uhlobo-4',
    '🚶🏾‍♀' => 'owesimame ohambayo: uhlobo-5',
    '🚶🏿‍♀' => 'owesimame ohambayo: uhlobo-6',
    '🧍🏻‍♂' => 'indoda emile: uhlobo-1-2',
    '🧍🏼‍♂' => 'indoda emile: uhlobo-3',
    '🧍🏽‍♂' => 'indoda emile: uhlobo-4',
    '🧍🏾‍♂' => 'indoda emile: uhlobo-5',
    '🧍🏿‍♂' => 'indoda emile: uhlobo-6',
    '🧍🏻‍♀' => 'umama omile: uhlobo-1-2',
    '🧍🏼‍♀' => 'umama omile: uhlobo-3',
    '🧍🏽‍♀' => 'umama omile: uhlobo-4',
    '🧍🏾‍♀' => 'umama omile: uhlobo-5',
    '🧍🏿‍♀' => 'umama omile: uhlobo-6',
    '🧎🏻‍♂' => 'indoda eguqlile: uhlobo-1-2',
    '🧎🏼‍♂' => 'indoda eguqlile: uhlobo-3',
    '🧎🏽‍♂' => 'indoda eguqlile: uhlobo-4',
    '🧎🏾‍♂' => 'indoda eguqlile: uhlobo-5',
    '🧎🏿‍♂' => 'indoda eguqlile: uhlobo-6',
    '🧎🏻‍♀' => 'umama ogulile: uhlobo-1-2',
    '🧎🏼‍♀' => 'umama ogulile: uhlobo-3',
    '🧎🏽‍♀' => 'umama ogulile: uhlobo-4',
    '🧎🏾‍♀' => 'umama ogulile: uhlobo-5',
    '🧎🏿‍♀' => 'umama ogulile: uhlobo-6',
    '🧑🏻‍🦯' => 'umuntu onenkinga yokungena: uhlobo-1-2',
    '🧑🏼‍🦯' => 'umuntu onenkinga yokungena: uhlobo-3',
    '🧑🏽‍🦯' => 'umuntu onenkinga yokungena: uhlobo-4',
    '🧑🏾‍🦯' => 'umuntu onenkinga yokungena: uhlobo-5',
    '🧑🏿‍🦯' => 'umuntu onenkinga yokungena: uhlobo-6',
    '👨🏻‍🦯' => 'indoda enekheni lokuhlola: uhlobo-1-2',
    '👨🏼‍🦯' => 'indoda enekheni lokuhlola: uhlobo-3',
    '👨🏽‍🦯' => 'indoda enekheni lokuhlola: uhlobo-4',
    '👨🏾‍🦯' => 'indoda enekheni lokuhlola: uhlobo-5',
    '👨🏿‍🦯' => 'indoda enekheni lokuhlola: uhlobo-6',
    '👩🏻‍🦯' => 'umama onekheni lokuhlola: uhlobo-1-2',
    '👩🏼‍🦯' => 'umama onekheni lokuhlola: uhlobo-3',
    '👩🏽‍🦯' => 'umama onekheni lokuhlola: uhlobo-4',
    '👩🏾‍🦯' => 'umama onekheni lokuhlola: uhlobo-5',
    '👩🏿‍🦯' => 'umama onekheni lokuhlola: uhlobo-6',
    '🧑🏻‍🦼' => 'umuntu onesihlalo sabakhubazekile: uhlobo-1-2',
    '🧑🏼‍🦼' => 'umuntu onesihlalo sabakhubazekile: uhlobo-3',
    '🧑🏽‍🦼' => 'umuntu onesihlalo sabakhubazekile: uhlobo-4',
    '🧑🏾‍🦼' => 'umuntu onesihlalo sabakhubazekile: uhlobo-5',
    '🧑🏿‍🦼' => 'umuntu onesihlalo sabakhubazekile: uhlobo-6',
    '👨🏻‍🦼' => 'indoda esesitulweni esizihambelayo: uhlobo-1-2',
    '👨🏼‍🦼' => 'indoda esesitulweni esizihambelayo: uhlobo-3',
    '👨🏽‍🦼' => 'indoda esesitulweni esizihambelayo: uhlobo-4',
    '👨🏾‍🦼' => 'indoda esesitulweni esizihambelayo: uhlobo-5',
    '👨🏿‍🦼' => 'indoda esesitulweni esizihambelayo: uhlobo-6',
    '👩🏻‍🦼' => 'umama osesitulweni esizihambelayo: uhlobo-1-2',
    '👩🏼‍🦼' => 'umama osesitulweni esizihambelayo: uhlobo-3',
    '👩🏽‍🦼' => 'umama osesitulweni esizihambelayo: uhlobo-4',
    '👩🏾‍🦼' => 'umama osesitulweni esizihambelayo: uhlobo-5',
    '👩🏿‍🦼' => 'umama osesitulweni esizihambelayo: uhlobo-6',
    '🧑🏻‍🦽' => 'umuntu ohlezi esihlalweni sabakhubazekile: uhlobo-1-2',
    '🧑🏼‍🦽' => 'umuntu ohlezi esihlalweni sabakhubazekile: uhlobo-3',
    '🧑🏽‍🦽' => 'umuntu ohlezi esihlalweni sabakhubazekile: uhlobo-4',
    '🧑🏾‍🦽' => 'umuntu ohlezi esihlalweni sabakhubazekile: uhlobo-5',
    '🧑🏿‍🦽' => 'umuntu ohlezi esihlalweni sabakhubazekile: uhlobo-6',
    '👨🏻‍🦽' => 'indoda esesitulweni sokuhanjiswa: uhlobo-1-2',
    '👨🏼‍🦽' => 'indoda esesitulweni sokuhanjiswa: uhlobo-3',
    '👨🏽‍🦽' => 'indoda esesitulweni sokuhanjiswa: uhlobo-4',
    '👨🏾‍🦽' => 'indoda esesitulweni sokuhanjiswa: uhlobo-5',
    '👨🏿‍🦽' => 'indoda esesitulweni sokuhanjiswa: uhlobo-6',
    '👩🏻‍🦽' => 'umama osesitulweni sokuhanjiswa: uhlobo-1-2',
    '👩🏼‍🦽' => 'umama osesitulweni sokuhanjiswa: uhlobo-3',
    '👩🏽‍🦽' => 'umama osesitulweni sokuhanjiswa: uhlobo-4',
    '👩🏾‍🦽' => 'umama osesitulweni sokuhanjiswa: uhlobo-5',
    '👩🏿‍🦽' => 'umama osesitulweni sokuhanjiswa: uhlobo-6',
    '🏃🏻‍♂' => 'indoda egijimayo: uhlobo-1-2',
    '🏃🏼‍♂' => 'indoda egijimayo: uhlobo-3',
    '🏃🏽‍♂' => 'indoda egijimayo: uhlobo-4',
    '🏃🏾‍♂' => 'indoda egijimayo: uhlobo-5',
    '🏃🏿‍♂' => 'indoda egijimayo: uhlobo-6',
    '🏃🏻‍♀' => 'owesimame ogijimayo: uhlobo-1-2',
    '🏃🏼‍♀' => 'owesimame ogijimayo: uhlobo-3',
    '🏃🏽‍♀' => 'owesimame ogijimayo: uhlobo-4',
    '🏃🏾‍♀' => 'owesimame ogijimayo: uhlobo-5',
    '🏃🏿‍♀' => 'owesimame ogijimayo: uhlobo-6',
    '👯🏻‍♀' => 'abasemame abasemcimbini: uhlobo-1-2',
    '👯🏼‍♀' => 'abasemame abasemcimbini: uhlobo-3',
    '👯🏽‍♀' => 'abasemame abasemcimbini: uhlobo-4',
    '👯🏾‍♀' => 'abasemame abasemcimbini: uhlobo-5',
    '👯🏿‍♀' => 'abasemame abasemcimbini: uhlobo-6',
    '👯🏻‍♂' => 'amadoda asemcimbini: uhlobo-1-2',
    '👯🏼‍♂' => 'amadoda asemcimbini: uhlobo-3',
    '👯🏽‍♂' => 'amadoda asemcimbini: uhlobo-4',
    '👯🏾‍♂' => 'amadoda asemcimbini: uhlobo-5',
    '👯🏿‍♂' => 'amadoda asemcimbini: uhlobo-6',
    '🧖🏻‍♂' => 'owesilisa egunjini lestimu: uhlobo-1-2',
    '🧖🏼‍♂' => 'owesilisa egunjini lestimu: uhlobo-3',
    '🧖🏽‍♂' => 'owesilisa egunjini lestimu: uhlobo-4',
    '🧖🏾‍♂' => 'owesilisa egunjini lestimu: uhlobo-5',
    '🧖🏿‍♂' => 'owesilisa egunjini lestimu: uhlobo-6',
    '🧖🏻‍♀' => 'owesifazane egunjini lestimu: uhlobo-1-2',
    '🧖🏼‍♀' => 'owesifazane egunjini lestimu: uhlobo-3',
    '🧖🏽‍♀' => 'owesifazane egunjini lestimu: uhlobo-4',
    '🧖🏾‍♀' => 'owesifazane egunjini lestimu: uhlobo-5',
    '🧖🏿‍♀' => 'owesifazane egunjini lestimu: uhlobo-6',
    '🧗🏻‍♂' => 'owesilisa oqwalayo: uhlobo-1-2',
    '🧗🏼‍♂' => 'owesilisa oqwalayo: uhlobo-3',
    '🧗🏽‍♂' => 'owesilisa oqwalayo: uhlobo-4',
    '🧗🏾‍♂' => 'owesilisa oqwalayo: uhlobo-5',
    '🧗🏿‍♂' => 'owesilisa oqwalayo: uhlobo-6',
    '🧗🏻‍♀' => 'owesifazane oqwalayo: uhlobo-1-2',
    '🧗🏼‍♀' => 'owesifazane oqwalayo: uhlobo-3',
    '🧗🏽‍♀' => 'owesifazane oqwalayo: uhlobo-4',
    '🧗🏾‍♀' => 'owesifazane oqwalayo: uhlobo-5',
    '🧗🏿‍♀' => 'owesifazane oqwalayo: uhlobo-6',
    '🏌🏻‍♂' => 'indoda edlala igalofu: uhlobo-1-2',
    '🏌🏼‍♂' => 'indoda edlala igalofu: uhlobo-3',
    '🏌🏽‍♂' => 'indoda edlala igalofu: uhlobo-4',
    '🏌🏾‍♂' => 'indoda edlala igalofu: uhlobo-5',
    '🏌🏿‍♂' => 'indoda edlala igalofu: uhlobo-6',
    '🏌🏻‍♀' => 'owesimame odlala igalofu: uhlobo-1-2',
    '🏌🏼‍♀' => 'owesimame odlala igalofu: uhlobo-3',
    '🏌🏽‍♀' => 'owesimame odlala igalofu: uhlobo-4',
    '🏌🏾‍♀' => 'owesimame odlala igalofu: uhlobo-5',
    '🏌🏿‍♀' => 'owesimame odlala igalofu: uhlobo-6',
    '🏄🏻‍♂' => 'indoda edlala isurfing: uhlobo-1-2',
    '🏄🏼‍♂' => 'indoda edlala isurfing: uhlobo-3',
    '🏄🏽‍♂' => 'indoda edlala isurfing: uhlobo-4',
    '🏄🏾‍♂' => 'indoda edlala isurfing: uhlobo-5',
    '🏄🏿‍♂' => 'indoda edlala isurfing: uhlobo-6',
    '🏄🏻‍♀' => 'owesimame odlala isurfing: uhlobo-1-2',
    '🏄🏼‍♀' => 'owesimame odlala isurfing: uhlobo-3',
    '🏄🏽‍♀' => 'owesimame odlala isurfing: uhlobo-4',
    '🏄🏾‍♀' => 'owesimame odlala isurfing: uhlobo-5',
    '🏄🏿‍♀' => 'owesimame odlala isurfing: uhlobo-6',
    '🚣🏻‍♂' => 'indoda egwedla isikebhe: uhlobo-1-2',
    '🚣🏼‍♂' => 'indoda egwedla isikebhe: uhlobo-3',
    '🚣🏽‍♂' => 'indoda egwedla isikebhe: uhlobo-4',
    '🚣🏾‍♂' => 'indoda egwedla isikebhe: uhlobo-5',
    '🚣🏿‍♂' => 'indoda egwedla isikebhe: uhlobo-6',
    '🚣🏻‍♀' => 'owesimame ogwedla isikebhe: uhlobo-1-2',
    '🚣🏼‍♀' => 'owesimame ogwedla isikebhe: uhlobo-3',
    '🚣🏽‍♀' => 'owesimame ogwedla isikebhe: uhlobo-4',
    '🚣🏾‍♀' => 'owesimame ogwedla isikebhe: uhlobo-5',
    '🚣🏿‍♀' => 'owesimame ogwedla isikebhe: uhlobo-6',
    '🏊🏻‍♂' => 'indoda ebhukudayo: uhlobo-1-2',
    '🏊🏼‍♂' => 'indoda ebhukudayo: uhlobo-3',
    '🏊🏽‍♂' => 'indoda ebhukudayo: uhlobo-4',
    '🏊🏾‍♂' => 'indoda ebhukudayo: uhlobo-5',
    '🏊🏿‍♂' => 'indoda ebhukudayo: uhlobo-6',
    '🏊🏻‍♀' => 'owesimame obhukudayo: uhlobo-1-2',
    '🏊🏼‍♀' => 'owesimame obhukudayo: uhlobo-3',
    '🏊🏽‍♀' => 'owesimame obhukudayo: uhlobo-4',
    '🏊🏾‍♀' => 'owesimame obhukudayo: uhlobo-5',
    '🏊🏿‍♀' => 'owesimame obhukudayo: uhlobo-6',
    '⛹🏻‍♂' => 'indoda enebhola: uhlobo-1-2',
    '⛹🏼‍♂' => 'indoda enebhola: uhlobo-3',
    '⛹🏽‍♂' => 'indoda enebhola: uhlobo-4',
    '⛹🏾‍♂' => 'indoda enebhola: uhlobo-5',
    '⛹🏿‍♂' => 'indoda enebhola: uhlobo-6',
    '⛹🏻‍♀' => 'owesimame onebhola: uhlobo-1-2',
    '⛹🏼‍♀' => 'owesimame onebhola: uhlobo-3',
    '⛹🏽‍♀' => 'owesimame onebhola: uhlobo-4',
    '⛹🏾‍♀' => 'owesimame onebhola: uhlobo-5',
    '⛹🏿‍♀' => 'owesimame onebhola: uhlobo-6',
    '🏋🏻‍♂' => 'indoda ephakamisa izinsimbi: uhlobo-1-2',
    '🏋🏼‍♂' => 'indoda ephakamisa izinsimbi: uhlobo-3',
    '🏋🏽‍♂' => 'indoda ephakamisa izinsimbi: uhlobo-4',
    '🏋🏾‍♂' => 'indoda ephakamisa izinsimbi: uhlobo-5',
    '🏋🏿‍♂' => 'indoda ephakamisa izinsimbi: uhlobo-6',
    '🏋🏻‍♀' => 'owesimame ophakamisa izinsimbi: uhlobo-1-2',
    '🏋🏼‍♀' => 'owesimame ophakamisa izinsimbi: uhlobo-3',
    '🏋🏽‍♀' => 'owesimame ophakamisa izinsimbi: uhlobo-4',
    '🏋🏾‍♀' => 'owesimame ophakamisa izinsimbi: uhlobo-5',
    '🏋🏿‍♀' => 'owesimame ophakamisa izinsimbi: uhlobo-6',
    '🚴🏻‍♂' => 'indoda egibele ibhayisikili: uhlobo-1-2',
    '🚴🏼‍♂' => 'indoda egibele ibhayisikili: uhlobo-3',
    '🚴🏽‍♂' => 'indoda egibele ibhayisikili: uhlobo-4',
    '🚴🏾‍♂' => 'indoda egibele ibhayisikili: uhlobo-5',
    '🚴🏿‍♂' => 'indoda egibele ibhayisikili: uhlobo-6',
    '🚴🏻‍♀' => 'owesimeme ogibele ibhayisikili: uhlobo-1-2',
    '🚴🏼‍♀' => 'owesimeme ogibele ibhayisikili: uhlobo-3',
    '🚴🏽‍♀' => 'owesimeme ogibele ibhayisikili: uhlobo-4',
    '🚴🏾‍♀' => 'owesimeme ogibele ibhayisikili: uhlobo-5',
    '🚴🏿‍♀' => 'owesimeme ogibele ibhayisikili: uhlobo-6',
    '🚵🏻‍♂' => 'indoda egibele ibhayisikili lezintaba: uhlobo-1-2',
    '🚵🏼‍♂' => 'indoda egibele ibhayisikili lezintaba: uhlobo-3',
    '🚵🏽‍♂' => 'indoda egibele ibhayisikili lezintaba: uhlobo-4',
    '🚵🏾‍♂' => 'indoda egibele ibhayisikili lezintaba: uhlobo-5',
    '🚵🏿‍♂' => 'indoda egibele ibhayisikili lezintaba: uhlobo-6',
    '🚵🏻‍♀' => 'owesimame ogibele ibhayisikili lezintaba: uhlobo-1-2',
    '🚵🏼‍♀' => 'owesimame ogibele ibhayisikili lezintaba: uhlobo-3',
    '🚵🏽‍♀' => 'owesimame ogibele ibhayisikili lezintaba: uhlobo-4',
    '🚵🏾‍♀' => 'owesimame ogibele ibhayisikili lezintaba: uhlobo-5',
    '🚵🏿‍♀' => 'owesimame ogibele ibhayisikili lezintaba: uhlobo-6',
    '🤸🏻‍♂' => 'owesilisa enza isondo lekalishi: uhlobo-1-2',
    '🤸🏼‍♂' => 'owesilisa enza isondo lekalishi: uhlobo-3',
    '🤸🏽‍♂' => 'owesilisa enza isondo lekalishi: uhlobo-4',
    '🤸🏾‍♂' => 'owesilisa enza isondo lekalishi: uhlobo-5',
    '🤸🏿‍♂' => 'owesilisa enza isondo lekalishi: uhlobo-6',
    '🤸🏻‍♀' => 'owesimame enza isondo lekalishi: uhlobo-1-2',
    '🤸🏼‍♀' => 'owesimame enza isondo lekalishi: uhlobo-3',
    '🤸🏽‍♀' => 'owesimame enza isondo lekalishi: uhlobo-4',
    '🤸🏾‍♀' => 'owesimame enza isondo lekalishi: uhlobo-5',
    '🤸🏿‍♀' => 'owesimame enza isondo lekalishi: uhlobo-6',
    '🤼🏻‍♀' => 'abashayisibhakela besimame: uhlobo-1-2',
    '🤼🏼‍♀' => 'abashayisibhakela besimame: uhlobo-3',
    '🤼🏽‍♀' => 'abashayisibhakela besimame: uhlobo-4',
    '🤼🏾‍♀' => 'abashayisibhakela besimame: uhlobo-5',
    '🤼🏿‍♀' => 'abashayisibhakela besimame: uhlobo-6',
    '🤼🏻‍♂' => 'abashayisibhakela besilisa: uhlobo-1-2',
    '🤼🏼‍♂' => 'abashayisibhakela besilisa: uhlobo-3',
    '🤼🏽‍♂' => 'abashayisibhakela besilisa: uhlobo-4',
    '🤼🏾‍♂' => 'abashayisibhakela besilisa: uhlobo-5',
    '🤼🏿‍♂' => 'abashayisibhakela besilisa: uhlobo-6',
    '🤽🏻‍♂' => 'umdlalo webhola lasemanzini wowesilisa: uhlobo-1-2',
    '🤽🏼‍♂' => 'umdlalo webhola lasemanzini wowesilisa: uhlobo-3',
    '🤽🏽‍♂' => 'umdlalo webhola lasemanzini wowesilisa: uhlobo-4',
    '🤽🏾‍♂' => 'umdlalo webhola lasemanzini wowesilisa: uhlobo-5',
    '🤽🏿‍♂' => 'umdlalo webhola lasemanzini wowesilisa: uhlobo-6',
    '🤽🏻‍♀' => 'umdlalo webhola lasemanzini wowesimame: uhlobo-1-2',
    '🤽🏼‍♀' => 'umdlalo webhola lasemanzini wowesimame: uhlobo-3',
    '🤽🏽‍♀' => 'umdlalo webhola lasemanzini wowesimame: uhlobo-4',
    '🤽🏾‍♀' => 'umdlalo webhola lasemanzini wowesimame: uhlobo-5',
    '🤽🏿‍♀' => 'umdlalo webhola lasemanzini wowesimame: uhlobo-6',
    '🤾🏻‍♂' => 'ibhola lesandla lowesilisa: uhlobo-1-2',
    '🤾🏼‍♂' => 'ibhola lesandla lowesilisa: uhlobo-3',
    '🤾🏽‍♂' => 'ibhola lesandla lowesilisa: uhlobo-4',
    '🤾🏾‍♂' => 'ibhola lesandla lowesilisa: uhlobo-5',
    '🤾🏿‍♂' => 'ibhola lesandla lowesilisa: uhlobo-6',
    '🤾🏻‍♀' => 'ibhola lesandla lowesimame: uhlobo-1-2',
    '🤾🏼‍♀' => 'ibhola lesandla lowesimame: uhlobo-3',
    '🤾🏽‍♀' => 'ibhola lesandla lowesimame: uhlobo-4',
    '🤾🏾‍♀' => 'ibhola lesandla lowesimame: uhlobo-5',
    '🤾🏿‍♀' => 'ibhola lesandla lowesimame: uhlobo-6',
    '🤹🏻‍♂' => 'indoda edlala ngamabhola: uhlobo-1-2',
    '🤹🏼‍♂' => 'indoda edlala ngamabhola: uhlobo-3',
    '🤹🏽‍♂' => 'indoda edlala ngamabhola: uhlobo-4',
    '🤹🏾‍♂' => 'indoda edlala ngamabhola: uhlobo-5',
    '🤹🏿‍♂' => 'indoda edlala ngamabhola: uhlobo-6',
    '🤹🏻‍♀' => 'owesimame odlala ngamabhola: uhlobo-1-2',
    '🤹🏼‍♀' => 'owesimame odlala ngamabhola: uhlobo-3',
    '🤹🏽‍♀' => 'owesimame odlala ngamabhola: uhlobo-4',
    '🤹🏾‍♀' => 'owesimame odlala ngamabhola: uhlobo-5',
    '🤹🏿‍♀' => 'owesimame odlala ngamabhola: uhlobo-6',
    '🧘🏻‍♂' => 'owesilisa esikhundleni se-lotus: uhlobo-1-2',
    '🧘🏼‍♂' => 'owesilisa esikhundleni se-lotus: uhlobo-3',
    '🧘🏽‍♂' => 'owesilisa esikhundleni se-lotus: uhlobo-4',
    '🧘🏾‍♂' => 'owesilisa esikhundleni se-lotus: uhlobo-5',
    '🧘🏿‍♂' => 'owesilisa esikhundleni se-lotus: uhlobo-6',
    '🧘🏻‍♀' => 'owesifazane esikhundleni se-lotus: uhlobo-1-2',
    '🧘🏼‍♀' => 'owesifazane esikhundleni se-lotus: uhlobo-3',
    '🧘🏽‍♀' => 'owesifazane esikhundleni se-lotus: uhlobo-4',
    '🧘🏾‍♀' => 'owesifazane esikhundleni se-lotus: uhlobo-5',
    '🧘🏿‍♀' => 'owesifazane esikhundleni se-lotus: uhlobo-6',
    '🧑‍🦰' => 'mdala: izinwele ezibomvu',
    '🧑‍🦱' => 'mdala: curly hair',
    '🧑‍🦳' => 'mdala: izinwele ezimpunga',
    '🧑‍🦲' => 'mdala: imbungculu',
    '👨‍🦰' => 'indoda: izinwele ezibomvu',
    '👨‍🦱' => 'indoda: curly hair',
    '👨‍🦳' => 'indoda: izinwele ezimpunga',
    '👨‍🦲' => 'indoda: imbungculu',
    '👩‍🦰' => 'umama: izinwele ezibomvu',
    '👩‍🦱' => 'umama: curly hair',
    '👩‍🦳' => 'umama: izinwele ezimpunga',
    '👩‍🦲' => 'umama: imbungculu',
    '👨‍👦' => 'umndeni: indoda, umfana',
    '👨‍👧' => 'umndeni: indoda, intombazane',
    '👩‍👦' => 'umndeni: umama, umfana',
    '👩‍👧' => 'umndeni: umama, intombazane',
    '😶‍🌫' => 'ubuso obusemafini',
    '😮‍💨' => 'ubuso obudonsa umoya',
    '🙂‍↕' => 'ukunikina ikhanda phansi naphezulu',
    '😵‍💫' => 'ubuso obunamehlo anendingiliza',
    '❤‍🔥' => 'inhliziyo ebhakuzayo',
    '❤‍🩹' => 'inhliziyo ehlanganayo',
    '👁‍🗨' => 'ihlo eliyibhaluni lenkulumo',
    '🧔‍♂' => 'indoda enezindevu',
    '👱‍♂' => 'indoda: izinwele ezimhlophe',
    '🧔‍♀' => 'umuntu wesimame : onezindevu',
    '👱‍♀' => 'umama: izinwele ezimhlophe',
    '🙍‍♂' => 'indoda ehwaqabele',
    '🙍‍♀' => 'owesimame ohwaqabele',
    '🙎‍♂' => 'indoda edangele',
    '🙎‍♀' => 'owesimame odangele',
    '🙅‍♂' => 'indoda eveza ukuthi akulungile',
    '🙅‍♀' => 'owesimame oveza ukuthi akulungile',
    '🙆‍♂' => 'owesilisa oveza ukuthi kulungile',
    '🙆‍♀' => 'owesimame oveza ukuthi kulungile',
    '💁‍♂' => 'indoda ecela ngesandla',
    '💁‍♀' => 'owesimame ocela ngesandla',
    '🙋‍♂' => 'indoda ephakamise isandla',
    '🙋‍♀' => 'owesimame ophakamise isandla',
    '🧏‍♂' => 'indoda engezwa',
    '🧏‍♀' => 'umama ongezwa',
    '🙇‍♂' => 'indoda ethobe kakhulu',
    '🙇‍♀' => 'owesimame othobe kakhulu',
    '🤦‍♂' => 'ukuzifihla kowesilisa',
    '🤦‍♀' => 'ukuzifihla kowesimame',
    '🤷‍♂' => 'ukushukuza amahlombe kowesilisa',
    '🤷‍♀' => 'ukushukuza amahlombe kowesimame',
    '🧑‍⚕' => 'umsebenzi wezempilo',
    '👨‍⚕' => 'unesi wesilisa',
    '👩‍⚕' => 'unesi wesifazane',
    '🧑‍🎓' => 'umfundi',
    '👨‍🎓' => 'umfundi wesilisa',
    '👩‍🎓' => 'umfundi wesifazane',
    '🧑‍🏫' => 'uthisha',
    '👨‍🏫' => 'uthisha wesilisa',
    '👩‍🏫' => 'uthisha wesifazane',
    '🧑‍⚖' => 'umahluleli',
    '👨‍⚖' => 'ijaji lesilisa',
    '👩‍⚖' => 'ijaji lesifazane',
    '🧑‍🌾' => 'umlimi',
    '👨‍🌾' => 'umlimi wesilisa',
    '👩‍🌾' => 'umlimi wesimame',
    '🧑‍🍳' => 'pheka',
    '👨‍🍳' => 'umpheki wesilisa',
    '👩‍🍳' => 'umpheki wesimame',
    '🧑‍🔧' => 'umakhenikha',
    '👨‍🔧' => 'umakhenikha wesilisa',
    '👩‍🔧' => 'umakhenikha wesimame',
    '🧑‍🏭' => 'umsebenzi wasefemini',
    '👨‍🏭' => 'umsebenzi wasefemini wesilisa',
    '👩‍🏭' => 'umsebenzi wasefemini wesifazane',
    '🧑‍💼' => 'umsebenzi wase-ofisi',
    '👨‍💼' => 'umsebenzi wasehhovisi wesilisa',
    '👩‍💼' => 'umsebenzi wasehhovisi wesifazane',
    '🧑‍🔬' => 'usosayensi',
    '👨‍🔬' => 'usosayensi wesilisa',
    '👩‍🔬' => 'usosayensi wesifazane',
    '🧑‍💻' => 'umcwaningi wethekhnoloji',
    '👨‍💻' => 'usochwepheshe wendoda',
    '👩‍💻' => 'usochwepheshe wesifazane',
    '🧑‍🎤' => 'umculi',
    '👨‍🎤' => 'umculi wesilisa',
    '👩‍🎤' => 'umculi wesimame',
    '🧑‍🎨' => 'iciko',
    '👨‍🎨' => 'umdwebi wesilisa',
    '👩‍🎨' => 'umdwebi wesimame',
    '🧑‍✈' => 'umshayeli webhanoyi',
    '👨‍✈' => 'umqhubi webhanoyi wesilisa',
    '👩‍✈' => 'umqhubi webhanoyi wesifazane',
    '🧑‍🚀' => 'i-astronaut',
    '👨‍🚀' => 'i-astronaut yesilisa',
    '👩‍🚀' => 'i-astronaut yesifazane',
    '🧑‍🚒' => 'isicishimlilo',
    '👨‍🚒' => 'isicishamlilo sesilisa',
    '👩‍🚒' => 'isicishamlilo sowesifazane',
    '👮‍♂' => 'iphoyisa lesilisa',
    '👮‍♀' => 'iphoyisa lesifazane',
    '🕵‍♂' => 'umseshi wesilisa',
    '🕵‍♀' => 'umseshi wesifazane',
    '💂‍♂' => 'unogada wesilisa',
    '💂‍♀' => 'unogada wesifazane',
    '👷‍♂' => 'umsebenzi wenkontileka wesilisa',
    '👷‍♀' => 'umsebenzi wenkontileka wesifazane',
    '👳‍♂' => 'indoda egqoke ithalibhani',
    '👳‍♀' => 'owesimame ogqoke ithalibhani',
    '🤵‍♂' => 'indoda igqoke isudi',
    '🤵‍♀' => 'owesifazane ugqoke isudi',
    '👰‍♂' => 'indoda ifake iveyili',
    '👰‍♀' => 'owesifazane ufake iveyili',
    '👩‍🍼' => 'owesifazane uncelisa ingane',
    '👨‍🍼' => 'indoda incelisa ingane',
    '🧑‍🍼' => 'umuntu oncelisa ingane',
    '🧑‍🎄' => 'u-mx claus',
    '🦸‍♂' => 'man superhero',
    '🦸‍♀' => 'woman superhero',
    '🦹‍♂' => 'man supervillain',
    '🦹‍♀' => 'woman supervillain',
    '🧙‍♂' => 'i-mage yowesilisa',
    '🧙‍♀' => 'i-mage yowesifazane',
    '🧚‍♂' => 'ngelosi yesilisa',
    '🧚‍♀' => 'ngelosi yesifazane',
    '🧛‍♂' => 'ivemphaya lendoda',
    '🧛‍♀' => 'ivemphaya lesifazane',
    '🧜‍♂' => 'i-merman',
    '🧜‍♀' => 'i-mermaid',
    '🧝‍♂' => 'i-elf yesilisa',
    '🧝‍♀' => 'i-elf yesifazane',
    '🧞‍♂' => 'ijeni yesilisa',
    '🧞‍♀' => 'ijeni yesifazane',
    '🧟‍♂' => 'isipoki sowesilisa',
    '🧟‍♀' => 'isilwane sowesifazane',
    '💆‍♂' => 'indoda ethola imasaji ebusweni',
    '💆‍♀' => 'owesimame othola imasaji ebusweni',
    '💇‍♂' => 'indoda egundayo',
    '💇‍♀' => 'owesimame ogundayo',
    '🚶‍♂' => 'indoda ehambayo',
    '🚶‍♀' => 'owesimame ohambayo',
    '🧍‍♂' => 'indoda emile',
    '🧍‍♀' => 'umama omile',
    '🧎‍♂' => 'indoda eguqlile',
    '🧎‍♀' => 'umama ogulile',
    '🧑‍🦯' => 'umuntu onenkinga yokungena',
    '👨‍🦯' => 'indoda enekheni lokuhlola',
    '👩‍🦯' => 'umama onekheni lokuhlola',
    '🧑‍🦼' => 'umuntu onesihlalo sabakhubazekile',
    '👨‍🦼' => 'indoda esesitulweni esizihambelayo',
    '👩‍🦼' => 'umama osesitulweni esizihambelayo',
    '🧑‍🦽' => 'umuntu ohlezi esihlalweni sabakhubazekile',
    '👨‍🦽' => 'indoda esesitulweni sokuhanjiswa',
    '👩‍🦽' => 'umama osesitulweni sokuhanjiswa',
    '🏃‍♂' => 'indoda egijimayo',
    '🏃‍♀' => 'owesimame ogijimayo',
    '🧑‍🩰' => 'ballet dancer',
    '👯‍♂' => 'amadoda asemcimbini',
    '👯‍♀' => 'abasemame abasemcimbini',
    '🧖‍♂' => 'owesilisa egunjini lestimu',
    '🧖‍♀' => 'owesifazane egunjini lestimu',
    '🧗‍♂' => 'owesilisa oqwalayo',
    '🧗‍♀' => 'owesifazane oqwalayo',
    '🏌‍♂' => 'indoda edlala igalofu',
    '🏌‍♀' => 'owesimame odlala igalofu',
    '🏄‍♂' => 'indoda edlala isurfing',
    '🏄‍♀' => 'owesimame odlala isurfing',
    '🚣‍♂' => 'indoda egwedla isikebhe',
    '🚣‍♀' => 'owesimame ogwedla isikebhe',
    '🏊‍♂' => 'indoda ebhukudayo',
    '🏊‍♀' => 'owesimame obhukudayo',
    '⛹‍♂' => 'indoda enebhola',
    '⛹‍♀' => 'owesimame onebhola',
    '🏋‍♂' => 'indoda ephakamisa izinsimbi',
    '🏋‍♀' => 'owesimame ophakamisa izinsimbi',
    '🚴‍♂' => 'indoda egibele ibhayisikili',
    '🚴‍♀' => 'owesimeme ogibele ibhayisikili',
    '🚵‍♂' => 'indoda egibele ibhayisikili lezintaba',
    '🚵‍♀' => 'owesimame ogibele ibhayisikili lezintaba',
    '🤸‍♂' => 'owesilisa enza isondo lekalishi',
    '🤸‍♀' => 'owesimame enza isondo lekalishi',
    '🤼‍♂' => 'abashayisibhakela besilisa',
    '🤼‍♀' => 'abashayisibhakela besimame',
    '🤽‍♂' => 'umdlalo webhola lasemanzini wowesilisa',
    '🤽‍♀' => 'umdlalo webhola lasemanzini wowesimame',
    '🤾‍♂' => 'ibhola lesandla lowesilisa',
    '🤾‍♀' => 'ibhola lesandla lowesimame',
    '🤹‍♂' => 'indoda edlala ngamabhola',
    '🤹‍♀' => 'owesimame odlala ngamabhola',
    '🧘‍♂' => 'owesilisa esikhundleni se-lotus',
    '🧘‍♀' => 'owesifazane esikhundleni se-lotus',
    '🧑‍🧒' => 'umndeni: omdala, ingane',
    '🐕‍🦺' => 'inja yesevisi',
    '🐈‍⬛' => 'ikati elimnyama',
    '🐻‍❄' => 'polar bear',
    '🐦‍⬛' => 'inyoni emnyama',
    '🐦‍🔥' => 'phoenix',
    '🍋‍🟩' => 'lime',
    '🍄‍🟫' => 'ikhowe elinsundu',
    '⛓‍💥' => 'iketango eliphukile',
    '🏳‍🌈' => 'Ifulegi elimibalabala',
    '🏳‍⚧' => 'ifulegi eli-blue, pink nokumhlophe',
    '🏴‍☠' => 'pirate flag',
    '👋🏻' => 'ukuphakamisa isandla: uhlobo-1-2',
    '👋🏼' => 'ukuphakamisa isandla: uhlobo-3',
    '👋🏽' => 'ukuphakamisa isandla: uhlobo-4',
    '👋🏾' => 'ukuphakamisa isandla: uhlobo-5',
    '👋🏿' => 'ukuphakamisa isandla: uhlobo-6',
    '🤚🏻' => 'thula: uhlobo-1-2',
    '🤚🏼' => 'thula: uhlobo-3',
    '🤚🏽' => 'thula: uhlobo-4',
    '🤚🏾' => 'thula: uhlobo-5',
    '🤚🏿' => 'thula: uhlobo-6',
    '🖐🏻' => 'isandla esiphakanyisiwe esivuliwe: uhlobo-1-2',
    '🖐🏼' => 'isandla esiphakanyisiwe esivuliwe: uhlobo-3',
    '🖐🏽' => 'isandla esiphakanyisiwe esivuliwe: uhlobo-4',
    '🖐🏾' => 'isandla esiphakanyisiwe esivuliwe: uhlobo-5',
    '🖐🏿' => 'isandla esiphakanyisiwe esivuliwe: uhlobo-6',
    '✋🏻' => 'isandla esiphanyisiwe: uhlobo-1-2',
    '✋🏼' => 'isandla esiphanyisiwe: uhlobo-3',
    '✋🏽' => 'isandla esiphanyisiwe: uhlobo-4',
    '✋🏾' => 'isandla esiphanyisiwe: uhlobo-5',
    '✋🏿' => 'isandla esiphanyisiwe: uhlobo-6',
    '🖖🏻' => 'i-vulcan salute: uhlobo-1-2',
    '🖖🏼' => 'i-vulcan salute: uhlobo-3',
    '🖖🏽' => 'i-vulcan salute: uhlobo-4',
    '🖖🏾' => 'i-vulcan salute: uhlobo-5',
    '🖖🏿' => 'i-vulcan salute: uhlobo-6',
    '🫱🏻' => 'rightwards hand: uhlobo-1-2',
    '🫱🏼' => 'rightwards hand: uhlobo-3',
    '🫱🏽' => 'rightwards hand: uhlobo-4',
    '🫱🏾' => 'rightwards hand: uhlobo-5',
    '🫱🏿' => 'rightwards hand: uhlobo-6',
    '🫲🏻' => 'leftwards hand: uhlobo-1-2',
    '🫲🏼' => 'leftwards hand: uhlobo-3',
    '🫲🏽' => 'leftwards hand: uhlobo-4',
    '🫲🏾' => 'leftwards hand: uhlobo-5',
    '🫲🏿' => 'leftwards hand: uhlobo-6',
    '🫳🏻' => 'palm down hand: uhlobo-1-2',
    '🫳🏼' => 'palm down hand: uhlobo-3',
    '🫳🏽' => 'palm down hand: uhlobo-4',
    '🫳🏾' => 'palm down hand: uhlobo-5',
    '🫳🏿' => 'palm down hand: uhlobo-6',
    '🫴🏻' => 'palm up hand: uhlobo-1-2',
    '🫴🏼' => 'palm up hand: uhlobo-3',
    '🫴🏽' => 'palm up hand: uhlobo-4',
    '🫴🏾' => 'palm up hand: uhlobo-5',
    '🫴🏿' => 'palm up hand: uhlobo-6',
    '🫷🏻' => 'leftwards pushing hand: uhlobo-1-2',
    '🫷🏼' => 'leftwards pushing hand: uhlobo-3',
    '🫷🏽' => 'leftwards pushing hand: uhlobo-4',
    '🫷🏾' => 'leftwards pushing hand: uhlobo-5',
    '🫷🏿' => 'leftwards pushing hand: uhlobo-6',
    '🫸🏻' => 'rightwards pushing hand: uhlobo-1-2',
    '🫸🏼' => 'rightwards pushing hand: uhlobo-3',
    '🫸🏽' => 'rightwards pushing hand: uhlobo-4',
    '🫸🏾' => 'rightwards pushing hand: uhlobo-5',
    '🫸🏿' => 'rightwards pushing hand: uhlobo-6',
    '👌🏻' => 'isandla sokuthi kulungile: uhlobo-1-2',
    '👌🏼' => 'isandla sokuthi kulungile: uhlobo-3',
    '👌🏽' => 'isandla sokuthi kulungile: uhlobo-4',
    '👌🏾' => 'isandla sokuthi kulungile: uhlobo-5',
    '👌🏿' => 'isandla sokuthi kulungile: uhlobo-6',
    '🤌🏻' => 'iminwe encinziwe: uhlobo-1-2',
    '🤌🏼' => 'iminwe encinziwe: uhlobo-3',
    '🤌🏽' => 'iminwe encinziwe: uhlobo-4',
    '🤌🏾' => 'iminwe encinziwe: uhlobo-5',
    '🤌🏿' => 'iminwe encinziwe: uhlobo-6',
    '🤏🏻' => 'isandla esincinzayo: uhlobo-1-2',
    '🤏🏼' => 'isandla esincinzayo: uhlobo-3',
    '🤏🏽' => 'isandla esincinzayo: uhlobo-4',
    '🤏🏾' => 'isandla esincinzayo: uhlobo-5',
    '🤏🏿' => 'isandla esincinzayo: uhlobo-6',
    '✌🏻' => 'isandla sokunqoba: uhlobo-1-2',
    '✌🏼' => 'isandla sokunqoba: uhlobo-3',
    '✌🏽' => 'isandla sokunqoba: uhlobo-4',
    '✌🏾' => 'isandla sokunqoba: uhlobo-5',
    '✌🏿' => 'isandla sokunqoba: uhlobo-6',
    '🤞🏻' => 'iminwe ebhanqiwe: uhlobo-1-2',
    '🤞🏼' => 'iminwe ebhanqiwe: uhlobo-3',
    '🤞🏽' => 'iminwe ebhanqiwe: uhlobo-4',
    '🤞🏾' => 'iminwe ebhanqiwe: uhlobo-5',
    '🤞🏿' => 'iminwe ebhanqiwe: uhlobo-6',
    '🫰🏻' => 'hand with index finger and thumb crossed: uhlobo-1-2',
    '🫰🏼' => 'hand with index finger and thumb crossed: uhlobo-3',
    '🫰🏽' => 'hand with index finger and thumb crossed: uhlobo-4',
    '🫰🏾' => 'hand with index finger and thumb crossed: uhlobo-5',
    '🫰🏿' => 'hand with index finger and thumb crossed: uhlobo-6',
    '🤟🏻' => 'ukukhombisa uthando: uhlobo-1-2',
    '🤟🏼' => 'ukukhombisa uthando: uhlobo-3',
    '🤟🏽' => 'ukukhombisa uthando: uhlobo-4',
    '🤟🏾' => 'ukukhombisa uthando: uhlobo-5',
    '🤟🏿' => 'ukukhombisa uthando: uhlobo-6',
    '🤘🏻' => 'uphawu lwezimpondo: uhlobo-1-2',
    '🤘🏼' => 'uphawu lwezimpondo: uhlobo-3',
    '🤘🏽' => 'uphawu lwezimpondo: uhlobo-4',
    '🤘🏾' => 'uphawu lwezimpondo: uhlobo-5',
    '🤘🏿' => 'uphawu lwezimpondo: uhlobo-6',
    '🤙🏻' => 'ngifonele: uhlobo-1-2',
    '🤙🏼' => 'ngifonele: uhlobo-3',
    '🤙🏽' => 'ngifonele: uhlobo-4',
    '🤙🏾' => 'ngifonele: uhlobo-5',
    '🤙🏿' => 'ngifonele: uhlobo-6',
    '👈🏻' => 'ukukhomba ngengemuva lesandla sokunxele ngomunwe wokukhomba: uhlobo-1-2',
    '👈🏼' => 'ukukhomba ngengemuva lesandla sokunxele ngomunwe wokukhomba: uhlobo-3',
    '👈🏽' => 'ukukhomba ngengemuva lesandla sokunxele ngomunwe wokukhomba: uhlobo-4',
    '👈🏾' => 'ukukhomba ngengemuva lesandla sokunxele ngomunwe wokukhomba: uhlobo-5',
    '👈🏿' => 'ukukhomba ngengemuva lesandla sokunxele ngomunwe wokukhomba: uhlobo-6',
    '👉🏻' => 'ukukhomba ngengemuva lesandla sokudla ngomunwe wokukhomba: uhlobo-1-2',
    '👉🏼' => 'ukukhomba ngengemuva lesandla sokudla ngomunwe wokukhomba: uhlobo-3',
    '👉🏽' => 'ukukhomba ngengemuva lesandla sokudla ngomunwe wokukhomba: uhlobo-4',
    '👉🏾' => 'ukukhomba ngengemuva lesandla sokudla ngomunwe wokukhomba: uhlobo-5',
    '👉🏿' => 'ukukhomba ngengemuva lesandla sokudla ngomunwe wokukhomba: uhlobo-6',
    '👆🏻' => 'ukukhomba phezulu ngengemuva lesandla ngomunwe wokukhomba: uhlobo-1-2',
    '👆🏼' => 'ukukhomba phezulu ngengemuva lesandla ngomunwe wokukhomba: uhlobo-3',
    '👆🏽' => 'ukukhomba phezulu ngengemuva lesandla ngomunwe wokukhomba: uhlobo-4',
    '👆🏾' => 'ukukhomba phezulu ngengemuva lesandla ngomunwe wokukhomba: uhlobo-5',
    '👆🏿' => 'ukukhomba phezulu ngengemuva lesandla ngomunwe wokukhomba: uhlobo-6',
    '🖕🏻' => 'umunwe omaphakathi: uhlobo-1-2',
    '🖕🏼' => 'umunwe omaphakathi: uhlobo-3',
    '🖕🏽' => 'umunwe omaphakathi: uhlobo-4',
    '🖕🏾' => 'umunwe omaphakathi: uhlobo-5',
    '🖕🏿' => 'umunwe omaphakathi: uhlobo-6',
    '👇🏻' => 'ukukhomba phansi ngengemuva lesandla ngomunwe wokukhomba: uhlobo-1-2',
    '👇🏼' => 'ukukhomba phansi ngengemuva lesandla ngomunwe wokukhomba: uhlobo-3',
    '👇🏽' => 'ukukhomba phansi ngengemuva lesandla ngomunwe wokukhomba: uhlobo-4',
    '👇🏾' => 'ukukhomba phansi ngengemuva lesandla ngomunwe wokukhomba: uhlobo-5',
    '👇🏿' => 'ukukhomba phansi ngengemuva lesandla ngomunwe wokukhomba: uhlobo-6',
    '☝🏻' => 'umunwe wokukhomba okhombe phezulu: uhlobo-1-2',
    '☝🏼' => 'umunwe wokukhomba okhombe phezulu: uhlobo-3',
    '☝🏽' => 'umunwe wokukhomba okhombe phezulu: uhlobo-4',
    '☝🏾' => 'umunwe wokukhomba okhombe phezulu: uhlobo-5',
    '☝🏿' => 'umunwe wokukhomba okhombe phezulu: uhlobo-6',
    '🫵🏻' => 'umunwe ukhomba umbukeli: uhlobo-1-2',
    '🫵🏼' => 'umunwe ukhomba umbukeli: uhlobo-3',
    '🫵🏽' => 'umunwe ukhomba umbukeli: uhlobo-4',
    '🫵🏾' => 'umunwe ukhomba umbukeli: uhlobo-5',
    '🫵🏿' => 'umunwe ukhomba umbukeli: uhlobo-6',
    '👍🏻' => 'ukumisa isithupha: uhlobo-1-2',
    '👍🏼' => 'ukumisa isithupha: uhlobo-3',
    '👍🏽' => 'ukumisa isithupha: uhlobo-4',
    '👍🏾' => 'ukumisa isithupha: uhlobo-5',
    '👍🏿' => 'ukumisa isithupha: uhlobo-6',
    '👎🏻' => 'ukubhekisa phansi isithupha: uhlobo-1-2',
    '👎🏼' => 'ukubhekisa phansi isithupha: uhlobo-3',
    '👎🏽' => 'ukubhekisa phansi isithupha: uhlobo-4',
    '👎🏾' => 'ukubhekisa phansi isithupha: uhlobo-5',
    '👎🏿' => 'ukubhekisa phansi isithupha: uhlobo-6',
    '✊🏻' => 'iqupha elimisiwe: uhlobo-1-2',
    '✊🏼' => 'iqupha elimisiwe: uhlobo-3',
    '✊🏽' => 'iqupha elimisiwe: uhlobo-4',
    '✊🏾' => 'iqupha elimisiwe: uhlobo-5',
    '✊🏿' => 'iqupha elimisiwe: uhlobo-6',
    '👊🏻' => 'iqupha elizayo: uhlobo-1-2',
    '👊🏼' => 'iqupha elizayo: uhlobo-3',
    '👊🏽' => 'iqupha elizayo: uhlobo-4',
    '👊🏾' => 'iqupha elizayo: uhlobo-5',
    '👊🏿' => 'iqupha elizayo: uhlobo-6',
    '🤛🏻' => 'inqindi ebheke kwesokunxele: uhlobo-1-2',
    '🤛🏼' => 'inqindi ebheke kwesokunxele: uhlobo-3',
    '🤛🏽' => 'inqindi ebheke kwesokunxele: uhlobo-4',
    '🤛🏾' => 'inqindi ebheke kwesokunxele: uhlobo-5',
    '🤛🏿' => 'inqindi ebheke kwesokunxele: uhlobo-6',
    '🤜🏻' => 'inqindi ebheke kwesokudla: uhlobo-1-2',
    '🤜🏼' => 'inqindi ebheke kwesokudla: uhlobo-3',
    '🤜🏽' => 'inqindi ebheke kwesokudla: uhlobo-4',
    '🤜🏾' => 'inqindi ebheke kwesokudla: uhlobo-5',
    '🤜🏿' => 'inqindi ebheke kwesokudla: uhlobo-6',
    '👏🏻' => 'ukushaya izandla: uhlobo-1-2',
    '👏🏼' => 'ukushaya izandla: uhlobo-3',
    '👏🏽' => 'ukushaya izandla: uhlobo-4',
    '👏🏾' => 'ukushaya izandla: uhlobo-5',
    '👏🏿' => 'ukushaya izandla: uhlobo-6',
    '🙌🏻' => 'umuntu ophakamise izandla: uhlobo-1-2',
    '🙌🏼' => 'umuntu ophakamise izandla: uhlobo-3',
    '🙌🏽' => 'umuntu ophakamise izandla: uhlobo-4',
    '🙌🏾' => 'umuntu ophakamise izandla: uhlobo-5',
    '🙌🏿' => 'umuntu ophakamise izandla: uhlobo-6',
    '🫶🏻' => 'thanda izandla: uhlobo-1-2',
    '🫶🏼' => 'thanda izandla: uhlobo-3',
    '🫶🏽' => 'thanda izandla: uhlobo-4',
    '🫶🏾' => 'thanda izandla: uhlobo-5',
    '🫶🏿' => 'thanda izandla: uhlobo-6',
    '👐🏻' => 'izandla ezivuliwe: uhlobo-1-2',
    '👐🏼' => 'izandla ezivuliwe: uhlobo-3',
    '👐🏽' => 'izandla ezivuliwe: uhlobo-4',
    '👐🏾' => 'izandla ezivuliwe: uhlobo-5',
    '👐🏿' => 'izandla ezivuliwe: uhlobo-6',
    '🤲🏻' => 'izandla zombili phezulu: uhlobo-1-2',
    '🤲🏼' => 'izandla zombili phezulu: uhlobo-3',
    '🤲🏽' => 'izandla zombili phezulu: uhlobo-4',
    '🤲🏾' => 'izandla zombili phezulu: uhlobo-5',
    '🤲🏿' => 'izandla zombili phezulu: uhlobo-6',
    '🤝🏻' => 'xhawula: uhlobo-1-2',
    '🤝🏼' => 'xhawula: uhlobo-3',
    '🤝🏽' => 'xhawula: uhlobo-4',
    '🤝🏾' => 'xhawula: uhlobo-5',
    '🤝🏿' => 'xhawula: uhlobo-6',
    '🙏🏻' => 'izandla ezigoqiwe: uhlobo-1-2',
    '🙏🏼' => 'izandla ezigoqiwe: uhlobo-3',
    '🙏🏽' => 'izandla ezigoqiwe: uhlobo-4',
    '🙏🏾' => 'izandla ezigoqiwe: uhlobo-5',
    '🙏🏿' => 'izandla ezigoqiwe: uhlobo-6',
    '✍🏻' => 'isandla esibhalayo: uhlobo-1-2',
    '✍🏼' => 'isandla esibhalayo: uhlobo-3',
    '✍🏽' => 'isandla esibhalayo: uhlobo-4',
    '✍🏾' => 'isandla esibhalayo: uhlobo-5',
    '✍🏿' => 'isandla esibhalayo: uhlobo-6',
    '💅🏻' => 'ikhyutheksi: uhlobo-1-2',
    '💅🏼' => 'ikhyutheksi: uhlobo-3',
    '💅🏽' => 'ikhyutheksi: uhlobo-4',
    '💅🏾' => 'ikhyutheksi: uhlobo-5',
    '💅🏿' => 'ikhyutheksi: uhlobo-6',
    '🤳🏻' => 'uzishuthe: uhlobo-1-2',
    '🤳🏼' => 'uzishuthe: uhlobo-3',
    '🤳🏽' => 'uzishuthe: uhlobo-4',
    '🤳🏾' => 'uzishuthe: uhlobo-5',
    '🤳🏿' => 'uzishuthe: uhlobo-6',
    '💪🏻' => 'ukuveza amandla: uhlobo-1-2',
    '💪🏼' => 'ukuveza amandla: uhlobo-3',
    '💪🏽' => 'ukuveza amandla: uhlobo-4',
    '💪🏾' => 'ukuveza amandla: uhlobo-5',
    '💪🏿' => 'ukuveza amandla: uhlobo-6',
    '🦵🏻' => 'umlenze: uhlobo-1-2',
    '🦵🏼' => 'umlenze: uhlobo-3',
    '🦵🏽' => 'umlenze: uhlobo-4',
    '🦵🏾' => 'umlenze: uhlobo-5',
    '🦵🏿' => 'umlenze: uhlobo-6',
    '🦶🏻' => 'unyawo: uhlobo-1-2',
    '🦶🏼' => 'unyawo: uhlobo-3',
    '🦶🏽' => 'unyawo: uhlobo-4',
    '🦶🏾' => 'unyawo: uhlobo-5',
    '🦶🏿' => 'unyawo: uhlobo-6',
    '👂🏻' => 'indlebe: uhlobo-1-2',
    '👂🏼' => 'indlebe: uhlobo-3',
    '👂🏽' => 'indlebe: uhlobo-4',
    '👂🏾' => 'indlebe: uhlobo-5',
    '👂🏿' => 'indlebe: uhlobo-6',
    '🦻🏻' => 'indlebe enensiza yokuzwa: uhlobo-1-2',
    '🦻🏼' => 'indlebe enensiza yokuzwa: uhlobo-3',
    '🦻🏽' => 'indlebe enensiza yokuzwa: uhlobo-4',
    '🦻🏾' => 'indlebe enensiza yokuzwa: uhlobo-5',
    '🦻🏿' => 'indlebe enensiza yokuzwa: uhlobo-6',
    '👃🏻' => 'ikhala: uhlobo-1-2',
    '👃🏼' => 'ikhala: uhlobo-3',
    '👃🏽' => 'ikhala: uhlobo-4',
    '👃🏾' => 'ikhala: uhlobo-5',
    '👃🏿' => 'ikhala: uhlobo-6',
    '👶🏻' => 'usana: uhlobo-1-2',
    '👶🏼' => 'usana: uhlobo-3',
    '👶🏽' => 'usana: uhlobo-4',
    '👶🏾' => 'usana: uhlobo-5',
    '👶🏿' => 'usana: uhlobo-6',
    '🧒🏻' => 'ingane: uhlobo-1-2',
    '🧒🏼' => 'ingane: uhlobo-3',
    '🧒🏽' => 'ingane: uhlobo-4',
    '🧒🏾' => 'ingane: uhlobo-5',
    '🧒🏿' => 'ingane: uhlobo-6',
    '👦🏻' => 'umfana: uhlobo-1-2',
    '👦🏼' => 'umfana: uhlobo-3',
    '👦🏽' => 'umfana: uhlobo-4',
    '👦🏾' => 'umfana: uhlobo-5',
    '👦🏿' => 'umfana: uhlobo-6',
    '👧🏻' => 'intombazane: uhlobo-1-2',
    '👧🏼' => 'intombazane: uhlobo-3',
    '👧🏽' => 'intombazane: uhlobo-4',
    '👧🏾' => 'intombazane: uhlobo-5',
    '👧🏿' => 'intombazane: uhlobo-6',
    '🧑🏻' => 'mdala: uhlobo-1-2',
    '🧑🏼' => 'mdala: uhlobo-3',
    '🧑🏽' => 'mdala: uhlobo-4',
    '🧑🏾' => 'mdala: uhlobo-5',
    '🧑🏿' => 'mdala: uhlobo-6',
    '👱🏻' => 'umuntu: uhlobo-1-2, izinwele ezinhlophe',
    '👱🏼' => 'umuntu: uhlobo-3, izinwele ezinhlophe',
    '👱🏽' => 'umuntu: uhlobo-4, izinwele ezinhlophe',
    '👱🏾' => 'umuntu: uhlobo-5, izinwele ezinhlophe',
    '👱🏿' => 'umuntu: uhlobo-6, izinwele ezinhlophe',
    '👨🏻' => 'indoda: uhlobo-1-2',
    '👨🏼' => 'indoda: uhlobo-3',
    '👨🏽' => 'indoda: uhlobo-4',
    '👨🏾' => 'indoda: uhlobo-5',
    '👨🏿' => 'indoda: uhlobo-6',
    '🧔🏻' => 'indoda: uhlobo-1-2, intshebe',
    '🧔🏼' => 'indoda: uhlobo-3, intshebe',
    '🧔🏽' => 'indoda: uhlobo-4, intshebe',
    '🧔🏾' => 'indoda: uhlobo-5, intshebe',
    '🧔🏿' => 'indoda: uhlobo-6, intshebe',
    '👩🏻' => 'umama: uhlobo-1-2',
    '👩🏼' => 'umama: uhlobo-3',
    '👩🏽' => 'umama: uhlobo-4',
    '👩🏾' => 'umama: uhlobo-5',
    '👩🏿' => 'umama: uhlobo-6',
    '🧓🏻' => 'omdala omdala: uhlobo-1-2',
    '🧓🏼' => 'omdala omdala: uhlobo-3',
    '🧓🏽' => 'omdala omdala: uhlobo-4',
    '🧓🏾' => 'omdala omdala: uhlobo-5',
    '🧓🏿' => 'omdala omdala: uhlobo-6',
    '👴🏻' => 'ikhehla: uhlobo-1-2',
    '👴🏼' => 'ikhehla: uhlobo-3',
    '👴🏽' => 'ikhehla: uhlobo-4',
    '👴🏾' => 'ikhehla: uhlobo-5',
    '👴🏿' => 'ikhehla: uhlobo-6',
    '👵🏻' => 'ugogo: uhlobo-1-2',
    '👵🏼' => 'ugogo: uhlobo-3',
    '👵🏽' => 'ugogo: uhlobo-4',
    '👵🏾' => 'ugogo: uhlobo-5',
    '👵🏿' => 'ugogo: uhlobo-6',
    '🙍🏻' => 'umuntu ohwaqabele: uhlobo-1-2',
    '🙍🏼' => 'umuntu ohwaqabele: uhlobo-3',
    '🙍🏽' => 'umuntu ohwaqabele: uhlobo-4',
    '🙍🏾' => 'umuntu ohwaqabele: uhlobo-5',
    '🙍🏿' => 'umuntu ohwaqabele: uhlobo-6',
    '🙎🏻' => 'umuntu odangele: uhlobo-1-2',
    '🙎🏼' => 'umuntu odangele: uhlobo-3',
    '🙎🏽' => 'umuntu odangele: uhlobo-4',
    '🙎🏾' => 'umuntu odangele: uhlobo-5',
    '🙎🏿' => 'umuntu odangele: uhlobo-6',
    '🙅🏻' => 'umuntu oveza ukuthi akulungile: uhlobo-1-2',
    '🙅🏼' => 'umuntu oveza ukuthi akulungile: uhlobo-3',
    '🙅🏽' => 'umuntu oveza ukuthi akulungile: uhlobo-4',
    '🙅🏾' => 'umuntu oveza ukuthi akulungile: uhlobo-5',
    '🙅🏿' => 'umuntu oveza ukuthi akulungile: uhlobo-6',
    '🙆🏻' => 'umuntu oveza ukuthi kulungile: uhlobo-1-2',
    '🙆🏼' => 'umuntu oveza ukuthi kulungile: uhlobo-3',
    '🙆🏽' => 'umuntu oveza ukuthi kulungile: uhlobo-4',
    '🙆🏾' => 'umuntu oveza ukuthi kulungile: uhlobo-5',
    '🙆🏿' => 'umuntu oveza ukuthi kulungile: uhlobo-6',
    '💁🏻' => 'umuntu ocela ngesandla: uhlobo-1-2',
    '💁🏼' => 'umuntu ocela ngesandla: uhlobo-3',
    '💁🏽' => 'umuntu ocela ngesandla: uhlobo-4',
    '💁🏾' => 'umuntu ocela ngesandla: uhlobo-5',
    '💁🏿' => 'umuntu ocela ngesandla: uhlobo-6',
    '🙋🏻' => 'umuntu ophakamisa isandla: uhlobo-1-2',
    '🙋🏼' => 'umuntu ophakamisa isandla: uhlobo-3',
    '🙋🏽' => 'umuntu ophakamisa isandla: uhlobo-4',
    '🙋🏾' => 'umuntu ophakamisa isandla: uhlobo-5',
    '🙋🏿' => 'umuntu ophakamisa isandla: uhlobo-6',
    '🧏🏻' => 'umuntu ongezwa: uhlobo-1-2',
    '🧏🏼' => 'umuntu ongezwa: uhlobo-3',
    '🧏🏽' => 'umuntu ongezwa: uhlobo-4',
    '🧏🏾' => 'umuntu ongezwa: uhlobo-5',
    '🧏🏿' => 'umuntu ongezwa: uhlobo-6',
    '🙇🏻' => 'umuntu othobile: uhlobo-1-2',
    '🙇🏼' => 'umuntu othobile: uhlobo-3',
    '🙇🏽' => 'umuntu othobile: uhlobo-4',
    '🙇🏾' => 'umuntu othobile: uhlobo-5',
    '🙇🏿' => 'umuntu othobile: uhlobo-6',
    '🤦🏻' => 'ukuzifihla: uhlobo-1-2',
    '🤦🏼' => 'ukuzifihla: uhlobo-3',
    '🤦🏽' => 'ukuzifihla: uhlobo-4',
    '🤦🏾' => 'ukuzifihla: uhlobo-5',
    '🤦🏿' => 'ukuzifihla: uhlobo-6',
    '🤷🏻' => 'shukuza amahlombe: uhlobo-1-2',
    '🤷🏼' => 'shukuza amahlombe: uhlobo-3',
    '🤷🏽' => 'shukuza amahlombe: uhlobo-4',
    '🤷🏾' => 'shukuza amahlombe: uhlobo-5',
    '🤷🏿' => 'shukuza amahlombe: uhlobo-6',
    '👮🏻' => 'iphoyisa: uhlobo-1-2',
    '👮🏼' => 'iphoyisa: uhlobo-3',
    '👮🏽' => 'iphoyisa: uhlobo-4',
    '👮🏾' => 'iphoyisa: uhlobo-5',
    '👮🏿' => 'iphoyisa: uhlobo-6',
    '🕵🏻' => 'umseshi: uhlobo-1-2',
    '🕵🏼' => 'umseshi: uhlobo-3',
    '🕵🏽' => 'umseshi: uhlobo-4',
    '🕵🏾' => 'umseshi: uhlobo-5',
    '🕵🏿' => 'umseshi: uhlobo-6',
    '💂🏻' => 'unogada: uhlobo-1-2',
    '💂🏼' => 'unogada: uhlobo-3',
    '💂🏽' => 'unogada: uhlobo-4',
    '💂🏾' => 'unogada: uhlobo-5',
    '💂🏿' => 'unogada: uhlobo-6',
    '🥷🏻' => 'ininja: uhlobo-1-2',
    '🥷🏼' => 'ininja: uhlobo-3',
    '🥷🏽' => 'ininja: uhlobo-4',
    '🥷🏾' => 'ininja: uhlobo-5',
    '🥷🏿' => 'ininja: uhlobo-6',
    '👷🏻' => 'umsebenzi wenkontileka: uhlobo-1-2',
    '👷🏼' => 'umsebenzi wenkontileka: uhlobo-3',
    '👷🏽' => 'umsebenzi wenkontileka: uhlobo-4',
    '👷🏾' => 'umsebenzi wenkontileka: uhlobo-5',
    '👷🏿' => 'umsebenzi wenkontileka: uhlobo-6',
    '🫅🏻' => 'umuntu onesicoco: uhlobo-1-2',
    '🫅🏼' => 'umuntu onesicoco: uhlobo-3',
    '🫅🏽' => 'umuntu onesicoco: uhlobo-4',
    '🫅🏾' => 'umuntu onesicoco: uhlobo-5',
    '🫅🏿' => 'umuntu onesicoco: uhlobo-6',
    '🤴🏻' => 'inkosana: uhlobo-1-2',
    '🤴🏼' => 'inkosana: uhlobo-3',
    '🤴🏽' => 'inkosana: uhlobo-4',
    '🤴🏾' => 'inkosana: uhlobo-5',
    '🤴🏿' => 'inkosana: uhlobo-6',
    '👸🏻' => 'inkosazane: uhlobo-1-2',
    '👸🏼' => 'inkosazane: uhlobo-3',
    '👸🏽' => 'inkosazane: uhlobo-4',
    '👸🏾' => 'inkosazane: uhlobo-5',
    '👸🏿' => 'inkosazane: uhlobo-6',
    '👳🏻' => 'umuntu ogqoke ithalibhani: uhlobo-1-2',
    '👳🏼' => 'umuntu ogqoke ithalibhani: uhlobo-3',
    '👳🏽' => 'umuntu ogqoke ithalibhani: uhlobo-4',
    '👳🏾' => 'umuntu ogqoke ithalibhani: uhlobo-5',
    '👳🏿' => 'umuntu ogqoke ithalibhani: uhlobo-6',
    '👲🏻' => 'indoda efake ikepishi lechinese: uhlobo-1-2',
    '👲🏼' => 'indoda efake ikepishi lechinese: uhlobo-3',
    '👲🏽' => 'indoda efake ikepishi lechinese: uhlobo-4',
    '👲🏾' => 'indoda efake ikepishi lechinese: uhlobo-5',
    '👲🏿' => 'indoda efake ikepishi lechinese: uhlobo-6',
    '🧕🏻' => 'owesifazane oneduku: uhlobo-1-2',
    '🧕🏼' => 'owesifazane oneduku: uhlobo-3',
    '🧕🏽' => 'owesifazane oneduku: uhlobo-4',
    '🧕🏾' => 'owesifazane oneduku: uhlobo-5',
    '🧕🏿' => 'owesifazane oneduku: uhlobo-6',
    '🤵🏻' => 'umuntu kwisudu: uhlobo-1-2',
    '🤵🏼' => 'umuntu kwisudu: uhlobo-3',
    '🤵🏽' => 'umuntu kwisudu: uhlobo-4',
    '🤵🏾' => 'umuntu kwisudu: uhlobo-5',
    '🤵🏿' => 'umuntu kwisudu: uhlobo-6',
    '👰🏻' => 'umuntu ofake iveyili: uhlobo-1-2',
    '👰🏼' => 'umuntu ofake iveyili: uhlobo-3',
    '👰🏽' => 'umuntu ofake iveyili: uhlobo-4',
    '👰🏾' => 'umuntu ofake iveyili: uhlobo-5',
    '👰🏿' => 'umuntu ofake iveyili: uhlobo-6',
    '🤰🏻' => 'okhulelwe: uhlobo-1-2',
    '🤰🏼' => 'okhulelwe: uhlobo-3',
    '🤰🏽' => 'okhulelwe: uhlobo-4',
    '🤰🏾' => 'okhulelwe: uhlobo-5',
    '🤰🏿' => 'okhulelwe: uhlobo-6',
    '🫃🏻' => 'indoda ekhulelwe: uhlobo-1-2',
    '🫃🏼' => 'indoda ekhulelwe: uhlobo-3',
    '🫃🏽' => 'indoda ekhulelwe: uhlobo-4',
    '🫃🏾' => 'indoda ekhulelwe: uhlobo-5',
    '🫃🏿' => 'indoda ekhulelwe: uhlobo-6',
    '🫄🏻' => 'umuntu okhulelwe: uhlobo-1-2',
    '🫄🏼' => 'umuntu okhulelwe: uhlobo-3',
    '🫄🏽' => 'umuntu okhulelwe: uhlobo-4',
    '🫄🏾' => 'umuntu okhulelwe: uhlobo-5',
    '🫄🏿' => 'umuntu okhulelwe: uhlobo-6',
    '🤱🏻' => 'ukuncelisa: uhlobo-1-2',
    '🤱🏼' => 'ukuncelisa: uhlobo-3',
    '🤱🏽' => 'ukuncelisa: uhlobo-4',
    '🤱🏾' => 'ukuncelisa: uhlobo-5',
    '🤱🏿' => 'ukuncelisa: uhlobo-6',
    '👼🏻' => 'ingelosi eyingane: uhlobo-1-2',
    '👼🏼' => 'ingelosi eyingane: uhlobo-3',
    '👼🏽' => 'ingelosi eyingane: uhlobo-4',
    '👼🏾' => 'ingelosi eyingane: uhlobo-5',
    '👼🏿' => 'ingelosi eyingane: uhlobo-6',
    '🎅🏻' => 'ubaba ukhisimusi: uhlobo-1-2',
    '🎅🏼' => 'ubaba ukhisimusi: uhlobo-3',
    '🎅🏽' => 'ubaba ukhisimusi: uhlobo-4',
    '🎅🏾' => 'ubaba ukhisimusi: uhlobo-5',
    '🎅🏿' => 'ubaba ukhisimusi: uhlobo-6',
    '🤶🏻' => 'umama kakhisimusi: uhlobo-1-2',
    '🤶🏼' => 'umama kakhisimusi: uhlobo-3',
    '🤶🏽' => 'umama kakhisimusi: uhlobo-4',
    '🤶🏾' => 'umama kakhisimusi: uhlobo-5',
    '🤶🏿' => 'umama kakhisimusi: uhlobo-6',
    '🦸🏻' => 'iqhawe: uhlobo-1-2',
    '🦸🏼' => 'iqhawe: uhlobo-3',
    '🦸🏽' => 'iqhawe: uhlobo-4',
    '🦸🏾' => 'iqhawe: uhlobo-5',
    '🦸🏿' => 'iqhawe: uhlobo-6',
    '🦹🏻' => 'supervillain: uhlobo-1-2',
    '🦹🏼' => 'supervillain: uhlobo-3',
    '🦹🏽' => 'supervillain: uhlobo-4',
    '🦹🏾' => 'supervillain: uhlobo-5',
    '🦹🏿' => 'supervillain: uhlobo-6',
    '🧙🏻' => 'i-mage: uhlobo-1-2',
    '🧙🏼' => 'i-mage: uhlobo-3',
    '🧙🏽' => 'i-mage: uhlobo-4',
    '🧙🏾' => 'i-mage: uhlobo-5',
    '🧙🏿' => 'i-mage: uhlobo-6',
    '🧚🏻' => 'nganekwane: uhlobo-1-2',
    '🧚🏼' => 'nganekwane: uhlobo-3',
    '🧚🏽' => 'nganekwane: uhlobo-4',
    '🧚🏾' => 'nganekwane: uhlobo-5',
    '🧚🏿' => 'nganekwane: uhlobo-6',
    '🧛🏻' => 'ivemphaya: uhlobo-1-2',
    '🧛🏼' => 'ivemphaya: uhlobo-3',
    '🧛🏽' => 'ivemphaya: uhlobo-4',
    '🧛🏾' => 'ivemphaya: uhlobo-5',
    '🧛🏿' => 'ivemphaya: uhlobo-6',
    '🧜🏻' => 'i-merperson: uhlobo-1-2',
    '🧜🏼' => 'i-merperson: uhlobo-3',
    '🧜🏽' => 'i-merperson: uhlobo-4',
    '🧜🏾' => 'i-merperson: uhlobo-5',
    '🧜🏿' => 'i-merperson: uhlobo-6',
    '🧝🏻' => 'i-elf: uhlobo-1-2',
    '🧝🏼' => 'i-elf: uhlobo-3',
    '🧝🏽' => 'i-elf: uhlobo-4',
    '🧝🏾' => 'i-elf: uhlobo-5',
    '🧝🏿' => 'i-elf: uhlobo-6',
    '💆🏻' => 'umuntu othola imasaji: uhlobo-1-2',
    '💆🏼' => 'umuntu othola imasaji: uhlobo-3',
    '💆🏽' => 'umuntu othola imasaji: uhlobo-4',
    '💆🏾' => 'umuntu othola imasaji: uhlobo-5',
    '💆🏿' => 'umuntu othola imasaji: uhlobo-6',
    '💇🏻' => 'umuntu ogundayo: uhlobo-1-2',
    '💇🏼' => 'umuntu ogundayo: uhlobo-3',
    '💇🏽' => 'umuntu ogundayo: uhlobo-4',
    '💇🏾' => 'umuntu ogundayo: uhlobo-5',
    '💇🏿' => 'umuntu ogundayo: uhlobo-6',
    '🚶🏻' => 'umuntu ohambayo: uhlobo-1-2',
    '🚶🏼' => 'umuntu ohambayo: uhlobo-3',
    '🚶🏽' => 'umuntu ohambayo: uhlobo-4',
    '🚶🏾' => 'umuntu ohambayo: uhlobo-5',
    '🚶🏿' => 'umuntu ohambayo: uhlobo-6',
    '🧍🏻' => 'umuntu omile: uhlobo-1-2',
    '🧍🏼' => 'umuntu omile: uhlobo-3',
    '🧍🏽' => 'umuntu omile: uhlobo-4',
    '🧍🏾' => 'umuntu omile: uhlobo-5',
    '🧍🏿' => 'umuntu omile: uhlobo-6',
    '🧎🏻' => 'umuntu oguqile: uhlobo-1-2',
    '🧎🏼' => 'umuntu oguqile: uhlobo-3',
    '🧎🏽' => 'umuntu oguqile: uhlobo-4',
    '🧎🏾' => 'umuntu oguqile: uhlobo-5',
    '🧎🏿' => 'umuntu oguqile: uhlobo-6',
    '🏃🏻' => 'umunto ogijimayo: uhlobo-1-2',
    '🏃🏼' => 'umunto ogijimayo: uhlobo-3',
    '🏃🏽' => 'umunto ogijimayo: uhlobo-4',
    '🏃🏾' => 'umunto ogijimayo: uhlobo-5',
    '🏃🏿' => 'umunto ogijimayo: uhlobo-6',
    '💃🏻' => 'owesimame odansayo: uhlobo-1-2',
    '💃🏼' => 'owesimame odansayo: uhlobo-3',
    '💃🏽' => 'owesimame odansayo: uhlobo-4',
    '💃🏾' => 'owesimame odansayo: uhlobo-5',
    '💃🏿' => 'owesimame odansayo: uhlobo-6',
    '🕺🏻' => 'ukudansa: uhlobo-1-2',
    '🕺🏼' => 'ukudansa: uhlobo-3',
    '🕺🏽' => 'ukudansa: uhlobo-4',
    '🕺🏾' => 'ukudansa: uhlobo-5',
    '🕺🏿' => 'ukudansa: uhlobo-6',
    '🕴🏻' => 'indoda egqoke isudu: uhlobo-1-2',
    '🕴🏼' => 'indoda egqoke isudu: uhlobo-3',
    '🕴🏽' => 'indoda egqoke isudu: uhlobo-4',
    '🕴🏾' => 'indoda egqoke isudu: uhlobo-5',
    '🕴🏿' => 'indoda egqoke isudu: uhlobo-6',
    '👯🏻' => 'abantu abasemcimbini: uhlobo-1-2',
    '👯🏼' => 'abantu abasemcimbini: uhlobo-3',
    '👯🏽' => 'abantu abasemcimbini: uhlobo-4',
    '👯🏾' => 'abantu abasemcimbini: uhlobo-5',
    '👯🏿' => 'abantu abasemcimbini: uhlobo-6',
    '🧖🏻' => 'umuntu egumbini elinestimu: uhlobo-1-2',
    '🧖🏼' => 'umuntu egumbini elinestimu: uhlobo-3',
    '🧖🏽' => 'umuntu egumbini elinestimu: uhlobo-4',
    '🧖🏾' => 'umuntu egumbini elinestimu: uhlobo-5',
    '🧖🏿' => 'umuntu egumbini elinestimu: uhlobo-6',
    '🧗🏻' => 'umuntu ogibelayo: uhlobo-1-2',
    '🧗🏼' => 'umuntu ogibelayo: uhlobo-3',
    '🧗🏽' => 'umuntu ogibelayo: uhlobo-4',
    '🧗🏾' => 'umuntu ogibelayo: uhlobo-5',
    '🧗🏿' => 'umuntu ogibelayo: uhlobo-6',
    '🏇🏻' => 'umjaho wamahhashi: uhlobo-1-2',
    '🏇🏼' => 'umjaho wamahhashi: uhlobo-3',
    '🏇🏽' => 'umjaho wamahhashi: uhlobo-4',
    '🏇🏾' => 'umjaho wamahhashi: uhlobo-5',
    '🏇🏿' => 'umjaho wamahhashi: uhlobo-6',
    '🏂🏻' => 'umgibeli webhodi lesithwathwa: uhlobo-1-2',
    '🏂🏼' => 'umgibeli webhodi lesithwathwa: uhlobo-3',
    '🏂🏽' => 'umgibeli webhodi lesithwathwa: uhlobo-4',
    '🏂🏾' => 'umgibeli webhodi lesithwathwa: uhlobo-5',
    '🏂🏿' => 'umgibeli webhodi lesithwathwa: uhlobo-6',
    '🏌🏻' => 'umuntu odlala igalofu: uhlobo-1-2',
    '🏌🏼' => 'umuntu odlala igalofu: uhlobo-3',
    '🏌🏽' => 'umuntu odlala igalofu: uhlobo-4',
    '🏌🏾' => 'umuntu odlala igalofu: uhlobo-5',
    '🏌🏿' => 'umuntu odlala igalofu: uhlobo-6',
    '🏄🏻' => 'umuntu ogibele isurf board: uhlobo-1-2',
    '🏄🏼' => 'umuntu ogibele isurf board: uhlobo-3',
    '🏄🏽' => 'umuntu ogibele isurf board: uhlobo-4',
    '🏄🏾' => 'umuntu ogibele isurf board: uhlobo-5',
    '🏄🏿' => 'umuntu ogibele isurf board: uhlobo-6',
    '🚣🏻' => 'umuntu ogwedla isikebhe: uhlobo-1-2',
    '🚣🏼' => 'umuntu ogwedla isikebhe: uhlobo-3',
    '🚣🏽' => 'umuntu ogwedla isikebhe: uhlobo-4',
    '🚣🏾' => 'umuntu ogwedla isikebhe: uhlobo-5',
    '🚣🏿' => 'umuntu ogwedla isikebhe: uhlobo-6',
    '🏊🏻' => 'umuntu obhukudayo: uhlobo-1-2',
    '🏊🏼' => 'umuntu obhukudayo: uhlobo-3',
    '🏊🏽' => 'umuntu obhukudayo: uhlobo-4',
    '🏊🏾' => 'umuntu obhukudayo: uhlobo-5',
    '🏊🏿' => 'umuntu obhukudayo: uhlobo-6',
    '⛹🏻' => 'umuntu onebhola: uhlobo-1-2',
    '⛹🏼' => 'umuntu onebhola: uhlobo-3',
    '⛹🏽' => 'umuntu onebhola: uhlobo-4',
    '⛹🏾' => 'umuntu onebhola: uhlobo-5',
    '⛹🏿' => 'umuntu onebhola: uhlobo-6',
    '🏋🏻' => 'umuntu ophakamisa izinsimbi: uhlobo-1-2',
    '🏋🏼' => 'umuntu ophakamisa izinsimbi: uhlobo-3',
    '🏋🏽' => 'umuntu ophakamisa izinsimbi: uhlobo-4',
    '🏋🏾' => 'umuntu ophakamisa izinsimbi: uhlobo-5',
    '🏋🏿' => 'umuntu ophakamisa izinsimbi: uhlobo-6',
    '🚴🏻' => 'umuntu ogibele ibhayisikili: uhlobo-1-2',
    '🚴🏼' => 'umuntu ogibele ibhayisikili: uhlobo-3',
    '🚴🏽' => 'umuntu ogibele ibhayisikili: uhlobo-4',
    '🚴🏾' => 'umuntu ogibele ibhayisikili: uhlobo-5',
    '🚴🏿' => 'umuntu ogibele ibhayisikili: uhlobo-6',
    '🚵🏻' => 'umuntu ogibele ibhayisikili lezintaba: uhlobo-1-2',
    '🚵🏼' => 'umuntu ogibele ibhayisikili lezintaba: uhlobo-3',
    '🚵🏽' => 'umuntu ogibele ibhayisikili lezintaba: uhlobo-4',
    '🚵🏾' => 'umuntu ogibele ibhayisikili lezintaba: uhlobo-5',
    '🚵🏿' => 'umuntu ogibele ibhayisikili lezintaba: uhlobo-6',
    '🤸🏻' => 'isondo lekalishi: uhlobo-1-2',
    '🤸🏼' => 'isondo lekalishi: uhlobo-3',
    '🤸🏽' => 'isondo lekalishi: uhlobo-4',
    '🤸🏾' => 'isondo lekalishi: uhlobo-5',
    '🤸🏿' => 'isondo lekalishi: uhlobo-6',
    '🤼🏻' => 'abashayi-sibhakela: uhlobo-1-2',
    '🤼🏼' => 'abashayi-sibhakela: uhlobo-3',
    '🤼🏽' => 'abashayi-sibhakela: uhlobo-4',
    '🤼🏾' => 'abashayi-sibhakela: uhlobo-5',
    '🤼🏿' => 'abashayi-sibhakela: uhlobo-6',
    '🤽🏻' => 'ukubhukuda: uhlobo-1-2',
    '🤽🏼' => 'ukubhukuda: uhlobo-3',
    '🤽🏽' => 'ukubhukuda: uhlobo-4',
    '🤽🏾' => 'ukubhukuda: uhlobo-5',
    '🤽🏿' => 'ukubhukuda: uhlobo-6',
    '🤾🏻' => 'ibhola lesandla: uhlobo-1-2',
    '🤾🏼' => 'ibhola lesandla: uhlobo-3',
    '🤾🏽' => 'ibhola lesandla: uhlobo-4',
    '🤾🏾' => 'ibhola lesandla: uhlobo-5',
    '🤾🏿' => 'ibhola lesandla: uhlobo-6',
    '🤹🏻' => 'ukudlala: uhlobo-1-2',
    '🤹🏼' => 'ukudlala: uhlobo-3',
    '🤹🏽' => 'ukudlala: uhlobo-4',
    '🤹🏾' => 'ukudlala: uhlobo-5',
    '🤹🏿' => 'ukudlala: uhlobo-6',
    '🧘🏻' => 'umuntu esikhundleni se-lotus: uhlobo-1-2',
    '🧘🏼' => 'umuntu esikhundleni se-lotus: uhlobo-3',
    '🧘🏽' => 'umuntu esikhundleni se-lotus: uhlobo-4',
    '🧘🏾' => 'umuntu esikhundleni se-lotus: uhlobo-5',
    '🧘🏿' => 'umuntu esikhundleni se-lotus: uhlobo-6',
    '🛀🏻' => 'umuntu ogezayo: uhlobo-1-2',
    '🛀🏼' => 'umuntu ogezayo: uhlobo-3',
    '🛀🏽' => 'umuntu ogezayo: uhlobo-4',
    '🛀🏾' => 'umuntu ogezayo: uhlobo-5',
    '🛀🏿' => 'umuntu ogezayo: uhlobo-6',
    '🛌🏻' => 'umuntu olele: uhlobo-1-2',
    '🛌🏼' => 'umuntu olele: uhlobo-3',
    '🛌🏽' => 'umuntu olele: uhlobo-4',
    '🛌🏾' => 'umuntu olele: uhlobo-5',
    '🛌🏿' => 'umuntu olele: uhlobo-6',
    '👭🏻' => 'abasimame ababambene ngesandla: uhlobo-1-2',
    '👭🏼' => 'abasimame ababambene ngesandla: uhlobo-3',
    '👭🏽' => 'abasimame ababambene ngesandla: uhlobo-4',
    '👭🏾' => 'abasimame ababambene ngesandla: uhlobo-5',
    '👭🏿' => 'abasimame ababambene ngesandla: uhlobo-6',
    '👫🏻' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-1-2',
    '👫🏼' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-3',
    '👫🏽' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-4',
    '👫🏾' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-5',
    '👫🏿' => 'owesilisa nowesifazane bebembene ngezandla: uhlobo-6',
    '👬🏻' => 'amadoda amabili abambene ngesandla: uhlobo-1-2',
    '👬🏼' => 'amadoda amabili abambene ngesandla: uhlobo-3',
    '👬🏽' => 'amadoda amabili abambene ngesandla: uhlobo-4',
    '👬🏾' => 'amadoda amabili abambene ngesandla: uhlobo-5',
    '👬🏿' => 'amadoda amabili abambene ngesandla: uhlobo-6',
    '💏🏻' => 'ukuqabula: uhlobo-1-2',
    '💏🏼' => 'ukuqabula: uhlobo-3',
    '💏🏽' => 'ukuqabula: uhlobo-4',
    '💏🏾' => 'ukuqabula: uhlobo-5',
    '💏🏿' => 'ukuqabula: uhlobo-6',
    '💑🏻' => 'izithandani ezinenhliziyo: uhlobo-1-2',
    '💑🏼' => 'izithandani ezinenhliziyo: uhlobo-3',
    '💑🏽' => 'izithandani ezinenhliziyo: uhlobo-4',
    '💑🏾' => 'izithandani ezinenhliziyo: uhlobo-5',
    '💑🏿' => 'izithandani ezinenhliziyo: uhlobo-6',
    '🇦🇨' => 'ifulegi: i-Ascension Island',
    '🇦🇩' => 'ifulegi: i-Andorra',
    '🇦🇪' => 'ifulegi: i-United Arab Emirates',
    '🇦🇫' => 'ifulegi: i-Afghanistan',
    '🇦🇬' => 'ifulegi: i-Antigua ne-Barbuda',
    '🇦🇮' => 'ifulegi: i-Anguilla',
    '🇦🇱' => 'ifulegi: i-Albania',
    '🇦🇲' => 'ifulegi: i-Armenia',
    '🇦🇴' => 'ifulegi: i-Angola',
    '🇦🇶' => 'ifulegi: i-Antarctica',
    '🇦🇷' => 'ifulegi: i-Argentina',
    '🇦🇸' => 'ifulegi: i-American Samoa',
    '🇦🇹' => 'ifulegi: i-Austria',
    '🇦🇺' => 'ifulegi: i-Australia',
    '🇦🇼' => 'ifulegi: i-Aruba',
    '🇦🇽' => 'ifulegi: i-Åland Islands',
    '🇦🇿' => 'ifulegi: i-Azerbaijan',
    '🇧🇦' => 'ifulegi: i-Bosnia ne-Herzegovina',
    '🇧🇧' => 'ifulegi: i-Barbados',
    '🇧🇩' => 'ifulegi: i-Bangladesh',
    '🇧🇪' => 'ifulegi: i-Belgium',
    '🇧🇫' => 'ifulegi: i-Burkina Faso',
    '🇧🇬' => 'ifulegi: i-Bulgaria',
    '🇧🇭' => 'ifulegi: i-Bahrain',
    '🇧🇮' => 'ifulegi: i-Burundi',
    '🇧🇯' => 'ifulegi: i-Benin',
    '🇧🇱' => 'ifulegi: i-Saint Barthélemy',
    '🇧🇲' => 'ifulegi: i-Bermuda',
    '🇧🇳' => 'ifulegi: i-Brunei',
    '🇧🇴' => 'ifulegi: i-Bolivia',
    '🇧🇶' => 'ifulegi: i-Caribbean Netherlands',
    '🇧🇷' => 'ifulegi: i-Brazil',
    '🇧🇸' => 'ifulegi: i-Bahamas',
    '🇧🇹' => 'ifulegi: i-Bhutan',
    '🇧🇻' => 'ifulegi: i-Bouvet Island',
    '🇧🇼' => 'ifulegi: iBotswana',
    '🇧🇾' => 'ifulegi: i-Belarus',
    '🇧🇿' => 'ifulegi: i-Belize',
    '🇨🇦' => 'ifulegi: i-Canada',
    '🇨🇨' => 'ifulegi: i-Cocos (Keeling) Islands',
    '🇨🇩' => 'ifulegi: i-Congo - Kinshasa',
    '🇨🇫' => 'ifulegi: i-Central African Republic',
    '🇨🇬' => 'ifulegi: i-Congo - Brazzaville',
    '🇨🇭' => 'ifulegi: i-Switzerland',
    '🇨🇮' => 'ifulegi: i-Côte d’Ivoire',
    '🇨🇰' => 'ifulegi: i-Cook Islands',
    '🇨🇱' => 'ifulegi: i-Chile',
    '🇨🇲' => 'ifulegi: i-Cameroon',
    '🇨🇳' => 'ifulegi: i-China',
    '🇨🇴' => 'ifulegi: i-Colombia',
    '🇨🇵' => 'ifulegi: i-Clipperton Island',
    '🇨🇶' => 'ifulegi: i-Sark',
    '🇨🇷' => 'ifulegi: i-Costa Rica',
    '🇨🇺' => 'ifulegi: i-Cuba',
    '🇨🇻' => 'ifulegi: i-Cape Verde',
    '🇨🇼' => 'ifulegi: i-Curaçao',
    '🇨🇽' => 'ifulegi: i-Christmas Island',
    '🇨🇾' => 'ifulegi: i-Cyprus',
    '🇨🇿' => 'ifulegi: i-Czechia',
    '🇩🇪' => 'ifulegi: i-Germany',
    '🇩🇬' => 'ifulegi: i-Diego Garcia',
    '🇩🇯' => 'ifulegi: i-Djibouti',
    '🇩🇰' => 'ifulegi: i-Denmark',
    '🇩🇲' => 'ifulegi: i-Dominica',
    '🇩🇴' => 'ifulegi: i-Dominican Republic',
    '🇩🇿' => 'ifulegi: i-Algeria',
    '🇪🇦' => 'ifulegi: i-Cueta ne-Melilla',
    '🇪🇨' => 'ifulegi: i-Ecuador',
    '🇪🇪' => 'ifulegi: i-Estonia',
    '🇪🇬' => 'ifulegi: i-Egypt',
    '🇪🇭' => 'ifulegi: i-Western Sahara',
    '🇪🇷' => 'ifulegi: i-Eritrea',
    '🇪🇸' => 'ifulegi: i-Spain',
    '🇪🇹' => 'ifulegi: i-Ethiopia',
    '🇪🇺' => 'ifulegi: i-European Union',
    '🇫🇮' => 'ifulegi: i-Finland',
    '🇫🇯' => 'ifulegi: i-Fiji',
    '🇫🇰' => 'ifulegi: i-Falkland Islands',
    '🇫🇲' => 'ifulegi: i-Micronesia',
    '🇫🇴' => 'ifulegi: i-Faroe Islands',
    '🇫🇷' => 'ifulegi: i-France',
    '🇬🇦' => 'ifulegi: i-Gabon',
    '🇬🇧' => 'ifulegi: i-United Kingdom',
    '🇬🇩' => 'ifulegi: i-Grenada',
    '🇬🇪' => 'ifulegi: i-Georgia',
    '🇬🇫' => 'ifulegi: i-French Guiana',
    '🇬🇬' => 'ifulegi: i-Guernsey',
    '🇬🇭' => 'ifulegi: i-Ghana',
    '🇬🇮' => 'ifulegi: i-Gibraltar',
    '🇬🇱' => 'ifulegi: i-Greenland',
    '🇬🇲' => 'ifulegi: i-Gambia',
    '🇬🇳' => 'ifulegi: i-Guinea',
    '🇬🇵' => 'ifulegi: i-Guadeloupe',
    '🇬🇶' => 'ifulegi: i-Equatorial Guinea',
    '🇬🇷' => 'ifulegi: i-Greece',
    '🇬🇸' => 'ifulegi: i-South Georgia ne-South Sandwich Islands',
    '🇬🇹' => 'ifulegi: i-Guatemala',
    '🇬🇺' => 'ifulegi: i-Guam',
    '🇬🇼' => 'ifulegi: i-Guinea-Bissau',
    '🇬🇾' => 'ifulegi: i-Guyana',
    '🇭🇰' => 'ifulegi: i-Hong Kong SAR China',
    '🇭🇲' => 'ifulegi: I-Heard & McDonald Island',
    '🇭🇳' => 'ifulegi: i-Honduras',
    '🇭🇷' => 'ifulegi: i-Croatia',
    '🇭🇹' => 'ifulegi: i-Haiti',
    '🇭🇺' => 'ifulegi: i-Hungary',
    '🇮🇨' => 'ifulegi: i-Canary Islands',
    '🇮🇩' => 'ifulegi: i-Indonesia',
    '🇮🇪' => 'ifulegi: i-Ireland',
    '🇮🇱' => 'ifulegi: kwa-Israel',
    '🇮🇲' => 'ifulegi: i-Isle of Man',
    '🇮🇳' => 'ifulegi: i-India',
    '🇮🇴' => 'ifulegi: i-British Indian Ocean Territory',
    '🇮🇶' => 'ifulegi: i-Iraq',
    '🇮🇷' => 'ifulegi: i-Iran',
    '🇮🇸' => 'ifulegi: i-Iceland',
    '🇮🇹' => 'ifulegi: i-Italy',
    '🇯🇪' => 'ifulegi: i-Jersey',
    '🇯🇲' => 'ifulegi: i-Jamaica',
    '🇯🇴' => 'ifulegi: i-Jordan',
    '🇯🇵' => 'ifulegi: i-Japan',
    '🇰🇪' => 'ifulegi: i-Kenya',
    '🇰🇬' => 'ifulegi: i-Kyrgyzstan',
    '🇰🇭' => 'ifulegi: i-Cambodia',
    '🇰🇮' => 'ifulegi: i-Kiribati',
    '🇰🇲' => 'ifulegi: i-Comoros',
    '🇰🇳' => 'ifulegi: i-Saint Kitts ne-Nevis',
    '🇰🇵' => 'ifulegi: i-North Korea',
    '🇰🇷' => 'ifulegi: i-South Korea',
    '🇰🇼' => 'ifulegi: i-Kuwait',
    '🇰🇾' => 'ifulegi: i-Cayman Islands',
    '🇰🇿' => 'ifulegi: i-Kazakhstan',
    '🇱🇦' => 'ifulegi: i-Laos',
    '🇱🇧' => 'ifulegi: i-Lebanon',
    '🇱🇨' => 'ifulegi: i-Saint Lucia',
    '🇱🇮' => 'ifulegi: i-Liechtenstein',
    '🇱🇰' => 'ifulegi: i-Sri Lanka',
    '🇱🇷' => 'ifulegi: i-Liberia',
    '🇱🇸' => 'ifulegi: iLesotho',
    '🇱🇹' => 'ifulegi: i-Lithuania',
    '🇱🇺' => 'ifulegi: i-Luxembourg',
    '🇱🇻' => 'ifulegi: i-Latvia',
    '🇱🇾' => 'ifulegi: i-Libya',
    '🇲🇦' => 'ifulegi: i-Morocco',
    '🇲🇨' => 'ifulegi: i-Monaco',
    '🇲🇩' => 'ifulegi: i-Moldova',
    '🇲🇪' => 'ifulegi: i-Montenegro',
    '🇲🇫' => 'ifulegi: i-Saint Martin',
    '🇲🇬' => 'ifulegi: i-Madagascar',
    '🇲🇭' => 'ifulegi: i-Marshall Islands',
    '🇲🇰' => 'ifulegi: i-North Macedonia',
    '🇲🇱' => 'ifulegi: iMali',
    '🇲🇲' => 'ifulegi: i-Myanmar (Burma)',
    '🇲🇳' => 'ifulegi: i-Mongolia',
    '🇲🇴' => 'ifulegi: i-Macau SAR China',
    '🇲🇵' => 'ifulegi: i-Northern Mariana Islands',
    '🇲🇶' => 'ifulegi: i-Martinique',
    '🇲🇷' => 'ifulegi: i-Mauritania',
    '🇲🇸' => 'ifulegi: i-Montserrat',
    '🇲🇹' => 'ifulegi: i-Malta',
    '🇲🇺' => 'ifulegi: i-Mauritius',
    '🇲🇻' => 'ifulegi: i-Maldives',
    '🇲🇼' => 'ifulegi: iMalawi',
    '🇲🇽' => 'ifulegi: i-Mexico',
    '🇲🇾' => 'ifulegi: i-Malaysia',
    '🇲🇿' => 'ifulegi: i-Mozambique',
    '🇳🇦' => 'ifulegi: i-Namibia',
    '🇳🇨' => 'ifulegi: i-New Caledonia',
    '🇳🇪' => 'ifulegi: i-Niger',
    '🇳🇫' => 'ifulegi: i-Norfolk Island',
    '🇳🇬' => 'ifulegi: i-Nigeria',
    '🇳🇮' => 'ifulegi: i-Nicaragua',
    '🇳🇱' => 'ifulegi: i-Netherlands',
    '🇳🇴' => 'ifulegi: i-Norway',
    '🇳🇵' => 'ifulegi: i-Nepal',
    '🇳🇷' => 'ifulegi: i-Nauru',
    '🇳🇺' => 'ifulegi: i-Niue',
    '🇳🇿' => 'ifulegi: i-New Zealand',
    '🇴🇲' => 'ifulegi: i-Oman',
    '🇵🇦' => 'ifulegi: i-Panama',
    '🇵🇪' => 'ifulegi: i-Peru',
    '🇵🇫' => 'ifulegi: i-French Polynesia',
    '🇵🇬' => 'ifulegi: i-Papua New Guinea',
    '🇵🇭' => 'ifulegi: i-Philippines',
    '🇵🇰' => 'ifulegi: i-Pakistan',
    '🇵🇱' => 'ifulegi: i-Poland',
    '🇵🇲' => 'ifulegi: i-Saint Pierre kanye ne-Miquelon',
    '🇵🇳' => 'ifulegi: i-Pitcairn Islands',
    '🇵🇷' => 'ifulegi: i-Puerto Rico',
    '🇵🇸' => 'ifulegi: i-Palestinian Territories',
    '🇵🇹' => 'ifulegi: i-Portugal',
    '🇵🇼' => 'ifulegi: i-Palau',
    '🇵🇾' => 'ifulegi: i-Paraguay',
    '🇶🇦' => 'ifulegi: i-Qatar',
    '🇷🇪' => 'ifulegi: i-Réunion',
    '🇷🇴' => 'ifulegi: i-Romania',
    '🇷🇸' => 'ifulegi: i-Serbia',
    '🇷🇺' => 'ifulegi: i-Russia',
    '🇷🇼' => 'ifulegi: i-Rwanda',
    '🇸🇦' => 'ifulegi: i-Saudi Arabia',
    '🇸🇧' => 'ifulegi: i-Solomon Islands',
    '🇸🇨' => 'ifulegi: i-Seychelles',
    '🇸🇩' => 'ifulegi: i-Sudan',
    '🇸🇪' => 'ifulegi: i-Sweden',
    '🇸🇬' => 'ifulegi: i-Singapore',
    '🇸🇭' => 'ifulegi: i-St. Helena',
    '🇸🇮' => 'ifulegi: i-Slovenia',
    '🇸🇯' => 'ifulegi: i-Svalbard ne-Jan Mayen',
    '🇸🇰' => 'ifulegi: i-Slovakia',
    '🇸🇱' => 'ifulegi: i-Sierra Leone',
    '🇸🇲' => 'ifulegi: i-San Marino',
    '🇸🇳' => 'ifulegi: i-Senegal',
    '🇸🇴' => 'ifulegi: i-Somalia',
    '🇸🇷' => 'ifulegi: i-Suriname',
    '🇸🇸' => 'ifulegi: i-South Sudan',
    '🇸🇹' => 'ifulegi: i-São Tomé kanye ne-Príncipe',
    '🇸🇻' => 'ifulegi: i-El Salvador',
    '🇸🇽' => 'ifulegi: i-Sint Maarten',
    '🇸🇾' => 'ifulegi: i-Syria',
    '🇸🇿' => 'ifulegi: i-Swaziland',
    '🇹🇦' => 'ifulegi: i-Tristan da Cunha',
    '🇹🇨' => 'ifulegi: i-Turks ne-Caicos Islands',
    '🇹🇩' => 'ifulegi: i-Chad',
    '🇹🇫' => 'ifulegi: i-French Southern Territories',
    '🇹🇬' => 'ifulegi: i-Togo',
    '🇹🇭' => 'ifulegi: i-Thailand',
    '🇹🇯' => 'ifulegi: i-Tajikistan',
    '🇹🇰' => 'ifulegi: i-Tokelau',
    '🇹🇱' => 'ifulegi: i-Timor-Leste',
    '🇹🇲' => 'ifulegi: i-Turkmenistan',
    '🇹🇳' => 'ifulegi: i-Tunisia',
    '🇹🇴' => 'ifulegi: i-Tonga',
    '🇹🇷' => 'ifulegi: i-Turkey',
    '🇹🇹' => 'ifulegi: i-Trinidad ne-Tobago',
    '🇹🇻' => 'ifulegi: i-Tuvalu',
    '🇹🇼' => 'ifulegi: i-Taiwan',
    '🇹🇿' => 'ifulegi: i-Tanzania',
    '🇺🇦' => 'ifulegi: i-Ukraine',
    '🇺🇬' => 'ifulegi: i-Uganda',
    '🇺🇲' => 'ifulegi: I-U.S. Outlying Islands',
    '🇺🇳' => 'ifulegi: I-United Nations',
    '🇺🇸' => 'ifulegi: i-United States',
    '🇺🇾' => 'ifulegi: i-Uruguay',
    '🇺🇿' => 'ifulegi: i-Uzbekistan',
    '🇻🇦' => 'ifulegi: i-Vatican City',
    '🇻🇨' => 'ifulegi: i-Saint Vincent ne-Grenadines',
    '🇻🇪' => 'ifulegi: i-Venezuela',
    '🇻🇬' => 'ifulegi: i-British Virgin Islands',
    '🇻🇮' => 'ifulegi: i-U.S. Virgin Islands',
    '🇻🇳' => 'ifulegi: i-Vietnam',
    '🇻🇺' => 'ifulegi: i-Vanuatu',
    '🇼🇫' => 'ifulegi: i-Wallis ne-Futuna',
    '🇼🇸' => 'ifulegi: i-Samoa',
    '🇽🇰' => 'ifulegi: i-Kosovo',
    '🇾🇪' => 'ifulegi: i-Yemen',
    '🇾🇹' => 'ifulegi: i-Mayotte',
    '🇿🇦' => 'ifulegi: iNingizimu Afrika',
    '🇿🇲' => 'ifulegi: i-Zambia',
    '🇿🇼' => 'ifulegi: iZimbabwe',
    '🔟' => 'i-keycap: 10',
    '🏻' => 'uhlobo-1-2',
    '🏼' => 'uhlobo-3',
    '🏽' => 'uhlobo-4',
    '🏾' => 'uhlobo-5',
    '🏿' => 'uhlobo-6',
    '😀' => 'ubuso obusinekile',
    '😃' => 'ubuso obumoyizelayo obuvule umlomo',
    '😄' => 'ubuso obumoyizelayo obuvule umlomo bunamehlo ajabule',
    '😁' => 'ubuso obusinekile obunamehlo amoyizelayo',
    '😆' => 'ubuso obumoyizelayo buvule umlomo buvale amehlo',
    '😅' => 'ubuso obumoyizelayo obuvule umlomo nomjuluko obandayo',
    '🤣' => 'ngihleka ngiyabhuquza',
    '😂' => 'ubuso obunezinyembezi zentokozo',
    '🙂' => 'ubuso obumoyizela kancane',
    '🙃' => 'ubuso obupheke phansi',
    '🫠' => 'ubuso obuncibilikayo',
    '😉' => 'ubuso obucishe ihlo',
    '😊' => 'ubuso obumoyizelayo namehlo ajabule',
    '😇' => 'ubuso obumoyizela nosawubona',
    '🥰' => 'Ubuso obumamathekayo obunezinhliziyo ezintathu',
    '😍' => 'ubuso obumoyizelayo obunamehlo anezinhliziyo',
    '🤩' => 'i-star-struck',
    '😘' => 'ubuso ophephetha ukuqabula',
    '😗' => 'ubuso obuqabulayo',
    '☺' => 'ubuso obumoyizelayo',
    '😚' => 'ubuso obuqabulayo obunamehlo avaliwe',
    '😙' => 'ubuso obuqabulayo obunamehlo amoyizelayo',
    '🥲' => 'ubuso obumamathekayo obunonyembezi',
    '😋' => 'ubuso obujabulela ukudla okumnandi',
    '😛' => 'ubuso obukhiphele phandle ulimi',
    '😜' => 'ubuso obukhiphele phandle ulimi obucishe ihlo',
    '🤪' => 'ubuso obuhlanyayo',
    '😝' => 'ubuso obukhiphele phandle ulimi evale amehlo',
    '🤑' => 'ubuso obunomlomo wemali',
    '🤗' => 'ubuso obangayo',
    '🤭' => 'ubuso obubekwe isandla emlonyeni',
    '🫢' => 'face with open eyes and hand over mouth',
    '🫣' => 'face with peeking eye',
    '🤫' => 'ubuso obuthule',
    '🤔' => 'ubuso obucabangayo',
    '🫡' => 'saluting face',
    '🤐' => 'ubuso obunoziphu',
    '🤨' => 'ubuso obunamashiya aphakanyisiwe',
    '😐' => 'ubuso obukahle',
    '😑' => 'ubuso obungavezi lutho',
    '😶' => 'ubuso obungenamlomo',
    '🫥' => 'ubuso bomugqa onamachashazi',
    '😏' => 'ubuso ubunyiphile',
    '😒' => 'ubuso obungachazekile',
    '🙄' => 'ubuso obupheqa amehlo',
    '😬' => 'ubuso obuhlinile',
    '🤥' => 'amanga',
    '🫨' => 'ubuso obunyakazayo',
    '😌' => 'ubuso obukhululekile',
    '😔' => 'ubuso obuphoxiwe',
    '😪' => 'ubuso obuzelayo',
    '🤤' => 'ukuhala',
    '😴' => 'ubuso obulalayo',
    '🫩' => 'Ubuso obunezigobhe',
    '😷' => 'ubso obufake imaski yobuso kadokotela',
    '🤒' => 'ubuso obunesihlolakushisa',
    '🤕' => 'ubuso obufake ibhandishi',
    '🤢' => 'isicanucanu',
    '🤮' => 'ubuso obuphalazayo',
    '🤧' => 'ukuthimula',
    '🥵' => 'ubuso obushiselwayo',
    '🥶' => 'ubuso obugodolayo',
    '🥴' => 'woozy face',
    '😵' => 'ubuso obunenzululwane',
    '🤯' => 'ikhanda eliqhumayo',
    '🤠' => 'umfana wezinkomo',
    '🥳' => 'ubuso bobumnandi',
    '🥸' => 'ubuso obuzifihlile',
    '😎' => 'ubuso obumoyizelayo obugqoke izibuko zelanga',
    '🤓' => 'ubuso besihlakaniphi',
    '🧐' => 'ubuso obunelensi eyodwa',
    '😕' => 'ubuso obudidekile',
    '🫤' => 'face with diagonal mouth',
    '😟' => 'ubuso obukhathazekile',
    '🙁' => 'ubuso obubipha kancane',
    '☹' => 'ubuso obubiphile',
    '😮' => 'ubuso obuvule umlomo',
    '😯' => 'ubuso obuthulisiwe',
    '😲' => 'ubuso obuthukile',
    '😳' => 'ubuso obumuncu',
    '🫪' => 'ubuso obuhlanekezelwe',
    '🥺' => 'pleading face',
    '🥹' => 'face holding back tears',
    '😦' => 'ubuso obubiphile obuvule umlomo',
    '😧' => 'ubuso obuxakekile',
    '😨' => 'ubuso obesabayo',
    '😰' => 'ubuso obuvule umlomo nomjuluko obandayo',
    '😥' => 'ubuso obudumele kodwa obukhululekile',
    '😢' => 'ubuso obukhalayo',
    '😭' => 'khala kakhulu',
    '😱' => 'ubuso obumemeza ngokwesaba',
    '😖' => 'ubuso obunokudideka',
    '😣' => 'ubuso obubi',
    '😞' => 'ubuso obuphosekile',
    '😓' => 'ubuso obunomjuluko obandayo',
    '😩' => 'ubuso obuyethile',
    '😫' => 'ubuso obukhathele',
    '🥱' => 'ubuso obuzamulayo',
    '😤' => 'ubuso obuphuma intuthu ekhaleni',
    '😡' => 'ubuso obunyiphayo',
    '😠' => 'ubuso obudiniwe',
    '🤬' => 'ubuso obunamasimbuli emlonyeni',
    '😈' => 'ubuso obumoyizelayo obunezimpondo',
    '👿' => 'imp',
    '💀' => 'ugebhezi',
    '☠' => 'ugebhezi namathambo',
    '💩' => 'idende',
    '🤡' => 'umhlekisi',
    '👹' => 'ogre',
    '👺' => 'goblin',
    '👻' => 'isipoki',
    '👽' => 'alien',
    '👾' => 'isilwane esingaziwa',
    '🤖' => 'ubuso berobhothi',
    '😺' => 'ikati elimoyizela sakuhlina',
    '😸' => 'ubuso bekati obusinekile namehlo ajabulile',
    '😹' => 'ubuso bekati obunezinyembezi zenjabulo',
    '😻' => 'ubuso bekati obumoyizelayo obunamehlo enhliziyo',
    '😼' => 'ubuso bekati obumoyizela ngokungagcwele',
    '😽' => 'ubuso bekati obuqabulayo obuvale amehlo',
    '🙀' => 'ubuso bekati obumangele',
    '😿' => 'ubuso bekati elikhalayo',
    '😾' => 'ubuso bekati obudangele',
    '🙈' => 'ungakuboni okubi',
    '🙉' => 'ukungezwa okubi',
    '🙊' => 'ukungakhulumi okubi',
    '💌' => 'incwadi yothando',
    '💘' => 'inhliziyo enomcibisholo',
    '💝' => 'inhliziyo eneribhini',
    '💖' => 'inhliziyo ekhazimulayo',
    '💗' => 'inhliziyo ekhulayo',
    '💓' => 'inhliziyo egxumagxumayo',
    '💞' => 'izinhliziyo ezizungezayo',
    '💕' => 'izinhliziyo ezimbili',
    '💟' => 'ukuhlobisa inhliziyo',
    '❣' => 'isibabazi senhliziyo edangele',
    '💔' => 'inhliziyo eyaphukile',
    '❤' => 'inhliziyo ebomvu',
    '🩷' => 'inhliziyo e-pink',
    '🧡' => 'inhliziyo ewolintshi',
    '💛' => 'inhliziyo eqanda',
    '💚' => 'inhliziyo eluhlaza satshani',
    '💙' => 'blue heart',
    '🩵' => 'light blue heart',
    '💜' => 'inhliziyo ensomi',
    '🤎' => 'inhliziyo ensundu',
    '🖤' => 'inhliziyo embi',
    '🩶' => 'inhliziyo e-grey',
    '🤍' => 'inhliziyo emhlophe',
    '💋' => 'uphawu lokuqabula',
    '💯' => 'amaphuzu ayikhulu',
    '💢' => 'uphawu lokudinwa',
    '🫯' => 'fight cloud',
    '💥' => 'ukushayisana',
    '💫' => 'inzululwane',
    '💦' => 'amaqabazi omjuluko',
    '💨' => 'ukushesha',
    '🕳' => 'imbobo',
    '💬' => 'ibhaluni lenikulumo',
    '🗨' => 'ibhaluni lenkulumo lakwesokunxele',
    '🗯' => 'ibhaluni lenkulumo lakwesokudla lolaka',
    '💭' => 'ibhaluni lokucabanga',
    '💤' => 'zzz',
    '👋' => 'ukuphakamisa isandla',
    '🤚' => 'thula',
    '🖐' => 'isandla esiphakanyisiwe esivuliwe',
    '✋' => 'isandla esiphanyisiwe',
    '🖖' => 'i-vulcan salute',
    '🫱' => 'rightwards hand',
    '🫲' => 'leftwards hand',
    '🫳' => 'palm down hand',
    '🫴' => 'palm up hand',
    '🫷' => 'leftwards pushing hand',
    '🫸' => 'rightwards pushing hand',
    '👌' => 'isandla sokuthi kulungile',
    '🤌' => 'iminwe encinziwe',
    '🤏' => 'isandla esincinzayo',
    '✌' => 'isandla sokunqoba',
    '🤞' => 'iminwe ebhanqiwe',
    '🫰' => 'hand with index finger and thumb crossed',
    '🤟' => 'ukukhombisa uthando',
    '🤘' => 'uphawu lwezimpondo',
    '🤙' => 'ngifonele',
    '👈' => 'ukukhomba ngengemuva lesandla sokunxele ngomunwe wokukhomba',
    '👉' => 'ukukhomba ngengemuva lesandla sokudla ngomunwe wokukhomba',
    '👆' => 'ukukhomba phezulu ngengemuva lesandla ngomunwe wokukhomba',
    '🖕' => 'umunwe omaphakathi',
    '👇' => 'ukukhomba phansi ngengemuva lesandla ngomunwe wokukhomba',
    '☝' => 'umunwe wokukhomba okhombe phezulu',
    '🫵' => 'umunwe ukhomba umbukeli',
    '👍' => 'ukumisa isithupha',
    '👎' => 'ukubhekisa phansi isithupha',
    '✊' => 'iqupha elimisiwe',
    '👊' => 'iqupha elizayo',
    '🤛' => 'inqindi ebheke kwesokunxele',
    '🤜' => 'inqindi ebheke kwesokudla',
    '👏' => 'ukushaya izandla',
    '🙌' => 'umuntu ophakamise izandla',
    '🫶' => 'thanda izandla',
    '👐' => 'izandla ezivuliwe',
    '🤲' => 'izandla zombili phezulu',
    '🤝' => 'xhawula',
    '🙏' => 'izandla ezigoqiwe',
    '✍' => 'isandla esibhalayo',
    '💅' => 'ikhyutheksi',
    '🤳' => 'uzishuthe',
    '💪' => 'ukuveza amandla',
    '🦾' => 'isandla sikamakhenikha',
    '🦿' => 'inyawo likamakhenikha',
    '🦵' => 'umlenze',
    '🦶' => 'unyawo',
    '👂' => 'indlebe',
    '🦻' => 'indlebe enensiza yokuzwa',
    '👃' => 'ikhala',
    '🧠' => 'ubuchopho',
    '🫀' => 'isitho senhliziyo',
    '🫁' => 'amaphaphu',
    '🦷' => 'izinyo',
    '🦴' => 'ithambo',
    '👀' => 'amehlo',
    '👁' => 'ihlo',
    '👅' => 'ulimi',
    '👄' => 'umlomo',
    '🫦' => 'ukuluma indebe',
    '👶' => 'usana',
    '🧒' => 'ingane',
    '👦' => 'umfana',
    '👧' => 'intombazane',
    '🧑' => 'mdala',
    '👱' => 'umuntu: izinwele ezinhlophe',
    '👨' => 'indoda',
    '🧔' => 'indoda: intshebe',
    '👩' => 'umama',
    '🧓' => 'omdala omdala',
    '👴' => 'ikhehla',
    '👵' => 'ugogo',
    '🙍' => 'umuntu ohwaqabele',
    '🙎' => 'umuntu odangele',
    '🙅' => 'umuntu oveza ukuthi akulungile',
    '🙆' => 'umuntu oveza ukuthi kulungile',
    '💁' => 'umuntu ocela ngesandla',
    '🙋' => 'umuntu ophakamisa isandla',
    '🧏' => 'umuntu ongezwa',
    '🙇' => 'umuntu othobile',
    '🤦' => 'ukuzifihla',
    '🤷' => 'shukuza amahlombe',
    '👮' => 'iphoyisa',
    '🕵' => 'umseshi',
    '💂' => 'unogada',
    '🥷' => 'ininja',
    '👷' => 'umsebenzi wenkontileka',
    '🫅' => 'umuntu onesicoco',
    '🤴' => 'inkosana',
    '👸' => 'inkosazane',
    '👳' => 'umuntu ogqoke ithalibhani',
    '👲' => 'indoda efake ikepishi lechinese',
    '🧕' => 'owesifazane oneduku',
    '🤵' => 'umuntu kwisudu',
    '👰' => 'umuntu ofake iveyili',
    '🤰' => 'okhulelwe',
    '🫃' => 'indoda ekhulelwe',
    '🫄' => 'umuntu okhulelwe',
    '🤱' => 'ukuncelisa',
    '👼' => 'ingelosi eyingane',
    '🎅' => 'ubaba ukhisimusi',
    '🤶' => 'umama kakhisimusi',
    '🦸' => 'iqhawe',
    '🦹' => 'supervillain',
    '🧙' => 'i-mage',
    '🧚' => 'nganekwane',
    '🧛' => 'ivemphaya',
    '🧜' => 'i-merperson',
    '🧝' => 'i-elf',
    '🧞' => 'ijeni',
    '🧟' => 'isilwane',
    '🧌' => 'troll',
    '🫈' => 'isidalwa esinoboya',
    '💆' => 'umuntu othola imasaji',
    '💇' => 'umuntu ogundayo',
    '🚶' => 'umuntu ohambayo',
    '🧍' => 'umuntu omile',
    '🧎' => 'umuntu oguqile',
    '🏃' => 'umunto ogijimayo',
    '💃' => 'owesimame odansayo',
    '🕺' => 'ukudansa',
    '🕴' => 'indoda egqoke isudu',
    '👯' => 'abantu abasemcimbini',
    '🧖' => 'umuntu egumbini elinestimu',
    '🧗' => 'umuntu ogibelayo',
    '🤺' => 'ifensa',
    '🏇' => 'umjaho wamahhashi',
    '⛷' => 'odlala iski',
    '🏂' => 'umgibeli webhodi lesithwathwa',
    '🏌' => 'umuntu odlala igalofu',
    '🏄' => 'umuntu ogibele isurf board',
    '🚣' => 'umuntu ogwedla isikebhe',
    '🏊' => 'umuntu obhukudayo',
    '⛹' => 'umuntu onebhola',
    '🏋' => 'umuntu ophakamisa izinsimbi',
    '🚴' => 'umuntu ogibele ibhayisikili',
    '🚵' => 'umuntu ogibele ibhayisikili lezintaba',
    '🤸' => 'isondo lekalishi',
    '🤼' => 'abashayi-sibhakela',
    '🤽' => 'ukubhukuda',
    '🤾' => 'ibhola lesandla',
    '🤹' => 'ukudlala',
    '🧘' => 'umuntu esikhundleni se-lotus',
    '🛀' => 'umuntu ogezayo',
    '🛌' => 'umuntu olele',
    '👭' => 'abasimame ababambene ngesandla',
    '👫' => 'owesilisa nowesifazane bebembene ngezandla',
    '👬' => 'amadoda amabili abambene ngesandla',
    '💏' => 'ukuqabula',
    '💑' => 'izithandani ezinenhliziyo',
    '🗣' => 'ikhanda elikhulumayo',
    '👤' => 'isithombe somuntu',
    '👥' => 'isithombe sabantu',
    '🫂' => 'abantu abanganayo',
    '👪' => 'umndeni',
    '👣' => 'izinsalela zezinyawo',
    '🫆' => 'fingerprint',
    '🦰' => 'izinwele ezibomvu',
    '🦱' => 'curly hair',
    '🦳' => 'izinwele ezimpunga',
    '🦲' => 'imbungculu',
    '🐵' => 'ubuso benkawu',
    '🐒' => 'inkawu',
    '🦍' => 'imfene',
    '🦧' => 'i-orangutan',
    '🐶' => 'ubuso benja',
    '🐕' => 'inja',
    '🦮' => 'inja yokusiza',
    '🐩' => 'inja yomlungu',
    '🐺' => 'i-wolf',
    '🦊' => 'iqili',
    '🦝' => 'raccoon',
    '🐱' => 'ubuso bekati',
    '🐈' => 'ikati',
    '🦁' => 'ibhubesi',
    '🐯' => 'ubuso bethayiga',
    '🐅' => 'ithayiga',
    '🐆' => 'ingwe',
    '🐴' => 'ubuso behhashi',
    '🫎' => 'i-moose',
    '🫏' => 'imbongolo',
    '🐎' => 'ihhashi',
    '🦄' => 'iyunikhoni',
    '🦓' => 'idube',
    '🦌' => 'inyamazane',
    '🦬' => 'bison',
    '🐮' => 'ubuso benkomo',
    '🐂' => 'inkunzi',
    '🐃' => 'inkomo yehlathi yamanzi',
    '🐄' => 'inkomo',
    '🐷' => 'ubuso bengulube',
    '🐖' => 'ingulube',
    '🐗' => 'inkunzi yengulube',
    '🐽' => 'ikhala lengulube',
    '🐏' => 'inkunzi yegusha',
    '🐑' => 'igusha',
    '🐐' => 'imbuzi',
    '🐪' => 'ikameli',
    '🐫' => 'ikameli elinezifumbu ezimbili',
    '🦙' => 'llama',
    '🦒' => 'indlulamithi',
    '🐘' => 'indlovu',
    '🦣' => 'mammoth',
    '🦏' => 'ubhejane',
    '🦛' => 'hippopotamus',
    '🐭' => 'ubuso begundane',
    '🐁' => 'igundane',
    '🐀' => 'igundane lasendle',
    '🐹' => 'i-hamster',
    '🐰' => 'ubuso bukanojwaja',
    '🐇' => 'unogwaja',
    '🐿' => 'i-chipmunk',
    '🦫' => 'i-beaver',
    '🦔' => 'inhloli',
    '🦇' => 'ilulwane',
    '🐻' => 'ibhele',
    '🐨' => 'i-koala',
    '🐼' => 'iphanda',
    '🦥' => 'i-sloth',
    '🦦' => 'i-otter',
    '🦨' => 'i-skunk',
    '🦘' => 'i-kangaroo',
    '🦡' => 'badger',
    '🐾' => 'amaqophelo ezidladla',
    '🦃' => 'ithekhi',
    '🐔' => 'inkukhu',
    '🐓' => 'iqhude',
    '🐣' => 'ichwane eliphuma eqandeni',
    '🐤' => 'ichwane elincane',
    '🐥' => 'ichwane elincane elibheke phambili',
    '🐦' => 'inyoni',
    '🐧' => 'iphengwini',
    '🕊' => 'ijuba',
    '🦅' => 'ukhozi',
    '🦆' => 'idada',
    '🦢' => 'cygnet',
    '🦉' => 'isikhova',
    '🦤' => 'dodo',
    '🪶' => 'uphaphe',
    '🦩' => 'i-flamingo',
    '🦚' => 'peacock',
    '🦜' => 'parrot',
    '🪽' => 'iphiko',
    '🪿' => 'i-goose',
    '🐸' => 'ixoxo',
    '🐊' => 'ingwenya',
    '🐢' => 'ufudu',
    '🦎' => 'isibankwa',
    '🐍' => 'inyoka',
    '🐲' => 'ubuso benyoka',
    '🐉' => 'udrakho',
    '🦕' => 'i-sauropod',
    '🦖' => 'i-T-Rex',
    '🐳' => 'umkhomo ekhipha amanzi',
    '🐋' => 'umkhomo',
    '🐬' => 'ihlengethwa',
    '🫍' => 'orca',
    '🦭' => 'i-seal',
    '🐟' => 'inhlanzi',
    '🐠' => 'ufishi',
    '🐡' => 'inhlanzi efuthekile',
    '🦈' => 'ushaka',
    '🐙' => 'i-okthophasi',
    '🐚' => 'igobolondo elizungezile',
    '🪸' => 'i-coral',
    '🪼' => 'i-jellyfish',
    '🦀' => 'inkalankala',
    '🦞' => 'lobster',
    '🦐' => 'imfanzi',
    '🦑' => 'ingwane',
    '🦪' => 'i-oyster',
    '🐌' => 'umnenke',
    '🦋' => 'uvemvane',
    '🐛' => 'isilokozane',
    '🐜' => 'intuthwane',
    '🐝' => 'inyosi yoju',
    '🪲' => 'ibhungane',
    '🐞' => 'ibhungezi',
    '🦗' => 'ikhilikithi',
    '🪳' => 'ikokoroshe',
    '🕷' => 'isicabucabu',
    '🕸' => 'ulwembu lwesicabucabu',
    '🦂' => 'ufezela',
    '🦟' => 'mosquito',
    '🪰' => 'impukane',
    '🪱' => 'isibungu',
    '🦠' => 'microbe',
    '💐' => 'isixha sezimbali',
    '🌸' => 'ukhukhula kwembali',
    '💮' => 'imbali emhlophe',
    '🪷' => 'lotus',
    '🏵' => 'irosette',
    '🌹' => 'irose',
    '🥀' => 'bunile',
    '🌺' => 'ihibiscus',
    '🌻' => 'ujikanelanga',
    '🌼' => 'ukuqhakaza',
    '🌷' => 'i-tulip',
    '🪻' => 'hyacinth',
    '🌱' => 'imbewu',
    '🪴' => 'isitshalo esisesitsheni',
    '🌲' => 'i-evergreen',
    '🌳' => 'i-deciduous tree',
    '🌴' => 'isundu',
    '🌵' => 'i-cactus',
    '🌾' => 'uhlamvu lwelayisi',
    '🌿' => 'iqabunga',
    '☘' => 'i-shamrock',
    '🍀' => 'i-four leaf clover',
    '🍁' => 'i-maple leaf',
    '🍂' => 'iqabunga eliqathakile',
    '🍃' => 'iqabunga eliphephethwa umoya',
    '🪹' => 'isidleke esingenalutho',
    '🪺' => 'nest with eggs',
    '🍄' => 'ikhowe',
    '🪾' => 'leafless tree',
    '🍇' => 'amagilebhisi',
    '🍈' => 'imeloni',
    '🍉' => 'ikhabe',
    '🍊' => 'inantshi',
    '🍋' => 'ulamula',
    '🍌' => 'ubhanana',
    '🍍' => 'upayinapu',
    '🥭' => 'umango',
    '🍎' => 'ihhabhula elibomvu',
    '🍏' => 'ihhabhula eliluhlaza',
    '🍐' => 'ipheya',
    '🍑' => 'ipetshisi',
    '🍒' => 'amasheri',
    '🍓' => 'amabhimbi',
    '🫐' => 'ama-blueberries',
    '🥝' => 'ikiwi',
    '🍅' => 'utamatisi',
    '🫒' => 'i-olive',
    '🥥' => 'ikhukhunathi',
    '🥑' => 'ukotapheya',
    '🍆' => 'ubrinjoli',
    '🥔' => 'izambane',
    '🥕' => 'ukhalothi',
    '🌽' => 'iqabunga lommbila',
    '🌶' => 'upelepele obabayo',
    '🫑' => 'i-bell pepper',
    '🥒' => 'ukhukhumba',
    '🥬' => 'leafy green',
    '🥦' => 'i-bhulokholi',
    '🧄' => 'igalikhi',
    '🧅' => 'u-anyanisi',
    '🥜' => 'amakinati',
    '🫘' => 'ubhontshisi',
    '🌰' => 'ichestnut',
    '🫚' => 'ingxabu yejinja',
    '🫛' => 'i-pea pod',
    '🫜' => 'Iveji eliyingxabu',
    '🍞' => 'ulofu',
    '🥐' => 'ibhanisi',
    '🥖' => 'isinkwa',
    '🫓' => 'isinkwa esibacakile',
    '🥨' => 'i-phulezeli',
    '🥯' => 'bagel',
    '🥞' => 'amakhekhe',
    '🧇' => 'i-waffle',
    '🧀' => 'ucezu lukashizi',
    '🍖' => 'inyamo ethajeni',
    '🍗' => 'umlenze wenkukhu',
    '🥩' => 'ingxenyana yenyama',
    '🥓' => 'ubhekeni',
    '🍔' => 'ibhega',
    '🍟' => 'amafrayizi',
    '🍕' => 'ipiza',
    '🌭' => 'ihot dog',
    '🥪' => 'isemishi',
    '🌮' => 'itaco',
    '🌯' => 'hburrito',
    '🫔' => 'i-tamale',
    '🥙' => 'isinkwa esishuthekwe ukudla',
    '🧆' => 'i-falafel',
    '🥚' => 'iqanda',
    '🍳' => 'ukupheka',
    '🥘' => 'ipani elinokudla',
    '🍲' => 'ibhdwe lokudla',
    '🫕' => 'i-fondue',
    '🥣' => 'idla ngespuni',
    '🥗' => 'isaladi lasengadini',
    '🍿' => 'uphophukhoni',
    '🧈' => 'ibhatha',
    '🧂' => 'salt',
    '🥫' => 'ukudla okusekanini',
    '🍱' => 'ibento bhoksi',
    '🍘' => 'irice cracker',
    '🍙' => 'ibhala lelayisi',
    '🍚' => 'ilayisi eliphekiwe',
    '🍛' => 'isishebo selayisi',
    '🍜' => 'isitsha esishunqayo',
    '🍝' => 'ispaghetti',
    '🍠' => 'ubhatata othosiwe',
    '🍢' => 'i-oden',
    '🍣' => 'isushi',
    '🍤' => 'ishrimpu ethosiwe',
    '🍥' => 'ikhekhe lenhlanzi elinokuzungezayo',
    '🥮' => 'moon cake',
    '🍡' => 'i-dango',
    '🥟' => 'idombolo',
    '🥠' => 'ikhekhe lenhlanhla',
    '🥡' => 'ibhokisi lokuthatha ngaphandle',
    '🍦' => 'u-ice cream othambile',
    '🍧' => 'i-shaved ice',
    '🍨' => 'u-ice cream',
    '🍩' => 'idonathi',
    '🍪' => 'iqebelengwane',
    '🎂' => 'ikhekhe lokuzalwa',
    '🍰' => 'ikhekhe elincane',
    '🧁' => 'cupcake',
    '🥧' => 'uphaya',
    '🍫' => 'ushokoledi',
    '🍬' => 'uswidi',
    '🍭' => 'ustikhiswidi',
    '🍮' => 'ukhastadi',
    '🍯' => 'isitsha soju',
    '🍼' => 'ibhodlela lengane',
    '🥛' => 'ingilazi yobisi',
    '☕' => 'isiphuzo esishisayo',
    '🫖' => 'ithibhothi',
    '🍵' => 'inkomishi yetiye engenasibambo',
    '🍶' => 'isake',
    '🍾' => 'ibhodlela elinokuputshuka phezulu',
    '🍷' => 'ingilazi yewayini',
    '🍸' => 'ingilazi yecocktail',
    '🍹' => 'isiphuzo esipholisayo',
    '🍺' => 'imagi kabhiya',
    '🍻' => 'ukushayisana kwamamagi kabhiya',
    '🥂' => 'ukushayanisa izingilazi',
    '🥃' => 'ingilazi yephepha',
    '🫗' => 'uthela uketshezi',
    '🥤' => 'inkomishi enomucu wokumoma',
    '🧋' => 'itiye le-bubble',
    '🧃' => 'ibhokisi leziphuzo',
    '🧉' => 'i-mate',
    '🧊' => 'ukubanda',
    '🥢' => 'izinti',
    '🍽' => 'imfoloko nommese nepleti',
    '🍴' => 'imfoloko nommese',
    '🥄' => 'isipunu',
    '🔪' => 'ummese wasekhishini',
    '🫙' => 'ujeke',
    '🏺' => 'i-amfrora',
    '🌍' => 'igilobhu eliveza i-europe-afrika',
    '🌎' => 'igilobhu eliveza emelika',
    '🌏' => 'igilobhu eliveza asia-australia',
    '🌐' => 'igilobhu elinemeridians',
    '🗺' => 'ibalazwe lomhlaba',
    '🗾' => 'ibalazwe lejapan',
    '🧭' => 'i-compass',
    '🏔' => 'intaba embethe iqhwa',
    '⛰' => 'intaba',
    '🛘' => 'ukudilika komhlaba',
    '🌋' => 'intabamlilo',
    '🗻' => 'intaba ifuji',
    '🏕' => 'ukukhempa',
    '🏖' => 'ibhishi nesambulela',
    '🏜' => 'ugwadule',
    '🏝' => 'isiqhingi sasogwadule',
    '🏞' => 'ipaki likazwelonke',
    '🏟' => 'inkundla yezemidlalo',
    '🏛' => 'isakhiwo sakudala',
    '🏗' => 'ukwakha isakhiwo',
    '🧱' => 'isitini',
    '🪨' => 'idwala',
    '🪵' => 'ukhuni',
    '🛖' => 'indlu',
    '🏘' => 'izakhiwo zezindlu',
    '🏚' => 'isakhiwo sendlu esinganakiwe',
    '🏠' => 'isakhiwo sendlu',
    '🏡' => 'indlu enengadi',
    '🏢' => 'isakhiwo sehhovisi',
    '🏣' => 'iposi lama-japanese',
    '🏤' => 'iposi',
    '🏥' => 'isibhedlela',
    '🏦' => 'ibhange',
    '🏨' => 'ihhotela',
    '🏩' => 'ihhotela lothando',
    '🏪' => 'isitolo esihlala sivuliwe',
    '🏫' => 'isikole',
    '🏬' => 'isitolo sempahla',
    '🏭' => 'imboni',
    '🏯' => 'isigodlo se-japanese',
    '🏰' => 'isigodlo',
    '💒' => 'umshado',
    '🗼' => 'itokyo tower',
    '🗽' => 'statue of liberty',
    '⛪' => 'isonto',
    '🕌' => 'isonto lamasulumane',
    '🛕' => 'ithempeli le-hindu',
    '🕍' => 'isinagoge',
    '⛩' => 'shinto shrine',
    '🕋' => 'i-kaaba',
    '⛲' => 'umthombo',
    '⛺' => 'itende',
    '🌁' => 'kunezinkungu',
    '🌃' => 'ubusuku obunezinkanyezi',
    '🏙' => 'ukubukeka kwedolobha',
    '🌄' => 'ukuphuma kwelanga ezintabeni',
    '🌅' => 'ukuphuma kwelanga',
    '🌆' => 'ukubukeka kwedolobha ukushona kwelanga',
    '🌇' => 'ukushona kwelanga',
    '🌉' => 'ibhuloho ebusuku',
    '♨' => 'iziphethu ezinamanzi ashisayo',
    '🎠' => 'ihhashi lekharaseli',
    '🛝' => 'islayidi sokudlala',
    '🎡' => 'isondo leferisi',
    '🎢' => 'i-roller coaster',
    '💈' => 'ipholi yomgundi wezinwele',
    '🎪' => 'itende lesekisi',
    '🚂' => 'ikhanda lesitmela',
    '🚃' => 'imoto eyisitimela',
    '🚄' => 'isitimela esinesivinini esikhulu',
    '🚅' => 'isitimela esinesivinini esikhulu esinekhala elinjengenhlamvu',
    '🚆' => 'isitimela',
    '🚇' => 'isitimela esihamba ngaphansi komhlaba',
    '🚈' => 'isitimela esingengethilamu',
    '🚉' => 'isiteshi',
    '🚊' => 'ithilamu',
    '🚝' => 'ujantshi owodwa',
    '🚞' => 'ujantshi wasentabeni',
    '🚋' => 'imoto eyithilamu',
    '🚌' => 'ibhasi',
    '🚍' => 'ibhasi elizayo',
    '🚎' => 'ibhasi elihamba ngogesi',
    '🚐' => 'ikhumbi',
    '🚑' => 'i-ambulense',
    '🚒' => 'injini yomlilo',
    '🚓' => 'imoto yamaphoyisa',
    '🚔' => 'imoto yamaphoyisa ezayo',
    '🚕' => 'itekisi',
    '🚖' => 'itekisi elizayo',
    '🚗' => 'imoto',
    '🚘' => 'imoto ezayo',
    '🚙' => 'isithuthi sokuzithokozisa',
    '🛻' => 'iloli likadoti',
    '🚚' => 'iloli lokudiliva',
    '🚛' => 'iloli elihlangene nogandaganda',
    '🚜' => 'ugandaganda',
    '🏎' => 'imoto yomjaho',
    '🏍' => 'isithuthuthu esigijimayo',
    '🛵' => 'isithuthuthu',
    '🦽' => 'isitulo esihanjiswayo',
    '🦼' => 'isitulo esizihambelayo',
    '🛺' => 'i-auto rickshaw',
    '🚲' => 'ibhayisikili',
    '🛴' => 'isikuta esikhahlelwayo',
    '🛹' => 'skateboard',
    '🛼' => 'i-roller skate',
    '🚏' => 'isitobhu sebhasi',
    '🛣' => 'umgwaqo onguthelawayeka',
    '🛤' => 'ujantshi wesitimela',
    '🛢' => 'idramu lamafutha',
    '⛽' => 'isifutho sesiphehlamandla',
    '🛞' => 'isondo',
    '🚨' => 'ilambu lemoto yamaphoyisa',
    '🚥' => 'irobhothi elivundlile',
    '🚦' => 'irobhothi elibheke phezulu',
    '🛑' => 'uphawu lokuma',
    '🚧' => 'ukwakha',
    '⚓' => 'ihange',
    '🛟' => 'ring buoy',
    '⛵' => 'isikebhe sasolwandle',
    '🛶' => 'isikebhe',
    '🚤' => 'isikebhe esinesivinini esikhulu',
    '🛳' => 'umkhumbi othwala abagbeli',
    '⛴' => 'isikebhe sokuwelisa',
    '🛥' => 'isikebhe esinenjini',
    '🚢' => 'umkhumbi',
    '✈' => 'ibhanoyi',
    '🛩' => 'ibhanoyi elincane',
    '🛫' => 'ukuhamba kwebhanoyi',
    '🛬' => 'ukufika kwebhanoyi',
    '🪂' => 'i-parachute',
    '💺' => 'isihlalo',
    '🚁' => 'ibhanoyi elinophephela emhlane',
    '🚟' => 'ujantshi',
    '🚠' => 'inqola eya entabeni',
    '🚡' => 'inqola yasemoyeni',
    '🛰' => 'isethalayithi',
    '🚀' => 'irokhethi',
    '🛸' => 'isosa endizayo',
    '🛎' => 'insimbi',
    '🧳' => 'umthwalo',
    '⌛' => 'hourglass',
    '⏳' => 'i-hourglass egeleza isihlabathi',
    '⌚' => 'iwashi',
    '⏰' => 'iwashi le-alamu',
    '⏱' => 'i-stop washi',
    '⏲' => 'timer clock',
    '🕰' => 'mantelpiece clock',
    '🕛' => 'twelve o’clock',
    '🕧' => 'twelve-thirty',
    '🕐' => 'one o’clock',
    '🕜' => 'elilodwa nengxenye',
    '🕑' => 'two o’clock',
    '🕝' => 'two-thirty',
    '🕒' => 'three o’clock',
    '🕞' => 'three-thirty',
    '🕓' => 'four o’clock',
    '🕟' => 'ihora lesine nengxenye',
    '🕔' => 'five o’clock',
    '🕠' => 'five-thirty',
    '🕕' => 'six o’clock',
    '🕡' => 'six-thirty',
    '🕖' => 'seven o’clock',
    '🕢' => 'seven-thirty',
    '🕗' => 'eight o’clock',
    '🕣' => 'eight-thirty',
    '🕘' => 'nine o’clock',
    '🕤' => 'nine-thirty',
    '🕙' => 'ten o’clock',
    '🕥' => 'ten-thirty',
    '🕚' => 'eleven o’clock',
    '🕦' => 'eleven-thirty',
    '🌑' => 'inyanga entsha',
    '🌒' => 'inyanga ewucezu olubheke emuva',
    '🌓' => 'ikota yokuqala yenyanga',
    '🌔' => 'inyange ewucezu ebheke phambili',
    '🌕' => 'inyange egcwele',
    '🌖' => 'inyanga ebheke emuva enciphile',
    '🌗' => 'inyanga yekota yokugcina',
    '🌘' => 'inyanga ebheke phambili enkulu',
    '🌙' => 'inyanga enciphile',
    '🌚' => 'ubuso benyanga entsha',
    '🌛' => 'inyanga yekota lokuqala elinobuso',
    '🌜' => 'ikota yokugcina yenyanga enobuso',
    '🌡' => 'ithemomitha',
    '☀' => 'ilanga',
    '🌝' => 'inyanga egcwele enobuso',
    '🌞' => 'ilanga elinobuso',
    '🪐' => 'iplanethi eringayo',
    '⭐' => 'inkanyezi ephakathi nendawo emhlophe',
    '🌟' => 'inkanyezi ebhanyazayo',
    '🌠' => 'inkanyezi edubulayo',
    '🌌' => 'imilkhi weyi',
    '☁' => 'ifu',
    '⛅' => 'ilanga elingemuva kwefu',
    '⛈' => 'ifu elinombani kanye nemvula',
    '🌤' => 'ilanga elingemuva kwefu elincane',
    '🌥' => 'ilanga elingemuva kwef elikhul',
    '🌦' => 'ilanga elingemuva kwefu elinemvula',
    '🌧' => 'ifu elinemvula',
    '🌨' => 'ifu elinesithwathwa',
    '🌩' => 'ifu elinombani',
    '🌪' => 'inkanyamba',
    '🌫' => 'inkungu',
    '🌬' => 'ubuso bomoya',
    '🌀' => 'isiphepho',
    '🌈' => 'uthingo',
    '🌂' => 'isambulela esivaliwe',
    '☂' => 'isambulela',
    '☔' => 'isambulela esinamaqabazi emvula',
    '⛱' => 'isambulela esiphansi',
    '⚡' => 'amandla kagesi amakhulu',
    '❄' => 'ikhekheba leqha',
    '☃' => 'indoda yesithwathwa',
    '⛄' => 'indoda yesithwathwa engenasithwathwa',
    '☄' => 'ikhomethi',
    '🔥' => 'umlimo',
    '💧' => 'iqabazi',
    '🌊' => 'igagasi lamanzi',
    '🎃' => 'i-jack-o-lantern',
    '🎄' => 'isihlahla sikaKhisimusi',
    '🎆' => 'amakhrikhethi',
    '🎇' => 'okuqhumayo',
    '🧨' => 'firecracker',
    '✨' => 'okukhazimulayo',
    '🎈' => 'ibhaluni',
    '🎉' => 'okuqhuma ephathini',
    '🎊' => 'ibhola eliqhumayo',
    '🎋' => 'isihlahla setanabata',
    '🎍' => 'imihlobiso yesundu',
    '🎎' => 'onodoli bejapanese',
    '🎏' => 'i-carp streamer',
    '🎐' => 'ichime yomoya',
    '🎑' => 'umcimbi wenyanga',
    '🧧' => 'red envelope',
    '🎀' => 'iribhini',
    '🎁' => 'isipho esigoqiwe',
    '🎗' => 'iribhini yesikhumbuzo',
    '🎟' => 'amathikithi okungena',
    '🎫' => 'ithikithi',
    '🎖' => 'imedali yamasosha',
    '🏆' => 'indondo',
    '🏅' => 'imedali yezamidlalo',
    '🥇' => 'indodo yendawo yokuqala',
    '🥈' => 'indondo yendawo yesibili',
    '🥉' => 'indondo yendawo yesithathu',
    '⚽' => 'ibhola likanobhujuzwayo',
    '⚾' => 'i-baseball',
    '🥎' => 'softball',
    '🏀' => 'i-basketball',
    '🏐' => 'i-volleyball',
    '🏈' => 'i-american football',
    '🏉' => 'ibhola lomboxo',
    '🎾' => 'ithenisi',
    '🥏' => 'flying disc',
    '🎳' => 'ukubhowla',
    '🏏' => 'umdlalo wekhilikithi',
    '🏑' => 'ihokhi',
    '🏒' => 'ihokhi yaseqhweni',
    '🥍' => 'lacrosse',
    '🏓' => 'ping pong',
    '🏸' => 'ibadminton',
    '🥊' => 'igilavu lokulwa',
    '🥋' => 'inyufomu yokulwa',
    '🥅' => 'inethi yegoli',
    '⛳' => 'ifulegi elisembobeni',
    '⛸' => 'ice skate',
    '🎣' => 'udobo',
    '🤿' => 'imaski yokudayiva',
    '🎽' => 'isikibha sokugijima',
    '🎿' => 'skis',
    '🛷' => 'isihlibhi',
    '🥌' => 'itshe lokutayela',
    '🎯' => 'ukunemba',
    '🪀' => 'i-yo-yo',
    '🪁' => 'i-kite',
    '🔫' => 'ivolovolo',
    '🎱' => 'amabhiliyade',
    '🔮' => 'ibhola lekhristali',
    '🪄' => 'induku yomlingo',
    '🎮' => 'umdlalo wevidiyo',
    '🕹' => 'ijoystiki',
    '🎰' => 'umshini onembotshana yokufaka imali',
    '🎲' => 'umdlalo wamadayisi',
    '🧩' => 'izingcezu zephazili',
    '🧸' => 'u-teddy bear',
    '🪅' => 'i-piñata',
    '🪩' => 'mirror ball',
    '🪆' => 'nesting dolls',
    '♠' => 'uspeyidi',
    '♥' => 'unhliziyo',
    '♦' => 'okumise okwedayimane',
    '♣' => 'umpukane',
    '♟' => 'chess pawn',
    '🃏' => 'ujokha',
    '🀄' => 'umajongi oyidragoni ebomvu',
    '🎴' => 'amakhadi okudlala ayimbali',
    '🎭' => 'ezobuciko bemibukiso',
    '🖼' => 'ifulemu enesithombe',
    '🎨' => 'ibhodi lengcweti yokupenda',
    '🧵' => 'thread',
    '🪡' => 'inaliti yokuthunga',
    '🧶' => 'yarn',
    '🪢' => 'ifindo',
    '👓' => 'izibuko',
    '🕶' => 'izibuko zelanga',
    '🥽' => 'izibuko zokuzivikela',
    '🥼' => 'lab coat',
    '🦺' => 'iveste yokuphepha',
    '👔' => 'uthayi womqala',
    '👕' => 'isikibha',
    '👖' => 'ijini',
    '🧣' => 'iskhafu',
    '🧤' => 'amaglavu',
    '🧥' => 'ijazi',
    '🧦' => 'amasokisi',
    '👗' => 'irokwe',
    '👘' => 'ikinomo',
    '🥻' => 'i-sari',
    '🩱' => 'insudu yokubhukuda eyodwa',
    '🩲' => 'izifinyezo',
    '🩳' => 'izikhindi',
    '👙' => 'ibikini',
    '👚' => 'impahla yomuntu wesifazane',
    '🪭' => 'folding hand fan',
    '👛' => 'isikhwama semali',
    '👜' => 'isikhwama esincane',
    '👝' => 'isikhwama',
    '🛍' => 'izikhwama zokuthenga',
    '🎒' => 'isikhwama sesikole',
    '🩴' => 'isicathulo esingena kubhozo',
    '👞' => 'izicathulo zamadoda',
    '👟' => 'izicathulo zokugijima',
    '🥾' => 'amabhuthi okuqwala',
    '🥿' => 'isicathulo esiphansi',
    '👠' => 'iqhoksi',
    '👡' => 'amasendeli owesimame',
    '🩰' => 'izicathulo ze-ballet',
    '👢' => 'ibhuzu lowesimame',
    '🪮' => 'hair pick',
    '👑' => 'umqhele',
    '👒' => 'isigqoko sowesimame',
    '🎩' => 'isigqoko sabesilisa',
    '🎓' => 'isigqoko semiyezane',
    '🧢' => 'ikhephu ekhokhisiwe',
    '🪖' => 'izigqoko zempi',
    '⛑' => 'isigqoko esiqinile esinesiphambano esimhlophe',
    '📿' => 'ubuhlalu bokuthandaza',
    '💄' => 'iruji',
    '💍' => 'iringi',
    '💎' => 'idayimane',
    '🔇' => 'ukucisha isipikha',
    '🔈' => 'ispikha',
    '🔉' => 'ukuvula ispikha',
    '🔊' => 'ispikha esiphezulu',
    '📢' => 'isipikha esimemezayo',
    '📣' => 'umbhobho omkhulu',
    '📯' => 'umbhobo weposi',
    '🔔' => 'ibheli',
    '🔕' => 'insimbi enodwi',
    '🎼' => 'umbhalo womculo',
    '🎵' => 'inothi lomculo',
    '🎶' => 'amanothi omculo',
    '🎙' => 'imakhrofoni yasestudiyo',
    '🎚' => 'izinga lesilawuli',
    '🎛' => 'izinkinobho zezilawuli',
    '🎤' => 'imakhrofoni',
    '🎧' => 'ama-headphone',
    '📻' => 'umsakazo',
    '🎷' => 'imfiliji',
    '🎺' => 'icilongo',
    '🪊' => 'trombone',
    '🪗' => 'i-accordion',
    '🎸' => 'isigingci',
    '🎹' => 'ikhibhodi yomculo',
    '🎻' => 'ivayolini',
    '🪕' => 'i-banjo',
    '🥁' => 'idilamu',
    '🪘' => 'isigubhu eside',
    '🪇' => 'maracas',
    '🪈' => 'flute',
    '🪉' => 'harp',
    '📱' => 'iselula',
    '📲' => 'iselula enomcibisholo',
    '☎' => 'ucingo',
    '📞' => 'ithelefoni',
    '📟' => 'ipheja',
    '📠' => 'umshini wefeksi',
    '🔋' => 'ibhetri',
    '🪫' => 'ibhethri isincane',
    '🔌' => 'ipulaki likagesi',
    '💻' => 'ikhompyutha eyilephuthophi',
    '🖥' => 'ikhompyutha yedeskhithophu',
    '🖨' => 'iphrinta',
    '⌨' => 'ikhibhodi',
    '🖱' => 'isilawuli sekhompyutha',
    '🖲' => 'itrackball',
    '💽' => 'idiski encane',
    '💾' => 'i-floppy diski',
    '💿' => 'isidi',
    '📀' => 'idividi',
    '🧮' => 'abacus',
    '🎥' => 'ikhamera yamamuvi',
    '🎞' => 'amafreymi amafilimu',
    '📽' => 'ibhayisikobho',
    '🎬' => 'i-clapper board',
    '📺' => 'ithelevishini',
    '📷' => 'ikhamera',
    '📸' => 'ikhamera enefleshi',
    '📹' => 'ividiyo khamera',
    '📼' => 'ividiyo khasethi',
    '🔍' => 'ibhodlela elikhulisayo elibheke kwesokunxele',
    '🔎' => 'ibhodlela elikhulisayo elibheke kwesokudla',
    '🕯' => 'ikhandlela',
    '💡' => 'igilobhu likagesi',
    '🔦' => 'ithoshi',
    '🏮' => 'ilambu elibomvu',
    '🪔' => 'isibani se-diya',
    '📔' => 'incwajana enekhava ehlotshisiwe',
    '📕' => 'incwadi evaliwe',
    '📖' => 'incwadi evuliwe',
    '📗' => 'incwadi eluhlaza satshani',
    '📘' => 'incwadi eluhlaza sasibhakabhaka',
    '📙' => 'incwadi ephuzi',
    '📚' => 'izincwadi',
    '📓' => 'incwajana',
    '📒' => 'ileja',
    '📃' => 'ikhasi eligobile',
    '📜' => 'umqulu',
    '📄' => 'ikhasi elibheke phezulu',
    '📰' => 'iphephandaba',
    '🗞' => 'iphephandaba eligoqiwe',
    '📑' => 'ama-tabs okumaka ibhuku',
    '🔖' => 'ibhuku lokumaka',
    '🏷' => 'ilebula',
    '🪙' => 'imali',
    '💰' => 'isaka lemali',
    '🪎' => 'treasure chest',
    '💴' => 'imali eyiyeni',
    '💵' => 'imali eyidola',
    '💶' => 'imali yase-euro',
    '💷' => 'imali eyi-pound',
    '💸' => 'imali enamaphiko',
    '💳' => 'ikhredithi khadi',
    '🧾' => 'receipt',
    '💹' => 'ishadi elivuza ukukhuphuka kweyeni',
    '✉' => 'imvilophu',
    '📧' => 'i-imeyli',
    '📨' => 'imvilophu engenayo',
    '📩' => 'imvalaphu enomcibisholo',
    '📤' => 'ibhokisi lokuphumayo',
    '📥' => 'ibhokisi lokungenayo',
    '📦' => 'iphasela',
    '📫' => 'ibhokisi leposi elivaliwe elinefulegi eliphakanyisiwe',
    '📪' => 'ibhokisi leposi elivaliwe elinefulegi elehlisiwe',
    '📬' => 'ibhokisi leposi elivuliwe elinefulgi eliphakanyisiwe',
    '📭' => 'iposi elivuliwe elinefulegi elehlisiwe',
    '📮' => 'ibhokisi leposi',
    '🗳' => 'ibhokisi lebhalothi elinebhalothi',
    '✏' => 'ipenseli',
    '✒' => 'umsizi omnyama',
    '🖋' => 'ifountain pen',
    '🖊' => 'ipeni elicijile',
    '🖌' => 'ibhulashi lokupeda',
    '🖍' => 'ikhrayoni',
    '📝' => 'imemo',
    '💼' => 'ibhrifukhesi',
    '📁' => 'ifolda yefayela',
    '📂' => 'vula ifolda yefayela',
    '🗂' => 'okwahlukanisa amakhadi',
    '📅' => 'ikhalenda',
    '📆' => 'ikhalenda elidabulekayo',
    '🗒' => 'okokubhala okunezipringi',
    '🗓' => 'ikhalenda lezipringi',
    '📇' => 'okokuhlela amakhadi',
    '📈' => 'ishadi elikhuphukayo',
    '📉' => 'ishadi elehlayo',
    '📊' => 'ishadi eliyibha',
    '📋' => 'ibhodi lokunamathelisa',
    '📌' => 'uphini wokuphusha',
    '📍' => 'uphini wokuphusha oyindingilizi',
    '📎' => 'okokubamba amaphepha',
    '🖇' => 'okokubamba amaphepha okuhlangene',
    '📏' => 'irula eliqondile',
    '📐' => 'irula eliwunxantathu',
    '✂' => 'isikelo',
    '🗃' => 'ibhodi lokugcina amakhadi',
    '🗄' => 'ikhabethei lamafayela',
    '🗑' => 'ubhasikidi wezibi',
    '🔒' => 'ingidi',
    '🔓' => 'ingidi evuliwe',
    '🔏' => 'ingidi enepeni',
    '🔐' => 'ingidi evaliwe enokhiye',
    '🔑' => 'ukhiye',
    '🗝' => 'ukhiye omdala',
    '🔨' => 'isando',
    '🪓' => 'imbazo',
    '⛏' => 'ipiki',
    '⚒' => 'isando ipiki',
    '🛠' => 'isando nespanelo',
    '🗡' => 'ummese',
    '⚔' => 'imikhonto ephambene',
    '💣' => 'ibhomu',
    '🪃' => 'i-boomerang',
    '🏹' => 'umcibisholo nesihlangu',
    '🛡' => 'ihawu',
    '🪚' => 'isaha lombazi',
    '🔧' => 'isipanelo',
    '🪛' => 'isikebheli',
    '🔩' => 'ibholidi',
    '⚙' => 'igiya',
    '🗜' => 'isicindezeli',
    '⚖' => 'okokulinganisa',
    '🦯' => 'ikheni yokusiza',
    '🔗' => 'ukuxhumanisa',
    '⛓' => 'amaketango',
    '🪝' => 'i-hook',
    '🧰' => 'ibhokisi lamathuluzi',
    '🧲' => 'umayibuthe',
    '🪜' => 'ilada',
    '🪏' => 'shovel',
    '⚗' => 'i-alambic',
    '🧪' => 'ishubhu lokuhlola',
    '🧫' => 'petri dish',
    '🧬' => 'ulibofuzo',
    '🔬' => 'i-microscope',
    '🔭' => 'i-telescope',
    '📡' => 'u-eriyeli wesethelaythi',
    '💉' => 'umjovo',
    '🩸' => 'ithonsi legazi',
    '💊' => 'iphilisi',
    '🩹' => 'ibhandishi yokubopha',
    '🩼' => 'crutch',
    '🩺' => 'i-slethoscope',
    '🩻' => 'x-ray',
    '🚪' => 'isicabha',
    '🛗' => 'ikheshi',
    '🪞' => 'isibuko',
    '🪟' => 'iwindi',
    '🛏' => 'umbhede',
    '🛋' => 'usofa ilambu',
    '🪑' => 'isitulo',
    '🚽' => 'indlu yangasese',
    '🪠' => 'i-plunger',
    '🚿' => 'ishawa',
    '🛁' => 'ubhavu wokugezela',
    '🪤' => 'unoxhaka',
    '🪒' => 'i-razor',
    '🧴' => 'ibhodlela leloshini',
    '🧷' => 'isipeletu',
    '🧹' => 'umshanelo',
    '🧺' => 'ubhasikidi',
    '🧻' => 'roll of paper',
    '🪣' => 'ibhakede',
    '🧼' => 'insipho',
    '🫧' => 'amagwebhu',
    '🪥' => 'isixubho',
    '🧽' => 'isipontshi',
    '🧯' => 'isicishamlilo',
    '🛒' => 'inqola yokuthenga',
    '🚬' => 'ukubhema',
    '⚰' => 'ibhokisi lomngcwabo',
    '🪦' => 'ikhanda eliyinhloko',
    '⚱' => 'isitsha somngcwabo',
    '🧿' => 'nazar amulet',
    '🪬' => 'i-hamsa',
    '🗿' => 'i-moai',
    '🪧' => 'iphakadi',
    '🪪' => 'umazisi',
    '🏧' => 'uphawu lwe-ATM',
    '🚮' => 'uphawu lomgqomo wezibi',
    '🚰' => 'amanzi asempompini',
    '♿' => 'isihlalo esinamasondo sabantu abaphila nokukhubazeka',
    '🚹' => 'indlu yangasese yamadoda',
    '🚺' => 'indlu yangasese yabesimame',
    '🚻' => 'indlu encane',
    '🚼' => 'uphawu lwengane',
    '🚾' => 'indawo yamanzi',
    '🛂' => 'ukulawula iphasiphothi',
    '🛃' => 'customs',
    '🛄' => 'ukulanda isikhwama',
    '🛅' => 'impahla esele',
    '⚠' => 'isexwayiso',
    '🚸' => 'izingane eziwelayo',
    '⛔' => 'akungenwa',
    '🚫' => 'okuvinjiwe',
    '🚳' => 'amabhayisikili akavunyelwe',
    '🚭' => 'akubhenywa',
    '🚯' => 'akulahlwa',
    '🚱' => 'amanzi angaphatheke',
    '🚷' => 'abavunyelwe abahamba ngezinyawo',
    '📵' => 'akavumelekile amaselula',
    '🔞' => 'abavumelekile abangaphansi kweminyaka eyi-18',
    '☢' => 'kusebenza ngowaya',
    '☣' => 'okungaba nobungozi kumvelo',
    '⬆' => 'inkomba phezulu',
    '↗' => 'Inkomba phezulu-kwesokudla',
    '➡' => 'Inkomba kwesokudla',
    '↘' => 'inkombaphansi ngqo',
    '⬇' => 'umcibisholo opheke phansi',
    '↙' => 'umcibisholo obheke phansi kwesokunxele',
    '⬅' => 'inkombasinxele',
    '↖' => 'umcibisholo obheke phezulu kwesokunxele',
    '↕' => 'umcibisholo ophansi phezulu',
    '↔' => 'umcibisholo okwesokunxele nesokudla',
    '↩' => 'umcibisholo okhombe kwesokudla ogobe kwesokunxele',
    '↪' => 'umcibisholo okhombe kwesokunxele ogobe kwesokudla',
    '⤴' => 'umcibisholo wakwesokudla ogobele phezulu',
    '⤵' => 'umcibisholo wakwesokudla ogobele phansi',
    '🔃' => 'imicibisholo ejikelezela ngakwesokudla',
    '🔄' => 'izinkinobho zemicibisholo ejikelezela kwesokunxele',
    '🔙' => 'umcibisholo oya emuva',
    '🔚' => 'umcibisholo wesiphetho',
    '🔛' => 'kuvuliwe! umcibisholo',
    '🔜' => 'umcibisholo wokushesha',
    '🔝' => 'umcibisholo waphezulu',
    '🛐' => 'indawo yokukhonza',
    '⚛' => 'uphawu lokungakhonzi',
    '🕉' => 'om',
    '✡' => 'inkanyezi kadavide',
    '☸' => 'isondo likadharma',
    '☯' => 'yin yang',
    '✝' => 'isiphambano sobulatini',
    '☦' => 'isiphambano senkolo',
    '☪' => 'inkanyezi nocezu lwenyanga',
    '☮' => 'uphawu lokuthula',
    '🕎' => 'imenora',
    '🔯' => 'intanyezi enechashazi ekhombe kasithupha',
    '🪯' => 'khanda',
    '♈' => 'aries',
    '♉' => 'taurus',
    '♊' => 'gemini',
    '♋' => 'cancer',
    '♌' => 'leo',
    '♍' => 'virgo',
    '♎' => 'libra',
    '♏' => 'scorpius',
    '♐' => 'sagittarius',
    '♑' => 'capricorn',
    '♒' => 'aquarius',
    '♓' => 'pisces',
    '⛎' => 'ophiuchus',
    '🔀' => 'inkinobho yokuxuba',
    '🔁' => 'inkinobho yokuphinda',
    '🔂' => 'inkinobho yokuphinda kube kanye',
    '▶' => 'inkinobho yokudlala',
    '⏩' => 'inkinobho yokuya phambili ngokushesha',
    '⏭' => 'inkinobho yokudlala okulandelayo',
    '⏯' => 'inkinobho yokudlala noma ukumisa',
    '◀' => 'inkinobho yokubuyela emuva',
    '⏪' => 'inkinobho yokuhlehla ngokushesha',
    '⏮' => 'inkinobho yeculo lokugcina',
    '🔼' => 'inkinobho ebheke phezulu',
    '⏫' => 'inkinobho yokushesha phambili',
    '🔽' => 'inkinobho eya phansi',
    '⏬' => 'inkinobho eshesha phansi',
    '⏸' => 'inkinobho yokuphumuza',
    '⏹' => 'inkinobho yokumisa',
    '⏺' => 'inkinobho yokuqopha',
    '⏏' => 'inkinobho yokukhipha',
    '🎦' => 'isinema',
    '🔅' => 'inkinobho kadimu',
    '🔆' => 'inkinobho yokukhanya',
    '📶' => 'u-eriyeli',
    '🛜' => 'okungenantambo',
    '📳' => 'isimo sokushukuma',
    '📴' => 'iselula icishiwe',
    '♀' => 'uphawu lowesifazane',
    '♂' => 'upahwu lwendoda',
    '⚧' => 'isimbuli ye-transgender',
    '✖' => 'phindaphinda',
    '➕' => 'hlanganisa',
    '➖' => 'uphawu lokususa oluwugqinsi',
    '➗' => 'uphawu lokwahlukanisa oluwugqinsi',
    '🟰' => 'amasayini asindayo alinganayo',
    '♾' => 'ingunaphakade',
    '‼' => 'uphawu lwesibabazi oluphindekile',
    '⁉' => 'uphawu lombuzo oluyisibabazi',
    '❓' => 'uphawu lombuzo',
    '❔' => 'uphawu lombuzo olumhlophe',
    '❕' => 'uphawu lwesibabazi olumhlophe',
    '❗' => 'uphawu lwesibabazi',
    '〰' => 'udeshi osagagasi',
    '💱' => 'izinga lokushintshanisa imali',
    '💲' => 'uphawu olukhulu lwedola',
    '⚕' => 'uphawu losizo lwezempilo',
    '♻' => 'uphawu lokuvuselela',
    '⚜' => 'i-fleur-de-lis',
    '🔱' => 'uphawu lwensika',
    '📛' => 'ibheji legama',
    '🔰' => 'uphawu lamajapanese lomuntu oqalayo',
    '⭕' => 'indingilizi enkulu oluwugqinsi ebomvu',
    '✅' => 'uphawu lokuhlola okukhulu',
    '☑' => 'ibhokisi lebhalothi elinokuhlola',
    '✔' => 'uphawu lokuhlola oluwugqinsi',
    '❌' => 'uphawu lwesiphambano',
    '❎' => 'inkinobho yophawu lwesiphambano',
    '➰' => 'iluphu egobile',
    '➿' => 'iluphu eligobile eliyimpinda',
    '〽' => 'upahwu lokulungisa ingxenye',
    '✳' => 'inkanyezi enemigxa eyisishiyagalombili',
    '✴' => 'inkanyezi ecije kayisishayagalombili',
    '❇' => 'ukubhanyaza',
    '™' => 'uphawu lokuhweba',
    '🫟' => 'splatter',
    '🔠' => 'ukufaka uhlamvu olukhulu lwesilatini',
    '🔡' => 'ukufaka uhlamvu oluncane lwesilatini',
    '🔢' => 'izinombolo ezifakiwe',
    '🔣' => 'izimpawu ezifakiwe',
    '🔤' => 'ukufaka izinhlamvu zesilatini',
    '🅰' => 'inkinobho ka-a',
    '🆎' => 'inkinobho ka-ab',
    '🅱' => 'inkinobho ka-b',
    '🆑' => 'inkinobho ka-CL',
    '🆒' => 'kupholile okusikwele',
    '🆓' => 'inkinobho loku-FREE',
    'ℹ' => 'umthombo wolwazi',
    '🆔' => 'inkinobho ye-ID',
    'Ⓜ' => 'uhlamvu m olusendingilizini',
    '🆕' => 'inkinobho ENTSHA',
    '🆖' => 'inkinobho ka-NG',
    '🅾' => 'inkinobho o',
    '🆗' => 'OK oyisikwele',
    '🅿' => 'inkinobho yokupaka',
    '🆘' => 'sos oyisikwele',
    '🆙' => 'u-up! inkinobho',
    '🆚' => 'u-vs oyisikwele',
    '🈁' => 'uphawu lokuthi lapha oluyiskwele',
    '🈂' => 'uphawu lokumahhala oluyiskwele',
    '🈷' => 'uphawu lwenyanga oluyiskwele',
    '🈶' => 'uphawu lokungabibikho oluyiskwele',
    '🈯' => 'uphawu lokukhomba ngomunwe oluyiskwele',
    '🉐' => 'uphawu lomtitilizo oluyindingilizi',
    '🈹' => 'uphawu lokuncishiswa kwentengo eliyiskwele',
    '🈚' => 'uphawu lokuphela komkhiqizo eliyiskwele',
    '🈲' => 'uphawu lokwenqatshelwa oluyiskwele',
    '🉑' => 'indingilizi ezungeziwe yokwamukela',
    '🈸' => 'uphawu lokufakiwe oluyiskwele',
    '🈴' => 'uphawu lokuhlanganiwe kwaba isikwele ndawonye',
    '🈳' => 'uphawu lokungabi nalutho oluyiskwele',
    '㊗' => 'uphawu lokuzungeleziwe kokuhalalisa',
    '㊙' => 'uphawu lobumfihlo ezungeziwe',
    '🈺' => 'uphawu okokusebenza okuyisikwele',
    '🈵' => 'uphawu lokugcwala okufakwe kuskwele',
    '🔴' => 'indingilizi ebomvu',
    '🟠' => 'isikokela esi-orintshi',
    '🟡' => 'isikokela esiphuzi',
    '🟢' => 'isikokela esihlaza',
    '🔵' => 'indingilizi eluhlaza sasibhakabhaka',
    '🟣' => 'isikokela esibukhwebezane',
    '🟤' => 'indilinga e-brown',
    '⚫' => 'indingilizi emnyama',
    '⚪' => 'indingilizi emhlophe',
    '🟥' => 'isikwele esibomvu',
    '🟧' => 'isikwele esi-orange',
    '🟨' => 'isikwele esi-yellow',
    '🟩' => 'isikwele esiluhlaza satshani',
    '🟦' => 'isikwele esiluhlaza',
    '🟪' => 'isikwele esiphephuli',
    '🟫' => 'esikwele esi-brown',
    '⬛' => 'iskwele esikhulu esimnyama',
    '⬜' => 'iskwele esimhlophe esikhulu',
    '◼' => 'iskwele esimnyama esimaphakathi',
    '◻' => 'isikwele esimhlophe esimaphakathi',
    '◾' => 'iskwele esimnyama esimaphakathi esincane',
    '◽' => 'iskwele esimhlophe esimaphakathi esincane',
    '▪' => 'iskwele esincane esimnyama',
    '▫' => 'isikwele esimhlophe esincane',
    '🔶' => 'idayimande elukhulu eliphuzu',
    '🔷' => 'idayimande elikhulu eliphuzu sasibhakabhaka',
    '🔸' => 'idayimande eliphuzi elincane',
    '🔹' => 'idayimande eliluhlaza sasibhakabhaka elincane',
    '🔺' => 'unxantathu obomvu obheke phezulu',
    '🔻' => 'unxantathu obomvu obheke phansi',
    '💠' => 'idayimande elingenachashashi',
    '🔘' => 'inkinobho yomsakazo',
    '🔳' => 'inkonobho eyiskwele emhlophe',
    '🔲' => 'inkinobho eyiskwele esimnyama',
    '🏁' => 'ifulegi eliyisikotshi',
    '🚩' => 'ifulegi eliwunxantathu',
    '🎌' => 'amafulegi aphambanayo',
    '🏴' => 'ukundizisa ifulegi elimnyama',
    '🏳' => 'ukundizisa ifulegi elimhlophe',
];
