<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'өбүшүү: адам, адам, акжуумал, буудай жүздүү',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'өбүшүү: адам, адам, акжуумал, орточо',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'өбүшүү: адам, адам, акжуумал, кара тору',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'өбүшүү: адам, адам, акжуумал, кара',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'өбүшүү: адам, адам, буудай жүздүү, акжуумал',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'өбүшүү: адам, адам, буудай жүздүү, орточо',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'өбүшүү: адам, адам, буудай жүздүү, кара тору',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'өбүшүү: адам, адам, буудай жүздүү, кара',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'өбүшүү: адам, адам, орточо, акжуумал',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'өбүшүү: адам, адам, орточо, буудай жүздүү',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'өбүшүү: адам, адам, орточо, кара тору',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'өбүшүү: адам, адам, орточо, кара',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'өбүшүү: адам, адам, кара тору, акжуумал',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'өбүшүү: адам, адам, кара тору, буудай жүздүү',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'өбүшүү: адам, адам, кара тору, орточо',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'өбүшүү: адам, адам, кара тору, кара',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'өбүшүү: адам, адам, кара, акжуумал',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'өбүшүү: адам, адам, кара, буудай жүздүү',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'өбүшүү: адам, адам, кара, орточо',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'өбүшүү: адам, адам, кара, кара тору',
    '👨🏻‍❤‍💋‍👨🏻' => 'өбүшүү: эркек, эркек, акжуумал',
    '👨🏻‍❤‍💋‍👨🏼' => 'өбүшүү: эркек, эркек, акжуумал, буудай жүздүү',
    '👨🏻‍❤‍💋‍👨🏽' => 'өбүшүү: эркек, эркек, акжуумал, орточо',
    '👨🏻‍❤‍💋‍👨🏾' => 'өбүшүү: эркек, эркек, акжуумал, кара тору',
    '👨🏻‍❤‍💋‍👨🏿' => 'өбүшүү: эркек, эркек, акжуумал, кара',
    '👨🏼‍❤‍💋‍👨🏻' => 'өбүшүү: эркек, эркек, буудай жүздүү, акжуумал',
    '👨🏼‍❤‍💋‍👨🏼' => 'өбүшүү: эркек, эркек, буудай жүздүү',
    '👨🏼‍❤‍💋‍👨🏽' => 'өбүшүү: эркек, эркек, буудай жүздүү, орточо',
    '👨🏼‍❤‍💋‍👨🏾' => 'өбүшүү: эркек, эркек, буудай жүздүү, кара тору',
    '👨🏼‍❤‍💋‍👨🏿' => 'өбүшүү: эркек, эркек, буудай жүздүү, кара',
    '👨🏽‍❤‍💋‍👨🏻' => 'өбүшүү: эркек, эркек, орточо, акжуумал',
    '👨🏽‍❤‍💋‍👨🏼' => 'өбүшүү: эркек, эркек, орточо, буудай жүздүү',
    '👨🏽‍❤‍💋‍👨🏽' => 'өбүшүү: эркек, эркек, орточо',
    '👨🏽‍❤‍💋‍👨🏾' => 'өбүшүү: эркек, эркек, орточо, кара тору',
    '👨🏽‍❤‍💋‍👨🏿' => 'өбүшүү: эркек, эркек, орточо, кара',
    '👨🏾‍❤‍💋‍👨🏻' => 'өбүшүү: эркек, эркек, кара тору, акжуумал',
    '👨🏾‍❤‍💋‍👨🏼' => 'өбүшүү: эркек, эркек, кара тору, буудай жүздүү',
    '👨🏾‍❤‍💋‍👨🏽' => 'өбүшүү: эркек, эркек, кара тору, орточо',
    '👨🏾‍❤‍💋‍👨🏾' => 'өбүшүү: эркек, эркек, кара тору',
    '👨🏾‍❤‍💋‍👨🏿' => 'өбүшүү: эркек, эркек, кара тору, кара',
    '👨🏿‍❤‍💋‍👨🏻' => 'өбүшүү: эркек, эркек, кара, акжуумал',
    '👨🏿‍❤‍💋‍👨🏼' => 'өбүшүү: эркек, эркек, кара, буудай жүздүү',
    '👨🏿‍❤‍💋‍👨🏽' => 'өбүшүү: эркек, эркек, кара, орточо',
    '👨🏿‍❤‍💋‍👨🏾' => 'өбүшүү: эркек, эркек, кара, кара тору',
    '👨🏿‍❤‍💋‍👨🏿' => 'өбүшүү: эркек, эркек, кара',
    '👩🏻‍❤‍💋‍👨🏻' => 'өбүшүү: аял, эркек, акжуумал',
    '👩🏻‍❤‍💋‍👨🏼' => 'өбүшүү: аял, эркек, акжуумал, буудай жүздүү',
    '👩🏻‍❤‍💋‍👨🏽' => 'өбүшүү: аял, эркек, акжуумал, орточо',
    '👩🏻‍❤‍💋‍👨🏾' => 'өбүшүү: аял, эркек, акжуумал, кара тору',
    '👩🏻‍❤‍💋‍👨🏿' => 'өбүшүү: аял, эркек, акжуумал, кара',
    '👩🏼‍❤‍💋‍👨🏻' => 'өбүшүү: аял, эркек, буудай жүздүү, акжуумал',
    '👩🏼‍❤‍💋‍👨🏼' => 'өбүшүү: аял, эркек, буудай жүздүү',
    '👩🏼‍❤‍💋‍👨🏽' => 'өбүшүү: аял, эркек, буудай жүздүү, орточо',
    '👩🏼‍❤‍💋‍👨🏾' => 'өбүшүү: аял, эркек, буудай жүздүү, кара тору',
    '👩🏼‍❤‍💋‍👨🏿' => 'өбүшүү: аял, эркек, буудай жүздүү, кара',
    '👩🏽‍❤‍💋‍👨🏻' => 'өбүшүү: аял, эркек, орточо, акжуумал',
    '👩🏽‍❤‍💋‍👨🏼' => 'өбүшүү: аял, эркек, орточо, буудай жүздүү',
    '👩🏽‍❤‍💋‍👨🏽' => 'өбүшүү: аял, эркек, орточо',
    '👩🏽‍❤‍💋‍👨🏾' => 'өбүшүү: аял, эркек, орточо, кара тору',
    '👩🏽‍❤‍💋‍👨🏿' => 'өбүшүү: аял, эркек, орточо, кара',
    '👩🏾‍❤‍💋‍👨🏻' => 'өбүшүү: аял, эркек, кара тору, акжуумал',
    '👩🏾‍❤‍💋‍👨🏼' => 'өбүшүү: аял, эркек, кара тору, буудай жүздүү',
    '👩🏾‍❤‍💋‍👨🏽' => 'өбүшүү: аял, эркек, кара тору, орточо',
    '👩🏾‍❤‍💋‍👨🏾' => 'өбүшүү: аял, эркек, кара тору',
    '👩🏾‍❤‍💋‍👨🏿' => 'өбүшүү: аял, эркек, кара тору, кара',
    '👩🏿‍❤‍💋‍👨🏻' => 'өбүшүү: аял, эркек, кара, акжуумал',
    '👩🏿‍❤‍💋‍👨🏼' => 'өбүшүү: аял, эркек, кара, буудай жүздүү',
    '👩🏿‍❤‍💋‍👨🏽' => 'өбүшүү: аял, эркек, кара, орточо',
    '👩🏿‍❤‍💋‍👨🏾' => 'өбүшүү: аял, эркек, кара, кара тору',
    '👩🏿‍❤‍💋‍👨🏿' => 'өбүшүү: аял, эркек, кара',
    '👩🏻‍❤‍💋‍👩🏻' => 'өбүшүү: аял, аял, акжуумал',
    '👩🏻‍❤‍💋‍👩🏼' => 'өбүшүү: аял, аял, акжуумал, буудай жүздүү',
    '👩🏻‍❤‍💋‍👩🏽' => 'өбүшүү: аял, аял, акжуумал, орточо',
    '👩🏻‍❤‍💋‍👩🏾' => 'өбүшүү: аял, аял, акжуумал, кара тору',
    '👩🏻‍❤‍💋‍👩🏿' => 'өбүшүү: аял, аял, акжуумал, кара',
    '👩🏼‍❤‍💋‍👩🏻' => 'өбүшүү: аял, аял, буудай жүздүү, акжуумал',
    '👩🏼‍❤‍💋‍👩🏼' => 'өбүшүү: аял, аял, буудай жүздүү',
    '👩🏼‍❤‍💋‍👩🏽' => 'өбүшүү: аял, аял, буудай жүздүү, орточо',
    '👩🏼‍❤‍💋‍👩🏾' => 'өбүшүү: аял, аял, буудай жүздүү, кара тору',
    '👩🏼‍❤‍💋‍👩🏿' => 'өбүшүү: аял, аял, буудай жүздүү, кара',
    '👩🏽‍❤‍💋‍👩🏻' => 'өбүшүү: аял, аял, орточо, акжуумал',
    '👩🏽‍❤‍💋‍👩🏼' => 'өбүшүү: аял, аял, орточо, буудай жүздүү',
    '👩🏽‍❤‍💋‍👩🏽' => 'өбүшүү: аял, аял, орточо',
    '👩🏽‍❤‍💋‍👩🏾' => 'өбүшүү: аял, аял, орточо, кара тору',
    '👩🏽‍❤‍💋‍👩🏿' => 'өбүшүү: аял, аял, орточо, кара',
    '👩🏾‍❤‍💋‍👩🏻' => 'өбүшүү: аял, аял, кара тору, акжуумал',
    '👩🏾‍❤‍💋‍👩🏼' => 'өбүшүү: аял, аял, кара тору, буудай жүздүү',
    '👩🏾‍❤‍💋‍👩🏽' => 'өбүшүү: аял, аял, кара тору, орточо',
    '👩🏾‍❤‍💋‍👩🏾' => 'өбүшүү: аял, аял, кара тору',
    '👩🏾‍❤‍💋‍👩🏿' => 'өбүшүү: аял, аял, кара тору, кара',
    '👩🏿‍❤‍💋‍👩🏻' => 'өбүшүү: аял, аял, кара, акжуумал',
    '👩🏿‍❤‍💋‍👩🏼' => 'өбүшүү: аял, аял, кара, буудай жүздүү',
    '👩🏿‍❤‍💋‍👩🏽' => 'өбүшүү: аял, аял, кара, орточо',
    '👩🏿‍❤‍💋‍👩🏾' => 'өбүшүү: аял, аял, кара, кара тору',
    '👩🏿‍❤‍💋‍👩🏿' => 'өбүшүү: аял, аял, кара',
    '🧑🏻‍🫯‍🧑🏼' => 'күрөшчүлөр: акжуумал, буудай жүздүү',
    '🧑🏻‍🫯‍🧑🏽' => 'күрөшчүлөр: акжуумал, орточо',
    '🧑🏻‍🫯‍🧑🏾' => 'күрөшчүлөр: акжуумал, кара тору',
    '🧑🏻‍🫯‍🧑🏿' => 'күрөшчүлөр: акжуумал, кара',
    '🧑🏼‍🫯‍🧑🏻' => 'күрөшчүлөр: буудай жүздүү, акжуумал',
    '🧑🏼‍🫯‍🧑🏽' => 'күрөшчүлөр: буудай жүздүү, орточо',
    '🧑🏼‍🫯‍🧑🏾' => 'күрөшчүлөр: буудай жүздүү, кара тору',
    '🧑🏼‍🫯‍🧑🏿' => 'күрөшчүлөр: буудай жүздүү, кара',
    '🧑🏽‍🫯‍🧑🏻' => 'күрөшчүлөр: орточо, акжуумал',
    '🧑🏽‍🫯‍🧑🏼' => 'күрөшчүлөр: орточо, буудай жүздүү',
    '🧑🏽‍🫯‍🧑🏾' => 'күрөшчүлөр: орточо, кара тору',
    '🧑🏽‍🫯‍🧑🏿' => 'күрөшчүлөр: орточо, кара',
    '🧑🏾‍🫯‍🧑🏻' => 'күрөшчүлөр: кара тору, акжуумал',
    '🧑🏾‍🫯‍🧑🏼' => 'күрөшчүлөр: кара тору, буудай жүздүү',
    '🧑🏾‍🫯‍🧑🏽' => 'күрөшчүлөр: кара тору, орточо',
    '🧑🏾‍🫯‍🧑🏿' => 'күрөшчүлөр: кара тору, кара',
    '🧑🏿‍🫯‍🧑🏻' => 'күрөшчүлөр: кара, акжуумал',
    '🧑🏿‍🫯‍🧑🏼' => 'күрөшчүлөр: кара, буудай жүздүү',
    '🧑🏿‍🫯‍🧑🏽' => 'күрөшчүлөр: кара, орточо',
    '🧑🏿‍🫯‍🧑🏾' => 'күрөшчүлөр: кара, кара тору',
    '🧑🏻‍❤‍🧑🏼' => 'сүйүшкөн түгөйлөр: адам, адам, акжуумал, буудай жүздүү',
    '🧑🏻‍❤‍🧑🏽' => 'сүйүшкөн түгөйлөр: адам, адам, акжуумал, орточо',
    '🧑🏻‍❤‍🧑🏾' => 'сүйүшкөн түгөйлөр: адам, адам, акжуумал, кара тору',
    '🧑🏻‍❤‍🧑🏿' => 'сүйүшкөн түгөйлөр: адам, адам, акжуумал, кара',
    '🧑🏼‍❤‍🧑🏻' => 'сүйүшкөн түгөйлөр: адам, адам, буудай жүздүү, акжуумал',
    '🧑🏼‍❤‍🧑🏽' => 'сүйүшкөн түгөйлөр: адам, адам, буудай жүздүү, орточо',
    '🧑🏼‍❤‍🧑🏾' => 'сүйүшкөн түгөйлөр: адам, адам, буудай жүздүү, кара тору',
    '🧑🏼‍❤‍🧑🏿' => 'сүйүшкөн түгөйлөр: адам, адам, буудай жүздүү, кара',
    '🧑🏽‍❤‍🧑🏻' => 'сүйүшкөн түгөйлөр: адам, адам, орточо, акжуумал',
    '🧑🏽‍❤‍🧑🏼' => 'сүйүшкөн түгөйлөр: адам, адам, орточо, буудай жүздүү',
    '🧑🏽‍❤‍🧑🏾' => 'сүйүшкөн түгөйлөр: адам, адам, орточо, кара тору',
    '🧑🏽‍❤‍🧑🏿' => 'сүйүшкөн түгөйлөр: адам, адам, орточо, кара',
    '🧑🏾‍❤‍🧑🏻' => 'сүйүшкөн түгөйлөр: адам, адам, кара тору, акжуумал',
    '🧑🏾‍❤‍🧑🏼' => 'сүйүшкөн түгөйлөр: адам, адам, кара тору, буудай жүздүү',
    '🧑🏾‍❤‍🧑🏽' => 'сүйүшкөн түгөйлөр: адам, адам, кара тору, орточо',
    '🧑🏾‍❤‍🧑🏿' => 'сүйүшкөн түгөйлөр: адам, адам, кара тору, кара',
    '🧑🏿‍❤‍🧑🏻' => 'сүйүшкөн түгөйлөр: адам, адам, кара, акжуумал',
    '🧑🏿‍❤‍🧑🏼' => 'сүйүшкөн түгөйлөр: адам, адам, кара, буудай жүздүү',
    '🧑🏿‍❤‍🧑🏽' => 'сүйүшкөн түгөйлөр: адам, адам, кара, орточо',
    '🧑🏿‍❤‍🧑🏾' => 'сүйүшкөн түгөйлөр: адам, адам, кара, кара тору',
    '🧑🏻‍🐰‍🧑🏼' => 'кыз-келиндер кечеси: акжуумал, буудай жүздүү',
    '🧑🏻‍🐰‍🧑🏽' => 'кыз-келиндер кечеси: акжуумал, орточо',
    '🧑🏻‍🐰‍🧑🏾' => 'кыз-келиндер кечеси: акжуумал, кара тору',
    '🧑🏻‍🐰‍🧑🏿' => 'кыз-келиндер кечеси: акжуумал, кара',
    '🧑🏼‍🐰‍🧑🏻' => 'кыз-келиндер кечеси: буудай жүздүү, акжуумал',
    '🧑🏼‍🐰‍🧑🏽' => 'кыз-келиндер кечеси: буудай жүздүү, орточо',
    '🧑🏼‍🐰‍🧑🏾' => 'кыз-келиндер кечеси: буудай жүздүү, кара тору',
    '🧑🏼‍🐰‍🧑🏿' => 'кыз-келиндер кечеси: буудай жүздүү, кара',
    '🧑🏽‍🐰‍🧑🏻' => 'кыз-келиндер кечеси: орточо, акжуумал',
    '🧑🏽‍🐰‍🧑🏼' => 'кыз-келиндер кечеси: орточо, буудай жүздүү',
    '🧑🏽‍🐰‍🧑🏾' => 'кыз-келиндер кечеси: орточо, кара тору',
    '🧑🏽‍🐰‍🧑🏿' => 'кыз-келиндер кечеси: орточо, кара',
    '🧑🏾‍🐰‍🧑🏻' => 'кыз-келиндер кечеси: кара тору, акжуумал',
    '🧑🏾‍🐰‍🧑🏼' => 'кыз-келиндер кечеси: кара тору, буудай жүздүү',
    '🧑🏾‍🐰‍🧑🏽' => 'кыз-келиндер кечеси: кара тору, орточо',
    '🧑🏾‍🐰‍🧑🏿' => 'кыз-келиндер кечеси: кара тору, кара',
    '🧑🏿‍🐰‍🧑🏻' => 'кыз-келиндер кечеси: кара, акжуумал',
    '🧑🏿‍🐰‍🧑🏼' => 'кыз-келиндер кечеси: кара, буудай жүздүү',
    '🧑🏿‍🐰‍🧑🏽' => 'кыз-келиндер кечеси: кара, орточо',
    '🧑🏿‍🐰‍🧑🏾' => 'кыз-келиндер кечеси: кара, кара тору',
    '👨🏻‍🫯‍👨🏼' => 'күрөшүп жаткан эркек: акжуумал, буудай жүздүү',
    '👨🏻‍🫯‍👨🏽' => 'күрөшүп жаткан эркек: акжуумал, орточо',
    '👨🏻‍🫯‍👨🏾' => 'күрөшүп жаткан эркек: акжуумал, кара тору',
    '👨🏻‍🫯‍👨🏿' => 'күрөшүп жаткан эркек: акжуумал, кара',
    '👨🏼‍🫯‍👨🏻' => 'күрөшүп жаткан эркек: буудай жүздүү, акжуумал',
    '👨🏼‍🫯‍👨🏽' => 'күрөшүп жаткан эркек: буудай жүздүү, орточо',
    '👨🏼‍🫯‍👨🏾' => 'күрөшүп жаткан эркек: буудай жүздүү, кара тору',
    '👨🏼‍🫯‍👨🏿' => 'күрөшүп жаткан эркек: буудай жүздүү, кара',
    '👨🏽‍🫯‍👨🏻' => 'күрөшүп жаткан эркек: орточо, акжуумал',
    '👨🏽‍🫯‍👨🏼' => 'күрөшүп жаткан эркек: орточо, буудай жүздүү',
    '👨🏽‍🫯‍👨🏾' => 'күрөшүп жаткан эркек: орточо, кара тору',
    '👨🏽‍🫯‍👨🏿' => 'күрөшүп жаткан эркек: орточо, кара',
    '👨🏾‍🫯‍👨🏻' => 'күрөшүп жаткан эркек: кара тору, акжуумал',
    '👨🏾‍🫯‍👨🏼' => 'күрөшүп жаткан эркек: кара тору, буудай жүздүү',
    '👨🏾‍🫯‍👨🏽' => 'күрөшүп жаткан эркек: кара тору, орточо',
    '👨🏾‍🫯‍👨🏿' => 'күрөшүп жаткан эркек: кара тору, кара',
    '👨🏿‍🫯‍👨🏻' => 'күрөшүп жаткан эркек: кара, акжуумал',
    '👨🏿‍🫯‍👨🏼' => 'күрөшүп жаткан эркек: кара, буудай жүздүү',
    '👨🏿‍🫯‍👨🏽' => 'күрөшүп жаткан эркек: кара, орточо',
    '👨🏿‍🫯‍👨🏾' => 'күрөшүп жаткан эркек: кара, кара тору',
    '👨🏻‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: эркек, эркек, акжуумал',
    '👨🏻‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: эркек, эркек, акжуумал, буудай жүздүү',
    '👨🏻‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: эркек, эркек, акжуумал, орточо',
    '👨🏻‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: эркек, эркек, акжуумал, кара тору',
    '👨🏻‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: эркек, эркек, акжуумал, кара',
    '👨🏼‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: эркек, эркек, буудай жүздүү, акжуумал',
    '👨🏼‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: эркек, эркек, буудай жүздүү',
    '👨🏼‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: эркек, эркек, буудай жүздүү, орточо',
    '👨🏼‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: эркек, эркек, буудай жүздүү, кара тору',
    '👨🏼‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: эркек, эркек, буудай жүздүү, кара',
    '👨🏽‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: эркек, эркек, орточо, акжуумал',
    '👨🏽‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: эркек, эркек, орточо, буудай жүздүү',
    '👨🏽‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: эркек, эркек, орточо',
    '👨🏽‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: эркек, эркек, орточо, кара тору',
    '👨🏽‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: эркек, эркек, орточо, кара',
    '👨🏾‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара тору, акжуумал',
    '👨🏾‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара тору, буудай жүздүү',
    '👨🏾‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара тору, орточо',
    '👨🏾‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара тору',
    '👨🏾‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара тору, кара',
    '👨🏿‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара, акжуумал',
    '👨🏿‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара, буудай жүздүү',
    '👨🏿‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара, орточо',
    '👨🏿‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара, кара тору',
    '👨🏿‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: эркек, эркек, кара',
    '👨🏻‍🐰‍👨🏼' => 'коен кулактарын тагынган эркектер: акжуумал, буудай жүздүү',
    '👨🏻‍🐰‍👨🏽' => 'коен кулактарын тагынган эркектер: акжуумал, орточо',
    '👨🏻‍🐰‍👨🏾' => 'коен кулактарын тагынган эркектер: акжуумал, кара тору',
    '👨🏻‍🐰‍👨🏿' => 'коен кулактарын тагынган эркектер: акжуумал, кара',
    '👨🏼‍🐰‍👨🏻' => 'коен кулактарын тагынган эркектер: буудай жүздүү, акжуумал',
    '👨🏼‍🐰‍👨🏽' => 'коен кулактарын тагынган эркектер: буудай жүздүү, орточо',
    '👨🏼‍🐰‍👨🏾' => 'коен кулактарын тагынган эркектер: буудай жүздүү, кара тору',
    '👨🏼‍🐰‍👨🏿' => 'коен кулактарын тагынган эркектер: буудай жүздүү, кара',
    '👨🏽‍🐰‍👨🏻' => 'коен кулактарын тагынган эркектер: орточо, акжуумал',
    '👨🏽‍🐰‍👨🏼' => 'коен кулактарын тагынган эркектер: орточо, буудай жүздүү',
    '👨🏽‍🐰‍👨🏾' => 'коен кулактарын тагынган эркектер: орточо, кара тору',
    '👨🏽‍🐰‍👨🏿' => 'коен кулактарын тагынган эркектер: орточо, кара',
    '👨🏾‍🐰‍👨🏻' => 'коен кулактарын тагынган эркектер: кара тору, акжуумал',
    '👨🏾‍🐰‍👨🏼' => 'коен кулактарын тагынган эркектер: кара тору, буудай жүздүү',
    '👨🏾‍🐰‍👨🏽' => 'коен кулактарын тагынган эркектер: кара тору, орточо',
    '👨🏾‍🐰‍👨🏿' => 'коен кулактарын тагынган эркектер: кара тору, кара',
    '👨🏿‍🐰‍👨🏻' => 'коен кулактарын тагынган эркектер: кара, акжуумал',
    '👨🏿‍🐰‍👨🏼' => 'коен кулактарын тагынган эркектер: кара, буудай жүздүү',
    '👨🏿‍🐰‍👨🏽' => 'коен кулактарын тагынган эркектер: кара, орточо',
    '👨🏿‍🐰‍👨🏾' => 'коен кулактарын тагынган эркектер: кара, кара тору',
    '👩🏻‍🫯‍👩🏼' => 'күрөшүп жаткан аял: акжуумал, буудай жүздүү',
    '👩🏻‍🫯‍👩🏽' => 'күрөшүп жаткан аял: акжуумал, орточо',
    '👩🏻‍🫯‍👩🏾' => 'күрөшүп жаткан аял: акжуумал, кара тору',
    '👩🏻‍🫯‍👩🏿' => 'күрөшүп жаткан аял: акжуумал, кара',
    '👩🏼‍🫯‍👩🏻' => 'күрөшүп жаткан аял: буудай жүздүү, акжуумал',
    '👩🏼‍🫯‍👩🏽' => 'күрөшүп жаткан аял: буудай жүздүү, орточо',
    '👩🏼‍🫯‍👩🏾' => 'күрөшүп жаткан аял: буудай жүздүү, кара тору',
    '👩🏼‍🫯‍👩🏿' => 'күрөшүп жаткан аял: буудай жүздүү, кара',
    '👩🏽‍🫯‍👩🏻' => 'күрөшүп жаткан аял: орточо, акжуумал',
    '👩🏽‍🫯‍👩🏼' => 'күрөшүп жаткан аял: орточо, буудай жүздүү',
    '👩🏽‍🫯‍👩🏾' => 'күрөшүп жаткан аял: орточо, кара тору',
    '👩🏽‍🫯‍👩🏿' => 'күрөшүп жаткан аял: орточо, кара',
    '👩🏾‍🫯‍👩🏻' => 'күрөшүп жаткан аял: кара тору, акжуумал',
    '👩🏾‍🫯‍👩🏼' => 'күрөшүп жаткан аял: кара тору, буудай жүздүү',
    '👩🏾‍🫯‍👩🏽' => 'күрөшүп жаткан аял: кара тору, орточо',
    '👩🏾‍🫯‍👩🏿' => 'күрөшүп жаткан аял: кара тору, кара',
    '👩🏿‍🫯‍👩🏻' => 'күрөшүп жаткан аял: кара, акжуумал',
    '👩🏿‍🫯‍👩🏼' => 'күрөшүп жаткан аял: кара, буудай жүздүү',
    '👩🏿‍🫯‍👩🏽' => 'күрөшүп жаткан аял: кара, орточо',
    '👩🏿‍🫯‍👩🏾' => 'күрөшүп жаткан аял: кара, кара тору',
    '👩🏻‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: аял, эркек, акжуумал',
    '👩🏻‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: аял, эркек, акжуумал, буудай жүздүү',
    '👩🏻‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: аял, эркек, акжуумал, орточо',
    '👩🏻‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: аял, эркек, акжуумал, кара тору',
    '👩🏻‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: аял, эркек, акжуумал, кара',
    '👩🏼‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: аял, эркек, буудай жүздүү, акжуумал',
    '👩🏼‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: аял, эркек, буудай жүздүү',
    '👩🏼‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: аял, эркек, буудай жүздүү, орточо',
    '👩🏼‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: аял, эркек, буудай жүздүү, кара тору',
    '👩🏼‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: аял, эркек, буудай жүздүү, кара',
    '👩🏽‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: аял, эркек, орточо, акжуумал',
    '👩🏽‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: аял, эркек, орточо, буудай жүздүү',
    '👩🏽‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: аял, эркек, орточо',
    '👩🏽‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: аял, эркек, орточо, кара тору',
    '👩🏽‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: аял, эркек, орточо, кара',
    '👩🏾‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: аял, эркек, кара тору, акжуумал',
    '👩🏾‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: аял, эркек, кара тору, буудай жүздүү',
    '👩🏾‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: аял, эркек, кара тору, орточо',
    '👩🏾‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: аял, эркек, кара тору',
    '👩🏾‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: аял, эркек, кара тору, кара',
    '👩🏿‍❤‍👨🏻' => 'сүйүшкөн түгөйлөр: аял, эркек, кара, акжуумал',
    '👩🏿‍❤‍👨🏼' => 'сүйүшкөн түгөйлөр: аял, эркек, кара, буудай жүздүү',
    '👩🏿‍❤‍👨🏽' => 'сүйүшкөн түгөйлөр: аял, эркек, кара, орточо',
    '👩🏿‍❤‍👨🏾' => 'сүйүшкөн түгөйлөр: аял, эркек, кара, кара тору',
    '👩🏿‍❤‍👨🏿' => 'сүйүшкөн түгөйлөр: аял, эркек, кара',
    '👩🏻‍❤‍👩🏻' => 'сүйүшкөн түгөйлөр: аял, аял, акжуумал',
    '👩🏻‍❤‍👩🏼' => 'сүйүшкөн түгөйлөр: аял, аял, акжуумал, буудай жүздүү',
    '👩🏻‍❤‍👩🏽' => 'сүйүшкөн түгөйлөр: аял, аял, акжуумал, орточо',
    '👩🏻‍❤‍👩🏾' => 'сүйүшкөн түгөйлөр: аял, аял, акжуумал, кара тору',
    '👩🏻‍❤‍👩🏿' => 'сүйүшкөн түгөйлөр: аял, аял, акжуумал, кара',
    '👩🏼‍❤‍👩🏻' => 'сүйүшкөн түгөйлөр: аял, аял, буудай жүздүү, акжуумал',
    '👩🏼‍❤‍👩🏼' => 'сүйүшкөн түгөйлөр: аял, аял, буудай жүздүү',
    '👩🏼‍❤‍👩🏽' => 'сүйүшкөн түгөйлөр: аял, аял, буудай жүздүү, орточо',
    '👩🏼‍❤‍👩🏾' => 'сүйүшкөн түгөйлөр: аял, аял, буудай жүздүү, кара тору',
    '👩🏼‍❤‍👩🏿' => 'сүйүшкөн түгөйлөр: аял, аял, буудай жүздүү, кара',
    '👩🏽‍❤‍👩🏻' => 'сүйүшкөн түгөйлөр: аял, аял, орточо, акжуумал',
    '👩🏽‍❤‍👩🏼' => 'сүйүшкөн түгөйлөр: аял, аял, орточо, буудай жүздүү',
    '👩🏽‍❤‍👩🏽' => 'сүйүшкөн түгөйлөр: аял, аял, орточо',
    '👩🏽‍❤‍👩🏾' => 'сүйүшкөн түгөйлөр: аял, аял, орточо, кара тору',
    '👩🏽‍❤‍👩🏿' => 'сүйүшкөн түгөйлөр: аял, аял, орточо, кара',
    '👩🏾‍❤‍👩🏻' => 'сүйүшкөн түгөйлөр: аял, аял, кара тору, акжуумал',
    '👩🏾‍❤‍👩🏼' => 'сүйүшкөн түгөйлөр: аял, аял, кара тору, буудай жүздүү',
    '👩🏾‍❤‍👩🏽' => 'сүйүшкөн түгөйлөр: аял, аял, кара тору, орточо',
    '👩🏾‍❤‍👩🏾' => 'сүйүшкөн түгөйлөр: аял, аял, кара тору',
    '👩🏾‍❤‍👩🏿' => 'сүйүшкөн түгөйлөр: аял, аял, кара тору, кара',
    '👩🏿‍❤‍👩🏻' => 'сүйүшкөн түгөйлөр: аял, аял, кара, акжуумал',
    '👩🏿‍❤‍👩🏼' => 'сүйүшкөн түгөйлөр: аял, аял, кара, буудай жүздүү',
    '👩🏿‍❤‍👩🏽' => 'сүйүшкөн түгөйлөр: аял, аял, кара, орточо',
    '👩🏿‍❤‍👩🏾' => 'сүйүшкөн түгөйлөр: аял, аял, кара, кара тору',
    '👩🏿‍❤‍👩🏿' => 'сүйүшкөн түгөйлөр: аял, аял, кара',
    '👩🏻‍🐰‍👩🏼' => 'коен кулактарын тагынган кыздар: акжуумал, буудай жүздүү',
    '👩🏻‍🐰‍👩🏽' => 'коен кулактарын тагынган кыздар: акжуумал, орточо',
    '👩🏻‍🐰‍👩🏾' => 'коен кулактарын тагынган кыздар: акжуумал, кара тору',
    '👩🏻‍🐰‍👩🏿' => 'коен кулактарын тагынган кыздар: акжуумал, кара',
    '👩🏼‍🐰‍👩🏻' => 'коен кулактарын тагынган кыздар: буудай жүздүү, акжуумал',
    '👩🏼‍🐰‍👩🏽' => 'коен кулактарын тагынган кыздар: буудай жүздүү, орточо',
    '👩🏼‍🐰‍👩🏾' => 'коен кулактарын тагынган кыздар: буудай жүздүү, кара тору',
    '👩🏼‍🐰‍👩🏿' => 'коен кулактарын тагынган кыздар: буудай жүздүү, кара',
    '👩🏽‍🐰‍👩🏻' => 'коен кулактарын тагынган кыздар: орточо, акжуумал',
    '👩🏽‍🐰‍👩🏼' => 'коен кулактарын тагынган кыздар: орточо, буудай жүздүү',
    '👩🏽‍🐰‍👩🏾' => 'коен кулактарын тагынган кыздар: орточо, кара тору',
    '👩🏽‍🐰‍👩🏿' => 'коен кулактарын тагынган кыздар: орточо, кара',
    '👩🏾‍🐰‍👩🏻' => 'коен кулактарын тагынган кыздар: кара тору, акжуумал',
    '👩🏾‍🐰‍👩🏼' => 'коен кулактарын тагынган кыздар: кара тору, буудай жүздүү',
    '👩🏾‍🐰‍👩🏽' => 'коен кулактарын тагынган кыздар: кара тору, орточо',
    '👩🏾‍🐰‍👩🏿' => 'коен кулактарын тагынган кыздар: кара тору, кара',
    '👩🏿‍🐰‍👩🏻' => 'коен кулактарын тагынган кыздар: кара, акжуумал',
    '👩🏿‍🐰‍👩🏼' => 'коен кулактарын тагынган кыздар: кара, буудай жүздүү',
    '👩🏿‍🐰‍👩🏽' => 'коен кулактарын тагынган кыздар: кара, орточо',
    '👩🏿‍🐰‍👩🏾' => 'коен кулактарын тагынган кыздар: кара, кара тору',
    '🧑🏻‍🤝‍🧑🏻' => 'кол кармашкан адамдар: акжуумал',
    '🧑🏻‍🤝‍🧑🏼' => 'кол кармашкан адамдар: акжуумал, буудай жүздүү',
    '🧑🏻‍🤝‍🧑🏽' => 'кол кармашкан адамдар: акжуумал, орточо',
    '🧑🏻‍🤝‍🧑🏾' => 'кол кармашкан адамдар: акжуумал, кара тору',
    '🧑🏻‍🤝‍🧑🏿' => 'кол кармашкан адамдар: акжуумал, кара',
    '🧑🏼‍🤝‍🧑🏻' => 'кол кармашкан адамдар: буудай жүздүү, акжуумал',
    '🧑🏼‍🤝‍🧑🏼' => 'кол кармашкан адамдар: буудай жүздүү',
    '🧑🏼‍🤝‍🧑🏽' => 'кол кармашкан адамдар: буудай жүздүү, орточо',
    '🧑🏼‍🤝‍🧑🏾' => 'кол кармашкан адамдар: буудай жүздүү, кара тору',
    '🧑🏼‍🤝‍🧑🏿' => 'кол кармашкан адамдар: буудай жүздүү, кара',
    '🧑🏽‍🤝‍🧑🏻' => 'кол кармашкан адамдар: орточо, акжуумал',
    '🧑🏽‍🤝‍🧑🏼' => 'кол кармашкан адамдар: орточо, буудай жүздүү',
    '🧑🏽‍🤝‍🧑🏽' => 'кол кармашкан адамдар: орточо',
    '🧑🏽‍🤝‍🧑🏾' => 'кол кармашкан адамдар: орточо, кара тору',
    '🧑🏽‍🤝‍🧑🏿' => 'кол кармашкан адамдар: орточо, кара',
    '🧑🏾‍🤝‍🧑🏻' => 'кол кармашкан адамдар: кара тору, акжуумал',
    '🧑🏾‍🤝‍🧑🏼' => 'кол кармашкан адамдар: кара тору, буудай жүздүү',
    '🧑🏾‍🤝‍🧑🏽' => 'кол кармашкан адамдар: кара тору, орточо',
    '🧑🏾‍🤝‍🧑🏾' => 'кол кармашкан адамдар: кара тору',
    '🧑🏾‍🤝‍🧑🏿' => 'кол кармашкан адамдар: кара тору, кара',
    '🧑🏿‍🤝‍🧑🏻' => 'кол кармашкан адамдар: кара, акжуумал',
    '🧑🏿‍🤝‍🧑🏼' => 'кол кармашкан адамдар: кара, буудай жүздүү',
    '🧑🏿‍🤝‍🧑🏽' => 'кол кармашкан адамдар: кара, орточо',
    '🧑🏿‍🤝‍🧑🏾' => 'кол кармашкан адамдар: кара, кара тору',
    '🧑🏿‍🤝‍🧑🏿' => 'кол кармашкан адамдар: кара',
    '👩🏻‍🤝‍👩🏼' => 'кол кармашкан эки аял: акжуумал, буудай жүздүү',
    '👩🏻‍🤝‍👩🏽' => 'кол кармашкан эки аял: акжуумал, орточо',
    '👩🏻‍🤝‍👩🏾' => 'кол кармашкан эки аял: акжуумал, кара тору',
    '👩🏻‍🤝‍👩🏿' => 'кол кармашкан эки аял: акжуумал, кара',
    '👩🏼‍🤝‍👩🏻' => 'кол кармашкан эки аял: буудай жүздүү, акжуумал',
    '👩🏼‍🤝‍👩🏽' => 'кол кармашкан эки аял: буудай жүздүү, орточо',
    '👩🏼‍🤝‍👩🏾' => 'кол кармашкан эки аял: буудай жүздүү, кара тору',
    '👩🏼‍🤝‍👩🏿' => 'кол кармашкан эки аял: буудай жүздүү, кара',
    '👩🏽‍🤝‍👩🏻' => 'кол кармашкан эки аял: орточо, акжуумал',
    '👩🏽‍🤝‍👩🏼' => 'кол кармашкан эки аял: орточо, буудай жүздүү',
    '👩🏽‍🤝‍👩🏾' => 'кол кармашкан эки аял: орточо, кара тору',
    '👩🏽‍🤝‍👩🏿' => 'кол кармашкан эки аял: орточо, кара',
    '👩🏾‍🤝‍👩🏻' => 'кол кармашкан эки аял: кара тору, акжуумал',
    '👩🏾‍🤝‍👩🏼' => 'кол кармашкан эки аял: кара тору, буудай жүздүү',
    '👩🏾‍🤝‍👩🏽' => 'кол кармашкан эки аял: кара тору, орточо',
    '👩🏾‍🤝‍👩🏿' => 'кол кармашкан эки аял: кара тору, кара',
    '👩🏿‍🤝‍👩🏻' => 'кол кармашкан эки аял: кара, акжуумал',
    '👩🏿‍🤝‍👩🏼' => 'кол кармашкан эки аял: кара, буудай жүздүү',
    '👩🏿‍🤝‍👩🏽' => 'кол кармашкан эки аял: кара, орточо',
    '👩🏿‍🤝‍👩🏾' => 'кол кармашкан эки аял: кара, кара тору',
    '👩🏻‍🤝‍👨🏼' => 'кол кармашкан эркек менен аял: акжуумал, буудай жүздүү',
    '👩🏻‍🤝‍👨🏽' => 'кол кармашкан эркек менен аял: акжуумал, орточо',
    '👩🏻‍🤝‍👨🏾' => 'кол кармашкан эркек менен аял: акжуумал, кара тору',
    '👩🏻‍🤝‍👨🏿' => 'кол кармашкан эркек менен аял: акжуумал, кара',
    '👩🏼‍🤝‍👨🏻' => 'кол кармашкан эркек менен аял: буудай жүздүү, акжуумал',
    '👩🏼‍🤝‍👨🏽' => 'кол кармашкан эркек менен аял: буудай жүздүү, орточо',
    '👩🏼‍🤝‍👨🏾' => 'кол кармашкан эркек менен аял: буудай жүздүү, кара тору',
    '👩🏼‍🤝‍👨🏿' => 'кол кармашкан эркек менен аял: буудай жүздүү, кара',
    '👩🏽‍🤝‍👨🏻' => 'кол кармашкан эркек менен аял: орточо, акжуумал',
    '👩🏽‍🤝‍👨🏼' => 'кол кармашкан эркек менен аял: орточо, буудай жүздүү',
    '👩🏽‍🤝‍👨🏾' => 'кол кармашкан эркек менен аял: орточо, кара тору',
    '👩🏽‍🤝‍👨🏿' => 'кол кармашкан эркек менен аял: орточо, кара',
    '👩🏾‍🤝‍👨🏻' => 'кол кармашкан эркек менен аял: кара тору, акжуумал',
    '👩🏾‍🤝‍👨🏼' => 'кол кармашкан эркек менен аял: кара тору, буудай жүздүү',
    '👩🏾‍🤝‍👨🏽' => 'кол кармашкан эркек менен аял: кара тору, орточо',
    '👩🏾‍🤝‍👨🏿' => 'кол кармашкан эркек менен аял: кара тору, кара',
    '👩🏿‍🤝‍👨🏻' => 'кол кармашкан эркек менен аял: кара, акжуумал',
    '👩🏿‍🤝‍👨🏼' => 'кол кармашкан эркек менен аял: кара, буудай жүздүү',
    '👩🏿‍🤝‍👨🏽' => 'кол кармашкан эркек менен аял: кара, орточо',
    '👩🏿‍🤝‍👨🏾' => 'кол кармашкан эркек менен аял: кара, кара тору',
    '👨🏻‍🤝‍👨🏼' => 'кол кармашкан эки киши: акжуумал, буудай жүздүү',
    '👨🏻‍🤝‍👨🏽' => 'кол кармашкан эки киши: акжуумал, орточо',
    '👨🏻‍🤝‍👨🏾' => 'кол кармашкан эки киши: акжуумал, кара тору',
    '👨🏻‍🤝‍👨🏿' => 'кол кармашкан эки киши: акжуумал, кара',
    '👨🏼‍🤝‍👨🏻' => 'кол кармашкан эки киши: буудай жүздүү, акжуумал',
    '👨🏼‍🤝‍👨🏽' => 'кол кармашкан эки киши: буудай жүздүү, орточо',
    '👨🏼‍🤝‍👨🏾' => 'кол кармашкан эки киши: буудай жүздүү, кара тору',
    '👨🏼‍🤝‍👨🏿' => 'кол кармашкан эки киши: буудай жүздүү, кара',
    '👨🏽‍🤝‍👨🏻' => 'кол кармашкан эки киши: орточо, акжуумал',
    '👨🏽‍🤝‍👨🏼' => 'кол кармашкан эки киши: орточо, буудай жүздүү',
    '👨🏽‍🤝‍👨🏾' => 'кол кармашкан эки киши: орточо, кара тору',
    '👨🏽‍🤝‍👨🏿' => 'кол кармашкан эки киши: орточо, кара',
    '👨🏾‍🤝‍👨🏻' => 'кол кармашкан эки киши: кара тору, акжуумал',
    '👨🏾‍🤝‍👨🏼' => 'кол кармашкан эки киши: кара тору, буудай жүздүү',
    '👨🏾‍🤝‍👨🏽' => 'кол кармашкан эки киши: кара тору, орточо',
    '👨🏾‍🤝‍👨🏿' => 'кол кармашкан эки киши: кара тору, кара',
    '👨🏿‍🤝‍👨🏻' => 'кол кармашкан эки киши: кара, акжуумал',
    '👨🏿‍🤝‍👨🏼' => 'кол кармашкан эки киши: кара, буудай жүздүү',
    '👨🏿‍🤝‍👨🏽' => 'кол кармашкан эки киши: кара, орточо',
    '👨🏿‍🤝‍👨🏾' => 'кол кармашкан эки киши: кара, кара тору',
    '👩‍❤‍💋‍👨' => 'өбүшүү: аял, эркек',
    '👨‍❤‍💋‍👨' => 'өбүшүү: эркек, эркек',
    '👩‍❤‍💋‍👩' => 'өбүшүү: аял, аял',
    '👨‍👩‍👧‍👦' => 'үй-бүлө: эркек, аял, кыз, бала',
    '👨‍👩‍👦‍👦' => 'үй-бүлө: эркек, аял, бала, бала',
    '👨‍👩‍👧‍👧' => 'үй-бүлө: эркек, аял, кыз, кыз',
    '👨‍👨‍👧‍👦' => 'үй-бүлө: эркек, эркек, кыз, бала',
    '👨‍👨‍👦‍👦' => 'үй-бүлө: эркек, эркек, бала, бала',
    '👨‍👨‍👧‍👧' => 'үй-бүлө: эркек, эркек, кыз, кыз',
    '👩‍👩‍👧‍👦' => 'үй-бүлө: аял, аял, кыз, бала',
    '👩‍👩‍👦‍👦' => 'үй-бүлө: аял, аял, бала, бала',
    '👩‍👩‍👧‍👧' => 'үй-бүлө: аял, аял, кыз, кыз',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'желек: Англия',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'желек: Шотландия',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'желек: Вельс',
    '🧑‍🧑‍🧒‍🧒' => 'үй-бүлө: чоң киши, чоң киши, бала, бала',
    '🚶🏻‍♀‍➡' => 'жөө басып бара жаткан аял: акжуумал, оңду карап турат',
    '🚶🏼‍♀‍➡' => 'жөө басып бара жаткан аял: буудай жүздүү, оңду карап турат',
    '🚶🏽‍♀‍➡' => 'жөө басып бара жаткан аял: орточо, оңду карап турат',
    '🚶🏾‍♀‍➡' => 'жөө басып бара жаткан аял: кара тору, оңду карап турат',
    '🚶🏿‍♀‍➡' => 'жөө басып бара жаткан аял: кара, оңду карап турат',
    '🚶🏻‍♂‍➡' => 'жөө басып бара жаткан эркек: акжуумал, оңду карап турат',
    '🚶🏼‍♂‍➡' => 'жөө басып бара жаткан эркек: буудай жүздүү, оңду карап турат',
    '🚶🏽‍♂‍➡' => 'жөө басып бара жаткан эркек: орточо, оңду карап турат',
    '🚶🏾‍♂‍➡' => 'жөө басып бара жаткан эркек: кара тору, оңду карап турат',
    '🚶🏿‍♂‍➡' => 'жөө басып бара жаткан эркек: кара, оңду карап турат',
    '🧎🏻‍♀‍➡' => 'аял тизелөөдө: акжуумал, оңду карап турат',
    '🧎🏼‍♀‍➡' => 'аял тизелөөдө: буудай жүздүү, оңду карап турат',
    '🧎🏽‍♀‍➡' => 'аял тизелөөдө: орточо, оңду карап турат',
    '🧎🏾‍♀‍➡' => 'аял тизелөөдө: кара тору, оңду карап турат',
    '🧎🏿‍♀‍➡' => 'аял тизелөөдө: кара, оңду карап турат',
    '🧎🏻‍♂‍➡' => 'тизелеген киши: акжуумал, оңду карап турат',
    '🧎🏼‍♂‍➡' => 'тизелеген киши: буудай жүздүү, оңду карап турат',
    '🧎🏽‍♂‍➡' => 'тизелеген киши: орточо, оңду карап турат',
    '🧎🏾‍♂‍➡' => 'тизелеген киши: кара тору, оңду карап турат',
    '🧎🏿‍♂‍➡' => 'тизелеген киши: кара, оңду карап турат',
    '🧑🏻‍🦯‍➡' => 'таякка жөлөнгөн киши: акжуумал, оңду карап турат',
    '🧑🏼‍🦯‍➡' => 'таякка жөлөнгөн киши: буудай жүздүү, оңду карап турат',
    '🧑🏽‍🦯‍➡' => 'таякка жөлөнгөн киши: орточо, оңду карап турат',
    '🧑🏾‍🦯‍➡' => 'таякка жөлөнгөн киши: кара тору, оңду карап турат',
    '🧑🏿‍🦯‍➡' => 'таякка жөлөнгөн киши: кара, оңду карап турат',
    '👨🏻‍🦯‍➡' => 'таяк таянган киши: акжуумал, оңду карап турат',
    '👨🏼‍🦯‍➡' => 'таяк таянган киши: буудай жүздүү, оңду карап турат',
    '👨🏽‍🦯‍➡' => 'таяк таянган киши: орточо, оңду карап турат',
    '👨🏾‍🦯‍➡' => 'таяк таянган киши: кара тору, оңду карап турат',
    '👨🏿‍🦯‍➡' => 'таяк таянган киши: кара, оңду карап турат',
    '👩🏻‍🦯‍➡' => 'таяк таянган аял: акжуумал, оңду карап турат',
    '👩🏼‍🦯‍➡' => 'таяк таянган аял: буудай жүздүү, оңду карап турат',
    '👩🏽‍🦯‍➡' => 'таяк таянган аял: орточо, оңду карап турат',
    '👩🏾‍🦯‍➡' => 'таяк таянган аял: кара тору, оңду карап турат',
    '👩🏿‍🦯‍➡' => 'таяк таянган аял: кара, оңду карап турат',
    '🧑🏻‍🦼‍➡' => 'мотору бар инвалид креслосундагы киши: акжуумал, оңду карап турат',
    '🧑🏼‍🦼‍➡' => 'мотору бар инвалид креслосундагы киши: буудай жүздүү, оңду карап турат',
    '🧑🏽‍🦼‍➡' => 'мотору бар инвалид креслосундагы киши: орточо, оңду карап турат',
    '🧑🏾‍🦼‍➡' => 'мотору бар инвалид креслосундагы киши: кара тору, оңду карап турат',
    '🧑🏿‍🦼‍➡' => 'мотору бар инвалид креслосундагы киши: кара, оңду карап турат',
    '👨🏻‍🦼‍➡' => 'моторлуу дөңгөлөк отургучтагы киши: акжуумал, оңду карап турат',
    '👨🏼‍🦼‍➡' => 'моторлуу дөңгөлөк отургучтагы киши: буудай жүздүү, оңду карап турат',
    '👨🏽‍🦼‍➡' => 'моторлуу дөңгөлөк отургучтагы киши: орточо, оңду карап турат',
    '👨🏾‍🦼‍➡' => 'моторлуу дөңгөлөк отургучтагы киши: кара тору, оңду карап турат',
    '👨🏿‍🦼‍➡' => 'моторлуу дөңгөлөк отургучтагы киши: кара, оңду карап турат',
    '👩🏻‍🦼‍➡' => 'мотору бар дөңгөлөктүү отургучтагы аял: акжуумал, оңду карап турат',
    '👩🏼‍🦼‍➡' => 'мотору бар дөңгөлөктүү отургучтагы аял: буудай жүздүү, оңду карап турат',
    '👩🏽‍🦼‍➡' => 'мотору бар дөңгөлөктүү отургучтагы аял: орточо, оңду карап турат',
    '👩🏾‍🦼‍➡' => 'мотору бар дөңгөлөктүү отургучтагы аял: кара тору, оңду карап турат',
    '👩🏿‍🦼‍➡' => 'мотору бар дөңгөлөктүү отургучтагы аял: кара, оңду карап турат',
    '🧑🏻‍🦽‍➡' => 'кол менен иштеген кресло: акжуумал, оңду карап турат',
    '🧑🏼‍🦽‍➡' => 'кол менен иштеген кресло: буудай жүздүү, оңду карап турат',
    '🧑🏽‍🦽‍➡' => 'кол менен иштеген кресло: орточо, оңду карап турат',
    '🧑🏾‍🦽‍➡' => 'кол менен иштеген кресло: кара тору, оңду карап турат',
    '🧑🏿‍🦽‍➡' => 'кол менен иштеген кресло: кара, оңду карап турат',
    '👨🏻‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы киши: акжуумал, оңду карап турат',
    '👨🏼‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы киши: буудай жүздүү, оңду карап турат',
    '👨🏽‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы киши: орточо, оңду карап турат',
    '👨🏾‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы киши: кара тору, оңду карап турат',
    '👨🏿‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы киши: кара, оңду карап турат',
    '👩🏻‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы аял: акжуумал, оңду карап турат',
    '👩🏼‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы аял: буудай жүздүү, оңду карап турат',
    '👩🏽‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы аял: орточо, оңду карап турат',
    '👩🏾‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы аял: кара тору, оңду карап турат',
    '👩🏿‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы аял: кара, оңду карап турат',
    '🏃🏻‍♀‍➡' => 'чуркап бара жаткан аял: акжуумал, оңду карап турат',
    '🏃🏼‍♀‍➡' => 'чуркап бара жаткан аял: буудай жүздүү, оңду карап турат',
    '🏃🏽‍♀‍➡' => 'чуркап бара жаткан аял: орточо, оңду карап турат',
    '🏃🏾‍♀‍➡' => 'чуркап бара жаткан аял: кара тору, оңду карап турат',
    '🏃🏿‍♀‍➡' => 'чуркап бара жаткан аял: кара, оңду карап турат',
    '🏃🏻‍♂‍➡' => 'чуркап бара жаткан эркек: акжуумал, оңду карап турат',
    '🏃🏼‍♂‍➡' => 'чуркап бара жаткан эркек: буудай жүздүү, оңду карап турат',
    '🏃🏽‍♂‍➡' => 'чуркап бара жаткан эркек: орточо, оңду карап турат',
    '🏃🏾‍♂‍➡' => 'чуркап бара жаткан эркек: кара тору, оңду карап турат',
    '🏃🏿‍♂‍➡' => 'чуркап бара жаткан эркек: кара, оңду карап турат',
    '🫱🏻‍🫲🏼' => 'кол алышуу: акжуумал, буудай жүздүү',
    '🫱🏻‍🫲🏽' => 'кол алышуу: акжуумал, орточо',
    '🫱🏻‍🫲🏾' => 'кол алышуу: акжуумал, кара тору',
    '🫱🏻‍🫲🏿' => 'кол алышуу: акжуумал, кара',
    '🫱🏼‍🫲🏻' => 'кол алышуу: буудай жүздүү, акжуумал',
    '🫱🏼‍🫲🏽' => 'кол алышуу: буудай жүздүү, орточо',
    '🫱🏼‍🫲🏾' => 'кол алышуу: буудай жүздүү, кара тору',
    '🫱🏼‍🫲🏿' => 'кол алышуу: буудай жүздүү, кара',
    '🫱🏽‍🫲🏻' => 'кол алышуу: орточо, акжуумал',
    '🫱🏽‍🫲🏼' => 'кол алышуу: орточо, буудай жүздүү',
    '🫱🏽‍🫲🏾' => 'кол алышуу: орточо, кара тору',
    '🫱🏽‍🫲🏿' => 'кол алышуу: орточо, кара',
    '🫱🏾‍🫲🏻' => 'кол алышуу: кара тору, акжуумал',
    '🫱🏾‍🫲🏼' => 'кол алышуу: кара тору, буудай жүздүү',
    '🫱🏾‍🫲🏽' => 'кол алышуу: кара тору, орточо',
    '🫱🏾‍🫲🏿' => 'кол алышуу: кара тору, кара',
    '🫱🏿‍🫲🏻' => 'кол алышуу: кара, акжуумал',
    '🫱🏿‍🫲🏼' => 'кол алышуу: кара, буудай жүздүү',
    '🫱🏿‍🫲🏽' => 'кол алышуу: кара, орточо',
    '🫱🏿‍🫲🏾' => 'кол алышуу: кара, кара тору',
    '🚶‍♀‍➡' => 'жөө басып бара жаткан аял: оңду карап турат',
    '🚶‍♂‍➡' => 'жөө басып бара жаткан эркек: оңду карап турат',
    '🧎‍♀‍➡' => 'аял тизелөөдө: оңду карап турат',
    '🧎‍♂‍➡' => 'тизелеген киши: оңду карап турат',
    '🧑‍🦯‍➡' => 'таякка жөлөнгөн киши: оңду карап турат',
    '👨‍🦯‍➡' => 'таяк таянган киши: оңду карап турат',
    '👩‍🦯‍➡' => 'таяк таянган аял: оңду карап турат',
    '🧑‍🦼‍➡' => 'мотору бар инвалид креслосундагы киши: оңду карап турат',
    '👨‍🦼‍➡' => 'моторлуу дөңгөлөк отургучтагы киши: оңду карап турат',
    '👩‍🦼‍➡' => 'мотору бар дөңгөлөктүү отургучтагы аял: оңду карап турат',
    '🧑‍🦽‍➡' => 'кол менен иштеген кресло: оңду карап турат',
    '👨‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы киши: оңду карап турат',
    '👩‍🦽‍➡' => 'кол менен дөңгөлөктүү отургучтагы аял: оңду карап турат',
    '🏃‍♀‍➡' => 'чуркап бара жаткан аял: оңду карап турат',
    '🏃‍♂‍➡' => 'чуркап бара жаткан эркек: оңду карап турат',
    '👩‍❤‍👨' => 'сүйүшкөн түгөйлөр: аял, эркек',
    '👨‍❤‍👨' => 'сүйүшкөн түгөйлөр: эркек, эркек',
    '👩‍❤‍👩' => 'сүйүшкөн түгөйлөр: аял, аял',
    '👨‍👩‍👦' => 'үй-бүлө: эркек, аял, бала',
    '👨‍👩‍👧' => 'үй-бүлө: эркек, аял, кыз',
    '👨‍👨‍👦' => 'үй-бүлө: эркек, эркек, бала',
    '👨‍👨‍👧' => 'үй-бүлө: эркек, эркек, кыз',
    '👩‍👩‍👦' => 'үй-бүлө: аял, аял, бала',
    '👩‍👩‍👧' => 'үй-бүлө: аял, аял, кыз',
    '👨‍👦‍👦' => 'үй-бүлө: эркек, бала, бала',
    '👨‍👧‍👦' => 'үй-бүлө: эркек, кыз, бала',
    '👨‍👧‍👧' => 'үй-бүлө: эркек, кыз, кыз',
    '👩‍👦‍👦' => 'үй-бүлө: аял, бала, бала',
    '👩‍👧‍👦' => 'үй-бүлө: аял, кыз, бала',
    '👩‍👧‍👧' => 'үй-бүлө: аял, кыз, кыз',
    '🧑‍🤝‍🧑' => 'кол кармашкан адамдар',
    '🧑‍🧑‍🧒' => 'үй-бүлө: чоң киши, чоң киши, бала',
    '🧑‍🧒‍🧒' => 'үй-бүлө: чоң киши, бала, бала',
    '🧑🏻‍🦰' => 'адам: акжуумал, кызыл чач',
    '🧑🏼‍🦰' => 'адам: буудай жүздүү, кызыл чач',
    '🧑🏽‍🦰' => 'адам: орточо, кызыл чач',
    '🧑🏾‍🦰' => 'адам: кара тору, кызыл чач',
    '🧑🏿‍🦰' => 'адам: кара, кызыл чач',
    '🧑🏻‍🦱' => 'адам: акжуумал, тармал чач',
    '🧑🏼‍🦱' => 'адам: буудай жүздүү, тармал чач',
    '🧑🏽‍🦱' => 'адам: орточо, тармал чач',
    '🧑🏾‍🦱' => 'адам: кара тору, тармал чач',
    '🧑🏿‍🦱' => 'адам: кара, тармал чач',
    '🧑🏻‍🦳' => 'адам: акжуумал, ак чач',
    '🧑🏼‍🦳' => 'адам: буудай жүздүү, ак чач',
    '🧑🏽‍🦳' => 'адам: орточо, ак чач',
    '🧑🏾‍🦳' => 'адам: кара тору, ак чач',
    '🧑🏿‍🦳' => 'адам: кара, ак чач',
    '🧑🏻‍🦲' => 'адам: акжуумал, тас',
    '🧑🏼‍🦲' => 'адам: буудай жүздүү, тас',
    '🧑🏽‍🦲' => 'адам: орточо, тас',
    '🧑🏾‍🦲' => 'адам: кара тору, тас',
    '🧑🏿‍🦲' => 'адам: кара, тас',
    '🧑🏻‍🩰' => 'балет бийчиси: акжуумал',
    '🧑🏼‍🩰' => 'балет бийчиси: буудай жүздүү',
    '🧑🏽‍🩰' => 'балет бийчиси: орточо',
    '🧑🏾‍🩰' => 'балет бийчиси: кара тору',
    '🧑🏿‍🩰' => 'балет бийчиси: кара',
    '🧔🏻‍♂' => 'киши: акжуумал, сакал',
    '🧔🏼‍♂' => 'киши: буудай жүздүү, сакал',
    '🧔🏽‍♂' => 'киши: орточо, сакал',
    '🧔🏾‍♂' => 'киши: кара тору, сакал',
    '🧔🏿‍♂' => 'киши: кара, сакал',
    '👱🏻‍♂' => 'сары чачтуу эркек: акжуумал',
    '👱🏼‍♂' => 'сары чачтуу эркек: буудай жүздүү',
    '👱🏽‍♂' => 'сары чачтуу эркек: орточо',
    '👱🏾‍♂' => 'сары чачтуу эркек: кара тору',
    '👱🏿‍♂' => 'сары чачтуу эркек: кара',
    '👨🏻‍🦰' => 'эркек: акжуумал, кызыл чач',
    '👨🏼‍🦰' => 'эркек: буудай жүздүү, кызыл чач',
    '👨🏽‍🦰' => 'эркек: орточо, кызыл чач',
    '👨🏾‍🦰' => 'эркек: кара тору, кызыл чач',
    '👨🏿‍🦰' => 'эркек: кара, кызыл чач',
    '👨🏻‍🦱' => 'эркек: акжуумал, тармал чач',
    '👨🏼‍🦱' => 'эркек: буудай жүздүү, тармал чач',
    '👨🏽‍🦱' => 'эркек: орточо, тармал чач',
    '👨🏾‍🦱' => 'эркек: кара тору, тармал чач',
    '👨🏿‍🦱' => 'эркек: кара, тармал чач',
    '👨🏻‍🦳' => 'эркек: акжуумал, ак чач',
    '👨🏼‍🦳' => 'эркек: буудай жүздүү, ак чач',
    '👨🏽‍🦳' => 'эркек: орточо, ак чач',
    '👨🏾‍🦳' => 'эркек: кара тору, ак чач',
    '👨🏿‍🦳' => 'эркек: кара, ак чач',
    '👨🏻‍🦲' => 'эркек: акжуумал, тас',
    '👨🏼‍🦲' => 'эркек: буудай жүздүү, тас',
    '👨🏽‍🦲' => 'эркек: орточо, тас',
    '👨🏾‍🦲' => 'эркек: кара тору, тас',
    '👨🏿‍🦲' => 'эркек: кара, тас',
    '🧔🏻‍♀' => 'аял : акжуумал, сакал',
    '🧔🏼‍♀' => 'аял : буудай жүздүү, сакал',
    '🧔🏽‍♀' => 'аял : орточо, сакал',
    '🧔🏾‍♀' => 'аял : кара тору, сакал',
    '🧔🏿‍♀' => 'аял : кара, сакал',
    '👱🏻‍♀' => 'сары чачтуу аял: акжуумал',
    '👱🏼‍♀' => 'сары чачтуу аял: буудай жүздүү',
    '👱🏽‍♀' => 'сары чачтуу аял: орточо',
    '👱🏾‍♀' => 'сары чачтуу аял: кара тору',
    '👱🏿‍♀' => 'сары чачтуу аял: кара',
    '👩🏻‍🦰' => 'аял: акжуумал, кызыл чач',
    '👩🏼‍🦰' => 'аял: буудай жүздүү, кызыл чач',
    '👩🏽‍🦰' => 'аял: орточо, кызыл чач',
    '👩🏾‍🦰' => 'аял: кара тору, кызыл чач',
    '👩🏿‍🦰' => 'аял: кара, кызыл чач',
    '👩🏻‍🦱' => 'аял: акжуумал, тармал чач',
    '👩🏼‍🦱' => 'аял: буудай жүздүү, тармал чач',
    '👩🏽‍🦱' => 'аял: орточо, тармал чач',
    '👩🏾‍🦱' => 'аял: кара тору, тармал чач',
    '👩🏿‍🦱' => 'аял: кара, тармал чач',
    '👩🏻‍🦳' => 'аял: акжуумал, ак чач',
    '👩🏼‍🦳' => 'аял: буудай жүздүү, ак чач',
    '👩🏽‍🦳' => 'аял: орточо, ак чач',
    '👩🏾‍🦳' => 'аял: кара тору, ак чач',
    '👩🏿‍🦳' => 'аял: кара, ак чач',
    '👩🏻‍🦲' => 'аял: акжуумал, тас',
    '👩🏼‍🦲' => 'аял: буудай жүздүү, тас',
    '👩🏽‍🦲' => 'аял: орточо, тас',
    '👩🏾‍🦲' => 'аял: кара тору, тас',
    '👩🏿‍🦲' => 'аял: кара, тас',
    '🙍🏻‍♂' => 'кабагын бүркөгөн эркек: акжуумал',
    '🙍🏼‍♂' => 'кабагын бүркөгөн эркек: буудай жүздүү',
    '🙍🏽‍♂' => 'кабагын бүркөгөн эркек: орточо',
    '🙍🏾‍♂' => 'кабагын бүркөгөн эркек: кара тору',
    '🙍🏿‍♂' => 'кабагын бүркөгөн эркек: кара',
    '🙍🏻‍♀' => 'кабагын бүркөгөн аял: акжуумал',
    '🙍🏼‍♀' => 'кабагын бүркөгөн аял: буудай жүздүү',
    '🙍🏽‍♀' => 'кабагын бүркөгөн аял: орточо',
    '🙍🏾‍♀' => 'кабагын бүркөгөн аял: кара тору',
    '🙍🏿‍♀' => 'кабагын бүркөгөн аял: кара',
    '🙎🏻‍♂' => 'тултуюп таарынган эркек: акжуумал',
    '🙎🏼‍♂' => 'тултуюп таарынган эркек: буудай жүздүү',
    '🙎🏽‍♂' => 'тултуюп таарынган эркек: орточо',
    '🙎🏾‍♂' => 'тултуюп таарынган эркек: кара тору',
    '🙎🏿‍♂' => 'тултуюп таарынган эркек: кара',
    '🙎🏻‍♀' => 'тултуюп таарынган аял: акжуумал',
    '🙎🏼‍♀' => 'тултуюп таарынган аял: буудай жүздүү',
    '🙎🏽‍♀' => 'тултуюп таарынган аял: орточо',
    '🙎🏾‍♀' => 'тултуюп таарынган аял: кара тору',
    '🙎🏿‍♀' => 'тултуюп таарынган аял: кара',
    '🙅🏻‍♂' => 'ЖОК деп жаткан эркек: акжуумал',
    '🙅🏼‍♂' => 'ЖОК деп жаткан эркек: буудай жүздүү',
    '🙅🏽‍♂' => 'ЖОК деп жаткан эркек: орточо',
    '🙅🏾‍♂' => 'ЖОК деп жаткан эркек: кара тору',
    '🙅🏿‍♂' => 'ЖОК деп жаткан эркек: кара',
    '🙅🏻‍♀' => '«жок» деп жаткан аял: акжуумал',
    '🙅🏼‍♀' => '«жок» деп жаткан аял: буудай жүздүү',
    '🙅🏽‍♀' => '«жок» деп жаткан аял: орточо',
    '🙅🏾‍♀' => '«жок» деп жаткан аял: кара тору',
    '🙅🏿‍♀' => '«жок» деп жаткан аял: кара',
    '🙆🏻‍♂' => '«жарайт» деп жаткан эркек: акжуумал',
    '🙆🏼‍♂' => '«жарайт» деп жаткан эркек: буудай жүздүү',
    '🙆🏽‍♂' => '«жарайт» деп жаткан эркек: орточо',
    '🙆🏾‍♂' => '«жарайт» деп жаткан эркек: кара тору',
    '🙆🏿‍♂' => '«жарайт» деп жаткан эркек: кара',
    '🙆🏻‍♀' => '«жарайт» деп жаткан аял: акжуумал',
    '🙆🏼‍♀' => '«жарайт» деп жаткан аял: буудай жүздүү',
    '🙆🏽‍♀' => '«жарайт» деп жаткан аял: орточо',
    '🙆🏾‍♀' => '«жарайт» деп жаткан аял: кара тору',
    '🙆🏿‍♀' => '«жарайт» деп жаткан аял: кара',
    '💁🏻‍♂' => 'Баш кийимин чечип учурашкан эркек: акжуумал',
    '💁🏼‍♂' => 'Баш кийимин чечип учурашкан эркек: буудай жүздүү',
    '💁🏽‍♂' => 'Баш кийимин чечип учурашкан эркек: орточо',
    '💁🏾‍♂' => 'Баш кийимин чечип учурашкан эркек: кара тору',
    '💁🏿‍♂' => 'Баш кийимин чечип учурашкан эркек: кара',
    '💁🏻‍♀' => 'Баш кийимин чечип учурашкан аял: акжуумал',
    '💁🏼‍♀' => 'Баш кийимин чечип учурашкан аял: буудай жүздүү',
    '💁🏽‍♀' => 'Баш кийимин чечип учурашкан аял: орточо',
    '💁🏾‍♀' => 'Баш кийимин чечип учурашкан аял: кара тору',
    '💁🏿‍♀' => 'Баш кийимин чечип учурашкан аял: кара',
    '🙋🏻‍♂' => 'колун көтөрүп жаткан эркек: акжуумал',
    '🙋🏼‍♂' => 'колун көтөрүп жаткан эркек: буудай жүздүү',
    '🙋🏽‍♂' => 'колун көтөрүп жаткан эркек: орточо',
    '🙋🏾‍♂' => 'колун көтөрүп жаткан эркек: кара тору',
    '🙋🏿‍♂' => 'колун көтөрүп жаткан эркек: кара',
    '🙋🏻‍♀' => 'колун көтөрүп жаткан аял: акжуумал',
    '🙋🏼‍♀' => 'колун көтөрүп жаткан аял: буудай жүздүү',
    '🙋🏽‍♀' => 'колун көтөрүп жаткан аял: орточо',
    '🙋🏾‍♀' => 'колун көтөрүп жаткан аял: кара тору',
    '🙋🏿‍♀' => 'колун көтөрүп жаткан аял: кара',
    '🧏🏻‍♂' => 'дүлөй адам: акжуумал',
    '🧏🏼‍♂' => 'дүлөй адам: буудай жүздүү',
    '🧏🏽‍♂' => 'дүлөй адам: орточо',
    '🧏🏾‍♂' => 'дүлөй адам: кара тору',
    '🧏🏿‍♂' => 'дүлөй адам: кара',
    '🧏🏻‍♀' => 'дүлөй аял: акжуумал',
    '🧏🏼‍♀' => 'дүлөй аял: буудай жүздүү',
    '🧏🏽‍♀' => 'дүлөй аял: орточо',
    '🧏🏾‍♀' => 'дүлөй аял: кара тору',
    '🧏🏿‍♀' => 'дүлөй аял: кара',
    '🙇🏻‍♂' => 'жүгүнүп жаткан эркек: акжуумал',
    '🙇🏼‍♂' => 'жүгүнүп жаткан эркек: буудай жүздүү',
    '🙇🏽‍♂' => 'жүгүнүп жаткан эркек: орточо',
    '🙇🏾‍♂' => 'жүгүнүп жаткан эркек: кара тору',
    '🙇🏿‍♂' => 'жүгүнүп жаткан эркек: кара',
    '🙇🏻‍♀' => 'жүгүнүп жаткан аял: акжуумал',
    '🙇🏼‍♀' => 'жүгүнүп жаткан аял: буудай жүздүү',
    '🙇🏽‍♀' => 'жүгүнүп жаткан аял: орточо',
    '🙇🏾‍♀' => 'жүгүнүп жаткан аял: кара тору',
    '🙇🏿‍♀' => 'жүгүнүп жаткан аял: кара',
    '🤦🏻‍♂' => 'бетин кармаган эркек: акжуумал',
    '🤦🏼‍♂' => 'бетин кармаган эркек: буудай жүздүү',
    '🤦🏽‍♂' => 'бетин кармаган эркек: орточо',
    '🤦🏾‍♂' => 'бетин кармаган эркек: кара тору',
    '🤦🏿‍♂' => 'бетин кармаган эркек: кара',
    '🤦🏻‍♀' => 'бетин кармаган аял: акжуумал',
    '🤦🏼‍♀' => 'бетин кармаган аял: буудай жүздүү',
    '🤦🏽‍♀' => 'бетин кармаган аял: орточо',
    '🤦🏾‍♀' => 'бетин кармаган аял: кара тору',
    '🤦🏿‍♀' => 'бетин кармаган аял: кара',
    '🤷🏻‍♂' => 'ийинин куушурган эркек: акжуумал',
    '🤷🏼‍♂' => 'ийинин куушурган эркек: буудай жүздүү',
    '🤷🏽‍♂' => 'ийинин куушурган эркек: орточо',
    '🤷🏾‍♂' => 'ийинин куушурган эркек: кара тору',
    '🤷🏿‍♂' => 'ийинин куушурган эркек: кара',
    '🤷🏻‍♀' => 'ийинин куушурган аял: акжуумал',
    '🤷🏼‍♀' => 'ийинин куушурган аял: буудай жүздүү',
    '🤷🏽‍♀' => 'ийинин куушурган аял: орточо',
    '🤷🏾‍♀' => 'ийинин куушурган аял: кара тору',
    '🤷🏿‍♀' => 'ийинин куушурган аял: кара',
    '🧑🏻‍⚕' => 'медицина кызматкери: акжуумал',
    '🧑🏼‍⚕' => 'медицина кызматкери: буудай жүздүү',
    '🧑🏽‍⚕' => 'медицина кызматкери: орточо',
    '🧑🏾‍⚕' => 'медицина кызматкери: кара тору',
    '🧑🏿‍⚕' => 'медицина кызматкери: кара',
    '👨🏻‍⚕' => 'эркек медицина кызматкери: акжуумал',
    '👨🏼‍⚕' => 'эркек медицина кызматкери: буудай жүздүү',
    '👨🏽‍⚕' => 'эркек медицина кызматкери: орточо',
    '👨🏾‍⚕' => 'эркек медицина кызматкери: кара тору',
    '👨🏿‍⚕' => 'эркек медицина кызматкери: кара',
    '👩🏻‍⚕' => 'аял медицина кызматкери: акжуумал',
    '👩🏼‍⚕' => 'аял медицина кызматкери: буудай жүздүү',
    '👩🏽‍⚕' => 'аял медицина кызматкери: орточо',
    '👩🏾‍⚕' => 'аял медицина кызматкери: кара тору',
    '👩🏿‍⚕' => 'аял медицина кызматкери: кара',
    '🧑🏻‍🎓' => 'студент: акжуумал',
    '🧑🏼‍🎓' => 'студент: буудай жүздүү',
    '🧑🏽‍🎓' => 'студент: орточо',
    '🧑🏾‍🎓' => 'студент: кара тору',
    '🧑🏿‍🎓' => 'студент: кара',
    '👨🏻‍🎓' => 'эркек студент: акжуумал',
    '👨🏼‍🎓' => 'эркек студент: буудай жүздүү',
    '👨🏽‍🎓' => 'эркек студент: орточо',
    '👨🏾‍🎓' => 'эркек студент: кара тору',
    '👨🏿‍🎓' => 'эркек студент: кара',
    '👩🏻‍🎓' => 'аял студент: акжуумал',
    '👩🏼‍🎓' => 'аял студент: буудай жүздүү',
    '👩🏽‍🎓' => 'аял студент: орточо',
    '👩🏾‍🎓' => 'аял студент: кара тору',
    '👩🏿‍🎓' => 'аял студент: кара',
    '🧑🏻‍🏫' => 'мугалим: акжуумал',
    '🧑🏼‍🏫' => 'мугалим: буудай жүздүү',
    '🧑🏽‍🏫' => 'мугалим: орточо',
    '🧑🏾‍🏫' => 'мугалим: кара тору',
    '🧑🏿‍🏫' => 'мугалим: кара',
    '👨🏻‍🏫' => 'эркек мугалим: акжуумал',
    '👨🏼‍🏫' => 'эркек мугалим: буудай жүздүү',
    '👨🏽‍🏫' => 'эркек мугалим: орточо',
    '👨🏾‍🏫' => 'эркек мугалим: кара тору',
    '👨🏿‍🏫' => 'эркек мугалим: кара',
    '👩🏻‍🏫' => 'аял мугалим: акжуумал',
    '👩🏼‍🏫' => 'аял мугалим: буудай жүздүү',
    '👩🏽‍🏫' => 'аял мугалим: орточо',
    '👩🏾‍🏫' => 'аял мугалим: кара тору',
    '👩🏿‍🏫' => 'аял мугалим: кара',
    '🧑🏻‍⚖' => 'сот: акжуумал',
    '🧑🏼‍⚖' => 'сот: буудай жүздүү',
    '🧑🏽‍⚖' => 'сот: орточо',
    '🧑🏾‍⚖' => 'сот: кара тору',
    '🧑🏿‍⚖' => 'сот: кара',
    '👨🏻‍⚖' => 'эркек сот: акжуумал',
    '👨🏼‍⚖' => 'эркек сот: буудай жүздүү',
    '👨🏽‍⚖' => 'эркек сот: орточо',
    '👨🏾‍⚖' => 'эркек сот: кара тору',
    '👨🏿‍⚖' => 'эркек сот: кара',
    '👩🏻‍⚖' => 'аял сот: акжуумал',
    '👩🏼‍⚖' => 'аял сот: буудай жүздүү',
    '👩🏽‍⚖' => 'аял сот: орточо',
    '👩🏾‍⚖' => 'аял сот: кара тору',
    '👩🏿‍⚖' => 'аял сот: кара',
    '🧑🏻‍🌾' => 'фермер: акжуумал',
    '🧑🏼‍🌾' => 'фермер: буудай жүздүү',
    '🧑🏽‍🌾' => 'фермер: орточо',
    '🧑🏾‍🌾' => 'фермер: кара тору',
    '🧑🏿‍🌾' => 'фермер: кара',
    '👨🏻‍🌾' => 'эркек фермер: акжуумал',
    '👨🏼‍🌾' => 'эркек фермер: буудай жүздүү',
    '👨🏽‍🌾' => 'эркек фермер: орточо',
    '👨🏾‍🌾' => 'эркек фермер: кара тору',
    '👨🏿‍🌾' => 'эркек фермер: кара',
    '👩🏻‍🌾' => 'аял фермер: акжуумал',
    '👩🏼‍🌾' => 'аял фермер: буудай жүздүү',
    '👩🏽‍🌾' => 'аял фермер: орточо',
    '👩🏾‍🌾' => 'аял фермер: кара тору',
    '👩🏿‍🌾' => 'аял фермер: кара',
    '🧑🏻‍🍳' => 'ашпозчу: акжуумал',
    '🧑🏼‍🍳' => 'ашпозчу: буудай жүздүү',
    '🧑🏽‍🍳' => 'ашпозчу: орточо',
    '🧑🏾‍🍳' => 'ашпозчу: кара тору',
    '🧑🏿‍🍳' => 'ашпозчу: кара',
    '👨🏻‍🍳' => 'эркек ашпозчу: акжуумал',
    '👨🏼‍🍳' => 'эркек ашпозчу: буудай жүздүү',
    '👨🏽‍🍳' => 'эркек ашпозчу: орточо',
    '👨🏾‍🍳' => 'эркек ашпозчу: кара тору',
    '👨🏿‍🍳' => 'эркек ашпозчу: кара',
    '👩🏻‍🍳' => 'аял ашпозчу: акжуумал',
    '👩🏼‍🍳' => 'аял ашпозчу: буудай жүздүү',
    '👩🏽‍🍳' => 'аял ашпозчу: орточо',
    '👩🏾‍🍳' => 'аял ашпозчу: кара тору',
    '👩🏿‍🍳' => 'аял ашпозчу: кара',
    '🧑🏻‍🔧' => 'механик: акжуумал',
    '🧑🏼‍🔧' => 'механик: буудай жүздүү',
    '🧑🏽‍🔧' => 'механик: орточо',
    '🧑🏾‍🔧' => 'механик: кара тору',
    '🧑🏿‍🔧' => 'механик: кара',
    '👨🏻‍🔧' => 'эркек механик: акжуумал',
    '👨🏼‍🔧' => 'эркек механик: буудай жүздүү',
    '👨🏽‍🔧' => 'эркек механик: орточо',
    '👨🏾‍🔧' => 'эркек механик: кара тору',
    '👨🏿‍🔧' => 'эркек механик: кара',
    '👩🏻‍🔧' => 'аял механик: акжуумал',
    '👩🏼‍🔧' => 'аял механик: буудай жүздүү',
    '👩🏽‍🔧' => 'аял механик: орточо',
    '👩🏾‍🔧' => 'аял механик: кара тору',
    '👩🏿‍🔧' => 'аял механик: кара',
    '🧑🏻‍🏭' => 'завод жумушчусу: акжуумал',
    '🧑🏼‍🏭' => 'завод жумушчусу: буудай жүздүү',
    '🧑🏽‍🏭' => 'завод жумушчусу: орточо',
    '🧑🏾‍🏭' => 'завод жумушчусу: кара тору',
    '🧑🏿‍🏭' => 'завод жумушчусу: кара',
    '👨🏻‍🏭' => 'эркек завод жумушчусу: акжуумал',
    '👨🏼‍🏭' => 'эркек завод жумушчусу: буудай жүздүү',
    '👨🏽‍🏭' => 'эркек завод жумушчусу: орточо',
    '👨🏾‍🏭' => 'эркек завод жумушчусу: кара тору',
    '👨🏿‍🏭' => 'эркек завод жумушчусу: кара',
    '👩🏻‍🏭' => 'аял завод жумушчусу: акжуумал',
    '👩🏼‍🏭' => 'аял завод жумушчусу: буудай жүздүү',
    '👩🏽‍🏭' => 'аял завод жумушчусу: орточо',
    '👩🏾‍🏭' => 'аял завод жумушчусу: кара тору',
    '👩🏿‍🏭' => 'аял завод жумушчусу: кара',
    '🧑🏻‍💼' => 'кеңсе кызматкери: акжуумал',
    '🧑🏼‍💼' => 'кеңсе кызматкери: буудай жүздүү',
    '🧑🏽‍💼' => 'кеңсе кызматкери: орточо',
    '🧑🏾‍💼' => 'кеңсе кызматкери: кара тору',
    '🧑🏿‍💼' => 'кеңсе кызматкери: кара',
    '👨🏻‍💼' => 'эркек офис жумушчусу: акжуумал',
    '👨🏼‍💼' => 'эркек офис жумушчусу: буудай жүздүү',
    '👨🏽‍💼' => 'эркек офис жумушчусу: орточо',
    '👨🏾‍💼' => 'эркек офис жумушчусу: кара тору',
    '👨🏿‍💼' => 'эркек офис жумушчусу: кара',
    '👩🏻‍💼' => 'аял офис жумушчусу: акжуумал',
    '👩🏼‍💼' => 'аял офис жумушчусу: буудай жүздүү',
    '👩🏽‍💼' => 'аял офис жумушчусу: орточо',
    '👩🏾‍💼' => 'аял офис жумушчусу: кара тору',
    '👩🏿‍💼' => 'аял офис жумушчусу: кара',
    '🧑🏻‍🔬' => 'илимпоз: акжуумал',
    '🧑🏼‍🔬' => 'илимпоз: буудай жүздүү',
    '🧑🏽‍🔬' => 'илимпоз: орточо',
    '🧑🏾‍🔬' => 'илимпоз: кара тору',
    '🧑🏿‍🔬' => 'илимпоз: кара',
    '👨🏻‍🔬' => 'эркек илимпоз: акжуумал',
    '👨🏼‍🔬' => 'эркек илимпоз: буудай жүздүү',
    '👨🏽‍🔬' => 'эркек илимпоз: орточо',
    '👨🏾‍🔬' => 'эркек илимпоз: кара тору',
    '👨🏿‍🔬' => 'эркек илимпоз: кара',
    '👩🏻‍🔬' => 'аял илимпоз: акжуумал',
    '👩🏼‍🔬' => 'аял илимпоз: буудай жүздүү',
    '👩🏽‍🔬' => 'аял илимпоз: орточо',
    '👩🏾‍🔬' => 'аял илимпоз: кара тору',
    '👩🏿‍🔬' => 'аял илимпоз: кара',
    '🧑🏻‍💻' => 'IT адиси: акжуумал',
    '🧑🏼‍💻' => 'IT адиси: буудай жүздүү',
    '🧑🏽‍💻' => 'IT адиси: орточо',
    '🧑🏾‍💻' => 'IT адиси: кара тору',
    '🧑🏿‍💻' => 'IT адиси: кара',
    '👨🏻‍💻' => 'эркек технолог: акжуумал',
    '👨🏼‍💻' => 'эркек технолог: буудай жүздүү',
    '👨🏽‍💻' => 'эркек технолог: орточо',
    '👨🏾‍💻' => 'эркек технолог: кара тору',
    '👨🏿‍💻' => 'эркек технолог: кара',
    '👩🏻‍💻' => 'аял технолог: акжуумал',
    '👩🏼‍💻' => 'аял технолог: буудай жүздүү',
    '👩🏽‍💻' => 'аял технолог: орточо',
    '👩🏾‍💻' => 'аял технолог: кара тору',
    '👩🏿‍💻' => 'аял технолог: кара',
    '🧑🏻‍🎤' => 'ырчы: акжуумал',
    '🧑🏼‍🎤' => 'ырчы: буудай жүздүү',
    '🧑🏽‍🎤' => 'ырчы: орточо',
    '🧑🏾‍🎤' => 'ырчы: кара тору',
    '🧑🏿‍🎤' => 'ырчы: кара',
    '👨🏻‍🎤' => 'эркек ырчы: акжуумал',
    '👨🏼‍🎤' => 'эркек ырчы: буудай жүздүү',
    '👨🏽‍🎤' => 'эркек ырчы: орточо',
    '👨🏾‍🎤' => 'эркек ырчы: кара тору',
    '👨🏿‍🎤' => 'эркек ырчы: кара',
    '👩🏻‍🎤' => 'аял ырчы: акжуумал',
    '👩🏼‍🎤' => 'аял ырчы: буудай жүздүү',
    '👩🏽‍🎤' => 'аял ырчы: орточо',
    '👩🏾‍🎤' => 'аял ырчы: кара тору',
    '👩🏿‍🎤' => 'аял ырчы: кара',
    '🧑🏻‍🎨' => 'сүрөтчү: акжуумал',
    '🧑🏼‍🎨' => 'сүрөтчү: буудай жүздүү',
    '🧑🏽‍🎨' => 'сүрөтчү: орточо',
    '🧑🏾‍🎨' => 'сүрөтчү: кара тору',
    '🧑🏿‍🎨' => 'сүрөтчү: кара',
    '👨🏻‍🎨' => 'эркек сүрөтчү: акжуумал',
    '👨🏼‍🎨' => 'эркек сүрөтчү: буудай жүздүү',
    '👨🏽‍🎨' => 'эркек сүрөтчү: орточо',
    '👨🏾‍🎨' => 'эркек сүрөтчү: кара тору',
    '👨🏿‍🎨' => 'эркек сүрөтчү: кара',
    '👩🏻‍🎨' => 'аял сүрөтчү: акжуумал',
    '👩🏼‍🎨' => 'аял сүрөтчү: буудай жүздүү',
    '👩🏽‍🎨' => 'аял сүрөтчү: орточо',
    '👩🏾‍🎨' => 'аял сүрөтчү: кара тору',
    '👩🏿‍🎨' => 'аял сүрөтчү: кара',
    '🧑🏻‍✈' => 'пилот: акжуумал',
    '🧑🏼‍✈' => 'пилот: буудай жүздүү',
    '🧑🏽‍✈' => 'пилот: орточо',
    '🧑🏾‍✈' => 'пилот: кара тору',
    '🧑🏿‍✈' => 'пилот: кара',
    '👨🏻‍✈' => 'эркек учкуч: акжуумал',
    '👨🏼‍✈' => 'эркек учкуч: буудай жүздүү',
    '👨🏽‍✈' => 'эркек учкуч: орточо',
    '👨🏾‍✈' => 'эркек учкуч: кара тору',
    '👨🏿‍✈' => 'эркек учкуч: кара',
    '👩🏻‍✈' => 'аял учкуч: акжуумал',
    '👩🏼‍✈' => 'аял учкуч: буудай жүздүү',
    '👩🏽‍✈' => 'аял учкуч: орточо',
    '👩🏾‍✈' => 'аял учкуч: кара тору',
    '👩🏿‍✈' => 'аял учкуч: кара',
    '🧑🏻‍🚀' => 'космонавт: акжуумал',
    '🧑🏼‍🚀' => 'космонавт: буудай жүздүү',
    '🧑🏽‍🚀' => 'космонавт: орточо',
    '🧑🏾‍🚀' => 'космонавт: кара тору',
    '🧑🏿‍🚀' => 'космонавт: кара',
    '👨🏻‍🚀' => 'эркек космонавт: акжуумал',
    '👨🏼‍🚀' => 'эркек космонавт: буудай жүздүү',
    '👨🏽‍🚀' => 'эркек космонавт: орточо',
    '👨🏾‍🚀' => 'эркек космонавт: кара тору',
    '👨🏿‍🚀' => 'эркек космонавт: кара',
    '👩🏻‍🚀' => 'аял космонавт: акжуумал',
    '👩🏼‍🚀' => 'аял космонавт: буудай жүздүү',
    '👩🏽‍🚀' => 'аял космонавт: орточо',
    '👩🏾‍🚀' => 'аял космонавт: кара тору',
    '👩🏿‍🚀' => 'аял космонавт: кара',
    '🧑🏻‍🚒' => 'өрт өчүрүүчү: акжуумал',
    '🧑🏼‍🚒' => 'өрт өчүрүүчү: буудай жүздүү',
    '🧑🏽‍🚒' => 'өрт өчүрүүчү: орточо',
    '🧑🏾‍🚒' => 'өрт өчүрүүчү: кара тору',
    '🧑🏿‍🚒' => 'өрт өчүрүүчү: кара',
    '👨🏻‍🚒' => 'эркек өрт өчүргүч: акжуумал',
    '👨🏼‍🚒' => 'эркек өрт өчүргүч: буудай жүздүү',
    '👨🏽‍🚒' => 'эркек өрт өчүргүч: орточо',
    '👨🏾‍🚒' => 'эркек өрт өчүргүч: кара тору',
    '👨🏿‍🚒' => 'эркек өрт өчүргүч: кара',
    '👩🏻‍🚒' => 'аял өрт өчүргүч: акжуумал',
    '👩🏼‍🚒' => 'аял өрт өчүргүч: буудай жүздүү',
    '👩🏽‍🚒' => 'аял өрт өчүргүч: орточо',
    '👩🏾‍🚒' => 'аял өрт өчүргүч: кара тору',
    '👩🏿‍🚒' => 'аял өрт өчүргүч: кара',
    '👮🏻‍♂' => 'эркек милиция кызматкери: акжуумал',
    '👮🏼‍♂' => 'эркек милиция кызматкери: буудай жүздүү',
    '👮🏽‍♂' => 'эркек милиция кызматкери: орточо',
    '👮🏾‍♂' => 'эркек милиция кызматкери: кара тору',
    '👮🏿‍♂' => 'эркек милиция кызматкери: кара',
    '👮🏻‍♀' => 'аял милиция кызматкери: акжуумал',
    '👮🏼‍♀' => 'аял милиция кызматкери: буудай жүздүү',
    '👮🏽‍♀' => 'аял милиция кызматкери: орточо',
    '👮🏾‍♀' => 'аял милиция кызматкери: кара тору',
    '👮🏿‍♀' => 'аял милиция кызматкери: кара',
    '🕵🏻‍♂' => 'детектив киши: акжуумал',
    '🕵🏼‍♂' => 'детектив киши: буудай жүздүү',
    '🕵🏽‍♂' => 'детектив киши: орточо',
    '🕵🏾‍♂' => 'детектив киши: кара тору',
    '🕵🏿‍♂' => 'детектив киши: кара',
    '🕵🏻‍♀' => 'детектив аял: акжуумал',
    '🕵🏼‍♀' => 'детектив аял: буудай жүздүү',
    '🕵🏽‍♀' => 'детектив аял: орточо',
    '🕵🏾‍♀' => 'детектив аял: кара тору',
    '🕵🏿‍♀' => 'детектив аял: кара',
    '💂🏻‍♂' => 'эркек кароолчу: акжуумал',
    '💂🏼‍♂' => 'эркек кароолчу: буудай жүздүү',
    '💂🏽‍♂' => 'эркек кароолчу: орточо',
    '💂🏾‍♂' => 'эркек кароолчу: кара тору',
    '💂🏿‍♂' => 'эркек кароолчу: кара',
    '💂🏻‍♀' => 'аял кароолчу: акжуумал',
    '💂🏼‍♀' => 'аял кароолчу: буудай жүздүү',
    '💂🏽‍♀' => 'аял кароолчу: орточо',
    '💂🏾‍♀' => 'аял кароолчу: кара тору',
    '💂🏿‍♀' => 'аял кароолчу: кара',
    '👷🏻‍♂' => 'эркек курулуш кызматкери: акжуумал',
    '👷🏼‍♂' => 'эркек курулуш кызматкери: буудай жүздүү',
    '👷🏽‍♂' => 'эркек курулуш кызматкери: орточо',
    '👷🏾‍♂' => 'эркек курулуш кызматкери: кара тору',
    '👷🏿‍♂' => 'эркек курулуш кызматкери: кара',
    '👷🏻‍♀' => 'аял курулуш кызматкери: акжуумал',
    '👷🏼‍♀' => 'аял курулуш кызматкери: буудай жүздүү',
    '👷🏽‍♀' => 'аял курулуш кызматкери: орточо',
    '👷🏾‍♀' => 'аял курулуш кызматкери: кара тору',
    '👷🏿‍♀' => 'аял курулуш кызматкери: кара',
    '👳🏻‍♂' => 'селдечен эркек: акжуумал',
    '👳🏼‍♂' => 'селдечен эркек: буудай жүздүү',
    '👳🏽‍♂' => 'селдечен эркек: орточо',
    '👳🏾‍♂' => 'селдечен эркек: кара тору',
    '👳🏿‍♂' => 'селдечен эркек: кара',
    '👳🏻‍♀' => 'селдечен аял: акжуумал',
    '👳🏼‍♀' => 'селдечен аял: буудай жүздүү',
    '👳🏽‍♀' => 'селдечен аял: орточо',
    '👳🏾‍♀' => 'селдечен аял: кара тору',
    '👳🏿‍♀' => 'селдечен аял: кара',
    '🤵🏻‍♂' => 'смокинг кийген адам: акжуумал',
    '🤵🏼‍♂' => 'смокинг кийген адам: буудай жүздүү',
    '🤵🏽‍♂' => 'смокинг кийген адам: орточо',
    '🤵🏾‍♂' => 'смокинг кийген адам: кара тору',
    '🤵🏿‍♂' => 'смокинг кийген адам: кара',
    '🤵🏻‍♀' => 'смокинг кийген аял: акжуумал',
    '🤵🏼‍♀' => 'смокинг кийген аял: буудай жүздүү',
    '🤵🏽‍♀' => 'смокинг кийген аял: орточо',
    '🤵🏾‍♀' => 'смокинг кийген аял: кара тору',
    '🤵🏿‍♀' => 'смокинг кийген аял: кара',
    '👰🏻‍♂' => 'вуальчан эркек: акжуумал',
    '👰🏼‍♂' => 'вуальчан эркек: буудай жүздүү',
    '👰🏽‍♂' => 'вуальчан эркек: орточо',
    '👰🏾‍♂' => 'вуальчан эркек: кара тору',
    '👰🏿‍♂' => 'вуальчан эркек: кара',
    '👰🏻‍♀' => 'вуальчан аял: акжуумал',
    '👰🏼‍♀' => 'вуальчан аял: буудай жүздүү',
    '👰🏽‍♀' => 'вуальчан аял: орточо',
    '👰🏾‍♀' => 'вуальчан аял: кара тору',
    '👰🏿‍♀' => 'вуальчан аял: кара',
    '👩🏻‍🍼' => 'балага тамак берип жаткан аял: акжуумал',
    '👩🏼‍🍼' => 'балага тамак берип жаткан аял: буудай жүздүү',
    '👩🏽‍🍼' => 'балага тамак берип жаткан аял: орточо',
    '👩🏾‍🍼' => 'балага тамак берип жаткан аял: кара тору',
    '👩🏿‍🍼' => 'балага тамак берип жаткан аял: кара',
    '👨🏻‍🍼' => 'балага тамак берип жаткан эркек киши: акжуумал',
    '👨🏼‍🍼' => 'балага тамак берип жаткан эркек киши: буудай жүздүү',
    '👨🏽‍🍼' => 'балага тамак берип жаткан эркек киши: орточо',
    '👨🏾‍🍼' => 'балага тамак берип жаткан эркек киши: кара тору',
    '👨🏿‍🍼' => 'балага тамак берип жаткан эркек киши: кара',
    '🧑🏻‍🍼' => 'балага тамак берип жаткан адам: акжуумал',
    '🧑🏼‍🍼' => 'балага тамак берип жаткан адам: буудай жүздүү',
    '🧑🏽‍🍼' => 'балага тамак берип жаткан адам: орточо',
    '🧑🏾‍🍼' => 'балага тамак берип жаткан адам: кара тору',
    '🧑🏿‍🍼' => 'балага тамак берип жаткан адам: кара',
    '🧑🏻‍🎄' => 'клаус: акжуумал',
    '🧑🏼‍🎄' => 'клаус: буудай жүздүү',
    '🧑🏽‍🎄' => 'клаус: орточо',
    '🧑🏾‍🎄' => 'клаус: кара тору',
    '🧑🏿‍🎄' => 'клаус: кара',
    '🦸🏻‍♂' => 'баатыр жигит: акжуумал',
    '🦸🏼‍♂' => 'баатыр жигит: буудай жүздүү',
    '🦸🏽‍♂' => 'баатыр жигит: орточо',
    '🦸🏾‍♂' => 'баатыр жигит: кара тору',
    '🦸🏿‍♂' => 'баатыр жигит: кара',
    '🦸🏻‍♀' => 'супер баатыр кыз: акжуумал',
    '🦸🏼‍♀' => 'супер баатыр кыз: буудай жүздүү',
    '🦸🏽‍♀' => 'супер баатыр кыз: орточо',
    '🦸🏾‍♀' => 'супер баатыр кыз: кара тору',
    '🦸🏿‍♀' => 'супер баатыр кыз: кара',
    '🦹🏻‍♂' => 'карасантай жигит: акжуумал',
    '🦹🏼‍♂' => 'карасантай жигит: буудай жүздүү',
    '🦹🏽‍♂' => 'карасантай жигит: орточо',
    '🦹🏾‍♂' => 'карасантай жигит: кара тору',
    '🦹🏿‍♂' => 'карасантай жигит: кара',
    '🦹🏻‍♀' => 'карасантай кыз: акжуумал',
    '🦹🏼‍♀' => 'карасантай кыз: буудай жүздүү',
    '🦹🏽‍♀' => 'карасантай кыз: орточо',
    '🦹🏾‍♀' => 'карасантай кыз: кара тору',
    '🦹🏿‍♀' => 'карасантай кыз: кара',
    '🧙🏻‍♂' => 'эркек сыйкырчы: акжуумал',
    '🧙🏼‍♂' => 'эркек сыйкырчы: буудай жүздүү',
    '🧙🏽‍♂' => 'эркек сыйкырчы: орточо',
    '🧙🏾‍♂' => 'эркек сыйкырчы: кара тору',
    '🧙🏿‍♂' => 'эркек сыйкырчы: кара',
    '🧙🏻‍♀' => 'аял сыйкырчы: акжуумал',
    '🧙🏼‍♀' => 'аял сыйкырчы: буудай жүздүү',
    '🧙🏽‍♀' => 'аял сыйкырчы: орточо',
    '🧙🏾‍♀' => 'аял сыйкырчы: кара тору',
    '🧙🏿‍♀' => 'аял сыйкырчы: кара',
    '🧚🏻‍♂' => 'эркек фея: акжуумал',
    '🧚🏼‍♂' => 'эркек фея: буудай жүздүү',
    '🧚🏽‍♂' => 'эркек фея: орточо',
    '🧚🏾‍♂' => 'эркек фея: кара тору',
    '🧚🏿‍♂' => 'эркек фея: кара',
    '🧚🏻‍♀' => 'аял фея: акжуумал',
    '🧚🏼‍♀' => 'аял фея: буудай жүздүү',
    '🧚🏽‍♀' => 'аял фея: орточо',
    '🧚🏾‍♀' => 'аял фея: кара тору',
    '🧚🏿‍♀' => 'аял фея: кара',
    '🧛🏻‍♂' => 'эркек кан соргуч: акжуумал',
    '🧛🏼‍♂' => 'эркек кан соргуч: буудай жүздүү',
    '🧛🏽‍♂' => 'эркек кан соргуч: орточо',
    '🧛🏾‍♂' => 'эркек кан соргуч: кара тору',
    '🧛🏿‍♂' => 'эркек кан соргуч: кара',
    '🧛🏻‍♀' => 'аял кан соргуч: акжуумал',
    '🧛🏼‍♀' => 'аял кан соргуч: буудай жүздүү',
    '🧛🏽‍♀' => 'аял кан соргуч: орточо',
    '🧛🏾‍♀' => 'аял кан соргуч: кара тору',
    '🧛🏿‍♀' => 'аял кан соргуч: кара',
    '🧜🏻‍♂' => 'эркек русалка: акжуумал',
    '🧜🏼‍♂' => 'эркек русалка: буудай жүздүү',
    '🧜🏽‍♂' => 'эркек русалка: орточо',
    '🧜🏾‍♂' => 'эркек русалка: кара тору',
    '🧜🏿‍♂' => 'эркек русалка: кара',
    '🧜🏻‍♀' => 'русалка: акжуумал',
    '🧜🏼‍♀' => 'русалка: буудай жүздүү',
    '🧜🏽‍♀' => 'русалка: орточо',
    '🧜🏾‍♀' => 'русалка: кара тору',
    '🧜🏿‍♀' => 'русалка: кара',
    '🧝🏻‍♂' => 'эркек эльф: акжуумал',
    '🧝🏼‍♂' => 'эркек эльф: буудай жүздүү',
    '🧝🏽‍♂' => 'эркек эльф: орточо',
    '🧝🏾‍♂' => 'эркек эльф: кара тору',
    '🧝🏿‍♂' => 'эркек эльф: кара',
    '🧝🏻‍♀' => 'аял эльф: акжуумал',
    '🧝🏼‍♀' => 'аял эльф: буудай жүздүү',
    '🧝🏽‍♀' => 'аял эльф: орточо',
    '🧝🏾‍♀' => 'аял эльф: кара тору',
    '🧝🏿‍♀' => 'аял эльф: кара',
    '💆🏻‍♂' => 'бетине массаж алып жаткан эркек: акжуумал',
    '💆🏼‍♂' => 'бетине массаж алып жаткан эркек: буудай жүздүү',
    '💆🏽‍♂' => 'бетине массаж алып жаткан эркек: орточо',
    '💆🏾‍♂' => 'бетине массаж алып жаткан эркек: кара тору',
    '💆🏿‍♂' => 'бетине массаж алып жаткан эркек: кара',
    '💆🏻‍♀' => 'бетине массаж алып жаткан аял: акжуумал',
    '💆🏼‍♀' => 'бетине массаж алып жаткан аял: буудай жүздүү',
    '💆🏽‍♀' => 'бетине массаж алып жаткан аял: орточо',
    '💆🏾‍♀' => 'бетине массаж алып жаткан аял: кара тору',
    '💆🏿‍♀' => 'бетине массаж алып жаткан аял: кара',
    '💇🏻‍♂' => 'чачын кырктырып жаткан эркек: акжуумал',
    '💇🏼‍♂' => 'чачын кырктырып жаткан эркек: буудай жүздүү',
    '💇🏽‍♂' => 'чачын кырктырып жаткан эркек: орточо',
    '💇🏾‍♂' => 'чачын кырктырып жаткан эркек: кара тору',
    '💇🏿‍♂' => 'чачын кырктырып жаткан эркек: кара',
    '💇🏻‍♀' => 'чачын кырктырып жаткан аял: акжуумал',
    '💇🏼‍♀' => 'чачын кырктырып жаткан аял: буудай жүздүү',
    '💇🏽‍♀' => 'чачын кырктырып жаткан аял: орточо',
    '💇🏾‍♀' => 'чачын кырктырып жаткан аял: кара тору',
    '💇🏿‍♀' => 'чачын кырктырып жаткан аял: кара',
    '🚶🏻‍♂' => 'жөө басып бара жаткан эркек: акжуумал',
    '🚶🏼‍♂' => 'жөө басып бара жаткан эркек: буудай жүздүү',
    '🚶🏽‍♂' => 'жөө басып бара жаткан эркек: орточо',
    '🚶🏾‍♂' => 'жөө басып бара жаткан эркек: кара тору',
    '🚶🏿‍♂' => 'жөө басып бара жаткан эркек: кара',
    '🚶🏻‍♀' => 'жөө басып бара жаткан аял: акжуумал',
    '🚶🏼‍♀' => 'жөө басып бара жаткан аял: буудай жүздүү',
    '🚶🏽‍♀' => 'жөө басып бара жаткан аял: орточо',
    '🚶🏾‍♀' => 'жөө басып бара жаткан аял: кара тору',
    '🚶🏿‍♀' => 'жөө басып бара жаткан аял: кара',
    '🚶🏻‍➡' => 'жөө адам: акжуумал, оңду карап турат',
    '🚶🏼‍➡' => 'жөө адам: буудай жүздүү, оңду карап турат',
    '🚶🏽‍➡' => 'жөө адам: орточо, оңду карап турат',
    '🚶🏾‍➡' => 'жөө адам: кара тору, оңду карап турат',
    '🚶🏿‍➡' => 'жөө адам: кара, оңду карап турат',
    '🧍🏻‍♂' => 'киши турат: акжуумал',
    '🧍🏼‍♂' => 'киши турат: буудай жүздүү',
    '🧍🏽‍♂' => 'киши турат: орточо',
    '🧍🏾‍♂' => 'киши турат: кара тору',
    '🧍🏿‍♂' => 'киши турат: кара',
    '🧍🏻‍♀' => 'аял турат: акжуумал',
    '🧍🏼‍♀' => 'аял турат: буудай жүздүү',
    '🧍🏽‍♀' => 'аял турат: орточо',
    '🧍🏾‍♀' => 'аял турат: кара тору',
    '🧍🏿‍♀' => 'аял турат: кара',
    '🧎🏻‍♂' => 'тизелеген киши: акжуумал',
    '🧎🏼‍♂' => 'тизелеген киши: буудай жүздүү',
    '🧎🏽‍♂' => 'тизелеген киши: орточо',
    '🧎🏾‍♂' => 'тизелеген киши: кара тору',
    '🧎🏿‍♂' => 'тизелеген киши: кара',
    '🧎🏻‍♀' => 'аял тизелөөдө: акжуумал',
    '🧎🏼‍♀' => 'аял тизелөөдө: буудай жүздүү',
    '🧎🏽‍♀' => 'аял тизелөөдө: орточо',
    '🧎🏾‍♀' => 'аял тизелөөдө: кара тору',
    '🧎🏿‍♀' => 'аял тизелөөдө: кара',
    '🧎🏻‍➡' => 'тизелеген адам: акжуумал, оңду карап турат',
    '🧎🏼‍➡' => 'тизелеген адам: буудай жүздүү, оңду карап турат',
    '🧎🏽‍➡' => 'тизелеген адам: орточо, оңду карап турат',
    '🧎🏾‍➡' => 'тизелеген адам: кара тору, оңду карап турат',
    '🧎🏿‍➡' => 'тизелеген адам: кара, оңду карап турат',
    '🧑🏻‍🦯' => 'таякка жөлөнгөн киши: акжуумал',
    '🧑🏼‍🦯' => 'таякка жөлөнгөн киши: буудай жүздүү',
    '🧑🏽‍🦯' => 'таякка жөлөнгөн киши: орточо',
    '🧑🏾‍🦯' => 'таякка жөлөнгөн киши: кара тору',
    '🧑🏿‍🦯' => 'таякка жөлөнгөн киши: кара',
    '👨🏻‍🦯' => 'таяк таянган киши: акжуумал',
    '👨🏼‍🦯' => 'таяк таянган киши: буудай жүздүү',
    '👨🏽‍🦯' => 'таяк таянган киши: орточо',
    '👨🏾‍🦯' => 'таяк таянган киши: кара тору',
    '👨🏿‍🦯' => 'таяк таянган киши: кара',
    '👩🏻‍🦯' => 'таяк таянган аял: акжуумал',
    '👩🏼‍🦯' => 'таяк таянган аял: буудай жүздүү',
    '👩🏽‍🦯' => 'таяк таянган аял: орточо',
    '👩🏾‍🦯' => 'таяк таянган аял: кара тору',
    '👩🏿‍🦯' => 'таяк таянган аял: кара',
    '🧑🏻‍🦼' => 'мотору бар инвалид креслосундагы киши: акжуумал',
    '🧑🏼‍🦼' => 'мотору бар инвалид креслосундагы киши: буудай жүздүү',
    '🧑🏽‍🦼' => 'мотору бар инвалид креслосундагы киши: орточо',
    '🧑🏾‍🦼' => 'мотору бар инвалид креслосундагы киши: кара тору',
    '🧑🏿‍🦼' => 'мотору бар инвалид креслосундагы киши: кара',
    '👨🏻‍🦼' => 'моторлуу дөңгөлөк отургучтагы киши: акжуумал',
    '👨🏼‍🦼' => 'моторлуу дөңгөлөк отургучтагы киши: буудай жүздүү',
    '👨🏽‍🦼' => 'моторлуу дөңгөлөк отургучтагы киши: орточо',
    '👨🏾‍🦼' => 'моторлуу дөңгөлөк отургучтагы киши: кара тору',
    '👨🏿‍🦼' => 'моторлуу дөңгөлөк отургучтагы киши: кара',
    '👩🏻‍🦼' => 'мотору бар дөңгөлөктүү отургучтагы аял: акжуумал',
    '👩🏼‍🦼' => 'мотору бар дөңгөлөктүү отургучтагы аял: буудай жүздүү',
    '👩🏽‍🦼' => 'мотору бар дөңгөлөктүү отургучтагы аял: орточо',
    '👩🏾‍🦼' => 'мотору бар дөңгөлөктүү отургучтагы аял: кара тору',
    '👩🏿‍🦼' => 'мотору бар дөңгөлөктүү отургучтагы аял: кара',
    '🧑🏻‍🦽' => 'кол менен иштеген кресло: акжуумал',
    '🧑🏼‍🦽' => 'кол менен иштеген кресло: буудай жүздүү',
    '🧑🏽‍🦽' => 'кол менен иштеген кресло: орточо',
    '🧑🏾‍🦽' => 'кол менен иштеген кресло: кара тору',
    '🧑🏿‍🦽' => 'кол менен иштеген кресло: кара',
    '👨🏻‍🦽' => 'кол менен дөңгөлөктүү отургучтагы киши: акжуумал',
    '👨🏼‍🦽' => 'кол менен дөңгөлөктүү отургучтагы киши: буудай жүздүү',
    '👨🏽‍🦽' => 'кол менен дөңгөлөктүү отургучтагы киши: орточо',
    '👨🏾‍🦽' => 'кол менен дөңгөлөктүү отургучтагы киши: кара тору',
    '👨🏿‍🦽' => 'кол менен дөңгөлөктүү отургучтагы киши: кара',
    '👩🏻‍🦽' => 'кол менен дөңгөлөктүү отургучтагы аял: акжуумал',
    '👩🏼‍🦽' => 'кол менен дөңгөлөктүү отургучтагы аял: буудай жүздүү',
    '👩🏽‍🦽' => 'кол менен дөңгөлөктүү отургучтагы аял: орточо',
    '👩🏾‍🦽' => 'кол менен дөңгөлөктүү отургучтагы аял: кара тору',
    '👩🏿‍🦽' => 'кол менен дөңгөлөктүү отургучтагы аял: кара',
    '🏃🏻‍♂' => 'чуркап бара жаткан эркек: акжуумал',
    '🏃🏼‍♂' => 'чуркап бара жаткан эркек: буудай жүздүү',
    '🏃🏽‍♂' => 'чуркап бара жаткан эркек: орточо',
    '🏃🏾‍♂' => 'чуркап бара жаткан эркек: кара тору',
    '🏃🏿‍♂' => 'чуркап бара жаткан эркек: кара',
    '🏃🏻‍♀' => 'чуркап бара жаткан аял: акжуумал',
    '🏃🏼‍♀' => 'чуркап бара жаткан аял: буудай жүздүү',
    '🏃🏽‍♀' => 'чуркап бара жаткан аял: орточо',
    '🏃🏾‍♀' => 'чуркап бара жаткан аял: кара тору',
    '🏃🏿‍♀' => 'чуркап бара жаткан аял: кара',
    '🏃🏻‍➡' => 'чуркап бара жаткан адам: акжуумал, оңду карап турат',
    '🏃🏼‍➡' => 'чуркап бара жаткан адам: буудай жүздүү, оңду карап турат',
    '🏃🏽‍➡' => 'чуркап бара жаткан адам: орточо, оңду карап турат',
    '🏃🏾‍➡' => 'чуркап бара жаткан адам: кара тору, оңду карап турат',
    '🏃🏿‍➡' => 'чуркап бара жаткан адам: кара, оңду карап турат',
    '👯🏻‍♀' => 'коен кулактарын тагынган кыздар: акжуумал',
    '👯🏼‍♀' => 'коен кулактарын тагынган кыздар: буудай жүздүү',
    '👯🏽‍♀' => 'коен кулактарын тагынган кыздар: орточо',
    '👯🏾‍♀' => 'коен кулактарын тагынган кыздар: кара тору',
    '👯🏿‍♀' => 'коен кулактарын тагынган кыздар: кара',
    '👯🏻‍♂' => 'коен кулактарын тагынган эркектер: акжуумал',
    '👯🏼‍♂' => 'коен кулактарын тагынган эркектер: буудай жүздүү',
    '👯🏽‍♂' => 'коен кулактарын тагынган эркектер: орточо',
    '👯🏾‍♂' => 'коен кулактарын тагынган эркектер: кара тору',
    '👯🏿‍♂' => 'коен кулактарын тагынган эркектер: кара',
    '🧖🏻‍♂' => 'бууланган бөлмөдө отурган эркек: акжуумал',
    '🧖🏼‍♂' => 'бууланган бөлмөдө отурган эркек: буудай жүздүү',
    '🧖🏽‍♂' => 'бууланган бөлмөдө отурган эркек: орточо',
    '🧖🏾‍♂' => 'бууланган бөлмөдө отурган эркек: кара тору',
    '🧖🏿‍♂' => 'бууланган бөлмөдө отурган эркек: кара',
    '🧖🏻‍♀' => 'бууланган бөлмөдө отурган аял: акжуумал',
    '🧖🏼‍♀' => 'бууланган бөлмөдө отурган аял: буудай жүздүү',
    '🧖🏽‍♀' => 'бууланган бөлмөдө отурган аял: орточо',
    '🧖🏾‍♀' => 'бууланган бөлмөдө отурган аял: кара тору',
    '🧖🏿‍♀' => 'бууланган бөлмөдө отурган аял: кара',
    '🧗🏻‍♂' => 'тоого чыгып жаткан эркек: акжуумал',
    '🧗🏼‍♂' => 'тоого чыгып жаткан эркек: буудай жүздүү',
    '🧗🏽‍♂' => 'тоого чыгып жаткан эркек: орточо',
    '🧗🏾‍♂' => 'тоого чыгып жаткан эркек: кара тору',
    '🧗🏿‍♂' => 'тоого чыгып жаткан эркек: кара',
    '🧗🏻‍♀' => 'тоого чыгып жаткан аял: акжуумал',
    '🧗🏼‍♀' => 'тоого чыгып жаткан аял: буудай жүздүү',
    '🧗🏽‍♀' => 'тоого чыгып жаткан аял: орточо',
    '🧗🏾‍♀' => 'тоого чыгып жаткан аял: кара тору',
    '🧗🏿‍♀' => 'тоого чыгып жаткан аял: кара',
    '🏌🏻‍♂' => 'гольф ойноп жаткан эркек: акжуумал',
    '🏌🏼‍♂' => 'гольф ойноп жаткан эркек: буудай жүздүү',
    '🏌🏽‍♂' => 'гольф ойноп жаткан эркек: орточо',
    '🏌🏾‍♂' => 'гольф ойноп жаткан эркек: кара тору',
    '🏌🏿‍♂' => 'гольф ойноп жаткан эркек: кара',
    '🏌🏻‍♀' => 'гольф ойноп жаткан аял: акжуумал',
    '🏌🏼‍♀' => 'гольф ойноп жаткан аял: буудай жүздүү',
    '🏌🏽‍♀' => 'гольф ойноп жаткан аял: орточо',
    '🏌🏾‍♀' => 'гольф ойноп жаткан аял: кара тору',
    '🏌🏿‍♀' => 'гольф ойноп жаткан аял: кара',
    '🏄🏻‍♂' => 'сёрфинг ойноп жаткан эркек: акжуумал',
    '🏄🏼‍♂' => 'сёрфинг ойноп жаткан эркек: буудай жүздүү',
    '🏄🏽‍♂' => 'сёрфинг ойноп жаткан эркек: орточо',
    '🏄🏾‍♂' => 'сёрфинг ойноп жаткан эркек: кара тору',
    '🏄🏿‍♂' => 'сёрфинг ойноп жаткан эркек: кара',
    '🏄🏻‍♀' => 'сёрфинг ойноп жаткан аял: акжуумал',
    '🏄🏼‍♀' => 'сёрфинг ойноп жаткан аял: буудай жүздүү',
    '🏄🏽‍♀' => 'сёрфинг ойноп жаткан аял: орточо',
    '🏄🏾‍♀' => 'сёрфинг ойноп жаткан аял: кара тору',
    '🏄🏿‍♀' => 'сёрфинг ойноп жаткан аял: кара',
    '🚣🏻‍♂' => 'калак сүзүп жаткан эркек: акжуумал',
    '🚣🏼‍♂' => 'калак сүзүп жаткан эркек: буудай жүздүү',
    '🚣🏽‍♂' => 'калак сүзүп жаткан эркек: орточо',
    '🚣🏾‍♂' => 'калак сүзүп жаткан эркек: кара тору',
    '🚣🏿‍♂' => 'калак сүзүп жаткан эркек: кара',
    '🚣🏻‍♀' => 'калак сүзүп жаткан аял: акжуумал',
    '🚣🏼‍♀' => 'калак сүзүп жаткан аял: буудай жүздүү',
    '🚣🏽‍♀' => 'калак сүзүп жаткан аял: орточо',
    '🚣🏾‍♀' => 'калак сүзүп жаткан аял: кара тору',
    '🚣🏿‍♀' => 'калак сүзүп жаткан аял: кара',
    '🏊🏻‍♂' => 'сүзүп бара жаткан эркек: акжуумал',
    '🏊🏼‍♂' => 'сүзүп бара жаткан эркек: буудай жүздүү',
    '🏊🏽‍♂' => 'сүзүп бара жаткан эркек: орточо',
    '🏊🏾‍♂' => 'сүзүп бара жаткан эркек: кара тору',
    '🏊🏿‍♂' => 'сүзүп бара жаткан эркек: кара',
    '🏊🏻‍♀' => 'сүзүп бара жаткан аял: акжуумал',
    '🏊🏼‍♀' => 'сүзүп бара жаткан аял: буудай жүздүү',
    '🏊🏽‍♀' => 'сүзүп бара жаткан аял: орточо',
    '🏊🏾‍♀' => 'сүзүп бара жаткан аял: кара тору',
    '🏊🏿‍♀' => 'сүзүп бара жаткан аял: кара',
    '⛹🏻‍♂' => 'топ кармаган эркек: акжуумал',
    '⛹🏼‍♂' => 'топ кармаган эркек: буудай жүздүү',
    '⛹🏽‍♂' => 'топ кармаган эркек: орточо',
    '⛹🏾‍♂' => 'топ кармаган эркек: кара тору',
    '⛹🏿‍♂' => 'топ кармаган эркек: кара',
    '⛹🏻‍♀' => 'топ кармаган аял: акжуумал',
    '⛹🏼‍♀' => 'топ кармаган аял: буудай жүздүү',
    '⛹🏽‍♀' => 'топ кармаган аял: орточо',
    '⛹🏾‍♀' => 'топ кармаган аял: кара тору',
    '⛹🏿‍♀' => 'топ кармаган аял: кара',
    '🏋🏻‍♂' => 'штанга көтөргөн эркек: акжуумал',
    '🏋🏼‍♂' => 'штанга көтөргөн эркек: буудай жүздүү',
    '🏋🏽‍♂' => 'штанга көтөргөн эркек: орточо',
    '🏋🏾‍♂' => 'штанга көтөргөн эркек: кара тору',
    '🏋🏿‍♂' => 'штанга көтөргөн эркек: кара',
    '🏋🏻‍♀' => 'штанга көтөргөн аял: акжуумал',
    '🏋🏼‍♀' => 'штанга көтөргөн аял: буудай жүздүү',
    '🏋🏽‍♀' => 'штанга көтөргөн аял: орточо',
    '🏋🏾‍♀' => 'штанга көтөргөн аял: кара тору',
    '🏋🏿‍♀' => 'штанга көтөргөн аял: кара',
    '🚴🏻‍♂' => 'велосипед тээп бара жаткан эркек: акжуумал',
    '🚴🏼‍♂' => 'велосипед тээп бара жаткан эркек: буудай жүздүү',
    '🚴🏽‍♂' => 'велосипед тээп бара жаткан эркек: орточо',
    '🚴🏾‍♂' => 'велосипед тээп бара жаткан эркек: кара тору',
    '🚴🏿‍♂' => 'велосипед тээп бара жаткан эркек: кара',
    '🚴🏻‍♀' => 'велосипед тээп бара жаткан аял: акжуумал',
    '🚴🏼‍♀' => 'велосипед тээп бара жаткан аял: буудай жүздүү',
    '🚴🏽‍♀' => 'велосипед тээп бара жаткан аял: орточо',
    '🚴🏾‍♀' => 'велосипед тээп бара жаткан аял: кара тору',
    '🚴🏿‍♀' => 'велосипед тээп бара жаткан аял: кара',
    '🚵🏻‍♂' => 'тоодо велосипед тээп бара жаткан эркек: акжуумал',
    '🚵🏼‍♂' => 'тоодо велосипед тээп бара жаткан эркек: буудай жүздүү',
    '🚵🏽‍♂' => 'тоодо велосипед тээп бара жаткан эркек: орточо',
    '🚵🏾‍♂' => 'тоодо велосипед тээп бара жаткан эркек: кара тору',
    '🚵🏿‍♂' => 'тоодо велосипед тээп бара жаткан эркек: кара',
    '🚵🏻‍♀' => 'тоодо велосипед тээп бара жаткан аял: акжуумал',
    '🚵🏼‍♀' => 'тоодо велосипед тээп бара жаткан аял: буудай жүздүү',
    '🚵🏽‍♀' => 'тоодо велосипед тээп бара жаткан аял: орточо',
    '🚵🏾‍♀' => 'тоодо велосипед тээп бара жаткан аял: кара тору',
    '🚵🏿‍♀' => 'тоодо велосипед тээп бара жаткан аял: кара',
    '🤸🏻‍♂' => 'машыгып жаткан эркек: акжуумал',
    '🤸🏼‍♂' => 'машыгып жаткан эркек: буудай жүздүү',
    '🤸🏽‍♂' => 'машыгып жаткан эркек: орточо',
    '🤸🏾‍♂' => 'машыгып жаткан эркек: кара тору',
    '🤸🏿‍♂' => 'машыгып жаткан эркек: кара',
    '🤸🏻‍♀' => 'акробатикалык көнүгүү жасап жаткан аял: акжуумал',
    '🤸🏼‍♀' => 'акробатикалык көнүгүү жасап жаткан аял: буудай жүздүү',
    '🤸🏽‍♀' => 'акробатикалык көнүгүү жасап жаткан аял: орточо',
    '🤸🏾‍♀' => 'акробатикалык көнүгүү жасап жаткан аял: кара тору',
    '🤸🏿‍♀' => 'акробатикалык көнүгүү жасап жаткан аял: кара',
    '🤼🏻‍♀' => 'күрөшүп жаткан аял: акжуумал',
    '🤼🏼‍♀' => 'күрөшүп жаткан аял: буудай жүздүү',
    '🤼🏽‍♀' => 'күрөшүп жаткан аял: орточо',
    '🤼🏾‍♀' => 'күрөшүп жаткан аял: кара тору',
    '🤼🏿‍♀' => 'күрөшүп жаткан аял: кара',
    '🤼🏻‍♂' => 'күрөшүп жаткан эркек: акжуумал',
    '🤼🏼‍♂' => 'күрөшүп жаткан эркек: буудай жүздүү',
    '🤼🏽‍♂' => 'күрөшүп жаткан эркек: орточо',
    '🤼🏾‍♂' => 'күрөшүп жаткан эркек: кара тору',
    '🤼🏿‍♂' => 'күрөшүп жаткан эркек: кара',
    '🤽🏻‍♂' => 'суудагы поло оюнун ойноп жаткан эркек: акжуумал',
    '🤽🏼‍♂' => 'суудагы поло оюнун ойноп жаткан эркек: буудай жүздүү',
    '🤽🏽‍♂' => 'суудагы поло оюнун ойноп жаткан эркек: орточо',
    '🤽🏾‍♂' => 'суудагы поло оюнун ойноп жаткан эркек: кара тору',
    '🤽🏿‍♂' => 'суудагы поло оюнун ойноп жаткан эркек: кара',
    '🤽🏻‍♀' => 'суудагы поло оюнун ойноп жаткан аял: акжуумал',
    '🤽🏼‍♀' => 'суудагы поло оюнун ойноп жаткан аял: буудай жүздүү',
    '🤽🏽‍♀' => 'суудагы поло оюнун ойноп жаткан аял: орточо',
    '🤽🏾‍♀' => 'суудагы поло оюнун ойноп жаткан аял: кара тору',
    '🤽🏿‍♀' => 'суудагы поло оюнун ойноп жаткан аял: кара',
    '🤾🏻‍♂' => 'гандбол ойноп жаткан эркек: акжуумал',
    '🤾🏼‍♂' => 'гандбол ойноп жаткан эркек: буудай жүздүү',
    '🤾🏽‍♂' => 'гандбол ойноп жаткан эркек: орточо',
    '🤾🏾‍♂' => 'гандбол ойноп жаткан эркек: кара тору',
    '🤾🏿‍♂' => 'гандбол ойноп жаткан эркек: кара',
    '🤾🏻‍♀' => 'гандбол ойноп жаткан аял: акжуумал',
    '🤾🏼‍♀' => 'гандбол ойноп жаткан аял: буудай жүздүү',
    '🤾🏽‍♀' => 'гандбол ойноп жаткан аял: орточо',
    '🤾🏾‍♀' => 'гандбол ойноп жаткан аял: кара тору',
    '🤾🏿‍♀' => 'гандбол ойноп жаткан аял: кара',
    '🤹🏻‍♂' => 'жонглер эркек: акжуумал',
    '🤹🏼‍♂' => 'жонглер эркек: буудай жүздүү',
    '🤹🏽‍♂' => 'жонглер эркек: орточо',
    '🤹🏾‍♂' => 'жонглер эркек: кара тору',
    '🤹🏿‍♂' => 'жонглер эркек: кара',
    '🤹🏻‍♀' => 'жонглер аял: акжуумал',
    '🤹🏼‍♀' => 'жонглер аял: буудай жүздүү',
    '🤹🏽‍♀' => 'жонглер аял: орточо',
    '🤹🏾‍♀' => 'жонглер аял: кара тору',
    '🤹🏿‍♀' => 'жонглер аял: кара',
    '🧘🏻‍♂' => 'йога жасап жаткан эркек: акжуумал',
    '🧘🏼‍♂' => 'йога жасап жаткан эркек: буудай жүздүү',
    '🧘🏽‍♂' => 'йога жасап жаткан эркек: орточо',
    '🧘🏾‍♂' => 'йога жасап жаткан эркек: кара тору',
    '🧘🏿‍♂' => 'йога жасап жаткан эркек: кара',
    '🧘🏻‍♀' => 'йога жасап жаткан аял: акжуумал',
    '🧘🏼‍♀' => 'йога жасап жаткан аял: буудай жүздүү',
    '🧘🏽‍♀' => 'йога жасап жаткан аял: орточо',
    '🧘🏾‍♀' => 'йога жасап жаткан аял: кара тору',
    '🧘🏿‍♀' => 'йога жасап жаткан аял: кара',
    '🧑‍🦰' => 'адам: кызыл чач',
    '🧑‍🦱' => 'адам: тармал чач',
    '🧑‍🦳' => 'адам: ак чач',
    '🧑‍🦲' => 'адам: тас',
    '👨‍🦰' => 'эркек: кызыл чач',
    '👨‍🦱' => 'эркек: тармал чач',
    '👨‍🦳' => 'эркек: ак чач',
    '👨‍🦲' => 'эркек: тас',
    '👩‍🦰' => 'аял: кызыл чач',
    '👩‍🦱' => 'аял: тармал чач',
    '👩‍🦳' => 'аял: ак чач',
    '👩‍🦲' => 'аял: тас',
    '🚶‍➡' => 'жөө адам: оңду карап турат',
    '🧎‍➡' => 'тизелеген адам: оңду карап турат',
    '🏃‍➡' => 'чуркап бара жаткан адам: оңду карап турат',
    '👨‍👦' => 'үй-бүлө: эркек, бала',
    '👨‍👧' => 'үй-бүлө: эркек, кыз',
    '👩‍👦' => 'үй-бүлө: аял, бала',
    '👩‍👧' => 'үй-бүлө: аял, кыз',
    '😶‍🌫' => 'булуттагы жүз',
    '😮‍💨' => 'үшкүрүнгөн жүз',
    '🙂‍↕' => 'өйдөдөн ылдый ийилген жүз',
    '😵‍💫' => 'көздүн ордуна спираль тартылган жүз',
    '❤‍🔥' => 'өрттөнгөн жүрөк',
    '❤‍🩹' => 'жарасы чапталган жүрөк',
    '👁‍🗨' => 'кеп көбүгүндөгү көз',
    '🧔‍♂' => 'киши: сакал',
    '👱‍♂' => 'сары чачтуу эркек',
    '🧔‍♀' => 'аял : сакал',
    '👱‍♀' => 'сары чачтуу аял',
    '🙍‍♂' => 'кабагын бүркөгөн эркек',
    '🙍‍♀' => 'кабагын бүркөгөн аял',
    '🙎‍♂' => 'тултуюп таарынган эркек',
    '🙎‍♀' => 'тултуюп таарынган аял',
    '🙅‍♂' => 'ЖОК деп жаткан эркек',
    '🙅‍♀' => '«жок» деп жаткан аял',
    '🙆‍♂' => '«жарайт» деп жаткан эркек',
    '🙆‍♀' => '«жарайт» деп жаткан аял',
    '💁‍♂' => 'Баш кийимин чечип учурашкан эркек',
    '💁‍♀' => 'Баш кийимин чечип учурашкан аял',
    '🙋‍♂' => 'колун көтөрүп жаткан эркек',
    '🙋‍♀' => 'колун көтөрүп жаткан аял',
    '🧏‍♂' => 'дүлөй адам',
    '🧏‍♀' => 'дүлөй аял',
    '🙇‍♂' => 'жүгүнүп жаткан эркек',
    '🙇‍♀' => 'жүгүнүп жаткан аял',
    '🤦‍♂' => 'бетин кармаган эркек',
    '🤦‍♀' => 'бетин кармаган аял',
    '🤷‍♂' => 'ийинин куушурган эркек',
    '🤷‍♀' => 'ийинин куушурган аял',
    '🧑‍⚕' => 'медицина кызматкери',
    '👨‍⚕' => 'эркек медицина кызматкери',
    '👩‍⚕' => 'аял медицина кызматкери',
    '🧑‍🎓' => 'студент',
    '👨‍🎓' => 'эркек студент',
    '👩‍🎓' => 'аял студент',
    '🧑‍🏫' => 'мугалим',
    '👨‍🏫' => 'эркек мугалим',
    '👩‍🏫' => 'аял мугалим',
    '🧑‍⚖' => 'сот',
    '👨‍⚖' => 'эркек сот',
    '👩‍⚖' => 'аял сот',
    '🧑‍🌾' => 'фермер',
    '👨‍🌾' => 'эркек фермер',
    '👩‍🌾' => 'аял фермер',
    '🧑‍🍳' => 'ашпозчу',
    '👨‍🍳' => 'эркек ашпозчу',
    '👩‍🍳' => 'аял ашпозчу',
    '🧑‍🔧' => 'механик',
    '👨‍🔧' => 'эркек механик',
    '👩‍🔧' => 'аял механик',
    '🧑‍🏭' => 'завод жумушчусу',
    '👨‍🏭' => 'эркек завод жумушчусу',
    '👩‍🏭' => 'аял завод жумушчусу',
    '🧑‍💼' => 'кеңсе кызматкери',
    '👨‍💼' => 'эркек офис жумушчусу',
    '👩‍💼' => 'аял офис жумушчусу',
    '🧑‍🔬' => 'илимпоз',
    '👨‍🔬' => 'эркек илимпоз',
    '👩‍🔬' => 'аял илимпоз',
    '🧑‍💻' => 'IT адиси',
    '👨‍💻' => 'эркек технолог',
    '👩‍💻' => 'аял технолог',
    '🧑‍🎤' => 'ырчы',
    '👨‍🎤' => 'эркек ырчы',
    '👩‍🎤' => 'аял ырчы',
    '🧑‍🎨' => 'сүрөтчү',
    '👨‍🎨' => 'эркек сүрөтчү',
    '👩‍🎨' => 'аял сүрөтчү',
    '🧑‍✈' => 'пилот',
    '👨‍✈' => 'эркек учкуч',
    '👩‍✈' => 'аял учкуч',
    '🧑‍🚀' => 'космонавт',
    '👨‍🚀' => 'эркек космонавт',
    '👩‍🚀' => 'аял космонавт',
    '🧑‍🚒' => 'өрт өчүрүүчү',
    '👨‍🚒' => 'эркек өрт өчүргүч',
    '👩‍🚒' => 'аял өрт өчүргүч',
    '👮‍♂' => 'эркек милиция кызматкери',
    '👮‍♀' => 'аял милиция кызматкери',
    '🕵‍♂' => 'детектив киши',
    '🕵‍♀' => 'детектив аял',
    '💂‍♂' => 'эркек кароолчу',
    '💂‍♀' => 'аял кароолчу',
    '👷‍♂' => 'эркек курулуш кызматкери',
    '👷‍♀' => 'аял курулуш кызматкери',
    '👳‍♂' => 'селдечен эркек',
    '👳‍♀' => 'селдечен аял',
    '🤵‍♂' => 'смокинг кийген адам',
    '🤵‍♀' => 'смокинг кийген аял',
    '👰‍♂' => 'вуальчан эркек',
    '👰‍♀' => 'вуальчан аял',
    '👩‍🍼' => 'балага тамак берип жаткан аял',
    '👨‍🍼' => 'балага тамак берип жаткан эркек киши',
    '🧑‍🍼' => 'балага тамак берип жаткан адам',
    '🧑‍🎄' => 'клаус',
    '🦸‍♂' => 'баатыр жигит',
    '🦸‍♀' => 'супер баатыр кыз',
    '🦹‍♂' => 'карасантай жигит',
    '🦹‍♀' => 'карасантай кыз',
    '🧙‍♂' => 'эркек сыйкырчы',
    '🧙‍♀' => 'аял сыйкырчы',
    '🧚‍♂' => 'эркек фея',
    '🧚‍♀' => 'аял фея',
    '🧛‍♂' => 'эркек кан соргуч',
    '🧛‍♀' => 'аял кан соргуч',
    '🧜‍♂' => 'эркек русалка',
    '🧜‍♀' => 'русалка',
    '🧝‍♂' => 'эркек эльф',
    '🧝‍♀' => 'аял эльф',
    '🧞‍♂' => 'эркек жин',
    '🧞‍♀' => 'албарсты',
    '🧟‍♂' => 'эркек зомби',
    '🧟‍♀' => 'аял зомби',
    '💆‍♂' => 'бетине массаж алып жаткан эркек',
    '💆‍♀' => 'бетине массаж алып жаткан аял',
    '💇‍♂' => 'чачын кырктырып жаткан эркек',
    '💇‍♀' => 'чачын кырктырып жаткан аял',
    '🚶‍♂' => 'жөө басып бара жаткан эркек',
    '🚶‍♀' => 'жөө басып бара жаткан аял',
    '🧍‍♂' => 'киши турат',
    '🧍‍♀' => 'аял турат',
    '🧎‍♂' => 'тизелеген киши',
    '🧎‍♀' => 'аял тизелөөдө',
    '🧑‍🦯' => 'таякка жөлөнгөн киши',
    '👨‍🦯' => 'таяк таянган киши',
    '👩‍🦯' => 'таяк таянган аял',
    '🧑‍🦼' => 'мотору бар инвалид креслосундагы киши',
    '👨‍🦼' => 'моторлуу дөңгөлөк отургучтагы киши',
    '👩‍🦼' => 'мотору бар дөңгөлөктүү отургучтагы аял',
    '🧑‍🦽' => 'кол менен иштеген кресло',
    '👨‍🦽' => 'кол менен дөңгөлөктүү отургучтагы киши',
    '👩‍🦽' => 'кол менен дөңгөлөктүү отургучтагы аял',
    '🏃‍♂' => 'чуркап бара жаткан эркек',
    '🏃‍♀' => 'чуркап бара жаткан аял',
    '🧑‍🩰' => 'балет бийчиси',
    '👯‍♂' => 'коен кулактарын тагынган эркектер',
    '👯‍♀' => 'коен кулактарын тагынган кыздар',
    '🧖‍♂' => 'бууланган бөлмөдө отурган эркек',
    '🧖‍♀' => 'бууланган бөлмөдө отурган аял',
    '🧗‍♂' => 'тоого чыгып жаткан эркек',
    '🧗‍♀' => 'тоого чыгып жаткан аял',
    '🏌‍♂' => 'гольф ойноп жаткан эркек',
    '🏌‍♀' => 'гольф ойноп жаткан аял',
    '🏄‍♂' => 'сёрфинг ойноп жаткан эркек',
    '🏄‍♀' => 'сёрфинг ойноп жаткан аял',
    '🚣‍♂' => 'калак сүзүп жаткан эркек',
    '🚣‍♀' => 'калак сүзүп жаткан аял',
    '🏊‍♂' => 'сүзүп бара жаткан эркек',
    '🏊‍♀' => 'сүзүп бара жаткан аял',
    '⛹‍♂' => 'топ кармаган эркек',
    '⛹‍♀' => 'топ кармаган аял',
    '🏋‍♂' => 'штанга көтөргөн эркек',
    '🏋‍♀' => 'штанга көтөргөн аял',
    '🚴‍♂' => 'велосипед тээп бара жаткан эркек',
    '🚴‍♀' => 'велосипед тээп бара жаткан аял',
    '🚵‍♂' => 'тоодо велосипед тээп бара жаткан эркек',
    '🚵‍♀' => 'тоодо велосипед тээп бара жаткан аял',
    '🤸‍♂' => 'машыгып жаткан эркек',
    '🤸‍♀' => 'акробатикалык көнүгүү жасап жаткан аял',
    '🤼‍♂' => 'күрөшүп жаткан эркек',
    '🤼‍♀' => 'күрөшүп жаткан аял',
    '🤽‍♂' => 'суудагы поло оюнун ойноп жаткан эркек',
    '🤽‍♀' => 'суудагы поло оюнун ойноп жаткан аял',
    '🤾‍♂' => 'гандбол ойноп жаткан эркек',
    '🤾‍♀' => 'гандбол ойноп жаткан аял',
    '🤹‍♂' => 'жонглер эркек',
    '🤹‍♀' => 'жонглер аял',
    '🧘‍♂' => 'йога жасап жаткан эркек',
    '🧘‍♀' => 'йога жасап жаткан аял',
    '🧑‍🧒' => 'үй-бүлө: чоң киши, бала',
    '🐕‍🦺' => 'кызматчы ит',
    '🐈‍⬛' => 'кара мышык',
    '🐻‍❄' => 'полярдык аюу',
    '🐦‍⬛' => 'кара чымчык',
    '🐦‍🔥' => 'феникс',
    '🍋‍🟩' => 'жашыл лимон',
    '🍄‍🟫' => 'күрөң козу карын',
    '⛓‍💥' => 'сынган чынжыр',
    '🏳‍🌈' => 'асан-үсөн желеги',
    '🏳‍⚧' => 'трансгендер желеги',
    '🏴‍☠' => 'каракчылардын желеги',
    '👋🏻' => 'кол булгалоо: акжуумал',
    '👋🏼' => 'кол булгалоо: буудай жүздүү',
    '👋🏽' => 'кол булгалоо: орточо',
    '👋🏾' => 'кол булгалоо: кара тору',
    '👋🏿' => 'кол булгалоо: кара',
    '🤚🏻' => 'көтөрүлгөн алакан: акжуумал',
    '🤚🏼' => 'көтөрүлгөн алакан: буудай жүздүү',
    '🤚🏽' => 'көтөрүлгөн алакан: орточо',
    '🤚🏾' => 'көтөрүлгөн алакан: кара тору',
    '🤚🏿' => 'көтөрүлгөн алакан: кара',
    '🖐🏻' => 'беш манжа: акжуумал',
    '🖐🏼' => 'беш манжа: буудай жүздүү',
    '🖐🏽' => 'беш манжа: орточо',
    '🖐🏾' => 'беш манжа: кара тору',
    '🖐🏿' => 'беш манжа: кара',
    '✋🏻' => 'кол көтөрүү: акжуумал',
    '✋🏼' => 'кол көтөрүү: буудай жүздүү',
    '✋🏽' => 'кол көтөрүү: орточо',
    '✋🏾' => 'кол көтөрүү: кара тору',
    '✋🏿' => 'кол көтөрүү: кара',
    '🖖🏻' => 'вулкандыктарча салам: акжуумал',
    '🖖🏼' => 'вулкандыктарча салам: буудай жүздүү',
    '🖖🏽' => 'вулкандыктарча салам: орточо',
    '🖖🏾' => 'вулкандыктарча салам: кара тору',
    '🖖🏿' => 'вулкандыктарча салам: кара',
    '🫱🏻' => 'оңду көрсөткөн кол: акжуумал',
    '🫱🏼' => 'оңду көрсөткөн кол: буудай жүздүү',
    '🫱🏽' => 'оңду көрсөткөн кол: орточо',
    '🫱🏾' => 'оңду көрсөткөн кол: кара тору',
    '🫱🏿' => 'оңду көрсөткөн кол: кара',
    '🫲🏻' => 'солду көрсөткөн кол: акжуумал',
    '🫲🏼' => 'солду көрсөткөн кол: буудай жүздүү',
    '🫲🏽' => 'солду көрсөткөн кол: орточо',
    '🫲🏾' => 'солду көрсөткөн кол: кара тору',
    '🫲🏿' => 'солду көрсөткөн кол: кара',
    '🫳🏻' => 'алаканы ылдый караган кол: акжуумал',
    '🫳🏼' => 'алаканы ылдый караган кол: буудай жүздүү',
    '🫳🏽' => 'алаканы ылдый караган кол: орточо',
    '🫳🏾' => 'алаканы ылдый караган кол: кара тору',
    '🫳🏿' => 'алаканы ылдый караган кол: кара',
    '🫴🏻' => 'алаканы өйдө караган кол: акжуумал',
    '🫴🏼' => 'алаканы өйдө караган кол: буудай жүздүү',
    '🫴🏽' => 'алаканы өйдө караган кол: орточо',
    '🫴🏾' => 'алаканы өйдө караган кол: кара тору',
    '🫴🏿' => 'алаканы өйдө караган кол: кара',
    '🫷🏻' => 'сол жакка түрткөн кол: акжуумал',
    '🫷🏼' => 'сол жакка түрткөн кол: буудай жүздүү',
    '🫷🏽' => 'сол жакка түрткөн кол: орточо',
    '🫷🏾' => 'сол жакка түрткөн кол: кара тору',
    '🫷🏿' => 'сол жакка түрткөн кол: кара',
    '🫸🏻' => 'оң жакка түрткөн кол: акжуумал',
    '🫸🏼' => 'оң жакка түрткөн кол: буудай жүздүү',
    '🫸🏽' => 'оң жакка түрткөн кол: орточо',
    '🫸🏾' => 'оң жакка түрткөн кол: кара тору',
    '🫸🏿' => 'оң жакка түрткөн кол: кара',
    '👌🏻' => '«ОК» белгиси: акжуумал',
    '👌🏼' => '«ОК» белгиси: буудай жүздүү',
    '👌🏽' => '«ОК» белгиси: орточо',
    '👌🏾' => '«ОК» белгиси: кара тору',
    '👌🏿' => '«ОК» белгиси: кара',
    '🤌🏻' => 'кыстырылган манжалар: акжуумал',
    '🤌🏼' => 'кыстырылган манжалар: буудай жүздүү',
    '🤌🏽' => 'кыстырылган манжалар: орточо',
    '🤌🏾' => 'кыстырылган манжалар: кара тору',
    '🤌🏿' => 'кыстырылган манжалар: кара',
    '🤏🏻' => 'чычмыган кол: акжуумал',
    '🤏🏼' => 'чычмыган кол: буудай жүздүү',
    '🤏🏽' => 'чычмыган кол: орточо',
    '🤏🏾' => 'чычмыган кол: кара тору',
    '🤏🏿' => 'чычмыган кол: кара',
    '✌🏻' => 'эки дегенди көрсөткөн манжалар: акжуумал',
    '✌🏼' => 'эки дегенди көрсөткөн манжалар: буудай жүздүү',
    '✌🏽' => 'эки дегенди көрсөткөн манжалар: орточо',
    '✌🏾' => 'эки дегенди көрсөткөн манжалар: кара тору',
    '✌🏿' => 'эки дегенди көрсөткөн манжалар: кара',
    '🤞🏻' => 'кайчылаштырылган манжалар: акжуумал',
    '🤞🏼' => 'кайчылаштырылган манжалар: буудай жүздүү',
    '🤞🏽' => 'кайчылаштырылган манжалар: орточо',
    '🤞🏾' => 'кайчылаштырылган манжалар: кара тору',
    '🤞🏿' => 'кайчылаштырылган манжалар: кара',
    '🫰🏻' => 'сөөмөй менен бармак кайчылаштырылган кол: акжуумал',
    '🫰🏼' => 'сөөмөй менен бармак кайчылаштырылган кол: буудай жүздүү',
    '🫰🏽' => 'сөөмөй менен бармак кайчылаштырылган кол: орточо',
    '🫰🏾' => 'сөөмөй менен бармак кайчылаштырылган кол: кара тору',
    '🫰🏿' => 'сөөмөй менен бармак кайчылаштырылган кол: кара',
    '🤟🏻' => 'сүйөм сени деген ишарат: акжуумал',
    '🤟🏼' => 'сүйөм сени деген ишарат: буудай жүздүү',
    '🤟🏽' => 'сүйөм сени деген ишарат: орточо',
    '🤟🏾' => 'сүйөм сени деген ишарат: кара тору',
    '🤟🏿' => 'сүйөм сени деген ишарат: кара',
    '🤘🏻' => 'мүйүз белгиси: акжуумал',
    '🤘🏼' => 'мүйүз белгиси: буудай жүздүү',
    '🤘🏽' => 'мүйүз белгиси: орточо',
    '🤘🏾' => 'мүйүз белгиси: кара тору',
    '🤘🏿' => 'мүйүз белгиси: кара',
    '🤙🏻' => '“мага чал” ишараты: акжуумал',
    '🤙🏼' => '“мага чал” ишараты: буудай жүздүү',
    '🤙🏽' => '“мага чал” ишараты: орточо',
    '🤙🏾' => '“мага чал” ишараты: кара тору',
    '🤙🏿' => '“мага чал” ишараты: кара',
    '👈🏻' => 'сол тарапты көрсөткөн сөөмөй: акжуумал',
    '👈🏼' => 'сол тарапты көрсөткөн сөөмөй: буудай жүздүү',
    '👈🏽' => 'сол тарапты көрсөткөн сөөмөй: орточо',
    '👈🏾' => 'сол тарапты көрсөткөн сөөмөй: кара тору',
    '👈🏿' => 'сол тарапты көрсөткөн сөөмөй: кара',
    '👉🏻' => 'оң тарапты көрсөткөн сөөмөй: акжуумал',
    '👉🏼' => 'оң тарапты көрсөткөн сөөмөй: буудай жүздүү',
    '👉🏽' => 'оң тарапты көрсөткөн сөөмөй: орточо',
    '👉🏾' => 'оң тарапты көрсөткөн сөөмөй: кара тору',
    '👉🏿' => 'оң тарапты көрсөткөн сөөмөй: кара',
    '👆🏻' => 'сөөмөйү өйдө караган колдун арткы бети: акжуумал',
    '👆🏼' => 'сөөмөйү өйдө караган колдун арткы бети: буудай жүздүү',
    '👆🏽' => 'сөөмөйү өйдө караган колдун арткы бети: орточо',
    '👆🏾' => 'сөөмөйү өйдө караган колдун арткы бети: кара тору',
    '👆🏿' => 'сөөмөйү өйдө караган колдун арткы бети: кара',
    '🖕🏻' => 'ортон: акжуумал',
    '🖕🏼' => 'ортон: буудай жүздүү',
    '🖕🏽' => 'ортон: орточо',
    '🖕🏾' => 'ортон: кара тору',
    '🖕🏿' => 'ортон: кара',
    '👇🏻' => 'төмөн жакты көрсөткөн сөөмөй: акжуумал',
    '👇🏼' => 'төмөн жакты көрсөткөн сөөмөй: буудай жүздүү',
    '👇🏽' => 'төмөн жакты көрсөткөн сөөмөй: орточо',
    '👇🏾' => 'төмөн жакты көрсөткөн сөөмөй: кара тору',
    '👇🏿' => 'төмөн жакты көрсөткөн сөөмөй: кара',
    '☝🏻' => 'өйдө жакты көрсөткөн сөөмөй: акжуумал',
    '☝🏼' => 'өйдө жакты көрсөткөн сөөмөй: буудай жүздүү',
    '☝🏽' => 'өйдө жакты көрсөткөн сөөмөй: орточо',
    '☝🏾' => 'өйдө жакты көрсөткөн сөөмөй: кара тору',
    '☝🏿' => 'өйдө жакты көрсөткөн сөөмөй: кара',
    '🫵🏻' => 'көрүүчүгө багытталган сөөмөй: акжуумал',
    '🫵🏼' => 'көрүүчүгө багытталган сөөмөй: буудай жүздүү',
    '🫵🏽' => 'көрүүчүгө багытталган сөөмөй: орточо',
    '🫵🏾' => 'көрүүчүгө багытталган сөөмөй: кара тору',
    '🫵🏿' => 'көрүүчүгө багытталган сөөмөй: кара',
    '👍🏻' => '«сонун»: акжуумал',
    '👍🏼' => '«сонун»: буудай жүздүү',
    '👍🏽' => '«сонун»: орточо',
    '👍🏾' => '«сонун»: кара тору',
    '👍🏿' => '«сонун»: кара',
    '👎🏻' => '«начар»: акжуумал',
    '👎🏼' => '«начар»: буудай жүздүү',
    '👎🏽' => '«начар»: орточо',
    '👎🏾' => '«начар»: кара тору',
    '👎🏿' => '«начар»: кара',
    '✊🏻' => 'көтөрүлгөн муштум: акжуумал',
    '✊🏼' => 'көтөрүлгөн муштум: буудай жүздүү',
    '✊🏽' => 'көтөрүлгөн муштум: орточо',
    '✊🏾' => 'көтөрүлгөн муштум: кара тору',
    '✊🏿' => 'көтөрүлгөн муштум: кара',
    '👊🏻' => 'уруп жаткан муштум: акжуумал',
    '👊🏼' => 'уруп жаткан муштум: буудай жүздүү',
    '👊🏽' => 'уруп жаткан муштум: орточо',
    '👊🏾' => 'уруп жаткан муштум: кара тору',
    '👊🏿' => 'уруп жаткан муштум: кара',
    '🤛🏻' => 'солго караган муштум: акжуумал',
    '🤛🏼' => 'солго караган муштум: буудай жүздүү',
    '🤛🏽' => 'солго караган муштум: орточо',
    '🤛🏾' => 'солго караган муштум: кара тору',
    '🤛🏿' => 'солго караган муштум: кара',
    '🤜🏻' => 'оңго караган муштум: акжуумал',
    '🤜🏼' => 'оңго караган муштум: буудай жүздүү',
    '🤜🏽' => 'оңго караган муштум: орточо',
    '🤜🏾' => 'оңго караган муштум: кара тору',
    '🤜🏿' => 'оңго караган муштум: кара',
    '👏🏻' => 'кол чабуу: акжуумал',
    '👏🏼' => 'кол чабуу: буудай жүздүү',
    '👏🏽' => 'кол чабуу: орточо',
    '👏🏾' => 'кол чабуу: кара тору',
    '👏🏿' => 'кол чабуу: кара',
    '🙌🏻' => 'кол көтөрүп жаткан адам: акжуумал',
    '🙌🏼' => 'кол көтөрүп жаткан адам: буудай жүздүү',
    '🙌🏽' => 'кол көтөрүп жаткан адам: орточо',
    '🙌🏾' => 'кол көтөрүп жаткан адам: кара тору',
    '🙌🏿' => 'кол көтөрүп жаткан адам: кара',
    '🫶🏻' => 'жүрөк кол: акжуумал',
    '🫶🏼' => 'жүрөк кол: буудай жүздүү',
    '🫶🏽' => 'жүрөк кол: орточо',
    '🫶🏾' => 'жүрөк кол: кара тору',
    '🫶🏿' => 'жүрөк кол: кара',
    '👐🏻' => 'ачык алакандар: акжуумал',
    '👐🏼' => 'ачык алакандар: буудай жүздүү',
    '👐🏽' => 'ачык алакандар: орточо',
    '👐🏾' => 'ачык алакандар: кара тору',
    '👐🏿' => 'ачык алакандар: кара',
    '🤲🏻' => 'алакан жаюу: акжуумал',
    '🤲🏼' => 'алакан жаюу: буудай жүздүү',
    '🤲🏽' => 'алакан жаюу: орточо',
    '🤲🏾' => 'алакан жаюу: кара тору',
    '🤲🏿' => 'алакан жаюу: кара',
    '🤝🏻' => 'кол алышуу: акжуумал',
    '🤝🏼' => 'кол алышуу: буудай жүздүү',
    '🤝🏽' => 'кол алышуу: орточо',
    '🤝🏾' => 'кол алышуу: кара тору',
    '🤝🏿' => 'кол алышуу: кара',
    '🙏🏻' => 'алаканын бириктирген колдор: акжуумал',
    '🙏🏼' => 'алаканын бириктирген колдор: буудай жүздүү',
    '🙏🏽' => 'алаканын бириктирген колдор: орточо',
    '🙏🏾' => 'алаканын бириктирген колдор: кара тору',
    '🙏🏿' => 'алаканын бириктирген колдор: кара',
    '✍🏻' => 'жазып жаткан кол: акжуумал',
    '✍🏼' => 'жазып жаткан кол: буудай жүздүү',
    '✍🏽' => 'жазып жаткан кол: орточо',
    '✍🏾' => 'жазып жаткан кол: кара тору',
    '✍🏿' => 'жазып жаткан кол: кара',
    '💅🏻' => 'тырмак боёо: акжуумал',
    '💅🏼' => 'тырмак боёо: буудай жүздүү',
    '💅🏽' => 'тырмак боёо: орточо',
    '💅🏾' => 'тырмак боёо: кара тору',
    '💅🏿' => 'тырмак боёо: кара',
    '🤳🏻' => 'селфи: акжуумал',
    '🤳🏼' => 'селфи: буудай жүздүү',
    '🤳🏽' => 'селфи: орточо',
    '🤳🏾' => 'селфи: кара тору',
    '🤳🏿' => 'селфи: кара',
    '💪🏻' => 'түйүлгөн булчуң: акжуумал',
    '💪🏼' => 'түйүлгөн булчуң: буудай жүздүү',
    '💪🏽' => 'түйүлгөн булчуң: орточо',
    '💪🏾' => 'түйүлгөн булчуң: кара тору',
    '💪🏿' => 'түйүлгөн булчуң: кара',
    '🦵🏻' => 'жоон сан: акжуумал',
    '🦵🏼' => 'жоон сан: буудай жүздүү',
    '🦵🏽' => 'жоон сан: орточо',
    '🦵🏾' => 'жоон сан: кара тору',
    '🦵🏿' => 'жоон сан: кара',
    '🦶🏻' => 'бут: акжуумал',
    '🦶🏼' => 'бут: буудай жүздүү',
    '🦶🏽' => 'бут: орточо',
    '🦶🏾' => 'бут: кара тору',
    '🦶🏿' => 'бут: кара',
    '👂🏻' => 'кулак: акжуумал',
    '👂🏼' => 'кулак: буудай жүздүү',
    '👂🏽' => 'кулак: орточо',
    '👂🏾' => 'кулак: кара тору',
    '👂🏿' => 'кулак: кара',
    '🦻🏻' => 'угуу аппараты менен кулак: акжуумал',
    '🦻🏼' => 'угуу аппараты менен кулак: буудай жүздүү',
    '🦻🏽' => 'угуу аппараты менен кулак: орточо',
    '🦻🏾' => 'угуу аппараты менен кулак: кара тору',
    '🦻🏿' => 'угуу аппараты менен кулак: кара',
    '👃🏻' => 'мурун: акжуумал',
    '👃🏼' => 'мурун: буудай жүздүү',
    '👃🏽' => 'мурун: орточо',
    '👃🏾' => 'мурун: кара тору',
    '👃🏿' => 'мурун: кара',
    '👶🏻' => 'кичинекей бала: акжуумал',
    '👶🏼' => 'кичинекей бала: буудай жүздүү',
    '👶🏽' => 'кичинекей бала: орточо',
    '👶🏾' => 'кичинекей бала: кара тору',
    '👶🏿' => 'кичинекей бала: кара',
    '🧒🏻' => 'чүрпө: акжуумал',
    '🧒🏼' => 'чүрпө: буудай жүздүү',
    '🧒🏽' => 'чүрпө: орточо',
    '🧒🏾' => 'чүрпө: кара тору',
    '🧒🏿' => 'чүрпө: кара',
    '👦🏻' => 'бала: акжуумал',
    '👦🏼' => 'бала: буудай жүздүү',
    '👦🏽' => 'бала: орточо',
    '👦🏾' => 'бала: кара тору',
    '👦🏿' => 'бала: кара',
    '👧🏻' => 'кыз: акжуумал',
    '👧🏼' => 'кыз: буудай жүздүү',
    '👧🏽' => 'кыз: орточо',
    '👧🏾' => 'кыз: кара тору',
    '👧🏿' => 'кыз: кара',
    '🧑🏻' => 'адам: акжуумал',
    '🧑🏼' => 'адам: буудай жүздүү',
    '🧑🏽' => 'адам: орточо',
    '🧑🏾' => 'адам: кара тору',
    '🧑🏿' => 'адам: кара',
    '👱🏻' => 'сары чачтуу киши: акжуумал',
    '👱🏼' => 'сары чачтуу киши: буудай жүздүү',
    '👱🏽' => 'сары чачтуу киши: орточо',
    '👱🏾' => 'сары чачтуу киши: кара тору',
    '👱🏿' => 'сары чачтуу киши: кара',
    '👨🏻' => 'эркек: акжуумал',
    '👨🏼' => 'эркек: буудай жүздүү',
    '👨🏽' => 'эркек: орточо',
    '👨🏾' => 'эркек: кара тору',
    '👨🏿' => 'эркек: кара',
    '🧔🏻' => 'сакалчан киши: акжуумал',
    '🧔🏼' => 'сакалчан киши: буудай жүздүү',
    '🧔🏽' => 'сакалчан киши: орточо',
    '🧔🏾' => 'сакалчан киши: кара тору',
    '🧔🏿' => 'сакалчан киши: кара',
    '👩🏻' => 'аял: акжуумал',
    '👩🏼' => 'аял: буудай жүздүү',
    '👩🏽' => 'аял: орточо',
    '👩🏾' => 'аял: кара тору',
    '👩🏿' => 'аял: кара',
    '🧓🏻' => 'кары адам: акжуумал',
    '🧓🏼' => 'кары адам: буудай жүздүү',
    '🧓🏽' => 'кары адам: орточо',
    '🧓🏾' => 'кары адам: кара тору',
    '🧓🏿' => 'кары адам: кара',
    '👴🏻' => 'абышка: акжуумал',
    '👴🏼' => 'абышка: буудай жүздүү',
    '👴🏽' => 'абышка: орточо',
    '👴🏾' => 'абышка: кара тору',
    '👴🏿' => 'абышка: кара',
    '👵🏻' => 'кемпир: акжуумал',
    '👵🏼' => 'кемпир: буудай жүздүү',
    '👵🏽' => 'кемпир: орточо',
    '👵🏾' => 'кемпир: кара тору',
    '👵🏿' => 'кемпир: кара',
    '🙍🏻' => 'кабагын бүркөгөн адам: акжуумал',
    '🙍🏼' => 'кабагын бүркөгөн адам: буудай жүздүү',
    '🙍🏽' => 'кабагын бүркөгөн адам: орточо',
    '🙍🏾' => 'кабагын бүркөгөн адам: кара тору',
    '🙍🏿' => 'кабагын бүркөгөн адам: кара',
    '🙎🏻' => 'тултуюп таарынган адам: акжуумал',
    '🙎🏼' => 'тултуюп таарынган адам: буудай жүздүү',
    '🙎🏽' => 'тултуюп таарынган адам: орточо',
    '🙎🏾' => 'тултуюп таарынган адам: кара тору',
    '🙎🏿' => 'тултуюп таарынган адам: кара',
    '🙅🏻' => '«жок» деген ишарат: акжуумал',
    '🙅🏼' => '«жок» деген ишарат: буудай жүздүү',
    '🙅🏽' => '«жок» деген ишарат: орточо',
    '🙅🏾' => '«жок» деген ишарат: кара тору',
    '🙅🏿' => '«жок» деген ишарат: кара',
    '🙆🏻' => '«жарайт» деп жаткан адам: акжуумал',
    '🙆🏼' => '«жарайт» деп жаткан адам: буудай жүздүү',
    '🙆🏽' => '«жарайт» деп жаткан адам: орточо',
    '🙆🏾' => '«жарайт» деп жаткан адам: кара тору',
    '🙆🏿' => '«жарайт» деп жаткан адам: кара',
    '💁🏻' => 'маалымат тактасындагы адам: акжуумал',
    '💁🏼' => 'маалымат тактасындагы адам: буудай жүздүү',
    '💁🏽' => 'маалымат тактасындагы адам: орточо',
    '💁🏾' => 'маалымат тактасындагы адам: кара тору',
    '💁🏿' => 'маалымат тактасындагы адам: кара',
    '🙋🏻' => 'кол көтөрүп жаткан бактылуу адам: акжуумал',
    '🙋🏼' => 'кол көтөрүп жаткан бактылуу адам: буудай жүздүү',
    '🙋🏽' => 'кол көтөрүп жаткан бактылуу адам: орточо',
    '🙋🏾' => 'кол көтөрүп жаткан бактылуу адам: кара тору',
    '🙋🏿' => 'кол көтөрүп жаткан бактылуу адам: кара',
    '🧏🏻' => 'дүлөй киши: акжуумал',
    '🧏🏼' => 'дүлөй киши: буудай жүздүү',
    '🧏🏽' => 'дүлөй киши: орточо',
    '🧏🏾' => 'дүлөй киши: кара тору',
    '🧏🏿' => 'дүлөй киши: кара',
    '🙇🏻' => 'жүгүнүп жаткан адам: акжуумал',
    '🙇🏼' => 'жүгүнүп жаткан адам: буудай жүздүү',
    '🙇🏽' => 'жүгүнүп жаткан адам: орточо',
    '🙇🏾' => 'жүгүнүп жаткан адам: кара тору',
    '🙇🏿' => 'жүгүнүп жаткан адам: кара',
    '🤦🏻' => 'сөз жок ишараты: акжуумал',
    '🤦🏼' => 'сөз жок ишараты: буудай жүздүү',
    '🤦🏽' => 'сөз жок ишараты: орточо',
    '🤦🏾' => 'сөз жок ишараты: кара тору',
    '🤦🏿' => 'сөз жок ишараты: кара',
    '🤷🏻' => 'ийиндерин куушуруу: акжуумал',
    '🤷🏼' => 'ийиндерин куушуруу: буудай жүздүү',
    '🤷🏽' => 'ийиндерин куушуруу: орточо',
    '🤷🏾' => 'ийиндерин куушуруу: кара тору',
    '🤷🏿' => 'ийиндерин куушуруу: кара',
    '👮🏻' => 'милиция кызматкери: акжуумал',
    '👮🏼' => 'милиция кызматкери: буудай жүздүү',
    '👮🏽' => 'милиция кызматкери: орточо',
    '👮🏾' => 'милиция кызматкери: кара тору',
    '👮🏿' => 'милиция кызматкери: кара',
    '🕵🏻' => 'детектив: акжуумал',
    '🕵🏼' => 'детектив: буудай жүздүү',
    '🕵🏽' => 'детектив: орточо',
    '🕵🏾' => 'детектив: кара тору',
    '🕵🏿' => 'детектив: кара',
    '💂🏻' => 'кароолчу: акжуумал',
    '💂🏼' => 'кароолчу: буудай жүздүү',
    '💂🏽' => 'кароолчу: орточо',
    '💂🏾' => 'кароолчу: кара тору',
    '💂🏿' => 'кароолчу: кара',
    '🥷🏻' => 'ниндзя: акжуумал',
    '🥷🏼' => 'ниндзя: буудай жүздүү',
    '🥷🏽' => 'ниндзя: орточо',
    '🥷🏾' => 'ниндзя: кара тору',
    '🥷🏿' => 'ниндзя: кара',
    '👷🏻' => 'куруучу: акжуумал',
    '👷🏼' => 'куруучу: буудай жүздүү',
    '👷🏽' => 'куруучу: орточо',
    '👷🏾' => 'куруучу: кара тору',
    '👷🏿' => 'куруучу: кара',
    '🫅🏻' => 'таажысы бар киши: акжуумал',
    '🫅🏼' => 'таажысы бар киши: буудай жүздүү',
    '🫅🏽' => 'таажысы бар киши: орточо',
    '🫅🏾' => 'таажысы бар киши: кара тору',
    '🫅🏿' => 'таажысы бар киши: кара',
    '🤴🏻' => 'ханзаада: акжуумал',
    '🤴🏼' => 'ханзаада: буудай жүздүү',
    '🤴🏽' => 'ханзаада: орточо',
    '🤴🏾' => 'ханзаада: кара тору',
    '🤴🏿' => 'ханзаада: кара',
    '👸🏻' => 'ханыша: акжуумал',
    '👸🏼' => 'ханыша: буудай жүздүү',
    '👸🏽' => 'ханыша: орточо',
    '👸🏾' => 'ханыша: кара тору',
    '👸🏿' => 'ханыша: кара',
    '👳🏻' => 'селдечен киши: акжуумал',
    '👳🏼' => 'селдечен киши: буудай жүздүү',
    '👳🏽' => 'селдечен киши: орточо',
    '👳🏾' => 'селдечен киши: кара тору',
    '👳🏿' => 'селдечен киши: кара',
    '👲🏻' => 'кытай топучан киши: акжуумал',
    '👲🏼' => 'кытай топучан киши: буудай жүздүү',
    '👲🏽' => 'кытай топучан киши: орточо',
    '👲🏾' => 'кытай топучан киши: кара тору',
    '👲🏿' => 'кытай топучан киши: кара',
    '🧕🏻' => 'жоолукчан аял: акжуумал',
    '🧕🏼' => 'жоолукчан аял: буудай жүздүү',
    '🧕🏽' => 'жоолукчан аял: орточо',
    '🧕🏾' => 'жоолукчан аял: кара тору',
    '🧕🏿' => 'жоолукчан аял: кара',
    '🤵🏻' => 'смокинг кийген мырза: акжуумал',
    '🤵🏼' => 'смокинг кийген мырза: буудай жүздүү',
    '🤵🏽' => 'смокинг кийген мырза: орточо',
    '🤵🏾' => 'смокинг кийген мырза: кара тору',
    '🤵🏿' => 'смокинг кийген мырза: кара',
    '👰🏻' => 'жоолукчан колукту: акжуумал',
    '👰🏼' => 'жоолукчан колукту: буудай жүздүү',
    '👰🏽' => 'жоолукчан колукту: орточо',
    '👰🏾' => 'жоолукчан колукту: кара тору',
    '👰🏿' => 'жоолукчан колукту: кара',
    '🤰🏻' => 'кош бойлуу аял: акжуумал',
    '🤰🏼' => 'кош бойлуу аял: буудай жүздүү',
    '🤰🏽' => 'кош бойлуу аял: орточо',
    '🤰🏾' => 'кош бойлуу аял: кара тору',
    '🤰🏿' => 'кош бойлуу аял: кара',
    '🫃🏻' => 'кош бойлуу эркек киши: акжуумал',
    '🫃🏼' => 'кош бойлуу эркек киши: буудай жүздүү',
    '🫃🏽' => 'кош бойлуу эркек киши: орточо',
    '🫃🏾' => 'кош бойлуу эркек киши: кара тору',
    '🫃🏿' => 'кош бойлуу эркек киши: кара',
    '🫄🏻' => 'боюнда бар адам: акжуумал',
    '🫄🏼' => 'боюнда бар адам: буудай жүздүү',
    '🫄🏽' => 'боюнда бар адам: орточо',
    '🫄🏾' => 'боюнда бар адам: кара тору',
    '🫄🏿' => 'боюнда бар адам: кара',
    '🤱🏻' => 'эмчек эмизүү: акжуумал',
    '🤱🏼' => 'эмчек эмизүү: буудай жүздүү',
    '🤱🏽' => 'эмчек эмизүү: орточо',
    '🤱🏾' => 'эмчек эмизүү: кара тору',
    '🤱🏿' => 'эмчек эмизүү: кара',
    '👼🏻' => 'бала периште: акжуумал',
    '👼🏼' => 'бала периште: буудай жүздүү',
    '👼🏽' => 'бала периште: орточо',
    '👼🏾' => 'бала периште: кара тору',
    '👼🏿' => 'бала периште: кара',
    '🎅🏻' => 'аяз ата: акжуумал',
    '🎅🏼' => 'аяз ата: буудай жүздүү',
    '🎅🏽' => 'аяз ата: орточо',
    '🎅🏾' => 'аяз ата: кара тору',
    '🎅🏿' => 'аяз ата: кара',
    '🤶🏻' => 'миссис клаус: акжуумал',
    '🤶🏼' => 'миссис клаус: буудай жүздүү',
    '🤶🏽' => 'миссис клаус: орточо',
    '🤶🏾' => 'миссис клаус: кара тору',
    '🤶🏿' => 'миссис клаус: кара',
    '🦸🏻' => 'супер баатыр: акжуумал',
    '🦸🏼' => 'супер баатыр: буудай жүздүү',
    '🦸🏽' => 'супер баатыр: орточо',
    '🦸🏾' => 'супер баатыр: кара тору',
    '🦸🏿' => 'супер баатыр: кара',
    '🦹🏻' => 'карасантай: акжуумал',
    '🦹🏼' => 'карасантай: буудай жүздүү',
    '🦹🏽' => 'карасантай: орточо',
    '🦹🏾' => 'карасантай: кара тору',
    '🦹🏿' => 'карасантай: кара',
    '🧙🏻' => 'сыйкырчы: акжуумал',
    '🧙🏼' => 'сыйкырчы: буудай жүздүү',
    '🧙🏽' => 'сыйкырчы: орточо',
    '🧙🏾' => 'сыйкырчы: кара тору',
    '🧙🏿' => 'сыйкырчы: кара',
    '🧚🏻' => 'фея: акжуумал',
    '🧚🏼' => 'фея: буудай жүздүү',
    '🧚🏽' => 'фея: орточо',
    '🧚🏾' => 'фея: кара тору',
    '🧚🏿' => 'фея: кара',
    '🧛🏻' => 'кан соргуч: акжуумал',
    '🧛🏼' => 'кан соргуч: буудай жүздүү',
    '🧛🏽' => 'кан соргуч: орточо',
    '🧛🏾' => 'кан соргуч: кара тору',
    '🧛🏿' => 'кан соргуч: кара',
    '🧜🏻' => 'сууда жашаган жандык (русалка сымал): акжуумал',
    '🧜🏼' => 'сууда жашаган жандык (русалка сымал): буудай жүздүү',
    '🧜🏽' => 'сууда жашаган жандык (русалка сымал): орточо',
    '🧜🏾' => 'сууда жашаган жандык (русалка сымал): кара тору',
    '🧜🏿' => 'сууда жашаган жандык (русалка сымал): кара',
    '🧝🏻' => 'эльф: акжуумал',
    '🧝🏼' => 'эльф: буудай жүздүү',
    '🧝🏽' => 'эльф: орточо',
    '🧝🏾' => 'эльф: кара тору',
    '🧝🏿' => 'эльф: кара',
    '💆🏻' => 'бетке массаж: акжуумал',
    '💆🏼' => 'бетке массаж: буудай жүздүү',
    '💆🏽' => 'бетке массаж: орточо',
    '💆🏾' => 'бетке массаж: кара тору',
    '💆🏿' => 'бетке массаж: кара',
    '💇🏻' => 'чач жасалгасы: акжуумал',
    '💇🏼' => 'чач жасалгасы: буудай жүздүү',
    '💇🏽' => 'чач жасалгасы: орточо',
    '💇🏾' => 'чач жасалгасы: кара тору',
    '💇🏿' => 'чач жасалгасы: кара',
    '🚶🏻' => 'жөө адам: акжуумал',
    '🚶🏼' => 'жөө адам: буудай жүздүү',
    '🚶🏽' => 'жөө адам: орточо',
    '🚶🏾' => 'жөө адам: кара тору',
    '🚶🏿' => 'жөө адам: кара',
    '🧍🏻' => 'адам турат: акжуумал',
    '🧍🏼' => 'адам турат: буудай жүздүү',
    '🧍🏽' => 'адам турат: орточо',
    '🧍🏾' => 'адам турат: кара тору',
    '🧍🏿' => 'адам турат: кара',
    '🧎🏻' => 'тизелеген адам: акжуумал',
    '🧎🏼' => 'тизелеген адам: буудай жүздүү',
    '🧎🏽' => 'тизелеген адам: орточо',
    '🧎🏾' => 'тизелеген адам: кара тору',
    '🧎🏿' => 'тизелеген адам: кара',
    '🏃🏻' => 'чуркап бара жаткан адам: акжуумал',
    '🏃🏼' => 'чуркап бара жаткан адам: буудай жүздүү',
    '🏃🏽' => 'чуркап бара жаткан адам: орточо',
    '🏃🏾' => 'чуркап бара жаткан адам: кара тору',
    '🏃🏿' => 'чуркап бара жаткан адам: кара',
    '💃🏻' => 'бийлеп жаткан аял: акжуумал',
    '💃🏼' => 'бийлеп жаткан аял: буудай жүздүү',
    '💃🏽' => 'бийлеп жаткан аял: орточо',
    '💃🏾' => 'бийлеп жаткан аял: кара тору',
    '💃🏿' => 'бийлеп жаткан аял: кара',
    '🕺🏻' => 'бийлеп жаткан мырза: акжуумал',
    '🕺🏼' => 'бийлеп жаткан мырза: буудай жүздүү',
    '🕺🏽' => 'бийлеп жаткан мырза: орточо',
    '🕺🏾' => 'бийлеп жаткан мырза: кара тору',
    '🕺🏿' => 'бийлеп жаткан мырза: кара',
    '🕴🏻' => 'костюм-шымчан киши: акжуумал',
    '🕴🏼' => 'костюм-шымчан киши: буудай жүздүү',
    '🕴🏽' => 'костюм-шымчан киши: орточо',
    '🕴🏾' => 'костюм-шымчан киши: кара тору',
    '🕴🏿' => 'костюм-шымчан киши: кара',
    '👯🏻' => 'кыз-келиндер кечеси: акжуумал',
    '👯🏼' => 'кыз-келиндер кечеси: буудай жүздүү',
    '👯🏽' => 'кыз-келиндер кечеси: орточо',
    '👯🏾' => 'кыз-келиндер кечеси: кара тору',
    '👯🏿' => 'кыз-келиндер кечеси: кара',
    '🧖🏻' => 'бууланган бөлмөдө отурган адам: акжуумал',
    '🧖🏼' => 'бууланган бөлмөдө отурган адам: буудай жүздүү',
    '🧖🏽' => 'бууланган бөлмөдө отурган адам: орточо',
    '🧖🏾' => 'бууланган бөлмөдө отурган адам: кара тору',
    '🧖🏿' => 'бууланган бөлмөдө отурган адам: кара',
    '🧗🏻' => 'тоого чыгып жаткан адам: акжуумал',
    '🧗🏼' => 'тоого чыгып жаткан адам: буудай жүздүү',
    '🧗🏽' => 'тоого чыгып жаткан адам: орточо',
    '🧗🏾' => 'тоого чыгып жаткан адам: кара тору',
    '🧗🏿' => 'тоого чыгып жаткан адам: кара',
    '🏇🏻' => 'ат чабыш: акжуумал',
    '🏇🏼' => 'ат чабыш: буудай жүздүү',
    '🏇🏽' => 'ат чабыш: орточо',
    '🏇🏾' => 'ат чабыш: кара тору',
    '🏇🏿' => 'ат чабыш: кара',
    '🏂🏻' => 'сноубордчу: акжуумал',
    '🏂🏼' => 'сноубордчу: буудай жүздүү',
    '🏂🏽' => 'сноубордчу: орточо',
    '🏂🏾' => 'сноубордчу: кара тору',
    '🏂🏿' => 'сноубордчу: кара',
    '🏌🏻' => 'гольф оюнчусу: акжуумал',
    '🏌🏼' => 'гольф оюнчусу: буудай жүздүү',
    '🏌🏽' => 'гольф оюнчусу: орточо',
    '🏌🏾' => 'гольф оюнчусу: кара тору',
    '🏌🏿' => 'гольф оюнчусу: кара',
    '🏄🏻' => 'сёрфер: акжуумал',
    '🏄🏼' => 'сёрфер: буудай жүздүү',
    '🏄🏽' => 'сёрфер: орточо',
    '🏄🏾' => 'сёрфер: кара тору',
    '🏄🏿' => 'сёрфер: кара',
    '🚣🏻' => 'кайык: акжуумал',
    '🚣🏼' => 'кайык: буудай жүздүү',
    '🚣🏽' => 'кайык: орточо',
    '🚣🏾' => 'кайык: кара тору',
    '🚣🏿' => 'кайык: кара',
    '🏊🏻' => 'сүзгүч: акжуумал',
    '🏊🏼' => 'сүзгүч: буудай жүздүү',
    '🏊🏽' => 'сүзгүч: орточо',
    '🏊🏾' => 'сүзгүч: кара тору',
    '🏊🏿' => 'сүзгүч: кара',
    '⛹🏻' => 'топ менен киши: акжуумал',
    '⛹🏼' => 'топ менен киши: буудай жүздүү',
    '⛹🏽' => 'топ менен киши: орточо',
    '⛹🏾' => 'топ менен киши: кара тору',
    '⛹🏿' => 'топ менен киши: кара',
    '🏋🏻' => 'оор көтөргөн спортчу: акжуумал',
    '🏋🏼' => 'оор көтөргөн спортчу: буудай жүздүү',
    '🏋🏽' => 'оор көтөргөн спортчу: орточо',
    '🏋🏾' => 'оор көтөргөн спортчу: кара тору',
    '🏋🏿' => 'оор көтөргөн спортчу: кара',
    '🚴🏻' => 'велосипедчи: акжуумал',
    '🚴🏼' => 'велосипедчи: буудай жүздүү',
    '🚴🏽' => 'велосипедчи: орточо',
    '🚴🏾' => 'велосипедчи: кара тору',
    '🚴🏿' => 'велосипедчи: кара',
    '🚵🏻' => 'тоо велосипедчиси: акжуумал',
    '🚵🏼' => 'тоо велосипедчиси: буудай жүздүү',
    '🚵🏽' => 'тоо велосипедчиси: орточо',
    '🚵🏾' => 'тоо велосипедчиси: кара тору',
    '🚵🏿' => 'тоо велосипедчиси: кара',
    '🤸🏻' => 'акробатикалык көнүгүү: акжуумал',
    '🤸🏼' => 'акробатикалык көнүгүү: буудай жүздүү',
    '🤸🏽' => 'акробатикалык көнүгүү: орточо',
    '🤸🏾' => 'акробатикалык көнүгүү: кара тору',
    '🤸🏿' => 'акробатикалык көнүгүү: кара',
    '🤼🏻' => 'күрөшчүлөр: акжуумал',
    '🤼🏼' => 'күрөшчүлөр: буудай жүздүү',
    '🤼🏽' => 'күрөшчүлөр: орточо',
    '🤼🏾' => 'күрөшчүлөр: кара тору',
    '🤼🏿' => 'күрөшчүлөр: кара',
    '🤽🏻' => 'суудагы поло оюну: акжуумал',
    '🤽🏼' => 'суудагы поло оюну: буудай жүздүү',
    '🤽🏽' => 'суудагы поло оюну: орточо',
    '🤽🏾' => 'суудагы поло оюну: кара тору',
    '🤽🏿' => 'суудагы поло оюну: кара',
    '🤾🏻' => 'гандбол: акжуумал',
    '🤾🏼' => 'гандбол: буудай жүздүү',
    '🤾🏽' => 'гандбол: орточо',
    '🤾🏾' => 'гандбол: кара тору',
    '🤾🏿' => 'гандбол: кара',
    '🤹🏻' => 'жонглер: акжуумал',
    '🤹🏼' => 'жонглер: буудай жүздүү',
    '🤹🏽' => 'жонглер: орточо',
    '🤹🏾' => 'жонглер: кара тору',
    '🤹🏿' => 'жонглер: кара',
    '🧘🏻' => 'йога жасап отурган адам: акжуумал',
    '🧘🏼' => 'йога жасап отурган адам: буудай жүздүү',
    '🧘🏽' => 'йога жасап отурган адам: орточо',
    '🧘🏾' => 'йога жасап отурган адам: кара тору',
    '🧘🏿' => 'йога жасап отурган адам: кара',
    '🛀🏻' => 'жуунуп жаткан адам: акжуумал',
    '🛀🏼' => 'жуунуп жаткан адам: буудай жүздүү',
    '🛀🏽' => 'жуунуп жаткан адам: орточо',
    '🛀🏾' => 'жуунуп жаткан адам: кара тору',
    '🛀🏿' => 'жуунуп жаткан адам: кара',
    '🛌🏻' => 'төшөктөгү адам: акжуумал',
    '🛌🏼' => 'төшөктөгү адам: буудай жүздүү',
    '🛌🏽' => 'төшөктөгү адам: орточо',
    '🛌🏾' => 'төшөктөгү адам: кара тору',
    '🛌🏿' => 'төшөктөгү адам: кара',
    '👭🏻' => 'кол кармашкан эки аял: акжуумал',
    '👭🏼' => 'кол кармашкан эки аял: буудай жүздүү',
    '👭🏽' => 'кол кармашкан эки аял: орточо',
    '👭🏾' => 'кол кармашкан эки аял: кара тору',
    '👭🏿' => 'кол кармашкан эки аял: кара',
    '👫🏻' => 'кол кармашкан эркек менен аял: акжуумал',
    '👫🏼' => 'кол кармашкан эркек менен аял: буудай жүздүү',
    '👫🏽' => 'кол кармашкан эркек менен аял: орточо',
    '👫🏾' => 'кол кармашкан эркек менен аял: кара тору',
    '👫🏿' => 'кол кармашкан эркек менен аял: кара',
    '👬🏻' => 'кол кармашкан эки киши: акжуумал',
    '👬🏼' => 'кол кармашкан эки киши: буудай жүздүү',
    '👬🏽' => 'кол кармашкан эки киши: орточо',
    '👬🏾' => 'кол кармашкан эки киши: кара тору',
    '👬🏿' => 'кол кармашкан эки киши: кара',
    '💏🏻' => 'өбүшүү: акжуумал',
    '💏🏼' => 'өбүшүү: буудай жүздүү',
    '💏🏽' => 'өбүшүү: орточо',
    '💏🏾' => 'өбүшүү: кара тору',
    '💏🏿' => 'өбүшүү: кара',
    '💑🏻' => 'сүйүшкөн түгөйлөр: акжуумал',
    '💑🏼' => 'сүйүшкөн түгөйлөр: буудай жүздүү',
    '💑🏽' => 'сүйүшкөн түгөйлөр: орточо',
    '💑🏾' => 'сүйүшкөн түгөйлөр: кара тору',
    '💑🏿' => 'сүйүшкөн түгөйлөр: кара',
    '🇦🇨' => 'желек: Вознесение аралы',
    '🇦🇩' => 'желек: Андорра',
    '🇦🇪' => 'желек: Бириккен Араб Эмираттары',
    '🇦🇫' => 'желек: Афганистан',
    '🇦🇬' => 'желек: Антигуа жана Барбуда',
    '🇦🇮' => 'желек: Ангилья',
    '🇦🇱' => 'желек: Албания',
    '🇦🇲' => 'желек: Армения',
    '🇦🇴' => 'желек: Ангола',
    '🇦🇶' => 'желек: Антарктида',
    '🇦🇷' => 'желек: Аргентина',
    '🇦🇸' => 'желек: Америкалык Самоа',
    '🇦🇹' => 'желек: Австрия',
    '🇦🇺' => 'желек: Австралия',
    '🇦🇼' => 'желек: Аруба',
    '🇦🇽' => 'желек: Аланд аралдары',
    '🇦🇿' => 'желек: Азербайжан',
    '🇧🇦' => 'желек: Босния жана Герцеговина',
    '🇧🇧' => 'желек: Барбадос',
    '🇧🇩' => 'желек: Бангладеш',
    '🇧🇪' => 'желек: Бельгия',
    '🇧🇫' => 'желек: Буркина-Фасо',
    '🇧🇬' => 'желек: Болгария',
    '🇧🇭' => 'желек: Бахрейн',
    '🇧🇮' => 'желек: Бурунди',
    '🇧🇯' => 'желек: Бенин',
    '🇧🇱' => 'желек: Сент Бартелеми',
    '🇧🇲' => 'желек: Бермуд аралдары',
    '🇧🇳' => 'желек: Бруней',
    '🇧🇴' => 'желек: Боливия',
    '🇧🇶' => 'желек: Кариб Нидерланддары',
    '🇧🇷' => 'желек: Бразилия',
    '🇧🇸' => 'желек: Багама аралдары',
    '🇧🇹' => 'желек: Бутан',
    '🇧🇻' => 'желек: Буве аралы',
    '🇧🇼' => 'желек: Ботсвана',
    '🇧🇾' => 'желек: Беларусь',
    '🇧🇿' => 'желек: Белиз',
    '🇨🇦' => 'желек: Канада',
    '🇨🇨' => 'желек: Кокос (Килинг) аралдары',
    '🇨🇩' => 'желек: Конго-Киншаса',
    '🇨🇫' => 'желек: Борбордук Африка Республикасы',
    '🇨🇬' => 'желек: Конго-Браззавил',
    '🇨🇭' => 'желек: Швейцария',
    '🇨🇮' => 'желек: Кот-д’Ивуар',
    '🇨🇰' => 'желек: Кук аралдары',
    '🇨🇱' => 'желек: Чили',
    '🇨🇲' => 'желек: Камерун',
    '🇨🇳' => 'желек: Кытай',
    '🇨🇴' => 'желек: Колумбия',
    '🇨🇵' => 'желек: Клиппертон аралы',
    '🇨🇶' => 'желек: саркча (нормандча)',
    '🇨🇷' => 'желек: Коста-Рика',
    '🇨🇺' => 'желек: Куба',
    '🇨🇻' => 'желек: Кабо-Верде',
    '🇨🇼' => 'желек: Кюрасао',
    '🇨🇽' => 'желек: Рождество аралы',
    '🇨🇾' => 'желек: Кипр',
    '🇨🇿' => 'желек: Чехия',
    '🇩🇪' => 'желек: Германия',
    '🇩🇬' => 'желек: Диего Гарсия',
    '🇩🇯' => 'желек: Джибути',
    '🇩🇰' => 'желек: Дания',
    '🇩🇲' => 'желек: Доминика',
    '🇩🇴' => 'желек: Доминика Республикасы',
    '🇩🇿' => 'желек: Алжир',
    '🇪🇦' => 'желек: Сеута жана Мелилла',
    '🇪🇨' => 'желек: Эквадор',
    '🇪🇪' => 'желек: Эстония',
    '🇪🇬' => 'желек: Египет',
    '🇪🇭' => 'желек: Батыш Сахара',
    '🇪🇷' => 'желек: Эритрея',
    '🇪🇸' => 'желек: Испания',
    '🇪🇹' => 'желек: Эфиопия',
    '🇪🇺' => 'желек: Европа Биримдиги',
    '🇫🇮' => 'желек: Финляндия',
    '🇫🇯' => 'желек: Фиджи',
    '🇫🇰' => 'желек: Фолкленд аралдары',
    '🇫🇲' => 'желек: Микронезия',
    '🇫🇴' => 'желек: Фарер аралдары',
    '🇫🇷' => 'желек: Франция',
    '🇬🇦' => 'желек: Габон',
    '🇬🇧' => 'желек: Улуу Британия',
    '🇬🇩' => 'желек: Гренада',
    '🇬🇪' => 'желек: Грузия',
    '🇬🇫' => 'желек: Франция Гвианасы',
    '🇬🇬' => 'желек: Гернси',
    '🇬🇭' => 'желек: Гана',
    '🇬🇮' => 'желек: Гибралтар',
    '🇬🇱' => 'желек: Гренландия',
    '🇬🇲' => 'желек: Гамбия',
    '🇬🇳' => 'желек: Гвинея',
    '🇬🇵' => 'желек: Гваделупа',
    '🇬🇶' => 'желек: Экватордук Гвинея',
    '🇬🇷' => 'желек: Греция',
    '🇬🇸' => 'желек: Түштүк Жоржия жана Түштүк Сэндвич аралдары',
    '🇬🇹' => 'желек: Гватемала',
    '🇬🇺' => 'желек: Гуам',
    '🇬🇼' => 'желек: Гвинея-Бисау',
    '🇬🇾' => 'желек: Гайана',
    '🇭🇰' => 'желек: Гонконг Кытай ААА',
    '🇭🇲' => 'желек: Херд жана Макдональд аралдары',
    '🇭🇳' => 'желек: Гондурас',
    '🇭🇷' => 'желек: Хорватия',
    '🇭🇹' => 'желек: Гаити',
    '🇭🇺' => 'желек: Венгрия',
    '🇮🇨' => 'желек: Канар аралдары',
    '🇮🇩' => 'желек: Индонезия',
    '🇮🇪' => 'желек: Ирландия',
    '🇮🇱' => 'желек: Израиль',
    '🇮🇲' => 'желек: Мэн аралы',
    '🇮🇳' => 'желек: Индия',
    '🇮🇴' => 'желек: Инди океанындагы Британ территориясы',
    '🇮🇶' => 'желек: Ирак',
    '🇮🇷' => 'желек: Иран',
    '🇮🇸' => 'желек: Исландия',
    '🇮🇹' => 'желек: Италия',
    '🇯🇪' => 'желек: Жерси',
    '🇯🇲' => 'желек: Ямайка',
    '🇯🇴' => 'желек: Иордания',
    '🇯🇵' => 'желек: Жапония',
    '🇰🇪' => 'желек: Кения',
    '🇰🇬' => 'желек: Кыргызстан',
    '🇰🇭' => 'желек: Камбоджа',
    '🇰🇮' => 'желек: Кирибати',
    '🇰🇲' => 'желек: Коморос',
    '🇰🇳' => 'желек: Сент-Китс жана Невис',
    '🇰🇵' => 'желек: Түндүк Корея',
    '🇰🇷' => 'желек: Түштүк Корея',
    '🇰🇼' => 'желек: Кувейт',
    '🇰🇾' => 'желек: Кайман аралдары',
    '🇰🇿' => 'желек: Казакстан',
    '🇱🇦' => 'желек: Лаос',
    '🇱🇧' => 'желек: Ливан',
    '🇱🇨' => 'желек: Сент-Люсия',
    '🇱🇮' => 'желек: Лихтенштейн',
    '🇱🇰' => 'желек: Шри-Ланка',
    '🇱🇷' => 'желек: Либерия',
    '🇱🇸' => 'желек: Лесото',
    '🇱🇹' => 'желек: Литва',
    '🇱🇺' => 'желек: Люксембург',
    '🇱🇻' => 'желек: Латвия',
    '🇱🇾' => 'желек: Ливия',
    '🇲🇦' => 'желек: Марокко',
    '🇲🇨' => 'желек: Монако',
    '🇲🇩' => 'желек: Молдова',
    '🇲🇪' => 'желек: Черногория',
    '🇲🇫' => 'желек: Сент-Мартин',
    '🇲🇬' => 'желек: Мадагаскар',
    '🇲🇭' => 'желек: Маршалл аралдары',
    '🇲🇰' => 'желек: Түндүк Македония',
    '🇲🇱' => 'желек: Мали',
    '🇲🇲' => 'желек: Мьянма (Бирма)',
    '🇲🇳' => 'желек: Монголия',
    '🇲🇴' => 'желек: Макао Кытай ААА',
    '🇲🇵' => 'желек: Түндүк Мариана аралдары',
    '🇲🇶' => 'желек: Мартиника',
    '🇲🇷' => 'желек: Мавритания',
    '🇲🇸' => 'желек: Монтсеррат',
    '🇲🇹' => 'желек: Мальта',
    '🇲🇺' => 'желек: Маврикий',
    '🇲🇻' => 'желек: Мальдив',
    '🇲🇼' => 'желек: Малави',
    '🇲🇽' => 'желек: Мексика',
    '🇲🇾' => 'желек: Малайзия',
    '🇲🇿' => 'желек: Мозамбик',
    '🇳🇦' => 'желек: Намибия',
    '🇳🇨' => 'желек: Жаңы Каледония',
    '🇳🇪' => 'желек: Нигер',
    '🇳🇫' => 'желек: Норфолк аралы',
    '🇳🇬' => 'желек: Нигерия',
    '🇳🇮' => 'желек: Никарагуа',
    '🇳🇱' => 'желек: Нидерланд',
    '🇳🇴' => 'желек: Норвегия',
    '🇳🇵' => 'желек: Непал',
    '🇳🇷' => 'желек: Науру',
    '🇳🇺' => 'желек: Ниуэ',
    '🇳🇿' => 'желек: Жаңы Зеландия',
    '🇴🇲' => 'желек: Оман',
    '🇵🇦' => 'желек: Панама',
    '🇵🇪' => 'желек: Перу',
    '🇵🇫' => 'желек: Полинезия (франциялык)',
    '🇵🇬' => 'желек: Папуа-Жаңы Гвинея',
    '🇵🇭' => 'желек: Филиппин',
    '🇵🇰' => 'желек: Пакистан',
    '🇵🇱' => 'желек: Польша',
    '🇵🇲' => 'желек: Сен-Пьер жана Микелон',
    '🇵🇳' => 'желек: Питкэрн аралдары',
    '🇵🇷' => 'желек: Пуэрто-Рико',
    '🇵🇸' => 'желек: Палестина аймактары',
    '🇵🇹' => 'желек: Португалия',
    '🇵🇼' => 'желек: Палау',
    '🇵🇾' => 'желек: Парагвай',
    '🇶🇦' => 'желек: Катар',
    '🇷🇪' => 'желек: Реюньон',
    '🇷🇴' => 'желек: Румыния',
    '🇷🇸' => 'желек: Сербия',
    '🇷🇺' => 'желек: Россия',
    '🇷🇼' => 'желек: Руанда',
    '🇸🇦' => 'желек: Сауд Арабиясы',
    '🇸🇧' => 'желек: Соломон аралдары',
    '🇸🇨' => 'желек: Сейшел аралдары',
    '🇸🇩' => 'желек: Судан',
    '🇸🇪' => 'желек: Швеция',
    '🇸🇬' => 'желек: Сингапур',
    '🇸🇭' => 'желек: Ыйык Елена',
    '🇸🇮' => 'желек: Словения',
    '🇸🇯' => 'желек: Шпицберген жана Ян-Майен',
    '🇸🇰' => 'желек: Словакия',
    '🇸🇱' => 'желек: Сьерра-Леоне',
    '🇸🇲' => 'желек: Сан Марино',
    '🇸🇳' => 'желек: Сенегал',
    '🇸🇴' => 'желек: Сомали',
    '🇸🇷' => 'желек: Суринам',
    '🇸🇸' => 'желек: Түштүк Судан',
    '🇸🇹' => 'желек: Сан-Томе жана Принсипи',
    '🇸🇻' => 'желек: Эль-Сальвадор',
    '🇸🇽' => 'желек: Синт-Мартен',
    '🇸🇾' => 'желек: Сирия',
    '🇸🇿' => 'желек: Свазиленд',
    '🇹🇦' => 'желек: Тристан-да-Кунья',
    '🇹🇨' => 'желек: Түркс жана Кайкос аралдары',
    '🇹🇩' => 'желек: Чад',
    '🇹🇫' => 'желек: Франциянын Түштүктөгү аймактары',
    '🇹🇬' => 'желек: Того',
    '🇹🇭' => 'желек: Тайланд',
    '🇹🇯' => 'желек: Тажикстан',
    '🇹🇰' => 'желек: Токелау',
    '🇹🇱' => 'желек: Тимор-Лесте',
    '🇹🇲' => 'желек: Түркмөнстан',
    '🇹🇳' => 'желек: Тунис',
    '🇹🇴' => 'желек: Тонга',
    '🇹🇷' => 'желек: Түркия',
    '🇹🇹' => 'желек: Тринидад жана Тобаго',
    '🇹🇻' => 'желек: Тувалу',
    '🇹🇼' => 'желек: Тайвань',
    '🇹🇿' => 'желек: Танзания',
    '🇺🇦' => 'желек: Украина',
    '🇺🇬' => 'желек: Уганда',
    '🇺🇲' => 'желек: АКШнын сырткы аралдары',
    '🇺🇳' => 'желек: БУ',
    '🇺🇸' => 'желек: Кошмо Штаттар',
    '🇺🇾' => 'желек: Уругвай',
    '🇺🇿' => 'желек: Өзбекстан',
    '🇻🇦' => 'желек: Ватикан',
    '🇻🇨' => 'желек: Сент-Винсент жана Гренадиндер',
    '🇻🇪' => 'желек: Венесуэла',
    '🇻🇬' => 'желек: Виргин аралдары (Британия)',
    '🇻🇮' => 'желек: Виргин аралдары (АКШ)',
    '🇻🇳' => 'желек: Вьетнам',
    '🇻🇺' => 'желек: Вануату',
    '🇼🇫' => 'желек: Уоллис жана Футуна',
    '🇼🇸' => 'желек: Самоа',
    '🇽🇰' => 'желек: Косово',
    '🇾🇪' => 'желек: Йемен',
    '🇾🇹' => 'желек: Майотта',
    '🇿🇦' => 'желек: Түштүк-Африка Республикасы',
    '🇿🇲' => 'желек: Замбия',
    '🇿🇼' => 'желек: Зимбабве',
    '🔟' => 'клавиатура калпакчасы: 10',
    '🏻' => 'акжуумал',
    '🏼' => 'буудай жүздүү',
    '🏽' => 'орточо',
    '🏾' => 'кара тору',
    '🏿' => 'кара',
    '😀' => 'ырсайган бет',
    '😃' => 'күлгөн бет',
    '😄' => 'каткырып күлгөн бет',
    '😁' => 'көздөрүн жымыңдатып ырсайган бет',
    '😆' => 'көздөрүн чылк жумуп күлгөн бет',
    '😅' => 'тердегенче күлгөн бет',
    '🤣' => 'тоголонуп күлүү',
    '😂' => 'боору эзилип күлгөн бет',
    '🙂' => 'күлүмсүрөгөн бет',
    '🙃' => 'башын ылдый каратып турган бет',
    '🫠' => 'ээрип жаткан бет',
    '😉' => 'көзүн кыскан бет',
    '😊' => 'уялыңкы жылмайган бет',
    '😇' => 'башында тегереги бар жылмайган бет',
    '🥰' => 'жүрөктөр каптаган жылмайган жүз',
    '😍' => 'сүйүүгө башы айланган бет',
    '🤩' => 'жылдыз оорусу',
    '😘' => 'аралыктан өөп жаткан бет',
    '😗' => 'өөп жаткан бет',
    '☺' => 'жылмайган бет',
    '😚' => 'көздөрүн жумуп өөп жаткан бет',
    '😙' => 'көздөрүн сүзүп өөп жаткан бет',
    '🥲' => 'ыйлаган жылмайган жүз',
    '😋' => 'даамдуу тамак татып жаткан бет',
    '😛' => 'тилин көрсөткөн бет',
    '😜' => 'көзүн кысып тилин көрсөткөн бет',
    '🤪' => 'жинденген жүз',
    '😝' => 'көздөрүн чылк жумуп, тилин сунган бет',
    '🤑' => 'акча тиштеген бет',
    '🤗' => 'кучактап жаткан бет',
    '🤭' => 'оозун колу менен жапкан жүз',
    '🫢' => 'көзү ачык жана колу менен оозун жапкан бет',
    '🫣' => 'көзүн жаап алып, бирок акырын тешиктен караган бет',
    '🤫' => 'акырын деген жүз',
    '🤔' => 'ойго баткан бет',
    '🫡' => 'салам берген бет',
    '🤐' => 'эч кимге ооз ачпайм деген бет',
    '🤨' => 'кашын серпкен жүз',
    '😐' => 'эриндерин бекем кыскан бет',
    '😑' => 'кебелбеген бет',
    '😶' => 'оозу жок бет',
    '🫥' => 'сызыкчадан турган бет',
    '😏' => 'мыйыгынан жылмайган бет',
    '😒' => 'таарынган бет',
    '🙄' => 'көзүн сүзгөн бет',
    '😬' => 'кебетесин бузган бет',
    '🤥' => 'жалганчы бет',
    '🫨' => 'титиреген бет',
    '😌' => 'магдыраган бет',
    '😔' => 'кайгылуу бет',
    '😪' => 'уйкусу келген бет',
    '🤤' => 'шилекейин чууруткан бет',
    '😴' => 'уктап жаткан бет',
    '🫩' => 'көздөрүнүн асты шишип калган бет',
    '😷' => 'медициналык беткапчан бет',
    '🤒' => 'градусник тиштеген бет',
    '🤕' => 'башы бинттелген бет',
    '🤢' => 'жүрөгү айланган бет',
    '🤮' => 'кусуп жаткан жүз',
    '🤧' => 'бышкырып жаткан бет',
    '🥵' => 'ысыган жүз',
    '🥶' => 'үшүгөн жүз',
    '🥴' => 'башы айланган жүз',
    '😵' => 'башы айланган бет',
    '🤯' => 'жарылып жаткан баш',
    '🤠' => 'ковбойдун шляпасын кийген бет',
    '🥳' => 'майрамдаган жүз',
    '🥸' => 'маска тагынып алган жүз',
    '😎' => 'кара көз айнекчен жылмайган бет',
    '🤓' => 'чилистен',
    '🧐' => 'монокль кармаган жүз',
    '😕' => 'башы маң болгон бет',
    '🫤' => 'оозу кыйшайган бет',
    '😟' => 'тынчсызданган бет',
    '🙁' => 'ээгин бир аз кемшийткен',
    '☹' => 'ээгин кемшийткен бет',
    '😮' => 'оозу ачылган бет',
    '😯' => 'таң калган бет',
    '😲' => 'айран-таң калган бет',
    '😳' => 'уялган бет',
    '🫪' => 'кыйшайган жүз',
    '🥺' => 'капалуу жүз',
    '🥹' => 'көзү жашылданган бет',
    '😦' => 'оозун аңырдай ачкан бет',
    '😧' => 'делдейип калган бет',
    '😨' => 'коркуп жаткан бет',
    '😰' => 'оозу ачылып, муздак тер аккан бет',
    '😥' => 'капа болуп эси оогон бет',
    '😢' => 'ыйлап жаткан бет',
    '😭' => 'ботодой боздогон бет',
    '😱' => 'коркконунан кыйкырып жаткан бет',
    '😖' => 'апкаарыган бет',
    '😣' => 'өжөрлөнгөн бет',
    '😞' => 'көңүлү чөккөн бет',
    '😓' => 'муздак тер аккан бет',
    '😩' => 'тажаган бет',
    '😫' => 'чарчаган бет',
    '🥱' => 'эстеп жаткан жүз',
    '😤' => 'ачуулангандан таноосу кыпчылган бет',
    '😡' => 'тултуюп таарынган бет',
    '😠' => 'ачуулуу бет',
    '🤬' => 'символдорду тиштеп алган жүз',
    '😈' => 'кытмыр жылмайган мүйүздүү шайтан',
    '👿' => 'шайтан',
    '💀' => 'баш сөөк',
    '☠' => 'баш сөөк жана кайчылашкан сөөктөр',
    '💩' => 'үйүлгөн заң',
    '🤡' => 'маскарапоздун бети',
    '👹' => 'дөө',
    '👺' => 'гоблин',
    '👻' => 'арбак',
    '👽' => 'чоочун планетадан',
    '👾' => 'чоочун планеталык желмогуз',
    '🤖' => 'робот',
    '😺' => 'күлүп жаткан мышык',
    '😸' => 'көздөрүн жымыңдатып ырсайган мышык',
    '😹' => 'боору эзилип күлгөн мышык',
    '😻' => 'сүйүүгө башы айланган мышык',
    '😼' => 'мыйыгынан жылмайган мышык',
    '😽' => 'көздөрүн жумуп өөп жаткан мышык',
    '🙀' => 'таң калган мышык',
    '😿' => 'ыйлап жаткан мышык',
    '😾' => 'тултуюп таарынган мышык',
    '🙈' => 'көзүм жамандыкты көрбөсүн',
    '🙉' => 'кулагым жамандыкты укпасын',
    '🙊' => 'оозуман жаман сөз чыкпасын',
    '💌' => 'сүйүү каты',
    '💘' => 'жебе сайылган жүрөк',
    '💝' => 'лента байланган жүрөк',
    '💖' => 'жылтылдаган жүрөк',
    '💗' => 'чоңоюп жаткан жүрөк',
    '💓' => 'кагып жаткан жүрөк',
    '💞' => 'айланып жаткан жүрөктөр',
    '💕' => 'кош жүрөк',
    '💟' => 'жүрөк менен кооздолгон',
    '❣' => 'жүрөк менен жазылган илеп белгиси',
    '💔' => 'жараланган жүрөк',
    '❤' => 'кызыл жүрөк',
    '🩷' => 'кызгылт түстөгү жүрөк',
    '🧡' => 'кызгылтым сары жүрөк',
    '💛' => 'сары жүрөк',
    '💚' => 'жашыл жүрөк',
    '💙' => 'көк жүрөк',
    '🩵' => 'көгүш түстүү жүрөк',
    '💜' => 'сыя түстүү жүрөк',
    '🤎' => 'күрөң жүрөк',
    '🖤' => 'кара жүрөк',
    '🩶' => 'боз түстөгү жүрөк',
    '🤍' => 'ак жүрөк',
    '💋' => 'өбүү белгиси',
    '💯' => 'жүз упай',
    '💢' => 'ачуулануу белгиси',
    '🫯' => 'булут менен күрөшүү',
    '💥' => 'сүзүшүү',
    '💫' => 'башы айланган',
    '💦' => 'тер тамчылары',
    '💨' => 'куюндай',
    '🕳' => 'тешик',
    '💬' => 'кеп шарчасы',
    '🗨' => 'сол тараптагы кеп көбүгү',
    '🗯' => 'оң тараптагы ачуулу кеп көбүгү',
    '💭' => 'ойлонуу көбүгү',
    '💤' => 'шшш',
    '👋' => 'кол булгалоо',
    '🤚' => 'көтөрүлгөн алакан',
    '🖐' => 'беш манжа',
    '✋' => 'кол көтөрүү',
    '🖖' => 'вулкандыктарча салам',
    '🫱' => 'оңду көрсөткөн кол',
    '🫲' => 'солду көрсөткөн кол',
    '🫳' => 'алаканы ылдый караган кол',
    '🫴' => 'алаканы өйдө караган кол',
    '🫷' => 'сол жакка түрткөн кол',
    '🫸' => 'оң жакка түрткөн кол',
    '👌' => '«ОК» белгиси',
    '🤌' => 'кыстырылган манжалар',
    '🤏' => 'чычмыган кол',
    '✌' => 'эки дегенди көрсөткөн манжалар',
    '🤞' => 'кайчылаштырылган манжалар',
    '🫰' => 'сөөмөй менен бармак кайчылаштырылган кол',
    '🤟' => 'сүйөм сени деген ишарат',
    '🤘' => 'мүйүз белгиси',
    '🤙' => '“мага чал” ишараты',
    '👈' => 'сол тарапты көрсөткөн сөөмөй',
    '👉' => 'оң тарапты көрсөткөн сөөмөй',
    '👆' => 'сөөмөйү өйдө караган колдун арткы бети',
    '🖕' => 'ортон',
    '👇' => 'төмөн жакты көрсөткөн сөөмөй',
    '☝' => 'өйдө жакты көрсөткөн сөөмөй',
    '🫵' => 'көрүүчүгө багытталган сөөмөй',
    '👍' => '«сонун»',
    '👎' => '«начар»',
    '✊' => 'көтөрүлгөн муштум',
    '👊' => 'уруп жаткан муштум',
    '🤛' => 'солго караган муштум',
    '🤜' => 'оңго караган муштум',
    '👏' => 'кол чабуу',
    '🙌' => 'кол көтөрүп жаткан адам',
    '🫶' => 'жүрөк кол',
    '👐' => 'ачык алакандар',
    '🤲' => 'алакан жаюу',
    '🤝' => 'кол алышуу',
    '🙏' => 'алаканын бириктирген колдор',
    '✍' => 'жазып жаткан кол',
    '💅' => 'тырмак боёо',
    '🤳' => 'селфи',
    '💪' => 'түйүлгөн булчуң',
    '🦾' => 'механикалык кол',
    '🦿' => 'механикалык бут',
    '🦵' => 'жоон сан',
    '🦶' => 'бут',
    '👂' => 'кулак',
    '🦻' => 'угуу аппараты менен кулак',
    '👃' => 'мурун',
    '🧠' => 'мээ',
    '🫀' => 'жүрөк',
    '🫁' => 'өпкө',
    '🦷' => 'тиш',
    '🦴' => 'сөөк',
    '👀' => 'көздөр',
    '👁' => 'көз',
    '👅' => 'тил',
    '👄' => 'ооз',
    '🫦' => 'ээрин тиштөө',
    '👶' => 'кичинекей бала',
    '🧒' => 'чүрпө',
    '👦' => 'бала',
    '👧' => 'кыз',
    '🧑' => 'адам',
    '👱' => 'сары чачтуу киши',
    '👨' => 'эркек',
    '🧔' => 'сакалчан киши',
    '👩' => 'аял',
    '🧓' => 'кары адам',
    '👴' => 'абышка',
    '👵' => 'кемпир',
    '🙍' => 'кабагын бүркөгөн адам',
    '🙎' => 'тултуюп таарынган адам',
    '🙅' => '«жок» деген ишарат',
    '🙆' => '«жарайт» деп жаткан адам',
    '💁' => 'маалымат тактасындагы адам',
    '🙋' => 'кол көтөрүп жаткан бактылуу адам',
    '🧏' => 'дүлөй киши',
    '🙇' => 'жүгүнүп жаткан адам',
    '🤦' => 'сөз жок ишараты',
    '🤷' => 'ийиндерин куушуруу',
    '👮' => 'милиция кызматкери',
    '🕵' => 'детектив',
    '💂' => 'кароолчу',
    '🥷' => 'ниндзя',
    '👷' => 'куруучу',
    '🫅' => 'таажысы бар киши',
    '🤴' => 'ханзаада',
    '👸' => 'ханыша',
    '👳' => 'селдечен киши',
    '👲' => 'кытай топучан киши',
    '🧕' => 'жоолукчан аял',
    '🤵' => 'смокинг кийген мырза',
    '👰' => 'жоолукчан колукту',
    '🤰' => 'кош бойлуу аял',
    '🫃' => 'кош бойлуу эркек киши',
    '🫄' => 'боюнда бар адам',
    '🤱' => 'эмчек эмизүү',
    '👼' => 'бала периште',
    '🎅' => 'аяз ата',
    '🤶' => 'миссис клаус',
    '🦸' => 'супер баатыр',
    '🦹' => 'карасантай',
    '🧙' => 'сыйкырчы',
    '🧚' => 'фея',
    '🧛' => 'кан соргуч',
    '🧜' => 'сууда жашаган жандык (русалка сымал)',
    '🧝' => 'эльф',
    '🧞' => 'жин',
    '🧟' => 'зомби',
    '🧌' => 'тролль',
    '🫈' => 'жүндүү жаныбар',
    '💆' => 'бетке массаж',
    '💇' => 'чач жасалгасы',
    '🚶' => 'жөө адам',
    '🧍' => 'адам турат',
    '🧎' => 'тизелеген адам',
    '🏃' => 'чуркап бара жаткан адам',
    '💃' => 'бийлеп жаткан аял',
    '🕺' => 'бийлеп жаткан мырза',
    '🕴' => 'костюм-шымчан киши',
    '👯' => 'кыз-келиндер кечеси',
    '🧖' => 'бууланган бөлмөдө отурган адам',
    '🧗' => 'тоого чыгып жаткан адам',
    '🤺' => 'сайышуу',
    '🏇' => 'ат чабыш',
    '⛷' => 'лыжачы',
    '🏂' => 'сноубордчу',
    '🏌' => 'гольф оюнчусу',
    '🏄' => 'сёрфер',
    '🚣' => 'кайык',
    '🏊' => 'сүзгүч',
    '⛹' => 'топ менен киши',
    '🏋' => 'оор көтөргөн спортчу',
    '🚴' => 'велосипедчи',
    '🚵' => 'тоо велосипедчиси',
    '🤸' => 'акробатикалык көнүгүү',
    '🤼' => 'күрөшчүлөр',
    '🤽' => 'суудагы поло оюну',
    '🤾' => 'гандбол',
    '🤹' => 'жонглер',
    '🧘' => 'йога жасап отурган адам',
    '🛀' => 'жуунуп жаткан адам',
    '🛌' => 'төшөктөгү адам',
    '👭' => 'кол кармашкан эки аял',
    '👫' => 'кол кармашкан эркек менен аял',
    '👬' => 'кол кармашкан эки киши',
    '💏' => 'өбүшүү',
    '💑' => 'сүйүшкөн түгөйлөр',
    '🗣' => 'сүйлөп жаткан баш',
    '👤' => 'бюст сөлөкөтү',
    '👥' => 'бюсттар сөлөкөтү',
    '🫂' => 'кучакташкан адамдар',
    '👪' => 'үй-бүлө',
    '👣' => 'буттун изи',
    '🫆' => 'манжа изи',
    '🦰' => 'кызыл чач',
    '🦱' => 'тармал чач',
    '🦳' => 'ак чач',
    '🦲' => 'тас',
    '🐵' => 'маймылдын башы',
    '🐒' => 'маймыл',
    '🦍' => 'горилла',
    '🦧' => 'орангутан',
    '🐶' => 'иттин башы',
    '🐕' => 'ит',
    '🦮' => 'жардамчы ит',
    '🐩' => 'пудель',
    '🐺' => 'карышкырдын башы',
    '🦊' => 'түлкү',
    '🦝' => 'енот',
    '🐱' => 'мышыктын башы',
    '🐈' => 'мышык',
    '🦁' => 'арстандын башы',
    '🐯' => 'жолборстун башы',
    '🐅' => 'жолборс',
    '🐆' => 'илбирс',
    '🐴' => 'аттын башы',
    '🫎' => 'багыш',
    '🫏' => 'эшек',
    '🐎' => 'ат',
    '🦄' => 'мүйүздүү аттын башы',
    '🦓' => 'зебра',
    '🦌' => 'бугу',
    '🦬' => 'бизон',
    '🐮' => 'уйдун башы',
    '🐂' => 'өгүз',
    '🐃' => 'азия буйволу',
    '🐄' => 'уй',
    '🐷' => 'чочконун башы',
    '🐖' => 'чочко',
    '🐗' => 'каман',
    '🐽' => 'чочконун мурду',
    '🐏' => 'кочкор',
    '🐑' => 'кой',
    '🐐' => 'эчки',
    '🐪' => 'төө',
    '🐫' => 'эки өркөчтүү төө',
    '🦙' => 'лама',
    '🦒' => 'жираф',
    '🐘' => 'пил',
    '🦣' => 'мамонт',
    '🦏' => 'керик',
    '🦛' => 'бегемот',
    '🐭' => 'чычкандын башы',
    '🐁' => 'чычкан',
    '🐀' => 'келемиш',
    '🐹' => 'хомяктын башы',
    '🐰' => 'коёндун башы',
    '🐇' => 'коён',
    '🐿' => 'бурундук',
    '🦫' => 'кемчет',
    '🦔' => 'кирпи',
    '🦇' => 'жарганат',
    '🐻' => 'аюунун башы',
    '🐨' => 'коала',
    '🐼' => 'панданын башы',
    '🦥' => 'жалкоо айбан',
    '🦦' => 'кундуз',
    '🦨' => 'скунс',
    '🦘' => 'кенгуру',
    '🦡' => 'кашкулак',
    '🐾' => 'жырткычтын изи',
    '🦃' => 'үндүк',
    '🐔' => 'тоок',
    '🐓' => 'короз',
    '🐣' => 'жумурткадан чыгып жаткан жөжө',
    '🐤' => 'жөжө',
    '🐥' => 'бери карап турган жөжө',
    '🐦' => 'чымчык',
    '🐧' => 'пингвин',
    '🕊' => 'көгүчкөн',
    '🦅' => 'бүркүт',
    '🦆' => 'өрдөк',
    '🦢' => 'ак куу',
    '🦉' => 'үкү',
    '🦤' => 'додо',
    '🪶' => 'бир тал канат',
    '🦩' => 'фламинго',
    '🦚' => 'тоос',
    '🦜' => 'тоту куш',
    '🪽' => 'канат',
    '🪿' => 'каз',
    '🐸' => 'баканын башы',
    '🐊' => 'крокодил',
    '🐢' => 'ташбака',
    '🦎' => 'кескелдирик',
    '🐍' => 'жылан',
    '🐲' => 'ажыдаардын башы',
    '🐉' => 'ажыдаар',
    '🦕' => 'заврапод',
    '🦖' => 'тираннозавр рекс',
    '🐳' => 'суу чачып жаткан кит',
    '🐋' => 'кит',
    '🐬' => 'дельфин',
    '🫍' => 'косатка',
    '🦭' => 'тюлень',
    '🐟' => 'балык',
    '🐠' => 'тропикалык балык',
    '🐡' => 'үйлөнмө балык',
    '🦈' => 'акула',
    '🐙' => 'сегиз бут',
    '🐚' => 'үлүл кабыгы',
    '🪸' => 'коралл',
    '🪼' => 'медуза',
    '🦀' => 'бөйөн',
    '🦞' => 'омар',
    '🦐' => 'креветка',
    '🦑' => 'кальмар',
    '🦪' => 'устрица',
    '🐌' => 'үлүл',
    '🦋' => 'көпөлөк',
    '🐛' => 'курт',
    '🐜' => 'кумурска',
    '🐝' => 'бал аары',
    '🪲' => 'коңуз',
    '🐞' => 'эл кайда көчөт',
    '🦗' => 'кара чегиртке',
    '🪳' => 'таракан',
    '🕷' => 'жөргөмүш',
    '🕸' => 'жөргөмүш желеси',
    '🦂' => 'чаян',
    '🦟' => 'чиркей',
    '🪰' => 'чымын',
    '🪱' => 'мите',
    '🦠' => 'микроб',
    '💐' => 'гүлдесте',
    '🌸' => 'чие гүлү',
    '💮' => 'ак гүл',
    '🪷' => 'лотос',
    '🏵' => 'жапайы роза',
    '🌹' => 'роза',
    '🥀' => 'соолуган гүл',
    '🌺' => 'гибискус',
    '🌻' => 'күн карама',
    '🌼' => 'гүлдөө',
    '🌷' => 'жоогазын',
    '🪻' => 'гиацинт',
    '🌱' => 'көчөт',
    '🪴' => 'идиштеги өсүмдүк',
    '🌲' => 'арча',
    '🌳' => 'жалбырактуу дарак',
    '🌴' => 'пальма дарагы',
    '🌵' => 'кактус',
    '🌾' => 'бир боо күрүч',
    '🌿' => 'чөп',
    '☘' => 'беде',
    '🍀' => 'төрт жалбырактуу беде',
    '🍁' => 'клён жалбырагы',
    '🍂' => 'түшкөн жалбырак',
    '🍃' => 'шамалдан дирилдеген жалбырак',
    '🪹' => 'бош уя',
    '🪺' => 'ичинде жумурткалары бар уя',
    '🍄' => 'козу карын',
    '🪾' => 'жалбырагы жок дарак',
    '🍇' => 'жүзүм',
    '🍈' => 'коон',
    '🍉' => 'дарбыз',
    '🍊' => 'мандарин',
    '🍋' => 'лимон',
    '🍌' => 'банан',
    '🍍' => 'ананас',
    '🥭' => 'манго',
    '🍎' => 'кызыл алма',
    '🍏' => 'көк алма',
    '🍐' => 'алмурут',
    '🍑' => 'шабдалы',
    '🍒' => 'алча',
    '🍓' => 'кулпунай',
    '🫐' => 'кара моюл',
    '🥝' => 'киви',
    '🍅' => 'помидор',
    '🫒' => 'зайтун',
    '🥥' => 'кокос',
    '🥑' => 'авокадо',
    '🍆' => 'баклажан',
    '🥔' => 'картөшкө',
    '🥕' => 'сабиз',
    '🌽' => 'бир баш жүгөрү',
    '🌶' => 'ачуу калемпир',
    '🫑' => 'таттуу мурч',
    '🥒' => 'бадыраң',
    '🥬' => 'көк чөптөр',
    '🥦' => 'брокколи',
    '🧄' => 'сарымсак',
    '🧅' => 'пияз',
    '🥜' => 'жер жаңгак',
    '🫘' => 'буурчактар',
    '🌰' => 'каштан',
    '🫚' => 'имбир тамыры',
    '🫛' => 'буурчак кабыгы',
    '🫜' => 'тамыры желе турган жашылча',
    '🍞' => 'нан',
    '🥐' => 'круассан',
    '🥖' => 'багет',
    '🫓' => 'жапма нан',
    '🥨' => 'крендель',
    '🥯' => 'тегерек токоч',
    '🥞' => 'куймак',
    '🧇' => 'вафли',
    '🧀' => 'кесилген сыр',
    '🍖' => 'жилик эт',
    '🍗' => 'канаттуунун сан эти',
    '🥩' => 'эттин кесими',
    '🥓' => 'бекон',
    '🍔' => 'гамбургер',
    '🍟' => 'фри',
    '🍕' => 'пицца',
    '🌭' => 'хот-дог',
    '🥪' => 'сэндвич',
    '🌮' => 'тако',
    '🌯' => 'буррито',
    '🫔' => 'тамале',
    '🥙' => 'шаурма',
    '🧆' => 'фалафель',
    '🥚' => 'жумуртка',
    '🍳' => 'бышыруу',
    '🥘' => 'көмөч казандагы рагу',
    '🍲' => 'бир табак тамак',
    '🫕' => 'фондю',
    '🥣' => 'кашык салынган кесе',
    '🥗' => 'жашылча салаты',
    '🍿' => 'попкорн',
    '🧈' => 'май',
    '🧂' => 'туз',
    '🥫' => 'консерваланган тамак',
    '🍱' => 'бенто кутусу',
    '🍘' => 'күрүч крекери',
    '🍙' => 'күрүч тобу',
    '🍚' => 'бышкан күрүч',
    '🍛' => 'карри кошулган күрүч',
    '🍜' => 'бууланып жаткан чыны',
    '🍝' => 'спагетти',
    '🍠' => 'куурулган таттуу картошка',
    '🍢' => 'оден',
    '🍣' => 'суши',
    '🍤' => 'куурулган креветка',
    '🍥' => 'айлантып салынган балык пирогу',
    '🥮' => 'кытай пирожныйы',
    '🍡' => 'данго',
    '🥟' => 'пельмен',
    '🥠' => 'келечекти айтуучу печеньелер',
    '🥡' => 'тамакты үйгө салып кетүү үчүн кутуча',
    '🍦' => 'жумшак балмуздак',
    '🍧' => 'жылмаланган муз',
    '🍨' => 'балмуздак',
    '🍩' => 'пончик',
    '🍪' => 'булочка',
    '🎂' => 'туулган күн торту',
    '🍰' => 'каттама торт',
    '🧁' => 'пирожное',
    '🥧' => 'пирог',
    '🍫' => 'шоколад тилкеси',
    '🍬' => 'момпосуй',
    '🍭' => 'чупачупс',
    '🍮' => 'кастард',
    '🍯' => 'бал челек',
    '🍼' => 'баланын бөтөлкөсү',
    '🥛' => 'бир стакан сүт',
    '☕' => 'ысык суусундук',
    '🫖' => 'чайнек',
    '🍵' => 'чай чыны',
    '🍶' => 'саке',
    '🍾' => 'шампан',
    '🍷' => 'вино бокалы',
    '🍸' => 'коктейль бокалы',
    '🍹' => 'тропикалык суусундук',
    '🍺' => 'сыра кружкасы',
    '🍻' => 'кагышкан сыра кружкалары',
    '🥂' => 'бокал кагыштыруу',
    '🥃' => 'винонун стаканы',
    '🫗' => 'куюлуп жаткан суюктук',
    '🥤' => 'таякча салынган стакан',
    '🧋' => 'көбүргөн чай',
    '🧃' => 'суусундук кутусу',
    '🧉' => 'мате',
    '🧊' => 'муз куб',
    '🥢' => 'тамак таякчалары',
    '🍽' => 'вилка, бычак жана табак',
    '🍴' => 'вилка жана бычак',
    '🥄' => 'кашык',
    '🔪' => 'ашкана бычагы',
    '🫙' => 'банка',
    '🏺' => 'амфора',
    '🌍' => 'европа-африканы көрсөткөн глобус',
    '🌎' => 'американы көрсөткөн глобус',
    '🌏' => 'азия-австралияны көрсөткөн глобус',
    '🌐' => 'меридиан сызыктары менен глобус',
    '🗺' => 'дүйнө картасы',
    '🗾' => 'жапония картасы',
    '🧭' => 'компас',
    '🏔' => 'ак мөңгүлүү тоо',
    '⛰' => 'тоо',
    '🛘' => 'жер көчкү',
    '🌋' => 'жанар тоо',
    '🗻' => 'фудзияма тоосу',
    '🏕' => 'өргү жасоо',
    '🏖' => 'жээктеги чатыр',
    '🏜' => 'чөл',
    '🏝' => 'чөл аралы',
    '🏞' => 'улуттук сейилбак',
    '🏟' => 'стадион',
    '🏛' => 'классикалык имарат',
    '🏗' => 'имарат курулушу',
    '🧱' => 'кирпич',
    '🪨' => 'таш',
    '🪵' => 'отун',
    '🛖' => 'алачык',
    '🏘' => 'үй курулуштары',
    '🏚' => 'каралбаган үй',
    '🏠' => 'үй имараты',
    '🏡' => 'бакчасы бар үй',
    '🏢' => 'кеңсе имараты',
    '🏣' => 'жапон почтасы',
    '🏤' => 'почта',
    '🏥' => 'оорукана',
    '🏦' => 'банк',
    '🏨' => 'мейманкана',
    '🏩' => 'сүйүү мейманканасы',
    '🏪' => 'күнүмдүк товарлар дүкөнү',
    '🏫' => 'мектеп',
    '🏬' => 'дүр-дүйнө дүкөнү',
    '🏭' => 'завод',
    '🏯' => 'жапончо сепили',
    '🏰' => 'сепил',
    '💒' => 'үлпөт',
    '🗼' => 'токио мунарасы',
    '🗽' => 'эркиндик айкели',
    '⛪' => 'чиркөө',
    '🕌' => 'мечит',
    '🛕' => 'индус храмы',
    '🕍' => 'синагога',
    '⛩' => 'синто храмы',
    '🕋' => 'кааба',
    '⛲' => 'фонтан',
    '⛺' => 'чатыр',
    '🌁' => 'туман баскан',
    '🌃' => 'жылдыздуу түн',
    '🏙' => 'шаар көрүнүшү',
    '🌄' => 'күндүн тоодон чыгышы',
    '🌅' => 'күндүн чыгышы',
    '🌆' => 'күүгүмдөгү шаардын көрүнүшү',
    '🌇' => 'күндүн батышы',
    '🌉' => 'түнкү көпүрө',
    '♨' => 'ысык булактар',
    '🎠' => 'айланкөчөктөгү ат',
    '🛝' => 'балдар аянтчасындагы жылгаяк',
    '🎡' => 'шайтан дөңгөлөгү',
    '🎢' => 'америка тоосу',
    '💈' => 'чачтарач белгиси',
    '🎪' => 'цирк чатыры',
    '🚂' => 'локомотив',
    '🚃' => 'вагон',
    '🚄' => 'жогорку ылдамдыктагы поезд',
    '🚅' => 'жогорку ылдамдыктагы экспресс',
    '🚆' => 'поезд',
    '🚇' => 'метро',
    '🚈' => 'чакан метро',
    '🚉' => 'станция',
    '🚊' => 'трамвай',
    '🚝' => 'жалгыз рельс',
    '🚞' => 'тоодогу темир жол',
    '🚋' => 'трамвай вагону',
    '🚌' => 'автобус',
    '🚍' => 'келе жаткан автобус',
    '🚎' => 'троллейбус',
    '🚐' => 'маршрутка',
    '🚑' => 'тез жардам унаасы',
    '🚒' => 'өрт өчүргүчтөр унаасы',
    '🚓' => 'милиция унаасы',
    '🚔' => 'келе жаткан милиция унаасы',
    '🚕' => 'такси',
    '🚖' => 'келе жаткан такси',
    '🚗' => 'автоунаа',
    '🚘' => 'келе жаткан автоунаа',
    '🚙' => 'кроссовер',
    '🛻' => 'чакан жүк ташуучу унаа',
    '🚚' => 'жүк ташуучу машина',
    '🚛' => 'чиркегичи бар жүк ташуучу унаа',
    '🚜' => 'трактор',
    '🏎' => 'жарыш машинасы',
    '🏍' => 'мотоцикл',
    '🛵' => 'мопед',
    '🦽' => 'кол менен дөңгөлөктүү отургуч',
    '🦼' => 'майыптардын моторлуу арабасы',
    '🛺' => 'авто рикша',
    '🚲' => 'велосипед',
    '🛴' => 'самокат',
    '🛹' => 'скейтборд',
    '🛼' => 'ролик конькиси',
    '🚏' => 'аялдама',
    '🛣' => 'шоссе',
    '🛤' => 'темир жол',
    '🛢' => 'нефть челеги',
    '⛽' => 'күйүүчү май колонкасы',
    '🛞' => 'дөңгөлөк',
    '🚨' => 'милиция унаасынын сиренасы',
    '🚥' => 'туурасынан орнотулган жолчырак',
    '🚦' => 'тигинен орнотулган жолчырак',
    '🛑' => 'стоп белгиси',
    '🚧' => 'курулуш',
    '⚓' => 'анкер',
    '🛟' => 'куткаруу тегереги',
    '⛵' => 'парус',
    '🛶' => 'каноэ',
    '🚤' => 'тез жүргөн катер',
    '🛳' => 'жүргүнчүлөрдү ташыган кеме',
    '⛴' => 'паром',
    '🛥' => 'катер',
    '🚢' => 'кеме',
    '✈' => 'учак',
    '🛩' => 'кичи учак',
    '🛫' => 'учактын учушу',
    '🛬' => 'учактын конушу',
    '🪂' => 'парашют',
    '💺' => 'отургуч',
    '🚁' => 'тик учма',
    '🚟' => 'асма темир жол',
    '🚠' => 'тоодогу кабель жолу',
    '🚡' => 'асма трамвай',
    '🛰' => 'спутник',
    '🚀' => 'ракета',
    '🛸' => 'учуучу объект',
    '🛎' => 'тейлөөчү адамды чакырган баскыч',
    '🧳' => 'жүк',
    '⌛' => 'кум саат',
    '⏳' => 'куму агып жаткан кум саат',
    '⌚' => 'саат',
    '⏰' => 'ойготкуч саат',
    '⏱' => 'секунд ченегич',
    '⏲' => 'таймер сааты',
    '🕰' => 'текчедеги саат',
    '🕛' => 'саат он эки',
    '🕧' => 'он эки жарым',
    '🕐' => 'саат бир',
    '🕜' => 'бир жарым',
    '🕑' => 'саат эки',
    '🕝' => 'эки жарым',
    '🕒' => 'саат үч',
    '🕞' => 'үч жарым',
    '🕓' => 'саат төрт',
    '🕟' => 'төрт жарым',
    '🕔' => 'саат беш',
    '🕠' => 'беш жарым',
    '🕕' => 'саат алты',
    '🕡' => 'алты жарым',
    '🕖' => 'саат жети',
    '🕢' => 'жети жарым',
    '🕗' => 'саат сегиз',
    '🕣' => 'сегиз жарым',
    '🕘' => 'саат тогуз',
    '🕤' => 'тогуз жарым',
    '🕙' => 'саат он',
    '🕥' => 'он жарым',
    '🕚' => 'саат он бир',
    '🕦' => 'он бир жарым',
    '🌑' => 'жаңырган ай',
    '🌒' => 'толуп баштаган ай',
    '🌓' => 'жартысы толгон ай',
    '🌔' => 'толгону калган ай',
    '🌕' => 'толгон ай',
    '🌖' => 'бөксөрүп баштаган ай',
    '🌗' => 'жартысы бөксөргөн ай',
    '🌘' => 'бөксөрүп бүткөнү калган ай',
    '🌙' => 'жарым ай',
    '🌚' => 'жаңырган айдын бети',
    '🌛' => 'жартысы толгон айдын бети',
    '🌜' => 'жартысы бөксөргөн айдын бети',
    '🌡' => 'термометр',
    '☀' => 'күн',
    '🌝' => 'толгон айдын бети',
    '🌞' => 'күндүн бети',
    '🪐' => 'шакек менен курчалган планета',
    '⭐' => 'жылдыз',
    '🌟' => 'жаркыраган жылдыз',
    '🌠' => 'учкан жылдыз',
    '🌌' => 'саманчынын жолу',
    '☁' => 'булут',
    '⛅' => 'булуттун артындагы күн',
    '⛈' => 'чагылгандуу жамгыр жаап жаткан булут',
    '🌤' => 'кичине булуттун артындагы күн',
    '🌥' => 'чоң булуттун артындагы күн',
    '🌦' => 'жамгыр жааган булуттун артындагы күн',
    '🌧' => 'жамгыр жаап жаткан булут',
    '🌨' => 'кар жаап жаткан булут',
    '🌩' => 'чагылган түшүп жаткан булут',
    '🌪' => 'торнадо',
    '🌫' => 'туман',
    '🌬' => 'шамалдын бети',
    '🌀' => 'циклон',
    '🌈' => 'күн желеси',
    '🌂' => 'жабылган кол чатыр',
    '☂' => 'кол чатыр',
    '☔' => 'жамгыр тамчылаган кол чатыр',
    '⛱' => 'күндөн/жаан-чачындан калкалоочу чатыр',
    '⚡' => 'жогорку чыңалуу',
    '❄' => 'кар бүртүгү',
    '☃' => 'кар киши',
    '⛄' => 'карсыз кар киши',
    '☄' => 'комета',
    '🔥' => 'от',
    '💧' => 'тамчы',
    '🌊' => 'суу толкуну',
    '🎃' => 'ашкабактан лампа',
    '🎄' => 'Рождество балатысы',
    '🎆' => 'фейерверк',
    '🎇' => 'бенгал шамы',
    '🧨' => 'петарда',
    '✨' => 'учкундар',
    '🎈' => 'шар',
    '🎉' => 'кече уюштургуч',
    '🎊' => 'конфетти тобу',
    '🎋' => 'танабата дарагы',
    '🎍' => 'соснаны кооздоо',
    '🎎' => 'жапон куурчактары',
    '🎏' => 'карп лентасы',
    '🎐' => 'кытай жылаажындары',
    '🎑' => 'айга көз салуу жөрөлгөсү',
    '🧧' => 'кызыл конверт',
    '🎀' => 'лента',
    '🎁' => 'оролгон белек',
    '🎗' => 'эскерүү лентасы',
    '🎟' => 'кирүү билети',
    '🎫' => 'билет',
    '🎖' => 'аскер медалы',
    '🏆' => 'кубок',
    '🏅' => 'спорт медалы',
    '🥇' => 'алтын медаль',
    '🥈' => 'күмүш медаль',
    '🥉' => 'коло медаль',
    '⚽' => 'футбол тобу',
    '⚾' => 'бейсбол',
    '🥎' => 'софтбол',
    '🏀' => 'баскетбол',
    '🏐' => 'воллейбол',
    '🏈' => 'америка футболу',
    '🏉' => 'регби футболу',
    '🎾' => 'теннис',
    '🥏' => 'учурма диск',
    '🎳' => 'боулинг',
    '🏏' => 'крикет',
    '🏑' => 'чөптө ойнолчу хоккей',
    '🏒' => 'муз хоккейи, таяк жана шайба',
    '🥍' => 'лакросс',
    '🏓' => 'стол тенниси',
    '🏸' => 'бадминтон',
    '🥊' => 'бокс кол кабы',
    '🥋' => 'спорттук кимоно',
    '🥅' => 'футбол дарбазасы',
    '⛳' => 'тешиктеги желек',
    '⛸' => 'коньки',
    '🎣' => 'кайырмак',
    '🤿' => 'суучулдардын маскасы',
    '🎽' => 'майка',
    '🎿' => 'лыжа',
    '🛷' => 'чана',
    '🥌' => 'керлинг ташы',
    '🎯' => 'дротик',
    '🪀' => 'жипке илинген шайтан',
    '🪁' => 'Кагаз батперек',
    '🔫' => 'пистолет',
    '🎱' => 'бильярд',
    '🔮' => 'кристаллдуу топ',
    '🪄' => 'сыйкырдуу таяк',
    '🎮' => 'видео оюну',
    '🕹' => 'жойстик',
    '🎰' => 'оюн автоматы',
    '🎲' => 'сөөк оюну',
    '🧩' => 'баш катырма',
    '🧸' => 'оюнчук мамалак',
    '🪅' => 'пиньята',
    '🪩' => 'күзгү топ',
    '🪆' => 'матрёшка',
    '♠' => 'карга',
    '♥' => 'ача',
    '♦' => 'момун',
    '♣' => 'чырым',
    '♟' => 'пешка',
    '🃏' => 'жокер',
    '🀄' => 'маджонг кызыл ажыдаар',
    '🎴' => 'гүл ойноткон карталар',
    '🎭' => 'аткаруу өнөрү',
    '🖼' => 'алкак ичиндеги сүрөт',
    '🎨' => 'сүрөтчүнүн боёктору',
    '🧵' => 'жип',
    '🪡' => 'тигүүчү ийне',
    '🧶' => 'ийрилген жип',
    '🪢' => 'түйүн',
    '👓' => 'көз айнек',
    '🕶' => 'кара көз айнек',
    '🥽' => 'коргоочу көз айнек',
    '🥼' => 'лаборатория халаты',
    '🦺' => 'коопсуздук жилети',
    '👔' => 'галстук',
    '👕' => 'футболка',
    '👖' => 'джинсы шым',
    '🧣' => 'шарф',
    '🧤' => 'колкап',
    '🧥' => 'пальто',
    '🧦' => 'байпак',
    '👗' => 'көйнөк',
    '👘' => 'кимоно',
    '🥻' => 'сари',
    '🩱' => 'бүтүн суулук',
    '🩲' => 'ич кийим',
    '🩳' => 'чолок шым',
    '👙' => 'бикини',
    '👚' => 'аялдар кийими',
    '🪭' => 'бүктөлмө желпингич',
    '👛' => 'капчык',
    '👜' => 'колбаштык',
    '👝' => 'клатч',
    '🛍' => 'соода баштыктары',
    '🎒' => 'окуучулардын жонбаштыгы',
    '🩴' => 'сандальдын тилке кайышы',
    '👞' => 'эркектер бут кийими',
    '👟' => 'спорттук бут кийим',
    '🥾' => 'ботинка',
    '🥿' => 'жалпак туфли',
    '👠' => 'бийик такалуу бут кийим',
    '👡' => 'аялдар сандалиясы',
    '🩰' => 'балет бут кийими',
    '👢' => 'аялдар өтүгү',
    '🪮' => 'чачсайгы',
    '👑' => 'таажы',
    '👒' => 'аялдар баш кийими',
    '🎩' => 'бийик шляпа',
    '🎓' => 'бүтүрүүчүлөрдүн баш кийими',
    '🧢' => 'калканчы бар кепка',
    '🪖' => 'аскер туулгасы',
    '⛑' => 'ак крести бар каска',
    '📿' => 'теспе',
    '💄' => 'помада',
    '💍' => 'шакек',
    '💎' => 'асыл таш',
    '🔇' => 'колонка өчүк',
    '🔈' => 'колонка',
    '🔉' => 'колонка күйүк',
    '🔊' => 'колонка катуу',
    '📢' => 'катуу сүйлөткүч',
    '📣' => 'мегафон',
    '📯' => 'почта сурнайы',
    '🔔' => 'жылаажын',
    '🔕' => 'тыюу салынган жылаажын',
    '🎼' => 'музыкалык ачкыч',
    '🎵' => 'музыкалык нота',
    '🎶' => 'музыкалык ноталар',
    '🎙' => 'студия микрофону',
    '🎚' => 'нивелир',
    '🎛' => 'көзөмөл баскычтары',
    '🎤' => 'микрофон',
    '🎧' => 'кулакаспап',
    '📻' => 'радио',
    '🎷' => 'саксофон',
    '🎺' => 'сурнай',
    '🪊' => 'тромбон',
    '🪗' => 'аккордеон',
    '🎸' => 'гитара',
    '🎹' => 'музыкалык клавиша',
    '🎻' => 'скрипка',
    '🪕' => 'банжо',
    '🥁' => 'барабан',
    '🪘' => 'узун добулбас',
    '🪇' => 'маракас',
    '🪈' => 'флейта',
    '🪉' => 'арфа',
    '📱' => 'мобилдик телефон',
    '📲' => 'мобилдик телефон менен жебе',
    '☎' => 'телефон',
    '📞' => 'телефон трубкасы',
    '📟' => 'пейджер',
    '📠' => 'факс машинасы',
    '🔋' => 'батарея',
    '🪫' => 'батарея төмөн',
    '🔌' => 'электр вилкасы',
    '💻' => 'ноутбук',
    '🖥' => 'иш тактасындагы компьютер',
    '🖨' => 'принтер',
    '⌨' => 'баскычтоп',
    '🖱' => 'компьютер чычканы',
    '🖲' => 'жылдыруу шары',
    '💽' => 'минидиск',
    '💾' => 'дискета',
    '💿' => 'оптикалык диск',
    '📀' => 'dvd',
    '🧮' => 'абакус',
    '🎥' => 'тасма камерасы',
    '🎞' => 'тасма кадрлары',
    '📽' => 'кинопроектор',
    '🎬' => 'шакылдак нумератор',
    '📺' => 'сыналгы',
    '📷' => 'камера',
    '📸' => 'жаркылдагы менен камера',
    '📹' => 'видео камера',
    '📼' => 'видеокассета',
    '🔍' => 'сол жакты караган лупа',
    '🔎' => 'оң жакты караган лупа',
    '🕯' => 'шам',
    '💡' => 'жарык лампочкасы',
    '🔦' => 'колчырак',
    '🏮' => 'кызыл кагаздан жасалган лампа',
    '🪔' => 'дия май чырагы',
    '📔' => 'мукабасы кооздолгон блокнот',
    '📕' => 'жабык китеп',
    '📖' => 'ачык китеп',
    '📗' => 'жашыл китеп',
    '📘' => 'көк китеп',
    '📙' => 'саргыч китеп',
    '📚' => 'китептер',
    '📓' => 'дептер',
    '📒' => 'бухгалтердик китепче',
    '📃' => 'оролган барак',
    '📜' => 'ороо',
    '📄' => 'өйдө караган барак',
    '📰' => 'гезит',
    '🗞' => 'оролгон гезит',
    '📑' => 'кыстарма өтмөктөрү',
    '🔖' => 'кыстарма',
    '🏷' => 'энбелги',
    '🪙' => 'тыйын',
    '💰' => 'акча баштыгы',
    '🪎' => 'казына сандык',
    '💴' => 'иена банкнотасы',
    '💵' => 'доллар банкнотасы',
    '💶' => 'евро банкнотасы',
    '💷' => 'фунт банкнотасы',
    '💸' => 'канаты бар акча',
    '💳' => 'насыя картасы',
    '🧾' => 'дүмүрчөк',
    '💹' => 'иена менен көтөрүлүп жаткан диаграмма',
    '✉' => 'конверт',
    '📧' => 'эл-кат',
    '📨' => 'кирүүчү конверт',
    '📩' => 'жебе менен конверт',
    '📤' => 'чыгуучу куту',
    '📥' => 'кирүүчү куту',
    '📦' => 'таңгак',
    '📫' => 'желеги көтөрүлгөн жабык кат кутусу',
    '📪' => 'желеги түшүрүлгөн жабык кат кутусу',
    '📬' => 'желеги көтөрүлгөн ачык кат кутусу',
    '📭' => 'желеги түшүрүлгөн ачык кат кутусу',
    '📮' => 'почта кутусу',
    '🗳' => 'бюллетень менен куту',
    '✏' => 'калем',
    '✒' => 'кара сыя калеми',
    '🖋' => 'авторучка',
    '🖊' => 'сыя калем',
    '🖌' => 'кисть',
    '🖍' => 'түстүү калем',
    '📝' => 'эскертме',
    '💼' => 'портфель',
    '📁' => 'файл куржуну',
    '📂' => 'файл куржунун ачуу',
    '🗂' => 'картотека бөлгүч',
    '📅' => 'жылнаама',
    '📆' => 'тытма жылнаама',
    '🗒' => 'спиралдуу блокнот',
    '🗓' => 'спиралдуу жылнаама',
    '📇' => 'картотека',
    '📈' => 'көтөрүлүп жаткан диаграмма',
    '📉' => 'түшүп жаткан диаграмма',
    '📊' => 'гистограмма',
    '📋' => 'кыскычтуу пюпитр',
    '📌' => 'мончоктуу төөнөгүч',
    '📍' => 'тегерек төөнөгүч',
    '📎' => 'кыпчыгыч',
    '🖇' => 'бириккен тиркегичтер',
    '📏' => 'түз сызгыч',
    '📐' => 'үч бурчтук сызгыч',
    '✂' => 'кайчы',
    '🗃' => 'карта файлынын кутусу',
    '🗄' => 'файл суурмасы',
    '🗑' => 'таштанды кутусу',
    '🔒' => 'кулпу',
    '🔓' => 'ачык кулпу',
    '🔏' => 'калем менен кулпулоо',
    '🔐' => 'ачкыч менен жабылган кулпу',
    '🔑' => 'ачкыч',
    '🗝' => 'эски ачкыч',
    '🔨' => 'балка',
    '🪓' => 'балта',
    '⛏' => 'керки',
    '⚒' => 'балка менен керки',
    '🛠' => 'балка менен гайка ачкычы',
    '🗡' => 'канжар',
    '⚔' => 'кайчылашкан кылычтар',
    '💣' => 'бомба',
    '🪃' => 'бумеранг',
    '🏹' => 'жаа менен жебе',
    '🛡' => 'калкан',
    '🪚' => 'жыгач уста араасы',
    '🔧' => 'гайка ачкычы',
    '🪛' => 'отвертка',
    '🔩' => 'гайка менен болт',
    '⚙' => 'механизм',
    '🗜' => 'кысуу',
    '⚖' => 'тараза',
    '🦯' => 'зонд таягы',
    '🔗' => 'тогоо',
    '⛓' => 'чынжыр',
    '🪝' => 'илгич',
    '🧰' => 'куралдар кутусу',
    '🧲' => 'магнит',
    '🪜' => 'тепкич',
    '🪏' => 'күрөк',
    '⚗' => 'дистиллятор',
    '🧪' => 'медициналык пробирка',
    '🧫' => 'Петри идиши',
    '🧬' => 'днк',
    '🔬' => 'микроскоп',
    '🔭' => 'телескоп',
    '📡' => 'спутниктик антенна',
    '💉' => 'шприц',
    '🩸' => 'тамчы кан',
    '💊' => 'таблетка',
    '🩹' => 'чаптама бинт',
    '🩼' => 'балдак',
    '🩺' => 'стетоскоп',
    '🩻' => 'рентген',
    '🚪' => 'эшик',
    '🛗' => 'лифт',
    '🪞' => 'күзгү',
    '🪟' => 'терезе',
    '🛏' => 'төшөк',
    '🛋' => 'софа жана лампа',
    '🪑' => 'стул',
    '🚽' => 'туалет',
    '🪠' => 'вантуз',
    '🚿' => 'душ',
    '🛁' => 'ванна',
    '🪤' => 'чычкан капкан',
    '🪒' => 'устара',
    '🧴' => 'лосьон куюлган идиш',
    '🧷' => 'төөнөгүч',
    '🧹' => 'шыпыргы',
    '🧺' => 'себет',
    '🧻' => 'түрүлгөн кагаз',
    '🪣' => 'чака',
    '🧼' => 'самын',
    '🫧' => 'көбүктөр',
    '🪥' => 'тиш щётка',
    '🧽' => 'губка',
    '🧯' => 'өрт өчүргүч',
    '🛒' => 'дүкөн арабасы',
    '🚬' => 'чылым чегүү',
    '⚰' => 'гроб',
    '🪦' => 'мүрзө ташы',
    '⚱' => 'көмүү урнасы',
    '🧿' => 'көз мончок',
    '🪬' => 'Хамса',
    '🗿' => 'моаи',
    '🪧' => 'афиша',
    '🪪' => 'идентификациондук карта',
    '🏧' => 'банкомат белгиси',
    '🚮' => 'таштандыга салуу белгиси',
    '🚰' => 'иче турган суу',
    '♿' => 'майыптардын арабасы',
    '🚹' => 'эркектердин дааратканасы',
    '🚺' => 'аялдардын дааратканасы',
    '🚻' => 'даараткана',
    '🚼' => 'бала символу',
    '🚾' => 'даараткана белгиси',
    '🛂' => 'паспортту текшерүү',
    '🛃' => 'бажы салыгы',
    '🛄' => 'багажды алуу',
    '🛅' => 'калтырылган жүк',
    '⚠' => 'эскертүү',
    '🚸' => 'жолдон балдар өтөт',
    '⛔' => 'кирүүгө болбойт',
    '🚫' => 'тыюу салынган',
    '🚳' => 'велосипедке уруксат жок',
    '🚭' => 'чылым чегүүгө болбойт',
    '🚯' => 'булгабагыла',
    '🚱' => 'ичкенге жараксыз суу',
    '🚷' => 'жөө өткөнгө болбойт',
    '📵' => 'мобилдик телефонду өчүр',
    '🔞' => 'он сегиз жашка чейинкилерге уруксат жок',
    '☢' => 'раидоактивдүү',
    '☣' => 'биологиялык коркунуч',
    '⬆' => 'өйдө караган жебе',
    '↗' => 'өйдө оң жакты караган жебе',
    '➡' => 'оң жакты караган жебе',
    '↘' => 'төмөн оң жакты караган жебе',
    '⬇' => 'төмөн караган жебе',
    '↙' => 'төмөн сол жакты караган жебе',
    '⬅' => 'сол жакты караган жебе',
    '↖' => 'өйдө сол жакты караган жебе',
    '↕' => 'өйдө-төмөн караган жебе',
    '↔' => 'оңго-солго караган жебе',
    '↩' => 'оңдон солго ийилген жебе',
    '↪' => 'солдон оңго ийилген жебе',
    '⤴' => 'оңдон өйдө ийилген жебе',
    '⤵' => 'оңдон төмөн ийилген жебе',
    '🔃' => 'саат жебеси менен тик турган жебелер',
    '🔄' => 'саат жебесине каршы жебелер',
    '🔙' => 'артка жебеси',
    '🔚' => 'аягы жебеси',
    '🔛' => 'күйүк! жебеси',
    '🔜' => 'жакында жебеси',
    '🔝' => 'башында жебеси',
    '🛐' => 'ыйык жер',
    '⚛' => 'атом символу',
    '🕉' => 'ом',
    '✡' => 'давид жылдызы',
    '☸' => 'дхарма дөңгөлөгү',
    '☯' => 'Инь-ян',
    '✝' => 'латын крести',
    '☦' => 'ортодокс крести',
    '☪' => 'ай жана жылдыз',
    '☮' => 'тынчтыктын символу',
    '🕎' => 'менора',
    '🔯' => 'чекиттүү алты жылдыз',
    '🪯' => 'кханда (Сикх белгиси)',
    '♈' => 'кой жылдызы',
    '♉' => 'букачар',
    '♊' => 'эгиздер',
    '♋' => 'бөйөн жылдызы',
    '♌' => 'арстан',
    '♍' => 'бийкеч',
    '♎' => 'тараза жылдызы',
    '♏' => 'чаян жылдызы',
    '♐' => 'жаачы',
    '♑' => 'текечер',
    '♒' => 'суупери',
    '♓' => 'балыктар',
    '⛎' => 'жыланчы',
    '🔀' => 'тректерди аралаштыруу баскычы',
    '🔁' => 'кайталоо баскычы',
    '🔂' => 'жалгыз кайталоо баскычы',
    '▶' => 'ойнотуу баскычы',
    '⏩' => 'алдыга түрүү баскычы',
    '⏭' => 'кийинки трек баскычы',
    '⏯' => 'ойнотуу же тындыруу баскычы',
    '◀' => 'артка баскычы',
    '⏪' => 'артка түрдүрүү баскычы',
    '⏮' => 'мурунку трек баскычы',
    '🔼' => 'өйдө баскычы',
    '⏫' => 'өйдө түрдүрүү баскычы',
    '🔽' => 'төмөн баскычы',
    '⏬' => 'төмөн түрдүрүү баскычы',
    '⏸' => 'тындыруу баскычы',
    '⏹' => 'токтотуу баскычы',
    '⏺' => 'жаздыруу баскычы',
    '⏏' => 'чыгаруу баскычы',
    '🎦' => 'кинотеатр',
    '🔅' => 'бүдөмүктөтүү баскычы',
    '🔆' => 'жарык баскычы',
    '📶' => 'антенна тилкелери',
    '🛜' => 'зымсыз',
    '📳' => 'титирөө режими',
    '📴' => 'мобилдик телефон өчүк',
    '♀' => 'аял белгиси',
    '♂' => 'эркек белгиси',
    '⚧' => 'трансгендер белгиси',
    '✖' => 'көбөйтүү',
    '➕' => 'плюс',
    '➖' => 'минус',
    '➗' => 'бөлүү',
    '🟰' => 'так барабар белгиси',
    '♾' => 'чексиз',
    '‼' => 'кош илеп белгиси',
    '⁉' => 'суроолу илеп белгиси',
    '❓' => 'кызыл суроо белгиси',
    '❔' => 'ак суроо белгиси',
    '❕' => 'ак илеп белгиси',
    '❗' => 'кызыл илеп белгиси',
    '〰' => 'толкундуу сызыкча',
    '💱' => 'акча алмаштыруу',
    '💲' => 'жоон доллар белгиси',
    '⚕' => 'эскулап белгиси',
    '♻' => 'кайра иштетүү символу',
    '⚜' => 'геральд лилиясы',
    '🔱' => 'үч тиштүү эмблема',
    '📛' => 'ысым бейджиги',
    '🔰' => 'жапончочо үйрөнчүктөр символу',
    '⭕' => 'жоон, ири тегерек',
    '✅' => 'ак «туура» белгиси',
    '☑' => '«чымчыкча» белгиси менен кутуча',
    '✔' => 'жоон «туура» белгиси',
    '❌' => 'кайчылаш белгиси',
    '❎' => 'кайчылаш белги баскычы',
    '➰' => 'тармал кайчылаш',
    '➿' => 'кош тармал кайчылаш',
    '〽' => 'өзгөртүү белгиси',
    '✳' => 'сегиз жылдыз',
    '✴' => 'төрт жылдыз',
    '❇' => 'жалтылдак',
    '™' => 'соода маркасы',
    '🫟' => 'чачыранды',
    '🔠' => 'латынча баш тамга менен киргизүү',
    '🔡' => 'латынча кичине тамга менен киргизүү',
    '🔢' => 'сандарды киргизүү',
    '🔣' => 'символдорду киргизүү',
    '🔤' => 'латын тамгаларын киргизүү',
    '🅰' => 'а баскычы',
    '🆎' => 'аб баскычы',
    '🅱' => 'б баскычы',
    '🆑' => 'CL баскычы',
    '🆒' => 'чарчыдагы салкын',
    '🆓' => 'чарчыдагы акысыз',
    'ℹ' => 'маалымат булагы',
    '🆔' => 'ID баскычы',
    'Ⓜ' => 'тегеректеги м',
    '🆕' => 'NEW баскычы',
    '🆖' => 'NG баскычы',
    '🅾' => 'о баскычы',
    '🆗' => 'чарчыдагы ок',
    '🅿' => 'р баскычы',
    '🆘' => 'чарчыдагы сос',
    '🆙' => 'ЖОГОРУ! баскычы',
    '🆚' => 'чарчыдагы крш.',
    '🈁' => 'чарчыдагы катакана коко',
    '🈂' => 'чарчыдагы катакана са',
    '🈷' => 'чарчыдагы ай идеограммасы',
    '🈶' => 'чарчыдагы жашоо идеограммасы',
    '🈯' => 'чарчыдагы манжа идеограммасы',
    '🉐' => 'тегеректеги мүмкүнчүлүк идеограммасы',
    '🈹' => 'чарчыдагы бөлүү идеограммасы',
    '🈚' => 'чарчыдагы сүйлөшүү идеограммасы',
    '🈲' => 'чарчыдагы тыюу салуу идеограммасы',
    '🉑' => 'тегеректеги кабыл алуу идеограммасы',
    '🈸' => 'чарчыдагы колдонуу идеограммасы',
    '🈴' => 'чарчыдагы бирге идеограммасы',
    '🈳' => 'чарчыдагы бош идеограммасы',
    '㊗' => 'тегеректеги куттуктоо идеограммасы',
    '㊙' => 'тегеректеги купуя идеограммасы',
    '🈺' => 'чарчыдагы иштетүү идеограммасы',
    '🈵' => 'чарчыдагы толуктук идеограммасы',
    '🔴' => 'кызыл тегерек',
    '🟠' => 'кызгылт сары айлана',
    '🟡' => 'сары айлана',
    '🟢' => 'жашыл айлана',
    '🔵' => 'көк тегерек',
    '🟣' => 'кызгылт көк айлана',
    '🟤' => 'күрөң айлана',
    '⚫' => 'кара тегерек',
    '⚪' => 'ак тегерек',
    '🟥' => 'кызыл квадрат',
    '🟧' => 'кызгылт сары квадрат',
    '🟨' => 'сары квадрат',
    '🟩' => 'жашыл квадрат',
    '🟦' => 'көк квадрат',
    '🟪' => 'кызгылт көк квадрат',
    '🟫' => 'күрөң квадрат',
    '⬛' => 'чоң кара чарчы',
    '⬜' => 'чоң ак чарчы',
    '◼' => 'орточо кара чарчы',
    '◻' => 'орточо ак чарчы',
    '◾' => 'кичирээк кара чарчы',
    '◽' => 'кичирээк ак чарчы',
    '▪' => 'кичинекей кара чарчы',
    '▫' => 'кичинекей ак чарчы',
    '🔶' => 'чоң саргыч ромб',
    '🔷' => 'чоң көк ромб',
    '🔸' => 'кичинекей саргыч ромб',
    '🔹' => 'кичинекей көк ромб',
    '🔺' => 'өйдө караган кызыл үч бурчтук',
    '🔻' => 'төмөн караган кызыл үч бурчтук',
    '💠' => 'чекиттүү ромб',
    '🔘' => 'радио баскычы',
    '🔳' => 'ак чарчы баскычы',
    '🔲' => 'кара чарчы баскычы',
    '🏁' => 'шахмат түсүндөгү желек',
    '🚩' => 'үч бурчтук желек',
    '🎌' => 'кайчылаш желектер',
    '🏴' => 'желбиреген кара желек',
    '🏳' => 'желбиреген ак желек',
];
