<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'koss: manneskja, manneskja, ljós húðlitur og meðalljós húðlitur',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'koss: manneskja, manneskja, ljós húðlitur og millihúðlitur',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'koss: manneskja, manneskja, ljós húðlitur og meðaldökkur húðlitur',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'koss: manneskja, manneskja, ljós húðlitur og dökkur húðlitur',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'koss: manneskja, manneskja, meðalljós húðlitur og ljós húðlitur',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'koss: manneskja, manneskja, meðalljós húðlitur og millihúðlitur',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'koss: manneskja, manneskja, meðalljós húðlitur og meðaldökkur húðlitur',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'koss: manneskja, manneskja, meðalljós húðlitur og dökkur húðlitur',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'koss: manneskja, manneskja, millihúðlitur og ljós húðlitur',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'koss: manneskja, manneskja, millihúðlitur og meðalljós húðlitur',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'koss: manneskja, manneskja, millihúðlitur og meðaldökkur húðlitur',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'koss: manneskja, manneskja, millihúðlitur og dökkur húðlitur',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'koss: manneskja, manneskja, meðaldökkur húðlitur og ljós húðlitur',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'koss: manneskja, manneskja, meðaldökkur húðlitur og meðalljós húðlitur',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'koss: manneskja, manneskja, meðaldökkur húðlitur og millihúðlitur',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'koss: manneskja, manneskja, meðaldökkur húðlitur og dökkur húðlitur',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'koss: manneskja, manneskja, dökkur húðlitur og ljós húðlitur',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'koss: manneskja, manneskja, dökkur húðlitur og meðalljós húðlitur',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'koss: manneskja, manneskja, dökkur húðlitur og millihúðlitur',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'koss: manneskja, manneskja, dökkur húðlitur og meðaldökkur húðlitur',
    '👨🏻‍❤‍💋‍👨🏻' => 'koss: karl, karl og ljós húðlitur',
    '👨🏻‍❤‍💋‍👨🏼' => 'koss: karl, karl, ljós húðlitur og meðalljós húðlitur',
    '👨🏻‍❤‍💋‍👨🏽' => 'koss: karl, karl, ljós húðlitur og millihúðlitur',
    '👨🏻‍❤‍💋‍👨🏾' => 'koss: karl, karl, ljós húðlitur og meðaldökkur húðlitur',
    '👨🏻‍❤‍💋‍👨🏿' => 'koss: karl, karl, ljós húðlitur og dökkur húðlitur',
    '👨🏼‍❤‍💋‍👨🏻' => 'koss: karl, karl, meðalljós húðlitur og ljós húðlitur',
    '👨🏼‍❤‍💋‍👨🏼' => 'koss: karl, karl og meðalljós húðlitur',
    '👨🏼‍❤‍💋‍👨🏽' => 'koss: karl, karl, meðalljós húðlitur og millihúðlitur',
    '👨🏼‍❤‍💋‍👨🏾' => 'koss: karl, karl, meðalljós húðlitur og meðaldökkur húðlitur',
    '👨🏼‍❤‍💋‍👨🏿' => 'koss: karl, karl, meðalljós húðlitur og dökkur húðlitur',
    '👨🏽‍❤‍💋‍👨🏻' => 'koss: karl, karl, millihúðlitur og ljós húðlitur',
    '👨🏽‍❤‍💋‍👨🏼' => 'koss: karl, karl, millihúðlitur og meðalljós húðlitur',
    '👨🏽‍❤‍💋‍👨🏽' => 'koss: karl, karl og millihúðlitur',
    '👨🏽‍❤‍💋‍👨🏾' => 'koss: karl, karl, millihúðlitur og meðaldökkur húðlitur',
    '👨🏽‍❤‍💋‍👨🏿' => 'koss: karl, karl, millihúðlitur og dökkur húðlitur',
    '👨🏾‍❤‍💋‍👨🏻' => 'koss: karl, karl, meðaldökkur húðlitur og ljós húðlitur',
    '👨🏾‍❤‍💋‍👨🏼' => 'koss: karl, karl, meðaldökkur húðlitur og meðalljós húðlitur',
    '👨🏾‍❤‍💋‍👨🏽' => 'koss: karl, karl, meðaldökkur húðlitur og millihúðlitur',
    '👨🏾‍❤‍💋‍👨🏾' => 'koss: karl, karl og meðaldökkur húðlitur',
    '👨🏾‍❤‍💋‍👨🏿' => 'koss: karl, karl, meðaldökkur húðlitur og dökkur húðlitur',
    '👨🏿‍❤‍💋‍👨🏻' => 'koss: karl, karl, dökkur húðlitur og ljós húðlitur',
    '👨🏿‍❤‍💋‍👨🏼' => 'koss: karl, karl, dökkur húðlitur og meðalljós húðlitur',
    '👨🏿‍❤‍💋‍👨🏽' => 'koss: karl, karl, dökkur húðlitur og millihúðlitur',
    '👨🏿‍❤‍💋‍👨🏾' => 'koss: karl, karl, dökkur húðlitur og meðaldökkur húðlitur',
    '👨🏿‍❤‍💋‍👨🏿' => 'koss: karl, karl og dökkur húðlitur',
    '👩🏻‍❤‍💋‍👨🏻' => 'koss: kona, karl og ljós húðlitur',
    '👩🏻‍❤‍💋‍👨🏼' => 'koss: kona, karl, ljós húðlitur og meðalljós húðlitur',
    '👩🏻‍❤‍💋‍👨🏽' => 'koss: kona, karl, ljós húðlitur og millihúðlitur',
    '👩🏻‍❤‍💋‍👨🏾' => 'koss: kona, karl, ljós húðlitur og meðaldökkur húðlitur',
    '👩🏻‍❤‍💋‍👨🏿' => 'koss: kona, karl, ljós húðlitur og dökkur húðlitur',
    '👩🏼‍❤‍💋‍👨🏻' => 'koss: kona, karl, meðalljós húðlitur og ljós húðlitur',
    '👩🏼‍❤‍💋‍👨🏼' => 'koss: kona, karl og meðalljós húðlitur',
    '👩🏼‍❤‍💋‍👨🏽' => 'koss: kona, karl, meðalljós húðlitur og millihúðlitur',
    '👩🏼‍❤‍💋‍👨🏾' => 'koss: kona, karl, meðalljós húðlitur og meðaldökkur húðlitur',
    '👩🏼‍❤‍💋‍👨🏿' => 'koss: kona, karl, meðalljós húðlitur og dökkur húðlitur',
    '👩🏽‍❤‍💋‍👨🏻' => 'koss: kona, karl, millihúðlitur og ljós húðlitur',
    '👩🏽‍❤‍💋‍👨🏼' => 'koss: kona, karl, millihúðlitur og meðalljós húðlitur',
    '👩🏽‍❤‍💋‍👨🏽' => 'koss: kona, karl og millihúðlitur',
    '👩🏽‍❤‍💋‍👨🏾' => 'koss: kona, karl, millihúðlitur og meðaldökkur húðlitur',
    '👩🏽‍❤‍💋‍👨🏿' => 'koss: kona, karl, millihúðlitur og dökkur húðlitur',
    '👩🏾‍❤‍💋‍👨🏻' => 'koss: kona, karl, meðaldökkur húðlitur og ljós húðlitur',
    '👩🏾‍❤‍💋‍👨🏼' => 'koss: kona, karl, meðaldökkur húðlitur og meðalljós húðlitur',
    '👩🏾‍❤‍💋‍👨🏽' => 'koss: kona, karl, meðaldökkur húðlitur og millihúðlitur',
    '👩🏾‍❤‍💋‍👨🏾' => 'koss: kona, karl og meðaldökkur húðlitur',
    '👩🏾‍❤‍💋‍👨🏿' => 'koss: kona, karl, meðaldökkur húðlitur og dökkur húðlitur',
    '👩🏿‍❤‍💋‍👨🏻' => 'koss: kona, karl, dökkur húðlitur og ljós húðlitur',
    '👩🏿‍❤‍💋‍👨🏼' => 'koss: kona, karl, dökkur húðlitur og meðalljós húðlitur',
    '👩🏿‍❤‍💋‍👨🏽' => 'koss: kona, karl, dökkur húðlitur og millihúðlitur',
    '👩🏿‍❤‍💋‍👨🏾' => 'koss: kona, karl, dökkur húðlitur og meðaldökkur húðlitur',
    '👩🏿‍❤‍💋‍👨🏿' => 'koss: kona, karl og dökkur húðlitur',
    '👩🏻‍❤‍💋‍👩🏻' => 'koss: kona, kona og ljós húðlitur',
    '👩🏻‍❤‍💋‍👩🏼' => 'koss: kona, kona, ljós húðlitur og meðalljós húðlitur',
    '👩🏻‍❤‍💋‍👩🏽' => 'koss: kona, kona, ljós húðlitur og millihúðlitur',
    '👩🏻‍❤‍💋‍👩🏾' => 'koss: kona, kona, ljós húðlitur og meðaldökkur húðlitur',
    '👩🏻‍❤‍💋‍👩🏿' => 'koss: kona, kona, ljós húðlitur og dökkur húðlitur',
    '👩🏼‍❤‍💋‍👩🏻' => 'koss: kona, kona, meðalljós húðlitur og ljós húðlitur',
    '👩🏼‍❤‍💋‍👩🏼' => 'koss: kona, kona og meðalljós húðlitur',
    '👩🏼‍❤‍💋‍👩🏽' => 'koss: kona, kona, meðalljós húðlitur og millihúðlitur',
    '👩🏼‍❤‍💋‍👩🏾' => 'koss: kona, kona, meðalljós húðlitur og meðaldökkur húðlitur',
    '👩🏼‍❤‍💋‍👩🏿' => 'koss: kona, kona, meðalljós húðlitur og dökkur húðlitur',
    '👩🏽‍❤‍💋‍👩🏻' => 'koss: kona, kona, millihúðlitur og ljós húðlitur',
    '👩🏽‍❤‍💋‍👩🏼' => 'koss: kona, kona, millihúðlitur og meðalljós húðlitur',
    '👩🏽‍❤‍💋‍👩🏽' => 'koss: kona, kona og millihúðlitur',
    '👩🏽‍❤‍💋‍👩🏾' => 'koss: kona, kona, millihúðlitur og meðaldökkur húðlitur',
    '👩🏽‍❤‍💋‍👩🏿' => 'koss: kona, kona, millihúðlitur og dökkur húðlitur',
    '👩🏾‍❤‍💋‍👩🏻' => 'koss: kona, kona, meðaldökkur húðlitur og ljós húðlitur',
    '👩🏾‍❤‍💋‍👩🏼' => 'koss: kona, kona, meðaldökkur húðlitur og meðalljós húðlitur',
    '👩🏾‍❤‍💋‍👩🏽' => 'koss: kona, kona, meðaldökkur húðlitur og millihúðlitur',
    '👩🏾‍❤‍💋‍👩🏾' => 'koss: kona, kona og meðaldökkur húðlitur',
    '👩🏾‍❤‍💋‍👩🏿' => 'koss: kona, kona, meðaldökkur húðlitur og dökkur húðlitur',
    '👩🏿‍❤‍💋‍👩🏻' => 'koss: kona, kona, dökkur húðlitur og ljós húðlitur',
    '👩🏿‍❤‍💋‍👩🏼' => 'koss: kona, kona, dökkur húðlitur og meðalljós húðlitur',
    '👩🏿‍❤‍💋‍👩🏽' => 'koss: kona, kona, dökkur húðlitur og millihúðlitur',
    '👩🏿‍❤‍💋‍👩🏾' => 'koss: kona, kona, dökkur húðlitur og meðaldökkur húðlitur',
    '👩🏿‍❤‍💋‍👩🏿' => 'koss: kona, kona og dökkur húðlitur',
    '🧑🏻‍🫯‍🧑🏼' => 'glíma: ljós húðlitur og meðalljós húðlitur',
    '🧑🏻‍🫯‍🧑🏽' => 'glíma: ljós húðlitur og millihúðlitur',
    '🧑🏻‍🫯‍🧑🏾' => 'glíma: ljós húðlitur og meðaldökkur húðlitur',
    '🧑🏻‍🫯‍🧑🏿' => 'glíma: ljós húðlitur og dökkur húðlitur',
    '🧑🏼‍🫯‍🧑🏻' => 'glíma: meðalljós húðlitur og ljós húðlitur',
    '🧑🏼‍🫯‍🧑🏽' => 'glíma: meðalljós húðlitur og millihúðlitur',
    '🧑🏼‍🫯‍🧑🏾' => 'glíma: meðalljós húðlitur og meðaldökkur húðlitur',
    '🧑🏼‍🫯‍🧑🏿' => 'glíma: meðalljós húðlitur og dökkur húðlitur',
    '🧑🏽‍🫯‍🧑🏻' => 'glíma: millihúðlitur og ljós húðlitur',
    '🧑🏽‍🫯‍🧑🏼' => 'glíma: millihúðlitur og meðalljós húðlitur',
    '🧑🏽‍🫯‍🧑🏾' => 'glíma: millihúðlitur og meðaldökkur húðlitur',
    '🧑🏽‍🫯‍🧑🏿' => 'glíma: millihúðlitur og dökkur húðlitur',
    '🧑🏾‍🫯‍🧑🏻' => 'glíma: meðaldökkur húðlitur og ljós húðlitur',
    '🧑🏾‍🫯‍🧑🏼' => 'glíma: meðaldökkur húðlitur og meðalljós húðlitur',
    '🧑🏾‍🫯‍🧑🏽' => 'glíma: meðaldökkur húðlitur og millihúðlitur',
    '🧑🏾‍🫯‍🧑🏿' => 'glíma: meðaldökkur húðlitur og dökkur húðlitur',
    '🧑🏿‍🫯‍🧑🏻' => 'glíma: dökkur húðlitur og ljós húðlitur',
    '🧑🏿‍🫯‍🧑🏼' => 'glíma: dökkur húðlitur og meðalljós húðlitur',
    '🧑🏿‍🫯‍🧑🏽' => 'glíma: dökkur húðlitur og millihúðlitur',
    '🧑🏿‍🫯‍🧑🏾' => 'glíma: dökkur húðlitur og meðaldökkur húðlitur',
    '🧑🏻‍❤‍🧑🏼' => 'par: manneskja, manneskja, ljós húðlitur og meðalljós húðlitur',
    '🧑🏻‍❤‍🧑🏽' => 'par: manneskja, manneskja, ljós húðlitur og millihúðlitur',
    '🧑🏻‍❤‍🧑🏾' => 'par: manneskja, manneskja, ljós húðlitur og meðaldökkur húðlitur',
    '🧑🏻‍❤‍🧑🏿' => 'par: manneskja, manneskja, ljós húðlitur og dökkur húðlitur',
    '🧑🏼‍❤‍🧑🏻' => 'par: manneskja, manneskja, meðalljós húðlitur og ljós húðlitur',
    '🧑🏼‍❤‍🧑🏽' => 'par: manneskja, manneskja, meðalljós húðlitur og millihúðlitur',
    '🧑🏼‍❤‍🧑🏾' => 'par: manneskja, manneskja, meðalljós húðlitur og meðaldökkur húðlitur',
    '🧑🏼‍❤‍🧑🏿' => 'par: manneskja, manneskja, meðalljós húðlitur og dökkur húðlitur',
    '🧑🏽‍❤‍🧑🏻' => 'par: manneskja, manneskja, millihúðlitur og ljós húðlitur',
    '🧑🏽‍❤‍🧑🏼' => 'par: manneskja, manneskja, millihúðlitur og meðalljós húðlitur',
    '🧑🏽‍❤‍🧑🏾' => 'par: manneskja, manneskja, millihúðlitur og meðaldökkur húðlitur',
    '🧑🏽‍❤‍🧑🏿' => 'par: manneskja, manneskja, millihúðlitur og dökkur húðlitur',
    '🧑🏾‍❤‍🧑🏻' => 'par: manneskja, manneskja, meðaldökkur húðlitur og ljós húðlitur',
    '🧑🏾‍❤‍🧑🏼' => 'par: manneskja, manneskja, meðaldökkur húðlitur og meðalljós húðlitur',
    '🧑🏾‍❤‍🧑🏽' => 'par: manneskja, manneskja, meðaldökkur húðlitur og millihúðlitur',
    '🧑🏾‍❤‍🧑🏿' => 'par: manneskja, manneskja, meðaldökkur húðlitur og dökkur húðlitur',
    '🧑🏿‍❤‍🧑🏻' => 'par: manneskja, manneskja, dökkur húðlitur og ljós húðlitur',
    '🧑🏿‍❤‍🧑🏼' => 'par: manneskja, manneskja, dökkur húðlitur og meðalljós húðlitur',
    '🧑🏿‍❤‍🧑🏽' => 'par: manneskja, manneskja, dökkur húðlitur og millihúðlitur',
    '🧑🏿‍❤‍🧑🏾' => 'par: manneskja, manneskja, dökkur húðlitur og meðaldökkur húðlitur',
    '🧑🏻‍🐰‍🧑🏼' => 'kanínueyru: ljós húðlitur og meðalljós húðlitur',
    '🧑🏻‍🐰‍🧑🏽' => 'kanínueyru: ljós húðlitur og millihúðlitur',
    '🧑🏻‍🐰‍🧑🏾' => 'kanínueyru: ljós húðlitur og meðaldökkur húðlitur',
    '🧑🏻‍🐰‍🧑🏿' => 'kanínueyru: ljós húðlitur og dökkur húðlitur',
    '🧑🏼‍🐰‍🧑🏻' => 'kanínueyru: meðalljós húðlitur og ljós húðlitur',
    '🧑🏼‍🐰‍🧑🏽' => 'kanínueyru: meðalljós húðlitur og millihúðlitur',
    '🧑🏼‍🐰‍🧑🏾' => 'kanínueyru: meðalljós húðlitur og meðaldökkur húðlitur',
    '🧑🏼‍🐰‍🧑🏿' => 'kanínueyru: meðalljós húðlitur og dökkur húðlitur',
    '🧑🏽‍🐰‍🧑🏻' => 'kanínueyru: millihúðlitur og ljós húðlitur',
    '🧑🏽‍🐰‍🧑🏼' => 'kanínueyru: millihúðlitur og meðalljós húðlitur',
    '🧑🏽‍🐰‍🧑🏾' => 'kanínueyru: millihúðlitur og meðaldökkur húðlitur',
    '🧑🏽‍🐰‍🧑🏿' => 'kanínueyru: millihúðlitur og dökkur húðlitur',
    '🧑🏾‍🐰‍🧑🏻' => 'kanínueyru: meðaldökkur húðlitur og ljós húðlitur',
    '🧑🏾‍🐰‍🧑🏼' => 'kanínueyru: meðaldökkur húðlitur og meðalljós húðlitur',
    '🧑🏾‍🐰‍🧑🏽' => 'kanínueyru: meðaldökkur húðlitur og millihúðlitur',
    '🧑🏾‍🐰‍🧑🏿' => 'kanínueyru: meðaldökkur húðlitur og dökkur húðlitur',
    '🧑🏿‍🐰‍🧑🏻' => 'kanínueyru: dökkur húðlitur og ljós húðlitur',
    '🧑🏿‍🐰‍🧑🏼' => 'kanínueyru: dökkur húðlitur og meðalljós húðlitur',
    '🧑🏿‍🐰‍🧑🏽' => 'kanínueyru: dökkur húðlitur og millihúðlitur',
    '🧑🏿‍🐰‍🧑🏾' => 'kanínueyru: dökkur húðlitur og meðaldökkur húðlitur',
    '👨🏻‍🫯‍👨🏼' => 'menn í glímu: ljós húðlitur og meðalljós húðlitur',
    '👨🏻‍🫯‍👨🏽' => 'menn í glímu: ljós húðlitur og millihúðlitur',
    '👨🏻‍🫯‍👨🏾' => 'menn í glímu: ljós húðlitur og meðaldökkur húðlitur',
    '👨🏻‍🫯‍👨🏿' => 'menn í glímu: ljós húðlitur og dökkur húðlitur',
    '👨🏼‍🫯‍👨🏻' => 'menn í glímu: meðalljós húðlitur og ljós húðlitur',
    '👨🏼‍🫯‍👨🏽' => 'menn í glímu: meðalljós húðlitur og millihúðlitur',
    '👨🏼‍🫯‍👨🏾' => 'menn í glímu: meðalljós húðlitur og meðaldökkur húðlitur',
    '👨🏼‍🫯‍👨🏿' => 'menn í glímu: meðalljós húðlitur og dökkur húðlitur',
    '👨🏽‍🫯‍👨🏻' => 'menn í glímu: millihúðlitur og ljós húðlitur',
    '👨🏽‍🫯‍👨🏼' => 'menn í glímu: millihúðlitur og meðalljós húðlitur',
    '👨🏽‍🫯‍👨🏾' => 'menn í glímu: millihúðlitur og meðaldökkur húðlitur',
    '👨🏽‍🫯‍👨🏿' => 'menn í glímu: millihúðlitur og dökkur húðlitur',
    '👨🏾‍🫯‍👨🏻' => 'menn í glímu: meðaldökkur húðlitur og ljós húðlitur',
    '👨🏾‍🫯‍👨🏼' => 'menn í glímu: meðaldökkur húðlitur og meðalljós húðlitur',
    '👨🏾‍🫯‍👨🏽' => 'menn í glímu: meðaldökkur húðlitur og millihúðlitur',
    '👨🏾‍🫯‍👨🏿' => 'menn í glímu: meðaldökkur húðlitur og dökkur húðlitur',
    '👨🏿‍🫯‍👨🏻' => 'menn í glímu: dökkur húðlitur og ljós húðlitur',
    '👨🏿‍🫯‍👨🏼' => 'menn í glímu: dökkur húðlitur og meðalljós húðlitur',
    '👨🏿‍🫯‍👨🏽' => 'menn í glímu: dökkur húðlitur og millihúðlitur',
    '👨🏿‍🫯‍👨🏾' => 'menn í glímu: dökkur húðlitur og meðaldökkur húðlitur',
    '👨🏻‍❤‍👨🏻' => 'par: karl, karl og ljós húðlitur',
    '👨🏻‍❤‍👨🏼' => 'par: karl, karl, ljós húðlitur og meðalljós húðlitur',
    '👨🏻‍❤‍👨🏽' => 'par: karl, karl, ljós húðlitur og millihúðlitur',
    '👨🏻‍❤‍👨🏾' => 'par: karl, karl, ljós húðlitur og meðaldökkur húðlitur',
    '👨🏻‍❤‍👨🏿' => 'par: karl, karl, ljós húðlitur og dökkur húðlitur',
    '👨🏼‍❤‍👨🏻' => 'par: karl, karl, meðalljós húðlitur og ljós húðlitur',
    '👨🏼‍❤‍👨🏼' => 'par: karl, karl og meðalljós húðlitur',
    '👨🏼‍❤‍👨🏽' => 'par: karl, karl, meðalljós húðlitur og millihúðlitur',
    '👨🏼‍❤‍👨🏾' => 'par: karl, karl, meðalljós húðlitur og meðaldökkur húðlitur',
    '👨🏼‍❤‍👨🏿' => 'par: karl, karl, meðalljós húðlitur og dökkur húðlitur',
    '👨🏽‍❤‍👨🏻' => 'par: karl, karl, millihúðlitur og ljós húðlitur',
    '👨🏽‍❤‍👨🏼' => 'par: karl, karl, millihúðlitur og meðalljós húðlitur',
    '👨🏽‍❤‍👨🏽' => 'par: karl, karl og millihúðlitur',
    '👨🏽‍❤‍👨🏾' => 'par: karl, karl, millihúðlitur og meðaldökkur húðlitur',
    '👨🏽‍❤‍👨🏿' => 'par: karl, karl, millihúðlitur og dökkur húðlitur',
    '👨🏾‍❤‍👨🏻' => 'par: karl, karl, meðaldökkur húðlitur og ljós húðlitur',
    '👨🏾‍❤‍👨🏼' => 'par: karl, karl, meðaldökkur húðlitur og meðalljós húðlitur',
    '👨🏾‍❤‍👨🏽' => 'par: karl, karl, meðaldökkur húðlitur og millihúðlitur',
    '👨🏾‍❤‍👨🏾' => 'par: karl, karl og meðaldökkur húðlitur',
    '👨🏾‍❤‍👨🏿' => 'par: karl, karl, meðaldökkur húðlitur og dökkur húðlitur',
    '👨🏿‍❤‍👨🏻' => 'par: karl, karl, dökkur húðlitur og ljós húðlitur',
    '👨🏿‍❤‍👨🏼' => 'par: karl, karl, dökkur húðlitur og meðalljós húðlitur',
    '👨🏿‍❤‍👨🏽' => 'par: karl, karl, dökkur húðlitur og millihúðlitur',
    '👨🏿‍❤‍👨🏾' => 'par: karl, karl, dökkur húðlitur og meðaldökkur húðlitur',
    '👨🏿‍❤‍👨🏿' => 'par: karl, karl og dökkur húðlitur',
    '👨🏻‍🐰‍👨🏼' => 'menn með kanínueyru: ljós húðlitur og meðalljós húðlitur',
    '👨🏻‍🐰‍👨🏽' => 'menn með kanínueyru: ljós húðlitur og millihúðlitur',
    '👨🏻‍🐰‍👨🏾' => 'menn með kanínueyru: ljós húðlitur og meðaldökkur húðlitur',
    '👨🏻‍🐰‍👨🏿' => 'menn með kanínueyru: ljós húðlitur og dökkur húðlitur',
    '👨🏼‍🐰‍👨🏻' => 'menn með kanínueyru: meðalljós húðlitur og ljós húðlitur',
    '👨🏼‍🐰‍👨🏽' => 'menn með kanínueyru: meðalljós húðlitur og millihúðlitur',
    '👨🏼‍🐰‍👨🏾' => 'menn með kanínueyru: meðalljós húðlitur og meðaldökkur húðlitur',
    '👨🏼‍🐰‍👨🏿' => 'menn með kanínueyru: meðalljós húðlitur og dökkur húðlitur',
    '👨🏽‍🐰‍👨🏻' => 'menn með kanínueyru: millihúðlitur og ljós húðlitur',
    '👨🏽‍🐰‍👨🏼' => 'menn með kanínueyru: millihúðlitur og meðalljós húðlitur',
    '👨🏽‍🐰‍👨🏾' => 'menn með kanínueyru: millihúðlitur og meðaldökkur húðlitur',
    '👨🏽‍🐰‍👨🏿' => 'menn með kanínueyru: millihúðlitur og dökkur húðlitur',
    '👨🏾‍🐰‍👨🏻' => 'menn með kanínueyru: meðaldökkur húðlitur og ljós húðlitur',
    '👨🏾‍🐰‍👨🏼' => 'menn með kanínueyru: meðaldökkur húðlitur og meðalljós húðlitur',
    '👨🏾‍🐰‍👨🏽' => 'menn með kanínueyru: meðaldökkur húðlitur og millihúðlitur',
    '👨🏾‍🐰‍👨🏿' => 'menn með kanínueyru: meðaldökkur húðlitur og dökkur húðlitur',
    '👨🏿‍🐰‍👨🏻' => 'menn með kanínueyru: dökkur húðlitur og ljós húðlitur',
    '👨🏿‍🐰‍👨🏼' => 'menn með kanínueyru: dökkur húðlitur og meðalljós húðlitur',
    '👨🏿‍🐰‍👨🏽' => 'menn með kanínueyru: dökkur húðlitur og millihúðlitur',
    '👨🏿‍🐰‍👨🏾' => 'menn með kanínueyru: dökkur húðlitur og meðaldökkur húðlitur',
    '👩🏻‍🫯‍👩🏼' => 'konur í glímu: ljós húðlitur og meðalljós húðlitur',
    '👩🏻‍🫯‍👩🏽' => 'konur í glímu: ljós húðlitur og millihúðlitur',
    '👩🏻‍🫯‍👩🏾' => 'konur í glímu: ljós húðlitur og meðaldökkur húðlitur',
    '👩🏻‍🫯‍👩🏿' => 'konur í glímu: ljós húðlitur og dökkur húðlitur',
    '👩🏼‍🫯‍👩🏻' => 'konur í glímu: meðalljós húðlitur og ljós húðlitur',
    '👩🏼‍🫯‍👩🏽' => 'konur í glímu: meðalljós húðlitur og millihúðlitur',
    '👩🏼‍🫯‍👩🏾' => 'konur í glímu: meðalljós húðlitur og meðaldökkur húðlitur',
    '👩🏼‍🫯‍👩🏿' => 'konur í glímu: meðalljós húðlitur og dökkur húðlitur',
    '👩🏽‍🫯‍👩🏻' => 'konur í glímu: millihúðlitur og ljós húðlitur',
    '👩🏽‍🫯‍👩🏼' => 'konur í glímu: millihúðlitur og meðalljós húðlitur',
    '👩🏽‍🫯‍👩🏾' => 'konur í glímu: millihúðlitur og meðaldökkur húðlitur',
    '👩🏽‍🫯‍👩🏿' => 'konur í glímu: millihúðlitur og dökkur húðlitur',
    '👩🏾‍🫯‍👩🏻' => 'konur í glímu: meðaldökkur húðlitur og ljós húðlitur',
    '👩🏾‍🫯‍👩🏼' => 'konur í glímu: meðaldökkur húðlitur og meðalljós húðlitur',
    '👩🏾‍🫯‍👩🏽' => 'konur í glímu: meðaldökkur húðlitur og millihúðlitur',
    '👩🏾‍🫯‍👩🏿' => 'konur í glímu: meðaldökkur húðlitur og dökkur húðlitur',
    '👩🏿‍🫯‍👩🏻' => 'konur í glímu: dökkur húðlitur og ljós húðlitur',
    '👩🏿‍🫯‍👩🏼' => 'konur í glímu: dökkur húðlitur og meðalljós húðlitur',
    '👩🏿‍🫯‍👩🏽' => 'konur í glímu: dökkur húðlitur og millihúðlitur',
    '👩🏿‍🫯‍👩🏾' => 'konur í glímu: dökkur húðlitur og meðaldökkur húðlitur',
    '👩🏻‍❤‍👨🏻' => 'par: kona, karl og ljós húðlitur',
    '👩🏻‍❤‍👨🏼' => 'par: kona, karl, ljós húðlitur og meðalljós húðlitur',
    '👩🏻‍❤‍👨🏽' => 'par: kona, karl, ljós húðlitur og millihúðlitur',
    '👩🏻‍❤‍👨🏾' => 'par: kona, karl, ljós húðlitur og meðaldökkur húðlitur',
    '👩🏻‍❤‍👨🏿' => 'par: kona, karl, ljós húðlitur og dökkur húðlitur',
    '👩🏼‍❤‍👨🏻' => 'par: kona, karl, meðalljós húðlitur og ljós húðlitur',
    '👩🏼‍❤‍👨🏼' => 'par: kona, karl og meðalljós húðlitur',
    '👩🏼‍❤‍👨🏽' => 'par: kona, karl, meðalljós húðlitur og millihúðlitur',
    '👩🏼‍❤‍👨🏾' => 'par: kona, karl, meðalljós húðlitur og meðaldökkur húðlitur',
    '👩🏼‍❤‍👨🏿' => 'par: kona, karl, meðalljós húðlitur og dökkur húðlitur',
    '👩🏽‍❤‍👨🏻' => 'par: kona, karl, millihúðlitur og ljós húðlitur',
    '👩🏽‍❤‍👨🏼' => 'par: kona, karl, millihúðlitur og meðalljós húðlitur',
    '👩🏽‍❤‍👨🏽' => 'par: kona, karl og millihúðlitur',
    '👩🏽‍❤‍👨🏾' => 'par: kona, karl, millihúðlitur og meðaldökkur húðlitur',
    '👩🏽‍❤‍👨🏿' => 'par: kona, karl, millihúðlitur og dökkur húðlitur',
    '👩🏾‍❤‍👨🏻' => 'par: kona, karl, meðaldökkur húðlitur og ljós húðlitur',
    '👩🏾‍❤‍👨🏼' => 'par: kona, karl, meðaldökkur húðlitur og meðalljós húðlitur',
    '👩🏾‍❤‍👨🏽' => 'par: kona, karl, meðaldökkur húðlitur og millihúðlitur',
    '👩🏾‍❤‍👨🏾' => 'par: kona, karl og meðaldökkur húðlitur',
    '👩🏾‍❤‍👨🏿' => 'par: kona, karl, meðaldökkur húðlitur og dökkur húðlitur',
    '👩🏿‍❤‍👨🏻' => 'par: kona, karl, dökkur húðlitur og ljós húðlitur',
    '👩🏿‍❤‍👨🏼' => 'par: kona, karl, dökkur húðlitur og meðalljós húðlitur',
    '👩🏿‍❤‍👨🏽' => 'par: kona, karl, dökkur húðlitur og millihúðlitur',
    '👩🏿‍❤‍👨🏾' => 'par: kona, karl, dökkur húðlitur og meðaldökkur húðlitur',
    '👩🏿‍❤‍👨🏿' => 'par: kona, karl og dökkur húðlitur',
    '👩🏻‍❤‍👩🏻' => 'par: kona, kona og ljós húðlitur',
    '👩🏻‍❤‍👩🏼' => 'par: kona, kona, ljós húðlitur og meðalljós húðlitur',
    '👩🏻‍❤‍👩🏽' => 'par: kona, kona, ljós húðlitur og millihúðlitur',
    '👩🏻‍❤‍👩🏾' => 'par: kona, kona, ljós húðlitur og meðaldökkur húðlitur',
    '👩🏻‍❤‍👩🏿' => 'par: kona, kona, ljós húðlitur og dökkur húðlitur',
    '👩🏼‍❤‍👩🏻' => 'par: kona, kona, meðalljós húðlitur og ljós húðlitur',
    '👩🏼‍❤‍👩🏼' => 'par: kona, kona og meðalljós húðlitur',
    '👩🏼‍❤‍👩🏽' => 'par: kona, kona, meðalljós húðlitur og millihúðlitur',
    '👩🏼‍❤‍👩🏾' => 'par: kona, kona, meðalljós húðlitur og meðaldökkur húðlitur',
    '👩🏼‍❤‍👩🏿' => 'par: kona, kona, meðalljós húðlitur og dökkur húðlitur',
    '👩🏽‍❤‍👩🏻' => 'par: kona, kona, millihúðlitur og ljós húðlitur',
    '👩🏽‍❤‍👩🏼' => 'par: kona, kona, millihúðlitur og meðalljós húðlitur',
    '👩🏽‍❤‍👩🏽' => 'par: kona, kona og millihúðlitur',
    '👩🏽‍❤‍👩🏾' => 'par: kona, kona, millihúðlitur og meðaldökkur húðlitur',
    '👩🏽‍❤‍👩🏿' => 'par: kona, kona, millihúðlitur og dökkur húðlitur',
    '👩🏾‍❤‍👩🏻' => 'par: kona, kona, meðaldökkur húðlitur og ljós húðlitur',
    '👩🏾‍❤‍👩🏼' => 'par: kona, kona, meðaldökkur húðlitur og meðalljós húðlitur',
    '👩🏾‍❤‍👩🏽' => 'par: kona, kona, meðaldökkur húðlitur og millihúðlitur',
    '👩🏾‍❤‍👩🏾' => 'par: kona, kona og meðaldökkur húðlitur',
    '👩🏾‍❤‍👩🏿' => 'par: kona, kona, meðaldökkur húðlitur og dökkur húðlitur',
    '👩🏿‍❤‍👩🏻' => 'par: kona, kona, dökkur húðlitur og ljós húðlitur',
    '👩🏿‍❤‍👩🏼' => 'par: kona, kona, dökkur húðlitur og meðalljós húðlitur',
    '👩🏿‍❤‍👩🏽' => 'par: kona, kona, dökkur húðlitur og millihúðlitur',
    '👩🏿‍❤‍👩🏾' => 'par: kona, kona, dökkur húðlitur og meðaldökkur húðlitur',
    '👩🏿‍❤‍👩🏿' => 'par: kona, kona og dökkur húðlitur',
    '👩🏻‍🐰‍👩🏼' => 'konur með kanínueyru: ljós húðlitur og meðalljós húðlitur',
    '👩🏻‍🐰‍👩🏽' => 'konur með kanínueyru: ljós húðlitur og millihúðlitur',
    '👩🏻‍🐰‍👩🏾' => 'konur með kanínueyru: ljós húðlitur og meðaldökkur húðlitur',
    '👩🏻‍🐰‍👩🏿' => 'konur með kanínueyru: ljós húðlitur og dökkur húðlitur',
    '👩🏼‍🐰‍👩🏻' => 'konur með kanínueyru: meðalljós húðlitur og ljós húðlitur',
    '👩🏼‍🐰‍👩🏽' => 'konur með kanínueyru: meðalljós húðlitur og millihúðlitur',
    '👩🏼‍🐰‍👩🏾' => 'konur með kanínueyru: meðalljós húðlitur og meðaldökkur húðlitur',
    '👩🏼‍🐰‍👩🏿' => 'konur með kanínueyru: meðalljós húðlitur og dökkur húðlitur',
    '👩🏽‍🐰‍👩🏻' => 'konur með kanínueyru: millihúðlitur og ljós húðlitur',
    '👩🏽‍🐰‍👩🏼' => 'konur með kanínueyru: millihúðlitur og meðalljós húðlitur',
    '👩🏽‍🐰‍👩🏾' => 'konur með kanínueyru: millihúðlitur og meðaldökkur húðlitur',
    '👩🏽‍🐰‍👩🏿' => 'konur með kanínueyru: millihúðlitur og dökkur húðlitur',
    '👩🏾‍🐰‍👩🏻' => 'konur með kanínueyru: meðaldökkur húðlitur og ljós húðlitur',
    '👩🏾‍🐰‍👩🏼' => 'konur með kanínueyru: meðaldökkur húðlitur og meðalljós húðlitur',
    '👩🏾‍🐰‍👩🏽' => 'konur með kanínueyru: meðaldökkur húðlitur og millihúðlitur',
    '👩🏾‍🐰‍👩🏿' => 'konur með kanínueyru: meðaldökkur húðlitur og dökkur húðlitur',
    '👩🏿‍🐰‍👩🏻' => 'konur með kanínueyru: dökkur húðlitur og ljós húðlitur',
    '👩🏿‍🐰‍👩🏼' => 'konur með kanínueyru: dökkur húðlitur og meðalljós húðlitur',
    '👩🏿‍🐰‍👩🏽' => 'konur með kanínueyru: dökkur húðlitur og millihúðlitur',
    '👩🏿‍🐰‍👩🏾' => 'konur með kanínueyru: dökkur húðlitur og meðaldökkur húðlitur',
    '🧑🏻‍🤝‍🧑🏻' => 'fólk að leiðast: ljós húðlitur',
    '🧑🏻‍🤝‍🧑🏼' => 'fólk að leiðast: ljós húðlitur og meðalljós húðlitur',
    '🧑🏻‍🤝‍🧑🏽' => 'fólk að leiðast: ljós húðlitur og millihúðlitur',
    '🧑🏻‍🤝‍🧑🏾' => 'fólk að leiðast: ljós húðlitur og meðaldökkur húðlitur',
    '🧑🏻‍🤝‍🧑🏿' => 'fólk að leiðast: ljós húðlitur og dökkur húðlitur',
    '🧑🏼‍🤝‍🧑🏻' => 'fólk að leiðast: meðalljós húðlitur og ljós húðlitur',
    '🧑🏼‍🤝‍🧑🏼' => 'fólk að leiðast: meðalljós húðlitur',
    '🧑🏼‍🤝‍🧑🏽' => 'fólk að leiðast: meðalljós húðlitur og millihúðlitur',
    '🧑🏼‍🤝‍🧑🏾' => 'fólk að leiðast: meðalljós húðlitur og meðaldökkur húðlitur',
    '🧑🏼‍🤝‍🧑🏿' => 'fólk að leiðast: meðalljós húðlitur og dökkur húðlitur',
    '🧑🏽‍🤝‍🧑🏻' => 'fólk að leiðast: millihúðlitur og ljós húðlitur',
    '🧑🏽‍🤝‍🧑🏼' => 'fólk að leiðast: millihúðlitur og meðalljós húðlitur',
    '🧑🏽‍🤝‍🧑🏽' => 'fólk að leiðast: millihúðlitur',
    '🧑🏽‍🤝‍🧑🏾' => 'fólk að leiðast: millihúðlitur og meðaldökkur húðlitur',
    '🧑🏽‍🤝‍🧑🏿' => 'fólk að leiðast: millihúðlitur og dökkur húðlitur',
    '🧑🏾‍🤝‍🧑🏻' => 'fólk að leiðast: meðaldökkur húðlitur og ljós húðlitur',
    '🧑🏾‍🤝‍🧑🏼' => 'fólk að leiðast: meðaldökkur húðlitur og meðalljós húðlitur',
    '🧑🏾‍🤝‍🧑🏽' => 'fólk að leiðast: meðaldökkur húðlitur og millihúðlitur',
    '🧑🏾‍🤝‍🧑🏾' => 'fólk að leiðast: meðaldökkur húðlitur',
    '🧑🏾‍🤝‍🧑🏿' => 'fólk að leiðast: meðaldökkur húðlitur og dökkur húðlitur',
    '🧑🏿‍🤝‍🧑🏻' => 'fólk að leiðast: dökkur húðlitur og ljós húðlitur',
    '🧑🏿‍🤝‍🧑🏼' => 'fólk að leiðast: dökkur húðlitur og meðalljós húðlitur',
    '🧑🏿‍🤝‍🧑🏽' => 'fólk að leiðast: dökkur húðlitur og millihúðlitur',
    '🧑🏿‍🤝‍🧑🏾' => 'fólk að leiðast: dökkur húðlitur og meðaldökkur húðlitur',
    '🧑🏿‍🤝‍🧑🏿' => 'fólk að leiðast: dökkur húðlitur',
    '👩🏻‍🤝‍👩🏼' => 'konur sem leiðast: ljós húðlitur og meðalljós húðlitur',
    '👩🏻‍🤝‍👩🏽' => 'konur sem leiðast: ljós húðlitur og millihúðlitur',
    '👩🏻‍🤝‍👩🏾' => 'konur sem leiðast: ljós húðlitur og meðaldökkur húðlitur',
    '👩🏻‍🤝‍👩🏿' => 'konur sem leiðast: ljós húðlitur og dökkur húðlitur',
    '👩🏼‍🤝‍👩🏻' => 'konur sem leiðast: meðalljós húðlitur og ljós húðlitur',
    '👩🏼‍🤝‍👩🏽' => 'konur sem leiðast: meðalljós húðlitur og millihúðlitur',
    '👩🏼‍🤝‍👩🏾' => 'konur sem leiðast: meðalljós húðlitur og meðaldökkur húðlitur',
    '👩🏼‍🤝‍👩🏿' => 'konur sem leiðast: meðalljós húðlitur og dökkur húðlitur',
    '👩🏽‍🤝‍👩🏻' => 'konur sem leiðast: millihúðlitur og ljós húðlitur',
    '👩🏽‍🤝‍👩🏼' => 'konur sem leiðast: millihúðlitur og meðalljós húðlitur',
    '👩🏽‍🤝‍👩🏾' => 'konur sem leiðast: millihúðlitur og meðaldökkur húðlitur',
    '👩🏽‍🤝‍👩🏿' => 'konur sem leiðast: millihúðlitur og dökkur húðlitur',
    '👩🏾‍🤝‍👩🏻' => 'konur sem leiðast: meðaldökkur húðlitur og ljós húðlitur',
    '👩🏾‍🤝‍👩🏼' => 'konur sem leiðast: meðaldökkur húðlitur og meðalljós húðlitur',
    '👩🏾‍🤝‍👩🏽' => 'konur sem leiðast: meðaldökkur húðlitur og millihúðlitur',
    '👩🏾‍🤝‍👩🏿' => 'konur sem leiðast: meðaldökkur húðlitur og dökkur húðlitur',
    '👩🏿‍🤝‍👩🏻' => 'konur sem leiðast: dökkur húðlitur og ljós húðlitur',
    '👩🏿‍🤝‍👩🏼' => 'konur sem leiðast: dökkur húðlitur og meðalljós húðlitur',
    '👩🏿‍🤝‍👩🏽' => 'konur sem leiðast: dökkur húðlitur og millihúðlitur',
    '👩🏿‍🤝‍👩🏾' => 'konur sem leiðast: dökkur húðlitur og meðaldökkur húðlitur',
    '👩🏻‍🤝‍👨🏼' => 'karl og kona sem leiðast: ljós húðlitur og meðalljós húðlitur',
    '👩🏻‍🤝‍👨🏽' => 'karl og kona sem leiðast: ljós húðlitur og millihúðlitur',
    '👩🏻‍🤝‍👨🏾' => 'karl og kona sem leiðast: ljós húðlitur og meðaldökkur húðlitur',
    '👩🏻‍🤝‍👨🏿' => 'karl og kona sem leiðast: ljós húðlitur og dökkur húðlitur',
    '👩🏼‍🤝‍👨🏻' => 'karl og kona sem leiðast: meðalljós húðlitur og ljós húðlitur',
    '👩🏼‍🤝‍👨🏽' => 'karl og kona sem leiðast: meðalljós húðlitur og millihúðlitur',
    '👩🏼‍🤝‍👨🏾' => 'karl og kona sem leiðast: meðalljós húðlitur og meðaldökkur húðlitur',
    '👩🏼‍🤝‍👨🏿' => 'karl og kona sem leiðast: meðalljós húðlitur og dökkur húðlitur',
    '👩🏽‍🤝‍👨🏻' => 'karl og kona sem leiðast: millihúðlitur og ljós húðlitur',
    '👩🏽‍🤝‍👨🏼' => 'karl og kona sem leiðast: millihúðlitur og meðalljós húðlitur',
    '👩🏽‍🤝‍👨🏾' => 'karl og kona sem leiðast: millihúðlitur og meðaldökkur húðlitur',
    '👩🏽‍🤝‍👨🏿' => 'karl og kona sem leiðast: millihúðlitur og dökkur húðlitur',
    '👩🏾‍🤝‍👨🏻' => 'karl og kona sem leiðast: meðaldökkur húðlitur og ljós húðlitur',
    '👩🏾‍🤝‍👨🏼' => 'karl og kona sem leiðast: meðaldökkur húðlitur og meðalljós húðlitur',
    '👩🏾‍🤝‍👨🏽' => 'karl og kona sem leiðast: meðaldökkur húðlitur og millihúðlitur',
    '👩🏾‍🤝‍👨🏿' => 'karl og kona sem leiðast: meðaldökkur húðlitur og dökkur húðlitur',
    '👩🏿‍🤝‍👨🏻' => 'karl og kona sem leiðast: dökkur húðlitur og ljós húðlitur',
    '👩🏿‍🤝‍👨🏼' => 'karl og kona sem leiðast: dökkur húðlitur og meðalljós húðlitur',
    '👩🏿‍🤝‍👨🏽' => 'karl og kona sem leiðast: dökkur húðlitur og millihúðlitur',
    '👩🏿‍🤝‍👨🏾' => 'karl og kona sem leiðast: dökkur húðlitur og meðaldökkur húðlitur',
    '👨🏻‍🤝‍👨🏼' => 'karlar sem leiðast: ljós húðlitur og meðalljós húðlitur',
    '👨🏻‍🤝‍👨🏽' => 'karlar sem leiðast: ljós húðlitur og millihúðlitur',
    '👨🏻‍🤝‍👨🏾' => 'karlar sem leiðast: ljós húðlitur og meðaldökkur húðlitur',
    '👨🏻‍🤝‍👨🏿' => 'karlar sem leiðast: ljós húðlitur og dökkur húðlitur',
    '👨🏼‍🤝‍👨🏻' => 'karlar sem leiðast: meðalljós húðlitur og ljós húðlitur',
    '👨🏼‍🤝‍👨🏽' => 'karlar sem leiðast: meðalljós húðlitur og millihúðlitur',
    '👨🏼‍🤝‍👨🏾' => 'karlar sem leiðast: meðalljós húðlitur og meðaldökkur húðlitur',
    '👨🏼‍🤝‍👨🏿' => 'karlar sem leiðast: meðalljós húðlitur og dökkur húðlitur',
    '👨🏽‍🤝‍👨🏻' => 'karlar sem leiðast: millihúðlitur og ljós húðlitur',
    '👨🏽‍🤝‍👨🏼' => 'karlar sem leiðast: millihúðlitur og meðalljós húðlitur',
    '👨🏽‍🤝‍👨🏾' => 'karlar sem leiðast: millihúðlitur og meðaldökkur húðlitur',
    '👨🏽‍🤝‍👨🏿' => 'karlar sem leiðast: millihúðlitur og dökkur húðlitur',
    '👨🏾‍🤝‍👨🏻' => 'karlar sem leiðast: meðaldökkur húðlitur og ljós húðlitur',
    '👨🏾‍🤝‍👨🏼' => 'karlar sem leiðast: meðaldökkur húðlitur og meðalljós húðlitur',
    '👨🏾‍🤝‍👨🏽' => 'karlar sem leiðast: meðaldökkur húðlitur og millihúðlitur',
    '👨🏾‍🤝‍👨🏿' => 'karlar sem leiðast: meðaldökkur húðlitur og dökkur húðlitur',
    '👨🏿‍🤝‍👨🏻' => 'karlar sem leiðast: dökkur húðlitur og ljós húðlitur',
    '👨🏿‍🤝‍👨🏼' => 'karlar sem leiðast: dökkur húðlitur og meðalljós húðlitur',
    '👨🏿‍🤝‍👨🏽' => 'karlar sem leiðast: dökkur húðlitur og millihúðlitur',
    '👨🏿‍🤝‍👨🏾' => 'karlar sem leiðast: dökkur húðlitur og meðaldökkur húðlitur',
    '👩‍❤‍💋‍👨' => 'koss: kona og karl',
    '👨‍❤‍💋‍👨' => 'koss: karl og karl',
    '👩‍❤‍💋‍👩' => 'koss: kona og kona',
    '👨‍👩‍👧‍👦' => 'fjölskylda: karl, kona, stúlka og drengur',
    '👨‍👩‍👦‍👦' => 'fjölskylda: karl, kona, drengur og drengur',
    '👨‍👩‍👧‍👧' => 'fjölskylda: karl, kona, stúlka og stúlka',
    '👨‍👨‍👧‍👦' => 'fjölskylda: karl, karl, stúlka og drengur',
    '👨‍👨‍👦‍👦' => 'fjölskylda: karl, karl, drengur og drengur',
    '👨‍👨‍👧‍👧' => 'fjölskylda: karl, karl, stúlka og stúlka',
    '👩‍👩‍👧‍👦' => 'fjölskylda: kona, kona, stúlka og drengur',
    '👩‍👩‍👦‍👦' => 'fjölskylda: kona, kona, drengur og drengur',
    '👩‍👩‍👧‍👧' => 'fjölskylda: kona, kona, stúlka og stúlka',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'fáni: England',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'fáni: Skotland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'fáni: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'fjölskylda: fullorðinn, fullorðinn, barn, barn',
    '🚶🏻‍♀‍➡' => 'gangandi kona: ljós húðlitur og snýr til hægri',
    '🚶🏼‍♀‍➡' => 'gangandi kona: meðalljós húðlitur og snýr til hægri',
    '🚶🏽‍♀‍➡' => 'gangandi kona: millihúðlitur og snýr til hægri',
    '🚶🏾‍♀‍➡' => 'gangandi kona: meðaldökkur húðlitur og snýr til hægri',
    '🚶🏿‍♀‍➡' => 'gangandi kona: dökkur húðlitur og snýr til hægri',
    '🚶🏻‍♂‍➡' => 'gangandi maður: ljós húðlitur og snýr til hægri',
    '🚶🏼‍♂‍➡' => 'gangandi maður: meðalljós húðlitur og snýr til hægri',
    '🚶🏽‍♂‍➡' => 'gangandi maður: millihúðlitur og snýr til hægri',
    '🚶🏾‍♂‍➡' => 'gangandi maður: meðaldökkur húðlitur og snýr til hægri',
    '🚶🏿‍♂‍➡' => 'gangandi maður: dökkur húðlitur og snýr til hægri',
    '🧎🏻‍♀‍➡' => 'krjúpandi kona: ljós húðlitur og snýr til hægri',
    '🧎🏼‍♀‍➡' => 'krjúpandi kona: meðalljós húðlitur og snýr til hægri',
    '🧎🏽‍♀‍➡' => 'krjúpandi kona: millihúðlitur og snýr til hægri',
    '🧎🏾‍♀‍➡' => 'krjúpandi kona: meðaldökkur húðlitur og snýr til hægri',
    '🧎🏿‍♀‍➡' => 'krjúpandi kona: dökkur húðlitur og snýr til hægri',
    '🧎🏻‍♂‍➡' => 'krjúpandi maður: ljós húðlitur og snýr til hægri',
    '🧎🏼‍♂‍➡' => 'krjúpandi maður: meðalljós húðlitur og snýr til hægri',
    '🧎🏽‍♂‍➡' => 'krjúpandi maður: millihúðlitur og snýr til hægri',
    '🧎🏾‍♂‍➡' => 'krjúpandi maður: meðaldökkur húðlitur og snýr til hægri',
    '🧎🏿‍♂‍➡' => 'krjúpandi maður: dökkur húðlitur og snýr til hægri',
    '🧑🏻‍🦯‍➡' => 'manneskja með blindrastaf: ljós húðlitur og snýr til hægri',
    '🧑🏼‍🦯‍➡' => 'manneskja með blindrastaf: meðalljós húðlitur og snýr til hægri',
    '🧑🏽‍🦯‍➡' => 'manneskja með blindrastaf: millihúðlitur og snýr til hægri',
    '🧑🏾‍🦯‍➡' => 'manneskja með blindrastaf: meðaldökkur húðlitur og snýr til hægri',
    '🧑🏿‍🦯‍➡' => 'manneskja með blindrastaf: dökkur húðlitur og snýr til hægri',
    '👨🏻‍🦯‍➡' => 'maður með blindrastaf: ljós húðlitur og snýr til hægri',
    '👨🏼‍🦯‍➡' => 'maður með blindrastaf: meðalljós húðlitur og snýr til hægri',
    '👨🏽‍🦯‍➡' => 'maður með blindrastaf: millihúðlitur og snýr til hægri',
    '👨🏾‍🦯‍➡' => 'maður með blindrastaf: meðaldökkur húðlitur og snýr til hægri',
    '👨🏿‍🦯‍➡' => 'maður með blindrastaf: dökkur húðlitur og snýr til hægri',
    '👩🏻‍🦯‍➡' => 'kona með blindrastaf: ljós húðlitur og snýr til hægri',
    '👩🏼‍🦯‍➡' => 'kona með blindrastaf: meðalljós húðlitur og snýr til hægri',
    '👩🏽‍🦯‍➡' => 'kona með blindrastaf: millihúðlitur og snýr til hægri',
    '👩🏾‍🦯‍➡' => 'kona með blindrastaf: meðaldökkur húðlitur og snýr til hægri',
    '👩🏿‍🦯‍➡' => 'kona með blindrastaf: dökkur húðlitur og snýr til hægri',
    '🧑🏻‍🦼‍➡' => 'manneskja í vélknúnum hjólastól: ljós húðlitur og snýr til hægri',
    '🧑🏼‍🦼‍➡' => 'manneskja í vélknúnum hjólastól: meðalljós húðlitur og snýr til hægri',
    '🧑🏽‍🦼‍➡' => 'manneskja í vélknúnum hjólastól: millihúðlitur og snýr til hægri',
    '🧑🏾‍🦼‍➡' => 'manneskja í vélknúnum hjólastól: meðaldökkur húðlitur og snýr til hægri',
    '🧑🏿‍🦼‍➡' => 'manneskja í vélknúnum hjólastól: dökkur húðlitur og snýr til hægri',
    '👨🏻‍🦼‍➡' => 'maður í vélknúnum hjólastól: ljós húðlitur og snýr til hægri',
    '👨🏼‍🦼‍➡' => 'maður í vélknúnum hjólastól: meðalljós húðlitur og snýr til hægri',
    '👨🏽‍🦼‍➡' => 'maður í vélknúnum hjólastól: millihúðlitur og snýr til hægri',
    '👨🏾‍🦼‍➡' => 'maður í vélknúnum hjólastól: meðaldökkur húðlitur og snýr til hægri',
    '👨🏿‍🦼‍➡' => 'maður í vélknúnum hjólastól: dökkur húðlitur og snýr til hægri',
    '👩🏻‍🦼‍➡' => 'kona í vélknúnum hjólastól: ljós húðlitur og snýr til hægri',
    '👩🏼‍🦼‍➡' => 'kona í vélknúnum hjólastól: meðalljós húðlitur og snýr til hægri',
    '👩🏽‍🦼‍➡' => 'kona í vélknúnum hjólastól: millihúðlitur og snýr til hægri',
    '👩🏾‍🦼‍➡' => 'kona í vélknúnum hjólastól: meðaldökkur húðlitur og snýr til hægri',
    '👩🏿‍🦼‍➡' => 'kona í vélknúnum hjólastól: dökkur húðlitur og snýr til hægri',
    '🧑🏻‍🦽‍➡' => 'manneskja í hjólastól: ljós húðlitur og snýr til hægri',
    '🧑🏼‍🦽‍➡' => 'manneskja í hjólastól: meðalljós húðlitur og snýr til hægri',
    '🧑🏽‍🦽‍➡' => 'manneskja í hjólastól: millihúðlitur og snýr til hægri',
    '🧑🏾‍🦽‍➡' => 'manneskja í hjólastól: meðaldökkur húðlitur og snýr til hægri',
    '🧑🏿‍🦽‍➡' => 'manneskja í hjólastól: dökkur húðlitur og snýr til hægri',
    '👨🏻‍🦽‍➡' => 'maður í hjólastól: ljós húðlitur og snýr til hægri',
    '👨🏼‍🦽‍➡' => 'maður í hjólastól: meðalljós húðlitur og snýr til hægri',
    '👨🏽‍🦽‍➡' => 'maður í hjólastól: millihúðlitur og snýr til hægri',
    '👨🏾‍🦽‍➡' => 'maður í hjólastól: meðaldökkur húðlitur og snýr til hægri',
    '👨🏿‍🦽‍➡' => 'maður í hjólastól: dökkur húðlitur og snýr til hægri',
    '👩🏻‍🦽‍➡' => 'kona í hjólastól: ljós húðlitur og snýr til hægri',
    '👩🏼‍🦽‍➡' => 'kona í hjólastól: meðalljós húðlitur og snýr til hægri',
    '👩🏽‍🦽‍➡' => 'kona í hjólastól: millihúðlitur og snýr til hægri',
    '👩🏾‍🦽‍➡' => 'kona í hjólastól: meðaldökkur húðlitur og snýr til hægri',
    '👩🏿‍🦽‍➡' => 'kona í hjólastól: dökkur húðlitur og snýr til hægri',
    '🏃🏻‍♀‍➡' => 'hlaupandi kona: ljós húðlitur og snýr til hægri',
    '🏃🏼‍♀‍➡' => 'hlaupandi kona: meðalljós húðlitur og snýr til hægri',
    '🏃🏽‍♀‍➡' => 'hlaupandi kona: millihúðlitur og snýr til hægri',
    '🏃🏾‍♀‍➡' => 'hlaupandi kona: meðaldökkur húðlitur og snýr til hægri',
    '🏃🏿‍♀‍➡' => 'hlaupandi kona: dökkur húðlitur og snýr til hægri',
    '🏃🏻‍♂‍➡' => 'hlaupandi maður: ljós húðlitur og snýr til hægri',
    '🏃🏼‍♂‍➡' => 'hlaupandi maður: meðalljós húðlitur og snýr til hægri',
    '🏃🏽‍♂‍➡' => 'hlaupandi maður: millihúðlitur og snýr til hægri',
    '🏃🏾‍♂‍➡' => 'hlaupandi maður: meðaldökkur húðlitur og snýr til hægri',
    '🏃🏿‍♂‍➡' => 'hlaupandi maður: dökkur húðlitur og snýr til hægri',
    '🫱🏻‍🫲🏼' => 'handaband: ljós húðlitur og meðalljós húðlitur',
    '🫱🏻‍🫲🏽' => 'handaband: ljós húðlitur og millihúðlitur',
    '🫱🏻‍🫲🏾' => 'handaband: ljós húðlitur og meðaldökkur húðlitur',
    '🫱🏻‍🫲🏿' => 'handaband: ljós húðlitur og dökkur húðlitur',
    '🫱🏼‍🫲🏻' => 'handaband: meðalljós húðlitur og ljós húðlitur',
    '🫱🏼‍🫲🏽' => 'handaband: meðalljós húðlitur og millihúðlitur',
    '🫱🏼‍🫲🏾' => 'handaband: meðalljós húðlitur og meðaldökkur húðlitur',
    '🫱🏼‍🫲🏿' => 'handaband: meðalljós húðlitur og dökkur húðlitur',
    '🫱🏽‍🫲🏻' => 'handaband: millihúðlitur og ljós húðlitur',
    '🫱🏽‍🫲🏼' => 'handaband: millihúðlitur og meðalljós húðlitur',
    '🫱🏽‍🫲🏾' => 'handaband: millihúðlitur og meðaldökkur húðlitur',
    '🫱🏽‍🫲🏿' => 'handaband: millihúðlitur og dökkur húðlitur',
    '🫱🏾‍🫲🏻' => 'handaband: meðaldökkur húðlitur og ljós húðlitur',
    '🫱🏾‍🫲🏼' => 'handaband: meðaldökkur húðlitur og meðalljós húðlitur',
    '🫱🏾‍🫲🏽' => 'handaband: meðaldökkur húðlitur og millihúðlitur',
    '🫱🏾‍🫲🏿' => 'handaband: meðaldökkur húðlitur og dökkur húðlitur',
    '🫱🏿‍🫲🏻' => 'handaband: dökkur húðlitur og ljós húðlitur',
    '🫱🏿‍🫲🏼' => 'handaband: dökkur húðlitur og meðalljós húðlitur',
    '🫱🏿‍🫲🏽' => 'handaband: dökkur húðlitur og millihúðlitur',
    '🫱🏿‍🫲🏾' => 'handaband: dökkur húðlitur og meðaldökkur húðlitur',
    '🚶‍♀‍➡' => 'gangandi kona: snýr til hægri',
    '🚶‍♂‍➡' => 'gangandi maður: snýr til hægri',
    '🧎‍♀‍➡' => 'krjúpandi kona: snýr til hægri',
    '🧎‍♂‍➡' => 'krjúpandi maður: snýr til hægri',
    '🧑‍🦯‍➡' => 'manneskja með blindrastaf: snýr til hægri',
    '👨‍🦯‍➡' => 'maður með blindrastaf: snýr til hægri',
    '👩‍🦯‍➡' => 'kona með blindrastaf: snýr til hægri',
    '🧑‍🦼‍➡' => 'manneskja í vélknúnum hjólastól: snýr til hægri',
    '👨‍🦼‍➡' => 'maður í vélknúnum hjólastól: snýr til hægri',
    '👩‍🦼‍➡' => 'kona í vélknúnum hjólastól: snýr til hægri',
    '🧑‍🦽‍➡' => 'manneskja í hjólastól: snýr til hægri',
    '👨‍🦽‍➡' => 'maður í hjólastól: snýr til hægri',
    '👩‍🦽‍➡' => 'kona í hjólastól: snýr til hægri',
    '🏃‍♀‍➡' => 'hlaupandi kona: snýr til hægri',
    '🏃‍♂‍➡' => 'hlaupandi maður: snýr til hægri',
    '👩‍❤‍👨' => 'par: kona og karl',
    '👨‍❤‍👨' => 'par: karl og karl',
    '👩‍❤‍👩' => 'par: kona og kona',
    '👨‍👩‍👦' => 'fjölskylda: karl, kona og drengur',
    '👨‍👩‍👧' => 'fjölskylda: karl, kona og stúlka',
    '👨‍👨‍👦' => 'fjölskylda: karl, karl og drengur',
    '👨‍👨‍👧' => 'fjölskylda: karl, karl og stúlka',
    '👩‍👩‍👦' => 'fjölskylda: kona, kona og drengur',
    '👩‍👩‍👧' => 'fjölskylda: kona, kona og stúlka',
    '👨‍👦‍👦' => 'fjölskylda: karl, drengur og drengur',
    '👨‍👧‍👦' => 'fjölskylda: karl, stúlka og drengur',
    '👨‍👧‍👧' => 'fjölskylda: karl, stúlka og stúlka',
    '👩‍👦‍👦' => 'fjölskylda: kona, drengur og drengur',
    '👩‍👧‍👦' => 'fjölskylda: kona, stúlka og drengur',
    '👩‍👧‍👧' => 'fjölskylda: kona, stúlka og stúlka',
    '🧑‍🤝‍🧑' => 'fólk að leiðast',
    '🧑‍🧑‍🧒' => 'fjölskylda: fullorðinn, fullorðinn, barn',
    '🧑‍🧒‍🧒' => 'fjölskylda: fullorðinn, barn, barn',
    '🧑🏻‍🦰' => 'manneskja: ljós húðlitur og rautt hár',
    '🧑🏼‍🦰' => 'manneskja: meðalljós húðlitur og rautt hár',
    '🧑🏽‍🦰' => 'manneskja: millihúðlitur og rautt hár',
    '🧑🏾‍🦰' => 'manneskja: meðaldökkur húðlitur og rautt hár',
    '🧑🏿‍🦰' => 'manneskja: dökkur húðlitur og rautt hár',
    '🧑🏻‍🦱' => 'manneskja: ljós húðlitur og krullur',
    '🧑🏼‍🦱' => 'manneskja: meðalljós húðlitur og krullur',
    '🧑🏽‍🦱' => 'manneskja: millihúðlitur og krullur',
    '🧑🏾‍🦱' => 'manneskja: meðaldökkur húðlitur og krullur',
    '🧑🏿‍🦱' => 'manneskja: dökkur húðlitur og krullur',
    '🧑🏻‍🦳' => 'manneskja: ljós húðlitur og hvítt hár',
    '🧑🏼‍🦳' => 'manneskja: meðalljós húðlitur og hvítt hár',
    '🧑🏽‍🦳' => 'manneskja: millihúðlitur og hvítt hár',
    '🧑🏾‍🦳' => 'manneskja: meðaldökkur húðlitur og hvítt hár',
    '🧑🏿‍🦳' => 'manneskja: dökkur húðlitur og hvítt hár',
    '🧑🏻‍🦲' => 'manneskja: ljós húðlitur og skalli',
    '🧑🏼‍🦲' => 'manneskja: meðalljós húðlitur og skalli',
    '🧑🏽‍🦲' => 'manneskja: millihúðlitur og skalli',
    '🧑🏾‍🦲' => 'manneskja: meðaldökkur húðlitur og skalli',
    '🧑🏿‍🦲' => 'manneskja: dökkur húðlitur og skalli',
    '🧑🏻‍🩰' => 'ballettdansari: ljós húðlitur',
    '🧑🏼‍🩰' => 'ballettdansari: meðalljós húðlitur',
    '🧑🏽‍🩰' => 'ballettdansari: millihúðlitur',
    '🧑🏾‍🩰' => 'ballettdansari: meðaldökkur húðlitur',
    '🧑🏿‍🩰' => 'ballettdansari: dökkur húðlitur',
    '🧔🏻‍♂' => 'karl: ljós húðlitur og skegg',
    '🧔🏼‍♂' => 'karl: meðalljós húðlitur og skegg',
    '🧔🏽‍♂' => 'karl: millihúðlitur og skegg',
    '🧔🏾‍♂' => 'karl: meðaldökkur húðlitur og skegg',
    '🧔🏿‍♂' => 'karl: dökkur húðlitur og skegg',
    '👱🏻‍♂' => 'ljóshærður maður: ljós húðlitur',
    '👱🏼‍♂' => 'ljóshærður maður: meðalljós húðlitur',
    '👱🏽‍♂' => 'ljóshærður maður: millihúðlitur',
    '👱🏾‍♂' => 'ljóshærður maður: meðaldökkur húðlitur',
    '👱🏿‍♂' => 'ljóshærður maður: dökkur húðlitur',
    '👨🏻‍🦰' => 'karl: ljós húðlitur og rautt hár',
    '👨🏼‍🦰' => 'karl: meðalljós húðlitur og rautt hár',
    '👨🏽‍🦰' => 'karl: millihúðlitur og rautt hár',
    '👨🏾‍🦰' => 'karl: meðaldökkur húðlitur og rautt hár',
    '👨🏿‍🦰' => 'karl: dökkur húðlitur og rautt hár',
    '👨🏻‍🦱' => 'karl: ljós húðlitur og krullur',
    '👨🏼‍🦱' => 'karl: meðalljós húðlitur og krullur',
    '👨🏽‍🦱' => 'karl: millihúðlitur og krullur',
    '👨🏾‍🦱' => 'karl: meðaldökkur húðlitur og krullur',
    '👨🏿‍🦱' => 'karl: dökkur húðlitur og krullur',
    '👨🏻‍🦳' => 'karl: ljós húðlitur og hvítt hár',
    '👨🏼‍🦳' => 'karl: meðalljós húðlitur og hvítt hár',
    '👨🏽‍🦳' => 'karl: millihúðlitur og hvítt hár',
    '👨🏾‍🦳' => 'karl: meðaldökkur húðlitur og hvítt hár',
    '👨🏿‍🦳' => 'karl: dökkur húðlitur og hvítt hár',
    '👨🏻‍🦲' => 'karl: ljós húðlitur og skalli',
    '👨🏼‍🦲' => 'karl: meðalljós húðlitur og skalli',
    '👨🏽‍🦲' => 'karl: millihúðlitur og skalli',
    '👨🏾‍🦲' => 'karl: meðaldökkur húðlitur og skalli',
    '👨🏿‍🦲' => 'karl: dökkur húðlitur og skalli',
    '🧔🏻‍♀' => 'kona: ljós húðlitur og skegg',
    '🧔🏼‍♀' => 'kona: meðalljós húðlitur og skegg',
    '🧔🏽‍♀' => 'kona: millihúðlitur og skegg',
    '🧔🏾‍♀' => 'kona: meðaldökkur húðlitur og skegg',
    '🧔🏿‍♀' => 'kona: dökkur húðlitur og skegg',
    '👱🏻‍♀' => 'ljóshærð kona: ljós húðlitur',
    '👱🏼‍♀' => 'ljóshærð kona: meðalljós húðlitur',
    '👱🏽‍♀' => 'ljóshærð kona: millihúðlitur',
    '👱🏾‍♀' => 'ljóshærð kona: meðaldökkur húðlitur',
    '👱🏿‍♀' => 'ljóshærð kona: dökkur húðlitur',
    '👩🏻‍🦰' => 'kona: ljós húðlitur og rautt hár',
    '👩🏼‍🦰' => 'kona: meðalljós húðlitur og rautt hár',
    '👩🏽‍🦰' => 'kona: millihúðlitur og rautt hár',
    '👩🏾‍🦰' => 'kona: meðaldökkur húðlitur og rautt hár',
    '👩🏿‍🦰' => 'kona: dökkur húðlitur og rautt hár',
    '👩🏻‍🦱' => 'kona: ljós húðlitur og krullur',
    '👩🏼‍🦱' => 'kona: meðalljós húðlitur og krullur',
    '👩🏽‍🦱' => 'kona: millihúðlitur og krullur',
    '👩🏾‍🦱' => 'kona: meðaldökkur húðlitur og krullur',
    '👩🏿‍🦱' => 'kona: dökkur húðlitur og krullur',
    '👩🏻‍🦳' => 'kona: ljós húðlitur og hvítt hár',
    '👩🏼‍🦳' => 'kona: meðalljós húðlitur og hvítt hár',
    '👩🏽‍🦳' => 'kona: millihúðlitur og hvítt hár',
    '👩🏾‍🦳' => 'kona: meðaldökkur húðlitur og hvítt hár',
    '👩🏿‍🦳' => 'kona: dökkur húðlitur og hvítt hár',
    '👩🏻‍🦲' => 'kona: ljós húðlitur og skalli',
    '👩🏼‍🦲' => 'kona: meðalljós húðlitur og skalli',
    '👩🏽‍🦲' => 'kona: millihúðlitur og skalli',
    '👩🏾‍🦲' => 'kona: meðaldökkur húðlitur og skalli',
    '👩🏿‍🦲' => 'kona: dökkur húðlitur og skalli',
    '🙍🏻‍♂' => 'maður með skeifu: ljós húðlitur',
    '🙍🏼‍♂' => 'maður með skeifu: meðalljós húðlitur',
    '🙍🏽‍♂' => 'maður með skeifu: millihúðlitur',
    '🙍🏾‍♂' => 'maður með skeifu: meðaldökkur húðlitur',
    '🙍🏿‍♂' => 'maður með skeifu: dökkur húðlitur',
    '🙍🏻‍♀' => 'kona með skeifu: ljós húðlitur',
    '🙍🏼‍♀' => 'kona með skeifu: meðalljós húðlitur',
    '🙍🏽‍♀' => 'kona með skeifu: millihúðlitur',
    '🙍🏾‍♀' => 'kona með skeifu: meðaldökkur húðlitur',
    '🙍🏿‍♀' => 'kona með skeifu: dökkur húðlitur',
    '🙎🏻‍♂' => 'maður í fýlu: ljós húðlitur',
    '🙎🏼‍♂' => 'maður í fýlu: meðalljós húðlitur',
    '🙎🏽‍♂' => 'maður í fýlu: millihúðlitur',
    '🙎🏾‍♂' => 'maður í fýlu: meðaldökkur húðlitur',
    '🙎🏿‍♂' => 'maður í fýlu: dökkur húðlitur',
    '🙎🏻‍♀' => 'kona í fýlu: ljós húðlitur',
    '🙎🏼‍♀' => 'kona í fýlu: meðalljós húðlitur',
    '🙎🏽‍♀' => 'kona í fýlu: millihúðlitur',
    '🙎🏾‍♀' => 'kona í fýlu: meðaldökkur húðlitur',
    '🙎🏿‍♀' => 'kona í fýlu: dökkur húðlitur',
    '🙅🏻‍♂' => 'maður segir ekki í lagi: ljós húðlitur',
    '🙅🏼‍♂' => 'maður segir ekki í lagi: meðalljós húðlitur',
    '🙅🏽‍♂' => 'maður segir ekki í lagi: millihúðlitur',
    '🙅🏾‍♂' => 'maður segir ekki í lagi: meðaldökkur húðlitur',
    '🙅🏿‍♂' => 'maður segir ekki í lagi: dökkur húðlitur',
    '🙅🏻‍♀' => 'kona segir ekki í lagi: ljós húðlitur',
    '🙅🏼‍♀' => 'kona segir ekki í lagi: meðalljós húðlitur',
    '🙅🏽‍♀' => 'kona segir ekki í lagi: millihúðlitur',
    '🙅🏾‍♀' => 'kona segir ekki í lagi: meðaldökkur húðlitur',
    '🙅🏿‍♀' => 'kona segir ekki í lagi: dökkur húðlitur',
    '🙆🏻‍♂' => 'maður segir allt í lagi: ljós húðlitur',
    '🙆🏼‍♂' => 'maður segir allt í lagi: meðalljós húðlitur',
    '🙆🏽‍♂' => 'maður segir allt í lagi: millihúðlitur',
    '🙆🏾‍♂' => 'maður segir allt í lagi: meðaldökkur húðlitur',
    '🙆🏿‍♂' => 'maður segir allt í lagi: dökkur húðlitur',
    '🙆🏻‍♀' => 'kona segir allt í lagi: ljós húðlitur',
    '🙆🏼‍♀' => 'kona segir allt í lagi: meðalljós húðlitur',
    '🙆🏽‍♀' => 'kona segir allt í lagi: millihúðlitur',
    '🙆🏾‍♀' => 'kona segir allt í lagi: meðaldökkur húðlitur',
    '🙆🏿‍♀' => 'kona segir allt í lagi: dökkur húðlitur',
    '💁🏻‍♂' => 'maður réttir út lófa: ljós húðlitur',
    '💁🏼‍♂' => 'maður réttir út lófa: meðalljós húðlitur',
    '💁🏽‍♂' => 'maður réttir út lófa: millihúðlitur',
    '💁🏾‍♂' => 'maður réttir út lófa: meðaldökkur húðlitur',
    '💁🏿‍♂' => 'maður réttir út lófa: dökkur húðlitur',
    '💁🏻‍♀' => 'kona réttir út lófa: ljós húðlitur',
    '💁🏼‍♀' => 'kona réttir út lófa: meðalljós húðlitur',
    '💁🏽‍♀' => 'kona réttir út lófa: millihúðlitur',
    '💁🏾‍♀' => 'kona réttir út lófa: meðaldökkur húðlitur',
    '💁🏿‍♀' => 'kona réttir út lófa: dökkur húðlitur',
    '🙋🏻‍♂' => 'maður réttir upp hönd: ljós húðlitur',
    '🙋🏼‍♂' => 'maður réttir upp hönd: meðalljós húðlitur',
    '🙋🏽‍♂' => 'maður réttir upp hönd: millihúðlitur',
    '🙋🏾‍♂' => 'maður réttir upp hönd: meðaldökkur húðlitur',
    '🙋🏿‍♂' => 'maður réttir upp hönd: dökkur húðlitur',
    '🙋🏻‍♀' => 'kona réttir upp hönd: ljós húðlitur',
    '🙋🏼‍♀' => 'kona réttir upp hönd: meðalljós húðlitur',
    '🙋🏽‍♀' => 'kona réttir upp hönd: millihúðlitur',
    '🙋🏾‍♀' => 'kona réttir upp hönd: meðaldökkur húðlitur',
    '🙋🏿‍♀' => 'kona réttir upp hönd: dökkur húðlitur',
    '🧏🏻‍♂' => 'heyrnarlaus karl: ljós húðlitur',
    '🧏🏼‍♂' => 'heyrnarlaus karl: meðalljós húðlitur',
    '🧏🏽‍♂' => 'heyrnarlaus karl: millihúðlitur',
    '🧏🏾‍♂' => 'heyrnarlaus karl: meðaldökkur húðlitur',
    '🧏🏿‍♂' => 'heyrnarlaus karl: dökkur húðlitur',
    '🧏🏻‍♀' => 'heyrnarlaus kona: ljós húðlitur',
    '🧏🏼‍♀' => 'heyrnarlaus kona: meðalljós húðlitur',
    '🧏🏽‍♀' => 'heyrnarlaus kona: millihúðlitur',
    '🧏🏾‍♀' => 'heyrnarlaus kona: meðaldökkur húðlitur',
    '🧏🏿‍♀' => 'heyrnarlaus kona: dökkur húðlitur',
    '🙇🏻‍♂' => 'maður hneigir sig: ljós húðlitur',
    '🙇🏼‍♂' => 'maður hneigir sig: meðalljós húðlitur',
    '🙇🏽‍♂' => 'maður hneigir sig: millihúðlitur',
    '🙇🏾‍♂' => 'maður hneigir sig: meðaldökkur húðlitur',
    '🙇🏿‍♂' => 'maður hneigir sig: dökkur húðlitur',
    '🙇🏻‍♀' => 'kona hneigir sig: ljós húðlitur',
    '🙇🏼‍♀' => 'kona hneigir sig: meðalljós húðlitur',
    '🙇🏽‍♀' => 'kona hneigir sig: millihúðlitur',
    '🙇🏾‍♀' => 'kona hneigir sig: meðaldökkur húðlitur',
    '🙇🏿‍♀' => 'kona hneigir sig: dökkur húðlitur',
    '🤦🏻‍♂' => 'maður með hönd fyrir andlit: ljós húðlitur',
    '🤦🏼‍♂' => 'maður með hönd fyrir andlit: meðalljós húðlitur',
    '🤦🏽‍♂' => 'maður með hönd fyrir andlit: millihúðlitur',
    '🤦🏾‍♂' => 'maður með hönd fyrir andlit: meðaldökkur húðlitur',
    '🤦🏿‍♂' => 'maður með hönd fyrir andlit: dökkur húðlitur',
    '🤦🏻‍♀' => 'kona með hönd fyrir andlit: ljós húðlitur',
    '🤦🏼‍♀' => 'kona með hönd fyrir andlit: meðalljós húðlitur',
    '🤦🏽‍♀' => 'kona með hönd fyrir andlit: millihúðlitur',
    '🤦🏾‍♀' => 'kona með hönd fyrir andlit: meðaldökkur húðlitur',
    '🤦🏿‍♀' => 'kona með hönd fyrir andlit: dökkur húðlitur',
    '🤷🏻‍♂' => 'maður yppir öxlum: ljós húðlitur',
    '🤷🏼‍♂' => 'maður yppir öxlum: meðalljós húðlitur',
    '🤷🏽‍♂' => 'maður yppir öxlum: millihúðlitur',
    '🤷🏾‍♂' => 'maður yppir öxlum: meðaldökkur húðlitur',
    '🤷🏿‍♂' => 'maður yppir öxlum: dökkur húðlitur',
    '🤷🏻‍♀' => 'kona yppir öxlum: ljós húðlitur',
    '🤷🏼‍♀' => 'kona yppir öxlum: meðalljós húðlitur',
    '🤷🏽‍♀' => 'kona yppir öxlum: millihúðlitur',
    '🤷🏾‍♀' => 'kona yppir öxlum: meðaldökkur húðlitur',
    '🤷🏿‍♀' => 'kona yppir öxlum: dökkur húðlitur',
    '🧑🏻‍⚕' => 'heilbrigðisstarfsmaður: ljós húðlitur',
    '🧑🏼‍⚕' => 'heilbrigðisstarfsmaður: meðalljós húðlitur',
    '🧑🏽‍⚕' => 'heilbrigðisstarfsmaður: millihúðlitur',
    '🧑🏾‍⚕' => 'heilbrigðisstarfsmaður: meðaldökkur húðlitur',
    '🧑🏿‍⚕' => 'heilbrigðisstarfsmaður: dökkur húðlitur',
    '👨🏻‍⚕' => 'karlkyns heilbrigðisstarfsmaður: ljós húðlitur',
    '👨🏼‍⚕' => 'karlkyns heilbrigðisstarfsmaður: meðalljós húðlitur',
    '👨🏽‍⚕' => 'karlkyns heilbrigðisstarfsmaður: millihúðlitur',
    '👨🏾‍⚕' => 'karlkyns heilbrigðisstarfsmaður: meðaldökkur húðlitur',
    '👨🏿‍⚕' => 'karlkyns heilbrigðisstarfsmaður: dökkur húðlitur',
    '👩🏻‍⚕' => 'kvenkyns heilbrigðisstarfsmaður: ljós húðlitur',
    '👩🏼‍⚕' => 'kvenkyns heilbrigðisstarfsmaður: meðalljós húðlitur',
    '👩🏽‍⚕' => 'kvenkyns heilbrigðisstarfsmaður: millihúðlitur',
    '👩🏾‍⚕' => 'kvenkyns heilbrigðisstarfsmaður: meðaldökkur húðlitur',
    '👩🏿‍⚕' => 'kvenkyns heilbrigðisstarfsmaður: dökkur húðlitur',
    '🧑🏻‍🎓' => 'nemi: ljós húðlitur',
    '🧑🏼‍🎓' => 'nemi: meðalljós húðlitur',
    '🧑🏽‍🎓' => 'nemi: millihúðlitur',
    '🧑🏾‍🎓' => 'nemi: meðaldökkur húðlitur',
    '🧑🏿‍🎓' => 'nemi: dökkur húðlitur',
    '👨🏻‍🎓' => 'karlkyns námsmaður: ljós húðlitur',
    '👨🏼‍🎓' => 'karlkyns námsmaður: meðalljós húðlitur',
    '👨🏽‍🎓' => 'karlkyns námsmaður: millihúðlitur',
    '👨🏾‍🎓' => 'karlkyns námsmaður: meðaldökkur húðlitur',
    '👨🏿‍🎓' => 'karlkyns námsmaður: dökkur húðlitur',
    '👩🏻‍🎓' => 'kvenkyns námsmaður: ljós húðlitur',
    '👩🏼‍🎓' => 'kvenkyns námsmaður: meðalljós húðlitur',
    '👩🏽‍🎓' => 'kvenkyns námsmaður: millihúðlitur',
    '👩🏾‍🎓' => 'kvenkyns námsmaður: meðaldökkur húðlitur',
    '👩🏿‍🎓' => 'kvenkyns námsmaður: dökkur húðlitur',
    '🧑🏻‍🏫' => 'kennari: ljós húðlitur',
    '🧑🏼‍🏫' => 'kennari: meðalljós húðlitur',
    '🧑🏽‍🏫' => 'kennari: millihúðlitur',
    '🧑🏾‍🏫' => 'kennari: meðaldökkur húðlitur',
    '🧑🏿‍🏫' => 'kennari: dökkur húðlitur',
    '👨🏻‍🏫' => 'karlkyns kennari: ljós húðlitur',
    '👨🏼‍🏫' => 'karlkyns kennari: meðalljós húðlitur',
    '👨🏽‍🏫' => 'karlkyns kennari: millihúðlitur',
    '👨🏾‍🏫' => 'karlkyns kennari: meðaldökkur húðlitur',
    '👨🏿‍🏫' => 'karlkyns kennari: dökkur húðlitur',
    '👩🏻‍🏫' => 'kvenkyns kennari: ljós húðlitur',
    '👩🏼‍🏫' => 'kvenkyns kennari: meðalljós húðlitur',
    '👩🏽‍🏫' => 'kvenkyns kennari: millihúðlitur',
    '👩🏾‍🏫' => 'kvenkyns kennari: meðaldökkur húðlitur',
    '👩🏿‍🏫' => 'kvenkyns kennari: dökkur húðlitur',
    '🧑🏻‍⚖' => 'dómari: ljós húðlitur',
    '🧑🏼‍⚖' => 'dómari: meðalljós húðlitur',
    '🧑🏽‍⚖' => 'dómari: millihúðlitur',
    '🧑🏾‍⚖' => 'dómari: meðaldökkur húðlitur',
    '🧑🏿‍⚖' => 'dómari: dökkur húðlitur',
    '👨🏻‍⚖' => 'karlkyns dómari: ljós húðlitur',
    '👨🏼‍⚖' => 'karlkyns dómari: meðalljós húðlitur',
    '👨🏽‍⚖' => 'karlkyns dómari: millihúðlitur',
    '👨🏾‍⚖' => 'karlkyns dómari: meðaldökkur húðlitur',
    '👨🏿‍⚖' => 'karlkyns dómari: dökkur húðlitur',
    '👩🏻‍⚖' => 'kvenkyns dómari: ljós húðlitur',
    '👩🏼‍⚖' => 'kvenkyns dómari: meðalljós húðlitur',
    '👩🏽‍⚖' => 'kvenkyns dómari: millihúðlitur',
    '👩🏾‍⚖' => 'kvenkyns dómari: meðaldökkur húðlitur',
    '👩🏿‍⚖' => 'kvenkyns dómari: dökkur húðlitur',
    '🧑🏻‍🌾' => 'bóndi: ljós húðlitur',
    '🧑🏼‍🌾' => 'bóndi: meðalljós húðlitur',
    '🧑🏽‍🌾' => 'bóndi: millihúðlitur',
    '🧑🏾‍🌾' => 'bóndi: meðaldökkur húðlitur',
    '🧑🏿‍🌾' => 'bóndi: dökkur húðlitur',
    '👨🏻‍🌾' => 'karlkyns bóndi: ljós húðlitur',
    '👨🏼‍🌾' => 'karlkyns bóndi: meðalljós húðlitur',
    '👨🏽‍🌾' => 'karlkyns bóndi: millihúðlitur',
    '👨🏾‍🌾' => 'karlkyns bóndi: meðaldökkur húðlitur',
    '👨🏿‍🌾' => 'karlkyns bóndi: dökkur húðlitur',
    '👩🏻‍🌾' => 'kvenkyns bóndi: ljós húðlitur',
    '👩🏼‍🌾' => 'kvenkyns bóndi: meðalljós húðlitur',
    '👩🏽‍🌾' => 'kvenkyns bóndi: millihúðlitur',
    '👩🏾‍🌾' => 'kvenkyns bóndi: meðaldökkur húðlitur',
    '👩🏿‍🌾' => 'kvenkyns bóndi: dökkur húðlitur',
    '🧑🏻‍🍳' => 'kokkur: ljós húðlitur',
    '🧑🏼‍🍳' => 'kokkur: meðalljós húðlitur',
    '🧑🏽‍🍳' => 'kokkur: millihúðlitur',
    '🧑🏾‍🍳' => 'kokkur: meðaldökkur húðlitur',
    '🧑🏿‍🍳' => 'kokkur: dökkur húðlitur',
    '👨🏻‍🍳' => 'karlkyns kokkur: ljós húðlitur',
    '👨🏼‍🍳' => 'karlkyns kokkur: meðalljós húðlitur',
    '👨🏽‍🍳' => 'karlkyns kokkur: millihúðlitur',
    '👨🏾‍🍳' => 'karlkyns kokkur: meðaldökkur húðlitur',
    '👨🏿‍🍳' => 'karlkyns kokkur: dökkur húðlitur',
    '👩🏻‍🍳' => 'kvenkyns kokkur: ljós húðlitur',
    '👩🏼‍🍳' => 'kvenkyns kokkur: meðalljós húðlitur',
    '👩🏽‍🍳' => 'kvenkyns kokkur: millihúðlitur',
    '👩🏾‍🍳' => 'kvenkyns kokkur: meðaldökkur húðlitur',
    '👩🏿‍🍳' => 'kvenkyns kokkur: dökkur húðlitur',
    '🧑🏻‍🔧' => 'vélvirki: ljós húðlitur',
    '🧑🏼‍🔧' => 'vélvirki: meðalljós húðlitur',
    '🧑🏽‍🔧' => 'vélvirki: millihúðlitur',
    '🧑🏾‍🔧' => 'vélvirki: meðaldökkur húðlitur',
    '🧑🏿‍🔧' => 'vélvirki: dökkur húðlitur',
    '👨🏻‍🔧' => 'karl með skiptilykil: ljós húðlitur',
    '👨🏼‍🔧' => 'karl með skiptilykil: meðalljós húðlitur',
    '👨🏽‍🔧' => 'karl með skiptilykil: millihúðlitur',
    '👨🏾‍🔧' => 'karl með skiptilykil: meðaldökkur húðlitur',
    '👨🏿‍🔧' => 'karl með skiptilykil: dökkur húðlitur',
    '👩🏻‍🔧' => 'kona með skiptilykil: ljós húðlitur',
    '👩🏼‍🔧' => 'kona með skiptilykil: meðalljós húðlitur',
    '👩🏽‍🔧' => 'kona með skiptilykil: millihúðlitur',
    '👩🏾‍🔧' => 'kona með skiptilykil: meðaldökkur húðlitur',
    '👩🏿‍🔧' => 'kona með skiptilykil: dökkur húðlitur',
    '🧑🏻‍🏭' => 'verksmiðjustarfsmaður: ljós húðlitur',
    '🧑🏼‍🏭' => 'verksmiðjustarfsmaður: meðalljós húðlitur',
    '🧑🏽‍🏭' => 'verksmiðjustarfsmaður: millihúðlitur',
    '🧑🏾‍🏭' => 'verksmiðjustarfsmaður: meðaldökkur húðlitur',
    '🧑🏿‍🏭' => 'verksmiðjustarfsmaður: dökkur húðlitur',
    '👨🏻‍🏭' => 'karlkyns verksmiðjustarfsmaður: ljós húðlitur',
    '👨🏼‍🏭' => 'karlkyns verksmiðjustarfsmaður: meðalljós húðlitur',
    '👨🏽‍🏭' => 'karlkyns verksmiðjustarfsmaður: millihúðlitur',
    '👨🏾‍🏭' => 'karlkyns verksmiðjustarfsmaður: meðaldökkur húðlitur',
    '👨🏿‍🏭' => 'karlkyns verksmiðjustarfsmaður: dökkur húðlitur',
    '👩🏻‍🏭' => 'kvenkyns verksmiðjustarfsmaður: ljós húðlitur',
    '👩🏼‍🏭' => 'kvenkyns verksmiðjustarfsmaður: meðalljós húðlitur',
    '👩🏽‍🏭' => 'kvenkyns verksmiðjustarfsmaður: millihúðlitur',
    '👩🏾‍🏭' => 'kvenkyns verksmiðjustarfsmaður: meðaldökkur húðlitur',
    '👩🏿‍🏭' => 'kvenkyns verksmiðjustarfsmaður: dökkur húðlitur',
    '🧑🏻‍💼' => 'skrifstofustarfsmaður: ljós húðlitur',
    '🧑🏼‍💼' => 'skrifstofustarfsmaður: meðalljós húðlitur',
    '🧑🏽‍💼' => 'skrifstofustarfsmaður: millihúðlitur',
    '🧑🏾‍💼' => 'skrifstofustarfsmaður: meðaldökkur húðlitur',
    '🧑🏿‍💼' => 'skrifstofustarfsmaður: dökkur húðlitur',
    '👨🏻‍💼' => 'karlkyns skrifstofustarfsmaður: ljós húðlitur',
    '👨🏼‍💼' => 'karlkyns skrifstofustarfsmaður: meðalljós húðlitur',
    '👨🏽‍💼' => 'karlkyns skrifstofustarfsmaður: millihúðlitur',
    '👨🏾‍💼' => 'karlkyns skrifstofustarfsmaður: meðaldökkur húðlitur',
    '👨🏿‍💼' => 'karlkyns skrifstofustarfsmaður: dökkur húðlitur',
    '👩🏻‍💼' => 'kvenkyns skrifstofustarfsmaður: ljós húðlitur',
    '👩🏼‍💼' => 'kvenkyns skrifstofustarfsmaður: meðalljós húðlitur',
    '👩🏽‍💼' => 'kvenkyns skrifstofustarfsmaður: millihúðlitur',
    '👩🏾‍💼' => 'kvenkyns skrifstofustarfsmaður: meðaldökkur húðlitur',
    '👩🏿‍💼' => 'kvenkyns skrifstofustarfsmaður: dökkur húðlitur',
    '🧑🏻‍🔬' => 'vísindafræðingur: ljós húðlitur',
    '🧑🏼‍🔬' => 'vísindafræðingur: meðalljós húðlitur',
    '🧑🏽‍🔬' => 'vísindafræðingur: millihúðlitur',
    '🧑🏾‍🔬' => 'vísindafræðingur: meðaldökkur húðlitur',
    '🧑🏿‍🔬' => 'vísindafræðingur: dökkur húðlitur',
    '👨🏻‍🔬' => 'vísindamaður: ljós húðlitur',
    '👨🏼‍🔬' => 'vísindamaður: meðalljós húðlitur',
    '👨🏽‍🔬' => 'vísindamaður: millihúðlitur',
    '👨🏾‍🔬' => 'vísindamaður: meðaldökkur húðlitur',
    '👨🏿‍🔬' => 'vísindamaður: dökkur húðlitur',
    '👩🏻‍🔬' => 'vísindakona: ljós húðlitur',
    '👩🏼‍🔬' => 'vísindakona: meðalljós húðlitur',
    '👩🏽‍🔬' => 'vísindakona: millihúðlitur',
    '👩🏾‍🔬' => 'vísindakona: meðaldökkur húðlitur',
    '👩🏿‍🔬' => 'vísindakona: dökkur húðlitur',
    '🧑🏻‍💻' => 'forritari: ljós húðlitur',
    '🧑🏼‍💻' => 'forritari: meðalljós húðlitur',
    '🧑🏽‍💻' => 'forritari: millihúðlitur',
    '🧑🏾‍💻' => 'forritari: meðaldökkur húðlitur',
    '🧑🏿‍💻' => 'forritari: dökkur húðlitur',
    '👨🏻‍💻' => 'karlkyns forritari: ljós húðlitur',
    '👨🏼‍💻' => 'karlkyns forritari: meðalljós húðlitur',
    '👨🏽‍💻' => 'karlkyns forritari: millihúðlitur',
    '👨🏾‍💻' => 'karlkyns forritari: meðaldökkur húðlitur',
    '👨🏿‍💻' => 'karlkyns forritari: dökkur húðlitur',
    '👩🏻‍💻' => 'kvenkyns forritari: ljós húðlitur',
    '👩🏼‍💻' => 'kvenkyns forritari: meðalljós húðlitur',
    '👩🏽‍💻' => 'kvenkyns forritari: millihúðlitur',
    '👩🏾‍💻' => 'kvenkyns forritari: meðaldökkur húðlitur',
    '👩🏿‍💻' => 'kvenkyns forritari: dökkur húðlitur',
    '🧑🏻‍🎤' => 'söngfugl: ljós húðlitur',
    '🧑🏼‍🎤' => 'söngfugl: meðalljós húðlitur',
    '🧑🏽‍🎤' => 'söngfugl: millihúðlitur',
    '🧑🏾‍🎤' => 'söngfugl: meðaldökkur húðlitur',
    '🧑🏿‍🎤' => 'söngfugl: dökkur húðlitur',
    '👨🏻‍🎤' => 'söngvari: ljós húðlitur',
    '👨🏼‍🎤' => 'söngvari: meðalljós húðlitur',
    '👨🏽‍🎤' => 'söngvari: millihúðlitur',
    '👨🏾‍🎤' => 'söngvari: meðaldökkur húðlitur',
    '👨🏿‍🎤' => 'söngvari: dökkur húðlitur',
    '👩🏻‍🎤' => 'söngkona: ljós húðlitur',
    '👩🏼‍🎤' => 'söngkona: meðalljós húðlitur',
    '👩🏽‍🎤' => 'söngkona: millihúðlitur',
    '👩🏾‍🎤' => 'söngkona: meðaldökkur húðlitur',
    '👩🏿‍🎤' => 'söngkona: dökkur húðlitur',
    '🧑🏻‍🎨' => 'listmálari: ljós húðlitur',
    '🧑🏼‍🎨' => 'listmálari: meðalljós húðlitur',
    '🧑🏽‍🎨' => 'listmálari: millihúðlitur',
    '🧑🏾‍🎨' => 'listmálari: meðaldökkur húðlitur',
    '🧑🏿‍🎨' => 'listmálari: dökkur húðlitur',
    '👨🏻‍🎨' => 'karlkyns listamaður: ljós húðlitur',
    '👨🏼‍🎨' => 'karlkyns listamaður: meðalljós húðlitur',
    '👨🏽‍🎨' => 'karlkyns listamaður: millihúðlitur',
    '👨🏾‍🎨' => 'karlkyns listamaður: meðaldökkur húðlitur',
    '👨🏿‍🎨' => 'karlkyns listamaður: dökkur húðlitur',
    '👩🏻‍🎨' => 'listakona: ljós húðlitur',
    '👩🏼‍🎨' => 'listakona: meðalljós húðlitur',
    '👩🏽‍🎨' => 'listakona: millihúðlitur',
    '👩🏾‍🎨' => 'listakona: meðaldökkur húðlitur',
    '👩🏿‍🎨' => 'listakona: dökkur húðlitur',
    '🧑🏻‍✈' => 'flugstjóri: ljós húðlitur',
    '🧑🏼‍✈' => 'flugstjóri: meðalljós húðlitur',
    '🧑🏽‍✈' => 'flugstjóri: millihúðlitur',
    '🧑🏾‍✈' => 'flugstjóri: meðaldökkur húðlitur',
    '🧑🏿‍✈' => 'flugstjóri: dökkur húðlitur',
    '👨🏻‍✈' => 'karlkyns flugstjóri: ljós húðlitur',
    '👨🏼‍✈' => 'karlkyns flugstjóri: meðalljós húðlitur',
    '👨🏽‍✈' => 'karlkyns flugstjóri: millihúðlitur',
    '👨🏾‍✈' => 'karlkyns flugstjóri: meðaldökkur húðlitur',
    '👨🏿‍✈' => 'karlkyns flugstjóri: dökkur húðlitur',
    '👩🏻‍✈' => 'kvenkyns flugstjóri: ljós húðlitur',
    '👩🏼‍✈' => 'kvenkyns flugstjóri: meðalljós húðlitur',
    '👩🏽‍✈' => 'kvenkyns flugstjóri: millihúðlitur',
    '👩🏾‍✈' => 'kvenkyns flugstjóri: meðaldökkur húðlitur',
    '👩🏿‍✈' => 'kvenkyns flugstjóri: dökkur húðlitur',
    '🧑🏻‍🚀' => 'geimfari: ljós húðlitur',
    '🧑🏼‍🚀' => 'geimfari: meðalljós húðlitur',
    '🧑🏽‍🚀' => 'geimfari: millihúðlitur',
    '🧑🏾‍🚀' => 'geimfari: meðaldökkur húðlitur',
    '🧑🏿‍🚀' => 'geimfari: dökkur húðlitur',
    '👨🏻‍🚀' => 'karlkyns geimfari: ljós húðlitur',
    '👨🏼‍🚀' => 'karlkyns geimfari: meðalljós húðlitur',
    '👨🏽‍🚀' => 'karlkyns geimfari: millihúðlitur',
    '👨🏾‍🚀' => 'karlkyns geimfari: meðaldökkur húðlitur',
    '👨🏿‍🚀' => 'karlkyns geimfari: dökkur húðlitur',
    '👩🏻‍🚀' => 'kvenkyns geimfari: ljós húðlitur',
    '👩🏼‍🚀' => 'kvenkyns geimfari: meðalljós húðlitur',
    '👩🏽‍🚀' => 'kvenkyns geimfari: millihúðlitur',
    '👩🏾‍🚀' => 'kvenkyns geimfari: meðaldökkur húðlitur',
    '👩🏿‍🚀' => 'kvenkyns geimfari: dökkur húðlitur',
    '🧑🏻‍🚒' => 'brunaliðsmaður: ljós húðlitur',
    '🧑🏼‍🚒' => 'brunaliðsmaður: meðalljós húðlitur',
    '🧑🏽‍🚒' => 'brunaliðsmaður: millihúðlitur',
    '🧑🏾‍🚒' => 'brunaliðsmaður: meðaldökkur húðlitur',
    '🧑🏿‍🚒' => 'brunaliðsmaður: dökkur húðlitur',
    '👨🏻‍🚒' => 'slökkviliðsmaður: ljós húðlitur',
    '👨🏼‍🚒' => 'slökkviliðsmaður: meðalljós húðlitur',
    '👨🏽‍🚒' => 'slökkviliðsmaður: millihúðlitur',
    '👨🏾‍🚒' => 'slökkviliðsmaður: meðaldökkur húðlitur',
    '👨🏿‍🚒' => 'slökkviliðsmaður: dökkur húðlitur',
    '👩🏻‍🚒' => 'slökkviliðskona: ljós húðlitur',
    '👩🏼‍🚒' => 'slökkviliðskona: meðalljós húðlitur',
    '👩🏽‍🚒' => 'slökkviliðskona: millihúðlitur',
    '👩🏾‍🚒' => 'slökkviliðskona: meðaldökkur húðlitur',
    '👩🏿‍🚒' => 'slökkviliðskona: dökkur húðlitur',
    '👮🏻‍♂' => 'karlkyns lögregluþjónn: ljós húðlitur',
    '👮🏼‍♂' => 'karlkyns lögregluþjónn: meðalljós húðlitur',
    '👮🏽‍♂' => 'karlkyns lögregluþjónn: millihúðlitur',
    '👮🏾‍♂' => 'karlkyns lögregluþjónn: meðaldökkur húðlitur',
    '👮🏿‍♂' => 'karlkyns lögregluþjónn: dökkur húðlitur',
    '👮🏻‍♀' => 'kvenkyns lögregluþjónn: ljós húðlitur',
    '👮🏼‍♀' => 'kvenkyns lögregluþjónn: meðalljós húðlitur',
    '👮🏽‍♀' => 'kvenkyns lögregluþjónn: millihúðlitur',
    '👮🏾‍♀' => 'kvenkyns lögregluþjónn: meðaldökkur húðlitur',
    '👮🏿‍♀' => 'kvenkyns lögregluþjónn: dökkur húðlitur',
    '🕵🏻‍♂' => 'karlkyns spæjari: ljós húðlitur',
    '🕵🏼‍♂' => 'karlkyns spæjari: meðalljós húðlitur',
    '🕵🏽‍♂' => 'karlkyns spæjari: millihúðlitur',
    '🕵🏾‍♂' => 'karlkyns spæjari: meðaldökkur húðlitur',
    '🕵🏿‍♂' => 'karlkyns spæjari: dökkur húðlitur',
    '🕵🏻‍♀' => 'kvenkyns spæjari: ljós húðlitur',
    '🕵🏼‍♀' => 'kvenkyns spæjari: meðalljós húðlitur',
    '🕵🏽‍♀' => 'kvenkyns spæjari: millihúðlitur',
    '🕵🏾‍♀' => 'kvenkyns spæjari: meðaldökkur húðlitur',
    '🕵🏿‍♀' => 'kvenkyns spæjari: dökkur húðlitur',
    '💂🏻‍♂' => 'karlkyns vörður: ljós húðlitur',
    '💂🏼‍♂' => 'karlkyns vörður: meðalljós húðlitur',
    '💂🏽‍♂' => 'karlkyns vörður: millihúðlitur',
    '💂🏾‍♂' => 'karlkyns vörður: meðaldökkur húðlitur',
    '💂🏿‍♂' => 'karlkyns vörður: dökkur húðlitur',
    '💂🏻‍♀' => 'kvenkyns vörður: ljós húðlitur',
    '💂🏼‍♀' => 'kvenkyns vörður: meðalljós húðlitur',
    '💂🏽‍♀' => 'kvenkyns vörður: millihúðlitur',
    '💂🏾‍♀' => 'kvenkyns vörður: meðaldökkur húðlitur',
    '💂🏿‍♀' => 'kvenkyns vörður: dökkur húðlitur',
    '👷🏻‍♂' => 'karlkyns byggingarstarfsmaður: ljós húðlitur',
    '👷🏼‍♂' => 'karlkyns byggingarstarfsmaður: meðalljós húðlitur',
    '👷🏽‍♂' => 'karlkyns byggingarstarfsmaður: millihúðlitur',
    '👷🏾‍♂' => 'karlkyns byggingarstarfsmaður: meðaldökkur húðlitur',
    '👷🏿‍♂' => 'karlkyns byggingarstarfsmaður: dökkur húðlitur',
    '👷🏻‍♀' => 'kvenkyns byggingarstarfsmaður: ljós húðlitur',
    '👷🏼‍♀' => 'kvenkyns byggingarstarfsmaður: meðalljós húðlitur',
    '👷🏽‍♀' => 'kvenkyns byggingarstarfsmaður: millihúðlitur',
    '👷🏾‍♀' => 'kvenkyns byggingarstarfsmaður: meðaldökkur húðlitur',
    '👷🏿‍♀' => 'kvenkyns byggingarstarfsmaður: dökkur húðlitur',
    '👳🏻‍♂' => 'karl með túrban: ljós húðlitur',
    '👳🏼‍♂' => 'karl með túrban: meðalljós húðlitur',
    '👳🏽‍♂' => 'karl með túrban: millihúðlitur',
    '👳🏾‍♂' => 'karl með túrban: meðaldökkur húðlitur',
    '👳🏿‍♂' => 'karl með túrban: dökkur húðlitur',
    '👳🏻‍♀' => 'kona með túrban: ljós húðlitur',
    '👳🏼‍♀' => 'kona með túrban: meðalljós húðlitur',
    '👳🏽‍♀' => 'kona með túrban: millihúðlitur',
    '👳🏾‍♀' => 'kona með túrban: meðaldökkur húðlitur',
    '👳🏿‍♀' => 'kona með túrban: dökkur húðlitur',
    '🤵🏻‍♂' => 'karl í smóking: ljós húðlitur',
    '🤵🏼‍♂' => 'karl í smóking: meðalljós húðlitur',
    '🤵🏽‍♂' => 'karl í smóking: millihúðlitur',
    '🤵🏾‍♂' => 'karl í smóking: meðaldökkur húðlitur',
    '🤵🏿‍♂' => 'karl í smóking: dökkur húðlitur',
    '🤵🏻‍♀' => 'kona í smóking: ljós húðlitur',
    '🤵🏼‍♀' => 'kona í smóking: meðalljós húðlitur',
    '🤵🏽‍♀' => 'kona í smóking: millihúðlitur',
    '🤵🏾‍♀' => 'kona í smóking: meðaldökkur húðlitur',
    '🤵🏿‍♀' => 'kona í smóking: dökkur húðlitur',
    '👰🏻‍♂' => 'karl með slör: ljós húðlitur',
    '👰🏼‍♂' => 'karl með slör: meðalljós húðlitur',
    '👰🏽‍♂' => 'karl með slör: millihúðlitur',
    '👰🏾‍♂' => 'karl með slör: meðaldökkur húðlitur',
    '👰🏿‍♂' => 'karl með slör: dökkur húðlitur',
    '👰🏻‍♀' => 'kona með slör: ljós húðlitur',
    '👰🏼‍♀' => 'kona með slör: meðalljós húðlitur',
    '👰🏽‍♀' => 'kona með slör: millihúðlitur',
    '👰🏾‍♀' => 'kona með slör: meðaldökkur húðlitur',
    '👰🏿‍♀' => 'kona með slör: dökkur húðlitur',
    '👩🏻‍🍼' => 'kona að gefa barni: ljós húðlitur',
    '👩🏼‍🍼' => 'kona að gefa barni: meðalljós húðlitur',
    '👩🏽‍🍼' => 'kona að gefa barni: millihúðlitur',
    '👩🏾‍🍼' => 'kona að gefa barni: meðaldökkur húðlitur',
    '👩🏿‍🍼' => 'kona að gefa barni: dökkur húðlitur',
    '👨🏻‍🍼' => 'karl að gefa barni: ljós húðlitur',
    '👨🏼‍🍼' => 'karl að gefa barni: meðalljós húðlitur',
    '👨🏽‍🍼' => 'karl að gefa barni: millihúðlitur',
    '👨🏾‍🍼' => 'karl að gefa barni: meðaldökkur húðlitur',
    '👨🏿‍🍼' => 'karl að gefa barni: dökkur húðlitur',
    '🧑🏻‍🍼' => 'manneskja að gefa barni: ljós húðlitur',
    '🧑🏼‍🍼' => 'manneskja að gefa barni: meðalljós húðlitur',
    '🧑🏽‍🍼' => 'manneskja að gefa barni: millihúðlitur',
    '🧑🏾‍🍼' => 'manneskja að gefa barni: meðaldökkur húðlitur',
    '🧑🏿‍🍼' => 'manneskja að gefa barni: dökkur húðlitur',
    '🧑🏻‍🎄' => 'frú sveinki: ljós húðlitur',
    '🧑🏼‍🎄' => 'frú sveinki: meðalljós húðlitur',
    '🧑🏽‍🎄' => 'frú sveinki: millihúðlitur',
    '🧑🏾‍🎄' => 'frú sveinki: meðaldökkur húðlitur',
    '🧑🏿‍🎄' => 'frú sveinki: dökkur húðlitur',
    '🦸🏻‍♂' => 'ofurmaður: ljós húðlitur',
    '🦸🏼‍♂' => 'ofurmaður: meðalljós húðlitur',
    '🦸🏽‍♂' => 'ofurmaður: millihúðlitur',
    '🦸🏾‍♂' => 'ofurmaður: meðaldökkur húðlitur',
    '🦸🏿‍♂' => 'ofurmaður: dökkur húðlitur',
    '🦸🏻‍♀' => 'ofurkona: ljós húðlitur',
    '🦸🏼‍♀' => 'ofurkona: meðalljós húðlitur',
    '🦸🏽‍♀' => 'ofurkona: millihúðlitur',
    '🦸🏾‍♀' => 'ofurkona: meðaldökkur húðlitur',
    '🦸🏿‍♀' => 'ofurkona: dökkur húðlitur',
    '🦹🏻‍♂' => 'illmenni: ljós húðlitur',
    '🦹🏼‍♂' => 'illmenni: meðalljós húðlitur',
    '🦹🏽‍♂' => 'illmenni: millihúðlitur',
    '🦹🏾‍♂' => 'illmenni: meðaldökkur húðlitur',
    '🦹🏿‍♂' => 'illmenni: dökkur húðlitur',
    '🦹🏻‍♀' => 'illkvendi: ljós húðlitur',
    '🦹🏼‍♀' => 'illkvendi: meðalljós húðlitur',
    '🦹🏽‍♀' => 'illkvendi: millihúðlitur',
    '🦹🏾‍♀' => 'illkvendi: meðaldökkur húðlitur',
    '🦹🏿‍♀' => 'illkvendi: dökkur húðlitur',
    '🧙🏻‍♂' => 'galdrakarl: ljós húðlitur',
    '🧙🏼‍♂' => 'galdrakarl: meðalljós húðlitur',
    '🧙🏽‍♂' => 'galdrakarl: millihúðlitur',
    '🧙🏾‍♂' => 'galdrakarl: meðaldökkur húðlitur',
    '🧙🏿‍♂' => 'galdrakarl: dökkur húðlitur',
    '🧙🏻‍♀' => 'galdrakona: ljós húðlitur',
    '🧙🏼‍♀' => 'galdrakona: meðalljós húðlitur',
    '🧙🏽‍♀' => 'galdrakona: millihúðlitur',
    '🧙🏾‍♀' => 'galdrakona: meðaldökkur húðlitur',
    '🧙🏿‍♀' => 'galdrakona: dökkur húðlitur',
    '🧚🏻‍♂' => 'álfakarl: ljós húðlitur',
    '🧚🏼‍♂' => 'álfakarl: meðalljós húðlitur',
    '🧚🏽‍♂' => 'álfakarl: millihúðlitur',
    '🧚🏾‍♂' => 'álfakarl: meðaldökkur húðlitur',
    '🧚🏿‍♂' => 'álfakarl: dökkur húðlitur',
    '🧚🏻‍♀' => 'álfadís: ljós húðlitur',
    '🧚🏼‍♀' => 'álfadís: meðalljós húðlitur',
    '🧚🏽‍♀' => 'álfadís: millihúðlitur',
    '🧚🏾‍♀' => 'álfadís: meðaldökkur húðlitur',
    '🧚🏿‍♀' => 'álfadís: dökkur húðlitur',
    '🧛🏻‍♂' => 'karlkyns vampíra: ljós húðlitur',
    '🧛🏼‍♂' => 'karlkyns vampíra: meðalljós húðlitur',
    '🧛🏽‍♂' => 'karlkyns vampíra: millihúðlitur',
    '🧛🏾‍♂' => 'karlkyns vampíra: meðaldökkur húðlitur',
    '🧛🏿‍♂' => 'karlkyns vampíra: dökkur húðlitur',
    '🧛🏻‍♀' => 'kvenkyns vampíra: ljós húðlitur',
    '🧛🏼‍♀' => 'kvenkyns vampíra: meðalljós húðlitur',
    '🧛🏽‍♀' => 'kvenkyns vampíra: millihúðlitur',
    '🧛🏾‍♀' => 'kvenkyns vampíra: meðaldökkur húðlitur',
    '🧛🏿‍♀' => 'kvenkyns vampíra: dökkur húðlitur',
    '🧜🏻‍♂' => 'marbendill: ljós húðlitur',
    '🧜🏼‍♂' => 'marbendill: meðalljós húðlitur',
    '🧜🏽‍♂' => 'marbendill: millihúðlitur',
    '🧜🏾‍♂' => 'marbendill: meðaldökkur húðlitur',
    '🧜🏿‍♂' => 'marbendill: dökkur húðlitur',
    '🧜🏻‍♀' => 'hafmeyja: ljós húðlitur',
    '🧜🏼‍♀' => 'hafmeyja: meðalljós húðlitur',
    '🧜🏽‍♀' => 'hafmeyja: millihúðlitur',
    '🧜🏾‍♀' => 'hafmeyja: meðaldökkur húðlitur',
    '🧜🏿‍♀' => 'hafmeyja: dökkur húðlitur',
    '🧝🏻‍♂' => 'huldukarl: ljós húðlitur',
    '🧝🏼‍♂' => 'huldukarl: meðalljós húðlitur',
    '🧝🏽‍♂' => 'huldukarl: millihúðlitur',
    '🧝🏾‍♂' => 'huldukarl: meðaldökkur húðlitur',
    '🧝🏿‍♂' => 'huldukarl: dökkur húðlitur',
    '🧝🏻‍♀' => 'huldukona: ljós húðlitur',
    '🧝🏼‍♀' => 'huldukona: meðalljós húðlitur',
    '🧝🏽‍♀' => 'huldukona: millihúðlitur',
    '🧝🏾‍♀' => 'huldukona: meðaldökkur húðlitur',
    '🧝🏿‍♀' => 'huldukona: dökkur húðlitur',
    '💆🏻‍♂' => 'maður fær andlitsnudd: ljós húðlitur',
    '💆🏼‍♂' => 'maður fær andlitsnudd: meðalljós húðlitur',
    '💆🏽‍♂' => 'maður fær andlitsnudd: millihúðlitur',
    '💆🏾‍♂' => 'maður fær andlitsnudd: meðaldökkur húðlitur',
    '💆🏿‍♂' => 'maður fær andlitsnudd: dökkur húðlitur',
    '💆🏻‍♀' => 'kona fær andlitsnudd: ljós húðlitur',
    '💆🏼‍♀' => 'kona fær andlitsnudd: meðalljós húðlitur',
    '💆🏽‍♀' => 'kona fær andlitsnudd: millihúðlitur',
    '💆🏾‍♀' => 'kona fær andlitsnudd: meðaldökkur húðlitur',
    '💆🏿‍♀' => 'kona fær andlitsnudd: dökkur húðlitur',
    '💇🏻‍♂' => 'maður í klippingu: ljós húðlitur',
    '💇🏼‍♂' => 'maður í klippingu: meðalljós húðlitur',
    '💇🏽‍♂' => 'maður í klippingu: millihúðlitur',
    '💇🏾‍♂' => 'maður í klippingu: meðaldökkur húðlitur',
    '💇🏿‍♂' => 'maður í klippingu: dökkur húðlitur',
    '💇🏻‍♀' => 'kona í klippingu: ljós húðlitur',
    '💇🏼‍♀' => 'kona í klippingu: meðalljós húðlitur',
    '💇🏽‍♀' => 'kona í klippingu: millihúðlitur',
    '💇🏾‍♀' => 'kona í klippingu: meðaldökkur húðlitur',
    '💇🏿‍♀' => 'kona í klippingu: dökkur húðlitur',
    '🚶🏻‍♂' => 'gangandi maður: ljós húðlitur',
    '🚶🏼‍♂' => 'gangandi maður: meðalljós húðlitur',
    '🚶🏽‍♂' => 'gangandi maður: millihúðlitur',
    '🚶🏾‍♂' => 'gangandi maður: meðaldökkur húðlitur',
    '🚶🏿‍♂' => 'gangandi maður: dökkur húðlitur',
    '🚶🏻‍♀' => 'gangandi kona: ljós húðlitur',
    '🚶🏼‍♀' => 'gangandi kona: meðalljós húðlitur',
    '🚶🏽‍♀' => 'gangandi kona: millihúðlitur',
    '🚶🏾‍♀' => 'gangandi kona: meðaldökkur húðlitur',
    '🚶🏿‍♀' => 'gangandi kona: dökkur húðlitur',
    '🚶🏻‍➡' => 'vegfarandi: ljós húðlitur og snýr til hægri',
    '🚶🏼‍➡' => 'vegfarandi: meðalljós húðlitur og snýr til hægri',
    '🚶🏽‍➡' => 'vegfarandi: millihúðlitur og snýr til hægri',
    '🚶🏾‍➡' => 'vegfarandi: meðaldökkur húðlitur og snýr til hægri',
    '🚶🏿‍➡' => 'vegfarandi: dökkur húðlitur og snýr til hægri',
    '🧍🏻‍♂' => 'standandi maður: ljós húðlitur',
    '🧍🏼‍♂' => 'standandi maður: meðalljós húðlitur',
    '🧍🏽‍♂' => 'standandi maður: millihúðlitur',
    '🧍🏾‍♂' => 'standandi maður: meðaldökkur húðlitur',
    '🧍🏿‍♂' => 'standandi maður: dökkur húðlitur',
    '🧍🏻‍♀' => 'standandi kona: ljós húðlitur',
    '🧍🏼‍♀' => 'standandi kona: meðalljós húðlitur',
    '🧍🏽‍♀' => 'standandi kona: millihúðlitur',
    '🧍🏾‍♀' => 'standandi kona: meðaldökkur húðlitur',
    '🧍🏿‍♀' => 'standandi kona: dökkur húðlitur',
    '🧎🏻‍♂' => 'krjúpandi maður: ljós húðlitur',
    '🧎🏼‍♂' => 'krjúpandi maður: meðalljós húðlitur',
    '🧎🏽‍♂' => 'krjúpandi maður: millihúðlitur',
    '🧎🏾‍♂' => 'krjúpandi maður: meðaldökkur húðlitur',
    '🧎🏿‍♂' => 'krjúpandi maður: dökkur húðlitur',
    '🧎🏻‍♀' => 'krjúpandi kona: ljós húðlitur',
    '🧎🏼‍♀' => 'krjúpandi kona: meðalljós húðlitur',
    '🧎🏽‍♀' => 'krjúpandi kona: millihúðlitur',
    '🧎🏾‍♀' => 'krjúpandi kona: meðaldökkur húðlitur',
    '🧎🏿‍♀' => 'krjúpandi kona: dökkur húðlitur',
    '🧎🏻‍➡' => 'krjúpandi manneskja: ljós húðlitur og snýr til hægri',
    '🧎🏼‍➡' => 'krjúpandi manneskja: meðalljós húðlitur og snýr til hægri',
    '🧎🏽‍➡' => 'krjúpandi manneskja: millihúðlitur og snýr til hægri',
    '🧎🏾‍➡' => 'krjúpandi manneskja: meðaldökkur húðlitur og snýr til hægri',
    '🧎🏿‍➡' => 'krjúpandi manneskja: dökkur húðlitur og snýr til hægri',
    '🧑🏻‍🦯' => 'manneskja með blindrastaf: ljós húðlitur',
    '🧑🏼‍🦯' => 'manneskja með blindrastaf: meðalljós húðlitur',
    '🧑🏽‍🦯' => 'manneskja með blindrastaf: millihúðlitur',
    '🧑🏾‍🦯' => 'manneskja með blindrastaf: meðaldökkur húðlitur',
    '🧑🏿‍🦯' => 'manneskja með blindrastaf: dökkur húðlitur',
    '👨🏻‍🦯' => 'maður með blindrastaf: ljós húðlitur',
    '👨🏼‍🦯' => 'maður með blindrastaf: meðalljós húðlitur',
    '👨🏽‍🦯' => 'maður með blindrastaf: millihúðlitur',
    '👨🏾‍🦯' => 'maður með blindrastaf: meðaldökkur húðlitur',
    '👨🏿‍🦯' => 'maður með blindrastaf: dökkur húðlitur',
    '👩🏻‍🦯' => 'kona með blindrastaf: ljós húðlitur',
    '👩🏼‍🦯' => 'kona með blindrastaf: meðalljós húðlitur',
    '👩🏽‍🦯' => 'kona með blindrastaf: millihúðlitur',
    '👩🏾‍🦯' => 'kona með blindrastaf: meðaldökkur húðlitur',
    '👩🏿‍🦯' => 'kona með blindrastaf: dökkur húðlitur',
    '🧑🏻‍🦼' => 'manneskja í vélknúnum hjólastól: ljós húðlitur',
    '🧑🏼‍🦼' => 'manneskja í vélknúnum hjólastól: meðalljós húðlitur',
    '🧑🏽‍🦼' => 'manneskja í vélknúnum hjólastól: millihúðlitur',
    '🧑🏾‍🦼' => 'manneskja í vélknúnum hjólastól: meðaldökkur húðlitur',
    '🧑🏿‍🦼' => 'manneskja í vélknúnum hjólastól: dökkur húðlitur',
    '👨🏻‍🦼' => 'maður í vélknúnum hjólastól: ljós húðlitur',
    '👨🏼‍🦼' => 'maður í vélknúnum hjólastól: meðalljós húðlitur',
    '👨🏽‍🦼' => 'maður í vélknúnum hjólastól: millihúðlitur',
    '👨🏾‍🦼' => 'maður í vélknúnum hjólastól: meðaldökkur húðlitur',
    '👨🏿‍🦼' => 'maður í vélknúnum hjólastól: dökkur húðlitur',
    '👩🏻‍🦼' => 'kona í vélknúnum hjólastól: ljós húðlitur',
    '👩🏼‍🦼' => 'kona í vélknúnum hjólastól: meðalljós húðlitur',
    '👩🏽‍🦼' => 'kona í vélknúnum hjólastól: millihúðlitur',
    '👩🏾‍🦼' => 'kona í vélknúnum hjólastól: meðaldökkur húðlitur',
    '👩🏿‍🦼' => 'kona í vélknúnum hjólastól: dökkur húðlitur',
    '🧑🏻‍🦽' => 'manneskja í hjólastól: ljós húðlitur',
    '🧑🏼‍🦽' => 'manneskja í hjólastól: meðalljós húðlitur',
    '🧑🏽‍🦽' => 'manneskja í hjólastól: millihúðlitur',
    '🧑🏾‍🦽' => 'manneskja í hjólastól: meðaldökkur húðlitur',
    '🧑🏿‍🦽' => 'manneskja í hjólastól: dökkur húðlitur',
    '👨🏻‍🦽' => 'maður í hjólastól: ljós húðlitur',
    '👨🏼‍🦽' => 'maður í hjólastól: meðalljós húðlitur',
    '👨🏽‍🦽' => 'maður í hjólastól: millihúðlitur',
    '👨🏾‍🦽' => 'maður í hjólastól: meðaldökkur húðlitur',
    '👨🏿‍🦽' => 'maður í hjólastól: dökkur húðlitur',
    '👩🏻‍🦽' => 'kona í hjólastól: ljós húðlitur',
    '👩🏼‍🦽' => 'kona í hjólastól: meðalljós húðlitur',
    '👩🏽‍🦽' => 'kona í hjólastól: millihúðlitur',
    '👩🏾‍🦽' => 'kona í hjólastól: meðaldökkur húðlitur',
    '👩🏿‍🦽' => 'kona í hjólastól: dökkur húðlitur',
    '🏃🏻‍♂' => 'hlaupandi maður: ljós húðlitur',
    '🏃🏼‍♂' => 'hlaupandi maður: meðalljós húðlitur',
    '🏃🏽‍♂' => 'hlaupandi maður: millihúðlitur',
    '🏃🏾‍♂' => 'hlaupandi maður: meðaldökkur húðlitur',
    '🏃🏿‍♂' => 'hlaupandi maður: dökkur húðlitur',
    '🏃🏻‍♀' => 'hlaupandi kona: ljós húðlitur',
    '🏃🏼‍♀' => 'hlaupandi kona: meðalljós húðlitur',
    '🏃🏽‍♀' => 'hlaupandi kona: millihúðlitur',
    '🏃🏾‍♀' => 'hlaupandi kona: meðaldökkur húðlitur',
    '🏃🏿‍♀' => 'hlaupandi kona: dökkur húðlitur',
    '🏃🏻‍➡' => 'hlaupari: ljós húðlitur og snýr til hægri',
    '🏃🏼‍➡' => 'hlaupari: meðalljós húðlitur og snýr til hægri',
    '🏃🏽‍➡' => 'hlaupari: millihúðlitur og snýr til hægri',
    '🏃🏾‍➡' => 'hlaupari: meðaldökkur húðlitur og snýr til hægri',
    '🏃🏿‍➡' => 'hlaupari: dökkur húðlitur og snýr til hægri',
    '👯🏻‍♀' => 'konur með kanínueyru: ljós húðlitur',
    '👯🏼‍♀' => 'konur með kanínueyru: meðalljós húðlitur',
    '👯🏽‍♀' => 'konur með kanínueyru: millihúðlitur',
    '👯🏾‍♀' => 'konur með kanínueyru: meðaldökkur húðlitur',
    '👯🏿‍♀' => 'konur með kanínueyru: dökkur húðlitur',
    '👯🏻‍♂' => 'menn með kanínueyru: ljós húðlitur',
    '👯🏼‍♂' => 'menn með kanínueyru: meðalljós húðlitur',
    '👯🏽‍♂' => 'menn með kanínueyru: millihúðlitur',
    '👯🏾‍♂' => 'menn með kanínueyru: meðaldökkur húðlitur',
    '👯🏿‍♂' => 'menn með kanínueyru: dökkur húðlitur',
    '🧖🏻‍♂' => 'maður í gufubaði: ljós húðlitur',
    '🧖🏼‍♂' => 'maður í gufubaði: meðalljós húðlitur',
    '🧖🏽‍♂' => 'maður í gufubaði: millihúðlitur',
    '🧖🏾‍♂' => 'maður í gufubaði: meðaldökkur húðlitur',
    '🧖🏿‍♂' => 'maður í gufubaði: dökkur húðlitur',
    '🧖🏻‍♀' => 'kona í gufubaði: ljós húðlitur',
    '🧖🏼‍♀' => 'kona í gufubaði: meðalljós húðlitur',
    '🧖🏽‍♀' => 'kona í gufubaði: millihúðlitur',
    '🧖🏾‍♀' => 'kona í gufubaði: meðaldökkur húðlitur',
    '🧖🏿‍♀' => 'kona í gufubaði: dökkur húðlitur',
    '🧗🏻‍♂' => 'karl í klettaklifri: ljós húðlitur',
    '🧗🏼‍♂' => 'karl í klettaklifri: meðalljós húðlitur',
    '🧗🏽‍♂' => 'karl í klettaklifri: millihúðlitur',
    '🧗🏾‍♂' => 'karl í klettaklifri: meðaldökkur húðlitur',
    '🧗🏿‍♂' => 'karl í klettaklifri: dökkur húðlitur',
    '🧗🏻‍♀' => 'kona í klettaklifri: ljós húðlitur',
    '🧗🏼‍♀' => 'kona í klettaklifri: meðalljós húðlitur',
    '🧗🏽‍♀' => 'kona í klettaklifri: millihúðlitur',
    '🧗🏾‍♀' => 'kona í klettaklifri: meðaldökkur húðlitur',
    '🧗🏿‍♀' => 'kona í klettaklifri: dökkur húðlitur',
    '🏌🏻‍♂' => 'maður í golfi: ljós húðlitur',
    '🏌🏼‍♂' => 'maður í golfi: meðalljós húðlitur',
    '🏌🏽‍♂' => 'maður í golfi: millihúðlitur',
    '🏌🏾‍♂' => 'maður í golfi: meðaldökkur húðlitur',
    '🏌🏿‍♂' => 'maður í golfi: dökkur húðlitur',
    '🏌🏻‍♀' => 'kona í golfi: ljós húðlitur',
    '🏌🏼‍♀' => 'kona í golfi: meðalljós húðlitur',
    '🏌🏽‍♀' => 'kona í golfi: millihúðlitur',
    '🏌🏾‍♀' => 'kona í golfi: meðaldökkur húðlitur',
    '🏌🏿‍♀' => 'kona í golfi: dökkur húðlitur',
    '🏄🏻‍♂' => 'maður á brimbretti: ljós húðlitur',
    '🏄🏼‍♂' => 'maður á brimbretti: meðalljós húðlitur',
    '🏄🏽‍♂' => 'maður á brimbretti: millihúðlitur',
    '🏄🏾‍♂' => 'maður á brimbretti: meðaldökkur húðlitur',
    '🏄🏿‍♂' => 'maður á brimbretti: dökkur húðlitur',
    '🏄🏻‍♀' => 'kona á brimbretti: ljós húðlitur',
    '🏄🏼‍♀' => 'kona á brimbretti: meðalljós húðlitur',
    '🏄🏽‍♀' => 'kona á brimbretti: millihúðlitur',
    '🏄🏾‍♀' => 'kona á brimbretti: meðaldökkur húðlitur',
    '🏄🏿‍♀' => 'kona á brimbretti: dökkur húðlitur',
    '🚣🏻‍♂' => 'maður á árabát: ljós húðlitur',
    '🚣🏼‍♂' => 'maður á árabát: meðalljós húðlitur',
    '🚣🏽‍♂' => 'maður á árabát: millihúðlitur',
    '🚣🏾‍♂' => 'maður á árabát: meðaldökkur húðlitur',
    '🚣🏿‍♂' => 'maður á árabát: dökkur húðlitur',
    '🚣🏻‍♀' => 'kona á árabát: ljós húðlitur',
    '🚣🏼‍♀' => 'kona á árabát: meðalljós húðlitur',
    '🚣🏽‍♀' => 'kona á árabát: millihúðlitur',
    '🚣🏾‍♀' => 'kona á árabát: meðaldökkur húðlitur',
    '🚣🏿‍♀' => 'kona á árabát: dökkur húðlitur',
    '🏊🏻‍♂' => 'sundmaður: ljós húðlitur',
    '🏊🏼‍♂' => 'sundmaður: meðalljós húðlitur',
    '🏊🏽‍♂' => 'sundmaður: millihúðlitur',
    '🏊🏾‍♂' => 'sundmaður: meðaldökkur húðlitur',
    '🏊🏿‍♂' => 'sundmaður: dökkur húðlitur',
    '🏊🏻‍♀' => 'sundkona: ljós húðlitur',
    '🏊🏼‍♀' => 'sundkona: meðalljós húðlitur',
    '🏊🏽‍♀' => 'sundkona: millihúðlitur',
    '🏊🏾‍♀' => 'sundkona: meðaldökkur húðlitur',
    '🏊🏿‍♀' => 'sundkona: dökkur húðlitur',
    '⛹🏻‍♂' => 'maður með bolta: ljós húðlitur',
    '⛹🏼‍♂' => 'maður með bolta: meðalljós húðlitur',
    '⛹🏽‍♂' => 'maður með bolta: millihúðlitur',
    '⛹🏾‍♂' => 'maður með bolta: meðaldökkur húðlitur',
    '⛹🏿‍♂' => 'maður með bolta: dökkur húðlitur',
    '⛹🏻‍♀' => 'kona með bolta: ljós húðlitur',
    '⛹🏼‍♀' => 'kona með bolta: meðalljós húðlitur',
    '⛹🏽‍♀' => 'kona með bolta: millihúðlitur',
    '⛹🏾‍♀' => 'kona með bolta: meðaldökkur húðlitur',
    '⛹🏿‍♀' => 'kona með bolta: dökkur húðlitur',
    '🏋🏻‍♂' => 'maður í kraftlyftingum: ljós húðlitur',
    '🏋🏼‍♂' => 'maður í kraftlyftingum: meðalljós húðlitur',
    '🏋🏽‍♂' => 'maður í kraftlyftingum: millihúðlitur',
    '🏋🏾‍♂' => 'maður í kraftlyftingum: meðaldökkur húðlitur',
    '🏋🏿‍♂' => 'maður í kraftlyftingum: dökkur húðlitur',
    '🏋🏻‍♀' => 'kona í kraftlyftingum: ljós húðlitur',
    '🏋🏼‍♀' => 'kona í kraftlyftingum: meðalljós húðlitur',
    '🏋🏽‍♀' => 'kona í kraftlyftingum: millihúðlitur',
    '🏋🏾‍♀' => 'kona í kraftlyftingum: meðaldökkur húðlitur',
    '🏋🏿‍♀' => 'kona í kraftlyftingum: dökkur húðlitur',
    '🚴🏻‍♂' => 'maður á hjóli: ljós húðlitur',
    '🚴🏼‍♂' => 'maður á hjóli: meðalljós húðlitur',
    '🚴🏽‍♂' => 'maður á hjóli: millihúðlitur',
    '🚴🏾‍♂' => 'maður á hjóli: meðaldökkur húðlitur',
    '🚴🏿‍♂' => 'maður á hjóli: dökkur húðlitur',
    '🚴🏻‍♀' => 'kona á hjóli: ljós húðlitur',
    '🚴🏼‍♀' => 'kona á hjóli: meðalljós húðlitur',
    '🚴🏽‍♀' => 'kona á hjóli: millihúðlitur',
    '🚴🏾‍♀' => 'kona á hjóli: meðaldökkur húðlitur',
    '🚴🏿‍♀' => 'kona á hjóli: dökkur húðlitur',
    '🚵🏻‍♂' => 'maður á fjallahjóli: ljós húðlitur',
    '🚵🏼‍♂' => 'maður á fjallahjóli: meðalljós húðlitur',
    '🚵🏽‍♂' => 'maður á fjallahjóli: millihúðlitur',
    '🚵🏾‍♂' => 'maður á fjallahjóli: meðaldökkur húðlitur',
    '🚵🏿‍♂' => 'maður á fjallahjóli: dökkur húðlitur',
    '🚵🏻‍♀' => 'kona á fjallahjóli: ljós húðlitur',
    '🚵🏼‍♀' => 'kona á fjallahjóli: meðalljós húðlitur',
    '🚵🏽‍♀' => 'kona á fjallahjóli: millihúðlitur',
    '🚵🏾‍♀' => 'kona á fjallahjóli: meðaldökkur húðlitur',
    '🚵🏿‍♀' => 'kona á fjallahjóli: dökkur húðlitur',
    '🤸🏻‍♂' => 'maður á handahlaupum: ljós húðlitur',
    '🤸🏼‍♂' => 'maður á handahlaupum: meðalljós húðlitur',
    '🤸🏽‍♂' => 'maður á handahlaupum: millihúðlitur',
    '🤸🏾‍♂' => 'maður á handahlaupum: meðaldökkur húðlitur',
    '🤸🏿‍♂' => 'maður á handahlaupum: dökkur húðlitur',
    '🤸🏻‍♀' => 'kona á handahlaupum: ljós húðlitur',
    '🤸🏼‍♀' => 'kona á handahlaupum: meðalljós húðlitur',
    '🤸🏽‍♀' => 'kona á handahlaupum: millihúðlitur',
    '🤸🏾‍♀' => 'kona á handahlaupum: meðaldökkur húðlitur',
    '🤸🏿‍♀' => 'kona á handahlaupum: dökkur húðlitur',
    '🤼🏻‍♀' => 'konur í glímu: ljós húðlitur',
    '🤼🏼‍♀' => 'konur í glímu: meðalljós húðlitur',
    '🤼🏽‍♀' => 'konur í glímu: millihúðlitur',
    '🤼🏾‍♀' => 'konur í glímu: meðaldökkur húðlitur',
    '🤼🏿‍♀' => 'konur í glímu: dökkur húðlitur',
    '🤼🏻‍♂' => 'menn í glímu: ljós húðlitur',
    '🤼🏼‍♂' => 'menn í glímu: meðalljós húðlitur',
    '🤼🏽‍♂' => 'menn í glímu: millihúðlitur',
    '🤼🏾‍♂' => 'menn í glímu: meðaldökkur húðlitur',
    '🤼🏿‍♂' => 'menn í glímu: dökkur húðlitur',
    '🤽🏻‍♂' => 'maður í vatnapóló: ljós húðlitur',
    '🤽🏼‍♂' => 'maður í vatnapóló: meðalljós húðlitur',
    '🤽🏽‍♂' => 'maður í vatnapóló: millihúðlitur',
    '🤽🏾‍♂' => 'maður í vatnapóló: meðaldökkur húðlitur',
    '🤽🏿‍♂' => 'maður í vatnapóló: dökkur húðlitur',
    '🤽🏻‍♀' => 'kona í vatnapóló: ljós húðlitur',
    '🤽🏼‍♀' => 'kona í vatnapóló: meðalljós húðlitur',
    '🤽🏽‍♀' => 'kona í vatnapóló: millihúðlitur',
    '🤽🏾‍♀' => 'kona í vatnapóló: meðaldökkur húðlitur',
    '🤽🏿‍♀' => 'kona í vatnapóló: dökkur húðlitur',
    '🤾🏻‍♂' => 'maður í handbolta: ljós húðlitur',
    '🤾🏼‍♂' => 'maður í handbolta: meðalljós húðlitur',
    '🤾🏽‍♂' => 'maður í handbolta: millihúðlitur',
    '🤾🏾‍♂' => 'maður í handbolta: meðaldökkur húðlitur',
    '🤾🏿‍♂' => 'maður í handbolta: dökkur húðlitur',
    '🤾🏻‍♀' => 'kona í handbolta: ljós húðlitur',
    '🤾🏼‍♀' => 'kona í handbolta: meðalljós húðlitur',
    '🤾🏽‍♀' => 'kona í handbolta: millihúðlitur',
    '🤾🏾‍♀' => 'kona í handbolta: meðaldökkur húðlitur',
    '🤾🏿‍♀' => 'kona í handbolta: dökkur húðlitur',
    '🤹🏻‍♂' => 'maður kastar boltum: ljós húðlitur',
    '🤹🏼‍♂' => 'maður kastar boltum: meðalljós húðlitur',
    '🤹🏽‍♂' => 'maður kastar boltum: millihúðlitur',
    '🤹🏾‍♂' => 'maður kastar boltum: meðaldökkur húðlitur',
    '🤹🏿‍♂' => 'maður kastar boltum: dökkur húðlitur',
    '🤹🏻‍♀' => 'kona kastar boltum: ljós húðlitur',
    '🤹🏼‍♀' => 'kona kastar boltum: meðalljós húðlitur',
    '🤹🏽‍♀' => 'kona kastar boltum: millihúðlitur',
    '🤹🏾‍♀' => 'kona kastar boltum: meðaldökkur húðlitur',
    '🤹🏿‍♀' => 'kona kastar boltum: dökkur húðlitur',
    '🧘🏻‍♂' => 'karl í lótuspósu: ljós húðlitur',
    '🧘🏼‍♂' => 'karl í lótuspósu: meðalljós húðlitur',
    '🧘🏽‍♂' => 'karl í lótuspósu: millihúðlitur',
    '🧘🏾‍♂' => 'karl í lótuspósu: meðaldökkur húðlitur',
    '🧘🏿‍♂' => 'karl í lótuspósu: dökkur húðlitur',
    '🧘🏻‍♀' => 'kona í lótusp´ósu: ljós húðlitur',
    '🧘🏼‍♀' => 'kona í lótusp´ósu: meðalljós húðlitur',
    '🧘🏽‍♀' => 'kona í lótusp´ósu: millihúðlitur',
    '🧘🏾‍♀' => 'kona í lótusp´ósu: meðaldökkur húðlitur',
    '🧘🏿‍♀' => 'kona í lótusp´ósu: dökkur húðlitur',
    '🧑‍🦰' => 'manneskja: rautt hár',
    '🧑‍🦱' => 'manneskja: krullur',
    '🧑‍🦳' => 'manneskja: hvítt hár',
    '🧑‍🦲' => 'manneskja: skalli',
    '👨‍🦰' => 'karl: rautt hár',
    '👨‍🦱' => 'karl: krullur',
    '👨‍🦳' => 'karl: hvítt hár',
    '👨‍🦲' => 'karl: skalli',
    '👩‍🦰' => 'kona: rautt hár',
    '👩‍🦱' => 'kona: krullur',
    '👩‍🦳' => 'kona: hvítt hár',
    '👩‍🦲' => 'kona: skalli',
    '🚶‍➡' => 'vegfarandi: snýr til hægri',
    '🧎‍➡' => 'krjúpandi manneskja: snýr til hægri',
    '🏃‍➡' => 'hlaupari: snýr til hægri',
    '👨‍👦' => 'fjölskylda: karl og drengur',
    '👨‍👧' => 'fjölskylda: karl og stúlka',
    '👩‍👦' => 'fjölskylda: kona og drengur',
    '👩‍👧' => 'fjölskylda: kona og stúlka',
    '😶‍🌫' => 'andlit í skýjum',
    '😮‍💨' => 'andlit að anda frá sér',
    '🙂‍↕' => 'hristir höfuðið lóðrétt',
    '😵‍💫' => 'andlit með gormaugu',
    '❤‍🔥' => 'logandi hjarta',
    '❤‍🩹' => 'hjarta að gróa',
    '👁‍🗨' => 'auga í talblöðru',
    '🧔‍♂' => 'karl: skegg',
    '👱‍♂' => 'ljóshærður maður',
    '🧔‍♀' => 'kona: skegg',
    '👱‍♀' => 'ljóshærð kona',
    '🙍‍♂' => 'maður með skeifu',
    '🙍‍♀' => 'kona með skeifu',
    '🙎‍♂' => 'maður í fýlu',
    '🙎‍♀' => 'kona í fýlu',
    '🙅‍♂' => 'maður segir ekki í lagi',
    '🙅‍♀' => 'kona segir ekki í lagi',
    '🙆‍♂' => 'maður segir allt í lagi',
    '🙆‍♀' => 'kona segir allt í lagi',
    '💁‍♂' => 'maður réttir út lófa',
    '💁‍♀' => 'kona réttir út lófa',
    '🙋‍♂' => 'maður réttir upp hönd',
    '🙋‍♀' => 'kona réttir upp hönd',
    '🧏‍♂' => 'heyrnarlaus karl',
    '🧏‍♀' => 'heyrnarlaus kona',
    '🙇‍♂' => 'maður hneigir sig',
    '🙇‍♀' => 'kona hneigir sig',
    '🤦‍♂' => 'maður með hönd fyrir andlit',
    '🤦‍♀' => 'kona með hönd fyrir andlit',
    '🤷‍♂' => 'maður yppir öxlum',
    '🤷‍♀' => 'kona yppir öxlum',
    '🧑‍⚕' => 'heilbrigðisstarfsmaður',
    '👨‍⚕' => 'karlkyns heilbrigðisstarfsmaður',
    '👩‍⚕' => 'kvenkyns heilbrigðisstarfsmaður',
    '🧑‍🎓' => 'nemi',
    '👨‍🎓' => 'karlkyns námsmaður',
    '👩‍🎓' => 'kvenkyns námsmaður',
    '🧑‍🏫' => 'kennari',
    '👨‍🏫' => 'karlkyns kennari',
    '👩‍🏫' => 'kvenkyns kennari',
    '🧑‍⚖' => 'dómari',
    '👨‍⚖' => 'karlkyns dómari',
    '👩‍⚖' => 'kvenkyns dómari',
    '🧑‍🌾' => 'bóndi',
    '👨‍🌾' => 'karlkyns bóndi',
    '👩‍🌾' => 'kvenkyns bóndi',
    '🧑‍🍳' => 'kokkur',
    '👨‍🍳' => 'karlkyns kokkur',
    '👩‍🍳' => 'kvenkyns kokkur',
    '🧑‍🔧' => 'vélvirki',
    '👨‍🔧' => 'karl með skiptilykil',
    '👩‍🔧' => 'kona með skiptilykil',
    '🧑‍🏭' => 'verksmiðjustarfsmaður',
    '👨‍🏭' => 'karlkyns verksmiðjustarfsmaður',
    '👩‍🏭' => 'kvenkyns verksmiðjustarfsmaður',
    '🧑‍💼' => 'skrifstofustarfsmaður',
    '👨‍💼' => 'karlkyns skrifstofustarfsmaður',
    '👩‍💼' => 'kvenkyns skrifstofustarfsmaður',
    '🧑‍🔬' => 'vísindafræðingur',
    '👨‍🔬' => 'vísindamaður',
    '👩‍🔬' => 'vísindakona',
    '🧑‍💻' => 'forritari',
    '👨‍💻' => 'karlkyns forritari',
    '👩‍💻' => 'kvenkyns forritari',
    '🧑‍🎤' => 'söngfugl',
    '👨‍🎤' => 'söngvari',
    '👩‍🎤' => 'söngkona',
    '🧑‍🎨' => 'listmálari',
    '👨‍🎨' => 'karlkyns listamaður',
    '👩‍🎨' => 'listakona',
    '🧑‍✈' => 'flugstjóri',
    '👨‍✈' => 'karlkyns flugstjóri',
    '👩‍✈' => 'kvenkyns flugstjóri',
    '🧑‍🚀' => 'geimfari',
    '👨‍🚀' => 'karlkyns geimfari',
    '👩‍🚀' => 'kvenkyns geimfari',
    '🧑‍🚒' => 'brunaliðsmaður',
    '👨‍🚒' => 'slökkviliðsmaður',
    '👩‍🚒' => 'slökkviliðskona',
    '👮‍♂' => 'karlkyns lögregluþjónn',
    '👮‍♀' => 'kvenkyns lögregluþjónn',
    '🕵‍♂' => 'karlkyns spæjari',
    '🕵‍♀' => 'kvenkyns spæjari',
    '💂‍♂' => 'karlkyns vörður',
    '💂‍♀' => 'kvenkyns vörður',
    '👷‍♂' => 'karlkyns byggingarstarfsmaður',
    '👷‍♀' => 'kvenkyns byggingarstarfsmaður',
    '👳‍♂' => 'karl með túrban',
    '👳‍♀' => 'kona með túrban',
    '🤵‍♂' => 'karl í smóking',
    '🤵‍♀' => 'kona í smóking',
    '👰‍♂' => 'karl með slör',
    '👰‍♀' => 'kona með slör',
    '👩‍🍼' => 'kona að gefa barni',
    '👨‍🍼' => 'karl að gefa barni',
    '🧑‍🍼' => 'manneskja að gefa barni',
    '🧑‍🎄' => 'frú sveinki',
    '🦸‍♂' => 'ofurmaður',
    '🦸‍♀' => 'ofurkona',
    '🦹‍♂' => 'illmenni',
    '🦹‍♀' => 'illkvendi',
    '🧙‍♂' => 'galdrakarl',
    '🧙‍♀' => 'galdrakona',
    '🧚‍♂' => 'álfakarl',
    '🧚‍♀' => 'álfadís',
    '🧛‍♂' => 'karlkyns vampíra',
    '🧛‍♀' => 'kvenkyns vampíra',
    '🧜‍♂' => 'marbendill',
    '🧜‍♀' => 'hafmeyja',
    '🧝‍♂' => 'huldukarl',
    '🧝‍♀' => 'huldukona',
    '🧞‍♂' => 'karlkyns andi',
    '🧞‍♀' => 'kvenkyns andi',
    '🧟‍♂' => 'karlkyns uppvakningur',
    '🧟‍♀' => 'kvenkyns uppvakningur',
    '💆‍♂' => 'maður fær andlitsnudd',
    '💆‍♀' => 'kona fær andlitsnudd',
    '💇‍♂' => 'maður í klippingu',
    '💇‍♀' => 'kona í klippingu',
    '🚶‍♂' => 'gangandi maður',
    '🚶‍♀' => 'gangandi kona',
    '🧍‍♂' => 'standandi maður',
    '🧍‍♀' => 'standandi kona',
    '🧎‍♂' => 'krjúpandi maður',
    '🧎‍♀' => 'krjúpandi kona',
    '🧑‍🦯' => 'manneskja með blindrastaf',
    '👨‍🦯' => 'maður með blindrastaf',
    '👩‍🦯' => 'kona með blindrastaf',
    '🧑‍🦼' => 'manneskja í vélknúnum hjólastól',
    '👨‍🦼' => 'maður í vélknúnum hjólastól',
    '👩‍🦼' => 'kona í vélknúnum hjólastól',
    '🧑‍🦽' => 'manneskja í hjólastól',
    '👨‍🦽' => 'maður í hjólastól',
    '👩‍🦽' => 'kona í hjólastól',
    '🏃‍♂' => 'hlaupandi maður',
    '🏃‍♀' => 'hlaupandi kona',
    '🧑‍🩰' => 'ballettdansari',
    '👯‍♂' => 'menn með kanínueyru',
    '👯‍♀' => 'konur með kanínueyru',
    '🧖‍♂' => 'maður í gufubaði',
    '🧖‍♀' => 'kona í gufubaði',
    '🧗‍♂' => 'karl í klettaklifri',
    '🧗‍♀' => 'kona í klettaklifri',
    '🏌‍♂' => 'maður í golfi',
    '🏌‍♀' => 'kona í golfi',
    '🏄‍♂' => 'maður á brimbretti',
    '🏄‍♀' => 'kona á brimbretti',
    '🚣‍♂' => 'maður á árabát',
    '🚣‍♀' => 'kona á árabát',
    '🏊‍♂' => 'sundmaður',
    '🏊‍♀' => 'sundkona',
    '⛹‍♂' => 'maður með bolta',
    '⛹‍♀' => 'kona með bolta',
    '🏋‍♂' => 'maður í kraftlyftingum',
    '🏋‍♀' => 'kona í kraftlyftingum',
    '🚴‍♂' => 'maður á hjóli',
    '🚴‍♀' => 'kona á hjóli',
    '🚵‍♂' => 'maður á fjallahjóli',
    '🚵‍♀' => 'kona á fjallahjóli',
    '🤸‍♂' => 'maður á handahlaupum',
    '🤸‍♀' => 'kona á handahlaupum',
    '🤼‍♂' => 'menn í glímu',
    '🤼‍♀' => 'konur í glímu',
    '🤽‍♂' => 'maður í vatnapóló',
    '🤽‍♀' => 'kona í vatnapóló',
    '🤾‍♂' => 'maður í handbolta',
    '🤾‍♀' => 'kona í handbolta',
    '🤹‍♂' => 'maður kastar boltum',
    '🤹‍♀' => 'kona kastar boltum',
    '🧘‍♂' => 'karl í lótuspósu',
    '🧘‍♀' => 'kona í lótusp´ósu',
    '🧑‍🧒' => 'fjölskylda: fullorðinn, barn',
    '🐕‍🦺' => 'þjónustuhundur',
    '🐈‍⬛' => 'svartur köttur',
    '🐻‍❄' => 'ísbjörn',
    '🐦‍⬛' => 'svartur fugl',
    '🐦‍🔥' => 'fönix',
    '🍋‍🟩' => 'límóna',
    '🍄‍🟫' => 'brúnn sveppur',
    '⛓‍💥' => 'slitin keðja',
    '🏳‍🌈' => 'regnbogafáni',
    '🏳‍⚧' => 'transfáni',
    '🏴‍☠' => 'sjóræningjafáni',
    '👋🏻' => 'hönd veifar: ljós húðlitur',
    '👋🏼' => 'hönd veifar: meðalljós húðlitur',
    '👋🏽' => 'hönd veifar: millihúðlitur',
    '👋🏾' => 'hönd veifar: meðaldökkur húðlitur',
    '👋🏿' => 'hönd veifar: dökkur húðlitur',
    '🤚🏻' => 'upprétt hönd: ljós húðlitur',
    '🤚🏼' => 'upprétt hönd: meðalljós húðlitur',
    '🤚🏽' => 'upprétt hönd: millihúðlitur',
    '🤚🏾' => 'upprétt hönd: meðaldökkur húðlitur',
    '🤚🏿' => 'upprétt hönd: dökkur húðlitur',
    '🖐🏻' => 'upprétt hönd með glennta fingur: ljós húðlitur',
    '🖐🏼' => 'upprétt hönd með glennta fingur: meðalljós húðlitur',
    '🖐🏽' => 'upprétt hönd með glennta fingur: millihúðlitur',
    '🖐🏾' => 'upprétt hönd með glennta fingur: meðaldökkur húðlitur',
    '🖐🏿' => 'upprétt hönd með glennta fingur: dökkur húðlitur',
    '✋🏻' => 'lófi: ljós húðlitur',
    '✋🏼' => 'lófi: meðalljós húðlitur',
    '✋🏽' => 'lófi: millihúðlitur',
    '✋🏾' => 'lófi: meðaldökkur húðlitur',
    '✋🏿' => 'lófi: dökkur húðlitur',
    '🖖🏻' => 'vulcan-kveðja: ljós húðlitur',
    '🖖🏼' => 'vulcan-kveðja: meðalljós húðlitur',
    '🖖🏽' => 'vulcan-kveðja: millihúðlitur',
    '🖖🏾' => 'vulcan-kveðja: meðaldökkur húðlitur',
    '🖖🏿' => 'vulcan-kveðja: dökkur húðlitur',
    '🫱🏻' => 'hendi hægra megin: ljós húðlitur',
    '🫱🏼' => 'hendi hægra megin: meðalljós húðlitur',
    '🫱🏽' => 'hendi hægra megin: millihúðlitur',
    '🫱🏾' => 'hendi hægra megin: meðaldökkur húðlitur',
    '🫱🏿' => 'hendi hægra megin: dökkur húðlitur',
    '🫲🏻' => 'hendi vinstra megin: ljós húðlitur',
    '🫲🏼' => 'hendi vinstra megin: meðalljós húðlitur',
    '🫲🏽' => 'hendi vinstra megin: millihúðlitur',
    '🫲🏾' => 'hendi vinstra megin: meðaldökkur húðlitur',
    '🫲🏿' => 'hendi vinstra megin: dökkur húðlitur',
    '🫳🏻' => 'hendi með lófa niður: ljós húðlitur',
    '🫳🏼' => 'hendi með lófa niður: meðalljós húðlitur',
    '🫳🏽' => 'hendi með lófa niður: millihúðlitur',
    '🫳🏾' => 'hendi með lófa niður: meðaldökkur húðlitur',
    '🫳🏿' => 'hendi með lófa niður: dökkur húðlitur',
    '🫴🏻' => 'hendi með lófa upp: ljós húðlitur',
    '🫴🏼' => 'hendi með lófa upp: meðalljós húðlitur',
    '🫴🏽' => 'hendi með lófa upp: millihúðlitur',
    '🫴🏾' => 'hendi með lófa upp: meðaldökkur húðlitur',
    '🫴🏿' => 'hendi með lófa upp: dökkur húðlitur',
    '🫷🏻' => 'hönd ýtt til vinstri: ljós húðlitur',
    '🫷🏼' => 'hönd ýtt til vinstri: meðalljós húðlitur',
    '🫷🏽' => 'hönd ýtt til vinstri: millihúðlitur',
    '🫷🏾' => 'hönd ýtt til vinstri: meðaldökkur húðlitur',
    '🫷🏿' => 'hönd ýtt til vinstri: dökkur húðlitur',
    '🫸🏻' => 'hönd ýtt til hægri: ljós húðlitur',
    '🫸🏼' => 'hönd ýtt til hægri: meðalljós húðlitur',
    '🫸🏽' => 'hönd ýtt til hægri: millihúðlitur',
    '🫸🏾' => 'hönd ýtt til hægri: meðaldökkur húðlitur',
    '🫸🏿' => 'hönd ýtt til hægri: dökkur húðlitur',
    '👌🏻' => 'Í lagi: ljós húðlitur',
    '👌🏼' => 'Í lagi: meðalljós húðlitur',
    '👌🏽' => 'Í lagi: millihúðlitur',
    '👌🏾' => 'Í lagi: meðaldökkur húðlitur',
    '👌🏿' => 'Í lagi: dökkur húðlitur',
    '🤌🏻' => 'klípandi fingur: ljós húðlitur',
    '🤌🏼' => 'klípandi fingur: meðalljós húðlitur',
    '🤌🏽' => 'klípandi fingur: millihúðlitur',
    '🤌🏾' => 'klípandi fingur: meðaldökkur húðlitur',
    '🤌🏿' => 'klípandi fingur: dökkur húðlitur',
    '🤏🏻' => 'klípandi hönd: ljós húðlitur',
    '🤏🏼' => 'klípandi hönd: meðalljós húðlitur',
    '🤏🏽' => 'klípandi hönd: millihúðlitur',
    '🤏🏾' => 'klípandi hönd: meðaldökkur húðlitur',
    '🤏🏿' => 'klípandi hönd: dökkur húðlitur',
    '✌🏻' => 'friðarmerki: ljós húðlitur',
    '✌🏼' => 'friðarmerki: meðalljós húðlitur',
    '✌🏽' => 'friðarmerki: millihúðlitur',
    '✌🏾' => 'friðarmerki: meðaldökkur húðlitur',
    '✌🏿' => 'friðarmerki: dökkur húðlitur',
    '🤞🏻' => 'krosslagðir fingur: ljós húðlitur',
    '🤞🏼' => 'krosslagðir fingur: meðalljós húðlitur',
    '🤞🏽' => 'krosslagðir fingur: millihúðlitur',
    '🤞🏾' => 'krosslagðir fingur: meðaldökkur húðlitur',
    '🤞🏿' => 'krosslagðir fingur: dökkur húðlitur',
    '🫰🏻' => 'hendi með vísifingur og þumal í kross: ljós húðlitur',
    '🫰🏼' => 'hendi með vísifingur og þumal í kross: meðalljós húðlitur',
    '🫰🏽' => 'hendi með vísifingur og þumal í kross: millihúðlitur',
    '🫰🏾' => 'hendi með vísifingur og þumal í kross: meðaldökkur húðlitur',
    '🫰🏿' => 'hendi með vísifingur og þumal í kross: dökkur húðlitur',
    '🤟🏻' => 'elska-þig merki: ljós húðlitur',
    '🤟🏼' => 'elska-þig merki: meðalljós húðlitur',
    '🤟🏽' => 'elska-þig merki: millihúðlitur',
    '🤟🏾' => 'elska-þig merki: meðaldökkur húðlitur',
    '🤟🏿' => 'elska-þig merki: dökkur húðlitur',
    '🤘🏻' => 'rokkmerki: ljós húðlitur',
    '🤘🏼' => 'rokkmerki: meðalljós húðlitur',
    '🤘🏽' => 'rokkmerki: millihúðlitur',
    '🤘🏾' => 'rokkmerki: meðaldökkur húðlitur',
    '🤘🏿' => 'rokkmerki: dökkur húðlitur',
    '🤙🏻' => 'hringdu: ljós húðlitur',
    '🤙🏼' => 'hringdu: meðalljós húðlitur',
    '🤙🏽' => 'hringdu: millihúðlitur',
    '🤙🏾' => 'hringdu: meðaldökkur húðlitur',
    '🤙🏿' => 'hringdu: dökkur húðlitur',
    '👈🏻' => 'fingur bendir til vinstri: ljós húðlitur',
    '👈🏼' => 'fingur bendir til vinstri: meðalljós húðlitur',
    '👈🏽' => 'fingur bendir til vinstri: millihúðlitur',
    '👈🏾' => 'fingur bendir til vinstri: meðaldökkur húðlitur',
    '👈🏿' => 'fingur bendir til vinstri: dökkur húðlitur',
    '👉🏻' => 'fingur bendir til hægri: ljós húðlitur',
    '👉🏼' => 'fingur bendir til hægri: meðalljós húðlitur',
    '👉🏽' => 'fingur bendir til hægri: millihúðlitur',
    '👉🏾' => 'fingur bendir til hægri: meðaldökkur húðlitur',
    '👉🏿' => 'fingur bendir til hægri: dökkur húðlitur',
    '👆🏻' => 'fingur bendir upp: ljós húðlitur',
    '👆🏼' => 'fingur bendir upp: meðalljós húðlitur',
    '👆🏽' => 'fingur bendir upp: millihúðlitur',
    '👆🏾' => 'fingur bendir upp: meðaldökkur húðlitur',
    '👆🏿' => 'fingur bendir upp: dökkur húðlitur',
    '🖕🏻' => 'langatöng: ljós húðlitur',
    '🖕🏼' => 'langatöng: meðalljós húðlitur',
    '🖕🏽' => 'langatöng: millihúðlitur',
    '🖕🏾' => 'langatöng: meðaldökkur húðlitur',
    '🖕🏿' => 'langatöng: dökkur húðlitur',
    '👇🏻' => 'fingur bendir niður: ljós húðlitur',
    '👇🏼' => 'fingur bendir niður: meðalljós húðlitur',
    '👇🏽' => 'fingur bendir niður: millihúðlitur',
    '👇🏾' => 'fingur bendir niður: meðaldökkur húðlitur',
    '👇🏿' => 'fingur bendir niður: dökkur húðlitur',
    '☝🏻' => 'vísifingur bendir upp: ljós húðlitur',
    '☝🏼' => 'vísifingur bendir upp: meðalljós húðlitur',
    '☝🏽' => 'vísifingur bendir upp: millihúðlitur',
    '☝🏾' => 'vísifingur bendir upp: meðaldökkur húðlitur',
    '☝🏿' => 'vísifingur bendir upp: dökkur húðlitur',
    '🫵🏻' => 'vísifingur bendir á áhorfandann: ljós húðlitur',
    '🫵🏼' => 'vísifingur bendir á áhorfandann: meðalljós húðlitur',
    '🫵🏽' => 'vísifingur bendir á áhorfandann: millihúðlitur',
    '🫵🏾' => 'vísifingur bendir á áhorfandann: meðaldökkur húðlitur',
    '🫵🏿' => 'vísifingur bendir á áhorfandann: dökkur húðlitur',
    '👍🏻' => 'þumall upp: ljós húðlitur',
    '👍🏼' => 'þumall upp: meðalljós húðlitur',
    '👍🏽' => 'þumall upp: millihúðlitur',
    '👍🏾' => 'þumall upp: meðaldökkur húðlitur',
    '👍🏿' => 'þumall upp: dökkur húðlitur',
    '👎🏻' => 'þumall niður: ljós húðlitur',
    '👎🏼' => 'þumall niður: meðalljós húðlitur',
    '👎🏽' => 'þumall niður: millihúðlitur',
    '👎🏾' => 'þumall niður: meðaldökkur húðlitur',
    '👎🏿' => 'þumall niður: dökkur húðlitur',
    '✊🏻' => 'hnefi: ljós húðlitur',
    '✊🏼' => 'hnefi: meðalljós húðlitur',
    '✊🏽' => 'hnefi: millihúðlitur',
    '✊🏾' => 'hnefi: meðaldökkur húðlitur',
    '✊🏿' => 'hnefi: dökkur húðlitur',
    '👊🏻' => 'krepptur hnefi: ljós húðlitur',
    '👊🏼' => 'krepptur hnefi: meðalljós húðlitur',
    '👊🏽' => 'krepptur hnefi: millihúðlitur',
    '👊🏾' => 'krepptur hnefi: meðaldökkur húðlitur',
    '👊🏿' => 'krepptur hnefi: dökkur húðlitur',
    '🤛🏻' => 'hægri hnefi: ljós húðlitur',
    '🤛🏼' => 'hægri hnefi: meðalljós húðlitur',
    '🤛🏽' => 'hægri hnefi: millihúðlitur',
    '🤛🏾' => 'hægri hnefi: meðaldökkur húðlitur',
    '🤛🏿' => 'hægri hnefi: dökkur húðlitur',
    '🤜🏻' => 'vinstri hnefi: ljós húðlitur',
    '🤜🏼' => 'vinstri hnefi: meðalljós húðlitur',
    '🤜🏽' => 'vinstri hnefi: millihúðlitur',
    '🤜🏾' => 'vinstri hnefi: meðaldökkur húðlitur',
    '🤜🏿' => 'vinstri hnefi: dökkur húðlitur',
    '👏🏻' => 'lófaklapp: ljós húðlitur',
    '👏🏼' => 'lófaklapp: meðalljós húðlitur',
    '👏🏽' => 'lófaklapp: millihúðlitur',
    '👏🏾' => 'lófaklapp: meðaldökkur húðlitur',
    '👏🏿' => 'lófaklapp: dökkur húðlitur',
    '🙌🏻' => 'húrra: ljós húðlitur',
    '🙌🏼' => 'húrra: meðalljós húðlitur',
    '🙌🏽' => 'húrra: millihúðlitur',
    '🙌🏾' => 'húrra: meðaldökkur húðlitur',
    '🙌🏿' => 'húrra: dökkur húðlitur',
    '🫶🏻' => 'hjartahendur: ljós húðlitur',
    '🫶🏼' => 'hjartahendur: meðalljós húðlitur',
    '🫶🏽' => 'hjartahendur: millihúðlitur',
    '🫶🏾' => 'hjartahendur: meðaldökkur húðlitur',
    '🫶🏿' => 'hjartahendur: dökkur húðlitur',
    '👐🏻' => 'opinn lófi: ljós húðlitur',
    '👐🏼' => 'opinn lófi: meðalljós húðlitur',
    '👐🏽' => 'opinn lófi: millihúðlitur',
    '👐🏾' => 'opinn lófi: meðaldökkur húðlitur',
    '👐🏿' => 'opinn lófi: dökkur húðlitur',
    '🤲🏻' => 'lófar saman: ljós húðlitur',
    '🤲🏼' => 'lófar saman: meðalljós húðlitur',
    '🤲🏽' => 'lófar saman: millihúðlitur',
    '🤲🏾' => 'lófar saman: meðaldökkur húðlitur',
    '🤲🏿' => 'lófar saman: dökkur húðlitur',
    '🤝🏻' => 'handaband: ljós húðlitur',
    '🤝🏼' => 'handaband: meðalljós húðlitur',
    '🤝🏽' => 'handaband: millihúðlitur',
    '🤝🏾' => 'handaband: meðaldökkur húðlitur',
    '🤝🏿' => 'handaband: dökkur húðlitur',
    '🙏🏻' => 'bæn: ljós húðlitur',
    '🙏🏼' => 'bæn: meðalljós húðlitur',
    '🙏🏽' => 'bæn: millihúðlitur',
    '🙏🏾' => 'bæn: meðaldökkur húðlitur',
    '🙏🏿' => 'bæn: dökkur húðlitur',
    '✍🏻' => 'skrifandi hönd: ljós húðlitur',
    '✍🏼' => 'skrifandi hönd: meðalljós húðlitur',
    '✍🏽' => 'skrifandi hönd: millihúðlitur',
    '✍🏾' => 'skrifandi hönd: meðaldökkur húðlitur',
    '✍🏿' => 'skrifandi hönd: dökkur húðlitur',
    '💅🏻' => 'naglalakk: ljós húðlitur',
    '💅🏼' => 'naglalakk: meðalljós húðlitur',
    '💅🏽' => 'naglalakk: millihúðlitur',
    '💅🏾' => 'naglalakk: meðaldökkur húðlitur',
    '💅🏿' => 'naglalakk: dökkur húðlitur',
    '🤳🏻' => 'sjálfa: ljós húðlitur',
    '🤳🏼' => 'sjálfa: meðalljós húðlitur',
    '🤳🏽' => 'sjálfa: millihúðlitur',
    '🤳🏾' => 'sjálfa: meðaldökkur húðlitur',
    '🤳🏿' => 'sjálfa: dökkur húðlitur',
    '💪🏻' => 'upphandleggsvöðvar: ljós húðlitur',
    '💪🏼' => 'upphandleggsvöðvar: meðalljós húðlitur',
    '💪🏽' => 'upphandleggsvöðvar: millihúðlitur',
    '💪🏾' => 'upphandleggsvöðvar: meðaldökkur húðlitur',
    '💪🏿' => 'upphandleggsvöðvar: dökkur húðlitur',
    '🦵🏻' => 'fótleggur: ljós húðlitur',
    '🦵🏼' => 'fótleggur: meðalljós húðlitur',
    '🦵🏽' => 'fótleggur: millihúðlitur',
    '🦵🏾' => 'fótleggur: meðaldökkur húðlitur',
    '🦵🏿' => 'fótleggur: dökkur húðlitur',
    '🦶🏻' => 'fótur: ljós húðlitur',
    '🦶🏼' => 'fótur: meðalljós húðlitur',
    '🦶🏽' => 'fótur: millihúðlitur',
    '🦶🏾' => 'fótur: meðaldökkur húðlitur',
    '🦶🏿' => 'fótur: dökkur húðlitur',
    '👂🏻' => 'eyru: ljós húðlitur',
    '👂🏼' => 'eyru: meðalljós húðlitur',
    '👂🏽' => 'eyru: millihúðlitur',
    '👂🏾' => 'eyru: meðaldökkur húðlitur',
    '👂🏿' => 'eyru: dökkur húðlitur',
    '🦻🏻' => 'eyra með heyrnartæki: ljós húðlitur',
    '🦻🏼' => 'eyra með heyrnartæki: meðalljós húðlitur',
    '🦻🏽' => 'eyra með heyrnartæki: millihúðlitur',
    '🦻🏾' => 'eyra með heyrnartæki: meðaldökkur húðlitur',
    '🦻🏿' => 'eyra með heyrnartæki: dökkur húðlitur',
    '👃🏻' => 'nef: ljós húðlitur',
    '👃🏼' => 'nef: meðalljós húðlitur',
    '👃🏽' => 'nef: millihúðlitur',
    '👃🏾' => 'nef: meðaldökkur húðlitur',
    '👃🏿' => 'nef: dökkur húðlitur',
    '👶🏻' => 'ungbarn: ljós húðlitur',
    '👶🏼' => 'ungbarn: meðalljós húðlitur',
    '👶🏽' => 'ungbarn: millihúðlitur',
    '👶🏾' => 'ungbarn: meðaldökkur húðlitur',
    '👶🏿' => 'ungbarn: dökkur húðlitur',
    '🧒🏻' => 'barn: ljós húðlitur',
    '🧒🏼' => 'barn: meðalljós húðlitur',
    '🧒🏽' => 'barn: millihúðlitur',
    '🧒🏾' => 'barn: meðaldökkur húðlitur',
    '🧒🏿' => 'barn: dökkur húðlitur',
    '👦🏻' => 'drengur: ljós húðlitur',
    '👦🏼' => 'drengur: meðalljós húðlitur',
    '👦🏽' => 'drengur: millihúðlitur',
    '👦🏾' => 'drengur: meðaldökkur húðlitur',
    '👦🏿' => 'drengur: dökkur húðlitur',
    '👧🏻' => 'stúlka: ljós húðlitur',
    '👧🏼' => 'stúlka: meðalljós húðlitur',
    '👧🏽' => 'stúlka: millihúðlitur',
    '👧🏾' => 'stúlka: meðaldökkur húðlitur',
    '👧🏿' => 'stúlka: dökkur húðlitur',
    '🧑🏻' => 'manneskja: ljós húðlitur',
    '🧑🏼' => 'manneskja: meðalljós húðlitur',
    '🧑🏽' => 'manneskja: millihúðlitur',
    '🧑🏾' => 'manneskja: meðaldökkur húðlitur',
    '🧑🏿' => 'manneskja: dökkur húðlitur',
    '👱🏻' => 'ljóshærð manneskja: ljós húðlitur',
    '👱🏼' => 'ljóshærð manneskja: meðalljós húðlitur',
    '👱🏽' => 'ljóshærð manneskja: millihúðlitur',
    '👱🏾' => 'ljóshærð manneskja: meðaldökkur húðlitur',
    '👱🏿' => 'ljóshærð manneskja: dökkur húðlitur',
    '👨🏻' => 'karl: ljós húðlitur',
    '👨🏼' => 'karl: meðalljós húðlitur',
    '👨🏽' => 'karl: millihúðlitur',
    '👨🏾' => 'karl: meðaldökkur húðlitur',
    '👨🏿' => 'karl: dökkur húðlitur',
    '🧔🏻' => 'maður með skegg: ljós húðlitur',
    '🧔🏼' => 'maður með skegg: meðalljós húðlitur',
    '🧔🏽' => 'maður með skegg: millihúðlitur',
    '🧔🏾' => 'maður með skegg: meðaldökkur húðlitur',
    '🧔🏿' => 'maður með skegg: dökkur húðlitur',
    '👩🏻' => 'kona: ljós húðlitur',
    '👩🏼' => 'kona: meðalljós húðlitur',
    '👩🏽' => 'kona: millihúðlitur',
    '👩🏾' => 'kona: meðaldökkur húðlitur',
    '👩🏿' => 'kona: dökkur húðlitur',
    '🧓🏻' => 'eldri fullorðinn: ljós húðlitur',
    '🧓🏼' => 'eldri fullorðinn: meðalljós húðlitur',
    '🧓🏽' => 'eldri fullorðinn: millihúðlitur',
    '🧓🏾' => 'eldri fullorðinn: meðaldökkur húðlitur',
    '🧓🏿' => 'eldri fullorðinn: dökkur húðlitur',
    '👴🏻' => 'eldri maður: ljós húðlitur',
    '👴🏼' => 'eldri maður: meðalljós húðlitur',
    '👴🏽' => 'eldri maður: millihúðlitur',
    '👴🏾' => 'eldri maður: meðaldökkur húðlitur',
    '👴🏿' => 'eldri maður: dökkur húðlitur',
    '👵🏻' => 'eldri kona: ljós húðlitur',
    '👵🏼' => 'eldri kona: meðalljós húðlitur',
    '👵🏽' => 'eldri kona: millihúðlitur',
    '👵🏾' => 'eldri kona: meðaldökkur húðlitur',
    '👵🏿' => 'eldri kona: dökkur húðlitur',
    '🙍🏻' => 'manneskja með ygglibrún: ljós húðlitur',
    '🙍🏼' => 'manneskja með ygglibrún: meðalljós húðlitur',
    '🙍🏽' => 'manneskja með ygglibrún: millihúðlitur',
    '🙍🏾' => 'manneskja með ygglibrún: meðaldökkur húðlitur',
    '🙍🏿' => 'manneskja með ygglibrún: dökkur húðlitur',
    '🙎🏻' => 'manneskja í fýlu: ljós húðlitur',
    '🙎🏼' => 'manneskja í fýlu: meðalljós húðlitur',
    '🙎🏽' => 'manneskja í fýlu: millihúðlitur',
    '🙎🏾' => 'manneskja í fýlu: meðaldökkur húðlitur',
    '🙎🏿' => 'manneskja í fýlu: dökkur húðlitur',
    '🙅🏻' => 'ekki gott: ljós húðlitur',
    '🙅🏼' => 'ekki gott: meðalljós húðlitur',
    '🙅🏽' => 'ekki gott: millihúðlitur',
    '🙅🏾' => 'ekki gott: meðaldökkur húðlitur',
    '🙅🏿' => 'ekki gott: dökkur húðlitur',
    '🙆🏻' => 'allt í lagi: ljós húðlitur',
    '🙆🏼' => 'allt í lagi: meðalljós húðlitur',
    '🙆🏽' => 'allt í lagi: millihúðlitur',
    '🙆🏾' => 'allt í lagi: meðaldökkur húðlitur',
    '🙆🏿' => 'allt í lagi: dökkur húðlitur',
    '💁🏻' => 'upplýsingaborð: ljós húðlitur',
    '💁🏼' => 'upplýsingaborð: meðalljós húðlitur',
    '💁🏽' => 'upplýsingaborð: millihúðlitur',
    '💁🏾' => 'upplýsingaborð: meðaldökkur húðlitur',
    '💁🏿' => 'upplýsingaborð: dökkur húðlitur',
    '🙋🏻' => 'gleði: ljós húðlitur',
    '🙋🏼' => 'gleði: meðalljós húðlitur',
    '🙋🏽' => 'gleði: millihúðlitur',
    '🙋🏾' => 'gleði: meðaldökkur húðlitur',
    '🙋🏿' => 'gleði: dökkur húðlitur',
    '🧏🏻' => 'heyrnarlaus: ljós húðlitur',
    '🧏🏼' => 'heyrnarlaus: meðalljós húðlitur',
    '🧏🏽' => 'heyrnarlaus: millihúðlitur',
    '🧏🏾' => 'heyrnarlaus: meðaldökkur húðlitur',
    '🧏🏿' => 'heyrnarlaus: dökkur húðlitur',
    '🙇🏻' => 'fyrirgefðu: ljós húðlitur',
    '🙇🏼' => 'fyrirgefðu: meðalljós húðlitur',
    '🙇🏽' => 'fyrirgefðu: millihúðlitur',
    '🙇🏾' => 'fyrirgefðu: meðaldökkur húðlitur',
    '🙇🏿' => 'fyrirgefðu: dökkur húðlitur',
    '🤦🏻' => 'hönd fyrir andlit: ljós húðlitur',
    '🤦🏼' => 'hönd fyrir andlit: meðalljós húðlitur',
    '🤦🏽' => 'hönd fyrir andlit: millihúðlitur',
    '🤦🏾' => 'hönd fyrir andlit: meðaldökkur húðlitur',
    '🤦🏿' => 'hönd fyrir andlit: dökkur húðlitur',
    '🤷🏻' => 'yppir öxlum: ljós húðlitur',
    '🤷🏼' => 'yppir öxlum: meðalljós húðlitur',
    '🤷🏽' => 'yppir öxlum: millihúðlitur',
    '🤷🏾' => 'yppir öxlum: meðaldökkur húðlitur',
    '🤷🏿' => 'yppir öxlum: dökkur húðlitur',
    '👮🏻' => 'lögregluþjónn: ljós húðlitur',
    '👮🏼' => 'lögregluþjónn: meðalljós húðlitur',
    '👮🏽' => 'lögregluþjónn: millihúðlitur',
    '👮🏾' => 'lögregluþjónn: meðaldökkur húðlitur',
    '👮🏿' => 'lögregluþjónn: dökkur húðlitur',
    '🕵🏻' => 'spæjari: ljós húðlitur',
    '🕵🏼' => 'spæjari: meðalljós húðlitur',
    '🕵🏽' => 'spæjari: millihúðlitur',
    '🕵🏾' => 'spæjari: meðaldökkur húðlitur',
    '🕵🏿' => 'spæjari: dökkur húðlitur',
    '💂🏻' => 'vörður: ljós húðlitur',
    '💂🏼' => 'vörður: meðalljós húðlitur',
    '💂🏽' => 'vörður: millihúðlitur',
    '💂🏾' => 'vörður: meðaldökkur húðlitur',
    '💂🏿' => 'vörður: dökkur húðlitur',
    '🥷🏻' => 'ninja: ljós húðlitur',
    '🥷🏼' => 'ninja: meðalljós húðlitur',
    '🥷🏽' => 'ninja: millihúðlitur',
    '🥷🏾' => 'ninja: meðaldökkur húðlitur',
    '🥷🏿' => 'ninja: dökkur húðlitur',
    '👷🏻' => 'verkamaður: ljós húðlitur',
    '👷🏼' => 'verkamaður: meðalljós húðlitur',
    '👷🏽' => 'verkamaður: millihúðlitur',
    '👷🏾' => 'verkamaður: meðaldökkur húðlitur',
    '👷🏿' => 'verkamaður: dökkur húðlitur',
    '🫅🏻' => 'manneskja með kórónu: ljós húðlitur',
    '🫅🏼' => 'manneskja með kórónu: meðalljós húðlitur',
    '🫅🏽' => 'manneskja með kórónu: millihúðlitur',
    '🫅🏾' => 'manneskja með kórónu: meðaldökkur húðlitur',
    '🫅🏿' => 'manneskja með kórónu: dökkur húðlitur',
    '🤴🏻' => 'prins: ljós húðlitur',
    '🤴🏼' => 'prins: meðalljós húðlitur',
    '🤴🏽' => 'prins: millihúðlitur',
    '🤴🏾' => 'prins: meðaldökkur húðlitur',
    '🤴🏿' => 'prins: dökkur húðlitur',
    '👸🏻' => 'prinsessa: ljós húðlitur',
    '👸🏼' => 'prinsessa: meðalljós húðlitur',
    '👸🏽' => 'prinsessa: millihúðlitur',
    '👸🏾' => 'prinsessa: meðaldökkur húðlitur',
    '👸🏿' => 'prinsessa: dökkur húðlitur',
    '👳🏻' => 'maður með túrban: ljós húðlitur',
    '👳🏼' => 'maður með túrban: meðalljós húðlitur',
    '👳🏽' => 'maður með túrban: millihúðlitur',
    '👳🏾' => 'maður með túrban: meðaldökkur húðlitur',
    '👳🏿' => 'maður með túrban: dökkur húðlitur',
    '👲🏻' => 'maður með kínverska húfu: ljós húðlitur',
    '👲🏼' => 'maður með kínverska húfu: meðalljós húðlitur',
    '👲🏽' => 'maður með kínverska húfu: millihúðlitur',
    '👲🏾' => 'maður með kínverska húfu: meðaldökkur húðlitur',
    '👲🏿' => 'maður með kínverska húfu: dökkur húðlitur',
    '🧕🏻' => 'kona með höfuðklút: ljós húðlitur',
    '🧕🏼' => 'kona með höfuðklút: meðalljós húðlitur',
    '🧕🏽' => 'kona með höfuðklút: millihúðlitur',
    '🧕🏾' => 'kona með höfuðklút: meðaldökkur húðlitur',
    '🧕🏿' => 'kona með höfuðklút: dökkur húðlitur',
    '🤵🏻' => 'smóking: ljós húðlitur',
    '🤵🏼' => 'smóking: meðalljós húðlitur',
    '🤵🏽' => 'smóking: millihúðlitur',
    '🤵🏾' => 'smóking: meðaldökkur húðlitur',
    '🤵🏿' => 'smóking: dökkur húðlitur',
    '👰🏻' => 'brúður: ljós húðlitur',
    '👰🏼' => 'brúður: meðalljós húðlitur',
    '👰🏽' => 'brúður: millihúðlitur',
    '👰🏾' => 'brúður: meðaldökkur húðlitur',
    '👰🏿' => 'brúður: dökkur húðlitur',
    '🤰🏻' => 'ólétt kona: ljós húðlitur',
    '🤰🏼' => 'ólétt kona: meðalljós húðlitur',
    '🤰🏽' => 'ólétt kona: millihúðlitur',
    '🤰🏾' => 'ólétt kona: meðaldökkur húðlitur',
    '🤰🏿' => 'ólétt kona: dökkur húðlitur',
    '🫃🏻' => 'barnshafandi maður: ljós húðlitur',
    '🫃🏼' => 'barnshafandi maður: meðalljós húðlitur',
    '🫃🏽' => 'barnshafandi maður: millihúðlitur',
    '🫃🏾' => 'barnshafandi maður: meðaldökkur húðlitur',
    '🫃🏿' => 'barnshafandi maður: dökkur húðlitur',
    '🫄🏻' => 'barnshafandi manneskja: ljós húðlitur',
    '🫄🏼' => 'barnshafandi manneskja: meðalljós húðlitur',
    '🫄🏽' => 'barnshafandi manneskja: millihúðlitur',
    '🫄🏾' => 'barnshafandi manneskja: meðaldökkur húðlitur',
    '🫄🏿' => 'barnshafandi manneskja: dökkur húðlitur',
    '🤱🏻' => 'brjóstagjöf: ljós húðlitur',
    '🤱🏼' => 'brjóstagjöf: meðalljós húðlitur',
    '🤱🏽' => 'brjóstagjöf: millihúðlitur',
    '🤱🏾' => 'brjóstagjöf: meðaldökkur húðlitur',
    '🤱🏿' => 'brjóstagjöf: dökkur húðlitur',
    '👼🏻' => 'barnsengill: ljós húðlitur',
    '👼🏼' => 'barnsengill: meðalljós húðlitur',
    '👼🏽' => 'barnsengill: millihúðlitur',
    '👼🏾' => 'barnsengill: meðaldökkur húðlitur',
    '👼🏿' => 'barnsengill: dökkur húðlitur',
    '🎅🏻' => 'jólasveinn: ljós húðlitur',
    '🎅🏼' => 'jólasveinn: meðalljós húðlitur',
    '🎅🏽' => 'jólasveinn: millihúðlitur',
    '🎅🏾' => 'jólasveinn: meðaldökkur húðlitur',
    '🎅🏿' => 'jólasveinn: dökkur húðlitur',
    '🤶🏻' => 'jólamamma: ljós húðlitur',
    '🤶🏼' => 'jólamamma: meðalljós húðlitur',
    '🤶🏽' => 'jólamamma: millihúðlitur',
    '🤶🏾' => 'jólamamma: meðaldökkur húðlitur',
    '🤶🏿' => 'jólamamma: dökkur húðlitur',
    '🦸🏻' => 'ofurhetja: ljós húðlitur',
    '🦸🏼' => 'ofurhetja: meðalljós húðlitur',
    '🦸🏽' => 'ofurhetja: millihúðlitur',
    '🦸🏾' => 'ofurhetja: meðaldökkur húðlitur',
    '🦸🏿' => 'ofurhetja: dökkur húðlitur',
    '🦹🏻' => 'skúrkur: ljós húðlitur',
    '🦹🏼' => 'skúrkur: meðalljós húðlitur',
    '🦹🏽' => 'skúrkur: millihúðlitur',
    '🦹🏾' => 'skúrkur: meðaldökkur húðlitur',
    '🦹🏿' => 'skúrkur: dökkur húðlitur',
    '🧙🏻' => 'galdramaður: ljós húðlitur',
    '🧙🏼' => 'galdramaður: meðalljós húðlitur',
    '🧙🏽' => 'galdramaður: millihúðlitur',
    '🧙🏾' => 'galdramaður: meðaldökkur húðlitur',
    '🧙🏿' => 'galdramaður: dökkur húðlitur',
    '🧚🏻' => 'álfur: ljós húðlitur',
    '🧚🏼' => 'álfur: meðalljós húðlitur',
    '🧚🏽' => 'álfur: millihúðlitur',
    '🧚🏾' => 'álfur: meðaldökkur húðlitur',
    '🧚🏿' => 'álfur: dökkur húðlitur',
    '🧛🏻' => 'vampíra: ljós húðlitur',
    '🧛🏼' => 'vampíra: meðalljós húðlitur',
    '🧛🏽' => 'vampíra: millihúðlitur',
    '🧛🏾' => 'vampíra: meðaldökkur húðlitur',
    '🧛🏿' => 'vampíra: dökkur húðlitur',
    '🧜🏻' => 'sæbúi: ljós húðlitur',
    '🧜🏼' => 'sæbúi: meðalljós húðlitur',
    '🧜🏽' => 'sæbúi: millihúðlitur',
    '🧜🏾' => 'sæbúi: meðaldökkur húðlitur',
    '🧜🏿' => 'sæbúi: dökkur húðlitur',
    '🧝🏻' => 'huldumaður: ljós húðlitur',
    '🧝🏼' => 'huldumaður: meðalljós húðlitur',
    '🧝🏽' => 'huldumaður: millihúðlitur',
    '🧝🏾' => 'huldumaður: meðaldökkur húðlitur',
    '🧝🏿' => 'huldumaður: dökkur húðlitur',
    '💆🏻' => 'andlitsnudd: ljós húðlitur',
    '💆🏼' => 'andlitsnudd: meðalljós húðlitur',
    '💆🏽' => 'andlitsnudd: millihúðlitur',
    '💆🏾' => 'andlitsnudd: meðaldökkur húðlitur',
    '💆🏿' => 'andlitsnudd: dökkur húðlitur',
    '💇🏻' => 'klipping: ljós húðlitur',
    '💇🏼' => 'klipping: meðalljós húðlitur',
    '💇🏽' => 'klipping: millihúðlitur',
    '💇🏾' => 'klipping: meðaldökkur húðlitur',
    '💇🏿' => 'klipping: dökkur húðlitur',
    '🚶🏻' => 'vegfarandi: ljós húðlitur',
    '🚶🏼' => 'vegfarandi: meðalljós húðlitur',
    '🚶🏽' => 'vegfarandi: millihúðlitur',
    '🚶🏾' => 'vegfarandi: meðaldökkur húðlitur',
    '🚶🏿' => 'vegfarandi: dökkur húðlitur',
    '🧍🏻' => 'standandi manneskja: ljós húðlitur',
    '🧍🏼' => 'standandi manneskja: meðalljós húðlitur',
    '🧍🏽' => 'standandi manneskja: millihúðlitur',
    '🧍🏾' => 'standandi manneskja: meðaldökkur húðlitur',
    '🧍🏿' => 'standandi manneskja: dökkur húðlitur',
    '🧎🏻' => 'krjúpandi manneskja: ljós húðlitur',
    '🧎🏼' => 'krjúpandi manneskja: meðalljós húðlitur',
    '🧎🏽' => 'krjúpandi manneskja: millihúðlitur',
    '🧎🏾' => 'krjúpandi manneskja: meðaldökkur húðlitur',
    '🧎🏿' => 'krjúpandi manneskja: dökkur húðlitur',
    '🏃🏻' => 'hlaupari: ljós húðlitur',
    '🏃🏼' => 'hlaupari: meðalljós húðlitur',
    '🏃🏽' => 'hlaupari: millihúðlitur',
    '🏃🏾' => 'hlaupari: meðaldökkur húðlitur',
    '🏃🏿' => 'hlaupari: dökkur húðlitur',
    '💃🏻' => 'dansandi kona: ljós húðlitur',
    '💃🏼' => 'dansandi kona: meðalljós húðlitur',
    '💃🏽' => 'dansandi kona: millihúðlitur',
    '💃🏾' => 'dansandi kona: meðaldökkur húðlitur',
    '💃🏿' => 'dansandi kona: dökkur húðlitur',
    '🕺🏻' => 'dansandi karl: ljós húðlitur',
    '🕺🏼' => 'dansandi karl: meðalljós húðlitur',
    '🕺🏽' => 'dansandi karl: millihúðlitur',
    '🕺🏾' => 'dansandi karl: meðaldökkur húðlitur',
    '🕺🏿' => 'dansandi karl: dökkur húðlitur',
    '🕴🏻' => 'svífandi bisnessmaður í jakkafötum: ljós húðlitur',
    '🕴🏼' => 'svífandi bisnessmaður í jakkafötum: meðalljós húðlitur',
    '🕴🏽' => 'svífandi bisnessmaður í jakkafötum: millihúðlitur',
    '🕴🏾' => 'svífandi bisnessmaður í jakkafötum: meðaldökkur húðlitur',
    '🕴🏿' => 'svífandi bisnessmaður í jakkafötum: dökkur húðlitur',
    '👯🏻' => 'kanínueyru: ljós húðlitur',
    '👯🏼' => 'kanínueyru: meðalljós húðlitur',
    '👯🏽' => 'kanínueyru: millihúðlitur',
    '👯🏾' => 'kanínueyru: meðaldökkur húðlitur',
    '👯🏿' => 'kanínueyru: dökkur húðlitur',
    '🧖🏻' => 'einstaklingur í gufubaði: ljós húðlitur',
    '🧖🏼' => 'einstaklingur í gufubaði: meðalljós húðlitur',
    '🧖🏽' => 'einstaklingur í gufubaði: millihúðlitur',
    '🧖🏾' => 'einstaklingur í gufubaði: meðaldökkur húðlitur',
    '🧖🏿' => 'einstaklingur í gufubaði: dökkur húðlitur',
    '🧗🏻' => 'maður í klettaklifri: ljós húðlitur',
    '🧗🏼' => 'maður í klettaklifri: meðalljós húðlitur',
    '🧗🏽' => 'maður í klettaklifri: millihúðlitur',
    '🧗🏾' => 'maður í klettaklifri: meðaldökkur húðlitur',
    '🧗🏿' => 'maður í klettaklifri: dökkur húðlitur',
    '🏇🏻' => 'veðreiðar: ljós húðlitur',
    '🏇🏼' => 'veðreiðar: meðalljós húðlitur',
    '🏇🏽' => 'veðreiðar: millihúðlitur',
    '🏇🏾' => 'veðreiðar: meðaldökkur húðlitur',
    '🏇🏿' => 'veðreiðar: dökkur húðlitur',
    '🏂🏻' => 'snjóbrettamaður: ljós húðlitur',
    '🏂🏼' => 'snjóbrettamaður: meðalljós húðlitur',
    '🏂🏽' => 'snjóbrettamaður: millihúðlitur',
    '🏂🏾' => 'snjóbrettamaður: meðaldökkur húðlitur',
    '🏂🏿' => 'snjóbrettamaður: dökkur húðlitur',
    '🏌🏻' => 'kylfingur: ljós húðlitur',
    '🏌🏼' => 'kylfingur: meðalljós húðlitur',
    '🏌🏽' => 'kylfingur: millihúðlitur',
    '🏌🏾' => 'kylfingur: meðaldökkur húðlitur',
    '🏌🏿' => 'kylfingur: dökkur húðlitur',
    '🏄🏻' => 'brimbrettamaður: ljós húðlitur',
    '🏄🏼' => 'brimbrettamaður: meðalljós húðlitur',
    '🏄🏽' => 'brimbrettamaður: millihúðlitur',
    '🏄🏾' => 'brimbrettamaður: meðaldökkur húðlitur',
    '🏄🏿' => 'brimbrettamaður: dökkur húðlitur',
    '🚣🏻' => 'árabátur: ljós húðlitur',
    '🚣🏼' => 'árabátur: meðalljós húðlitur',
    '🚣🏽' => 'árabátur: millihúðlitur',
    '🚣🏾' => 'árabátur: meðaldökkur húðlitur',
    '🚣🏿' => 'árabátur: dökkur húðlitur',
    '🏊🏻' => 'sund: ljós húðlitur',
    '🏊🏼' => 'sund: meðalljós húðlitur',
    '🏊🏽' => 'sund: millihúðlitur',
    '🏊🏾' => 'sund: meðaldökkur húðlitur',
    '🏊🏿' => 'sund: dökkur húðlitur',
    '⛹🏻' => 'manneskja með bolta: ljós húðlitur',
    '⛹🏼' => 'manneskja með bolta: meðalljós húðlitur',
    '⛹🏽' => 'manneskja með bolta: millihúðlitur',
    '⛹🏾' => 'manneskja með bolta: meðaldökkur húðlitur',
    '⛹🏿' => 'manneskja með bolta: dökkur húðlitur',
    '🏋🏻' => 'kraftlyftingamaður: ljós húðlitur',
    '🏋🏼' => 'kraftlyftingamaður: meðalljós húðlitur',
    '🏋🏽' => 'kraftlyftingamaður: millihúðlitur',
    '🏋🏾' => 'kraftlyftingamaður: meðaldökkur húðlitur',
    '🏋🏿' => 'kraftlyftingamaður: dökkur húðlitur',
    '🚴🏻' => 'manneskja á hjóli: ljós húðlitur',
    '🚴🏼' => 'manneskja á hjóli: meðalljós húðlitur',
    '🚴🏽' => 'manneskja á hjóli: millihúðlitur',
    '🚴🏾' => 'manneskja á hjóli: meðaldökkur húðlitur',
    '🚴🏿' => 'manneskja á hjóli: dökkur húðlitur',
    '🚵🏻' => 'fjallahjól: ljós húðlitur',
    '🚵🏼' => 'fjallahjól: meðalljós húðlitur',
    '🚵🏽' => 'fjallahjól: millihúðlitur',
    '🚵🏾' => 'fjallahjól: meðaldökkur húðlitur',
    '🚵🏿' => 'fjallahjól: dökkur húðlitur',
    '🤸🏻' => 'handahlaup: ljós húðlitur',
    '🤸🏼' => 'handahlaup: meðalljós húðlitur',
    '🤸🏽' => 'handahlaup: millihúðlitur',
    '🤸🏾' => 'handahlaup: meðaldökkur húðlitur',
    '🤸🏿' => 'handahlaup: dökkur húðlitur',
    '🤼🏻' => 'glíma: ljós húðlitur',
    '🤼🏼' => 'glíma: meðalljós húðlitur',
    '🤼🏽' => 'glíma: millihúðlitur',
    '🤼🏾' => 'glíma: meðaldökkur húðlitur',
    '🤼🏿' => 'glíma: dökkur húðlitur',
    '🤽🏻' => 'manneskja í vatnapóló: ljós húðlitur',
    '🤽🏼' => 'manneskja í vatnapóló: meðalljós húðlitur',
    '🤽🏽' => 'manneskja í vatnapóló: millihúðlitur',
    '🤽🏾' => 'manneskja í vatnapóló: meðaldökkur húðlitur',
    '🤽🏿' => 'manneskja í vatnapóló: dökkur húðlitur',
    '🤾🏻' => 'handbolti: ljós húðlitur',
    '🤾🏼' => 'handbolti: meðalljós húðlitur',
    '🤾🏽' => 'handbolti: millihúðlitur',
    '🤾🏾' => 'handbolti: meðaldökkur húðlitur',
    '🤾🏿' => 'handbolti: dökkur húðlitur',
    '🤹🏻' => 'boltakast: ljós húðlitur',
    '🤹🏼' => 'boltakast: meðalljós húðlitur',
    '🤹🏽' => 'boltakast: millihúðlitur',
    '🤹🏾' => 'boltakast: meðaldökkur húðlitur',
    '🤹🏿' => 'boltakast: dökkur húðlitur',
    '🧘🏻' => 'maður í lótuspósu: ljós húðlitur',
    '🧘🏼' => 'maður í lótuspósu: meðalljós húðlitur',
    '🧘🏽' => 'maður í lótuspósu: millihúðlitur',
    '🧘🏾' => 'maður í lótuspósu: meðaldökkur húðlitur',
    '🧘🏿' => 'maður í lótuspósu: dökkur húðlitur',
    '🛀🏻' => 'bað: ljós húðlitur',
    '🛀🏼' => 'bað: meðalljós húðlitur',
    '🛀🏽' => 'bað: millihúðlitur',
    '🛀🏾' => 'bað: meðaldökkur húðlitur',
    '🛀🏿' => 'bað: dökkur húðlitur',
    '🛌🏻' => 'manneskja í rúmi: ljós húðlitur',
    '🛌🏼' => 'manneskja í rúmi: meðalljós húðlitur',
    '🛌🏽' => 'manneskja í rúmi: millihúðlitur',
    '🛌🏾' => 'manneskja í rúmi: meðaldökkur húðlitur',
    '🛌🏿' => 'manneskja í rúmi: dökkur húðlitur',
    '👭🏻' => 'konur sem leiðast: ljós húðlitur',
    '👭🏼' => 'konur sem leiðast: meðalljós húðlitur',
    '👭🏽' => 'konur sem leiðast: millihúðlitur',
    '👭🏾' => 'konur sem leiðast: meðaldökkur húðlitur',
    '👭🏿' => 'konur sem leiðast: dökkur húðlitur',
    '👫🏻' => 'karl og kona sem leiðast: ljós húðlitur',
    '👫🏼' => 'karl og kona sem leiðast: meðalljós húðlitur',
    '👫🏽' => 'karl og kona sem leiðast: millihúðlitur',
    '👫🏾' => 'karl og kona sem leiðast: meðaldökkur húðlitur',
    '👫🏿' => 'karl og kona sem leiðast: dökkur húðlitur',
    '👬🏻' => 'karlar sem leiðast: ljós húðlitur',
    '👬🏼' => 'karlar sem leiðast: meðalljós húðlitur',
    '👬🏽' => 'karlar sem leiðast: millihúðlitur',
    '👬🏾' => 'karlar sem leiðast: meðaldökkur húðlitur',
    '👬🏿' => 'karlar sem leiðast: dökkur húðlitur',
    '💏🏻' => 'koss: ljós húðlitur',
    '💏🏼' => 'koss: meðalljós húðlitur',
    '💏🏽' => 'koss: millihúðlitur',
    '💏🏾' => 'koss: meðaldökkur húðlitur',
    '💏🏿' => 'koss: dökkur húðlitur',
    '💑🏻' => 'par: ljós húðlitur',
    '💑🏼' => 'par: meðalljós húðlitur',
    '💑🏽' => 'par: millihúðlitur',
    '💑🏾' => 'par: meðaldökkur húðlitur',
    '💑🏿' => 'par: dökkur húðlitur',
    '🇦🇨' => 'fáni: Ascension-eyja',
    '🇦🇩' => 'fáni: Andorra',
    '🇦🇪' => 'fáni: Sameinuðu arabísku furstadæmin',
    '🇦🇫' => 'fáni: Afganistan',
    '🇦🇬' => 'fáni: Antígva og Barbúda',
    '🇦🇮' => 'fáni: Angvilla',
    '🇦🇱' => 'fáni: Albanía',
    '🇦🇲' => 'fáni: Armenía',
    '🇦🇴' => 'fáni: Angóla',
    '🇦🇶' => 'fáni: Suðurskautslandið',
    '🇦🇷' => 'fáni: Argentína',
    '🇦🇸' => 'fáni: Bandaríska Samóa',
    '🇦🇹' => 'fáni: Austurríki',
    '🇦🇺' => 'fáni: Ástralía',
    '🇦🇼' => 'fáni: Arúba',
    '🇦🇽' => 'fáni: Álandseyjar',
    '🇦🇿' => 'fáni: Aserbaídsjan',
    '🇧🇦' => 'fáni: Bosnía og Hersegóvína',
    '🇧🇧' => 'fáni: Barbados',
    '🇧🇩' => 'fáni: Bangladess',
    '🇧🇪' => 'fáni: Belgía',
    '🇧🇫' => 'fáni: Búrkína Fasó',
    '🇧🇬' => 'fáni: Búlgaría',
    '🇧🇭' => 'fáni: Barein',
    '🇧🇮' => 'fáni: Búrúndí',
    '🇧🇯' => 'fáni: Benín',
    '🇧🇱' => 'fáni: Sankti Bartólómeusareyjar',
    '🇧🇲' => 'fáni: Bermúdaeyjar',
    '🇧🇳' => 'fáni: Brúnei',
    '🇧🇴' => 'fáni: Bólivía',
    '🇧🇶' => 'fáni: Karíbahafshluti Hollands',
    '🇧🇷' => 'fáni: Brasilía',
    '🇧🇸' => 'fáni: Bahamaeyjar',
    '🇧🇹' => 'fáni: Bútan',
    '🇧🇻' => 'fáni: Bouveteyja',
    '🇧🇼' => 'fáni: Botsvana',
    '🇧🇾' => 'fáni: Hvíta-Rússland',
    '🇧🇿' => 'fáni: Belís',
    '🇨🇦' => 'fáni: Kanada',
    '🇨🇨' => 'fáni: Kókoseyjar (Keeling)',
    '🇨🇩' => 'fáni: Kongó-Kinshasa',
    '🇨🇫' => 'fáni: Mið-Afríkulýðveldið',
    '🇨🇬' => 'fáni: Kongó-Brazzaville',
    '🇨🇭' => 'fáni: Sviss',
    '🇨🇮' => 'fáni: Fílabeinsströndin',
    '🇨🇰' => 'fáni: Cooks-eyjar',
    '🇨🇱' => 'fáni: Síle',
    '🇨🇲' => 'fáni: Kamerún',
    '🇨🇳' => 'fáni: Kína',
    '🇨🇴' => 'fáni: Kólumbía',
    '🇨🇵' => 'fáni: Clipperton-eyja',
    '🇨🇶' => 'fáni: Sark',
    '🇨🇷' => 'fáni: Kostaríka',
    '🇨🇺' => 'fáni: Kúba',
    '🇨🇻' => 'fáni: Grænhöfðaeyjar',
    '🇨🇼' => 'fáni: Curacao',
    '🇨🇽' => 'fáni: Jólaey',
    '🇨🇾' => 'fáni: Kýpur',
    '🇨🇿' => 'fáni: Tékkland',
    '🇩🇪' => 'fáni: Þýskaland',
    '🇩🇬' => 'fáni: Diego Garcia',
    '🇩🇯' => 'fáni: Djíbútí',
    '🇩🇰' => 'fáni: Danmörk',
    '🇩🇲' => 'fáni: Dóminíka',
    '🇩🇴' => 'fáni: Dóminíska lýðveldið',
    '🇩🇿' => 'fáni: Alsír',
    '🇪🇦' => 'fáni: Ceuta og Melilla',
    '🇪🇨' => 'fáni: Ekvador',
    '🇪🇪' => 'fáni: Eistland',
    '🇪🇬' => 'fáni: Egyptaland',
    '🇪🇭' => 'fáni: Vestur-Sahara',
    '🇪🇷' => 'fáni: Erítrea',
    '🇪🇸' => 'fáni: Spánn',
    '🇪🇹' => 'fáni: Eþíópía',
    '🇪🇺' => 'fáni: Evrópusambandið',
    '🇫🇮' => 'fáni: Finnland',
    '🇫🇯' => 'fáni: Fídjíeyjar',
    '🇫🇰' => 'fáni: Falklandseyjar',
    '🇫🇲' => 'fáni: Míkrónesía',
    '🇫🇴' => 'fáni: Færeyjar',
    '🇫🇷' => 'fáni: Frakkland',
    '🇬🇦' => 'fáni: Gabon',
    '🇬🇧' => 'fáni: Bretland',
    '🇬🇩' => 'fáni: Grenada',
    '🇬🇪' => 'fáni: Georgía',
    '🇬🇫' => 'fáni: Franska Gvæjana',
    '🇬🇬' => 'fáni: Guernsey',
    '🇬🇭' => 'fáni: Gana',
    '🇬🇮' => 'fáni: Gíbraltar',
    '🇬🇱' => 'fáni: Grænland',
    '🇬🇲' => 'fáni: Gambía',
    '🇬🇳' => 'fáni: Gínea',
    '🇬🇵' => 'fáni: Gvadelúpeyjar',
    '🇬🇶' => 'fáni: Miðbaugs-Gínea',
    '🇬🇷' => 'fáni: Grikkland',
    '🇬🇸' => 'fáni: Suður-Georgía og Suður-Sandvíkureyjar',
    '🇬🇹' => 'fáni: Gvatemala',
    '🇬🇺' => 'fáni: Gvam',
    '🇬🇼' => 'fáni: Gínea-Bissá',
    '🇬🇾' => 'fáni: Gvæjana',
    '🇭🇰' => 'fáni: sérstjórnarsvæðið Hong Kong',
    '🇭🇲' => 'fáni: Heard og McDonaldseyjar',
    '🇭🇳' => 'fáni: Hondúras',
    '🇭🇷' => 'fáni: Króatía',
    '🇭🇹' => 'fáni: Haítí',
    '🇭🇺' => 'fáni: Ungverjaland',
    '🇮🇨' => 'fáni: Kanaríeyjar',
    '🇮🇩' => 'fáni: Indónesía',
    '🇮🇪' => 'fáni: Írland',
    '🇮🇱' => 'fáni: Ísrael',
    '🇮🇲' => 'fáni: Mön',
    '🇮🇳' => 'fáni: Indland',
    '🇮🇴' => 'fáni: Bresku Indlandshafseyjar',
    '🇮🇶' => 'fáni: Írak',
    '🇮🇷' => 'fáni: Íran',
    '🇮🇸' => 'fáni: Ísland',
    '🇮🇹' => 'fáni: Ítalía',
    '🇯🇪' => 'fáni: Jersey',
    '🇯🇲' => 'fáni: Jamaíka',
    '🇯🇴' => 'fáni: Jórdanía',
    '🇯🇵' => 'fáni: Japan',
    '🇰🇪' => 'fáni: Kenía',
    '🇰🇬' => 'fáni: Kirgistan',
    '🇰🇭' => 'fáni: Kambódía',
    '🇰🇮' => 'fáni: Kíribatí',
    '🇰🇲' => 'fáni: Kómoreyjar',
    '🇰🇳' => 'fáni: Sankti Kitts og Nevis',
    '🇰🇵' => 'fáni: Norður-Kórea',
    '🇰🇷' => 'fáni: Suður-Kórea',
    '🇰🇼' => 'fáni: Kúveit',
    '🇰🇾' => 'fáni: Caymaneyjar',
    '🇰🇿' => 'fáni: Kasakstan',
    '🇱🇦' => 'fáni: Laos',
    '🇱🇧' => 'fáni: Líbanon',
    '🇱🇨' => 'fáni: Sankti Lúsía',
    '🇱🇮' => 'fáni: Liechtenstein',
    '🇱🇰' => 'fáni: Srí Lanka',
    '🇱🇷' => 'fáni: Líbería',
    '🇱🇸' => 'fáni: Lesótó',
    '🇱🇹' => 'fáni: Litháen',
    '🇱🇺' => 'fáni: Lúxemborg',
    '🇱🇻' => 'fáni: Lettland',
    '🇱🇾' => 'fáni: Líbía',
    '🇲🇦' => 'fáni: Marokkó',
    '🇲🇨' => 'fáni: Mónakó',
    '🇲🇩' => 'fáni: Moldóva',
    '🇲🇪' => 'fáni: Svartfjallaland',
    '🇲🇫' => 'fáni: Saint-Martin',
    '🇲🇬' => 'fáni: Madagaskar',
    '🇲🇭' => 'fáni: Marshalleyjar',
    '🇲🇰' => 'fáni: Norður-Makedónía',
    '🇲🇱' => 'fáni: Malí',
    '🇲🇲' => 'fáni: Mjanmar (Búrma)',
    '🇲🇳' => 'fáni: Mongólía',
    '🇲🇴' => 'fáni: sérstjórnarsvæðið Makaó',
    '🇲🇵' => 'fáni: Norður-Maríanaeyjar',
    '🇲🇶' => 'fáni: Martiník',
    '🇲🇷' => 'fáni: Máritanía',
    '🇲🇸' => 'fáni: Montserrat',
    '🇲🇹' => 'fáni: Malta',
    '🇲🇺' => 'fáni: Máritíus',
    '🇲🇻' => 'fáni: Maldíveyjar',
    '🇲🇼' => 'fáni: Malaví',
    '🇲🇽' => 'fáni: Mexíkó',
    '🇲🇾' => 'fáni: Malasía',
    '🇲🇿' => 'fáni: Mósambík',
    '🇳🇦' => 'fáni: Namibía',
    '🇳🇨' => 'fáni: Nýja-Kaledónía',
    '🇳🇪' => 'fáni: Níger',
    '🇳🇫' => 'fáni: Norfolkeyja',
    '🇳🇬' => 'fáni: Nígería',
    '🇳🇮' => 'fáni: Níkaragva',
    '🇳🇱' => 'fáni: Holland',
    '🇳🇴' => 'fáni: Noregur',
    '🇳🇵' => 'fáni: Nepal',
    '🇳🇷' => 'fáni: Nárú',
    '🇳🇺' => 'fáni: Niue',
    '🇳🇿' => 'fáni: Nýja-Sjáland',
    '🇴🇲' => 'fáni: Óman',
    '🇵🇦' => 'fáni: Panama',
    '🇵🇪' => 'fáni: Perú',
    '🇵🇫' => 'fáni: Franska Pólýnesía',
    '🇵🇬' => 'fáni: Papúa Nýja-Gínea',
    '🇵🇭' => 'fáni: Filippseyjar',
    '🇵🇰' => 'fáni: Pakistan',
    '🇵🇱' => 'fáni: Pólland',
    '🇵🇲' => 'fáni: Sankti Pierre og Miquelon',
    '🇵🇳' => 'fáni: Pitcairn-eyjar',
    '🇵🇷' => 'fáni: Púertó Ríkó',
    '🇵🇸' => 'fáni: Heimastjórnarsvæði Palestínumanna',
    '🇵🇹' => 'fáni: Portúgal',
    '🇵🇼' => 'fáni: Palá',
    '🇵🇾' => 'fáni: Paragvæ',
    '🇶🇦' => 'fáni: Katar',
    '🇷🇪' => 'fáni: Réunion',
    '🇷🇴' => 'fáni: Rúmenía',
    '🇷🇸' => 'fáni: Serbía',
    '🇷🇺' => 'fáni: Rússland',
    '🇷🇼' => 'fáni: Rúanda',
    '🇸🇦' => 'fáni: Sádi-Arabía',
    '🇸🇧' => 'fáni: Salómonseyjar',
    '🇸🇨' => 'fáni: Seychelles-eyjar',
    '🇸🇩' => 'fáni: Súdan',
    '🇸🇪' => 'fáni: Svíþjóð',
    '🇸🇬' => 'fáni: Singapúr',
    '🇸🇭' => 'fáni: Sankti Helena',
    '🇸🇮' => 'fáni: Slóvenía',
    '🇸🇯' => 'fáni: Svalbarði og Jan Mayen',
    '🇸🇰' => 'fáni: Slóvakía',
    '🇸🇱' => 'fáni: Síerra Leóne',
    '🇸🇲' => 'fáni: San Marínó',
    '🇸🇳' => 'fáni: Senegal',
    '🇸🇴' => 'fáni: Sómalía',
    '🇸🇷' => 'fáni: Súrínam',
    '🇸🇸' => 'fáni: Suður-Súdan',
    '🇸🇹' => 'fáni: Saó Tóme og Prinsípe',
    '🇸🇻' => 'fáni: El Salvador',
    '🇸🇽' => 'fáni: Sint Maarten',
    '🇸🇾' => 'fáni: Sýrland',
    '🇸🇿' => 'fáni: Esvatíní',
    '🇹🇦' => 'fáni: Tristan da Cunha',
    '🇹🇨' => 'fáni: Turks- og Caicoseyjar',
    '🇹🇩' => 'fáni: Tsjad',
    '🇹🇫' => 'fáni: Frönsku suðlægu landsvæðin',
    '🇹🇬' => 'fáni: Tógó',
    '🇹🇭' => 'fáni: Taíland',
    '🇹🇯' => 'fáni: Tadsíkistan',
    '🇹🇰' => 'fáni: Tókelá',
    '🇹🇱' => 'fáni: Tímor-Leste',
    '🇹🇲' => 'fáni: Túrkmenistan',
    '🇹🇳' => 'fáni: Túnis',
    '🇹🇴' => 'fáni: Tonga',
    '🇹🇷' => 'fáni: Tyrkland',
    '🇹🇹' => 'fáni: Trínidad og Tóbagó',
    '🇹🇻' => 'fáni: Túvalú',
    '🇹🇼' => 'fáni: Taívan',
    '🇹🇿' => 'fáni: Tansanía',
    '🇺🇦' => 'fáni: Úkraína',
    '🇺🇬' => 'fáni: Úganda',
    '🇺🇲' => 'fáni: Smáeyjar Bandaríkjanna',
    '🇺🇳' => 'fáni: Sameinuðu þjóðirnar',
    '🇺🇸' => 'fáni: Bandaríkin',
    '🇺🇾' => 'fáni: Úrúgvæ',
    '🇺🇿' => 'fáni: Úsbekistan',
    '🇻🇦' => 'fáni: Vatíkanið',
    '🇻🇨' => 'fáni: Sankti Vinsent og Grenadíneyjar',
    '🇻🇪' => 'fáni: Venesúela',
    '🇻🇬' => 'fáni: Bresku Jómfrúaeyjar',
    '🇻🇮' => 'fáni: Bandarísku Jómfrúaeyjar',
    '🇻🇳' => 'fáni: Víetnam',
    '🇻🇺' => 'fáni: Vanúatú',
    '🇼🇫' => 'fáni: Wallis- og Fútúnaeyjar',
    '🇼🇸' => 'fáni: Samóa',
    '🇽🇰' => 'fáni: Kósóvó',
    '🇾🇪' => 'fáni: Jemen',
    '🇾🇹' => 'fáni: Mayotte',
    '🇿🇦' => 'fáni: Suður-Afríka',
    '🇿🇲' => 'fáni: Sambía',
    '🇿🇼' => 'fáni: Simbabve',
    '🔟' => 'takki: 10',
    '🏻' => 'ljós húðlitur',
    '🏼' => 'meðalljós húðlitur',
    '🏽' => 'millihúðlitur',
    '🏾' => 'meðaldökkur húðlitur',
    '🏿' => 'dökkur húðlitur',
    '😀' => 'glottandi andlit',
    '😃' => 'brosandi andlit með opinn munn',
    '😄' => 'hlæjandi andlit',
    '😁' => 'glottandi andlit með brosandi augum',
    '😆' => 'brosandi andlit með pírð augu',
    '😅' => 'bros og kaldur sviti',
    '🤣' => 'veltist um af hlátri',
    '😂' => 'andlit tárast af gleði',
    '🙂' => 'milt bros',
    '🙃' => 'andlit á hvolfi',
    '🫠' => 'andlit að bráðna',
    '😉' => 'blikkandi andlit',
    '😊' => 'bros',
    '😇' => 'brosandi andlit með geislabaug',
    '🥰' => 'brosandi andlit með hjörtum',
    '😍' => 'brosandi andlit með hjartalaga augu',
    '🤩' => 'stjörnustjarfur',
    '😘' => 'kveðjukoss',
    '😗' => 'kyssandi andlit',
    '☺' => 'broskarl',
    '😚' => 'kyssandi andlit með lokuð augu',
    '😙' => 'kyssa og brosa',
    '🥲' => 'brosandi andlit með tár',
    '😋' => 'andlit að njóta matar',
    '😛' => 'tunga út',
    '😜' => 'blikkarl með útrétta tungu',
    '🤪' => 'sturlað andlit',
    '😝' => 'oj',
    '🤑' => 'andlit með peningaseðil í munninum',
    '🤗' => 'faðmandi andlit',
    '🤭' => 'andlit með hendi fyrir munn',
    '🫢' => 'andlit með opin augu og hendi yfir munni',
    '🫣' => 'andlit með auga að kíkja',
    '🤫' => 'andlit að segja uss',
    '🤔' => 'hugsandi andlit',
    '🫡' => 'andlit að heilsa',
    '🤐' => 'andlit með rennilás fyrir munninum',
    '🤨' => 'andlit með yppta brún',
    '😐' => 'hlutlaust andlit',
    '😑' => 'svipbrigðalaust andlit',
    '😶' => 'andlit án munns',
    '🫥' => 'punktalínuandlit',
    '😏' => 'sjálfsánægt andlit',
    '😒' => 'engin gleði',
    '🙄' => 'ranghvolfir augum',
    '😬' => 'gretta',
    '🤥' => 'lygari',
    '🫨' => 'skjálfandi andlit',
    '😌' => 'andlit sem er létt',
    '😔' => 'íbyggið andlit',
    '😪' => 'syfjað andlit',
    '🤤' => 'slefandi',
    '😴' => 'sofandi',
    '🫩' => 'andlit með poka undir augum',
    '😷' => 'andlit með grímu',
    '🤒' => 'andlit með hitamæli í munninum',
    '🤕' => 'andlit með sárabindi',
    '🤢' => 'gubbukall',
    '🤮' => 'ælandi andlit',
    '🤧' => 'hnerrandi andlit',
    '🥵' => 'heitt',
    '🥶' => 'kalt',
    '🥴' => 'ringlað andlit',
    '😵' => 'svimi',
    '🤯' => 'splundrað höfuð',
    '🤠' => 'kúreki',
    '🥳' => 'partíandlit',
    '🥸' => 'dulargervi',
    '😎' => 'brosandi andlit með sólgleraugu',
    '🤓' => 'nördaandlit',
    '🧐' => 'andlit með einglyrni',
    '😕' => 'ruglingslegt andlit',
    '🫤' => 'andlit með skáhallan munn',
    '😟' => 'áhyggjufullt andlit',
    '🙁' => 'andlit með litla skeifu',
    '☹' => 'andlit með stóra skeifu',
    '😮' => 'andlit með opinn munn',
    '😯' => 'undrandi andlit',
    '😲' => 'stórundrandi andlit',
    '😳' => 'andlit að roðna',
    '🫪' => 'afmyndað andlit',
    '🥺' => 'biðjandi andlit',
    '🥹' => 'andlit að berjast við tárin',
    '😦' => 'leitt andlit',
    '😧' => 'angistarfullt andlit',
    '😨' => 'hrætt andlit',
    '😰' => 'sveitt andlit',
    '😥' => 'léttir',
    '😢' => 'grátandi andlit',
    '😭' => 'hágrátandi andlit',
    '😱' => 'óttaslegið andlit',
    '😖' => 'forviða andlit',
    '😣' => 'klúður',
    '😞' => 'vonbrigði',
    '😓' => 'kaldur sviti',
    '😩' => 'þreytulegt andlit',
    '😫' => 'þreytt andlit',
    '🥱' => 'geispandi andlit',
    '😤' => 'sigursvipur',
    '😡' => 'fýlulegt andlit',
    '😠' => 'reitt andlit',
    '🤬' => 'andlit með tákn fyrir munni',
    '😈' => 'broskarl með horn',
    '👿' => 'púki',
    '💀' => 'hauskúpa',
    '☠' => 'hauskúpa og beinleggir',
    '💩' => 'kúkur',
    '🤡' => 'trúður',
    '👹' => 'tröll',
    '👺' => 'ári',
    '👻' => 'draugur',
    '👽' => 'geimvera',
    '👾' => 'geimveruskrímsli',
    '🤖' => 'vélmennisandlit',
    '😺' => 'hlæjandi köttur',
    '😸' => 'glottandi köttur',
    '😹' => 'köttur með gleðitár',
    '😻' => 'brosandi köttur',
    '😼' => 'lúmskur köttur',
    '😽' => 'kyssandi köttur',
    '🙀' => 'hnugginn köttur',
    '😿' => 'grátandi köttur',
    '😾' => 'köttur í fýlu',
    '🙈' => 'api heldur fyrir augu',
    '🙉' => 'api heldur fyrir eyru',
    '🙊' => 'api heldur fyrir munn',
    '💌' => 'ástarbréf',
    '💘' => 'hjarta með ör',
    '💝' => 'hjarta með slaufu',
    '💖' => 'glitrandi hjarta',
    '💗' => 'stækkandi hjarta',
    '💓' => 'hjartsláttur',
    '💞' => 'snúningshjörtu',
    '💕' => 'tvö hjörtu',
    '💟' => 'skraut með hjarta',
    '❣' => 'hjarta sem upphrópunarmerki',
    '💔' => 'brostið hjarta',
    '❤' => 'rautt hjarta',
    '🩷' => 'bleikt hjarta',
    '🧡' => 'appelsínugult hjarta',
    '💛' => 'gult hjarta',
    '💚' => 'grænt hjarta',
    '💙' => 'blátt hjarta',
    '🩵' => 'ljósblátt hjarta',
    '💜' => 'fjólublátt hjarta',
    '🤎' => 'brúnt hjarta',
    '🖤' => 'svart hjarta',
    '🩶' => 'grátt hjarta',
    '🤍' => 'hvítt hjarta',
    '💋' => 'kossafar',
    '💯' => 'fullt hús',
    '💢' => 'reiði',
    '🫯' => 'rifrildisský',
    '💥' => 'árekstur',
    '💫' => 'ringlaður',
    '💦' => 'svitadropar',
    '💨' => 'hraðferð',
    '🕳' => 'hola',
    '💬' => 'talblaðra',
    '🗨' => 'vinstri talblaðra',
    '🗯' => 'reiðileg hægri talblaðra',
    '💭' => 'hugsanablaðra',
    '💤' => 'þreyta',
    '👋' => 'hönd veifar',
    '🤚' => 'upprétt hönd',
    '🖐' => 'upprétt hönd með glennta fingur',
    '✋' => 'lófi',
    '🖖' => 'vulcan-kveðja',
    '🫱' => 'hendi hægra megin',
    '🫲' => 'hendi vinstra megin',
    '🫳' => 'hendi með lófa niður',
    '🫴' => 'hendi með lófa upp',
    '🫷' => 'hönd ýtt til vinstri',
    '🫸' => 'hönd ýtt til hægri',
    '👌' => 'Í lagi',
    '🤌' => 'klípandi fingur',
    '🤏' => 'klípandi hönd',
    '✌' => 'friðarmerki',
    '🤞' => 'krosslagðir fingur',
    '🫰' => 'hendi með vísifingur og þumal í kross',
    '🤟' => 'elska-þig merki',
    '🤘' => 'rokkmerki',
    '🤙' => 'hringdu',
    '👈' => 'fingur bendir til vinstri',
    '👉' => 'fingur bendir til hægri',
    '👆' => 'fingur bendir upp',
    '🖕' => 'langatöng',
    '👇' => 'fingur bendir niður',
    '☝' => 'vísifingur bendir upp',
    '🫵' => 'vísifingur bendir á áhorfandann',
    '👍' => 'þumall upp',
    '👎' => 'þumall niður',
    '✊' => 'hnefi',
    '👊' => 'krepptur hnefi',
    '🤛' => 'hægri hnefi',
    '🤜' => 'vinstri hnefi',
    '👏' => 'lófaklapp',
    '🙌' => 'húrra',
    '🫶' => 'hjartahendur',
    '👐' => 'opinn lófi',
    '🤲' => 'lófar saman',
    '🤝' => 'handaband',
    '🙏' => 'bæn',
    '✍' => 'skrifandi hönd',
    '💅' => 'naglalakk',
    '🤳' => 'sjálfa',
    '💪' => 'upphandleggsvöðvar',
    '🦾' => 'vélhandleggur',
    '🦿' => 'vélfótleggur',
    '🦵' => 'fótleggur',
    '🦶' => 'fótur',
    '👂' => 'eyru',
    '🦻' => 'eyra með heyrnartæki',
    '👃' => 'nef',
    '🧠' => 'heili',
    '🫀' => 'hjartavöðvi',
    '🫁' => 'lungu',
    '🦷' => 'tennur',
    '🦴' => 'bein',
    '👀' => 'augu',
    '👁' => 'auga',
    '👅' => 'tunga',
    '👄' => 'munnur',
    '🫦' => 'bítur í vör',
    '👶' => 'ungbarn',
    '🧒' => 'barn',
    '👦' => 'drengur',
    '👧' => 'stúlka',
    '🧑' => 'manneskja',
    '👱' => 'ljóshærð manneskja',
    '👨' => 'karl',
    '🧔' => 'maður með skegg',
    '👩' => 'kona',
    '🧓' => 'eldri fullorðinn',
    '👴' => 'eldri maður',
    '👵' => 'eldri kona',
    '🙍' => 'manneskja með ygglibrún',
    '🙎' => 'manneskja í fýlu',
    '🙅' => 'ekki gott',
    '🙆' => 'allt í lagi',
    '💁' => 'upplýsingaborð',
    '🙋' => 'gleði',
    '🧏' => 'heyrnarlaus',
    '🙇' => 'fyrirgefðu',
    '🤦' => 'hönd fyrir andlit',
    '🤷' => 'yppir öxlum',
    '👮' => 'lögregluþjónn',
    '🕵' => 'spæjari',
    '💂' => 'vörður',
    '🥷' => 'ninja',
    '👷' => 'verkamaður',
    '🫅' => 'manneskja með kórónu',
    '🤴' => 'prins',
    '👸' => 'prinsessa',
    '👳' => 'maður með túrban',
    '👲' => 'maður með kínverska húfu',
    '🧕' => 'kona með höfuðklút',
    '🤵' => 'smóking',
    '👰' => 'brúður',
    '🤰' => 'ólétt kona',
    '🫃' => 'barnshafandi maður',
    '🫄' => 'barnshafandi manneskja',
    '🤱' => 'brjóstagjöf',
    '👼' => 'barnsengill',
    '🎅' => 'jólasveinn',
    '🤶' => 'jólamamma',
    '🦸' => 'ofurhetja',
    '🦹' => 'skúrkur',
    '🧙' => 'galdramaður',
    '🧚' => 'álfur',
    '🧛' => 'vampíra',
    '🧜' => 'sæbúi',
    '🧝' => 'huldumaður',
    '🧞' => 'andi',
    '🧟' => 'uppvakningur',
    '🧌' => 'jarðálfur',
    '🫈' => 'loðin skepna',
    '💆' => 'andlitsnudd',
    '💇' => 'klipping',
    '🚶' => 'vegfarandi',
    '🧍' => 'standandi manneskja',
    '🧎' => 'krjúpandi manneskja',
    '🏃' => 'hlaupari',
    '💃' => 'dansandi kona',
    '🕺' => 'dansandi karl',
    '🕴' => 'svífandi bisnessmaður í jakkafötum',
    '👯' => 'kanínueyru',
    '🧖' => 'einstaklingur í gufubaði',
    '🧗' => 'maður í klettaklifri',
    '🤺' => 'skylmingar',
    '🏇' => 'veðreiðar',
    '⛷' => 'skíðamaður',
    '🏂' => 'snjóbrettamaður',
    '🏌' => 'kylfingur',
    '🏄' => 'brimbrettamaður',
    '🚣' => 'árabátur',
    '🏊' => 'sund',
    '⛹' => 'manneskja með bolta',
    '🏋' => 'kraftlyftingamaður',
    '🚴' => 'manneskja á hjóli',
    '🚵' => 'fjallahjól',
    '🤸' => 'handahlaup',
    '🤼' => 'glíma',
    '🤽' => 'manneskja í vatnapóló',
    '🤾' => 'handbolti',
    '🤹' => 'boltakast',
    '🧘' => 'maður í lótuspósu',
    '🛀' => 'bað',
    '🛌' => 'manneskja í rúmi',
    '👭' => 'konur sem leiðast',
    '👫' => 'karl og kona sem leiðast',
    '👬' => 'karlar sem leiðast',
    '💏' => 'koss',
    '💑' => 'par',
    '🗣' => 'talandi höfuð',
    '👤' => 'brjóstmynd í skugga',
    '👥' => 'brjóstmyndir í skugga',
    '🫂' => 'fólk að faðmast',
    '👪' => 'fjölskylda',
    '👣' => 'fótspor',
    '🫆' => 'fingrafar',
    '🦰' => 'rautt hár',
    '🦱' => 'krullur',
    '🦳' => 'hvítt hár',
    '🦲' => 'skalli',
    '🐵' => 'apahöfuð',
    '🐒' => 'api',
    '🦍' => 'górilla',
    '🦧' => 'órangútan',
    '🐶' => 'hundshöfuð',
    '🐕' => 'hundur',
    '🦮' => 'leiðsöguhundur',
    '🐩' => 'púðluhundur',
    '🐺' => 'úlfur',
    '🦊' => 'refur',
    '🦝' => 'þvottabjörn',
    '🐱' => 'kattarhöfuð',
    '🐈' => 'köttur',
    '🦁' => 'ljón',
    '🐯' => 'tígrisdýrshöfuð',
    '🐅' => 'tígrisdýr',
    '🐆' => 'hlébarði',
    '🐴' => 'hestshöfuð',
    '🫎' => 'elgur',
    '🫏' => 'asni',
    '🐎' => 'hestur',
    '🦄' => 'einhyrningur',
    '🦓' => 'sebrahestur',
    '🦌' => 'hjartardýr',
    '🦬' => 'vísundur',
    '🐮' => 'kýrhöfuð',
    '🐂' => 'uxi',
    '🐃' => 'vatnabuffaló',
    '🐄' => 'kýr',
    '🐷' => 'svínshöfuð',
    '🐖' => 'svín',
    '🐗' => 'villisvín',
    '🐽' => 'svínstrýni',
    '🐏' => 'hrútur',
    '🐑' => 'ær',
    '🐐' => 'geit',
    '🐪' => 'drómedari',
    '🐫' => 'kameldýr',
    '🦙' => 'lamadýr',
    '🦒' => 'gíraffi',
    '🐘' => 'fíll',
    '🦣' => 'loðfíll',
    '🦏' => 'nashyrningur',
    '🦛' => 'flóðhestur',
    '🐭' => 'músarhöfuð',
    '🐁' => 'mús',
    '🐀' => 'rotta',
    '🐹' => 'hamstur',
    '🐰' => 'kanínuhöfuð',
    '🐇' => 'kanína',
    '🐿' => 'jarðíkorni',
    '🦫' => 'bifur',
    '🦔' => 'broddgöltur',
    '🦇' => 'leðurblaka',
    '🐻' => 'björn',
    '🐨' => 'kóalabjörn',
    '🐼' => 'panda',
    '🦥' => 'letidýr',
    '🦦' => 'otur',
    '🦨' => 'skunkur',
    '🦘' => 'kengúra',
    '🦡' => 'greifingi',
    '🐾' => 'loppa',
    '🦃' => 'kalkúnn',
    '🐔' => 'kjúklingur',
    '🐓' => 'hani',
    '🐣' => 'hænuungi í eggi',
    '🐤' => 'hænuungi',
    '🐥' => 'framhlið hænuunga',
    '🐦' => 'fugl',
    '🐧' => 'mörgæs',
    '🕊' => 'dúfa',
    '🦅' => 'örn',
    '🦆' => 'önd',
    '🦢' => 'svanur',
    '🦉' => 'ugla',
    '🦤' => 'dúdúfugl',
    '🪶' => 'fjöður',
    '🦩' => 'flamingói',
    '🦚' => 'páfugl',
    '🦜' => 'páfagaukur',
    '🪽' => 'vængur',
    '🪿' => 'gæs',
    '🐸' => 'froskur',
    '🐊' => 'krókódíll',
    '🐢' => 'skjaldbaka',
    '🦎' => 'eðla',
    '🐍' => 'snákur',
    '🐲' => 'drekahöfuð',
    '🐉' => 'dreki',
    '🦕' => 'graseðla',
    '🦖' => 'Grameðla',
    '🐳' => 'blásandi hvalur',
    '🐋' => 'hvalur',
    '🐬' => 'höfrungur',
    '🫍' => 'háhyrningur',
    '🦭' => 'selur',
    '🐟' => 'fiskur',
    '🐠' => 'hitabeltisfiskur',
    '🐡' => 'blöðrufiskur',
    '🦈' => 'hákarl',
    '🐙' => 'kolkrabbi',
    '🐚' => 'kuðungur',
    '🪸' => 'kórall',
    '🪼' => 'marglytta',
    '🦀' => 'krabbi',
    '🦞' => 'humar',
    '🦐' => 'rækja',
    '🦑' => 'smokkfiskur',
    '🦪' => 'ostra',
    '🐌' => 'snigill',
    '🦋' => 'fiðrildi',
    '🐛' => 'skordýr',
    '🐜' => 'maur',
    '🐝' => 'hunangsfluga',
    '🪲' => 'bjölludýr',
    '🐞' => 'maríuhæna',
    '🦗' => 'krybba',
    '🪳' => 'kakkalakki',
    '🕷' => 'könguló',
    '🕸' => 'köngulóarvefur',
    '🦂' => 'sporðdreki',
    '🦟' => 'moskító',
    '🪰' => 'fluga',
    '🪱' => 'ormur',
    '🦠' => 'örvera',
    '💐' => 'blómvöndur',
    '🌸' => 'kirsuberjablóm',
    '💮' => 'hvítt blóm',
    '🪷' => 'lótus',
    '🏵' => 'rósarmynstur',
    '🌹' => 'rós',
    '🥀' => 'sölnað blóm',
    '🌺' => 'Havaírós',
    '🌻' => 'sólblóm',
    '🌼' => 'blóm',
    '🌷' => 'túlípani',
    '🪻' => 'hýasinta',
    '🌱' => 'græðlingur',
    '🪴' => 'pottaplanta',
    '🌲' => 'sígrænt tré',
    '🌳' => 'sumargrænt tré',
    '🌴' => 'pálmatré',
    '🌵' => 'kaktus',
    '🌾' => 'hrísgrjónaplanta',
    '🌿' => 'kryddjurt',
    '☘' => 'músarsmári',
    '🍀' => 'fjögurra laufa smári',
    '🍁' => 'hlynslauf',
    '🍂' => 'fallandi lauf',
    '🍃' => 'lauf í vindi',
    '🪹' => 'tómt hreiður',
    '🪺' => 'hreiður með eggjum',
    '🍄' => 'sveppur',
    '🪾' => 'blaðlaust tré',
    '🍇' => 'vínber',
    '🍈' => 'melóna',
    '🍉' => 'vatnsmelóna',
    '🍊' => 'mandarína',
    '🍋' => 'sítróna',
    '🍌' => 'banani',
    '🍍' => 'ananas',
    '🥭' => 'mangó',
    '🍎' => 'rautt epli',
    '🍏' => 'grænt epli',
    '🍐' => 'pera',
    '🍑' => 'ferskja',
    '🍒' => 'kirsuber',
    '🍓' => 'jarðarber',
    '🫐' => 'bláber',
    '🥝' => 'kíví',
    '🍅' => 'tómatur',
    '🫒' => 'ólífa',
    '🥥' => 'kókoshneta',
    '🥑' => 'avókadó',
    '🍆' => 'eggaldin',
    '🥔' => 'kartafla',
    '🥕' => 'gulrót',
    '🌽' => 'maís',
    '🌶' => 'chilipipar',
    '🫑' => 'paprika',
    '🥒' => 'gúrka',
    '🥬' => 'kál',
    '🥦' => 'brokkólí',
    '🧄' => 'hvítlaukur',
    '🧅' => 'laukur',
    '🥜' => 'jarðhneta',
    '🫘' => 'baunir',
    '🌰' => 'kastanía',
    '🫚' => 'engiferrót',
    '🫛' => 'baunabelgur',
    '🫜' => 'rótargrænmeti',
    '🍞' => 'brauð',
    '🥐' => 'smjördeigshorn',
    '🥖' => 'fransbrauð',
    '🫓' => 'flatkaka',
    '🥨' => 'saltkringla',
    '🥯' => 'beygla',
    '🥞' => 'pönnukökur',
    '🧇' => 'vaffla',
    '🧀' => 'götóttur ostur',
    '🍖' => 'kjöt',
    '🍗' => 'kjúklingaleggur',
    '🥩' => 'kjötsneið',
    '🥓' => 'beikon',
    '🍔' => 'hamborgari',
    '🍟' => 'franskar',
    '🍕' => 'pítsusneið',
    '🌭' => 'pylsa í brauði',
    '🥪' => 'samloka',
    '🌮' => 'takó',
    '🌯' => 'búrrító',
    '🫔' => 'tamale',
    '🥙' => 'kebab',
    '🧆' => 'falafel',
    '🥚' => 'egg',
    '🍳' => 'steikarpanna',
    '🥘' => 'pönnuréttur',
    '🍲' => 'pottréttur',
    '🫕' => 'fondú',
    '🥣' => 'skál og skeið',
    '🥗' => 'salat',
    '🍿' => 'popp',
    '🧈' => 'smjör',
    '🧂' => 'salt',
    '🥫' => 'dósamatur',
    '🍱' => 'bento-box',
    '🍘' => 'hrísgrjónakex',
    '🍙' => 'hrísgrjónabolla',
    '🍚' => 'soðin hrísgrjón',
    '🍛' => 'hrísgrjón og karrí',
    '🍜' => 'núðlur',
    '🍝' => 'spagettí',
    '🍠' => 'steiktar sætar kartöflur',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'djúpsteikt rækja',
    '🍥' => 'fiskkaka',
    '🥮' => 'tunglkaka',
    '🍡' => 'soðkökur á teini',
    '🥟' => 'soðkaka',
    '🥠' => 'spádómskaka',
    '🥡' => 'takeaway-box',
    '🍦' => 'rjómaís',
    '🍧' => 'skafís',
    '🍨' => 'kúluís',
    '🍩' => 'kleinuhringur',
    '🍪' => 'smákaka',
    '🎂' => 'afmæliskaka',
    '🍰' => 'kökusneið',
    '🧁' => 'bollakaka',
    '🥧' => 'baka',
    '🍫' => 'súkkulaði',
    '🍬' => 'nammi',
    '🍭' => 'sleikibrjóstsykur',
    '🍮' => 'búðingur',
    '🍯' => 'hunang',
    '🍼' => 'peli',
    '🥛' => 'mjólkurglas',
    '☕' => 'heitur drykkur',
    '🫖' => 'tekanna',
    '🍵' => 'tebolli',
    '🍶' => 'sake',
    '🍾' => 'flaska með korktappa',
    '🍷' => 'vín',
    '🍸' => 'kokteill',
    '🍹' => 'suðrænn kokteill',
    '🍺' => 'bjór',
    '🍻' => 'bjórglös',
    '🥂' => 'skál',
    '🥃' => 'viskíglas',
    '🫗' => 'hellir vökva',
    '🥤' => 'glas og rör',
    '🧋' => 'kúlute',
    '🧃' => 'ferna',
    '🧉' => 'mate',
    '🧊' => 'ísmoli',
    '🥢' => 'matprjónar',
    '🍽' => 'gaffall og hnífur við disk',
    '🍴' => 'hnífur og gaffall',
    '🥄' => 'skeið',
    '🔪' => 'hnífur',
    '🫙' => 'krukka',
    '🏺' => 'leirkrukka',
    '🌍' => 'hnöttur sem sýnir Evrópu-Afríku',
    '🌎' => 'hnöttur sem sýnir Ameríku',
    '🌏' => 'hnöttur sem sýnir Asíu-Ástralíu',
    '🌐' => 'hnöttur sem sýnir lengdarbauga',
    '🗺' => 'heimskort',
    '🗾' => 'kort af Japan',
    '🧭' => 'áttaviti',
    '🏔' => 'snæviþakinn fjallstindur',
    '⛰' => 'fjall',
    '🛘' => 'skriða',
    '🌋' => 'eldfjall',
    '🗻' => 'fuji-fjall',
    '🏕' => 'tjaldstæði',
    '🏖' => 'strönd með sólhlíf',
    '🏜' => 'eyðimörk',
    '🏝' => 'eyðieyja',
    '🏞' => 'þjóðgarður',
    '🏟' => 'leikvangur',
    '🏛' => 'klassísk fornbygging',
    '🏗' => 'mannvirki í byggingu',
    '🧱' => 'múrsteinn',
    '🪨' => 'steinn',
    '🪵' => 'timbur',
    '🛖' => 'kofi',
    '🏘' => 'húsaþyrping',
    '🏚' => 'niðurnítt hús',
    '🏠' => 'hús',
    '🏡' => 'hús með garði',
    '🏢' => 'skrifstofuhúsnæði',
    '🏣' => 'japanskt pósthús',
    '🏤' => 'evrópskt pósthús',
    '🏥' => 'sjúkrahús',
    '🏦' => 'banki',
    '🏨' => 'hótel',
    '🏩' => 'ástarhótel',
    '🏪' => 'matvörubúð',
    '🏫' => 'skóli',
    '🏬' => 'stórmarkaður',
    '🏭' => 'verksmiðja',
    '🏯' => 'japanskur kastali',
    '🏰' => 'evrópskur kastali',
    '💒' => 'brúðkaup',
    '🗼' => 'tokyo-turninn',
    '🗽' => 'frelsisstyttan',
    '⛪' => 'kirkja',
    '🕌' => 'moska',
    '🛕' => 'hindúahof',
    '🕍' => 'sýnagóga',
    '⛩' => 'sjintó-hof',
    '🕋' => 'kaaba-byggingin',
    '⛲' => 'gosbrunnur',
    '⛺' => 'tjald',
    '🌁' => 'þokukennt',
    '🌃' => 'stjörnuhiminn',
    '🏙' => 'borgarlandslag',
    '🌄' => 'sólarupprás yfir fjöllum',
    '🌅' => 'sólarupprás',
    '🌆' => 'borg um kvöld',
    '🌇' => 'sólarlag',
    '🌉' => 'brú um nótt',
    '♨' => 'hverir',
    '🎠' => 'hringekjuhestur',
    '🛝' => 'rennibraut',
    '🎡' => 'parísarhjól',
    '🎢' => 'rússíbani',
    '💈' => 'rakarastofa',
    '🎪' => 'sirkus',
    '🚂' => 'eimreið',
    '🚃' => 'járnbrautarlest',
    '🚄' => 'hraðlest',
    '🚅' => 'háhraðalest',
    '🚆' => 'lest',
    '🚇' => 'neðanjarðarlest',
    '🚈' => 'léttlest',
    '🚉' => 'lestarstöð',
    '🚊' => 'vagn',
    '🚝' => 'einteinungur',
    '🚞' => 'fjallalest',
    '🚋' => 'sporvagn',
    '🚌' => 'strætó',
    '🚍' => 'strætó á móti',
    '🚎' => 'trissustrætó',
    '🚐' => 'smárúta',
    '🚑' => 'sjúkrabíll',
    '🚒' => 'slökkviliðsbíll',
    '🚓' => 'lögreglubíll',
    '🚔' => 'lögreglubíll á móti',
    '🚕' => 'leigubíll',
    '🚖' => 'leigubíll á móti',
    '🚗' => 'bíll',
    '🚘' => 'bíll á móti',
    '🚙' => 'jeppi',
    '🛻' => 'pallbíll',
    '🚚' => 'flutningabíll',
    '🚛' => 'vörubíll',
    '🚜' => 'dráttarvél',
    '🏎' => 'kappakstursbíll',
    '🏍' => 'mótorhjól',
    '🛵' => 'vespa',
    '🦽' => 'hjólastóll',
    '🦼' => 'vélknúinn hjólastóll',
    '🛺' => 'vélknúinn léttvagn',
    '🚲' => 'hjólreiðar',
    '🛴' => 'hlaupahjól',
    '🛹' => 'hjólabretti',
    '🛼' => 'hjólaskautar',
    '🚏' => 'rúta',
    '🛣' => 'hraðbraut',
    '🛤' => 'járnbrautarteinar',
    '🛢' => 'olíutunna',
    '⛽' => 'bensíndæla',
    '🛞' => 'hjól',
    '🚨' => 'sírena',
    '🚥' => 'lárétt umferðarljós',
    '🚦' => 'lóðrétt umferðarljós',
    '🛑' => 'stöðvunarskylda',
    '🚧' => 'vegavinna',
    '⚓' => 'akkeri',
    '🛟' => 'björgunarhringur',
    '⛵' => 'seglskúta',
    '🛶' => 'kanó',
    '🚤' => 'hraðbátur',
    '🛳' => 'farþegaskip',
    '⛴' => 'ferja',
    '🛥' => 'mótorbátur',
    '🚢' => 'skip',
    '✈' => 'flugvél',
    '🛩' => 'lítil flugvél',
    '🛫' => 'flugvél í flugtaki',
    '🛬' => 'flugvél í lendingu',
    '🪂' => 'fallhlíf',
    '💺' => 'sæti',
    '🚁' => 'þyrla',
    '🚟' => 'loftlest',
    '🚠' => 'kláfferja í fjalli',
    '🚡' => 'kláfferja á línu',
    '🛰' => 'gervihnöttur',
    '🚀' => 'eldflaug',
    '🛸' => 'fljúgandi diskur',
    '🛎' => 'hótelbjalla',
    '🧳' => 'farangur',
    '⌛' => 'stundaglas',
    '⏳' => 'stundaglas með rennandi sandi',
    '⌚' => 'úr',
    '⏰' => 'vekjaraklukka',
    '⏱' => 'skeiðklukka',
    '⏲' => 'tímamælir',
    '🕰' => 'stássklukka',
    '🕛' => 'klukkan tólf',
    '🕧' => 'hálfeitt',
    '🕐' => 'klukkan eitt',
    '🕜' => 'hálftvö',
    '🕑' => 'klukkan tvö',
    '🕝' => 'hálfþrjú',
    '🕒' => 'klukkan þrjú',
    '🕞' => 'hálffjögur',
    '🕓' => 'klukkan fjögur',
    '🕟' => 'hálffimm',
    '🕔' => 'klukkan fimm',
    '🕠' => 'hálfsex',
    '🕕' => 'klukkan sex',
    '🕡' => 'hálfsjö',
    '🕖' => 'klukkan sjö',
    '🕢' => 'hálfátta',
    '🕗' => 'klukkan átta',
    '🕣' => 'hálfníu',
    '🕘' => 'klukkan níu',
    '🕤' => 'hálftíu',
    '🕙' => 'klukkan tíu',
    '🕥' => 'hálfellefu',
    '🕚' => 'klukkan ellefu',
    '🕦' => 'hálftólf',
    '🌑' => 'nýtt tungl',
    '🌒' => 'vaxandi tungl (minna en hálft)',
    '🌓' => 'fyrsta kvartil tungls',
    '🌔' => 'vaxandi tungl (meira en hálft)',
    '🌕' => 'fullt tungl',
    '🌖' => 'minnkandi tungl (meira en hálft)',
    '🌗' => 'síðasta kvartil',
    '🌘' => 'minnkandi tungl (minna en hálft)',
    '🌙' => 'hálfmáni',
    '🌚' => 'nýtt tungl með andliti',
    '🌛' => 'fyrsta kvartil tungls með andliti',
    '🌜' => 'síðasta kvartil tungls með andliti',
    '🌡' => 'hitamælir',
    '☀' => 'sól',
    '🌝' => 'fullt tungl með andliti',
    '🌞' => 'sól með andliti',
    '🪐' => 'pláneta með hringi',
    '⭐' => 'gul stjarna',
    '🌟' => 'skínandi stjarna',
    '🌠' => 'stjörnuhrap',
    '🌌' => 'vetrarbrautin',
    '☁' => 'ský',
    '⛅' => 'sól bakvið ský',
    '⛈' => 'ský með eldingu og regni',
    '🌤' => 'sól á bak við ský',
    '🌥' => 'sól á bak við stórt ský',
    '🌦' => 'sól á bak við regnský',
    '🌧' => 'regnský',
    '🌨' => 'snjóský',
    '🌩' => 'eldingarský',
    '🌪' => 'skýstrókur',
    '🌫' => 'þoka',
    '🌬' => 'veðurandlit',
    '🌀' => 'fellibylur',
    '🌈' => 'regnbogi',
    '🌂' => 'lokuð regnhlíf',
    '☂' => 'regnhlíf',
    '☔' => 'regnhlíf með regndropum',
    '⛱' => 'sólhlíf á jörðinni',
    '⚡' => 'háspenna',
    '❄' => 'snjókorn',
    '☃' => 'snjókarl í snjókomu',
    '⛄' => 'snjókarl',
    '☄' => 'halastjarna',
    '🔥' => 'eldur',
    '💧' => 'dropi',
    '🌊' => 'alda',
    '🎃' => 'hrekkjavökugrasker',
    '🎄' => 'jólatré',
    '🎆' => 'flugeldar',
    '🎇' => 'stjörnuljós',
    '🧨' => 'púðurkerling',
    '✨' => 'stjörnur',
    '🎈' => 'blaðra',
    '🎉' => 'knall',
    '🎊' => 'veisluskraut',
    '🎋' => 'Tanabata-tré',
    '🎍' => 'blómaskreyting með furu',
    '🎎' => 'japanskar brúður',
    '🎏' => 'fiskveifur',
    '🎐' => 'órói',
    '🎑' => 'tunglskoðun',
    '🧧' => 'rautt umslag',
    '🎀' => 'borði',
    '🎁' => 'gjöf',
    '🎗' => 'minnisvarðaborði',
    '🎟' => 'aðgöngumiðar',
    '🎫' => 'miði',
    '🎖' => 'hermedalía',
    '🏆' => 'verðlaunabikar',
    '🏅' => 'íþróttamedalía',
    '🥇' => 'gullverðlaun',
    '🥈' => 'silfurverðlaun',
    '🥉' => 'bronsverðlaun',
    '⚽' => 'fótbolti',
    '⚾' => 'hafnabolti',
    '🥎' => 'mjúkbolti',
    '🏀' => 'körfubolti',
    '🏐' => 'blak',
    '🏈' => 'amerískur fótbolti',
    '🏉' => 'rúgbíbolti',
    '🎾' => 'tennis',
    '🥏' => 'frisbídiskur',
    '🎳' => 'keila',
    '🏏' => 'krikket',
    '🏑' => 'grashokkí',
    '🏒' => 'íshokkí',
    '🥍' => 'háfleikur',
    '🏓' => 'borðtennis',
    '🏸' => 'badminton',
    '🥊' => 'boxhanski',
    '🥋' => 'bardagabúningur',
    '🥅' => 'mark',
    '⛳' => 'golf',
    '⛸' => 'skauti',
    '🎣' => 'veiðistöng',
    '🤿' => 'köfunargríma',
    '🎽' => 'hlaupabolur',
    '🎿' => 'skíði',
    '🛷' => 'sleði',
    '🥌' => 'krullusteinn',
    '🎯' => 'skotmark',
    '🪀' => 'jójó',
    '🪁' => 'flugdreki',
    '🔫' => 'byssa',
    '🎱' => 'billjard',
    '🔮' => 'kristalskúla',
    '🪄' => 'töfrasproti',
    '🎮' => 'tölvuleikur',
    '🕹' => 'stýripinni',
    '🎰' => 'spilakassi',
    '🎲' => 'teningur',
    '🧩' => 'púsl',
    '🧸' => 'bangsi',
    '🪅' => 'piñata',
    '🪩' => 'diskókúla',
    '🪆' => 'babúskur',
    '♠' => 'spaði',
    '♥' => 'hjarta',
    '♦' => 'tígull',
    '♣' => 'lauf',
    '♟' => 'taflpeð',
    '🃏' => 'jókerspil',
    '🀄' => 'Mahjong-tafla',
    '🎴' => 'blómaspil',
    '🎭' => 'leikhúsgrímur',
    '🖼' => 'rammi með mynd',
    '🎨' => 'litapalletta',
    '🧵' => 'tvinni',
    '🪡' => 'saumnál',
    '🧶' => 'garn',
    '🪢' => 'hnútur',
    '👓' => 'gleraugu',
    '🕶' => 'sólgleraugu',
    '🥽' => 'hlífðargleraugu',
    '🥼' => 'læknasloppur',
    '🦺' => 'öryggisvesti',
    '👔' => 'hálsbindi',
    '👕' => 'stuttermabolur',
    '👖' => 'buxur',
    '🧣' => 'trefill',
    '🧤' => 'hanskar',
    '🧥' => 'kápa',
    '🧦' => 'sokkar',
    '👗' => 'kjóll',
    '👘' => 'kímónó',
    '🥻' => 'sari',
    '🩱' => 'sundföt',
    '🩲' => 'nærbuxur',
    '🩳' => 'stuttbuxur',
    '👙' => 'bikíní',
    '👚' => 'kvenföt',
    '🪭' => 'blævængur',
    '👛' => 'budda',
    '👜' => 'handtaska',
    '👝' => 'smáveski',
    '🛍' => 'innkaupapoki',
    '🎒' => 'skólataska',
    '🩴' => 'sandali með ól',
    '👞' => 'herraskór',
    '👟' => 'íþróttaskór',
    '🥾' => 'gönguskór',
    '🥿' => 'lágbotna skór',
    '👠' => 'háhælaður skór',
    '👡' => 'kvensandali',
    '🩰' => 'balletskór',
    '👢' => 'kvenstígvél',
    '🪮' => 'hárkambur',
    '👑' => 'kóróna',
    '👒' => 'kvenhattur',
    '🎩' => 'pípuhattur',
    '🎓' => 'útskriftarhúfa',
    '🧢' => 'derhúfa',
    '🪖' => 'hermannahjálmur',
    '⛑' => 'hjálmur með hvítum krossi',
    '📿' => 'bænaband',
    '💄' => 'varalitur',
    '💍' => 'hringur',
    '💎' => 'gimsteinn',
    '🔇' => 'hljóðlaus hátalari',
    '🔈' => 'lágvær hátalari',
    '🔉' => 'hátalari í gangi',
    '🔊' => 'hávær hátalari',
    '📢' => 'Almannavarnahátalari',
    '📣' => 'gjallarhorn',
    '📯' => 'póstlúður',
    '🔔' => 'bjalla',
    '🔕' => 'engin bjalla',
    '🎼' => 'nótnaskrif',
    '🎵' => 'nóta',
    '🎶' => 'nótur',
    '🎙' => 'hljóðnemi í hljóðveri',
    '🎚' => 'hljóðstyrkssleði',
    '🎛' => 'stýritakkar',
    '🎤' => 'hljóðnemi',
    '🎧' => 'heyrnartól',
    '📻' => 'útvarp',
    '🎷' => 'saxófónn',
    '🎺' => 'trompet',
    '🪊' => 'básúna',
    '🪗' => 'harmonika',
    '🎸' => 'gítar',
    '🎹' => 'píanó',
    '🎻' => 'fiðla',
    '🪕' => 'banjó',
    '🥁' => 'tromma',
    '🪘' => 'handtromma',
    '🪇' => 'hristur',
    '🪈' => 'flauta',
    '🪉' => 'harpa',
    '📱' => 'farsími',
    '📲' => 'farsími með ör',
    '☎' => 'sími',
    '📞' => 'símtól',
    '📟' => 'símboði',
    '📠' => 'fax',
    '🔋' => 'rafhlaða',
    '🪫' => 'raflítil rafhlaða',
    '🔌' => 'innstunga',
    '💻' => 'tölva',
    '🖥' => 'heimilistölva',
    '🖨' => 'prentari',
    '⌨' => 'lyklaborð',
    '🖱' => 'tölvumús',
    '🖲' => 'stýrihjól',
    '💽' => 'MD-diskur',
    '💾' => 'disketta',
    '💿' => 'blu-ray',
    '📀' => 'DVD',
    '🧮' => 'talnagrind',
    '🎥' => 'kvikmyndatökuvél',
    '🎞' => 'kvikmyndafilma',
    '📽' => 'sýningarvél',
    '🎬' => 'klapptré',
    '📺' => 'sjónvarp',
    '📷' => 'myndavél',
    '📸' => 'myndavél með flassi',
    '📹' => 'lítil kvikmyndatökuvél',
    '📼' => 'myndbandsspóla',
    '🔍' => 'stækkunargler sem vísar til vinstri',
    '🔎' => 'stækkunargler sem vísar til hægri',
    '🕯' => 'kerti',
    '💡' => 'ljósapera',
    '🔦' => 'vasaljós',
    '🏮' => 'rauður lampi',
    '🪔' => 'diya-lampi',
    '📔' => 'glósubók með skrautkápu',
    '📕' => 'lokuð bók',
    '📖' => 'opin bók',
    '📗' => 'græn bók',
    '📘' => 'blá bók',
    '📙' => 'appelsínugul bók',
    '📚' => 'bækur',
    '📓' => 'glósubók',
    '📒' => 'dagbók',
    '📃' => 'skjal',
    '📜' => 'bókrolla',
    '📄' => 'skjal snýr upp',
    '📰' => 'dagblað',
    '🗞' => 'samanrúllað dagblað',
    '📑' => 'merkiflipar',
    '🔖' => 'bókamerki',
    '🏷' => 'merkimiði',
    '🪙' => 'mynt',
    '💰' => 'peningapoki',
    '🪎' => 'fjársjóðskista',
    '💴' => 'yenaseðill',
    '💵' => 'dollaraseðill',
    '💶' => 'evruseðill',
    '💷' => 'pundaseðill',
    '💸' => 'fljúgandi peningar',
    '💳' => 'kreditkort',
    '🧾' => 'kvittun',
    '💹' => 'markaður á uppleið',
    '✉' => 'umslag',
    '📧' => 'tölvupóstur',
    '📨' => 'póstur á innleið',
    '📩' => 'póstur á útleið',
    '📤' => 'sendur póstur',
    '📥' => 'móttekinn póstur',
    '📦' => 'pakki',
    '📫' => 'lokaður póstkassi með reistum fána',
    '📪' => 'lokaður póstkassi með niðurdregnum fána',
    '📬' => 'opinn póstkassi með reistum fána',
    '📭' => 'opinn póstkassi með niðurdregnum fána',
    '📮' => 'póstkassi',
    '🗳' => 'kjörseðlakassi með kjörseðli',
    '✏' => 'blýantur',
    '✒' => 'svartur pennaoddur',
    '🖋' => 'sjálfblekungur',
    '🖊' => 'penni',
    '🖌' => 'málningarpensill',
    '🖍' => 'vaxlitur',
    '📝' => 'minnismiði',
    '💼' => 'skjalataska',
    '📁' => 'skráamappa',
    '📂' => 'opin mappa',
    '🗂' => 'spjaldskráarblöð',
    '📅' => 'dagatal',
    '📆' => 'dagatal með rifgötum',
    '🗒' => 'minnisblokk með gormum',
    '🗓' => 'dagatal með gormum',
    '📇' => 'spjaldskrá',
    '📈' => 'á uppleið',
    '📉' => 'á niðurleið',
    '📊' => 'súlurit',
    '📋' => 'klippiborð',
    '📌' => 'teiknibóla',
    '📍' => 'teiknibóla með kúlu',
    '📎' => 'bréfaklemma',
    '🖇' => 'samankræktar bréfaklemmur',
    '📏' => 'reglustika',
    '📐' => 'þríhyrnd reglustika',
    '✂' => 'skæri',
    '🗃' => 'kassi með minnismiðum',
    '🗄' => 'skjalaskápur',
    '🗑' => 'ruslakarfa',
    '🔒' => 'lás',
    '🔓' => 'opinn lás',
    '🔏' => 'lás með penna',
    '🔐' => 'lokaður lás',
    '🔑' => 'lykill',
    '🗝' => 'gamall lykill',
    '🔨' => 'hamar',
    '🪓' => 'öxi',
    '⛏' => 'haki',
    '⚒' => 'hamar og haki',
    '🛠' => 'hamar og skiptilykill',
    '🗡' => 'rýtingur',
    '⚔' => 'krosslögð sverð',
    '💣' => 'sprengja',
    '🪃' => 'búmerang',
    '🏹' => 'bogi og ör',
    '🛡' => 'skjöldur',
    '🪚' => 'sög',
    '🔧' => 'skiptilykill',
    '🪛' => 'skrúfjárn',
    '🔩' => 'bolti og ró',
    '⚙' => 'gírhjól',
    '🗜' => 'þjöppun',
    '⚖' => 'vog',
    '🦯' => 'blindrastafur',
    '🔗' => 'tenglamerki',
    '⛓' => 'keðja',
    '🪝' => 'krókur',
    '🧰' => 'verkfærakassi',
    '🧲' => 'segull',
    '🪜' => 'stigi',
    '🪏' => 'skófla',
    '⚗' => 'eimingarflaska',
    '🧪' => 'tilraunaglas',
    '🧫' => 'petrískál',
    '🧬' => 'dna',
    '🔬' => 'smásjá',
    '🔭' => 'sjónauki',
    '📡' => 'gervihnattaloftnet',
    '💉' => 'sprauta',
    '🩸' => 'blóðdropi',
    '💊' => 'pilla',
    '🩹' => 'plástur',
    '🩼' => 'hækja',
    '🩺' => 'hlustunarpípa',
    '🩻' => 'röntgengeisli',
    '🚪' => 'dyr',
    '🛗' => 'lyfta',
    '🪞' => 'spegill',
    '🪟' => 'gluggi',
    '🛏' => 'rúm',
    '🛋' => 'sófi og lampi',
    '🪑' => 'stóll',
    '🚽' => 'klósett',
    '🪠' => 'drullusokkur',
    '🚿' => 'sturta',
    '🛁' => 'baðker',
    '🪤' => 'músagildra',
    '🪒' => 'rakhnífur',
    '🧴' => 'áburðarflaska',
    '🧷' => 'öryggisnæla',
    '🧹' => 'kústur',
    '🧺' => 'karfa',
    '🧻' => 'pappírsrúlla',
    '🪣' => 'fata',
    '🧼' => 'sápa',
    '🫧' => 'loftbólur',
    '🪥' => 'tannbursti',
    '🧽' => 'svampur',
    '🧯' => 'slökkvitæki',
    '🛒' => 'innkaupakerra',
    '🚬' => 'sígaretta',
    '⚰' => 'líkkista',
    '🪦' => 'legsteinn',
    '⚱' => 'duftker',
    '🧿' => 'nazar verndargripur',
    '🪬' => 'hamsa',
    '🗿' => 'moyai-stytta',
    '🪧' => 'skilti',
    '🪪' => 'persónuskilríki',
    '🏧' => 'hraðbanki',
    '🚮' => 'merki, rusl í ruslatunnu',
    '🚰' => 'drykkjarvatn',
    '♿' => 'hjólastólaaðgengi',
    '🚹' => 'karlaklósett',
    '🚺' => 'kvennaklósett',
    '🚻' => 'salernisaðstaða',
    '🚼' => 'barnamerki',
    '🚾' => 'salerni',
    '🛂' => 'vegabréfaeftirlit',
    '🛃' => 'tollur',
    '🛄' => 'töskur',
    '🛅' => 'farangursgeymsla',
    '⚠' => 'varúð',
    '🚸' => 'börn á ferð',
    '⛔' => 'einstefna',
    '🚫' => 'bannað',
    '🚳' => 'hjólreiðar bannaðar',
    '🚭' => 'reykingar bannaðar',
    '🚯' => 'ekkert rusl',
    '🚱' => 'óhæft drykkjarvatn',
    '🚷' => 'bannað að ganga',
    '📵' => 'enginn farsími',
    '🔞' => 'enginn undir 18 ára',
    '☢' => 'geislavirkni',
    '☣' => 'hættuleg efni',
    '⬆' => 'ör upp',
    '↗' => 'ör ská upp til hægri',
    '➡' => 'ör til hægri',
    '↘' => 'ör ská niður til hægri',
    '⬇' => 'ör niður',
    '↙' => 'ör ská niður til vinstri',
    '⬅' => 'ör til vinstri',
    '↖' => 'ör ská upp til vinstri',
    '↕' => 'ör upp og niður',
    '↔' => 'ör til vinstri og hægri',
    '↩' => 'sveigð ör til vinstri',
    '↪' => 'sveigð ör til hægri',
    '⤴' => 'sveigð ör upp',
    '⤵' => 'sveigð ör niður',
    '🔃' => 'endurhlaða',
    '🔄' => 'rangsælis örvar',
    '🔙' => 'til baka',
    '🔚' => 'endir',
    '🔛' => 'kveikt-ör',
    '🔜' => 'bráðum-ör',
    '🔝' => 'efst-ör',
    '🛐' => 'tilbeiðslustaður',
    '⚛' => 'frumeindartákn',
    '🕉' => 'om-merki',
    '✡' => 'davíðsstjarna',
    '☸' => 'dharmahjól',
    '☯' => 'jin jang',
    '✝' => 'latneskur kross',
    '☦' => 'rétttrúnaðarkross',
    '☪' => 'stjarna og skarður máni',
    '☮' => 'friðartákn',
    '🕎' => 'menorah-ljósastika',
    '🔯' => 'sexhyrnd stjarna',
    '🪯' => 'khanda',
    '♈' => 'hrúturinn',
    '♉' => 'nautið',
    '♊' => 'tvíburar',
    '♋' => 'krabbinn',
    '♌' => 'ljónið',
    '♍' => 'meyja',
    '♎' => 'vogin',
    '♏' => 'sporðdrekinn',
    '♐' => 'bogmaður',
    '♑' => 'steingeit',
    '♒' => 'vatnsberi',
    '♓' => 'fiskar',
    '⛎' => 'naðurvaldi',
    '🔀' => 'fléttaðar örvar til hægri',
    '🔁' => 'endurtaka',
    '🔂' => 'réttsælis örvar',
    '▶' => 'spilunartakki',
    '⏩' => 'spóla áfram',
    '⏭' => 'skiptitakki',
    '⏯' => 'spilunar- og pásuhnappur',
    '◀' => 'hnappur til að spóla til baka',
    '⏪' => 'spóla til baka',
    '⏮' => 'hnappur til að skipta á síðustu rás',
    '🔼' => 'uppvísandi þríhyrningur',
    '⏫' => 'uppör',
    '🔽' => 'niðurvísandi þríhyrningur',
    '⏬' => 'niðurör',
    '⏸' => 'pásutakki',
    '⏹' => 'stopptakki',
    '⏺' => 'upptökutakki',
    '⏏' => 'takki til að opna',
    '🎦' => 'bíó',
    '🔅' => 'lítil birta',
    '🔆' => 'mikil birta',
    '📶' => 'farsímasamband',
    '🛜' => 'þráðlaust',
    '📳' => 'titringur',
    '📴' => 'slökkt á síma',
    '♀' => 'kvenkyns merki',
    '♂' => 'karlkyns merki',
    '⚧' => 'transmerki',
    '✖' => 'margföldunartákn',
    '➕' => 'plús',
    '➖' => 'mínus',
    '➗' => 'deiling',
    '🟰' => 'þungt jafnaðarmerki',
    '♾' => 'óendanleiki',
    '‼' => 'tvöfalt upphrópunarmerki',
    '⁉' => 'upphrópunarmerki og spurningarmerki',
    '❓' => 'rautt spurningarmerki',
    '❔' => 'hvítt spurningarmerki',
    '❕' => 'hvítt upphrópunarmerki',
    '❗' => 'rautt upphrópunarmerki',
    '〰' => 'bugðustrik',
    '💱' => 'gjaldmiðlar',
    '💲' => 'dollaramerki',
    '⚕' => 'lækningamerki',
    '♻' => 'endurvinnsla',
    '⚜' => 'fleur-de-lis-tákn',
    '🔱' => 'þríforkur',
    '📛' => 'nafnspjald',
    '🔰' => 'græn og gul lauf',
    '⭕' => 'holur rauður hringur',
    '✅' => 'hakmerki',
    '☑' => 'hakreitur með hakmerki',
    '✔' => 'hak',
    '❌' => 'kross',
    '❎' => 'krosshnappur',
    '➰' => 'lykkja',
    '➿' => 'tvöföld lykkja',
    '〽' => 'japanskt upphafsmerki söngs',
    '✳' => 'áttarma stjörnumerki',
    '✴' => 'áttarma stjarna',
    '❇' => 'leiftur',
    '™' => 'skrásett vörumerki',
    '🫟' => 'sletta',
    '🔠' => 'hástafir',
    '🔡' => 'lágstafir',
    '🔢' => 'tölustafir',
    '🔣' => 'tákn',
    '🔤' => 'latneska stafrófið',
    '🅰' => 'A-blóðflokkur',
    '🆎' => 'AB-blóðflokkur',
    '🅱' => 'B-blóðflokkur',
    '🆑' => 'CL',
    '🆒' => 'svalt',
    '🆓' => 'ókeypis',
    'ℹ' => 'upplýsingaveita',
    '🆔' => 'ID',
    'Ⓜ' => 'bókstafurinn m inni í hring',
    '🆕' => 'nýtt',
    '🆖' => 'NG',
    '🅾' => 'O-blóðflokkur',
    '🆗' => 'OK',
    '🅿' => 'bílastæði',
    '🆘' => 'SOS',
    '🆙' => 'UP!',
    '🆚' => 'VS',
    '🈁' => 'katakana koko, kassi',
    '🈂' => 'katakana sa, kassi',
    '🈷' => 'mánaðarleg upphæð, kassi',
    '🈶' => '„Ekki ókeypis“ á japönsku',
    '🈯' => '„Frátekið“ á japönsku',
    '🉐' => '„Kjarakaup“ á japönsku',
    '🈹' => '„Afsláttur“ á japönsku',
    '🈚' => '„Ókeypis“ á japönsku',
    '🈲' => '„Bannað“ á japönsku',
    '🉑' => '„Viðunandi“ á japönsku',
    '🈸' => '„Umsókn“ á japönsku',
    '🈴' => '„Viðunandi einkunn“ á japönsku',
    '🈳' => '„Laust pláss“ á japönsku',
    '㊗' => '„Til hamingju“ á japönsku',
    '㊙' => '„Leyndarmál“ á japönsku',
    '🈺' => '„Opið“ á japönsku',
    '🈵' => '„Allt fullt“ á japönsku',
    '🔴' => 'stór rauður hringur',
    '🟠' => 'appelsínugulur hringur',
    '🟡' => 'gulur hringur',
    '🟢' => 'grænn hringur',
    '🔵' => 'stór blár hringur',
    '🟣' => 'fjólublár hringur',
    '🟤' => 'brúnn hringur',
    '⚫' => 'svartur hringur',
    '⚪' => 'hvítur hringur',
    '🟥' => 'rauður ferningur',
    '🟧' => 'appelsínugulur ferningur',
    '🟨' => 'gulur ferningur',
    '🟩' => 'grænn ferningur',
    '🟦' => 'blár ferningur',
    '🟪' => 'fjólublár ferningur',
    '🟫' => 'brúnn ferningur',
    '⬛' => 'stór svartur ferningur',
    '⬜' => 'stór hvítur ferningur',
    '◼' => 'svartur meðalstór ferningur',
    '◻' => 'hvítur meðalstór ferningur',
    '◾' => 'svartur meðalsmár ferningur',
    '◽' => 'hvítur meðalsmár ferningur',
    '▪' => 'lítill svartur ferningur',
    '▫' => 'lítill hvítur ferningur',
    '🔶' => 'stór appelsínugulur tígull',
    '🔷' => 'stór blár tígull',
    '🔸' => 'lítill appelsínugulur tígull',
    '🔹' => 'lítill blár tígull',
    '🔺' => 'uppvísandi rauður þríhyrningur',
    '🔻' => 'niðurvísandi rauður þríhyrningur',
    '💠' => 'blóm með punkti',
    '🔘' => 'valhnappur',
    '🔳' => 'hvítur ferningslaga hnappur',
    '🔲' => 'svartur ferningslaga hnappur',
    '🏁' => 'rásflagg',
    '🚩' => 'flagg',
    '🎌' => 'japanskir fánar í kross',
    '🏴' => 'svartur fáni',
    '🏳' => 'hvítur fáni',
];
