<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'კოცნა: სრულწლოვანი, სრულწლოვანი, კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏻‍❤‍💋‍👨🏻' => 'კოცნა: კაცი, კაცი, კანის ღია ტონალობა',
    '👨🏻‍❤‍💋‍👨🏼' => 'კოცნა: კაცი, კაცი, კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏻‍❤‍💋‍👨🏽' => 'კოცნა: კაცი, კაცი, კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👨🏻‍❤‍💋‍👨🏾' => 'კოცნა: კაცი, კაცი, კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏻‍❤‍💋‍👨🏿' => 'კოცნა: კაცი, კაცი, კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👨🏼‍❤‍💋‍👨🏻' => 'კოცნა: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏼‍❤‍💋‍👨🏼' => 'კოცნა: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏼‍❤‍💋‍👨🏽' => 'კოცნა: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏼‍❤‍💋‍👨🏾' => 'კოცნა: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏼‍❤‍💋‍👨🏿' => 'კოცნა: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏽‍❤‍💋‍👨🏻' => 'კოცნა: კაცი, კაცი, კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👨🏽‍❤‍💋‍👨🏼' => 'კოცნა: კაცი, კაცი, კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍❤‍💋‍👨🏽' => 'კოცნა: კაცი, კაცი, კანის საშუალო ტონალობა',
    '👨🏽‍❤‍💋‍👨🏾' => 'კოცნა: კაცი, კაცი, კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏽‍❤‍💋‍👨🏿' => 'კოცნა: კაცი, კაცი, კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👨🏾‍❤‍💋‍👨🏻' => 'კოცნა: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏾‍❤‍💋‍👨🏼' => 'კოცნა: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏾‍❤‍💋‍👨🏽' => 'კოცნა: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏾‍❤‍💋‍👨🏾' => 'კოცნა: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏾‍❤‍💋‍👨🏿' => 'კოცნა: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏿‍❤‍💋‍👨🏻' => 'კოცნა: კაცი, კაცი, კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👨🏿‍❤‍💋‍👨🏼' => 'კოცნა: კაცი, კაცი, კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏿‍❤‍💋‍👨🏽' => 'კოცნა: კაცი, კაცი, კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👨🏿‍❤‍💋‍👨🏾' => 'კოცნა: კაცი, კაცი, კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍❤‍💋‍👨🏿' => 'კოცნა: კაცი, კაცი, კანის მუქი ტონალობა',
    '👩🏻‍❤‍💋‍👨🏻' => 'კოცნა: ქალი, კაცი, კანის ღია ტონალობა',
    '👩🏻‍❤‍💋‍👨🏼' => 'კოცნა: ქალი, კაცი, კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏻‍❤‍💋‍👨🏽' => 'კოცნა: ქალი, კაცი, კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👩🏻‍❤‍💋‍👨🏾' => 'კოცნა: ქალი, კაცი, კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍❤‍💋‍👨🏿' => 'კოცნა: ქალი, კაცი, კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👩🏼‍❤‍💋‍👨🏻' => 'კოცნა: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏼‍❤‍💋‍👨🏼' => 'კოცნა: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏼‍❤‍💋‍👨🏽' => 'კოცნა: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏼‍❤‍💋‍👨🏾' => 'კოცნა: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏼‍❤‍💋‍👨🏿' => 'კოცნა: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏽‍❤‍💋‍👨🏻' => 'კოცნა: ქალი, კაცი, კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👩🏽‍❤‍💋‍👨🏼' => 'კოცნა: ქალი, კაცი, კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍❤‍💋‍👨🏽' => 'კოცნა: ქალი, კაცი, კანის საშუალო ტონალობა',
    '👩🏽‍❤‍💋‍👨🏾' => 'კოცნა: ქალი, კაცი, კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏽‍❤‍💋‍👨🏿' => 'კოცნა: ქალი, კაცი, კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👩🏾‍❤‍💋‍👨🏻' => 'კოცნა: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏾‍❤‍💋‍👨🏼' => 'კოცნა: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏾‍❤‍💋‍👨🏽' => 'კოცნა: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏾‍❤‍💋‍👨🏾' => 'კოცნა: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏾‍❤‍💋‍👨🏿' => 'კოცნა: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏿‍❤‍💋‍👨🏻' => 'კოცნა: ქალი, კაცი, კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👩🏿‍❤‍💋‍👨🏼' => 'კოცნა: ქალი, კაცი, კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏿‍❤‍💋‍👨🏽' => 'კოცნა: ქალი, კაცი, კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👩🏿‍❤‍💋‍👨🏾' => 'კოცნა: ქალი, კაცი, კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍❤‍💋‍👨🏿' => 'კოცნა: ქალი, კაცი, კანის მუქი ტონალობა',
    '👩🏻‍❤‍💋‍👩🏻' => 'კოცნა: ქალი, ქალი, კანის ღია ტონალობა',
    '👩🏻‍❤‍💋‍👩🏼' => 'კოცნა: ქალი, ქალი, კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏻‍❤‍💋‍👩🏽' => 'კოცნა: ქალი, ქალი, კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👩🏻‍❤‍💋‍👩🏾' => 'კოცნა: ქალი, ქალი, კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍❤‍💋‍👩🏿' => 'კოცნა: ქალი, ქალი, კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👩🏼‍❤‍💋‍👩🏻' => 'კოცნა: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏼‍❤‍💋‍👩🏼' => 'კოცნა: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏼‍❤‍💋‍👩🏽' => 'კოცნა: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏼‍❤‍💋‍👩🏾' => 'კოცნა: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏼‍❤‍💋‍👩🏿' => 'კოცნა: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏽‍❤‍💋‍👩🏻' => 'კოცნა: ქალი, ქალი, კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👩🏽‍❤‍💋‍👩🏼' => 'კოცნა: ქალი, ქალი, კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍❤‍💋‍👩🏽' => 'კოცნა: ქალი, ქალი, კანის საშუალო ტონალობა',
    '👩🏽‍❤‍💋‍👩🏾' => 'კოცნა: ქალი, ქალი, კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏽‍❤‍💋‍👩🏿' => 'კოცნა: ქალი, ქალი, კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👩🏾‍❤‍💋‍👩🏻' => 'კოცნა: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏾‍❤‍💋‍👩🏼' => 'კოცნა: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏾‍❤‍💋‍👩🏽' => 'კოცნა: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏾‍❤‍💋‍👩🏾' => 'კოცნა: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏾‍❤‍💋‍👩🏿' => 'კოცნა: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏿‍❤‍💋‍👩🏻' => 'კოცნა: ქალი, ქალი, კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👩🏿‍❤‍💋‍👩🏼' => 'კოცნა: ქალი, ქალი, კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏿‍❤‍💋‍👩🏽' => 'კოცნა: ქალი, ქალი, კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👩🏿‍❤‍💋‍👩🏾' => 'კოცნა: ქალი, ქალი, კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍❤‍💋‍👩🏿' => 'კოცნა: ქალი, ქალი, კანის მუქი ტონალობა',
    '🧑🏻‍🫯‍🧑🏼' => 'მოჭიდავეები: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏻‍🫯‍🧑🏽' => 'მოჭიდავეები: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏻‍🫯‍🧑🏾' => 'მოჭიდავეები: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏻‍🫯‍🧑🏿' => 'მოჭიდავეები: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '🧑🏼‍🫯‍🧑🏻' => 'მოჭიდავეები: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏼‍🫯‍🧑🏽' => 'მოჭიდავეები: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏼‍🫯‍🧑🏾' => 'მოჭიდავეები: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏼‍🫯‍🧑🏿' => 'მოჭიდავეები: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏽‍🫯‍🧑🏻' => 'მოჭიდავეები: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '🧑🏽‍🫯‍🧑🏼' => 'მოჭიდავეები: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🫯‍🧑🏾' => 'მოჭიდავეები: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏽‍🫯‍🧑🏿' => 'მოჭიდავეები: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '🧑🏾‍🫯‍🧑🏻' => 'მოჭიდავეები: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏾‍🫯‍🧑🏼' => 'მოჭიდავეები: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏾‍🫯‍🧑🏽' => 'მოჭიდავეები: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏾‍🫯‍🧑🏿' => 'მოჭიდავეები: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏿‍🫯‍🧑🏻' => 'მოჭიდავეები: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '🧑🏿‍🫯‍🧑🏼' => 'მოჭიდავეები: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏿‍🫯‍🧑🏽' => 'მოჭიდავეები: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏿‍🫯‍🧑🏾' => 'მოჭიდავეები: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏻‍❤‍🧑🏼' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏻‍❤‍🧑🏽' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏻‍❤‍🧑🏾' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏻‍❤‍🧑🏿' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '🧑🏼‍❤‍🧑🏻' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏼‍❤‍🧑🏽' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏼‍❤‍🧑🏾' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏼‍❤‍🧑🏿' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏽‍❤‍🧑🏻' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '🧑🏽‍❤‍🧑🏼' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍❤‍🧑🏾' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏽‍❤‍🧑🏿' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '🧑🏾‍❤‍🧑🏻' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏾‍❤‍🧑🏼' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏾‍❤‍🧑🏽' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏾‍❤‍🧑🏿' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏿‍❤‍🧑🏻' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '🧑🏿‍❤‍🧑🏼' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏿‍❤‍🧑🏽' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏿‍❤‍🧑🏾' => 'წყვილი და გული: სრულწლოვანი, სრულწლოვანი, კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏻‍🐰‍🧑🏼' => 'ქალები ერთობიან: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏻‍🐰‍🧑🏽' => 'ქალები ერთობიან: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏻‍🐰‍🧑🏾' => 'ქალები ერთობიან: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏻‍🐰‍🧑🏿' => 'ქალები ერთობიან: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '🧑🏼‍🐰‍🧑🏻' => 'ქალები ერთობიან: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏼‍🐰‍🧑🏽' => 'ქალები ერთობიან: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏼‍🐰‍🧑🏾' => 'ქალები ერთობიან: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏼‍🐰‍🧑🏿' => 'ქალები ერთობიან: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏽‍🐰‍🧑🏻' => 'ქალები ერთობიან: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '🧑🏽‍🐰‍🧑🏼' => 'ქალები ერთობიან: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🐰‍🧑🏾' => 'ქალები ერთობიან: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏽‍🐰‍🧑🏿' => 'ქალები ერთობიან: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '🧑🏾‍🐰‍🧑🏻' => 'ქალები ერთობიან: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏾‍🐰‍🧑🏼' => 'ქალები ერთობიან: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏾‍🐰‍🧑🏽' => 'ქალები ერთობიან: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏾‍🐰‍🧑🏿' => 'ქალები ერთობიან: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏿‍🐰‍🧑🏻' => 'ქალები ერთობიან: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '🧑🏿‍🐰‍🧑🏼' => 'ქალები ერთობიან: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏿‍🐰‍🧑🏽' => 'ქალები ერთობიან: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏿‍🐰‍🧑🏾' => 'ქალები ერთობიან: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏻‍🫯‍👨🏼' => 'მოჭიდავე კაცები: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏻‍🫯‍👨🏽' => 'მოჭიდავე კაცები: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👨🏻‍🫯‍👨🏾' => 'მოჭიდავე კაცები: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏻‍🫯‍👨🏿' => 'მოჭიდავე კაცები: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👨🏼‍🫯‍👨🏻' => 'მოჭიდავე კაცები: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏼‍🫯‍👨🏽' => 'მოჭიდავე კაცები: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏼‍🫯‍👨🏾' => 'მოჭიდავე კაცები: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏼‍🫯‍👨🏿' => 'მოჭიდავე კაცები: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏽‍🫯‍👨🏻' => 'მოჭიდავე კაცები: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👨🏽‍🫯‍👨🏼' => 'მოჭიდავე კაცები: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🫯‍👨🏾' => 'მოჭიდავე კაცები: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏽‍🫯‍👨🏿' => 'მოჭიდავე კაცები: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👨🏾‍🫯‍👨🏻' => 'მოჭიდავე კაცები: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏾‍🫯‍👨🏼' => 'მოჭიდავე კაცები: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏾‍🫯‍👨🏽' => 'მოჭიდავე კაცები: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏾‍🫯‍👨🏿' => 'მოჭიდავე კაცები: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏿‍🫯‍👨🏻' => 'მოჭიდავე კაცები: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👨🏿‍🫯‍👨🏼' => 'მოჭიდავე კაცები: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏿‍🫯‍👨🏽' => 'მოჭიდავე კაცები: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👨🏿‍🫯‍👨🏾' => 'მოჭიდავე კაცები: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏻‍❤‍👨🏻' => 'წყვილი და გული: კაცი, კაცი, კანის ღია ტონალობა',
    '👨🏻‍❤‍👨🏼' => 'წყვილი და გული: კაცი, კაცი, კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏻‍❤‍👨🏽' => 'წყვილი და გული: კაცი, კაცი, კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👨🏻‍❤‍👨🏾' => 'წყვილი და გული: კაცი, კაცი, კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏻‍❤‍👨🏿' => 'წყვილი და გული: კაცი, კაცი, კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👨🏼‍❤‍👨🏻' => 'წყვილი და გული: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏼‍❤‍👨🏼' => 'წყვილი და გული: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏼‍❤‍👨🏽' => 'წყვილი და გული: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏼‍❤‍👨🏾' => 'წყვილი და გული: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏼‍❤‍👨🏿' => 'წყვილი და გული: კაცი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏽‍❤‍👨🏻' => 'წყვილი და გული: კაცი, კაცი, კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👨🏽‍❤‍👨🏼' => 'წყვილი და გული: კაცი, კაცი, კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍❤‍👨🏽' => 'წყვილი და გული: კაცი, კაცი, კანის საშუალო ტონალობა',
    '👨🏽‍❤‍👨🏾' => 'წყვილი და გული: კაცი, კაცი, კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏽‍❤‍👨🏿' => 'წყვილი და გული: კაცი, კაცი, კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👨🏾‍❤‍👨🏻' => 'წყვილი და გული: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏾‍❤‍👨🏼' => 'წყვილი და გული: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏾‍❤‍👨🏽' => 'წყვილი და გული: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏾‍❤‍👨🏾' => 'წყვილი და გული: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏾‍❤‍👨🏿' => 'წყვილი და გული: კაცი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏿‍❤‍👨🏻' => 'წყვილი და გული: კაცი, კაცი, კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👨🏿‍❤‍👨🏼' => 'წყვილი და გული: კაცი, კაცი, კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏿‍❤‍👨🏽' => 'წყვილი და გული: კაცი, კაცი, კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👨🏿‍❤‍👨🏾' => 'წყვილი და გული: კაცი, კაცი, კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍❤‍👨🏿' => 'წყვილი და გული: კაცი, კაცი, კანის მუქი ტონალობა',
    '👨🏻‍🐰‍👨🏼' => 'მოცეკვავე კაცები: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏻‍🐰‍👨🏽' => 'მოცეკვავე კაცები: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👨🏻‍🐰‍👨🏾' => 'მოცეკვავე კაცები: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏻‍🐰‍👨🏿' => 'მოცეკვავე კაცები: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👨🏼‍🐰‍👨🏻' => 'მოცეკვავე კაცები: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏼‍🐰‍👨🏽' => 'მოცეკვავე კაცები: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏼‍🐰‍👨🏾' => 'მოცეკვავე კაცები: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏼‍🐰‍👨🏿' => 'მოცეკვავე კაცები: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏽‍🐰‍👨🏻' => 'მოცეკვავე კაცები: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👨🏽‍🐰‍👨🏼' => 'მოცეკვავე კაცები: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🐰‍👨🏾' => 'მოცეკვავე კაცები: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏽‍🐰‍👨🏿' => 'მოცეკვავე კაცები: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👨🏾‍🐰‍👨🏻' => 'მოცეკვავე კაცები: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏾‍🐰‍👨🏼' => 'მოცეკვავე კაცები: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏾‍🐰‍👨🏽' => 'მოცეკვავე კაცები: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏾‍🐰‍👨🏿' => 'მოცეკვავე კაცები: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏿‍🐰‍👨🏻' => 'მოცეკვავე კაცები: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👨🏿‍🐰‍👨🏼' => 'მოცეკვავე კაცები: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏿‍🐰‍👨🏽' => 'მოცეკვავე კაცები: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👨🏿‍🐰‍👨🏾' => 'მოცეკვავე კაცები: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍🫯‍👩🏼' => 'მოჭიდავე ქალები: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏻‍🫯‍👩🏽' => 'მოჭიდავე ქალები: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👩🏻‍🫯‍👩🏾' => 'მოჭიდავე ქალები: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍🫯‍👩🏿' => 'მოჭიდავე ქალები: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👩🏼‍🫯‍👩🏻' => 'მოჭიდავე ქალები: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏼‍🫯‍👩🏽' => 'მოჭიდავე ქალები: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏼‍🫯‍👩🏾' => 'მოჭიდავე ქალები: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏼‍🫯‍👩🏿' => 'მოჭიდავე ქალები: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏽‍🫯‍👩🏻' => 'მოჭიდავე ქალები: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👩🏽‍🫯‍👩🏼' => 'მოჭიდავე ქალები: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🫯‍👩🏾' => 'მოჭიდავე ქალები: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏽‍🫯‍👩🏿' => 'მოჭიდავე ქალები: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👩🏾‍🫯‍👩🏻' => 'მოჭიდავე ქალები: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏾‍🫯‍👩🏼' => 'მოჭიდავე ქალები: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏾‍🫯‍👩🏽' => 'მოჭიდავე ქალები: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏾‍🫯‍👩🏿' => 'მოჭიდავე ქალები: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏿‍🫯‍👩🏻' => 'მოჭიდავე ქალები: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👩🏿‍🫯‍👩🏼' => 'მოჭიდავე ქალები: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏿‍🫯‍👩🏽' => 'მოჭიდავე ქალები: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👩🏿‍🫯‍👩🏾' => 'მოჭიდავე ქალები: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍❤‍👨🏻' => 'წყვილი და გული: ქალი, კაცი, კანის ღია ტონალობა',
    '👩🏻‍❤‍👨🏼' => 'წყვილი და გული: ქალი, კაცი, კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏻‍❤‍👨🏽' => 'წყვილი და გული: ქალი, კაცი, კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👩🏻‍❤‍👨🏾' => 'წყვილი და გული: ქალი, კაცი, კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍❤‍👨🏿' => 'წყვილი და გული: ქალი, კაცი, კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👩🏼‍❤‍👨🏻' => 'წყვილი და გული: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏼‍❤‍👨🏼' => 'წყვილი და გული: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏼‍❤‍👨🏽' => 'წყვილი და გული: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏼‍❤‍👨🏾' => 'წყვილი და გული: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏼‍❤‍👨🏿' => 'წყვილი და გული: ქალი, კაცი, ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏽‍❤‍👨🏻' => 'წყვილი და გული: ქალი, კაცი, კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👩🏽‍❤‍👨🏼' => 'წყვილი და გული: ქალი, კაცი, კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍❤‍👨🏽' => 'წყვილი და გული: ქალი, კაცი, კანის საშუალო ტონალობა',
    '👩🏽‍❤‍👨🏾' => 'წყვილი და გული: ქალი, კაცი, კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏽‍❤‍👨🏿' => 'წყვილი და გული: ქალი, კაცი, კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👩🏾‍❤‍👨🏻' => 'წყვილი და გული: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏾‍❤‍👨🏼' => 'წყვილი და გული: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏾‍❤‍👨🏽' => 'წყვილი და გული: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏾‍❤‍👨🏾' => 'წყვილი და გული: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏾‍❤‍👨🏿' => 'წყვილი და გული: ქალი, კაცი, საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏿‍❤‍👨🏻' => 'წყვილი და გული: ქალი, კაცი, კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👩🏿‍❤‍👨🏼' => 'წყვილი და გული: ქალი, კაცი, კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏿‍❤‍👨🏽' => 'წყვილი და გული: ქალი, კაცი, კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👩🏿‍❤‍👨🏾' => 'წყვილი და გული: ქალი, კაცი, კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍❤‍👨🏿' => 'წყვილი და გული: ქალი, კაცი, კანის მუქი ტონალობა',
    '👩🏻‍❤‍👩🏻' => 'წყვილი და გული: ქალი, ქალი, კანის ღია ტონალობა',
    '👩🏻‍❤‍👩🏼' => 'წყვილი და გული: ქალი, ქალი, კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏻‍❤‍👩🏽' => 'წყვილი და გული: ქალი, ქალი, კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👩🏻‍❤‍👩🏾' => 'წყვილი და გული: ქალი, ქალი, კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍❤‍👩🏿' => 'წყვილი და გული: ქალი, ქალი, კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👩🏼‍❤‍👩🏻' => 'წყვილი და გული: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏼‍❤‍👩🏼' => 'წყვილი და გული: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏼‍❤‍👩🏽' => 'წყვილი და გული: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏼‍❤‍👩🏾' => 'წყვილი და გული: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏼‍❤‍👩🏿' => 'წყვილი და გული: ქალი, ქალი, ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏽‍❤‍👩🏻' => 'წყვილი და გული: ქალი, ქალი, კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👩🏽‍❤‍👩🏼' => 'წყვილი და გული: ქალი, ქალი, კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍❤‍👩🏽' => 'წყვილი და გული: ქალი, ქალი, კანის საშუალო ტონალობა',
    '👩🏽‍❤‍👩🏾' => 'წყვილი და გული: ქალი, ქალი, კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏽‍❤‍👩🏿' => 'წყვილი და გული: ქალი, ქალი, კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👩🏾‍❤‍👩🏻' => 'წყვილი და გული: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏾‍❤‍👩🏼' => 'წყვილი და გული: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏾‍❤‍👩🏽' => 'წყვილი და გული: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏾‍❤‍👩🏾' => 'წყვილი და გული: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏾‍❤‍👩🏿' => 'წყვილი და გული: ქალი, ქალი, საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏿‍❤‍👩🏻' => 'წყვილი და გული: ქალი, ქალი, კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👩🏿‍❤‍👩🏼' => 'წყვილი და გული: ქალი, ქალი, კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏿‍❤‍👩🏽' => 'წყვილი და გული: ქალი, ქალი, კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👩🏿‍❤‍👩🏾' => 'წყვილი და გული: ქალი, ქალი, კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍❤‍👩🏿' => 'წყვილი და გული: ქალი, ქალი, კანის მუქი ტონალობა',
    '👩🏻‍🐰‍👩🏼' => 'მოცეკვავე ქალები: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏻‍🐰‍👩🏽' => 'მოცეკვავე ქალები: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👩🏻‍🐰‍👩🏾' => 'მოცეკვავე ქალები: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍🐰‍👩🏿' => 'მოცეკვავე ქალები: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👩🏼‍🐰‍👩🏻' => 'მოცეკვავე ქალები: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏼‍🐰‍👩🏽' => 'მოცეკვავე ქალები: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏼‍🐰‍👩🏾' => 'მოცეკვავე ქალები: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏼‍🐰‍👩🏿' => 'მოცეკვავე ქალები: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏽‍🐰‍👩🏻' => 'მოცეკვავე ქალები: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👩🏽‍🐰‍👩🏼' => 'მოცეკვავე ქალები: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🐰‍👩🏾' => 'მოცეკვავე ქალები: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏽‍🐰‍👩🏿' => 'მოცეკვავე ქალები: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👩🏾‍🐰‍👩🏻' => 'მოცეკვავე ქალები: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏾‍🐰‍👩🏼' => 'მოცეკვავე ქალები: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏾‍🐰‍👩🏽' => 'მოცეკვავე ქალები: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏾‍🐰‍👩🏿' => 'მოცეკვავე ქალები: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏿‍🐰‍👩🏻' => 'მოცეკვავე ქალები: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👩🏿‍🐰‍👩🏼' => 'მოცეკვავე ქალები: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏿‍🐰‍👩🏽' => 'მოცეკვავე ქალები: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👩🏿‍🐰‍👩🏾' => 'მოცეკვავე ქალები: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏻‍🤝‍🧑🏻' => 'ხელჩაკიდებული ხალხი: კანის ღია ტონალობა',
    '🧑🏻‍🤝‍🧑🏼' => 'ხელჩაკიდებული ხალხი: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏻‍🤝‍🧑🏽' => 'ხელჩაკიდებული ხალხი: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏻‍🤝‍🧑🏾' => 'ხელჩაკიდებული ხალხი: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏻‍🤝‍🧑🏿' => 'ხელჩაკიდებული ხალხი: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '🧑🏼‍🤝‍🧑🏻' => 'ხელჩაკიდებული ხალხი: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏼‍🤝‍🧑🏼' => 'ხელჩაკიდებული ხალხი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏼‍🤝‍🧑🏽' => 'ხელჩაკიდებული ხალხი: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏼‍🤝‍🧑🏾' => 'ხელჩაკიდებული ხალხი: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏼‍🤝‍🧑🏿' => 'ხელჩაკიდებული ხალხი: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏽‍🤝‍🧑🏻' => 'ხელჩაკიდებული ხალხი: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '🧑🏽‍🤝‍🧑🏼' => 'ხელჩაკიდებული ხალხი: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🤝‍🧑🏽' => 'ხელჩაკიდებული ხალხი: კანის საშუალო ტონალობა',
    '🧑🏽‍🤝‍🧑🏾' => 'ხელჩაკიდებული ხალხი: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏽‍🤝‍🧑🏿' => 'ხელჩაკიდებული ხალხი: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '🧑🏾‍🤝‍🧑🏻' => 'ხელჩაკიდებული ხალხი: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '🧑🏾‍🤝‍🧑🏼' => 'ხელჩაკიდებული ხალხი: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏾‍🤝‍🧑🏽' => 'ხელჩაკიდებული ხალხი: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏾‍🤝‍🧑🏾' => 'ხელჩაკიდებული ხალხი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏾‍🤝‍🧑🏿' => 'ხელჩაკიდებული ხალხი: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🧑🏿‍🤝‍🧑🏻' => 'ხელჩაკიდებული ხალხი: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '🧑🏿‍🤝‍🧑🏼' => 'ხელჩაკიდებული ხალხი: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏿‍🤝‍🧑🏽' => 'ხელჩაკიდებული ხალხი: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '🧑🏿‍🤝‍🧑🏾' => 'ხელჩაკიდებული ხალხი: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🤝‍🧑🏿' => 'ხელჩაკიდებული ხალხი: კანის მუქი ტონალობა',
    '👩🏻‍🤝‍👩🏼' => 'ორი ხელჩაკიდებული ქალი: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏻‍🤝‍👩🏽' => 'ორი ხელჩაკიდებული ქალი: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👩🏻‍🤝‍👩🏾' => 'ორი ხელჩაკიდებული ქალი: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍🤝‍👩🏿' => 'ორი ხელჩაკიდებული ქალი: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👩🏼‍🤝‍👩🏻' => 'ორი ხელჩაკიდებული ქალი: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏼‍🤝‍👩🏽' => 'ორი ხელჩაკიდებული ქალი: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏼‍🤝‍👩🏾' => 'ორი ხელჩაკიდებული ქალი: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏼‍🤝‍👩🏿' => 'ორი ხელჩაკიდებული ქალი: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏽‍🤝‍👩🏻' => 'ორი ხელჩაკიდებული ქალი: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👩🏽‍🤝‍👩🏼' => 'ორი ხელჩაკიდებული ქალი: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🤝‍👩🏾' => 'ორი ხელჩაკიდებული ქალი: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏽‍🤝‍👩🏿' => 'ორი ხელჩაკიდებული ქალი: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👩🏾‍🤝‍👩🏻' => 'ორი ხელჩაკიდებული ქალი: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏾‍🤝‍👩🏼' => 'ორი ხელჩაკიდებული ქალი: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏾‍🤝‍👩🏽' => 'ორი ხელჩაკიდებული ქალი: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏾‍🤝‍👩🏿' => 'ორი ხელჩაკიდებული ქალი: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏿‍🤝‍👩🏻' => 'ორი ხელჩაკიდებული ქალი: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👩🏿‍🤝‍👩🏼' => 'ორი ხელჩაკიდებული ქალი: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏿‍🤝‍👩🏽' => 'ორი ხელჩაკიდებული ქალი: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👩🏿‍🤝‍👩🏾' => 'ორი ხელჩაკიდებული ქალი: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍🤝‍👨🏼' => 'ხელჩაკიდებული კაცი და ქალი: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏻‍🤝‍👨🏽' => 'ხელჩაკიდებული კაცი და ქალი: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👩🏻‍🤝‍👨🏾' => 'ხელჩაკიდებული კაცი და ქალი: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏻‍🤝‍👨🏿' => 'ხელჩაკიდებული კაცი და ქალი: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👩🏼‍🤝‍👨🏻' => 'ხელჩაკიდებული კაცი და ქალი: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏼‍🤝‍👨🏽' => 'ხელჩაკიდებული კაცი და ქალი: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏼‍🤝‍👨🏾' => 'ხელჩაკიდებული კაცი და ქალი: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏼‍🤝‍👨🏿' => 'ხელჩაკიდებული კაცი და ქალი: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏽‍🤝‍👨🏻' => 'ხელჩაკიდებული კაცი და ქალი: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👩🏽‍🤝‍👨🏼' => 'ხელჩაკიდებული კაცი და ქალი: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🤝‍👨🏾' => 'ხელჩაკიდებული კაცი და ქალი: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏽‍🤝‍👨🏿' => 'ხელჩაკიდებული კაცი და ქალი: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👩🏾‍🤝‍👨🏻' => 'ხელჩაკიდებული კაცი და ქალი: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👩🏾‍🤝‍👨🏼' => 'ხელჩაკიდებული კაცი და ქალი: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏾‍🤝‍👨🏽' => 'ხელჩაკიდებული კაცი და ქალი: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👩🏾‍🤝‍👨🏿' => 'ხელჩაკიდებული კაცი და ქალი: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👩🏿‍🤝‍👨🏻' => 'ხელჩაკიდებული კაცი და ქალი: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👩🏿‍🤝‍👨🏼' => 'ხელჩაკიდებული კაცი და ქალი: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👩🏿‍🤝‍👨🏽' => 'ხელჩაკიდებული კაცი და ქალი: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👩🏿‍🤝‍👨🏾' => 'ხელჩაკიდებული კაცი და ქალი: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏻‍🤝‍👨🏼' => 'ორი ხელჩაკიდებული კაცი: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏻‍🤝‍👨🏽' => 'ორი ხელჩაკიდებული კაცი: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '👨🏻‍🤝‍👨🏾' => 'ორი ხელჩაკიდებული კაცი: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏻‍🤝‍👨🏿' => 'ორი ხელჩაკიდებული კაცი: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '👨🏼‍🤝‍👨🏻' => 'ორი ხელჩაკიდებული კაცი: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏼‍🤝‍👨🏽' => 'ორი ხელჩაკიდებული კაცი: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏼‍🤝‍👨🏾' => 'ორი ხელჩაკიდებული კაცი: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏼‍🤝‍👨🏿' => 'ორი ხელჩაკიდებული კაცი: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏽‍🤝‍👨🏻' => 'ორი ხელჩაკიდებული კაცი: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '👨🏽‍🤝‍👨🏼' => 'ორი ხელჩაკიდებული კაცი: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🤝‍👨🏾' => 'ორი ხელჩაკიდებული კაცი: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏽‍🤝‍👨🏿' => 'ორი ხელჩაკიდებული კაცი: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '👨🏾‍🤝‍👨🏻' => 'ორი ხელჩაკიდებული კაცი: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '👨🏾‍🤝‍👨🏼' => 'ორი ხელჩაკიდებული კაცი: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏾‍🤝‍👨🏽' => 'ორი ხელჩაკიდებული კაცი: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '👨🏾‍🤝‍👨🏿' => 'ორი ხელჩაკიდებული კაცი: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '👨🏿‍🤝‍👨🏻' => 'ორი ხელჩაკიდებული კაცი: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '👨🏿‍🤝‍👨🏼' => 'ორი ხელჩაკიდებული კაცი: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '👨🏿‍🤝‍👨🏽' => 'ორი ხელჩაკიდებული კაცი: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '👨🏿‍🤝‍👨🏾' => 'ორი ხელჩაკიდებული კაცი: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '👩‍❤‍💋‍👨' => 'კოცნა: ქალი, კაცი',
    '👨‍❤‍💋‍👨' => 'კოცნა: კაცი, კაცი',
    '👩‍❤‍💋‍👩' => 'კოცნა: ქალი, ქალი',
    '👨‍👩‍👧‍👦' => 'ოჯახი: კაცი, ქალი, გოგო, ბიჭი',
    '👨‍👩‍👦‍👦' => 'ოჯახი: კაცი, ქალი, ბიჭი, ბიჭი',
    '👨‍👩‍👧‍👧' => 'ოჯახი: კაცი, ქალი, გოგო, გოგო',
    '👨‍👨‍👧‍👦' => 'ოჯახი: კაცი, კაცი, გოგო, ბიჭი',
    '👨‍👨‍👦‍👦' => 'ოჯახი: კაცი, კაცი, ბიჭი, ბიჭი',
    '👨‍👨‍👧‍👧' => 'ოჯახი: კაცი, კაცი, გოგო, გოგო',
    '👩‍👩‍👧‍👦' => 'ოჯახი: ქალი, ქალი, გოგო, ბიჭი',
    '👩‍👩‍👦‍👦' => 'ოჯახი: ქალი, ქალი, ბიჭი, ბიჭი',
    '👩‍👩‍👧‍👧' => 'ოჯახი: ქალი, ქალი, გოგო, გოგო',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'დროშა: ინგლისი',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'დროშა: შოტლანდია',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'დროშა: უელსი',
    '🧑‍🧑‍🧒‍🧒' => 'ოჯახი: ზრდასრული, ზრდასრული, ბავშვი, ბავშვი',
    '🚶🏻‍♀‍➡' => 'მოსიარულე ქალი: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🚶🏼‍♀‍➡' => 'მოსიარულე ქალი: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🚶🏽‍♀‍➡' => 'მოსიარულე ქალი: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🚶🏾‍♀‍➡' => 'მოსიარულე ქალი: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🚶🏿‍♀‍➡' => 'მოსიარულე ქალი: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🚶🏻‍♂‍➡' => 'მოსიარულე კაცი: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🚶🏼‍♂‍➡' => 'მოსიარულე კაცი: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🚶🏽‍♂‍➡' => 'მოსიარულე კაცი: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🚶🏾‍♂‍➡' => 'მოსიარულე კაცი: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🚶🏿‍♂‍➡' => 'მოსიარულე კაცი: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🧎🏻‍♀‍➡' => 'დაჩოქილი ქალი: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🧎🏼‍♀‍➡' => 'დაჩოქილი ქალი: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧎🏽‍♀‍➡' => 'დაჩოქილი ქალი: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🧎🏾‍♀‍➡' => 'დაჩოქილი ქალი: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧎🏿‍♀‍➡' => 'დაჩოქილი ქალი: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🧎🏻‍♂‍➡' => 'დაჩოქილი კაცი: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🧎🏼‍♂‍➡' => 'დაჩოქილი კაცი: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧎🏽‍♂‍➡' => 'დაჩოქილი კაცი: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🧎🏾‍♂‍➡' => 'დაჩოქილი კაცი: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧎🏿‍♂‍➡' => 'დაჩოქილი კაცი: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🧑🏻‍🦯‍➡' => 'ადამიანი თეთრი ხელჯოხით: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🧑🏼‍🦯‍➡' => 'ადამიანი თეთრი ხელჯოხით: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧑🏽‍🦯‍➡' => 'ადამიანი თეთრი ხელჯოხით: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🧑🏾‍🦯‍➡' => 'ადამიანი თეთრი ხელჯოხით: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧑🏿‍🦯‍➡' => 'ადამიანი თეთრი ხელჯოხით: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '👨🏻‍🦯‍➡' => 'კაცი თეთრი ჯოხით: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '👨🏼‍🦯‍➡' => 'კაცი თეთრი ჯოხით: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👨🏽‍🦯‍➡' => 'კაცი თეთრი ჯოხით: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '👨🏾‍🦯‍➡' => 'კაცი თეთრი ჯოხით: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👨🏿‍🦯‍➡' => 'კაცი თეთრი ჯოხით: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '👩🏻‍🦯‍➡' => 'ქალი თეთრი ჯოხით: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '👩🏼‍🦯‍➡' => 'ქალი თეთრი ჯოხით: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👩🏽‍🦯‍➡' => 'ქალი თეთრი ჯოხით: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '👩🏾‍🦯‍➡' => 'ქალი თეთრი ჯოხით: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👩🏿‍🦯‍➡' => 'ქალი თეთრი ჯოხით: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🧑🏻‍🦼‍➡' => 'ადამიანი მოტორიან ეტლში: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🧑🏼‍🦼‍➡' => 'ადამიანი მოტორიან ეტლში: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧑🏽‍🦼‍➡' => 'ადამიანი მოტორიან ეტლში: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🧑🏾‍🦼‍➡' => 'ადამიანი მოტორიან ეტლში: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧑🏿‍🦼‍➡' => 'ადამიანი მოტორიან ეტლში: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '👨🏻‍🦼‍➡' => 'კაცი მოტორიან ეტლში: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '👨🏼‍🦼‍➡' => 'კაცი მოტორიან ეტლში: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👨🏽‍🦼‍➡' => 'კაცი მოტორიან ეტლში: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '👨🏾‍🦼‍➡' => 'კაცი მოტორიან ეტლში: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👨🏿‍🦼‍➡' => 'კაცი მოტორიან ეტლში: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '👩🏻‍🦼‍➡' => 'ქალი მოტორიან ეტლში: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '👩🏼‍🦼‍➡' => 'ქალი მოტორიან ეტლში: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👩🏽‍🦼‍➡' => 'ქალი მოტორიან ეტლში: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '👩🏾‍🦼‍➡' => 'ქალი მოტორიან ეტლში: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👩🏿‍🦼‍➡' => 'ქალი მოტორიან ეტლში: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🧑🏻‍🦽‍➡' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🧑🏼‍🦽‍➡' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧑🏽‍🦽‍➡' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🧑🏾‍🦽‍➡' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧑🏿‍🦽‍➡' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '👨🏻‍🦽‍➡' => 'კაცი შშმ პირის მექანიკურ ეტლში: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '👨🏼‍🦽‍➡' => 'კაცი შშმ პირის მექანიკურ ეტლში: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👨🏽‍🦽‍➡' => 'კაცი შშმ პირის მექანიკურ ეტლში: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '👨🏾‍🦽‍➡' => 'კაცი შშმ პირის მექანიკურ ეტლში: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👨🏿‍🦽‍➡' => 'კაცი შშმ პირის მექანიკურ ეტლში: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '👩🏻‍🦽‍➡' => 'ქალი შშმ პირის მექანიკურ ეტლში: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '👩🏼‍🦽‍➡' => 'ქალი შშმ პირის მექანიკურ ეტლში: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👩🏽‍🦽‍➡' => 'ქალი შშმ პირის მექანიკურ ეტლში: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '👩🏾‍🦽‍➡' => 'ქალი შშმ პირის მექანიკურ ეტლში: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '👩🏿‍🦽‍➡' => 'ქალი შშმ პირის მექანიკურ ეტლში: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🏃🏻‍♀‍➡' => 'მორბენალი ქალი: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🏃🏼‍♀‍➡' => 'მორბენალი ქალი: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🏃🏽‍♀‍➡' => 'მორბენალი ქალი: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🏃🏾‍♀‍➡' => 'მორბენალი ქალი: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🏃🏿‍♀‍➡' => 'მორბენალი ქალი: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🏃🏻‍♂‍➡' => 'მორბენალი კაცი: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🏃🏼‍♂‍➡' => 'მორბენალი კაცი: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🏃🏽‍♂‍➡' => 'მორბენალი კაცი: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🏃🏾‍♂‍➡' => 'მორბენალი კაცი: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🏃🏿‍♂‍➡' => 'მორბენალი კაცი: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🫱🏻‍🫲🏼' => 'ხელის ჩამორთმევა: კანის ღია ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🫱🏻‍🫲🏽' => 'ხელის ჩამორთმევა: კანის ღია ტონალობა, კანის საშუალო ტონალობა',
    '🫱🏻‍🫲🏾' => 'ხელის ჩამორთმევა: კანის ღია ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🫱🏻‍🫲🏿' => 'ხელის ჩამორთმევა: კანის ღია ტონალობა, კანის მუქი ტონალობა',
    '🫱🏼‍🫲🏻' => 'ხელის ჩამორთმევა: ღიადან საშუალომდე კანის ტონალობა, კანის ღია ტონალობა',
    '🫱🏼‍🫲🏽' => 'ხელის ჩამორთმევა: ღიადან საშუალომდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🫱🏼‍🫲🏾' => 'ხელის ჩამორთმევა: ღიადან საშუალომდე კანის ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🫱🏼‍🫲🏿' => 'ხელის ჩამორთმევა: ღიადან საშუალომდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🫱🏽‍🫲🏻' => 'ხელის ჩამორთმევა: კანის საშუალო ტონალობა, კანის ღია ტონალობა',
    '🫱🏽‍🫲🏼' => 'ხელის ჩამორთმევა: კანის საშუალო ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🫱🏽‍🫲🏾' => 'ხელის ჩამორთმევა: კანის საშუალო ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🫱🏽‍🫲🏿' => 'ხელის ჩამორთმევა: კანის საშუალო ტონალობა, კანის მუქი ტონალობა',
    '🫱🏾‍🫲🏻' => 'ხელის ჩამორთმევა: საშუალოდან მუქამდე კანის ტონალობა, კანის ღია ტონალობა',
    '🫱🏾‍🫲🏼' => 'ხელის ჩამორთმევა: საშუალოდან მუქამდე კანის ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🫱🏾‍🫲🏽' => 'ხელის ჩამორთმევა: საშუალოდან მუქამდე კანის ტონალობა, კანის საშუალო ტონალობა',
    '🫱🏾‍🫲🏿' => 'ხელის ჩამორთმევა: საშუალოდან მუქამდე კანის ტონალობა, კანის მუქი ტონალობა',
    '🫱🏿‍🫲🏻' => 'ხელის ჩამორთმევა: კანის მუქი ტონალობა, კანის ღია ტონალობა',
    '🫱🏿‍🫲🏼' => 'ხელის ჩამორთმევა: კანის მუქი ტონალობა, ღიადან საშუალომდე კანის ტონალობა',
    '🫱🏿‍🫲🏽' => 'ხელის ჩამორთმევა: კანის მუქი ტონალობა, კანის საშუალო ტონალობა',
    '🫱🏿‍🫲🏾' => 'ხელის ჩამორთმევა: კანის მუქი ტონალობა, საშუალოდან მუქამდე კანის ტონალობა',
    '🚶‍♀‍➡' => 'მოსიარულე ქალი: მარჯვნივ მიმართული',
    '🚶‍♂‍➡' => 'მოსიარულე კაცი: მარჯვნივ მიმართული',
    '🧎‍♀‍➡' => 'დაჩოქილი ქალი: მარჯვნივ მიმართული',
    '🧎‍♂‍➡' => 'დაჩოქილი კაცი: მარჯვნივ მიმართული',
    '🧑‍🦯‍➡' => 'ადამიანი თეთრი ხელჯოხით: მარჯვნივ მიმართული',
    '👨‍🦯‍➡' => 'კაცი თეთრი ჯოხით: მარჯვნივ მიმართული',
    '👩‍🦯‍➡' => 'ქალი თეთრი ჯოხით: მარჯვნივ მიმართული',
    '🧑‍🦼‍➡' => 'ადამიანი მოტორიან ეტლში: მარჯვნივ მიმართული',
    '👨‍🦼‍➡' => 'კაცი მოტორიან ეტლში: მარჯვნივ მიმართული',
    '👩‍🦼‍➡' => 'ქალი მოტორიან ეტლში: მარჯვნივ მიმართული',
    '🧑‍🦽‍➡' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: მარჯვნივ მიმართული',
    '👨‍🦽‍➡' => 'კაცი შშმ პირის მექანიკურ ეტლში: მარჯვნივ მიმართული',
    '👩‍🦽‍➡' => 'ქალი შშმ პირის მექანიკურ ეტლში: მარჯვნივ მიმართული',
    '🏃‍♀‍➡' => 'მორბენალი ქალი: მარჯვნივ მიმართული',
    '🏃‍♂‍➡' => 'მორბენალი კაცი: მარჯვნივ მიმართული',
    '👩‍❤‍👨' => 'წყვილი და გული: ქალი, კაცი',
    '👨‍❤‍👨' => 'წყვილი და გული: კაცი, კაცი',
    '👩‍❤‍👩' => 'წყვილი და გული: ქალი, ქალი',
    '👨‍👩‍👦' => 'ოჯახი: კაცი, ქალი, ბიჭი',
    '👨‍👩‍👧' => 'ოჯახი: კაცი, ქალი, გოგო',
    '👨‍👨‍👦' => 'ოჯახი: კაცი, კაცი, ბიჭი',
    '👨‍👨‍👧' => 'ოჯახი: კაცი, კაცი, გოგო',
    '👩‍👩‍👦' => 'ოჯახი: ქალი, ქალი, ბიჭი',
    '👩‍👩‍👧' => 'ოჯახი: ქალი, ქალი, გოგო',
    '👨‍👦‍👦' => 'ოჯახი: კაცი, ბიჭი, ბიჭი',
    '👨‍👧‍👦' => 'ოჯახი: კაცი, გოგო, ბიჭი',
    '👨‍👧‍👧' => 'ოჯახი: კაცი, გოგო, გოგო',
    '👩‍👦‍👦' => 'ოჯახი: ქალი, ბიჭი, ბიჭი',
    '👩‍👧‍👦' => 'ოჯახი: ქალი, გოგო, ბიჭი',
    '👩‍👧‍👧' => 'ოჯახი: ქალი, გოგო, გოგო',
    '🧑‍🤝‍🧑' => 'ხელჩაკიდებული ხალხი',
    '🧑‍🧑‍🧒' => 'ოჯახი: ზრდასრული, ზრდასრული, ბავშვი',
    '🧑‍🧒‍🧒' => 'ოჯახი: ზრდასრული, ბავშვი, ბავშვი',
    '🧑🏻‍🦰' => 'სრულწლოვანი: კანის ღია ტონალობა, წითელი თმა',
    '🧑🏼‍🦰' => 'სრულწლოვანი: ღიადან საშუალომდე კანის ტონალობა, წითელი თმა',
    '🧑🏽‍🦰' => 'სრულწლოვანი: კანის საშუალო ტონალობა, წითელი თმა',
    '🧑🏾‍🦰' => 'სრულწლოვანი: საშუალოდან მუქამდე კანის ტონალობა, წითელი თმა',
    '🧑🏿‍🦰' => 'სრულწლოვანი: კანის მუქი ტონალობა, წითელი თმა',
    '🧑🏻‍🦱' => 'სრულწლოვანი: კანის ღია ტონალობა, ხვეული თმა',
    '🧑🏼‍🦱' => 'სრულწლოვანი: ღიადან საშუალომდე კანის ტონალობა, ხვეული თმა',
    '🧑🏽‍🦱' => 'სრულწლოვანი: კანის საშუალო ტონალობა, ხვეული თმა',
    '🧑🏾‍🦱' => 'სრულწლოვანი: საშუალოდან მუქამდე კანის ტონალობა, ხვეული თმა',
    '🧑🏿‍🦱' => 'სრულწლოვანი: კანის მუქი ტონალობა, ხვეული თმა',
    '🧑🏻‍🦳' => 'სრულწლოვანი: კანის ღია ტონალობა, თეთრი თმა',
    '🧑🏼‍🦳' => 'სრულწლოვანი: ღიადან საშუალომდე კანის ტონალობა, თეთრი თმა',
    '🧑🏽‍🦳' => 'სრულწლოვანი: კანის საშუალო ტონალობა, თეთრი თმა',
    '🧑🏾‍🦳' => 'სრულწლოვანი: საშუალოდან მუქამდე კანის ტონალობა, თეთრი თმა',
    '🧑🏿‍🦳' => 'სრულწლოვანი: კანის მუქი ტონალობა, თეთრი თმა',
    '🧑🏻‍🦲' => 'სრულწლოვანი: კანის ღია ტონალობა, მელოტი',
    '🧑🏼‍🦲' => 'სრულწლოვანი: ღიადან საშუალომდე კანის ტონალობა, მელოტი',
    '🧑🏽‍🦲' => 'სრულწლოვანი: კანის საშუალო ტონალობა, მელოტი',
    '🧑🏾‍🦲' => 'სრულწლოვანი: საშუალოდან მუქამდე კანის ტონალობა, მელოტი',
    '🧑🏿‍🦲' => 'სრულწლოვანი: კანის მუქი ტონალობა, მელოტი',
    '🧑🏻‍🩰' => 'ბალერინა: კანის ღია ტონალობა',
    '🧑🏼‍🩰' => 'ბალერინა: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🩰' => 'ბალერინა: კანის საშუალო ტონალობა',
    '🧑🏾‍🩰' => 'ბალერინა: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🩰' => 'ბალერინა: კანის მუქი ტონალობა',
    '🧔🏻‍♂' => 'კაცი: კანის ღია ტონალობა, წვერი',
    '🧔🏼‍♂' => 'კაცი: ღიადან საშუალომდე კანის ტონალობა, წვერი',
    '🧔🏽‍♂' => 'კაცი: კანის საშუალო ტონალობა, წვერი',
    '🧔🏾‍♂' => 'კაცი: საშუალოდან მუქამდე კანის ტონალობა, წვერი',
    '🧔🏿‍♂' => 'კაცი: კანის მუქი ტონალობა, წვერი',
    '👱🏻‍♂' => 'ქერათმიანი კაცი: კანის ღია ტონალობა',
    '👱🏼‍♂' => 'ქერათმიანი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👱🏽‍♂' => 'ქერათმიანი კაცი: კანის საშუალო ტონალობა',
    '👱🏾‍♂' => 'ქერათმიანი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👱🏿‍♂' => 'ქერათმიანი კაცი: კანის მუქი ტონალობა',
    '👨🏻‍🦰' => 'კაცი: კანის ღია ტონალობა, წითელი თმა',
    '👨🏼‍🦰' => 'კაცი: ღიადან საშუალომდე კანის ტონალობა, წითელი თმა',
    '👨🏽‍🦰' => 'კაცი: კანის საშუალო ტონალობა, წითელი თმა',
    '👨🏾‍🦰' => 'კაცი: საშუალოდან მუქამდე კანის ტონალობა, წითელი თმა',
    '👨🏿‍🦰' => 'კაცი: კანის მუქი ტონალობა, წითელი თმა',
    '👨🏻‍🦱' => 'კაცი: კანის ღია ტონალობა, ხვეული თმა',
    '👨🏼‍🦱' => 'კაცი: ღიადან საშუალომდე კანის ტონალობა, ხვეული თმა',
    '👨🏽‍🦱' => 'კაცი: კანის საშუალო ტონალობა, ხვეული თმა',
    '👨🏾‍🦱' => 'კაცი: საშუალოდან მუქამდე კანის ტონალობა, ხვეული თმა',
    '👨🏿‍🦱' => 'კაცი: კანის მუქი ტონალობა, ხვეული თმა',
    '👨🏻‍🦳' => 'კაცი: კანის ღია ტონალობა, თეთრი თმა',
    '👨🏼‍🦳' => 'კაცი: ღიადან საშუალომდე კანის ტონალობა, თეთრი თმა',
    '👨🏽‍🦳' => 'კაცი: კანის საშუალო ტონალობა, თეთრი თმა',
    '👨🏾‍🦳' => 'კაცი: საშუალოდან მუქამდე კანის ტონალობა, თეთრი თმა',
    '👨🏿‍🦳' => 'კაცი: კანის მუქი ტონალობა, თეთრი თმა',
    '👨🏻‍🦲' => 'კაცი: კანის ღია ტონალობა, მელოტი',
    '👨🏼‍🦲' => 'კაცი: ღიადან საშუალომდე კანის ტონალობა, მელოტი',
    '👨🏽‍🦲' => 'კაცი: კანის საშუალო ტონალობა, მელოტი',
    '👨🏾‍🦲' => 'კაცი: საშუალოდან მუქამდე კანის ტონალობა, მელოტი',
    '👨🏿‍🦲' => 'კაცი: კანის მუქი ტონალობა, მელოტი',
    '🧔🏻‍♀' => 'ქალი: კანის ღია ტონალობა, წვერი',
    '🧔🏼‍♀' => 'ქალი: ღიადან საშუალომდე კანის ტონალობა, წვერი',
    '🧔🏽‍♀' => 'ქალი: კანის საშუალო ტონალობა, წვერი',
    '🧔🏾‍♀' => 'ქალი: საშუალოდან მუქამდე კანის ტონალობა, წვერი',
    '🧔🏿‍♀' => 'ქალი: კანის მუქი ტონალობა, წვერი',
    '👱🏻‍♀' => 'ქერათმიანი ქალი: კანის ღია ტონალობა',
    '👱🏼‍♀' => 'ქერათმიანი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👱🏽‍♀' => 'ქერათმიანი ქალი: კანის საშუალო ტონალობა',
    '👱🏾‍♀' => 'ქერათმიანი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👱🏿‍♀' => 'ქერათმიანი ქალი: კანის მუქი ტონალობა',
    '👩🏻‍🦰' => 'ქალი: კანის ღია ტონალობა, წითელი თმა',
    '👩🏼‍🦰' => 'ქალი: ღიადან საშუალომდე კანის ტონალობა, წითელი თმა',
    '👩🏽‍🦰' => 'ქალი: კანის საშუალო ტონალობა, წითელი თმა',
    '👩🏾‍🦰' => 'ქალი: საშუალოდან მუქამდე კანის ტონალობა, წითელი თმა',
    '👩🏿‍🦰' => 'ქალი: კანის მუქი ტონალობა, წითელი თმა',
    '👩🏻‍🦱' => 'ქალი: კანის ღია ტონალობა, ხვეული თმა',
    '👩🏼‍🦱' => 'ქალი: ღიადან საშუალომდე კანის ტონალობა, ხვეული თმა',
    '👩🏽‍🦱' => 'ქალი: კანის საშუალო ტონალობა, ხვეული თმა',
    '👩🏾‍🦱' => 'ქალი: საშუალოდან მუქამდე კანის ტონალობა, ხვეული თმა',
    '👩🏿‍🦱' => 'ქალი: კანის მუქი ტონალობა, ხვეული თმა',
    '👩🏻‍🦳' => 'ქალი: კანის ღია ტონალობა, თეთრი თმა',
    '👩🏼‍🦳' => 'ქალი: ღიადან საშუალომდე კანის ტონალობა, თეთრი თმა',
    '👩🏽‍🦳' => 'ქალი: კანის საშუალო ტონალობა, თეთრი თმა',
    '👩🏾‍🦳' => 'ქალი: საშუალოდან მუქამდე კანის ტონალობა, თეთრი თმა',
    '👩🏿‍🦳' => 'ქალი: კანის მუქი ტონალობა, თეთრი თმა',
    '👩🏻‍🦲' => 'ქალი: კანის ღია ტონალობა, მელოტი',
    '👩🏼‍🦲' => 'ქალი: ღიადან საშუალომდე კანის ტონალობა, მელოტი',
    '👩🏽‍🦲' => 'ქალი: კანის საშუალო ტონალობა, მელოტი',
    '👩🏾‍🦲' => 'ქალი: საშუალოდან მუქამდე კანის ტონალობა, მელოტი',
    '👩🏿‍🦲' => 'ქალი: კანის მუქი ტონალობა, მელოტი',
    '🙍🏻‍♂' => 'შეჭმუხნილი კაცი: კანის ღია ტონალობა',
    '🙍🏼‍♂' => 'შეჭმუხნილი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🙍🏽‍♂' => 'შეჭმუხნილი კაცი: კანის საშუალო ტონალობა',
    '🙍🏾‍♂' => 'შეჭმუხნილი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🙍🏿‍♂' => 'შეჭმუხნილი კაცი: კანის მუქი ტონალობა',
    '🙍🏻‍♀' => 'შეჭმუხნილი ქალი: კანის ღია ტონალობა',
    '🙍🏼‍♀' => 'შეჭმუხნილი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🙍🏽‍♀' => 'შეჭმუხნილი ქალი: კანის საშუალო ტონალობა',
    '🙍🏾‍♀' => 'შეჭმუხნილი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🙍🏿‍♀' => 'შეჭმუხნილი ქალი: კანის მუქი ტონალობა',
    '🙎🏻‍♂' => 'გაბუტული კაცი: კანის ღია ტონალობა',
    '🙎🏼‍♂' => 'გაბუტული კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🙎🏽‍♂' => 'გაბუტული კაცი: კანის საშუალო ტონალობა',
    '🙎🏾‍♂' => 'გაბუტული კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🙎🏿‍♂' => 'გაბუტული კაცი: კანის მუქი ტონალობა',
    '🙎🏻‍♀' => 'გაბუტული ქალი: კანის ღია ტონალობა',
    '🙎🏼‍♀' => 'გაბუტული ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🙎🏽‍♀' => 'გაბუტული ქალი: კანის საშუალო ტონალობა',
    '🙎🏾‍♀' => 'გაბუტული ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🙎🏿‍♀' => 'გაბუტული ქალი: კანის მუქი ტონალობა',
    '🙅🏻‍♂' => 'კაცი ჟესტით „არა“: კანის ღია ტონალობა',
    '🙅🏼‍♂' => 'კაცი ჟესტით „არა“: ღიადან საშუალომდე კანის ტონალობა',
    '🙅🏽‍♂' => 'კაცი ჟესტით „არა“: კანის საშუალო ტონალობა',
    '🙅🏾‍♂' => 'კაცი ჟესტით „არა“: საშუალოდან მუქამდე კანის ტონალობა',
    '🙅🏿‍♂' => 'კაცი ჟესტით „არა“: კანის მუქი ტონალობა',
    '🙅🏻‍♀' => 'ქალი ჟესტით „არა“: კანის ღია ტონალობა',
    '🙅🏼‍♀' => 'ქალი ჟესტით „არა“: ღიადან საშუალომდე კანის ტონალობა',
    '🙅🏽‍♀' => 'ქალი ჟესტით „არა“: კანის საშუალო ტონალობა',
    '🙅🏾‍♀' => 'ქალი ჟესტით „არა“: საშუალოდან მუქამდე კანის ტონალობა',
    '🙅🏿‍♀' => 'ქალი ჟესტით „არა“: კანის მუქი ტონალობა',
    '🙆🏻‍♂' => 'კაცი ჟესტით „კარგი“: კანის ღია ტონალობა',
    '🙆🏼‍♂' => 'კაცი ჟესტით „კარგი“: ღიადან საშუალომდე კანის ტონალობა',
    '🙆🏽‍♂' => 'კაცი ჟესტით „კარგი“: კანის საშუალო ტონალობა',
    '🙆🏾‍♂' => 'კაცი ჟესტით „კარგი“: საშუალოდან მუქამდე კანის ტონალობა',
    '🙆🏿‍♂' => 'კაცი ჟესტით „კარგი“: კანის მუქი ტონალობა',
    '🙆🏻‍♀' => 'ქალი ჟესტით „კარგი“: კანის ღია ტონალობა',
    '🙆🏼‍♀' => 'ქალი ჟესტით „კარგი“: ღიადან საშუალომდე კანის ტონალობა',
    '🙆🏽‍♀' => 'ქალი ჟესტით „კარგი“: კანის საშუალო ტონალობა',
    '🙆🏾‍♀' => 'ქალი ჟესტით „კარგი“: საშუალოდან მუქამდე კანის ტონალობა',
    '🙆🏿‍♀' => 'ქალი ჟესტით „კარგი“: კანის მუქი ტონალობა',
    '💁🏻‍♂' => 'კაცი დახრილი ხელით: კანის ღია ტონალობა',
    '💁🏼‍♂' => 'კაცი დახრილი ხელით: ღიადან საშუალომდე კანის ტონალობა',
    '💁🏽‍♂' => 'კაცი დახრილი ხელით: კანის საშუალო ტონალობა',
    '💁🏾‍♂' => 'კაცი დახრილი ხელით: საშუალოდან მუქამდე კანის ტონალობა',
    '💁🏿‍♂' => 'კაცი დახრილი ხელით: კანის მუქი ტონალობა',
    '💁🏻‍♀' => 'ქალი დახრილი ხელით: კანის ღია ტონალობა',
    '💁🏼‍♀' => 'ქალი დახრილი ხელით: ღიადან საშუალომდე კანის ტონალობა',
    '💁🏽‍♀' => 'ქალი დახრილი ხელით: კანის საშუალო ტონალობა',
    '💁🏾‍♀' => 'ქალი დახრილი ხელით: საშუალოდან მუქამდე კანის ტონალობა',
    '💁🏿‍♀' => 'ქალი დახრილი ხელით: კანის მუქი ტონალობა',
    '🙋🏻‍♂' => 'ხელაწეული კაცი: კანის ღია ტონალობა',
    '🙋🏼‍♂' => 'ხელაწეული კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🙋🏽‍♂' => 'ხელაწეული კაცი: კანის საშუალო ტონალობა',
    '🙋🏾‍♂' => 'ხელაწეული კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🙋🏿‍♂' => 'ხელაწეული კაცი: კანის მუქი ტონალობა',
    '🙋🏻‍♀' => 'ხელაწეული ქალი: კანის ღია ტონალობა',
    '🙋🏼‍♀' => 'ხელაწეული ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🙋🏽‍♀' => 'ხელაწეული ქალი: კანის საშუალო ტონალობა',
    '🙋🏾‍♀' => 'ხელაწეული ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🙋🏿‍♀' => 'ხელაწეული ქალი: კანის მუქი ტონალობა',
    '🧏🏻‍♂' => 'ყრუ კაცი: კანის ღია ტონალობა',
    '🧏🏼‍♂' => 'ყრუ კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🧏🏽‍♂' => 'ყრუ კაცი: კანის საშუალო ტონალობა',
    '🧏🏾‍♂' => 'ყრუ კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧏🏿‍♂' => 'ყრუ კაცი: კანის მუქი ტონალობა',
    '🧏🏻‍♀' => 'ყრუ ქალი: კანის ღია ტონალობა',
    '🧏🏼‍♀' => 'ყრუ ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🧏🏽‍♀' => 'ყრუ ქალი: კანის საშუალო ტონალობა',
    '🧏🏾‍♀' => 'ყრუ ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧏🏿‍♀' => 'ყრუ ქალი: კანის მუქი ტონალობა',
    '🙇🏻‍♂' => 'თავდახრილი კაცი: კანის ღია ტონალობა',
    '🙇🏼‍♂' => 'თავდახრილი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🙇🏽‍♂' => 'თავდახრილი კაცი: კანის საშუალო ტონალობა',
    '🙇🏾‍♂' => 'თავდახრილი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🙇🏿‍♂' => 'თავდახრილი კაცი: კანის მუქი ტონალობა',
    '🙇🏻‍♀' => 'თავდახრილი ქალი: კანის ღია ტონალობა',
    '🙇🏼‍♀' => 'თავდახრილი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🙇🏽‍♀' => 'თავდახრილი ქალი: კანის საშუალო ტონალობა',
    '🙇🏾‍♀' => 'თავდახრილი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🙇🏿‍♀' => 'თავდახრილი ქალი: კანის მუქი ტონალობა',
    '🤦🏻‍♂' => 'სახეზე ხელაფარებული კაცი: კანის ღია ტონალობა',
    '🤦🏼‍♂' => 'სახეზე ხელაფარებული კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🤦🏽‍♂' => 'სახეზე ხელაფარებული კაცი: კანის საშუალო ტონალობა',
    '🤦🏾‍♂' => 'სახეზე ხელაფარებული კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤦🏿‍♂' => 'სახეზე ხელაფარებული კაცი: კანის მუქი ტონალობა',
    '🤦🏻‍♀' => 'სახეზე ხელაფარებული ქალი: კანის ღია ტონალობა',
    '🤦🏼‍♀' => 'სახეზე ხელაფარებული ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🤦🏽‍♀' => 'სახეზე ხელაფარებული ქალი: კანის საშუალო ტონალობა',
    '🤦🏾‍♀' => 'სახეზე ხელაფარებული ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤦🏿‍♀' => 'სახეზე ხელაფარებული ქალი: კანის მუქი ტონალობა',
    '🤷🏻‍♂' => 'კაცი მხრებს იჩეჩავს: კანის ღია ტონალობა',
    '🤷🏼‍♂' => 'კაცი მხრებს იჩეჩავს: ღიადან საშუალომდე კანის ტონალობა',
    '🤷🏽‍♂' => 'კაცი მხრებს იჩეჩავს: კანის საშუალო ტონალობა',
    '🤷🏾‍♂' => 'კაცი მხრებს იჩეჩავს: საშუალოდან მუქამდე კანის ტონალობა',
    '🤷🏿‍♂' => 'კაცი მხრებს იჩეჩავს: კანის მუქი ტონალობა',
    '🤷🏻‍♀' => 'ქალი მხრებს იჩეჩავს: კანის ღია ტონალობა',
    '🤷🏼‍♀' => 'ქალი მხრებს იჩეჩავს: ღიადან საშუალომდე კანის ტონალობა',
    '🤷🏽‍♀' => 'ქალი მხრებს იჩეჩავს: კანის საშუალო ტონალობა',
    '🤷🏾‍♀' => 'ქალი მხრებს იჩეჩავს: საშუალოდან მუქამდე კანის ტონალობა',
    '🤷🏿‍♀' => 'ქალი მხრებს იჩეჩავს: კანის მუქი ტონალობა',
    '🧑🏻‍⚕' => 'ჯანდაცვის თანამშრომელი: კანის ღია ტონალობა',
    '🧑🏼‍⚕' => 'ჯანდაცვის თანამშრომელი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍⚕' => 'ჯანდაცვის თანამშრომელი: კანის საშუალო ტონალობა',
    '🧑🏾‍⚕' => 'ჯანდაცვის თანამშრომელი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍⚕' => 'ჯანდაცვის თანამშრომელი: კანის მუქი ტონალობა',
    '👨🏻‍⚕' => 'ექიმი კაცი: კანის ღია ტონალობა',
    '👨🏼‍⚕' => 'ექიმი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍⚕' => 'ექიმი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍⚕' => 'ექიმი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍⚕' => 'ექიმი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍⚕' => 'ექიმი ქალი: კანის ღია ტონალობა',
    '👩🏼‍⚕' => 'ექიმი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍⚕' => 'ექიმი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍⚕' => 'ექიმი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍⚕' => 'ექიმი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🎓' => 'სტუდენტი: კანის ღია ტონალობა',
    '🧑🏼‍🎓' => 'სტუდენტი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🎓' => 'სტუდენტი: კანის საშუალო ტონალობა',
    '🧑🏾‍🎓' => 'სტუდენტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🎓' => 'სტუდენტი: კანის მუქი ტონალობა',
    '👨🏻‍🎓' => 'სტუდენტი კაცი: კანის ღია ტონალობა',
    '👨🏼‍🎓' => 'სტუდენტი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🎓' => 'სტუდენტი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🎓' => 'სტუდენტი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🎓' => 'სტუდენტი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🎓' => 'სტუდენტი ქალი: კანის ღია ტონალობა',
    '👩🏼‍🎓' => 'სტუდენტი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🎓' => 'სტუდენტი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🎓' => 'სტუდენტი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🎓' => 'სტუდენტი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🏫' => 'მასწავლებელი: კანის ღია ტონალობა',
    '🧑🏼‍🏫' => 'მასწავლებელი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🏫' => 'მასწავლებელი: კანის საშუალო ტონალობა',
    '🧑🏾‍🏫' => 'მასწავლებელი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🏫' => 'მასწავლებელი: კანის მუქი ტონალობა',
    '👨🏻‍🏫' => 'მასწავლებელი კაცი: კანის ღია ტონალობა',
    '👨🏼‍🏫' => 'მასწავლებელი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🏫' => 'მასწავლებელი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🏫' => 'მასწავლებელი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🏫' => 'მასწავლებელი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🏫' => 'მასწავლებელი ქალი: კანის ღია ტონალობა',
    '👩🏼‍🏫' => 'მასწავლებელი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🏫' => 'მასწავლებელი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🏫' => 'მასწავლებელი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🏫' => 'მასწავლებელი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍⚖' => 'მოსამართლე: კანის ღია ტონალობა',
    '🧑🏼‍⚖' => 'მოსამართლე: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍⚖' => 'მოსამართლე: კანის საშუალო ტონალობა',
    '🧑🏾‍⚖' => 'მოსამართლე: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍⚖' => 'მოსამართლე: კანის მუქი ტონალობა',
    '👨🏻‍⚖' => 'მოსამართლე კაცი: კანის ღია ტონალობა',
    '👨🏼‍⚖' => 'მოსამართლე კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍⚖' => 'მოსამართლე კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍⚖' => 'მოსამართლე კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍⚖' => 'მოსამართლე კაცი: კანის მუქი ტონალობა',
    '👩🏻‍⚖' => 'მოსამართლე ქალი: კანის ღია ტონალობა',
    '👩🏼‍⚖' => 'მოსამართლე ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍⚖' => 'მოსამართლე ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍⚖' => 'მოსამართლე ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍⚖' => 'მოსამართლე ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🌾' => 'ფერმერი: კანის ღია ტონალობა',
    '🧑🏼‍🌾' => 'ფერმერი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🌾' => 'ფერმერი: კანის საშუალო ტონალობა',
    '🧑🏾‍🌾' => 'ფერმერი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🌾' => 'ფერმერი: კანის მუქი ტონალობა',
    '👨🏻‍🌾' => 'ფერმერი კაცი: კანის ღია ტონალობა',
    '👨🏼‍🌾' => 'ფერმერი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🌾' => 'ფერმერი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🌾' => 'ფერმერი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🌾' => 'ფერმერი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🌾' => 'ფერმერი ქალი: კანის ღია ტონალობა',
    '👩🏼‍🌾' => 'ფერმერი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🌾' => 'ფერმერი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🌾' => 'ფერმერი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🌾' => 'ფერმერი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🍳' => 'მზარეული: კანის ღია ტონალობა',
    '🧑🏼‍🍳' => 'მზარეული: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🍳' => 'მზარეული: კანის საშუალო ტონალობა',
    '🧑🏾‍🍳' => 'მზარეული: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🍳' => 'მზარეული: კანის მუქი ტონალობა',
    '👨🏻‍🍳' => 'მზარეული კაცი: კანის ღია ტონალობა',
    '👨🏼‍🍳' => 'მზარეული კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🍳' => 'მზარეული კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🍳' => 'მზარეული კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🍳' => 'მზარეული კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🍳' => 'მზარეული ქალი: კანის ღია ტონალობა',
    '👩🏼‍🍳' => 'მზარეული ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🍳' => 'მზარეული ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🍳' => 'მზარეული ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🍳' => 'მზარეული ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🔧' => 'ხელოსანი: კანის ღია ტონალობა',
    '🧑🏼‍🔧' => 'ხელოსანი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🔧' => 'ხელოსანი: კანის საშუალო ტონალობა',
    '🧑🏾‍🔧' => 'ხელოსანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🔧' => 'ხელოსანი: კანის მუქი ტონალობა',
    '👨🏻‍🔧' => 'მექანიკოსი კაცი: კანის ღია ტონალობა',
    '👨🏼‍🔧' => 'მექანიკოსი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🔧' => 'მექანიკოსი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🔧' => 'მექანიკოსი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🔧' => 'მექანიკოსი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🔧' => 'მექანიკოსი ქალი: კანის ღია ტონალობა',
    '👩🏼‍🔧' => 'მექანიკოსი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🔧' => 'მექანიკოსი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🔧' => 'მექანიკოსი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🔧' => 'მექანიკოსი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🏭' => 'ქარხნის მუშა: კანის ღია ტონალობა',
    '🧑🏼‍🏭' => 'ქარხნის მუშა: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🏭' => 'ქარხნის მუშა: კანის საშუალო ტონალობა',
    '🧑🏾‍🏭' => 'ქარხნის მუშა: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🏭' => 'ქარხნის მუშა: კანის მუქი ტონალობა',
    '👨🏻‍🏭' => 'ქარხნის მუშაკი კაცი: კანის ღია ტონალობა',
    '👨🏼‍🏭' => 'ქარხნის მუშაკი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🏭' => 'ქარხნის მუშაკი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🏭' => 'ქარხნის მუშაკი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🏭' => 'ქარხნის მუშაკი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🏭' => 'ქარხნის მუშაკი ქალი: კანის ღია ტონალობა',
    '👩🏼‍🏭' => 'ქარხნის მუშაკი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🏭' => 'ქარხნის მუშაკი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🏭' => 'ქარხნის მუშაკი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🏭' => 'ქარხნის მუშაკი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍💼' => 'ოფისის თანამშრომელი: კანის ღია ტონალობა',
    '🧑🏼‍💼' => 'ოფისის თანამშრომელი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍💼' => 'ოფისის თანამშრომელი: კანის საშუალო ტონალობა',
    '🧑🏾‍💼' => 'ოფისის თანამშრომელი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍💼' => 'ოფისის თანამშრომელი: კანის მუქი ტონალობა',
    '👨🏻‍💼' => 'თანამშრომელი კაცი: კანის ღია ტონალობა',
    '👨🏼‍💼' => 'თანამშრომელი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍💼' => 'თანამშრომელი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍💼' => 'თანამშრომელი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍💼' => 'თანამშრომელი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍💼' => 'თანამშრომელი ქალი: კანის ღია ტონალობა',
    '👩🏼‍💼' => 'თანამშრომელი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍💼' => 'თანამშრომელი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍💼' => 'თანამშრომელი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍💼' => 'თანამშრომელი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🔬' => 'მეცნიერი: კანის ღია ტონალობა',
    '🧑🏼‍🔬' => 'მეცნიერი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🔬' => 'მეცნიერი: კანის საშუალო ტონალობა',
    '🧑🏾‍🔬' => 'მეცნიერი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🔬' => 'მეცნიერი: კანის მუქი ტონალობა',
    '👨🏻‍🔬' => 'მეცნიერი კაცი: კანის ღია ტონალობა',
    '👨🏼‍🔬' => 'მეცნიერი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🔬' => 'მეცნიერი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🔬' => 'მეცნიერი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🔬' => 'მეცნიერი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🔬' => 'მეცნიერი ქალი: კანის ღია ტონალობა',
    '👩🏼‍🔬' => 'მეცნიერი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🔬' => 'მეცნიერი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🔬' => 'მეცნიერი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🔬' => 'მეცნიერი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍💻' => 'ტექნოლოგი: კანის ღია ტონალობა',
    '🧑🏼‍💻' => 'ტექნოლოგი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍💻' => 'ტექნოლოგი: კანის საშუალო ტონალობა',
    '🧑🏾‍💻' => 'ტექნოლოგი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍💻' => 'ტექნოლოგი: კანის მუქი ტონალობა',
    '👨🏻‍💻' => 'პროგრამისტი კაცი: კანის ღია ტონალობა',
    '👨🏼‍💻' => 'პროგრამისტი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍💻' => 'პროგრამისტი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍💻' => 'პროგრამისტი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍💻' => 'პროგრამისტი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍💻' => 'პროგრამისტი ქალი: კანის ღია ტონალობა',
    '👩🏼‍💻' => 'პროგრამისტი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍💻' => 'პროგრამისტი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍💻' => 'პროგრამისტი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍💻' => 'პროგრამისტი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🎤' => 'მომღერალი: კანის ღია ტონალობა',
    '🧑🏼‍🎤' => 'მომღერალი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🎤' => 'მომღერალი: კანის საშუალო ტონალობა',
    '🧑🏾‍🎤' => 'მომღერალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🎤' => 'მომღერალი: კანის მუქი ტონალობა',
    '👨🏻‍🎤' => 'მომღერალი კაცი: კანის ღია ტონალობა',
    '👨🏼‍🎤' => 'მომღერალი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🎤' => 'მომღერალი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🎤' => 'მომღერალი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🎤' => 'მომღერალი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🎤' => 'მომღერალი ქალი: კანის ღია ტონალობა',
    '👩🏼‍🎤' => 'მომღერალი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🎤' => 'მომღერალი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🎤' => 'მომღერალი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🎤' => 'მომღერალი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🎨' => 'მხატვარი: კანის ღია ტონალობა',
    '🧑🏼‍🎨' => 'მხატვარი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🎨' => 'მხატვარი: კანის საშუალო ტონალობა',
    '🧑🏾‍🎨' => 'მხატვარი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🎨' => 'მხატვარი: კანის მუქი ტონალობა',
    '👨🏻‍🎨' => 'მხატვარი კაცი: კანის ღია ტონალობა',
    '👨🏼‍🎨' => 'მხატვარი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🎨' => 'მხატვარი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🎨' => 'მხატვარი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🎨' => 'მხატვარი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🎨' => 'მხატვარი ქალი: კანის ღია ტონალობა',
    '👩🏼‍🎨' => 'მხატვარი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🎨' => 'მხატვარი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🎨' => 'მხატვარი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🎨' => 'მხატვარი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍✈' => 'პილოტი: კანის ღია ტონალობა',
    '🧑🏼‍✈' => 'პილოტი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍✈' => 'პილოტი: კანის საშუალო ტონალობა',
    '🧑🏾‍✈' => 'პილოტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍✈' => 'პილოტი: კანის მუქი ტონალობა',
    '👨🏻‍✈' => 'პილოტი კაცი: კანის ღია ტონალობა',
    '👨🏼‍✈' => 'პილოტი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍✈' => 'პილოტი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍✈' => 'პილოტი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍✈' => 'პილოტი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍✈' => 'პილოტი ქალი: კანის ღია ტონალობა',
    '👩🏼‍✈' => 'პილოტი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍✈' => 'პილოტი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍✈' => 'პილოტი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍✈' => 'პილოტი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🚀' => 'ასტრონავტი: კანის ღია ტონალობა',
    '🧑🏼‍🚀' => 'ასტრონავტი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🚀' => 'ასტრონავტი: კანის საშუალო ტონალობა',
    '🧑🏾‍🚀' => 'ასტრონავტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🚀' => 'ასტრონავტი: კანის მუქი ტონალობა',
    '👨🏻‍🚀' => 'ასტრონავტი კაცი: კანის ღია ტონალობა',
    '👨🏼‍🚀' => 'ასტრონავტი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🚀' => 'ასტრონავტი კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🚀' => 'ასტრონავტი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🚀' => 'ასტრონავტი კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🚀' => 'ასტრონავტი ქალი: კანის ღია ტონალობა',
    '👩🏼‍🚀' => 'ასტრონავტი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🚀' => 'ასტრონავტი ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🚀' => 'ასტრონავტი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🚀' => 'ასტრონავტი ქალი: კანის მუქი ტონალობა',
    '🧑🏻‍🚒' => 'მეხანძრე: კანის ღია ტონალობა',
    '🧑🏼‍🚒' => 'მეხანძრე: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🚒' => 'მეხანძრე: კანის საშუალო ტონალობა',
    '🧑🏾‍🚒' => 'მეხანძრე: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🚒' => 'მეხანძრე: კანის მუქი ტონალობა',
    '👨🏻‍🚒' => 'მეხანძრე კაცი: კანის ღია ტონალობა',
    '👨🏼‍🚒' => 'მეხანძრე კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🚒' => 'მეხანძრე კაცი: კანის საშუალო ტონალობა',
    '👨🏾‍🚒' => 'მეხანძრე კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🚒' => 'მეხანძრე კაცი: კანის მუქი ტონალობა',
    '👩🏻‍🚒' => 'მეხანძრე ქალი: კანის ღია ტონალობა',
    '👩🏼‍🚒' => 'მეხანძრე ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🚒' => 'მეხანძრე ქალი: კანის საშუალო ტონალობა',
    '👩🏾‍🚒' => 'მეხანძრე ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🚒' => 'მეხანძრე ქალი: კანის მუქი ტონალობა',
    '👮🏻‍♂' => 'პოლიციელი კაცი: კანის ღია ტონალობა',
    '👮🏼‍♂' => 'პოლიციელი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👮🏽‍♂' => 'პოლიციელი კაცი: კანის საშუალო ტონალობა',
    '👮🏾‍♂' => 'პოლიციელი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👮🏿‍♂' => 'პოლიციელი კაცი: კანის მუქი ტონალობა',
    '👮🏻‍♀' => 'პოლიციელი ქალი: კანის ღია ტონალობა',
    '👮🏼‍♀' => 'პოლიციელი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👮🏽‍♀' => 'პოლიციელი ქალი: კანის საშუალო ტონალობა',
    '👮🏾‍♀' => 'პოლიციელი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👮🏿‍♀' => 'პოლიციელი ქალი: კანის მუქი ტონალობა',
    '🕵🏻‍♂' => 'დეტექტივი კაცი: კანის ღია ტონალობა',
    '🕵🏼‍♂' => 'დეტექტივი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🕵🏽‍♂' => 'დეტექტივი კაცი: კანის საშუალო ტონალობა',
    '🕵🏾‍♂' => 'დეტექტივი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🕵🏿‍♂' => 'დეტექტივი კაცი: კანის მუქი ტონალობა',
    '🕵🏻‍♀' => 'დეტექტივი ქალი: კანის ღია ტონალობა',
    '🕵🏼‍♀' => 'დეტექტივი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🕵🏽‍♀' => 'დეტექტივი ქალი: კანის საშუალო ტონალობა',
    '🕵🏾‍♀' => 'დეტექტივი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🕵🏿‍♀' => 'დეტექტივი ქალი: კანის მუქი ტონალობა',
    '💂🏻‍♂' => 'მცველი კაცი: კანის ღია ტონალობა',
    '💂🏼‍♂' => 'მცველი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '💂🏽‍♂' => 'მცველი კაცი: კანის საშუალო ტონალობა',
    '💂🏾‍♂' => 'მცველი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '💂🏿‍♂' => 'მცველი კაცი: კანის მუქი ტონალობა',
    '💂🏻‍♀' => 'მცველი ქალი: კანის ღია ტონალობა',
    '💂🏼‍♀' => 'მცველი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '💂🏽‍♀' => 'მცველი ქალი: კანის საშუალო ტონალობა',
    '💂🏾‍♀' => 'მცველი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '💂🏿‍♀' => 'მცველი ქალი: კანის მუქი ტონალობა',
    '👷🏻‍♂' => 'მუშა კაცი: კანის ღია ტონალობა',
    '👷🏼‍♂' => 'მუშა კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👷🏽‍♂' => 'მუშა კაცი: კანის საშუალო ტონალობა',
    '👷🏾‍♂' => 'მუშა კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👷🏿‍♂' => 'მუშა კაცი: კანის მუქი ტონალობა',
    '👷🏻‍♀' => 'მუშა ქალი: კანის ღია ტონალობა',
    '👷🏼‍♀' => 'მუშა ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👷🏽‍♀' => 'მუშა ქალი: კანის საშუალო ტონალობა',
    '👷🏾‍♀' => 'მუშა ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👷🏿‍♀' => 'მუშა ქალი: კანის მუქი ტონალობა',
    '👳🏻‍♂' => 'კაცი ჩალმით: კანის ღია ტონალობა',
    '👳🏼‍♂' => 'კაცი ჩალმით: ღიადან საშუალომდე კანის ტონალობა',
    '👳🏽‍♂' => 'კაცი ჩალმით: კანის საშუალო ტონალობა',
    '👳🏾‍♂' => 'კაცი ჩალმით: საშუალოდან მუქამდე კანის ტონალობა',
    '👳🏿‍♂' => 'კაცი ჩალმით: კანის მუქი ტონალობა',
    '👳🏻‍♀' => 'ქალი ჩალმით: კანის ღია ტონალობა',
    '👳🏼‍♀' => 'ქალი ჩალმით: ღიადან საშუალომდე კანის ტონალობა',
    '👳🏽‍♀' => 'ქალი ჩალმით: კანის საშუალო ტონალობა',
    '👳🏾‍♀' => 'ქალი ჩალმით: საშუალოდან მუქამდე კანის ტონალობა',
    '👳🏿‍♀' => 'ქალი ჩალმით: კანის მუქი ტონალობა',
    '🤵🏻‍♂' => 'მამაკაცი სმოკინგში: კანის ღია ტონალობა',
    '🤵🏼‍♂' => 'მამაკაცი სმოკინგში: ღიადან საშუალომდე კანის ტონალობა',
    '🤵🏽‍♂' => 'მამაკაცი სმოკინგში: კანის საშუალო ტონალობა',
    '🤵🏾‍♂' => 'მამაკაცი სმოკინგში: საშუალოდან მუქამდე კანის ტონალობა',
    '🤵🏿‍♂' => 'მამაკაცი სმოკინგში: კანის მუქი ტონალობა',
    '🤵🏻‍♀' => 'ქალი სმოკინგში: კანის ღია ტონალობა',
    '🤵🏼‍♀' => 'ქალი სმოკინგში: ღიადან საშუალომდე კანის ტონალობა',
    '🤵🏽‍♀' => 'ქალი სმოკინგში: კანის საშუალო ტონალობა',
    '🤵🏾‍♀' => 'ქალი სმოკინგში: საშუალოდან მუქამდე კანის ტონალობა',
    '🤵🏿‍♀' => 'ქალი სმოკინგში: კანის მუქი ტონალობა',
    '👰🏻‍♂' => 'ჩალმიანი კაცი: კანის ღია ტონალობა',
    '👰🏼‍♂' => 'ჩალმიანი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👰🏽‍♂' => 'ჩალმიანი კაცი: კანის საშუალო ტონალობა',
    '👰🏾‍♂' => 'ჩალმიანი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👰🏿‍♂' => 'ჩალმიანი კაცი: კანის მუქი ტონალობა',
    '👰🏻‍♀' => 'ქალი ვუალით: კანის ღია ტონალობა',
    '👰🏼‍♀' => 'ქალი ვუალით: ღიადან საშუალომდე კანის ტონალობა',
    '👰🏽‍♀' => 'ქალი ვუალით: კანის საშუალო ტონალობა',
    '👰🏾‍♀' => 'ქალი ვუალით: საშუალოდან მუქამდე კანის ტონალობა',
    '👰🏿‍♀' => 'ქალი ვუალით: კანის მუქი ტონალობა',
    '👩🏻‍🍼' => 'ქალი აჭმევს ბავშვს: კანის ღია ტონალობა',
    '👩🏼‍🍼' => 'ქალი აჭმევს ბავშვს: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🍼' => 'ქალი აჭმევს ბავშვს: კანის საშუალო ტონალობა',
    '👩🏾‍🍼' => 'ქალი აჭმევს ბავშვს: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🍼' => 'ქალი აჭმევს ბავშვს: კანის მუქი ტონალობა',
    '👨🏻‍🍼' => 'კაცი აჭმევს ბავშვს: კანის ღია ტონალობა',
    '👨🏼‍🍼' => 'კაცი აჭმევს ბავშვს: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🍼' => 'კაცი აჭმევს ბავშვს: კანის საშუალო ტონალობა',
    '👨🏾‍🍼' => 'კაცი აჭმევს ბავშვს: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🍼' => 'კაცი აჭმევს ბავშვს: კანის მუქი ტონალობა',
    '🧑🏻‍🍼' => 'ადამიანი აჭმევს ბავშვს: კანის ღია ტონალობა',
    '🧑🏼‍🍼' => 'ადამიანი აჭმევს ბავშვს: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🍼' => 'ადამიანი აჭმევს ბავშვს: კანის საშუალო ტონალობა',
    '🧑🏾‍🍼' => 'ადამიანი აჭმევს ბავშვს: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🍼' => 'ადამიანი აჭმევს ბავშვს: კანის მუქი ტონალობა',
    '🧑🏻‍🎄' => 'სანტა: კანის ღია ტონალობა',
    '🧑🏼‍🎄' => 'სანტა: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🎄' => 'სანტა: კანის საშუალო ტონალობა',
    '🧑🏾‍🎄' => 'სანტა: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🎄' => 'სანტა: კანის მუქი ტონალობა',
    '🦸🏻‍♂' => 'სუპერგმირი კაცი: კანის ღია ტონალობა',
    '🦸🏼‍♂' => 'სუპერგმირი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🦸🏽‍♂' => 'სუპერგმირი კაცი: კანის საშუალო ტონალობა',
    '🦸🏾‍♂' => 'სუპერგმირი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🦸🏿‍♂' => 'სუპერგმირი კაცი: კანის მუქი ტონალობა',
    '🦸🏻‍♀' => 'სუპერგმირი ქალი: კანის ღია ტონალობა',
    '🦸🏼‍♀' => 'სუპერგმირი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🦸🏽‍♀' => 'სუპერგმირი ქალი: კანის საშუალო ტონალობა',
    '🦸🏾‍♀' => 'სუპერგმირი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🦸🏿‍♀' => 'სუპერგმირი ქალი: კანის მუქი ტონალობა',
    '🦹🏻‍♂' => 'ბოროტი გმირი კაცი: კანის ღია ტონალობა',
    '🦹🏼‍♂' => 'ბოროტი გმირი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🦹🏽‍♂' => 'ბოროტი გმირი კაცი: კანის საშუალო ტონალობა',
    '🦹🏾‍♂' => 'ბოროტი გმირი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🦹🏿‍♂' => 'ბოროტი გმირი კაცი: კანის მუქი ტონალობა',
    '🦹🏻‍♀' => 'ბოროტი გმირი ქალი: კანის ღია ტონალობა',
    '🦹🏼‍♀' => 'ბოროტი გმირი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🦹🏽‍♀' => 'ბოროტი გმირი ქალი: კანის საშუალო ტონალობა',
    '🦹🏾‍♀' => 'ბოროტი გმირი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🦹🏿‍♀' => 'ბოროტი გმირი ქალი: კანის მუქი ტონალობა',
    '🧙🏻‍♂' => 'ჯადოქარი კაცი: კანის ღია ტონალობა',
    '🧙🏼‍♂' => 'ჯადოქარი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🧙🏽‍♂' => 'ჯადოქარი კაცი: კანის საშუალო ტონალობა',
    '🧙🏾‍♂' => 'ჯადოქარი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧙🏿‍♂' => 'ჯადოქარი კაცი: კანის მუქი ტონალობა',
    '🧙🏻‍♀' => 'ჯადოქარი ქალი: კანის ღია ტონალობა',
    '🧙🏼‍♀' => 'ჯადოქარი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🧙🏽‍♀' => 'ჯადოქარი ქალი: კანის საშუალო ტონალობა',
    '🧙🏾‍♀' => 'ჯადოქარი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧙🏿‍♀' => 'ჯადოქარი ქალი: კანის მუქი ტონალობა',
    '🧚🏻‍♂' => 'კაცი ფერია: კანის ღია ტონალობა',
    '🧚🏼‍♂' => 'კაცი ფერია: ღიადან საშუალომდე კანის ტონალობა',
    '🧚🏽‍♂' => 'კაცი ფერია: კანის საშუალო ტონალობა',
    '🧚🏾‍♂' => 'კაცი ფერია: საშუალოდან მუქამდე კანის ტონალობა',
    '🧚🏿‍♂' => 'კაცი ფერია: კანის მუქი ტონალობა',
    '🧚🏻‍♀' => 'ქალი ფერია: კანის ღია ტონალობა',
    '🧚🏼‍♀' => 'ქალი ფერია: ღიადან საშუალომდე კანის ტონალობა',
    '🧚🏽‍♀' => 'ქალი ფერია: კანის საშუალო ტონალობა',
    '🧚🏾‍♀' => 'ქალი ფერია: საშუალოდან მუქამდე კანის ტონალობა',
    '🧚🏿‍♀' => 'ქალი ფერია: კანის მუქი ტონალობა',
    '🧛🏻‍♂' => 'ვამპირი კაცი: კანის ღია ტონალობა',
    '🧛🏼‍♂' => 'ვამპირი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🧛🏽‍♂' => 'ვამპირი კაცი: კანის საშუალო ტონალობა',
    '🧛🏾‍♂' => 'ვამპირი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧛🏿‍♂' => 'ვამპირი კაცი: კანის მუქი ტონალობა',
    '🧛🏻‍♀' => 'ვამპირი ქალი: კანის ღია ტონალობა',
    '🧛🏼‍♀' => 'ვამპირი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🧛🏽‍♀' => 'ვამპირი ქალი: კანის საშუალო ტონალობა',
    '🧛🏾‍♀' => 'ვამპირი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧛🏿‍♀' => 'ვამპირი ქალი: კანის მუქი ტონალობა',
    '🧜🏻‍♂' => 'კაცთევზა: კანის ღია ტონალობა',
    '🧜🏼‍♂' => 'კაცთევზა: ღიადან საშუალომდე კანის ტონალობა',
    '🧜🏽‍♂' => 'კაცთევზა: კანის საშუალო ტონალობა',
    '🧜🏾‍♂' => 'კაცთევზა: საშუალოდან მუქამდე კანის ტონალობა',
    '🧜🏿‍♂' => 'კაცთევზა: კანის მუქი ტონალობა',
    '🧜🏻‍♀' => 'ქალთევზა: კანის ღია ტონალობა',
    '🧜🏼‍♀' => 'ქალთევზა: ღიადან საშუალომდე კანის ტონალობა',
    '🧜🏽‍♀' => 'ქალთევზა: კანის საშუალო ტონალობა',
    '🧜🏾‍♀' => 'ქალთევზა: საშუალოდან მუქამდე კანის ტონალობა',
    '🧜🏿‍♀' => 'ქალთევზა: კანის მუქი ტონალობა',
    '🧝🏻‍♂' => 'კაცი ელფი: კანის ღია ტონალობა',
    '🧝🏼‍♂' => 'კაცი ელფი: ღიადან საშუალომდე კანის ტონალობა',
    '🧝🏽‍♂' => 'კაცი ელფი: კანის საშუალო ტონალობა',
    '🧝🏾‍♂' => 'კაცი ელფი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧝🏿‍♂' => 'კაცი ელფი: კანის მუქი ტონალობა',
    '🧝🏻‍♀' => 'ქალი ელფი: კანის ღია ტონალობა',
    '🧝🏼‍♀' => 'ქალი ელფი: ღიადან საშუალომდე კანის ტონალობა',
    '🧝🏽‍♀' => 'ქალი ელფი: კანის საშუალო ტონალობა',
    '🧝🏾‍♀' => 'ქალი ელფი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧝🏿‍♀' => 'ქალი ელფი: კანის მუქი ტონალობა',
    '💆🏻‍♂' => 'სახის მასაჟი - კაცი: კანის ღია ტონალობა',
    '💆🏼‍♂' => 'სახის მასაჟი - კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '💆🏽‍♂' => 'სახის მასაჟი - კაცი: კანის საშუალო ტონალობა',
    '💆🏾‍♂' => 'სახის მასაჟი - კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '💆🏿‍♂' => 'სახის მასაჟი - კაცი: კანის მუქი ტონალობა',
    '💆🏻‍♀' => 'სახის მასაჟი - ქალი: კანის ღია ტონალობა',
    '💆🏼‍♀' => 'სახის მასაჟი - ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '💆🏽‍♀' => 'სახის მასაჟი - ქალი: კანის საშუალო ტონალობა',
    '💆🏾‍♀' => 'სახის მასაჟი - ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '💆🏿‍♀' => 'სახის მასაჟი - ქალი: კანის მუქი ტონალობა',
    '💇🏻‍♂' => 'კაცის თმის შეჭრა: კანის ღია ტონალობა',
    '💇🏼‍♂' => 'კაცის თმის შეჭრა: ღიადან საშუალომდე კანის ტონალობა',
    '💇🏽‍♂' => 'კაცის თმის შეჭრა: კანის საშუალო ტონალობა',
    '💇🏾‍♂' => 'კაცის თმის შეჭრა: საშუალოდან მუქამდე კანის ტონალობა',
    '💇🏿‍♂' => 'კაცის თმის შეჭრა: კანის მუქი ტონალობა',
    '💇🏻‍♀' => 'ქალის თმის შეჭრა: კანის ღია ტონალობა',
    '💇🏼‍♀' => 'ქალის თმის შეჭრა: ღიადან საშუალომდე კანის ტონალობა',
    '💇🏽‍♀' => 'ქალის თმის შეჭრა: კანის საშუალო ტონალობა',
    '💇🏾‍♀' => 'ქალის თმის შეჭრა: საშუალოდან მუქამდე კანის ტონალობა',
    '💇🏿‍♀' => 'ქალის თმის შეჭრა: კანის მუქი ტონალობა',
    '🚶🏻‍♂' => 'მოსიარულე კაცი: კანის ღია ტონალობა',
    '🚶🏼‍♂' => 'მოსიარულე კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🚶🏽‍♂' => 'მოსიარულე კაცი: კანის საშუალო ტონალობა',
    '🚶🏾‍♂' => 'მოსიარულე კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🚶🏿‍♂' => 'მოსიარულე კაცი: კანის მუქი ტონალობა',
    '🚶🏻‍♀' => 'მოსიარულე ქალი: კანის ღია ტონალობა',
    '🚶🏼‍♀' => 'მოსიარულე ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🚶🏽‍♀' => 'მოსიარულე ქალი: კანის საშუალო ტონალობა',
    '🚶🏾‍♀' => 'მოსიარულე ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🚶🏿‍♀' => 'მოსიარულე ქალი: კანის მუქი ტონალობა',
    '🚶🏻‍➡' => 'ქვეითი: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🚶🏼‍➡' => 'ქვეითი: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🚶🏽‍➡' => 'ქვეითი: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🚶🏾‍➡' => 'ქვეითი: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🚶🏿‍➡' => 'ქვეითი: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🧍🏻‍♂' => 'ფეხზე მდგომი კაცი: კანის ღია ტონალობა',
    '🧍🏼‍♂' => 'ფეხზე მდგომი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🧍🏽‍♂' => 'ფეხზე მდგომი კაცი: კანის საშუალო ტონალობა',
    '🧍🏾‍♂' => 'ფეხზე მდგომი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧍🏿‍♂' => 'ფეხზე მდგომი კაცი: კანის მუქი ტონალობა',
    '🧍🏻‍♀' => 'ფეხზე მდგომი ქალი: კანის ღია ტონალობა',
    '🧍🏼‍♀' => 'ფეხზე მდგომი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🧍🏽‍♀' => 'ფეხზე მდგომი ქალი: კანის საშუალო ტონალობა',
    '🧍🏾‍♀' => 'ფეხზე მდგომი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧍🏿‍♀' => 'ფეხზე მდგომი ქალი: კანის მუქი ტონალობა',
    '🧎🏻‍♂' => 'დაჩოქილი კაცი: კანის ღია ტონალობა',
    '🧎🏼‍♂' => 'დაჩოქილი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🧎🏽‍♂' => 'დაჩოქილი კაცი: კანის საშუალო ტონალობა',
    '🧎🏾‍♂' => 'დაჩოქილი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧎🏿‍♂' => 'დაჩოქილი კაცი: კანის მუქი ტონალობა',
    '🧎🏻‍♀' => 'დაჩოქილი ქალი: კანის ღია ტონალობა',
    '🧎🏼‍♀' => 'დაჩოქილი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🧎🏽‍♀' => 'დაჩოქილი ქალი: კანის საშუალო ტონალობა',
    '🧎🏾‍♀' => 'დაჩოქილი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧎🏿‍♀' => 'დაჩოქილი ქალი: კანის მუქი ტონალობა',
    '🧎🏻‍➡' => 'დაჩოქილი ადამიანი: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🧎🏼‍➡' => 'დაჩოქილი ადამიანი: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧎🏽‍➡' => 'დაჩოქილი ადამიანი: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🧎🏾‍➡' => 'დაჩოქილი ადამიანი: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🧎🏿‍➡' => 'დაჩოქილი ადამიანი: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '🧑🏻‍🦯' => 'ადამიანი თეთრი ხელჯოხით: კანის ღია ტონალობა',
    '🧑🏼‍🦯' => 'ადამიანი თეთრი ხელჯოხით: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🦯' => 'ადამიანი თეთრი ხელჯოხით: კანის საშუალო ტონალობა',
    '🧑🏾‍🦯' => 'ადამიანი თეთრი ხელჯოხით: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🦯' => 'ადამიანი თეთრი ხელჯოხით: კანის მუქი ტონალობა',
    '👨🏻‍🦯' => 'კაცი თეთრი ჯოხით: კანის ღია ტონალობა',
    '👨🏼‍🦯' => 'კაცი თეთრი ჯოხით: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🦯' => 'კაცი თეთრი ჯოხით: კანის საშუალო ტონალობა',
    '👨🏾‍🦯' => 'კაცი თეთრი ჯოხით: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🦯' => 'კაცი თეთრი ჯოხით: კანის მუქი ტონალობა',
    '👩🏻‍🦯' => 'ქალი თეთრი ჯოხით: კანის ღია ტონალობა',
    '👩🏼‍🦯' => 'ქალი თეთრი ჯოხით: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🦯' => 'ქალი თეთრი ჯოხით: კანის საშუალო ტონალობა',
    '👩🏾‍🦯' => 'ქალი თეთრი ჯოხით: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🦯' => 'ქალი თეთრი ჯოხით: კანის მუქი ტონალობა',
    '🧑🏻‍🦼' => 'ადამიანი მოტორიან ეტლში: კანის ღია ტონალობა',
    '🧑🏼‍🦼' => 'ადამიანი მოტორიან ეტლში: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🦼' => 'ადამიანი მოტორიან ეტლში: კანის საშუალო ტონალობა',
    '🧑🏾‍🦼' => 'ადამიანი მოტორიან ეტლში: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🦼' => 'ადამიანი მოტორიან ეტლში: კანის მუქი ტონალობა',
    '👨🏻‍🦼' => 'კაცი მოტორიან ეტლში: კანის ღია ტონალობა',
    '👨🏼‍🦼' => 'კაცი მოტორიან ეტლში: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🦼' => 'კაცი მოტორიან ეტლში: კანის საშუალო ტონალობა',
    '👨🏾‍🦼' => 'კაცი მოტორიან ეტლში: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🦼' => 'კაცი მოტორიან ეტლში: კანის მუქი ტონალობა',
    '👩🏻‍🦼' => 'ქალი მოტორიან ეტლში: კანის ღია ტონალობა',
    '👩🏼‍🦼' => 'ქალი მოტორიან ეტლში: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🦼' => 'ქალი მოტორიან ეტლში: კანის საშუალო ტონალობა',
    '👩🏾‍🦼' => 'ქალი მოტორიან ეტლში: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🦼' => 'ქალი მოტორიან ეტლში: კანის მუქი ტონალობა',
    '🧑🏻‍🦽' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: კანის ღია ტონალობა',
    '🧑🏼‍🦽' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽‍🦽' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: კანის საშუალო ტონალობა',
    '🧑🏾‍🦽' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿‍🦽' => 'ადამიანი მექანიკურ ბორბლიან ეტლში: კანის მუქი ტონალობა',
    '👨🏻‍🦽' => 'კაცი შშმ პირის მექანიკურ ეტლში: კანის ღია ტონალობა',
    '👨🏼‍🦽' => 'კაცი შშმ პირის მექანიკურ ეტლში: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽‍🦽' => 'კაცი შშმ პირის მექანიკურ ეტლში: კანის საშუალო ტონალობა',
    '👨🏾‍🦽' => 'კაცი შშმ პირის მექანიკურ ეტლში: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿‍🦽' => 'კაცი შშმ პირის მექანიკურ ეტლში: კანის მუქი ტონალობა',
    '👩🏻‍🦽' => 'ქალი შშმ პირის მექანიკურ ეტლში: კანის ღია ტონალობა',
    '👩🏼‍🦽' => 'ქალი შშმ პირის მექანიკურ ეტლში: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽‍🦽' => 'ქალი შშმ პირის მექანიკურ ეტლში: კანის საშუალო ტონალობა',
    '👩🏾‍🦽' => 'ქალი შშმ პირის მექანიკურ ეტლში: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿‍🦽' => 'ქალი შშმ პირის მექანიკურ ეტლში: კანის მუქი ტონალობა',
    '🏃🏻‍♂' => 'მორბენალი კაცი: კანის ღია ტონალობა',
    '🏃🏼‍♂' => 'მორბენალი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🏃🏽‍♂' => 'მორბენალი კაცი: კანის საშუალო ტონალობა',
    '🏃🏾‍♂' => 'მორბენალი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏃🏿‍♂' => 'მორბენალი კაცი: კანის მუქი ტონალობა',
    '🏃🏻‍♀' => 'მორბენალი ქალი: კანის ღია ტონალობა',
    '🏃🏼‍♀' => 'მორბენალი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🏃🏽‍♀' => 'მორბენალი ქალი: კანის საშუალო ტონალობა',
    '🏃🏾‍♀' => 'მორბენალი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏃🏿‍♀' => 'მორბენალი ქალი: კანის მუქი ტონალობა',
    '🏃🏻‍➡' => 'მორბენალი: კანის ღია ტონალობა, მარჯვნივ მიმართული',
    '🏃🏼‍➡' => 'მორბენალი: ღიადან საშუალომდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🏃🏽‍➡' => 'მორბენალი: კანის საშუალო ტონალობა, მარჯვნივ მიმართული',
    '🏃🏾‍➡' => 'მორბენალი: საშუალოდან მუქამდე კანის ტონალობა, მარჯვნივ მიმართული',
    '🏃🏿‍➡' => 'მორბენალი: კანის მუქი ტონალობა, მარჯვნივ მიმართული',
    '👯🏻‍♀' => 'მოცეკვავე ქალები: კანის ღია ტონალობა',
    '👯🏼‍♀' => 'მოცეკვავე ქალები: ღიადან საშუალომდე კანის ტონალობა',
    '👯🏽‍♀' => 'მოცეკვავე ქალები: კანის საშუალო ტონალობა',
    '👯🏾‍♀' => 'მოცეკვავე ქალები: საშუალოდან მუქამდე კანის ტონალობა',
    '👯🏿‍♀' => 'მოცეკვავე ქალები: კანის მუქი ტონალობა',
    '👯🏻‍♂' => 'მოცეკვავე კაცები: კანის ღია ტონალობა',
    '👯🏼‍♂' => 'მოცეკვავე კაცები: ღიადან საშუალომდე კანის ტონალობა',
    '👯🏽‍♂' => 'მოცეკვავე კაცები: კანის საშუალო ტონალობა',
    '👯🏾‍♂' => 'მოცეკვავე კაცები: საშუალოდან მუქამდე კანის ტონალობა',
    '👯🏿‍♂' => 'მოცეკვავე კაცები: კანის მუქი ტონალობა',
    '🧖🏻‍♂' => 'კაცი საუნაში: კანის ღია ტონალობა',
    '🧖🏼‍♂' => 'კაცი საუნაში: ღიადან საშუალომდე კანის ტონალობა',
    '🧖🏽‍♂' => 'კაცი საუნაში: კანის საშუალო ტონალობა',
    '🧖🏾‍♂' => 'კაცი საუნაში: საშუალოდან მუქამდე კანის ტონალობა',
    '🧖🏿‍♂' => 'კაცი საუნაში: კანის მუქი ტონალობა',
    '🧖🏻‍♀' => 'ქალი საუნაში: კანის ღია ტონალობა',
    '🧖🏼‍♀' => 'ქალი საუნაში: ღიადან საშუალომდე კანის ტონალობა',
    '🧖🏽‍♀' => 'ქალი საუნაში: კანის საშუალო ტონალობა',
    '🧖🏾‍♀' => 'ქალი საუნაში: საშუალოდან მუქამდე კანის ტონალობა',
    '🧖🏿‍♀' => 'ქალი საუნაში: კანის მუქი ტონალობა',
    '🧗🏻‍♂' => 'მთასვლელი კაცი: კანის ღია ტონალობა',
    '🧗🏼‍♂' => 'მთასვლელი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🧗🏽‍♂' => 'მთასვლელი კაცი: კანის საშუალო ტონალობა',
    '🧗🏾‍♂' => 'მთასვლელი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧗🏿‍♂' => 'მთასვლელი კაცი: კანის მუქი ტონალობა',
    '🧗🏻‍♀' => 'მთასვლელი ქალი: კანის ღია ტონალობა',
    '🧗🏼‍♀' => 'მთასვლელი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🧗🏽‍♀' => 'მთასვლელი ქალი: კანის საშუალო ტონალობა',
    '🧗🏾‍♀' => 'მთასვლელი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧗🏿‍♀' => 'მთასვლელი ქალი: კანის მუქი ტონალობა',
    '🏌🏻‍♂' => 'გოლფის მოთამაშე კაცი: კანის ღია ტონალობა',
    '🏌🏼‍♂' => 'გოლფის მოთამაშე კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🏌🏽‍♂' => 'გოლფის მოთამაშე კაცი: კანის საშუალო ტონალობა',
    '🏌🏾‍♂' => 'გოლფის მოთამაშე კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏌🏿‍♂' => 'გოლფის მოთამაშე კაცი: კანის მუქი ტონალობა',
    '🏌🏻‍♀' => 'გოლფის მოთამაშე ქალი: კანის ღია ტონალობა',
    '🏌🏼‍♀' => 'გოლფის მოთამაშე ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🏌🏽‍♀' => 'გოლფის მოთამაშე ქალი: კანის საშუალო ტონალობა',
    '🏌🏾‍♀' => 'გოლფის მოთამაშე ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏌🏿‍♀' => 'გოლფის მოთამაშე ქალი: კანის მუქი ტონალობა',
    '🏄🏻‍♂' => 'სერფერი კაცი: კანის ღია ტონალობა',
    '🏄🏼‍♂' => 'სერფერი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🏄🏽‍♂' => 'სერფერი კაცი: კანის საშუალო ტონალობა',
    '🏄🏾‍♂' => 'სერფერი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏄🏿‍♂' => 'სერფერი კაცი: კანის მუქი ტონალობა',
    '🏄🏻‍♀' => 'სერფერი ქალი: კანის ღია ტონალობა',
    '🏄🏼‍♀' => 'სერფერი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🏄🏽‍♀' => 'სერფერი ქალი: კანის საშუალო ტონალობა',
    '🏄🏾‍♀' => 'სერფერი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏄🏿‍♀' => 'სერფერი ქალი: კანის მუქი ტონალობა',
    '🚣🏻‍♂' => 'ნიჩბოსანი კაცი: კანის ღია ტონალობა',
    '🚣🏼‍♂' => 'ნიჩბოსანი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🚣🏽‍♂' => 'ნიჩბოსანი კაცი: კანის საშუალო ტონალობა',
    '🚣🏾‍♂' => 'ნიჩბოსანი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🚣🏿‍♂' => 'ნიჩბოსანი კაცი: კანის მუქი ტონალობა',
    '🚣🏻‍♀' => 'ნიჩბოსანი ქალი: კანის ღია ტონალობა',
    '🚣🏼‍♀' => 'ნიჩბოსანი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🚣🏽‍♀' => 'ნიჩბოსანი ქალი: კანის საშუალო ტონალობა',
    '🚣🏾‍♀' => 'ნიჩბოსანი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🚣🏿‍♀' => 'ნიჩბოსანი ქალი: კანის მუქი ტონალობა',
    '🏊🏻‍♂' => 'მოცურავე კაცი: კანის ღია ტონალობა',
    '🏊🏼‍♂' => 'მოცურავე კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🏊🏽‍♂' => 'მოცურავე კაცი: კანის საშუალო ტონალობა',
    '🏊🏾‍♂' => 'მოცურავე კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏊🏿‍♂' => 'მოცურავე კაცი: კანის მუქი ტონალობა',
    '🏊🏻‍♀' => 'მოცურავე ქალი: კანის ღია ტონალობა',
    '🏊🏼‍♀' => 'მოცურავე ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🏊🏽‍♀' => 'მოცურავე ქალი: კანის საშუალო ტონალობა',
    '🏊🏾‍♀' => 'მოცურავე ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏊🏿‍♀' => 'მოცურავე ქალი: კანის მუქი ტონალობა',
    '⛹🏻‍♂' => 'კაცი ბურთით: კანის ღია ტონალობა',
    '⛹🏼‍♂' => 'კაცი ბურთით: ღიადან საშუალომდე კანის ტონალობა',
    '⛹🏽‍♂' => 'კაცი ბურთით: კანის საშუალო ტონალობა',
    '⛹🏾‍♂' => 'კაცი ბურთით: საშუალოდან მუქამდე კანის ტონალობა',
    '⛹🏿‍♂' => 'კაცი ბურთით: კანის მუქი ტონალობა',
    '⛹🏻‍♀' => 'ქალი ბურთით: კანის ღია ტონალობა',
    '⛹🏼‍♀' => 'ქალი ბურთით: ღიადან საშუალომდე კანის ტონალობა',
    '⛹🏽‍♀' => 'ქალი ბურთით: კანის საშუალო ტონალობა',
    '⛹🏾‍♀' => 'ქალი ბურთით: საშუალოდან მუქამდე კანის ტონალობა',
    '⛹🏿‍♀' => 'ქალი ბურთით: კანის მუქი ტონალობა',
    '🏋🏻‍♂' => 'ძალოსანი კაცი: კანის ღია ტონალობა',
    '🏋🏼‍♂' => 'ძალოსანი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🏋🏽‍♂' => 'ძალოსანი კაცი: კანის საშუალო ტონალობა',
    '🏋🏾‍♂' => 'ძალოსანი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏋🏿‍♂' => 'ძალოსანი კაცი: კანის მუქი ტონალობა',
    '🏋🏻‍♀' => 'ძალოსანი ქალი: კანის ღია ტონალობა',
    '🏋🏼‍♀' => 'ძალოსანი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🏋🏽‍♀' => 'ძალოსანი ქალი: კანის საშუალო ტონალობა',
    '🏋🏾‍♀' => 'ძალოსანი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏋🏿‍♀' => 'ძალოსანი ქალი: კანის მუქი ტონალობა',
    '🚴🏻‍♂' => 'კაცი ველოსიპედით: კანის ღია ტონალობა',
    '🚴🏼‍♂' => 'კაცი ველოსიპედით: ღიადან საშუალომდე კანის ტონალობა',
    '🚴🏽‍♂' => 'კაცი ველოსიპედით: კანის საშუალო ტონალობა',
    '🚴🏾‍♂' => 'კაცი ველოსიპედით: საშუალოდან მუქამდე კანის ტონალობა',
    '🚴🏿‍♂' => 'კაცი ველოსიპედით: კანის მუქი ტონალობა',
    '🚴🏻‍♀' => 'ქალი ველოსიპედით: კანის ღია ტონალობა',
    '🚴🏼‍♀' => 'ქალი ველოსიპედით: ღიადან საშუალომდე კანის ტონალობა',
    '🚴🏽‍♀' => 'ქალი ველოსიპედით: კანის საშუალო ტონალობა',
    '🚴🏾‍♀' => 'ქალი ველოსიპედით: საშუალოდან მუქამდე კანის ტონალობა',
    '🚴🏿‍♀' => 'ქალი ველოსიპედით: კანის მუქი ტონალობა',
    '🚵🏻‍♂' => 'კაცი სამთო ველოსიპედით: კანის ღია ტონალობა',
    '🚵🏼‍♂' => 'კაცი სამთო ველოსიპედით: ღიადან საშუალომდე კანის ტონალობა',
    '🚵🏽‍♂' => 'კაცი სამთო ველოსიპედით: კანის საშუალო ტონალობა',
    '🚵🏾‍♂' => 'კაცი სამთო ველოსიპედით: საშუალოდან მუქამდე კანის ტონალობა',
    '🚵🏿‍♂' => 'კაცი სამთო ველოსიპედით: კანის მუქი ტონალობა',
    '🚵🏻‍♀' => 'ქალი სამთო ველოსიპედით: კანის ღია ტონალობა',
    '🚵🏼‍♀' => 'ქალი სამთო ველოსიპედით: ღიადან საშუალომდე კანის ტონალობა',
    '🚵🏽‍♀' => 'ქალი სამთო ველოსიპედით: კანის საშუალო ტონალობა',
    '🚵🏾‍♀' => 'ქალი სამთო ველოსიპედით: საშუალოდან მუქამდე კანის ტონალობა',
    '🚵🏿‍♀' => 'ქალი სამთო ველოსიპედით: კანის მუქი ტონალობა',
    '🤸🏻‍♂' => 'აკრობატი კაცი: კანის ღია ტონალობა',
    '🤸🏼‍♂' => 'აკრობატი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🤸🏽‍♂' => 'აკრობატი კაცი: კანის საშუალო ტონალობა',
    '🤸🏾‍♂' => 'აკრობატი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤸🏿‍♂' => 'აკრობატი კაცი: კანის მუქი ტონალობა',
    '🤸🏻‍♀' => 'აკრობატი ქალი: კანის ღია ტონალობა',
    '🤸🏼‍♀' => 'აკრობატი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🤸🏽‍♀' => 'აკრობატი ქალი: კანის საშუალო ტონალობა',
    '🤸🏾‍♀' => 'აკრობატი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤸🏿‍♀' => 'აკრობატი ქალი: კანის მუქი ტონალობა',
    '🤼🏻‍♀' => 'მოჭიდავე ქალები: კანის ღია ტონალობა',
    '🤼🏼‍♀' => 'მოჭიდავე ქალები: ღიადან საშუალომდე კანის ტონალობა',
    '🤼🏽‍♀' => 'მოჭიდავე ქალები: კანის საშუალო ტონალობა',
    '🤼🏾‍♀' => 'მოჭიდავე ქალები: საშუალოდან მუქამდე კანის ტონალობა',
    '🤼🏿‍♀' => 'მოჭიდავე ქალები: კანის მუქი ტონალობა',
    '🤼🏻‍♂' => 'მოჭიდავე კაცები: კანის ღია ტონალობა',
    '🤼🏼‍♂' => 'მოჭიდავე კაცები: ღიადან საშუალომდე კანის ტონალობა',
    '🤼🏽‍♂' => 'მოჭიდავე კაცები: კანის საშუალო ტონალობა',
    '🤼🏾‍♂' => 'მოჭიდავე კაცები: საშუალოდან მუქამდე კანის ტონალობა',
    '🤼🏿‍♂' => 'მოჭიდავე კაცები: კანის მუქი ტონალობა',
    '🤽🏻‍♂' => 'წყალბურთელი კაცი: კანის ღია ტონალობა',
    '🤽🏼‍♂' => 'წყალბურთელი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🤽🏽‍♂' => 'წყალბურთელი კაცი: კანის საშუალო ტონალობა',
    '🤽🏾‍♂' => 'წყალბურთელი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤽🏿‍♂' => 'წყალბურთელი კაცი: კანის მუქი ტონალობა',
    '🤽🏻‍♀' => 'წყალბურთელი ქალი: კანის ღია ტონალობა',
    '🤽🏼‍♀' => 'წყალბურთელი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🤽🏽‍♀' => 'წყალბურთელი ქალი: კანის საშუალო ტონალობა',
    '🤽🏾‍♀' => 'წყალბურთელი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤽🏿‍♀' => 'წყალბურთელი ქალი: კანის მუქი ტონალობა',
    '🤾🏻‍♂' => 'ხელბურთელი კაცი: კანის ღია ტონალობა',
    '🤾🏼‍♂' => 'ხელბურთელი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🤾🏽‍♂' => 'ხელბურთელი კაცი: კანის საშუალო ტონალობა',
    '🤾🏾‍♂' => 'ხელბურთელი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤾🏿‍♂' => 'ხელბურთელი კაცი: კანის მუქი ტონალობა',
    '🤾🏻‍♀' => 'ხელბურთელი ქალი: კანის ღია ტონალობა',
    '🤾🏼‍♀' => 'ხელბურთელი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🤾🏽‍♀' => 'ხელბურთელი ქალი: კანის საშუალო ტონალობა',
    '🤾🏾‍♀' => 'ხელბურთელი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤾🏿‍♀' => 'ხელბურთელი ქალი: კანის მუქი ტონალობა',
    '🤹🏻‍♂' => 'ჟონგლიორი კაცი: კანის ღია ტონალობა',
    '🤹🏼‍♂' => 'ჟონგლიორი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🤹🏽‍♂' => 'ჟონგლიორი კაცი: კანის საშუალო ტონალობა',
    '🤹🏾‍♂' => 'ჟონგლიორი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤹🏿‍♂' => 'ჟონგლიორი კაცი: კანის მუქი ტონალობა',
    '🤹🏻‍♀' => 'ჟონგლიორი ქალი: კანის ღია ტონალობა',
    '🤹🏼‍♀' => 'ჟონგლიორი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🤹🏽‍♀' => 'ჟონგლიორი ქალი: კანის საშუალო ტონალობა',
    '🤹🏾‍♀' => 'ჟონგლიორი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤹🏿‍♀' => 'ჟონგლიორი ქალი: კანის მუქი ტონალობა',
    '🧘🏻‍♂' => 'ფეხმორთხმული კაცი: კანის ღია ტონალობა',
    '🧘🏼‍♂' => 'ფეხმორთხმული კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🧘🏽‍♂' => 'ფეხმორთხმული კაცი: კანის საშუალო ტონალობა',
    '🧘🏾‍♂' => 'ფეხმორთხმული კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧘🏿‍♂' => 'ფეხმორთხმული კაცი: კანის მუქი ტონალობა',
    '🧘🏻‍♀' => 'ფეხმორთხმული ქალი: კანის ღია ტონალობა',
    '🧘🏼‍♀' => 'ფეხმორთხმული ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🧘🏽‍♀' => 'ფეხმორთხმული ქალი: კანის საშუალო ტონალობა',
    '🧘🏾‍♀' => 'ფეხმორთხმული ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧘🏿‍♀' => 'ფეხმორთხმული ქალი: კანის მუქი ტონალობა',
    '🧑‍🦰' => 'სრულწლოვანი: წითელი თმა',
    '🧑‍🦱' => 'სრულწლოვანი: ხვეული თმა',
    '🧑‍🦳' => 'სრულწლოვანი: თეთრი თმა',
    '🧑‍🦲' => 'სრულწლოვანი: მელოტი',
    '👨‍🦰' => 'კაცი: წითელი თმა',
    '👨‍🦱' => 'კაცი: ხვეული თმა',
    '👨‍🦳' => 'კაცი: თეთრი თმა',
    '👨‍🦲' => 'კაცი: მელოტი',
    '👩‍🦰' => 'ქალი: წითელი თმა',
    '👩‍🦱' => 'ქალი: ხვეული თმა',
    '👩‍🦳' => 'ქალი: თეთრი თმა',
    '👩‍🦲' => 'ქალი: მელოტი',
    '🚶‍➡' => 'ქვეითი: მარჯვნივ მიმართული',
    '🧎‍➡' => 'დაჩოქილი ადამიანი: მარჯვნივ მიმართული',
    '🏃‍➡' => 'მორბენალი: მარჯვნივ მიმართული',
    '👨‍👦' => 'ოჯახი: კაცი, ბიჭი',
    '👨‍👧' => 'ოჯახი: კაცი, გოგო',
    '👩‍👦' => 'ოჯახი: ქალი, ბიჭი',
    '👩‍👧' => 'ოჯახი: ქალი, გოგო',
    '😶‍🌫' => 'სახე ღრუბლებში',
    '😮‍💨' => 'ამოსუნთქვა',
    '🙂‍↕' => 'თავის დაქნევა',
    '😵‍💫' => 'სახე სპირალური თვალებით',
    '❤‍🔥' => 'ალმოდებული გული',
    '❤‍🩹' => 'გულის გამთელება',
    '👁‍🗨' => 'თვალი საუბრის ბუშტში',
    '🧔‍♂' => 'კაცი: წვერი',
    '👱‍♂' => 'ქერათმიანი კაცი',
    '🧔‍♀' => 'ქალი: წვერი',
    '👱‍♀' => 'ქერათმიანი ქალი',
    '🙍‍♂' => 'შეჭმუხნილი კაცი',
    '🙍‍♀' => 'შეჭმუხნილი ქალი',
    '🙎‍♂' => 'გაბუტული კაცი',
    '🙎‍♀' => 'გაბუტული ქალი',
    '🙅‍♂' => 'კაცი ჟესტით „არა“',
    '🙅‍♀' => 'ქალი ჟესტით „არა“',
    '🙆‍♂' => 'კაცი ჟესტით „კარგი“',
    '🙆‍♀' => 'ქალი ჟესტით „კარგი“',
    '💁‍♂' => 'კაცი დახრილი ხელით',
    '💁‍♀' => 'ქალი დახრილი ხელით',
    '🙋‍♂' => 'ხელაწეული კაცი',
    '🙋‍♀' => 'ხელაწეული ქალი',
    '🧏‍♂' => 'ყრუ კაცი',
    '🧏‍♀' => 'ყრუ ქალი',
    '🙇‍♂' => 'თავდახრილი კაცი',
    '🙇‍♀' => 'თავდახრილი ქალი',
    '🤦‍♂' => 'სახეზე ხელაფარებული კაცი',
    '🤦‍♀' => 'სახეზე ხელაფარებული ქალი',
    '🤷‍♂' => 'კაცი მხრებს იჩეჩავს',
    '🤷‍♀' => 'ქალი მხრებს იჩეჩავს',
    '🧑‍⚕' => 'ჯანდაცვის თანამშრომელი',
    '👨‍⚕' => 'ექიმი კაცი',
    '👩‍⚕' => 'ექიმი ქალი',
    '🧑‍🎓' => 'სტუდენტი',
    '👨‍🎓' => 'სტუდენტი კაცი',
    '👩‍🎓' => 'სტუდენტი ქალი',
    '🧑‍🏫' => 'მასწავლებელი',
    '👨‍🏫' => 'მასწავლებელი კაცი',
    '👩‍🏫' => 'მასწავლებელი ქალი',
    '🧑‍⚖' => 'მოსამართლე',
    '👨‍⚖' => 'მოსამართლე კაცი',
    '👩‍⚖' => 'მოსამართლე ქალი',
    '🧑‍🌾' => 'ფერმერი',
    '👨‍🌾' => 'ფერმერი კაცი',
    '👩‍🌾' => 'ფერმერი ქალი',
    '🧑‍🍳' => 'მზარეული',
    '👨‍🍳' => 'მზარეული კაცი',
    '👩‍🍳' => 'მზარეული ქალი',
    '🧑‍🔧' => 'ხელოსანი',
    '👨‍🔧' => 'მექანიკოსი კაცი',
    '👩‍🔧' => 'მექანიკოსი ქალი',
    '🧑‍🏭' => 'ქარხნის მუშა',
    '👨‍🏭' => 'ქარხნის მუშაკი კაცი',
    '👩‍🏭' => 'ქარხნის მუშაკი ქალი',
    '🧑‍💼' => 'ოფისის თანამშრომელი',
    '👨‍💼' => 'თანამშრომელი კაცი',
    '👩‍💼' => 'თანამშრომელი ქალი',
    '🧑‍🔬' => 'მეცნიერი',
    '👨‍🔬' => 'მეცნიერი კაცი',
    '👩‍🔬' => 'მეცნიერი ქალი',
    '🧑‍💻' => 'ტექნოლოგი',
    '👨‍💻' => 'პროგრამისტი კაცი',
    '👩‍💻' => 'პროგრამისტი ქალი',
    '🧑‍🎤' => 'მომღერალი',
    '👨‍🎤' => 'მომღერალი კაცი',
    '👩‍🎤' => 'მომღერალი ქალი',
    '🧑‍🎨' => 'მხატვარი',
    '👨‍🎨' => 'მხატვარი კაცი',
    '👩‍🎨' => 'მხატვარი ქალი',
    '🧑‍✈' => 'პილოტი',
    '👨‍✈' => 'პილოტი კაცი',
    '👩‍✈' => 'პილოტი ქალი',
    '🧑‍🚀' => 'ასტრონავტი',
    '👨‍🚀' => 'ასტრონავტი კაცი',
    '👩‍🚀' => 'ასტრონავტი ქალი',
    '🧑‍🚒' => 'მეხანძრე',
    '👨‍🚒' => 'მეხანძრე კაცი',
    '👩‍🚒' => 'მეხანძრე ქალი',
    '👮‍♂' => 'პოლიციელი კაცი',
    '👮‍♀' => 'პოლიციელი ქალი',
    '🕵‍♂' => 'დეტექტივი კაცი',
    '🕵‍♀' => 'დეტექტივი ქალი',
    '💂‍♂' => 'მცველი კაცი',
    '💂‍♀' => 'მცველი ქალი',
    '👷‍♂' => 'მუშა კაცი',
    '👷‍♀' => 'მუშა ქალი',
    '👳‍♂' => 'კაცი ჩალმით',
    '👳‍♀' => 'ქალი ჩალმით',
    '🤵‍♂' => 'მამაკაცი სმოკინგში',
    '🤵‍♀' => 'ქალი სმოკინგში',
    '👰‍♂' => 'ჩალმიანი კაცი',
    '👰‍♀' => 'ქალი ვუალით',
    '👩‍🍼' => 'ქალი აჭმევს ბავშვს',
    '👨‍🍼' => 'კაცი აჭმევს ბავშვს',
    '🧑‍🍼' => 'ადამიანი აჭმევს ბავშვს',
    '🧑‍🎄' => 'სანტა',
    '🦸‍♂' => 'სუპერგმირი კაცი',
    '🦸‍♀' => 'სუპერგმირი ქალი',
    '🦹‍♂' => 'ბოროტი გმირი კაცი',
    '🦹‍♀' => 'ბოროტი გმირი ქალი',
    '🧙‍♂' => 'ჯადოქარი კაცი',
    '🧙‍♀' => 'ჯადოქარი ქალი',
    '🧚‍♂' => 'კაცი ფერია',
    '🧚‍♀' => 'ქალი ფერია',
    '🧛‍♂' => 'ვამპირი კაცი',
    '🧛‍♀' => 'ვამპირი ქალი',
    '🧜‍♂' => 'კაცთევზა',
    '🧜‍♀' => 'ქალთევზა',
    '🧝‍♂' => 'კაცი ელფი',
    '🧝‍♀' => 'ქალი ელფი',
    '🧞‍♂' => 'კაცი ჯინი',
    '🧞‍♀' => 'ქალი ჯინი',
    '🧟‍♂' => 'ზომბი კაცი',
    '🧟‍♀' => 'ზომბი ქალი',
    '💆‍♂' => 'სახის მასაჟი - კაცი',
    '💆‍♀' => 'სახის მასაჟი - ქალი',
    '💇‍♂' => 'კაცის თმის შეჭრა',
    '💇‍♀' => 'ქალის თმის შეჭრა',
    '🚶‍♂' => 'მოსიარულე კაცი',
    '🚶‍♀' => 'მოსიარულე ქალი',
    '🧍‍♂' => 'ფეხზე მდგომი კაცი',
    '🧍‍♀' => 'ფეხზე მდგომი ქალი',
    '🧎‍♂' => 'დაჩოქილი კაცი',
    '🧎‍♀' => 'დაჩოქილი ქალი',
    '🧑‍🦯' => 'ადამიანი თეთრი ხელჯოხით',
    '👨‍🦯' => 'კაცი თეთრი ჯოხით',
    '👩‍🦯' => 'ქალი თეთრი ჯოხით',
    '🧑‍🦼' => 'ადამიანი მოტორიან ეტლში',
    '👨‍🦼' => 'კაცი მოტორიან ეტლში',
    '👩‍🦼' => 'ქალი მოტორიან ეტლში',
    '🧑‍🦽' => 'ადამიანი მექანიკურ ბორბლიან ეტლში',
    '👨‍🦽' => 'კაცი შშმ პირის მექანიკურ ეტლში',
    '👩‍🦽' => 'ქალი შშმ პირის მექანიკურ ეტლში',
    '🏃‍♂' => 'მორბენალი კაცი',
    '🏃‍♀' => 'მორბენალი ქალი',
    '🧑‍🩰' => 'ბალერინა',
    '👯‍♂' => 'მოცეკვავე კაცები',
    '👯‍♀' => 'მოცეკვავე ქალები',
    '🧖‍♂' => 'კაცი საუნაში',
    '🧖‍♀' => 'ქალი საუნაში',
    '🧗‍♂' => 'მთასვლელი კაცი',
    '🧗‍♀' => 'მთასვლელი ქალი',
    '🏌‍♂' => 'გოლფის მოთამაშე კაცი',
    '🏌‍♀' => 'გოლფის მოთამაშე ქალი',
    '🏄‍♂' => 'სერფერი კაცი',
    '🏄‍♀' => 'სერფერი ქალი',
    '🚣‍♂' => 'ნიჩბოსანი კაცი',
    '🚣‍♀' => 'ნიჩბოსანი ქალი',
    '🏊‍♂' => 'მოცურავე კაცი',
    '🏊‍♀' => 'მოცურავე ქალი',
    '⛹‍♂' => 'კაცი ბურთით',
    '⛹‍♀' => 'ქალი ბურთით',
    '🏋‍♂' => 'ძალოსანი კაცი',
    '🏋‍♀' => 'ძალოსანი ქალი',
    '🚴‍♂' => 'კაცი ველოსიპედით',
    '🚴‍♀' => 'ქალი ველოსიპედით',
    '🚵‍♂' => 'კაცი სამთო ველოსიპედით',
    '🚵‍♀' => 'ქალი სამთო ველოსიპედით',
    '🤸‍♂' => 'აკრობატი კაცი',
    '🤸‍♀' => 'აკრობატი ქალი',
    '🤼‍♂' => 'მოჭიდავე კაცები',
    '🤼‍♀' => 'მოჭიდავე ქალები',
    '🤽‍♂' => 'წყალბურთელი კაცი',
    '🤽‍♀' => 'წყალბურთელი ქალი',
    '🤾‍♂' => 'ხელბურთელი კაცი',
    '🤾‍♀' => 'ხელბურთელი ქალი',
    '🤹‍♂' => 'ჟონგლიორი კაცი',
    '🤹‍♀' => 'ჟონგლიორი ქალი',
    '🧘‍♂' => 'ფეხმორთხმული კაცი',
    '🧘‍♀' => 'ფეხმორთხმული ქალი',
    '🧑‍🧒' => 'ოჯახი: ზრდასრული, ბავშვი',
    '🐕‍🦺' => 'მაშველი ძაღლი',
    '🐈‍⬛' => 'შავი კატა',
    '🐻‍❄' => 'პოლარული დათვი',
    '🐦‍⬛' => 'შავი ჩიტი',
    '🐦‍🔥' => 'ფენიქსი',
    '🍋‍🟩' => 'ლაიმი',
    '🍄‍🟫' => 'ყავისფერი სოკო',
    '⛓‍💥' => 'გაწყვეტილი ჯაჭვი',
    '🏳‍🌈' => 'ცისარტყელას დროშა',
    '🏳‍⚧' => 'ტრანსგენდერი დროშა',
    '🏴‍☠' => 'მეკობრეთა დროშა',
    '👋🏻' => 'ხელის ქნევა: კანის ღია ტონალობა',
    '👋🏼' => 'ხელის ქნევა: ღიადან საშუალომდე კანის ტონალობა',
    '👋🏽' => 'ხელის ქნევა: კანის საშუალო ტონალობა',
    '👋🏾' => 'ხელის ქნევა: საშუალოდან მუქამდე კანის ტონალობა',
    '👋🏿' => 'ხელის ქნევა: კანის მუქი ტონალობა',
    '🤚🏻' => 'აწეული ხელის ზურგიდან: კანის ღია ტონალობა',
    '🤚🏼' => 'აწეული ხელის ზურგიდან: ღიადან საშუალომდე კანის ტონალობა',
    '🤚🏽' => 'აწეული ხელის ზურგიდან: კანის საშუალო ტონალობა',
    '🤚🏾' => 'აწეული ხელის ზურგიდან: საშუალოდან მუქამდე კანის ტონალობა',
    '🤚🏿' => 'აწეული ხელის ზურგიდან: კანის მუქი ტონალობა',
    '🖐🏻' => 'აწეული ხელი გაშლილი თითებით: კანის ღია ტონალობა',
    '🖐🏼' => 'აწეული ხელი გაშლილი თითებით: ღიადან საშუალომდე კანის ტონალობა',
    '🖐🏽' => 'აწეული ხელი გაშლილი თითებით: კანის საშუალო ტონალობა',
    '🖐🏾' => 'აწეული ხელი გაშლილი თითებით: საშუალოდან მუქამდე კანის ტონალობა',
    '🖐🏿' => 'აწეული ხელი გაშლილი თითებით: კანის მუქი ტონალობა',
    '✋🏻' => 'აწეული ხელი: კანის ღია ტონალობა',
    '✋🏼' => 'აწეული ხელი: ღიადან საშუალომდე კანის ტონალობა',
    '✋🏽' => 'აწეული ხელი: კანის საშუალო ტონალობა',
    '✋🏾' => 'აწეული ხელი: საშუალოდან მუქამდე კანის ტონალობა',
    '✋🏿' => 'აწეული ხელი: კანის მუქი ტონალობა',
    '🖖🏻' => 'ვულკანელების მისალმება: კანის ღია ტონალობა',
    '🖖🏼' => 'ვულკანელების მისალმება: ღიადან საშუალომდე კანის ტონალობა',
    '🖖🏽' => 'ვულკანელების მისალმება: კანის საშუალო ტონალობა',
    '🖖🏾' => 'ვულკანელების მისალმება: საშუალოდან მუქამდე კანის ტონალობა',
    '🖖🏿' => 'ვულკანელების მისალმება: კანის მუქი ტონალობა',
    '🫱🏻' => 'მარჯვენა ხელი: კანის ღია ტონალობა',
    '🫱🏼' => 'მარჯვენა ხელი: ღიადან საშუალომდე კანის ტონალობა',
    '🫱🏽' => 'მარჯვენა ხელი: კანის საშუალო ტონალობა',
    '🫱🏾' => 'მარჯვენა ხელი: საშუალოდან მუქამდე კანის ტონალობა',
    '🫱🏿' => 'მარჯვენა ხელი: კანის მუქი ტონალობა',
    '🫲🏻' => 'მარცხენა ხელი: კანის ღია ტონალობა',
    '🫲🏼' => 'მარცხენა ხელი: ღიადან საშუალომდე კანის ტონალობა',
    '🫲🏽' => 'მარცხენა ხელი: კანის საშუალო ტონალობა',
    '🫲🏾' => 'მარცხენა ხელი: საშუალოდან მუქამდე კანის ტონალობა',
    '🫲🏿' => 'მარცხენა ხელი: კანის მუქი ტონალობა',
    '🫳🏻' => 'ქვემოთ მიმართული ხელის გული: კანის ღია ტონალობა',
    '🫳🏼' => 'ქვემოთ მიმართული ხელის გული: ღიადან საშუალომდე კანის ტონალობა',
    '🫳🏽' => 'ქვემოთ მიმართული ხელის გული: კანის საშუალო ტონალობა',
    '🫳🏾' => 'ქვემოთ მიმართული ხელის გული: საშუალოდან მუქამდე კანის ტონალობა',
    '🫳🏿' => 'ქვემოთ მიმართული ხელის გული: კანის მუქი ტონალობა',
    '🫴🏻' => 'ზემოთ მიმართული ხელის გული: კანის ღია ტონალობა',
    '🫴🏼' => 'ზემოთ მიმართული ხელის გული: ღიადან საშუალომდე კანის ტონალობა',
    '🫴🏽' => 'ზემოთ მიმართული ხელის გული: კანის საშუალო ტონალობა',
    '🫴🏾' => 'ზემოთ მიმართული ხელის გული: საშუალოდან მუქამდე კანის ტონალობა',
    '🫴🏿' => 'ზემოთ მიმართული ხელის გული: კანის მუქი ტონალობა',
    '🫷🏻' => 'მარცხნივ მიწოლის ხელი: კანის ღია ტონალობა',
    '🫷🏼' => 'მარცხნივ მიწოლის ხელი: ღიადან საშუალომდე კანის ტონალობა',
    '🫷🏽' => 'მარცხნივ მიწოლის ხელი: კანის საშუალო ტონალობა',
    '🫷🏾' => 'მარცხნივ მიწოლის ხელი: საშუალოდან მუქამდე კანის ტონალობა',
    '🫷🏿' => 'მარცხნივ მიწოლის ხელი: კანის მუქი ტონალობა',
    '🫸🏻' => 'მარჯვნივ მიწოლის ხელი: კანის ღია ტონალობა',
    '🫸🏼' => 'მარჯვნივ მიწოლის ხელი: ღიადან საშუალომდე კანის ტონალობა',
    '🫸🏽' => 'მარჯვნივ მიწოლის ხელი: კანის საშუალო ტონალობა',
    '🫸🏾' => 'მარჯვნივ მიწოლის ხელი: საშუალოდან მუქამდე კანის ტონალობა',
    '🫸🏿' => 'მარჯვნივ მიწოლის ხელი: კანის მუქი ტონალობა',
    '👌🏻' => 'ო’ქეის ჟესტი ხელით: კანის ღია ტონალობა',
    '👌🏼' => 'ო’ქეის ჟესტი ხელით: ღიადან საშუალომდე კანის ტონალობა',
    '👌🏽' => 'ო’ქეის ჟესტი ხელით: კანის საშუალო ტონალობა',
    '👌🏾' => 'ო’ქეის ჟესტი ხელით: საშუალოდან მუქამდე კანის ტონალობა',
    '👌🏿' => 'ო’ქეის ჟესტი ხელით: კანის მუქი ტონალობა',
    '🤌🏻' => 'შეჯგუფებული თითები: კანის ღია ტონალობა',
    '🤌🏼' => 'შეჯგუფებული თითები: ღიადან საშუალომდე კანის ტონალობა',
    '🤌🏽' => 'შეჯგუფებული თითები: კანის საშუალო ტონალობა',
    '🤌🏾' => 'შეჯგუფებული თითები: საშუალოდან მუქამდე კანის ტონალობა',
    '🤌🏿' => 'შეჯგუფებული თითები: კანის მუქი ტონალობა',
    '🤏🏻' => 'ცოტა: კანის ღია ტონალობა',
    '🤏🏼' => 'ცოტა: ღიადან საშუალომდე კანის ტონალობა',
    '🤏🏽' => 'ცოტა: კანის საშუალო ტონალობა',
    '🤏🏾' => 'ცოტა: საშუალოდან მუქამდე კანის ტონალობა',
    '🤏🏿' => 'ცოტა: კანის მუქი ტონალობა',
    '✌🏻' => 'გამარჯვების გამოხატვა ხელით: კანის ღია ტონალობა',
    '✌🏼' => 'გამარჯვების გამოხატვა ხელით: ღიადან საშუალომდე კანის ტონალობა',
    '✌🏽' => 'გამარჯვების გამოხატვა ხელით: კანის საშუალო ტონალობა',
    '✌🏾' => 'გამარჯვების გამოხატვა ხელით: საშუალოდან მუქამდე კანის ტონალობა',
    '✌🏿' => 'გამარჯვების გამოხატვა ხელით: კანის მუქი ტონალობა',
    '🤞🏻' => 'გადაჯვარედინებული თითები: კანის ღია ტონალობა',
    '🤞🏼' => 'გადაჯვარედინებული თითები: ღიადან საშუალომდე კანის ტონალობა',
    '🤞🏽' => 'გადაჯვარედინებული თითები: კანის საშუალო ტონალობა',
    '🤞🏾' => 'გადაჯვარედინებული თითები: საშუალოდან მუქამდე კანის ტონალობა',
    '🤞🏿' => 'გადაჯვარედინებული თითები: კანის მუქი ტონალობა',
    '🫰🏻' => 'ხელი საჩვენებელი თითით და ცერი გადაჯვარედინებული: კანის ღია ტონალობა',
    '🫰🏼' => 'ხელი საჩვენებელი თითით და ცერი გადაჯვარედინებული: ღიადან საშუალომდე კანის ტონალობა',
    '🫰🏽' => 'ხელი საჩვენებელი თითით და ცერი გადაჯვარედინებული: კანის საშუალო ტონალობა',
    '🫰🏾' => 'ხელი საჩვენებელი თითით და ცერი გადაჯვარედინებული: საშუალოდან მუქამდე კანის ტონალობა',
    '🫰🏿' => 'ხელი საჩვენებელი თითით და ცერი გადაჯვარედინებული: კანის მუქი ტონალობა',
    '🤟🏻' => 'ჟესტი „მიყვარხარ“: კანის ღია ტონალობა',
    '🤟🏼' => 'ჟესტი „მიყვარხარ“: ღიადან საშუალომდე კანის ტონალობა',
    '🤟🏽' => 'ჟესტი „მიყვარხარ“: კანის საშუალო ტონალობა',
    '🤟🏾' => 'ჟესტი „მიყვარხარ“: საშუალოდან მუქამდე კანის ტონალობა',
    '🤟🏿' => 'ჟესტი „მიყვარხარ“: კანის მუქი ტონალობა',
    '🤘🏻' => 'რქების ნიშანი: კანის ღია ტონალობა',
    '🤘🏼' => 'რქების ნიშანი: ღიადან საშუალომდე კანის ტონალობა',
    '🤘🏽' => 'რქების ნიშანი: კანის საშუალო ტონალობა',
    '🤘🏾' => 'რქების ნიშანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤘🏿' => 'რქების ნიშანი: კანის მუქი ტონალობა',
    '🤙🏻' => '„დამირეკე“ ჟესტი: კანის ღია ტონალობა',
    '🤙🏼' => '„დამირეკე“ ჟესტი: ღიადან საშუალომდე კანის ტონალობა',
    '🤙🏽' => '„დამირეკე“ ჟესტი: კანის საშუალო ტონალობა',
    '🤙🏾' => '„დამირეკე“ ჟესტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤙🏿' => '„დამირეკე“ ჟესტი: კანის მუქი ტონალობა',
    '👈🏻' => 'ხელის ზურგიდან მარხცნივ გაშვერილი საჩვენებელი თითი: კანის ღია ტონალობა',
    '👈🏼' => 'ხელის ზურგიდან მარხცნივ გაშვერილი საჩვენებელი თითი: ღიადან საშუალომდე კანის ტონალობა',
    '👈🏽' => 'ხელის ზურგიდან მარხცნივ გაშვერილი საჩვენებელი თითი: კანის საშუალო ტონალობა',
    '👈🏾' => 'ხელის ზურგიდან მარხცნივ გაშვერილი საჩვენებელი თითი: საშუალოდან მუქამდე კანის ტონალობა',
    '👈🏿' => 'ხელის ზურგიდან მარხცნივ გაშვერილი საჩვენებელი თითი: კანის მუქი ტონალობა',
    '👉🏻' => 'ხელის ზურგიდან მარჯვნივ გაშვერილი საჩვენებელი თითი: კანის ღია ტონალობა',
    '👉🏼' => 'ხელის ზურგიდან მარჯვნივ გაშვერილი საჩვენებელი თითი: ღიადან საშუალომდე კანის ტონალობა',
    '👉🏽' => 'ხელის ზურგიდან მარჯვნივ გაშვერილი საჩვენებელი თითი: კანის საშუალო ტონალობა',
    '👉🏾' => 'ხელის ზურგიდან მარჯვნივ გაშვერილი საჩვენებელი თითი: საშუალოდან მუქამდე კანის ტონალობა',
    '👉🏿' => 'ხელის ზურგიდან მარჯვნივ გაშვერილი საჩვენებელი თითი: კანის მუქი ტონალობა',
    '👆🏻' => 'ხელის ზურგიდან ზემოთ აშვერილი საჩვენებელი თითი: კანის ღია ტონალობა',
    '👆🏼' => 'ხელის ზურგიდან ზემოთ აშვერილი საჩვენებელი თითი: ღიადან საშუალომდე კანის ტონალობა',
    '👆🏽' => 'ხელის ზურგიდან ზემოთ აშვერილი საჩვენებელი თითი: კანის საშუალო ტონალობა',
    '👆🏾' => 'ხელის ზურგიდან ზემოთ აშვერილი საჩვენებელი თითი: საშუალოდან მუქამდე კანის ტონალობა',
    '👆🏿' => 'ხელის ზურგიდან ზემოთ აშვერილი საჩვენებელი თითი: კანის მუქი ტონალობა',
    '🖕🏻' => 'შუა თითი: კანის ღია ტონალობა',
    '🖕🏼' => 'შუა თითი: ღიადან საშუალომდე კანის ტონალობა',
    '🖕🏽' => 'შუა თითი: კანის საშუალო ტონალობა',
    '🖕🏾' => 'შუა თითი: საშუალოდან მუქამდე კანის ტონალობა',
    '🖕🏿' => 'შუა თითი: კანის მუქი ტონალობა',
    '👇🏻' => 'ხელის ზურგიდან ქვემოთ დაშვერილი საჩვენებელი თითი: კანის ღია ტონალობა',
    '👇🏼' => 'ხელის ზურგიდან ქვემოთ დაშვერილი საჩვენებელი თითი: ღიადან საშუალომდე კანის ტონალობა',
    '👇🏽' => 'ხელის ზურგიდან ქვემოთ დაშვერილი საჩვენებელი თითი: კანის საშუალო ტონალობა',
    '👇🏾' => 'ხელის ზურგიდან ქვემოთ დაშვერილი საჩვენებელი თითი: საშუალოდან მუქამდე კანის ტონალობა',
    '👇🏿' => 'ხელის ზურგიდან ქვემოთ დაშვერილი საჩვენებელი თითი: კანის მუქი ტონალობა',
    '☝🏻' => 'ზემოთ აშვერილი საჩვენებელი თითი: კანის ღია ტონალობა',
    '☝🏼' => 'ზემოთ აშვერილი საჩვენებელი თითი: ღიადან საშუალომდე კანის ტონალობა',
    '☝🏽' => 'ზემოთ აშვერილი საჩვენებელი თითი: კანის საშუალო ტონალობა',
    '☝🏾' => 'ზემოთ აშვერილი საჩვენებელი თითი: საშუალოდან მუქამდე კანის ტონალობა',
    '☝🏿' => 'ზემოთ აშვერილი საჩვენებელი თითი: კანის მუქი ტონალობა',
    '🫵🏻' => 'საჩვენებელი თითი თავისკენ მიუთითებს: კანის ღია ტონალობა',
    '🫵🏼' => 'საჩვენებელი თითი თავისკენ მიუთითებს: ღიადან საშუალომდე კანის ტონალობა',
    '🫵🏽' => 'საჩვენებელი თითი თავისკენ მიუთითებს: კანის საშუალო ტონალობა',
    '🫵🏾' => 'საჩვენებელი თითი თავისკენ მიუთითებს: საშუალოდან მუქამდე კანის ტონალობა',
    '🫵🏿' => 'საჩვენებელი თითი თავისკენ მიუთითებს: კანის მუქი ტონალობა',
    '👍🏻' => 'ცერა ზემოთ: კანის ღია ტონალობა',
    '👍🏼' => 'ცერა ზემოთ: ღიადან საშუალომდე კანის ტონალობა',
    '👍🏽' => 'ცერა ზემოთ: კანის საშუალო ტონალობა',
    '👍🏾' => 'ცერა ზემოთ: საშუალოდან მუქამდე კანის ტონალობა',
    '👍🏿' => 'ცერა ზემოთ: კანის მუქი ტონალობა',
    '👎🏻' => 'ცერა ქვემოთ: კანის ღია ტონალობა',
    '👎🏼' => 'ცერა ქვემოთ: ღიადან საშუალომდე კანის ტონალობა',
    '👎🏽' => 'ცერა ქვემოთ: კანის საშუალო ტონალობა',
    '👎🏾' => 'ცერა ქვემოთ: საშუალოდან მუქამდე კანის ტონალობა',
    '👎🏿' => 'ცერა ქვემოთ: კანის მუქი ტონალობა',
    '✊🏻' => 'აწეული მუშტი: კანის ღია ტონალობა',
    '✊🏼' => 'აწეული მუშტი: ღიადან საშუალომდე კანის ტონალობა',
    '✊🏽' => 'აწეული მუშტი: კანის საშუალო ტონალობა',
    '✊🏾' => 'აწეული მუშტი: საშუალოდან მუქამდე კანის ტონალობა',
    '✊🏿' => 'აწეული მუშტი: კანის მუქი ტონალობა',
    '👊🏻' => 'მოახლოებული მუშტი: კანის ღია ტონალობა',
    '👊🏼' => 'მოახლოებული მუშტი: ღიადან საშუალომდე კანის ტონალობა',
    '👊🏽' => 'მოახლოებული მუშტი: კანის საშუალო ტონალობა',
    '👊🏾' => 'მოახლოებული მუშტი: საშუალოდან მუქამდე კანის ტონალობა',
    '👊🏿' => 'მოახლოებული მუშტი: კანის მუქი ტონალობა',
    '🤛🏻' => 'მარცხნივ მიმართული მუშტი: კანის ღია ტონალობა',
    '🤛🏼' => 'მარცხნივ მიმართული მუშტი: ღიადან საშუალომდე კანის ტონალობა',
    '🤛🏽' => 'მარცხნივ მიმართული მუშტი: კანის საშუალო ტონალობა',
    '🤛🏾' => 'მარცხნივ მიმართული მუშტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤛🏿' => 'მარცხნივ მიმართული მუშტი: კანის მუქი ტონალობა',
    '🤜🏻' => 'მარჯვნივ მიმართული მუშტი: კანის ღია ტონალობა',
    '🤜🏼' => 'მარჯვნივ მიმართული მუშტი: ღიადან საშუალომდე კანის ტონალობა',
    '🤜🏽' => 'მარჯვნივ მიმართული მუშტი: კანის საშუალო ტონალობა',
    '🤜🏾' => 'მარჯვნივ მიმართული მუშტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤜🏿' => 'მარჯვნივ მიმართული მუშტი: კანის მუქი ტონალობა',
    '👏🏻' => 'ხელები, რომლებიც ტაშს უკრავს: კანის ღია ტონალობა',
    '👏🏼' => 'ხელები, რომლებიც ტაშს უკრავს: ღიადან საშუალომდე კანის ტონალობა',
    '👏🏽' => 'ხელები, რომლებიც ტაშს უკრავს: კანის საშუალო ტონალობა',
    '👏🏾' => 'ხელები, რომლებიც ტაშს უკრავს: საშუალოდან მუქამდე კანის ტონალობა',
    '👏🏿' => 'ხელები, რომლებიც ტაშს უკრავს: კანის მუქი ტონალობა',
    '🙌🏻' => 'ხელებაწეული პიროვნება: კანის ღია ტონალობა',
    '🙌🏼' => 'ხელებაწეული პიროვნება: ღიადან საშუალომდე კანის ტონალობა',
    '🙌🏽' => 'ხელებაწეული პიროვნება: კანის საშუალო ტონალობა',
    '🙌🏾' => 'ხელებაწეული პიროვნება: საშუალოდან მუქამდე კანის ტონალობა',
    '🙌🏿' => 'ხელებაწეული პიროვნება: კანის მუქი ტონალობა',
    '🫶🏻' => 'გულის ჟესტი: კანის ღია ტონალობა',
    '🫶🏼' => 'გულის ჟესტი: ღიადან საშუალომდე კანის ტონალობა',
    '🫶🏽' => 'გულის ჟესტი: კანის საშუალო ტონალობა',
    '🫶🏾' => 'გულის ჟესტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🫶🏿' => 'გულის ჟესტი: კანის მუქი ტონალობა',
    '👐🏻' => 'გაშლილი ხელები: კანის ღია ტონალობა',
    '👐🏼' => 'გაშლილი ხელები: ღიადან საშუალომდე კანის ტონალობა',
    '👐🏽' => 'გაშლილი ხელები: კანის საშუალო ტონალობა',
    '👐🏾' => 'გაშლილი ხელები: საშუალოდან მუქამდე კანის ტონალობა',
    '👐🏿' => 'გაშლილი ხელები: კანის მუქი ტონალობა',
    '🤲🏻' => 'ზეცისკენ აღპყრობილი ხელისგულები: კანის ღია ტონალობა',
    '🤲🏼' => 'ზეცისკენ აღპყრობილი ხელისგულები: ღიადან საშუალომდე კანის ტონალობა',
    '🤲🏽' => 'ზეცისკენ აღპყრობილი ხელისგულები: კანის საშუალო ტონალობა',
    '🤲🏾' => 'ზეცისკენ აღპყრობილი ხელისგულები: საშუალოდან მუქამდე კანის ტონალობა',
    '🤲🏿' => 'ზეცისკენ აღპყრობილი ხელისგულები: კანის მუქი ტონალობა',
    '🤝🏻' => 'ხელის ჩამორთმევა: კანის ღია ტონალობა',
    '🤝🏼' => 'ხელის ჩამორთმევა: ღიადან საშუალომდე კანის ტონალობა',
    '🤝🏽' => 'ხელის ჩამორთმევა: კანის საშუალო ტონალობა',
    '🤝🏾' => 'ხელის ჩამორთმევა: საშუალოდან მუქამდე კანის ტონალობა',
    '🤝🏿' => 'ხელის ჩამორთმევა: კანის მუქი ტონალობა',
    '🙏🏻' => 'ერთმანეთზე მიდებული ხელები: კანის ღია ტონალობა',
    '🙏🏼' => 'ერთმანეთზე მიდებული ხელები: ღიადან საშუალომდე კანის ტონალობა',
    '🙏🏽' => 'ერთმანეთზე მიდებული ხელები: კანის საშუალო ტონალობა',
    '🙏🏾' => 'ერთმანეთზე მიდებული ხელები: საშუალოდან მუქამდე კანის ტონალობა',
    '🙏🏿' => 'ერთმანეთზე მიდებული ხელები: კანის მუქი ტონალობა',
    '✍🏻' => 'ხელი, რომელიც წერს: კანის ღია ტონალობა',
    '✍🏼' => 'ხელი, რომელიც წერს: ღიადან საშუალომდე კანის ტონალობა',
    '✍🏽' => 'ხელი, რომელიც წერს: კანის საშუალო ტონალობა',
    '✍🏾' => 'ხელი, რომელიც წერს: საშუალოდან მუქამდე კანის ტონალობა',
    '✍🏿' => 'ხელი, რომელიც წერს: კანის მუქი ტონალობა',
    '💅🏻' => 'ფრჩხილების ლაქი: კანის ღია ტონალობა',
    '💅🏼' => 'ფრჩხილების ლაქი: ღიადან საშუალომდე კანის ტონალობა',
    '💅🏽' => 'ფრჩხილების ლაქი: კანის საშუალო ტონალობა',
    '💅🏾' => 'ფრჩხილების ლაქი: საშუალოდან მუქამდე კანის ტონალობა',
    '💅🏿' => 'ფრჩხილების ლაქი: კანის მუქი ტონალობა',
    '🤳🏻' => 'სელფი: კანის ღია ტონალობა',
    '🤳🏼' => 'სელფი: ღიადან საშუალომდე კანის ტონალობა',
    '🤳🏽' => 'სელფი: კანის საშუალო ტონალობა',
    '🤳🏾' => 'სელფი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤳🏿' => 'სელფი: კანის მუქი ტონალობა',
    '💪🏻' => 'მოხრილი ბიცეპსები: კანის ღია ტონალობა',
    '💪🏼' => 'მოხრილი ბიცეპსები: ღიადან საშუალომდე კანის ტონალობა',
    '💪🏽' => 'მოხრილი ბიცეპსები: კანის საშუალო ტონალობა',
    '💪🏾' => 'მოხრილი ბიცეპსები: საშუალოდან მუქამდე კანის ტონალობა',
    '💪🏿' => 'მოხრილი ბიცეპსები: კანის მუქი ტონალობა',
    '🦵🏻' => 'ფეხი: კანის ღია ტონალობა',
    '🦵🏼' => 'ფეხი: ღიადან საშუალომდე კანის ტონალობა',
    '🦵🏽' => 'ფეხი: კანის საშუალო ტონალობა',
    '🦵🏾' => 'ფეხი: საშუალოდან მუქამდე კანის ტონალობა',
    '🦵🏿' => 'ფეხი: კანის მუქი ტონალობა',
    '🦶🏻' => 'ტერფი: კანის ღია ტონალობა',
    '🦶🏼' => 'ტერფი: ღიადან საშუალომდე კანის ტონალობა',
    '🦶🏽' => 'ტერფი: კანის საშუალო ტონალობა',
    '🦶🏾' => 'ტერფი: საშუალოდან მუქამდე კანის ტონალობა',
    '🦶🏿' => 'ტერფი: კანის მუქი ტონალობა',
    '👂🏻' => 'ყური: კანის ღია ტონალობა',
    '👂🏼' => 'ყური: ღიადან საშუალომდე კანის ტონალობა',
    '👂🏽' => 'ყური: კანის საშუალო ტონალობა',
    '👂🏾' => 'ყური: საშუალოდან მუქამდე კანის ტონალობა',
    '👂🏿' => 'ყური: კანის მუქი ტონალობა',
    '🦻🏻' => 'ყური სმენის აპარატით: კანის ღია ტონალობა',
    '🦻🏼' => 'ყური სმენის აპარატით: ღიადან საშუალომდე კანის ტონალობა',
    '🦻🏽' => 'ყური სმენის აპარატით: კანის საშუალო ტონალობა',
    '🦻🏾' => 'ყური სმენის აპარატით: საშუალოდან მუქამდე კანის ტონალობა',
    '🦻🏿' => 'ყური სმენის აპარატით: კანის მუქი ტონალობა',
    '👃🏻' => 'ცხვირი: კანის ღია ტონალობა',
    '👃🏼' => 'ცხვირი: ღიადან საშუალომდე კანის ტონალობა',
    '👃🏽' => 'ცხვირი: კანის საშუალო ტონალობა',
    '👃🏾' => 'ცხვირი: საშუალოდან მუქამდე კანის ტონალობა',
    '👃🏿' => 'ცხვირი: კანის მუქი ტონალობა',
    '👶🏻' => 'ჩვილი: კანის ღია ტონალობა',
    '👶🏼' => 'ჩვილი: ღიადან საშუალომდე კანის ტონალობა',
    '👶🏽' => 'ჩვილი: კანის საშუალო ტონალობა',
    '👶🏾' => 'ჩვილი: საშუალოდან მუქამდე კანის ტონალობა',
    '👶🏿' => 'ჩვილი: კანის მუქი ტონალობა',
    '🧒🏻' => 'ბავშვი: კანის ღია ტონალობა',
    '🧒🏼' => 'ბავშვი: ღიადან საშუალომდე კანის ტონალობა',
    '🧒🏽' => 'ბავშვი: კანის საშუალო ტონალობა',
    '🧒🏾' => 'ბავშვი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧒🏿' => 'ბავშვი: კანის მუქი ტონალობა',
    '👦🏻' => 'ბიჭი: კანის ღია ტონალობა',
    '👦🏼' => 'ბიჭი: ღიადან საშუალომდე კანის ტონალობა',
    '👦🏽' => 'ბიჭი: კანის საშუალო ტონალობა',
    '👦🏾' => 'ბიჭი: საშუალოდან მუქამდე კანის ტონალობა',
    '👦🏿' => 'ბიჭი: კანის მუქი ტონალობა',
    '👧🏻' => 'გოგო: კანის ღია ტონალობა',
    '👧🏼' => 'გოგო: ღიადან საშუალომდე კანის ტონალობა',
    '👧🏽' => 'გოგო: კანის საშუალო ტონალობა',
    '👧🏾' => 'გოგო: საშუალოდან მუქამდე კანის ტონალობა',
    '👧🏿' => 'გოგო: კანის მუქი ტონალობა',
    '🧑🏻' => 'სრულწლოვანი: კანის ღია ტონალობა',
    '🧑🏼' => 'სრულწლოვანი: ღიადან საშუალომდე კანის ტონალობა',
    '🧑🏽' => 'სრულწლოვანი: კანის საშუალო ტონალობა',
    '🧑🏾' => 'სრულწლოვანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧑🏿' => 'სრულწლოვანი: კანის მუქი ტონალობა',
    '👱🏻' => 'ქერათმიანი ადამიანი: კანის ღია ტონალობა',
    '👱🏼' => 'ქერათმიანი ადამიანი: ღიადან საშუალომდე კანის ტონალობა',
    '👱🏽' => 'ქერათმიანი ადამიანი: კანის საშუალო ტონალობა',
    '👱🏾' => 'ქერათმიანი ადამიანი: საშუალოდან მუქამდე კანის ტონალობა',
    '👱🏿' => 'ქერათმიანი ადამიანი: კანის მუქი ტონალობა',
    '👨🏻' => 'კაცი: კანის ღია ტონალობა',
    '👨🏼' => 'კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👨🏽' => 'კაცი: კანის საშუალო ტონალობა',
    '👨🏾' => 'კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👨🏿' => 'კაცი: კანის მუქი ტონალობა',
    '🧔🏻' => 'წვეროსანი: კანის ღია ტონალობა',
    '🧔🏼' => 'წვეროსანი: ღიადან საშუალომდე კანის ტონალობა',
    '🧔🏽' => 'წვეროსანი: კანის საშუალო ტონალობა',
    '🧔🏾' => 'წვეროსანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧔🏿' => 'წვეროსანი: კანის მუქი ტონალობა',
    '👩🏻' => 'ქალი: კანის ღია ტონალობა',
    '👩🏼' => 'ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👩🏽' => 'ქალი: კანის საშუალო ტონალობა',
    '👩🏾' => 'ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👩🏿' => 'ქალი: კანის მუქი ტონალობა',
    '🧓🏻' => 'ჭარმაგი: კანის ღია ტონალობა',
    '🧓🏼' => 'ჭარმაგი: ღიადან საშუალომდე კანის ტონალობა',
    '🧓🏽' => 'ჭარმაგი: კანის საშუალო ტონალობა',
    '🧓🏾' => 'ჭარმაგი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧓🏿' => 'ჭარმაგი: კანის მუქი ტონალობა',
    '👴🏻' => 'მოხუცი კაცი: კანის ღია ტონალობა',
    '👴🏼' => 'მოხუცი კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👴🏽' => 'მოხუცი კაცი: კანის საშუალო ტონალობა',
    '👴🏾' => 'მოხუცი კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👴🏿' => 'მოხუცი კაცი: კანის მუქი ტონალობა',
    '👵🏻' => 'მოხუცი ქალი: კანის ღია ტონალობა',
    '👵🏼' => 'მოხუცი ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👵🏽' => 'მოხუცი ქალი: კანის საშუალო ტონალობა',
    '👵🏾' => 'მოხუცი ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👵🏿' => 'მოხუცი ქალი: კანის მუქი ტონალობა',
    '🙍🏻' => 'შეჭმუხნილი პიროვნება: კანის ღია ტონალობა',
    '🙍🏼' => 'შეჭმუხნილი პიროვნება: ღიადან საშუალომდე კანის ტონალობა',
    '🙍🏽' => 'შეჭმუხნილი პიროვნება: კანის საშუალო ტონალობა',
    '🙍🏾' => 'შეჭმუხნილი პიროვნება: საშუალოდან მუქამდე კანის ტონალობა',
    '🙍🏿' => 'შეჭმუხნილი პიროვნება: კანის მუქი ტონალობა',
    '🙎🏻' => 'გაბერილი პიროვნება: კანის ღია ტონალობა',
    '🙎🏼' => 'გაბერილი პიროვნება: ღიადან საშუალომდე კანის ტონალობა',
    '🙎🏽' => 'გაბერილი პიროვნება: კანის საშუალო ტონალობა',
    '🙎🏾' => 'გაბერილი პიროვნება: საშუალოდან მუქამდე კანის ტონალობა',
    '🙎🏿' => 'გაბერილი პიროვნება: კანის მუქი ტონალობა',
    '🙅🏻' => 'ჟესტი „არა“: კანის ღია ტონალობა',
    '🙅🏼' => 'ჟესტი „არა“: ღიადან საშუალომდე კანის ტონალობა',
    '🙅🏽' => 'ჟესტი „არა“: კანის საშუალო ტონალობა',
    '🙅🏾' => 'ჟესტი „არა“: საშუალოდან მუქამდე კანის ტონალობა',
    '🙅🏿' => 'ჟესტი „არა“: კანის მუქი ტონალობა',
    '🙆🏻' => 'ჟესტი „კარგი“: კანის ღია ტონალობა',
    '🙆🏼' => 'ჟესტი „კარგი“: ღიადან საშუალომდე კანის ტონალობა',
    '🙆🏽' => 'ჟესტი „კარგი“: კანის საშუალო ტონალობა',
    '🙆🏾' => 'ჟესტი „კარგი“: საშუალოდან მუქამდე კანის ტონალობა',
    '🙆🏿' => 'ჟესტი „კარგი“: კანის მუქი ტონალობა',
    '💁🏻' => 'საინფორმაციო დახლის თანამშრომელი: კანის ღია ტონალობა',
    '💁🏼' => 'საინფორმაციო დახლის თანამშრომელი: ღიადან საშუალომდე კანის ტონალობა',
    '💁🏽' => 'საინფორმაციო დახლის თანამშრომელი: კანის საშუალო ტონალობა',
    '💁🏾' => 'საინფორმაციო დახლის თანამშრომელი: საშუალოდან მუქამდე კანის ტონალობა',
    '💁🏿' => 'საინფორმაციო დახლის თანამშრომელი: კანის მუქი ტონალობა',
    '🙋🏻' => 'ბედნიერი ხელაწეული პიროვნება: კანის ღია ტონალობა',
    '🙋🏼' => 'ბედნიერი ხელაწეული პიროვნება: ღიადან საშუალომდე კანის ტონალობა',
    '🙋🏽' => 'ბედნიერი ხელაწეული პიროვნება: კანის საშუალო ტონალობა',
    '🙋🏾' => 'ბედნიერი ხელაწეული პიროვნება: საშუალოდან მუქამდე კანის ტონალობა',
    '🙋🏿' => 'ბედნიერი ხელაწეული პიროვნება: კანის მუქი ტონალობა',
    '🧏🏻' => 'ყრუ ადამიანი: კანის ღია ტონალობა',
    '🧏🏼' => 'ყრუ ადამიანი: ღიადან საშუალომდე კანის ტონალობა',
    '🧏🏽' => 'ყრუ ადამიანი: კანის საშუალო ტონალობა',
    '🧏🏾' => 'ყრუ ადამიანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧏🏿' => 'ყრუ ადამიანი: კანის მუქი ტონალობა',
    '🙇🏻' => 'თავდახრილი პიროვნება: კანის ღია ტონალობა',
    '🙇🏼' => 'თავდახრილი პიროვნება: ღიადან საშუალომდე კანის ტონალობა',
    '🙇🏽' => 'თავდახრილი პიროვნება: კანის საშუალო ტონალობა',
    '🙇🏾' => 'თავდახრილი პიროვნება: საშუალოდან მუქამდე კანის ტონალობა',
    '🙇🏿' => 'თავდახრილი პიროვნება: კანის მუქი ტონალობა',
    '🤦🏻' => 'სახეზე ხელის აფარება: კანის ღია ტონალობა',
    '🤦🏼' => 'სახეზე ხელის აფარება: ღიადან საშუალომდე კანის ტონალობა',
    '🤦🏽' => 'სახეზე ხელის აფარება: კანის საშუალო ტონალობა',
    '🤦🏾' => 'სახეზე ხელის აფარება: საშუალოდან მუქამდე კანის ტონალობა',
    '🤦🏿' => 'სახეზე ხელის აფარება: კანის მუქი ტონალობა',
    '🤷🏻' => 'მხრების აჩეჩვა: კანის ღია ტონალობა',
    '🤷🏼' => 'მხრების აჩეჩვა: ღიადან საშუალომდე კანის ტონალობა',
    '🤷🏽' => 'მხრების აჩეჩვა: კანის საშუალო ტონალობა',
    '🤷🏾' => 'მხრების აჩეჩვა: საშუალოდან მუქამდე კანის ტონალობა',
    '🤷🏿' => 'მხრების აჩეჩვა: კანის მუქი ტონალობა',
    '👮🏻' => 'პოლიციელი: კანის ღია ტონალობა',
    '👮🏼' => 'პოლიციელი: ღიადან საშუალომდე კანის ტონალობა',
    '👮🏽' => 'პოლიციელი: კანის საშუალო ტონალობა',
    '👮🏾' => 'პოლიციელი: საშუალოდან მუქამდე კანის ტონალობა',
    '👮🏿' => 'პოლიციელი: კანის მუქი ტონალობა',
    '🕵🏻' => 'დეტექტივი: კანის ღია ტონალობა',
    '🕵🏼' => 'დეტექტივი: ღიადან საშუალომდე კანის ტონალობა',
    '🕵🏽' => 'დეტექტივი: კანის საშუალო ტონალობა',
    '🕵🏾' => 'დეტექტივი: საშუალოდან მუქამდე კანის ტონალობა',
    '🕵🏿' => 'დეტექტივი: კანის მუქი ტონალობა',
    '💂🏻' => 'ყარაული: კანის ღია ტონალობა',
    '💂🏼' => 'ყარაული: ღიადან საშუალომდე კანის ტონალობა',
    '💂🏽' => 'ყარაული: კანის საშუალო ტონალობა',
    '💂🏾' => 'ყარაული: საშუალოდან მუქამდე კანის ტონალობა',
    '💂🏿' => 'ყარაული: კანის მუქი ტონალობა',
    '🥷🏻' => 'ნინძა: კანის ღია ტონალობა',
    '🥷🏼' => 'ნინძა: ღიადან საშუალომდე კანის ტონალობა',
    '🥷🏽' => 'ნინძა: კანის საშუალო ტონალობა',
    '🥷🏾' => 'ნინძა: საშუალოდან მუქამდე კანის ტონალობა',
    '🥷🏿' => 'ნინძა: კანის მუქი ტონალობა',
    '👷🏻' => 'მშენებელი: კანის ღია ტონალობა',
    '👷🏼' => 'მშენებელი: ღიადან საშუალომდე კანის ტონალობა',
    '👷🏽' => 'მშენებელი: კანის საშუალო ტონალობა',
    '👷🏾' => 'მშენებელი: საშუალოდან მუქამდე კანის ტონალობა',
    '👷🏿' => 'მშენებელი: კანის მუქი ტონალობა',
    '🫅🏻' => 'პირი გვირგვინით: კანის ღია ტონალობა',
    '🫅🏼' => 'პირი გვირგვინით: ღიადან საშუალომდე კანის ტონალობა',
    '🫅🏽' => 'პირი გვირგვინით: კანის საშუალო ტონალობა',
    '🫅🏾' => 'პირი გვირგვინით: საშუალოდან მუქამდე კანის ტონალობა',
    '🫅🏿' => 'პირი გვირგვინით: კანის მუქი ტონალობა',
    '🤴🏻' => 'პრინცი: კანის ღია ტონალობა',
    '🤴🏼' => 'პრინცი: ღიადან საშუალომდე კანის ტონალობა',
    '🤴🏽' => 'პრინცი: კანის საშუალო ტონალობა',
    '🤴🏾' => 'პრინცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤴🏿' => 'პრინცი: კანის მუქი ტონალობა',
    '👸🏻' => 'პრინცესა: კანის ღია ტონალობა',
    '👸🏼' => 'პრინცესა: ღიადან საშუალომდე კანის ტონალობა',
    '👸🏽' => 'პრინცესა: კანის საშუალო ტონალობა',
    '👸🏾' => 'პრინცესა: საშუალოდან მუქამდე კანის ტონალობა',
    '👸🏿' => 'პრინცესა: კანის მუქი ტონალობა',
    '👳🏻' => 'ადამიანი ჩალმით: კანის ღია ტონალობა',
    '👳🏼' => 'ადამიანი ჩალმით: ღიადან საშუალომდე კანის ტონალობა',
    '👳🏽' => 'ადამიანი ჩალმით: კანის საშუალო ტონალობა',
    '👳🏾' => 'ადამიანი ჩალმით: საშუალოდან მუქამდე კანის ტონალობა',
    '👳🏿' => 'ადამიანი ჩალმით: კანის მუქი ტონალობა',
    '👲🏻' => 'კაცი ჩინური ქუდით: კანის ღია ტონალობა',
    '👲🏼' => 'კაცი ჩინური ქუდით: ღიადან საშუალომდე კანის ტონალობა',
    '👲🏽' => 'კაცი ჩინური ქუდით: კანის საშუალო ტონალობა',
    '👲🏾' => 'კაცი ჩინური ქუდით: საშუალოდან მუქამდე კანის ტონალობა',
    '👲🏿' => 'კაცი ჩინური ქუდით: კანის მუქი ტონალობა',
    '🧕🏻' => 'ქალი თავსაბურავით: კანის ღია ტონალობა',
    '🧕🏼' => 'ქალი თავსაბურავით: ღიადან საშუალომდე კანის ტონალობა',
    '🧕🏽' => 'ქალი თავსაბურავით: კანის საშუალო ტონალობა',
    '🧕🏾' => 'ქალი თავსაბურავით: საშუალოდან მუქამდე კანის ტონალობა',
    '🧕🏿' => 'ქალი თავსაბურავით: კანის მუქი ტონალობა',
    '🤵🏻' => 'ადამიანი სმოკინგით: კანის ღია ტონალობა',
    '🤵🏼' => 'ადამიანი სმოკინგით: ღიადან საშუალომდე კანის ტონალობა',
    '🤵🏽' => 'ადამიანი სმოკინგით: კანის საშუალო ტონალობა',
    '🤵🏾' => 'ადამიანი სმოკინგით: საშუალოდან მუქამდე კანის ტონალობა',
    '🤵🏿' => 'ადამიანი სმოკინგით: კანის მუქი ტონალობა',
    '👰🏻' => 'ადამიანი ვუალით: კანის ღია ტონალობა',
    '👰🏼' => 'ადამიანი ვუალით: ღიადან საშუალომდე კანის ტონალობა',
    '👰🏽' => 'ადამიანი ვუალით: კანის საშუალო ტონალობა',
    '👰🏾' => 'ადამიანი ვუალით: საშუალოდან მუქამდე კანის ტონალობა',
    '👰🏿' => 'ადამიანი ვუალით: კანის მუქი ტონალობა',
    '🤰🏻' => 'ორსული ქალი: კანის ღია ტონალობა',
    '🤰🏼' => 'ორსული ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '🤰🏽' => 'ორსული ქალი: კანის საშუალო ტონალობა',
    '🤰🏾' => 'ორსული ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤰🏿' => 'ორსული ქალი: კანის მუქი ტონალობა',
    '🫃🏻' => 'ორსული კაცი: კანის ღია ტონალობა',
    '🫃🏼' => 'ორსული კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🫃🏽' => 'ორსული კაცი: კანის საშუალო ტონალობა',
    '🫃🏾' => 'ორსული კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🫃🏿' => 'ორსული კაცი: კანის მუქი ტონალობა',
    '🫄🏻' => 'ორსული ადამიანი: კანის ღია ტონალობა',
    '🫄🏼' => 'ორსული ადამიანი: ღიადან საშუალომდე კანის ტონალობა',
    '🫄🏽' => 'ორსული ადამიანი: კანის საშუალო ტონალობა',
    '🫄🏾' => 'ორსული ადამიანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🫄🏿' => 'ორსული ადამიანი: კანის მუქი ტონალობა',
    '🤱🏻' => 'მეძუძური: კანის ღია ტონალობა',
    '🤱🏼' => 'მეძუძური: ღიადან საშუალომდე კანის ტონალობა',
    '🤱🏽' => 'მეძუძური: კანის საშუალო ტონალობა',
    '🤱🏾' => 'მეძუძური: საშუალოდან მუქამდე კანის ტონალობა',
    '🤱🏿' => 'მეძუძური: კანის მუქი ტონალობა',
    '👼🏻' => 'ბავშვი ანგელოზი: კანის ღია ტონალობა',
    '👼🏼' => 'ბავშვი ანგელოზი: ღიადან საშუალომდე კანის ტონალობა',
    '👼🏽' => 'ბავშვი ანგელოზი: კანის საშუალო ტონალობა',
    '👼🏾' => 'ბავშვი ანგელოზი: საშუალოდან მუქამდე კანის ტონალობა',
    '👼🏿' => 'ბავშვი ანგელოზი: კანის მუქი ტონალობა',
    '🎅🏻' => 'სანტა კლაუსი: კანის ღია ტონალობა',
    '🎅🏼' => 'სანტა კლაუსი: ღიადან საშუალომდე კანის ტონალობა',
    '🎅🏽' => 'სანტა კლაუსი: კანის საშუალო ტონალობა',
    '🎅🏾' => 'სანტა კლაუსი: საშუალოდან მუქამდე კანის ტონალობა',
    '🎅🏿' => 'სანტა კლაუსი: კანის მუქი ტონალობა',
    '🤶🏻' => 'ქალბატონი კლაუსი: კანის ღია ტონალობა',
    '🤶🏼' => 'ქალბატონი კლაუსი: ღიადან საშუალომდე კანის ტონალობა',
    '🤶🏽' => 'ქალბატონი კლაუსი: კანის საშუალო ტონალობა',
    '🤶🏾' => 'ქალბატონი კლაუსი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤶🏿' => 'ქალბატონი კლაუსი: კანის მუქი ტონალობა',
    '🦸🏻' => 'სუპერგმირი: კანის ღია ტონალობა',
    '🦸🏼' => 'სუპერგმირი: ღიადან საშუალომდე კანის ტონალობა',
    '🦸🏽' => 'სუპერგმირი: კანის საშუალო ტონალობა',
    '🦸🏾' => 'სუპერგმირი: საშუალოდან მუქამდე კანის ტონალობა',
    '🦸🏿' => 'სუპერგმირი: კანის მუქი ტონალობა',
    '🦹🏻' => 'ბოროტი გმირი: კანის ღია ტონალობა',
    '🦹🏼' => 'ბოროტი გმირი: ღიადან საშუალომდე კანის ტონალობა',
    '🦹🏽' => 'ბოროტი გმირი: კანის საშუალო ტონალობა',
    '🦹🏾' => 'ბოროტი გმირი: საშუალოდან მუქამდე კანის ტონალობა',
    '🦹🏿' => 'ბოროტი გმირი: კანის მუქი ტონალობა',
    '🧙🏻' => 'ჯადოქარი: კანის ღია ტონალობა',
    '🧙🏼' => 'ჯადოქარი: ღიადან საშუალომდე კანის ტონალობა',
    '🧙🏽' => 'ჯადოქარი: კანის საშუალო ტონალობა',
    '🧙🏾' => 'ჯადოქარი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧙🏿' => 'ჯადოქარი: კანის მუქი ტონალობა',
    '🧚🏻' => 'ფერია: კანის ღია ტონალობა',
    '🧚🏼' => 'ფერია: ღიადან საშუალომდე კანის ტონალობა',
    '🧚🏽' => 'ფერია: კანის საშუალო ტონალობა',
    '🧚🏾' => 'ფერია: საშუალოდან მუქამდე კანის ტონალობა',
    '🧚🏿' => 'ფერია: კანის მუქი ტონალობა',
    '🧛🏻' => 'ვამპირი: კანის ღია ტონალობა',
    '🧛🏼' => 'ვამპირი: ღიადან საშუალომდე კანის ტონალობა',
    '🧛🏽' => 'ვამპირი: კანის საშუალო ტონალობა',
    '🧛🏾' => 'ვამპირი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧛🏿' => 'ვამპირი: კანის მუქი ტონალობა',
    '🧜🏻' => 'ადამიანთევზა: კანის ღია ტონალობა',
    '🧜🏼' => 'ადამიანთევზა: ღიადან საშუალომდე კანის ტონალობა',
    '🧜🏽' => 'ადამიანთევზა: კანის საშუალო ტონალობა',
    '🧜🏾' => 'ადამიანთევზა: საშუალოდან მუქამდე კანის ტონალობა',
    '🧜🏿' => 'ადამიანთევზა: კანის მუქი ტონალობა',
    '🧝🏻' => 'ელფი: კანის ღია ტონალობა',
    '🧝🏼' => 'ელფი: ღიადან საშუალომდე კანის ტონალობა',
    '🧝🏽' => 'ელფი: კანის საშუალო ტონალობა',
    '🧝🏾' => 'ელფი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧝🏿' => 'ელფი: კანის მუქი ტონალობა',
    '💆🏻' => 'სახის მასაჟი: კანის ღია ტონალობა',
    '💆🏼' => 'სახის მასაჟი: ღიადან საშუალომდე კანის ტონალობა',
    '💆🏽' => 'სახის მასაჟი: კანის საშუალო ტონალობა',
    '💆🏾' => 'სახის მასაჟი: საშუალოდან მუქამდე კანის ტონალობა',
    '💆🏿' => 'სახის მასაჟი: კანის მუქი ტონალობა',
    '💇🏻' => 'თმის შეჭრა: კანის ღია ტონალობა',
    '💇🏼' => 'თმის შეჭრა: ღიადან საშუალომდე კანის ტონალობა',
    '💇🏽' => 'თმის შეჭრა: კანის საშუალო ტონალობა',
    '💇🏾' => 'თმის შეჭრა: საშუალოდან მუქამდე კანის ტონალობა',
    '💇🏿' => 'თმის შეჭრა: კანის მუქი ტონალობა',
    '🚶🏻' => 'ქვეითი: კანის ღია ტონალობა',
    '🚶🏼' => 'ქვეითი: ღიადან საშუალომდე კანის ტონალობა',
    '🚶🏽' => 'ქვეითი: კანის საშუალო ტონალობა',
    '🚶🏾' => 'ქვეითი: საშუალოდან მუქამდე კანის ტონალობა',
    '🚶🏿' => 'ქვეითი: კანის მუქი ტონალობა',
    '🧍🏻' => 'ფეხზე მდგომი ადამიანი: კანის ღია ტონალობა',
    '🧍🏼' => 'ფეხზე მდგომი ადამიანი: ღიადან საშუალომდე კანის ტონალობა',
    '🧍🏽' => 'ფეხზე მდგომი ადამიანი: კანის საშუალო ტონალობა',
    '🧍🏾' => 'ფეხზე მდგომი ადამიანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧍🏿' => 'ფეხზე მდგომი ადამიანი: კანის მუქი ტონალობა',
    '🧎🏻' => 'დაჩოქილი ადამიანი: კანის ღია ტონალობა',
    '🧎🏼' => 'დაჩოქილი ადამიანი: ღიადან საშუალომდე კანის ტონალობა',
    '🧎🏽' => 'დაჩოქილი ადამიანი: კანის საშუალო ტონალობა',
    '🧎🏾' => 'დაჩოქილი ადამიანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧎🏿' => 'დაჩოქილი ადამიანი: კანის მუქი ტონალობა',
    '🏃🏻' => 'მორბენალი: კანის ღია ტონალობა',
    '🏃🏼' => 'მორბენალი: ღიადან საშუალომდე კანის ტონალობა',
    '🏃🏽' => 'მორბენალი: კანის საშუალო ტონალობა',
    '🏃🏾' => 'მორბენალი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏃🏿' => 'მორბენალი: კანის მუქი ტონალობა',
    '💃🏻' => 'მოცეკვავე ქალი: კანის ღია ტონალობა',
    '💃🏼' => 'მოცეკვავე ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '💃🏽' => 'მოცეკვავე ქალი: კანის საშუალო ტონალობა',
    '💃🏾' => 'მოცეკვავე ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '💃🏿' => 'მოცეკვავე ქალი: კანის მუქი ტონალობა',
    '🕺🏻' => 'მოცეკვავე კაცი: კანის ღია ტონალობა',
    '🕺🏼' => 'მოცეკვავე კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '🕺🏽' => 'მოცეკვავე კაცი: კანის საშუალო ტონალობა',
    '🕺🏾' => 'მოცეკვავე კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '🕺🏿' => 'მოცეკვავე კაცი: კანის მუქი ტონალობა',
    '🕴🏻' => 'ჰაერში გაჩერებული კაცი ბიზნეს კოსტიუმში: კანის ღია ტონალობა',
    '🕴🏼' => 'ჰაერში გაჩერებული კაცი ბიზნეს კოსტიუმში: ღიადან საშუალომდე კანის ტონალობა',
    '🕴🏽' => 'ჰაერში გაჩერებული კაცი ბიზნეს კოსტიუმში: კანის საშუალო ტონალობა',
    '🕴🏾' => 'ჰაერში გაჩერებული კაცი ბიზნეს კოსტიუმში: საშუალოდან მუქამდე კანის ტონალობა',
    '🕴🏿' => 'ჰაერში გაჩერებული კაცი ბიზნეს კოსტიუმში: კანის მუქი ტონალობა',
    '👯🏻' => 'ქალები ერთობიან: კანის ღია ტონალობა',
    '👯🏼' => 'ქალები ერთობიან: ღიადან საშუალომდე კანის ტონალობა',
    '👯🏽' => 'ქალები ერთობიან: კანის საშუალო ტონალობა',
    '👯🏾' => 'ქალები ერთობიან: საშუალოდან მუქამდე კანის ტონალობა',
    '👯🏿' => 'ქალები ერთობიან: კანის მუქი ტონალობა',
    '🧖🏻' => 'ადამიანი საუნაში: კანის ღია ტონალობა',
    '🧖🏼' => 'ადამიანი საუნაში: ღიადან საშუალომდე კანის ტონალობა',
    '🧖🏽' => 'ადამიანი საუნაში: კანის საშუალო ტონალობა',
    '🧖🏾' => 'ადამიანი საუნაში: საშუალოდან მუქამდე კანის ტონალობა',
    '🧖🏿' => 'ადამიანი საუნაში: კანის მუქი ტონალობა',
    '🧗🏻' => 'მთასვლელი: კანის ღია ტონალობა',
    '🧗🏼' => 'მთასვლელი: ღიადან საშუალომდე კანის ტონალობა',
    '🧗🏽' => 'მთასვლელი: კანის საშუალო ტონალობა',
    '🧗🏾' => 'მთასვლელი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧗🏿' => 'მთასვლელი: კანის მუქი ტონალობა',
    '🏇🏻' => 'დოღი: კანის ღია ტონალობა',
    '🏇🏼' => 'დოღი: ღიადან საშუალომდე კანის ტონალობა',
    '🏇🏽' => 'დოღი: კანის საშუალო ტონალობა',
    '🏇🏾' => 'დოღი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏇🏿' => 'დოღი: კანის მუქი ტონალობა',
    '🏂🏻' => 'სნოუბორდისტი: კანის ღია ტონალობა',
    '🏂🏼' => 'სნოუბორდისტი: ღიადან საშუალომდე კანის ტონალობა',
    '🏂🏽' => 'სნოუბორდისტი: კანის საშუალო ტონალობა',
    '🏂🏾' => 'სნოუბორდისტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏂🏿' => 'სნოუბორდისტი: კანის მუქი ტონალობა',
    '🏌🏻' => 'გოლფის მოთამაშე: კანის ღია ტონალობა',
    '🏌🏼' => 'გოლფის მოთამაშე: ღიადან საშუალომდე კანის ტონალობა',
    '🏌🏽' => 'გოლფის მოთამაშე: კანის საშუალო ტონალობა',
    '🏌🏾' => 'გოლფის მოთამაშე: საშუალოდან მუქამდე კანის ტონალობა',
    '🏌🏿' => 'გოლფის მოთამაშე: კანის მუქი ტონალობა',
    '🏄🏻' => 'სერფერი: კანის ღია ტონალობა',
    '🏄🏼' => 'სერფერი: ღიადან საშუალომდე კანის ტონალობა',
    '🏄🏽' => 'სერფერი: კანის საშუალო ტონალობა',
    '🏄🏾' => 'სერფერი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏄🏿' => 'სერფერი: კანის მუქი ტონალობა',
    '🚣🏻' => 'ნავი: კანის ღია ტონალობა',
    '🚣🏼' => 'ნავი: ღიადან საშუალომდე კანის ტონალობა',
    '🚣🏽' => 'ნავი: კანის საშუალო ტონალობა',
    '🚣🏾' => 'ნავი: საშუალოდან მუქამდე კანის ტონალობა',
    '🚣🏿' => 'ნავი: კანის მუქი ტონალობა',
    '🏊🏻' => 'მოცურავე: კანის ღია ტონალობა',
    '🏊🏼' => 'მოცურავე: ღიადან საშუალომდე კანის ტონალობა',
    '🏊🏽' => 'მოცურავე: კანის საშუალო ტონალობა',
    '🏊🏾' => 'მოცურავე: საშუალოდან მუქამდე კანის ტონალობა',
    '🏊🏿' => 'მოცურავე: კანის მუქი ტონალობა',
    '⛹🏻' => 'პიროვნება ბურთით: კანის ღია ტონალობა',
    '⛹🏼' => 'პიროვნება ბურთით: ღიადან საშუალომდე კანის ტონალობა',
    '⛹🏽' => 'პიროვნება ბურთით: კანის საშუალო ტონალობა',
    '⛹🏾' => 'პიროვნება ბურთით: საშუალოდან მუქამდე კანის ტონალობა',
    '⛹🏿' => 'პიროვნება ბურთით: კანის მუქი ტონალობა',
    '🏋🏻' => 'ძალოსანი: კანის ღია ტონალობა',
    '🏋🏼' => 'ძალოსანი: ღიადან საშუალომდე კანის ტონალობა',
    '🏋🏽' => 'ძალოსანი: კანის საშუალო ტონალობა',
    '🏋🏾' => 'ძალოსანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🏋🏿' => 'ძალოსანი: კანის მუქი ტონალობა',
    '🚴🏻' => 'ველოსიპედისტი: კანის ღია ტონალობა',
    '🚴🏼' => 'ველოსიპედისტი: ღიადან საშუალომდე კანის ტონალობა',
    '🚴🏽' => 'ველოსიპედისტი: კანის საშუალო ტონალობა',
    '🚴🏾' => 'ველოსიპედისტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🚴🏿' => 'ველოსიპედისტი: კანის მუქი ტონალობა',
    '🚵🏻' => 'მთის ველოსიპედისტი: კანის ღია ტონალობა',
    '🚵🏼' => 'მთის ველოსიპედისტი: ღიადან საშუალომდე კანის ტონალობა',
    '🚵🏽' => 'მთის ველოსიპედისტი: კანის საშუალო ტონალობა',
    '🚵🏾' => 'მთის ველოსიპედისტი: საშუალოდან მუქამდე კანის ტონალობა',
    '🚵🏿' => 'მთის ველოსიპედისტი: კანის მუქი ტონალობა',
    '🤸🏻' => 'აკრობატული ილეთი: კანის ღია ტონალობა',
    '🤸🏼' => 'აკრობატული ილეთი: ღიადან საშუალომდე კანის ტონალობა',
    '🤸🏽' => 'აკრობატული ილეთი: კანის საშუალო ტონალობა',
    '🤸🏾' => 'აკრობატული ილეთი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤸🏿' => 'აკრობატული ილეთი: კანის მუქი ტონალობა',
    '🤼🏻' => 'მოჭიდავეები: კანის ღია ტონალობა',
    '🤼🏼' => 'მოჭიდავეები: ღიადან საშუალომდე კანის ტონალობა',
    '🤼🏽' => 'მოჭიდავეები: კანის საშუალო ტონალობა',
    '🤼🏾' => 'მოჭიდავეები: საშუალოდან მუქამდე კანის ტონალობა',
    '🤼🏿' => 'მოჭიდავეები: კანის მუქი ტონალობა',
    '🤽🏻' => 'წყალბურთი: კანის ღია ტონალობა',
    '🤽🏼' => 'წყალბურთი: ღიადან საშუალომდე კანის ტონალობა',
    '🤽🏽' => 'წყალბურთი: კანის საშუალო ტონალობა',
    '🤽🏾' => 'წყალბურთი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤽🏿' => 'წყალბურთი: კანის მუქი ტონალობა',
    '🤾🏻' => 'ხელბურთი: კანის ღია ტონალობა',
    '🤾🏼' => 'ხელბურთი: ღიადან საშუალომდე კანის ტონალობა',
    '🤾🏽' => 'ხელბურთი: კანის საშუალო ტონალობა',
    '🤾🏾' => 'ხელბურთი: საშუალოდან მუქამდე კანის ტონალობა',
    '🤾🏿' => 'ხელბურთი: კანის მუქი ტონალობა',
    '🤹🏻' => 'ჟონგლიორობა: კანის ღია ტონალობა',
    '🤹🏼' => 'ჟონგლიორობა: ღიადან საშუალომდე კანის ტონალობა',
    '🤹🏽' => 'ჟონგლიორობა: კანის საშუალო ტონალობა',
    '🤹🏾' => 'ჟონგლიორობა: საშუალოდან მუქამდე კანის ტონალობა',
    '🤹🏿' => 'ჟონგლიორობა: კანის მუქი ტონალობა',
    '🧘🏻' => 'ფეხმორთხმული ადამიანი: კანის ღია ტონალობა',
    '🧘🏼' => 'ფეხმორთხმული ადამიანი: ღიადან საშუალომდე კანის ტონალობა',
    '🧘🏽' => 'ფეხმორთხმული ადამიანი: კანის საშუალო ტონალობა',
    '🧘🏾' => 'ფეხმორთხმული ადამიანი: საშუალოდან მუქამდე კანის ტონალობა',
    '🧘🏿' => 'ფეხმორთხმული ადამიანი: კანის მუქი ტონალობა',
    '🛀🏻' => 'ადამიანი აბაზანაში: კანის ღია ტონალობა',
    '🛀🏼' => 'ადამიანი აბაზანაში: ღიადან საშუალომდე კანის ტონალობა',
    '🛀🏽' => 'ადამიანი აბაზანაში: კანის საშუალო ტონალობა',
    '🛀🏾' => 'ადამიანი აბაზანაში: საშუალოდან მუქამდე კანის ტონალობა',
    '🛀🏿' => 'ადამიანი აბაზანაში: კანის მუქი ტონალობა',
    '🛌🏻' => 'ადამიანი საწოლში: კანის ღია ტონალობა',
    '🛌🏼' => 'ადამიანი საწოლში: ღიადან საშუალომდე კანის ტონალობა',
    '🛌🏽' => 'ადამიანი საწოლში: კანის საშუალო ტონალობა',
    '🛌🏾' => 'ადამიანი საწოლში: საშუალოდან მუქამდე კანის ტონალობა',
    '🛌🏿' => 'ადამიანი საწოლში: კანის მუქი ტონალობა',
    '👭🏻' => 'ორი ხელჩაკიდებული ქალი: კანის ღია ტონალობა',
    '👭🏼' => 'ორი ხელჩაკიდებული ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👭🏽' => 'ორი ხელჩაკიდებული ქალი: კანის საშუალო ტონალობა',
    '👭🏾' => 'ორი ხელჩაკიდებული ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👭🏿' => 'ორი ხელჩაკიდებული ქალი: კანის მუქი ტონალობა',
    '👫🏻' => 'ხელჩაკიდებული კაცი და ქალი: კანის ღია ტონალობა',
    '👫🏼' => 'ხელჩაკიდებული კაცი და ქალი: ღიადან საშუალომდე კანის ტონალობა',
    '👫🏽' => 'ხელჩაკიდებული კაცი და ქალი: კანის საშუალო ტონალობა',
    '👫🏾' => 'ხელჩაკიდებული კაცი და ქალი: საშუალოდან მუქამდე კანის ტონალობა',
    '👫🏿' => 'ხელჩაკიდებული კაცი და ქალი: კანის მუქი ტონალობა',
    '👬🏻' => 'ორი ხელჩაკიდებული კაცი: კანის ღია ტონალობა',
    '👬🏼' => 'ორი ხელჩაკიდებული კაცი: ღიადან საშუალომდე კანის ტონალობა',
    '👬🏽' => 'ორი ხელჩაკიდებული კაცი: კანის საშუალო ტონალობა',
    '👬🏾' => 'ორი ხელჩაკიდებული კაცი: საშუალოდან მუქამდე კანის ტონალობა',
    '👬🏿' => 'ორი ხელჩაკიდებული კაცი: კანის მუქი ტონალობა',
    '💏🏻' => 'კოცნა: კანის ღია ტონალობა',
    '💏🏼' => 'კოცნა: ღიადან საშუალომდე კანის ტონალობა',
    '💏🏽' => 'კოცნა: კანის საშუალო ტონალობა',
    '💏🏾' => 'კოცნა: საშუალოდან მუქამდე კანის ტონალობა',
    '💏🏿' => 'კოცნა: კანის მუქი ტონალობა',
    '💑🏻' => 'წყვილი და გული: კანის ღია ტონალობა',
    '💑🏼' => 'წყვილი და გული: ღიადან საშუალომდე კანის ტონალობა',
    '💑🏽' => 'წყვილი და გული: კანის საშუალო ტონალობა',
    '💑🏾' => 'წყვილი და გული: საშუალოდან მუქამდე კანის ტონალობა',
    '💑🏿' => 'წყვილი და გული: კანის მუქი ტონალობა',
    '🇦🇨' => 'დროშა: ამაღლების კუნძული',
    '🇦🇩' => 'დროშა: ანდორა',
    '🇦🇪' => 'დროშა: არაბთა გაერთიანებული საამიროები',
    '🇦🇫' => 'დროშა: ავღანეთი',
    '🇦🇬' => 'დროშა: ანტიგუა და ბარბუდა',
    '🇦🇮' => 'დროშა: ანგილია',
    '🇦🇱' => 'დროშა: ალბანეთი',
    '🇦🇲' => 'დროშა: სომხეთი',
    '🇦🇴' => 'დროშა: ანგოლა',
    '🇦🇶' => 'დროშა: ანტარქტიკა',
    '🇦🇷' => 'დროშა: არგენტინა',
    '🇦🇸' => 'დროშა: ამერიკის სამოა',
    '🇦🇹' => 'დროშა: ავსტრია',
    '🇦🇺' => 'დროშა: ავსტრალია',
    '🇦🇼' => 'დროშა: არუბა',
    '🇦🇽' => 'დროშა: ალანდის კუნძულები',
    '🇦🇿' => 'დროშა: აზერბაიჯანი',
    '🇧🇦' => 'დროშა: ბოსნია და ჰერცეგოვინა',
    '🇧🇧' => 'დროშა: ბარბადოსი',
    '🇧🇩' => 'დროშა: ბანგლადეში',
    '🇧🇪' => 'დროშა: ბელგია',
    '🇧🇫' => 'დროშა: ბურკინა-ფასო',
    '🇧🇬' => 'დროშა: ბულგარეთი',
    '🇧🇭' => 'დროშა: ბაჰრეინი',
    '🇧🇮' => 'დროშა: ბურუნდი',
    '🇧🇯' => 'დროშა: ბენინი',
    '🇧🇱' => 'დროშა: სენ-ბართელმი',
    '🇧🇲' => 'დროშა: ბერმუდა',
    '🇧🇳' => 'დროშა: ბრუნეი',
    '🇧🇴' => 'დროშა: ბოლივია',
    '🇧🇶' => 'დროშა: კარიბის ნიდერლანდები',
    '🇧🇷' => 'დროშა: ბრაზილია',
    '🇧🇸' => 'დროშა: ბაჰამის კუნძულები',
    '🇧🇹' => 'დროშა: ბუტანი',
    '🇧🇻' => 'დროშა: ბუვე',
    '🇧🇼' => 'დროშა: ბოტსვანა',
    '🇧🇾' => 'დროშა: ბელარუსი',
    '🇧🇿' => 'დროშა: ბელიზი',
    '🇨🇦' => 'დროშა: კანადა',
    '🇨🇨' => 'დროშა: ქოქოსის (კილინგის) კუნძულები',
    '🇨🇩' => 'დროშა: კონგო - კინშასა',
    '🇨🇫' => 'დროშა: ცენტრალური აფრიკის რესპუბლიკა',
    '🇨🇬' => 'დროშა: კონგო - ბრაზავილი',
    '🇨🇭' => 'დროშა: შვეიცარია',
    '🇨🇮' => 'დროშა: კოტ-დივუარი',
    '🇨🇰' => 'დროშა: კუკის კუნძულები',
    '🇨🇱' => 'დროშა: ჩილე',
    '🇨🇲' => 'დროშა: კამერუნი',
    '🇨🇳' => 'დროშა: ჩინეთი',
    '🇨🇴' => 'დროშა: კოლუმბია',
    '🇨🇵' => 'დროშა: კლიპერტონის კუნძული',
    '🇨🇶' => 'დროშა: სარკი',
    '🇨🇷' => 'დროშა: კოსტა-რიკა',
    '🇨🇺' => 'დროშა: კუბა',
    '🇨🇻' => 'დროშა: კაბო-ვერდე',
    '🇨🇼' => 'დროშა: კიურასაო',
    '🇨🇽' => 'დროშა: შობის კუნძული',
    '🇨🇾' => 'დროშა: კვიპროსი',
    '🇨🇿' => 'დროშა: ჩეხეთი',
    '🇩🇪' => 'დროშა: გერმანია',
    '🇩🇬' => 'დროშა: დიეგო-გარსია',
    '🇩🇯' => 'დროშა: ჯიბუტი',
    '🇩🇰' => 'დროშა: დანია',
    '🇩🇲' => 'დროშა: დომინიკა',
    '🇩🇴' => 'დროშა: დომინიკელთა რესპუბლიკა',
    '🇩🇿' => 'დროშა: ალჟირი',
    '🇪🇦' => 'დროშა: სეუტა და მელილა',
    '🇪🇨' => 'დროშა: ეკვადორი',
    '🇪🇪' => 'დროშა: ესტონეთი',
    '🇪🇬' => 'დროშა: ეგვიპტე',
    '🇪🇭' => 'დროშა: დასავლეთ საჰარა',
    '🇪🇷' => 'დროშა: ერიტრეა',
    '🇪🇸' => 'დროშა: ესპანეთი',
    '🇪🇹' => 'დროშა: ეთიოპია',
    '🇪🇺' => 'დროშა: ევროკავშირი',
    '🇫🇮' => 'დროშა: ფინეთი',
    '🇫🇯' => 'დროშა: ფიჯი',
    '🇫🇰' => 'დროშა: ფოლკლენდის კუნძულები',
    '🇫🇲' => 'დროშა: მიკრონეზია',
    '🇫🇴' => 'დროშა: ფარერის კუნძულები',
    '🇫🇷' => 'დროშა: საფრანგეთი',
    '🇬🇦' => 'დროშა: გაბონი',
    '🇬🇧' => 'დროშა: გაერთიანებული სამეფო',
    '🇬🇩' => 'დროშა: გრენადა',
    '🇬🇪' => 'დროშა: საქართველო',
    '🇬🇫' => 'დროშა: საფრანგეთის გვიანა',
    '🇬🇬' => 'დროშა: გერნსი',
    '🇬🇭' => 'დროშა: განა',
    '🇬🇮' => 'დროშა: გიბრალტარი',
    '🇬🇱' => 'დროშა: გრენლანდია',
    '🇬🇲' => 'დროშა: გამბია',
    '🇬🇳' => 'დროშა: გვინეა',
    '🇬🇵' => 'დროშა: გვადელუპა',
    '🇬🇶' => 'დროშა: ეკვატორული გვინეა',
    '🇬🇷' => 'დროშა: საბერძნეთი',
    '🇬🇸' => 'დროშა: სამხრეთ ჯორჯია და სამხრეთ სენდვიჩის კუნძულები',
    '🇬🇹' => 'დროშა: გვატემალა',
    '🇬🇺' => 'დროშა: გუამი',
    '🇬🇼' => 'დროშა: გვინეა-ბისაუ',
    '🇬🇾' => 'დროშა: გაიანა',
    '🇭🇰' => 'დროშა: ჰონკონგის სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი',
    '🇭🇲' => 'დროშა: ჰერდი და მაკდონალდის კუნძულები',
    '🇭🇳' => 'დროშა: ჰონდურასი',
    '🇭🇷' => 'დროშა: ხორვატია',
    '🇭🇹' => 'დროშა: ჰაიტი',
    '🇭🇺' => 'დროშა: უნგრეთი',
    '🇮🇨' => 'დროშა: კანარის კუნძულები',
    '🇮🇩' => 'დროშა: ინდონეზია',
    '🇮🇪' => 'დროშა: ირლანდია',
    '🇮🇱' => 'დროშა: ისრაელი',
    '🇮🇲' => 'დროშა: მენის კუნძული',
    '🇮🇳' => 'დროშა: ინდოეთი',
    '🇮🇴' => 'დროშა: ბრიტანეთის ტერიტორია ინდოეთის ოკეანეში',
    '🇮🇶' => 'დროშა: ერაყი',
    '🇮🇷' => 'დროშა: ირანი',
    '🇮🇸' => 'დროშა: ისლანდია',
    '🇮🇹' => 'დროშა: იტალია',
    '🇯🇪' => 'დროშა: ჯერსი',
    '🇯🇲' => 'დროშა: იამაიკა',
    '🇯🇴' => 'დროშა: იორდანია',
    '🇯🇵' => 'დროშა: იაპონია',
    '🇰🇪' => 'დროშა: კენია',
    '🇰🇬' => 'დროშა: ყირგიზეთი',
    '🇰🇭' => 'დროშა: კამბოჯა',
    '🇰🇮' => 'დროშა: კირიბატი',
    '🇰🇲' => 'დროშა: კომორის კუნძულები',
    '🇰🇳' => 'დროშა: სენტ-კიტსი და ნევისი',
    '🇰🇵' => 'დროშა: ჩრდილოეთ კორეა',
    '🇰🇷' => 'დროშა: სამხრეთ კორეა',
    '🇰🇼' => 'დროშა: ქუვეითი',
    '🇰🇾' => 'დროშა: კაიმანის კუნძულები',
    '🇰🇿' => 'დროშა: ყაზახეთი',
    '🇱🇦' => 'დროშა: ლაოსი',
    '🇱🇧' => 'დროშა: ლიბანი',
    '🇱🇨' => 'დროშა: სენტ-ლუსია',
    '🇱🇮' => 'დროშა: ლიხტენშტაინი',
    '🇱🇰' => 'დროშა: შრი-ლანკა',
    '🇱🇷' => 'დროშა: ლიბერია',
    '🇱🇸' => 'დროშა: ლესოთო',
    '🇱🇹' => 'დროშა: ლიეტუვა',
    '🇱🇺' => 'დროშა: ლუქსემბურგი',
    '🇱🇻' => 'დროშა: ლატვია',
    '🇱🇾' => 'დროშა: ლიბია',
    '🇲🇦' => 'დროშა: მაროკო',
    '🇲🇨' => 'დროშა: მონაკო',
    '🇲🇩' => 'დროშა: მოლდოვა',
    '🇲🇪' => 'დროშა: მონტენეგრო',
    '🇲🇫' => 'დროშა: სენ-მარტენი',
    '🇲🇬' => 'დროშა: მადაგასკარი',
    '🇲🇭' => 'დროშა: მარშალის კუნძულები',
    '🇲🇰' => 'დროშა: ჩრდილოეთ მაკედონია',
    '🇲🇱' => 'დროშა: მალი',
    '🇲🇲' => 'დროშა: მიანმარი (ბირმა)',
    '🇲🇳' => 'დროშა: მონღოლეთი',
    '🇲🇴' => 'დროშა: მაკაოს სპეციალური ადმინისტრაციული რეგიონი, ჩინეთი',
    '🇲🇵' => 'დროშა: ჩრდილოეთ მარიანას კუნძულები',
    '🇲🇶' => 'დროშა: მარტინიკა',
    '🇲🇷' => 'დროშა: მავრიტანია',
    '🇲🇸' => 'დროშა: მონსერატი',
    '🇲🇹' => 'დროშა: მალტა',
    '🇲🇺' => 'დროშა: მავრიკი',
    '🇲🇻' => 'დროშა: მალდივები',
    '🇲🇼' => 'დროშა: მალავი',
    '🇲🇽' => 'დროშა: მექსიკა',
    '🇲🇾' => 'დროშა: მალაიზია',
    '🇲🇿' => 'დროშა: მოზამბიკი',
    '🇳🇦' => 'დროშა: ნამიბია',
    '🇳🇨' => 'დროშა: ახალი კალედონია',
    '🇳🇪' => 'დროშა: ნიგერი',
    '🇳🇫' => 'დროშა: ნორფოლკის კუნძული',
    '🇳🇬' => 'დროშა: ნიგერია',
    '🇳🇮' => 'დროშა: ნიკარაგუა',
    '🇳🇱' => 'დროშა: ნიდერლანდები',
    '🇳🇴' => 'დროშა: ნორვეგია',
    '🇳🇵' => 'დროშა: ნეპალი',
    '🇳🇷' => 'დროშა: ნაურუ',
    '🇳🇺' => 'დროშა: ნიუე',
    '🇳🇿' => 'დროშა: ახალი ზელანდია',
    '🇴🇲' => 'დროშა: ომანი',
    '🇵🇦' => 'დროშა: პანამა',
    '🇵🇪' => 'დროშა: პერუ',
    '🇵🇫' => 'დროშა: საფრანგეთის პოლინეზია',
    '🇵🇬' => 'დროშა: პაპუა-ახალი გვინეა',
    '🇵🇭' => 'დროშა: ფილიპინები',
    '🇵🇰' => 'დროშა: პაკისტანი',
    '🇵🇱' => 'დროშა: პოლონეთი',
    '🇵🇲' => 'დროშა: სენ-პიერი და მიკელონი',
    '🇵🇳' => 'დროშა: პიტკერნის კუნძულები',
    '🇵🇷' => 'დროშა: პუერტო-რიკო',
    '🇵🇸' => 'დროშა: პალესტინის ტერიტორიები',
    '🇵🇹' => 'დროშა: პორტუგალია',
    '🇵🇼' => 'დროშა: პალაუ',
    '🇵🇾' => 'დროშა: პარაგვაი',
    '🇶🇦' => 'დროშა: კატარი',
    '🇷🇪' => 'დროშა: რეუნიონი',
    '🇷🇴' => 'დროშა: რუმინეთი',
    '🇷🇸' => 'დროშა: სერბეთი',
    '🇷🇺' => 'დროშა: რუსეთი',
    '🇷🇼' => 'დროშა: რუანდა',
    '🇸🇦' => 'დროშა: საუდის არაბეთი',
    '🇸🇧' => 'დროშა: სოლომონის კუნძულები',
    '🇸🇨' => 'დროშა: სეიშელის კუნძულები',
    '🇸🇩' => 'დროშა: სუდანი',
    '🇸🇪' => 'დროშა: შვედეთი',
    '🇸🇬' => 'დროშა: სინგაპური',
    '🇸🇭' => 'დროშა: წმინდა ელენეს კუნძული',
    '🇸🇮' => 'დროშა: სლოვენია',
    '🇸🇯' => 'დროშა: შპიცბერგენი და იან-მაიენი',
    '🇸🇰' => 'დროშა: სლოვაკეთი',
    '🇸🇱' => 'დროშა: სიერა-ლეონე',
    '🇸🇲' => 'დროშა: სან-მარინო',
    '🇸🇳' => 'დროშა: სენეგალი',
    '🇸🇴' => 'დროშა: სომალი',
    '🇸🇷' => 'დროშა: სურინამი',
    '🇸🇸' => 'დროშა: სამხრეთ სუდანი',
    '🇸🇹' => 'დროშა: სან-ტომე და პრინსიპი',
    '🇸🇻' => 'დროშა: სალვადორი',
    '🇸🇽' => 'დროშა: სინტ-მარტენი',
    '🇸🇾' => 'დროშა: სირია',
    '🇸🇿' => 'დროშა: სვაზილენდი',
    '🇹🇦' => 'დროშა: ტრისტან-და-კუნია',
    '🇹🇨' => 'დროშა: თერქს-ქაიქოსის კუნძულები',
    '🇹🇩' => 'დროშა: ჩადი',
    '🇹🇫' => 'დროშა: ფრანგული სამხრეთის ტერიტორიები',
    '🇹🇬' => 'დროშა: ტოგო',
    '🇹🇭' => 'დროშა: ტაილანდი',
    '🇹🇯' => 'დროშა: ტაჯიკეთი',
    '🇹🇰' => 'დროშა: ტოკელაუ',
    '🇹🇱' => 'დროშა: ტიმორ-ლესტე',
    '🇹🇲' => 'დროშა: თურქმენეთი',
    '🇹🇳' => 'დროშა: ტუნისი',
    '🇹🇴' => 'დროშა: ტონგა',
    '🇹🇷' => 'დროშა: თურქეთი',
    '🇹🇹' => 'დროშა: ტრინიდადი და ტობაგო',
    '🇹🇻' => 'დროშა: ტუვალუ',
    '🇹🇼' => 'დროშა: ტაივანი',
    '🇹🇿' => 'დროშა: ტანზანია',
    '🇺🇦' => 'დროშა: უკრაინა',
    '🇺🇬' => 'დროშა: უგანდა',
    '🇺🇲' => 'დროშა: აშშ-ის შორეული კუნძულები',
    '🇺🇳' => 'დროშა: გაერო',
    '🇺🇸' => 'დროშა: ამერიკის შეერთებული შტატები',
    '🇺🇾' => 'დროშა: ურუგვაი',
    '🇺🇿' => 'დროშა: უზბეკეთი',
    '🇻🇦' => 'დროშა: ქალაქი ვატიკანი',
    '🇻🇨' => 'დროშა: სენტ-ვინსენტი და გრენადინები',
    '🇻🇪' => 'დროშა: ვენესუელა',
    '🇻🇬' => 'დროშა: ბრიტანეთის ვირჯინის კუნძულები',
    '🇻🇮' => 'დროშა: აშშ-ის ვირჯინის კუნძულები',
    '🇻🇳' => 'დროშა: ვიეტნამი',
    '🇻🇺' => 'დროშა: ვანუატუ',
    '🇼🇫' => 'დროშა: უოლისი და ფუტუნა',
    '🇼🇸' => 'დროშა: სამოა',
    '🇽🇰' => 'დროშა: კოსოვო',
    '🇾🇪' => 'დროშა: იემენი',
    '🇾🇹' => 'დროშა: მაიოტა',
    '🇿🇦' => 'დროშა: სამხრეთ აფრიკის რესპუბლიკა',
    '🇿🇲' => 'დროშა: ზამბია',
    '🇿🇼' => 'დროშა: ზიმბაბვე',
    '🔟' => 'კლავიში: 10',
    '🏻' => 'კანის ღია ტონალობა',
    '🏼' => 'ღიადან საშუალომდე კანის ტონალობა',
    '🏽' => 'კანის საშუალო ტონალობა',
    '🏾' => 'საშუალოდან მუქამდე კანის ტონალობა',
    '🏿' => 'კანის მუქი ტონალობა',
    '😀' => 'დაკრეჭილი სახე',
    '😃' => 'მომღიმარე სახე ღია პირით',
    '😄' => 'მომღიმარე სახე ღია პირითა და მომღიმარე თვალებით',
    '😁' => 'დაკრეჭილი სახე მომღიმარე თვალებით',
    '😆' => 'მომღიმარე სახე ღია პირითა და მაგრად დახუჭული თვალებით',
    '😅' => 'მომღიმარე სახე ღია პირითა და ცივი ოფლით',
    '🤣' => 'სიცილისგან იატაკზე ხოხვა',
    '😂' => 'სახე სიხარულის ცრემლებით',
    '🙂' => 'ოდნავ მომღიმარე სახე',
    '🙃' => 'ამოტრიალებული სახე',
    '🫠' => 'დნება სახე',
    '😉' => 'სახე ჩაკრული თვალით',
    '😊' => 'მომღიმარე სახე მომღიმარე თვალებით',
    '😇' => 'მომღიმარე სახე შარავანდედით',
    '🥰' => 'მომღიმარე სახე სამი გულით',
    '😍' => 'მომღიმარე სახე გულის ფორმის თვალებით',
    '🤩' => 'ვარსკვლავიანი სახე',
    '😘' => 'სახე, რომელიც კოცნას აგზავნის',
    '😗' => 'კოცნის გამომხატველი სახე',
    '☺' => 'მომღიმარე სახე',
    '😚' => 'კოცნის გამომხატველი სახე დახუჭული თვალებით',
    '😙' => 'კოცნის გამომხატველი სახე მომღიმარე თვალებით',
    '🥲' => 'მომღიმარი სახე ცრემლით',
    '😋' => 'სახე, რომელიც გემრიელ საჭმელს აგემოვნებს',
    '😛' => 'სახე გამოყოფილი ენით',
    '😜' => 'სახე გამოყოფილი ენითა და ჩაკრული თვალით',
    '🤪' => 'შეშლილი სახე',
    '😝' => 'სახე გამოყოფილი ენითა და მაგრად დახუჭული თვალებით',
    '🤑' => 'სახე ენაზე ფულით',
    '🤗' => 'ჩახუტების გამომხატველი სახე',
    '🤭' => 'სახეზე აფარებული ხელი',
    '🫢' => 'სახე თვალებგაფართოებული და პირზე ხელი გადასცა',
    '🫣' => 'სახე იჭყიტება ცალი თვალით',
    '🤫' => 'გაჩუმების ჟესტი',
    '🤔' => 'ჩაფიქრებული სახე',
    '🫡' => 'სახე მხედრული სალმით',
    '🤐' => 'ელვა-შესაკრავიანი სახე',
    '🤨' => 'წარბაწეული სახე',
    '😐' => 'ნეიტრალური სახე',
    '😑' => 'უემოციო სახე',
    '😶' => 'უპირო სახე',
    '🫥' => 'პუნქტირით შემოხაზული სახე',
    '😏' => 'დამცინავი სახე',
    '😒' => 'უხალისო სახე',
    '🙄' => 'სახე გადატრიალებული თვალებით',
    '😬' => 'დამანჭული სახე',
    '🤥' => 'მატყუარა სახე',
    '🫨' => 'აცახცახებული სახე',
    '😌' => 'შვების გამომხატველი სახე',
    '😔' => 'ფიქრებში ჩაძირული სახე',
    '😪' => 'ძილმორეული სახე',
    '🤤' => 'დორბლიანი სახე',
    '😴' => 'მძინარე სახე',
    '🫩' => 'სახე დასიებული თვალებით',
    '😷' => 'სახე სამედიცინო ნიღბით',
    '🤒' => 'სახე თერმომეტრით',
    '🤕' => 'სახე თავზე ბინტით',
    '🤢' => 'გულისრევა',
    '🤮' => 'ღებინება',
    '🤧' => 'ცემინება',
    '🥵' => 'ცხელი სახე',
    '🥶' => 'ცივი სახე',
    '🥴' => 'თავბრუდახვეული სახე',
    '😵' => 'გაბრუებული სახე',
    '🤯' => 'აფეთქებული თავი',
    '🤠' => 'სახე კოვბოის ქუდით',
    '🥳' => 'მოზეიმე სახე',
    '🥸' => 'შენიღბული სახე',
    '😎' => 'მომღიმარე სახე მზის სათვალით',
    '🤓' => 'სულელური სახე',
    '🧐' => 'სახე მონოკლით',
    '😕' => 'დაბნეული სახე',
    '🫤' => 'სახე დახრილი პირით',
    '😟' => 'აღელვებული სახე',
    '🙁' => 'ოდნავ შეჭმუხნილი სახე',
    '☹' => 'შეჭმუხნილი სახე',
    '😮' => 'სახე ღია პირით',
    '😯' => 'გაოცებული სახე',
    '😲' => 'გაკვირვებული სახე',
    '😳' => 'გაწითლებული სახე',
    '🫪' => 'მოღრეცილი სახე',
    '🥺' => 'შემოვედრება',
    '🥹' => 'აცრემლიანებული სახე',
    '😦' => 'შეჭმუხნილი სახე ღია პირით',
    '😧' => 'ტანჯული სახე',
    '😨' => 'შეშინებული სახე',
    '😰' => 'სახე ღია პირითა და ცივი ოფლით',
    '😥' => 'იმედგაცრუებული, მაგრამ შვების გამომხატველი სახე',
    '😢' => 'მტირალა სახე',
    '😭' => 'ხმამაღლა მტირალა სახე',
    '😱' => 'სახე, რომელიც შიშისგან კივის',
    '😖' => 'შეცბუნებული სახე',
    '😣' => 'შეუპოვარი სახე',
    '😞' => 'იმედგაცრუებული სახე',
    '😓' => 'სახე ცივი ოფლით',
    '😩' => 'დაქანცული სახე',
    '😫' => 'დაღლილი სახე',
    '🥱' => 'მთქნარება',
    '😤' => 'სახე ცხვირიდან გამომავალი ორთქლით',
    '😡' => 'გაბერილი სახე',
    '😠' => 'გაბრაზებული სახე',
    '🤬' => 'სახე პირზე აფარებული სიმბოლოებით',
    '😈' => 'მომღიმარე სახე რქებით',
    '👿' => 'ეშმაკუნა',
    '💀' => 'თავის ქალა',
    '☠' => 'თავის ქალა და გადაჯვარედინებული ძვლები',
    '💩' => 'განავლის გროვა',
    '🤡' => 'ჯამბაზის სახე',
    '👹' => 'კაციჭამია-გოლიათი',
    '👺' => 'გობლინი',
    '👻' => 'მოჩვენება',
    '👽' => 'უცხოპლანეტელი',
    '👾' => 'უცხოპლანეტელი მონსტრი',
    '🤖' => 'რობოტის სახე',
    '😺' => 'კატის მომღიმარე სახე ღია პირით',
    '😸' => 'კატის დაკრეჭილი სახე მომღიმარე თვალებით',
    '😹' => 'კატის სახე სიხარულის ცრემლებით',
    '😻' => 'კატის მომღიმარე სახე გულის ფორმის თვალებით',
    '😼' => 'კატის სახე უხალისო ღიმილით',
    '😽' => 'კატის კოცნის გამომხატველი სახე დახუჭული თვალებით',
    '🙀' => 'კატის დაქანცული სახე',
    '😿' => 'კატის მტირალა სახე',
    '😾' => 'კატის გაბერილი სახე',
    '🙈' => 'არდანახვა',
    '🙉' => 'არმოსმენა',
    '🙊' => 'ართქმა',
    '💌' => 'სასიყვარულო წერილი',
    '💘' => 'გული ისრით',
    '💝' => 'გული ლენტით',
    '💖' => 'მბრწყინავი გული',
    '💗' => 'მზარდი გული',
    '💓' => 'მფეთქავი გული',
    '💞' => 'მბრუნავი გულები',
    '💕' => 'ორი გული',
    '💟' => 'გულის დეკორაცია',
    '❣' => 'გულის ფორმის მსხვილი ძახილის ნიშანი',
    '💔' => 'გატეხილი გული',
    '❤' => 'წითელი გული',
    '🩷' => 'ვარდისფერი გული',
    '🧡' => 'ნარინჯისფერი გული',
    '💛' => 'ყვითელი გული',
    '💚' => 'მწვანე გული',
    '💙' => 'ლურჯი გული',
    '🩵' => 'ღია ცისფერი გული',
    '💜' => 'იასამნისფერი გული',
    '🤎' => 'ყავისფერი გული',
    '🖤' => 'შავი გული',
    '🩶' => 'რუხი გული',
    '🤍' => 'თეთრი გული',
    '💋' => 'კოცნის კვალი',
    '💯' => 'ასი ქულა',
    '💢' => 'სიბრაზის სიმბოლო',
    '🫯' => 'საბრძოლო ღრუბელი',
    '💥' => 'შეჯახება',
    '💫' => 'გაბრუებული',
    '💦' => 'ოფლის წვეთები',
    '💨' => 'მოწყვეტა',
    '🕳' => 'ხვრელი',
    '💬' => 'საუბრის ბუშტი',
    '🗨' => 'საუბრის მარცხენა ბუშტი',
    '🗯' => 'სიბრაზის მარჯვენა ბუშტი',
    '💭' => 'ფიქრის ბუშტი',
    '💤' => 'zzz',
    '👋' => 'ხელის ქნევა',
    '🤚' => 'აწეული ხელის ზურგიდან',
    '🖐' => 'აწეული ხელი გაშლილი თითებით',
    '✋' => 'აწეული ხელი',
    '🖖' => 'ვულკანელების მისალმება',
    '🫱' => 'მარჯვენა ხელი',
    '🫲' => 'მარცხენა ხელი',
    '🫳' => 'ქვემოთ მიმართული ხელის გული',
    '🫴' => 'ზემოთ მიმართული ხელის გული',
    '🫷' => 'მარცხნივ მიწოლის ხელი',
    '🫸' => 'მარჯვნივ მიწოლის ხელი',
    '👌' => 'ო’ქეის ჟესტი ხელით',
    '🤌' => 'შეჯგუფებული თითები',
    '🤏' => 'ცოტა',
    '✌' => 'გამარჯვების გამოხატვა ხელით',
    '🤞' => 'გადაჯვარედინებული თითები',
    '🫰' => 'ხელი საჩვენებელი თითით და ცერი გადაჯვარედინებული',
    '🤟' => 'ჟესტი „მიყვარხარ“',
    '🤘' => 'რქების ნიშანი',
    '🤙' => '„დამირეკე“ ჟესტი',
    '👈' => 'ხელის ზურგიდან მარხცნივ გაშვერილი საჩვენებელი თითი',
    '👉' => 'ხელის ზურგიდან მარჯვნივ გაშვერილი საჩვენებელი თითი',
    '👆' => 'ხელის ზურგიდან ზემოთ აშვერილი საჩვენებელი თითი',
    '🖕' => 'შუა თითი',
    '👇' => 'ხელის ზურგიდან ქვემოთ დაშვერილი საჩვენებელი თითი',
    '☝' => 'ზემოთ აშვერილი საჩვენებელი თითი',
    '🫵' => 'საჩვენებელი თითი თავისკენ მიუთითებს',
    '👍' => 'ცერა ზემოთ',
    '👎' => 'ცერა ქვემოთ',
    '✊' => 'აწეული მუშტი',
    '👊' => 'მოახლოებული მუშტი',
    '🤛' => 'მარცხნივ მიმართული მუშტი',
    '🤜' => 'მარჯვნივ მიმართული მუშტი',
    '👏' => 'ხელები, რომლებიც ტაშს უკრავს',
    '🙌' => 'ხელებაწეული პიროვნება',
    '🫶' => 'გულის ჟესტი',
    '👐' => 'გაშლილი ხელები',
    '🤲' => 'ზეცისკენ აღპყრობილი ხელისგულები',
    '🤝' => 'ხელის ჩამორთმევა',
    '🙏' => 'ერთმანეთზე მიდებული ხელები',
    '✍' => 'ხელი, რომელიც წერს',
    '💅' => 'ფრჩხილების ლაქი',
    '🤳' => 'სელფი',
    '💪' => 'მოხრილი ბიცეპსები',
    '🦾' => 'მექანიკური მხარი',
    '🦿' => 'მექანიკური ფეხი',
    '🦵' => 'ფეხი',
    '🦶' => 'ტერფი',
    '👂' => 'ყური',
    '🦻' => 'ყური სმენის აპარატით',
    '👃' => 'ცხვირი',
    '🧠' => 'ტვინი',
    '🫀' => 'გული',
    '🫁' => 'ფილტვები',
    '🦷' => 'კბილი',
    '🦴' => 'ძვალი',
    '👀' => 'თვალები',
    '👁' => 'თვალი',
    '👅' => 'ენა',
    '👄' => 'პირი',
    '🫦' => 'ტუჩის კბენა',
    '👶' => 'ჩვილი',
    '🧒' => 'ბავშვი',
    '👦' => 'ბიჭი',
    '👧' => 'გოგო',
    '🧑' => 'სრულწლოვანი',
    '👱' => 'ქერათმიანი ადამიანი',
    '👨' => 'კაცი',
    '🧔' => 'წვეროსანი',
    '👩' => 'ქალი',
    '🧓' => 'ჭარმაგი',
    '👴' => 'მოხუცი კაცი',
    '👵' => 'მოხუცი ქალი',
    '🙍' => 'შეჭმუხნილი პიროვნება',
    '🙎' => 'გაბერილი პიროვნება',
    '🙅' => 'ჟესტი „არა“',
    '🙆' => 'ჟესტი „კარგი“',
    '💁' => 'საინფორმაციო დახლის თანამშრომელი',
    '🙋' => 'ბედნიერი ხელაწეული პიროვნება',
    '🧏' => 'ყრუ ადამიანი',
    '🙇' => 'თავდახრილი პიროვნება',
    '🤦' => 'სახეზე ხელის აფარება',
    '🤷' => 'მხრების აჩეჩვა',
    '👮' => 'პოლიციელი',
    '🕵' => 'დეტექტივი',
    '💂' => 'ყარაული',
    '🥷' => 'ნინძა',
    '👷' => 'მშენებელი',
    '🫅' => 'პირი გვირგვინით',
    '🤴' => 'პრინცი',
    '👸' => 'პრინცესა',
    '👳' => 'ადამიანი ჩალმით',
    '👲' => 'კაცი ჩინური ქუდით',
    '🧕' => 'ქალი თავსაბურავით',
    '🤵' => 'ადამიანი სმოკინგით',
    '👰' => 'ადამიანი ვუალით',
    '🤰' => 'ორსული ქალი',
    '🫃' => 'ორსული კაცი',
    '🫄' => 'ორსული ადამიანი',
    '🤱' => 'მეძუძური',
    '👼' => 'ბავშვი ანგელოზი',
    '🎅' => 'სანტა კლაუსი',
    '🤶' => 'ქალბატონი კლაუსი',
    '🦸' => 'სუპერგმირი',
    '🦹' => 'ბოროტი გმირი',
    '🧙' => 'ჯადოქარი',
    '🧚' => 'ფერია',
    '🧛' => 'ვამპირი',
    '🧜' => 'ადამიანთევზა',
    '🧝' => 'ელფი',
    '🧞' => 'ჯინი',
    '🧟' => 'ზომბი',
    '🧌' => 'ტროლი',
    '🫈' => 'იეტი',
    '💆' => 'სახის მასაჟი',
    '💇' => 'თმის შეჭრა',
    '🚶' => 'ქვეითი',
    '🧍' => 'ფეხზე მდგომი ადამიანი',
    '🧎' => 'დაჩოქილი ადამიანი',
    '🏃' => 'მორბენალი',
    '💃' => 'მოცეკვავე ქალი',
    '🕺' => 'მოცეკვავე კაცი',
    '🕴' => 'ჰაერში გაჩერებული კაცი ბიზნეს კოსტიუმში',
    '👯' => 'ქალები ერთობიან',
    '🧖' => 'ადამიანი საუნაში',
    '🧗' => 'მთასვლელი',
    '🤺' => 'მოფარიკავე',
    '🏇' => 'დოღი',
    '⛷' => 'მოთხილამურე',
    '🏂' => 'სნოუბორდისტი',
    '🏌' => 'გოლფის მოთამაშე',
    '🏄' => 'სერფერი',
    '🚣' => 'ნავი',
    '🏊' => 'მოცურავე',
    '⛹' => 'პიროვნება ბურთით',
    '🏋' => 'ძალოსანი',
    '🚴' => 'ველოსიპედისტი',
    '🚵' => 'მთის ველოსიპედისტი',
    '🤸' => 'აკრობატული ილეთი',
    '🤼' => 'მოჭიდავეები',
    '🤽' => 'წყალბურთი',
    '🤾' => 'ხელბურთი',
    '🤹' => 'ჟონგლიორობა',
    '🧘' => 'ფეხმორთხმული ადამიანი',
    '🛀' => 'ადამიანი აბაზანაში',
    '🛌' => 'ადამიანი საწოლში',
    '👭' => 'ორი ხელჩაკიდებული ქალი',
    '👫' => 'ხელჩაკიდებული კაცი და ქალი',
    '👬' => 'ორი ხელჩაკიდებული კაცი',
    '💏' => 'კოცნა',
    '💑' => 'წყვილი და გული',
    '🗣' => 'მოლაპარაკე თავი',
    '👤' => 'ბიუსტის სილუეტი',
    '👥' => 'ბიუსტების სილუეტი',
    '🫂' => 'ჩახუტებული ხალხი',
    '👪' => 'ოჯახი',
    '👣' => 'ფეხების ნაკვალევი',
    '🫆' => 'თითის ანაბეჭდი',
    '🦰' => 'წითელი თმა',
    '🦱' => 'ხვეული თმა',
    '🦳' => 'თეთრი თმა',
    '🦲' => 'მელოტი',
    '🐵' => 'მაიმუნის სახე',
    '🐒' => 'მაიმუნი',
    '🦍' => 'გორილა',
    '🦧' => 'ორანგუტანი',
    '🐶' => 'ძაღლის სახე',
    '🐕' => 'ძაღლი',
    '🦮' => 'გამყოლი ძაღლი',
    '🐩' => 'პუდელი',
    '🐺' => 'მგლის სახე',
    '🦊' => 'მელიის თავი',
    '🦝' => 'ენოტი',
    '🐱' => 'კატის სახე',
    '🐈' => 'კატა',
    '🦁' => 'ლომის სახე',
    '🐯' => 'ვეფხვის სახე',
    '🐅' => 'ვეფხვი',
    '🐆' => 'ლეოპარდი',
    '🐴' => 'ცხენის სახე',
    '🫎' => 'ლოსი',
    '🫏' => 'ვირი',
    '🐎' => 'ცხენი',
    '🦄' => 'ზღაპრული მარტორქის სახე',
    '🦓' => 'ზებრა',
    '🦌' => 'ირემი',
    '🦬' => 'ბიზონი',
    '🐮' => 'ძროხის სახე',
    '🐂' => 'ხარი',
    '🐃' => 'კამეჩი',
    '🐄' => 'ძროხა',
    '🐷' => 'ღორის სახე',
    '🐖' => 'ღორი',
    '🐗' => 'ტახი',
    '🐽' => 'ღორის დინგი',
    '🐏' => 'ერკემალი',
    '🐑' => 'ცხვარი',
    '🐐' => 'თხა',
    '🐪' => 'აქლემი',
    '🐫' => 'ორკუზიანი აქლემი',
    '🦙' => 'ლამა',
    '🦒' => 'ჟირაფი',
    '🐘' => 'სპილო',
    '🦣' => 'მამონტი',
    '🦏' => 'მარტორქა',
    '🦛' => 'ბეჰემოთი',
    '🐭' => 'თაგვის სახე',
    '🐁' => 'თაგვი',
    '🐀' => 'ვირთხა',
    '🐹' => 'ზაზუნას სახე',
    '🐰' => 'კურდღლის სახე',
    '🐇' => 'კურდღელი',
    '🐿' => 'ციყვი',
    '🦫' => 'თახვი',
    '🦔' => 'ზღარბი',
    '🦇' => 'ღამურა',
    '🐻' => 'დათვის სახე',
    '🐨' => 'კოალა',
    '🐼' => 'პანდას სახე',
    '🦥' => 'ზარმაცა',
    '🦦' => 'წავი',
    '🦨' => 'მყრალა',
    '🦘' => 'კენგურუ',
    '🦡' => 'მაჩვი',
    '🐾' => 'თათების ნაკვალევი',
    '🦃' => 'ინდაური',
    '🐔' => 'ქათამი',
    '🐓' => 'მამალი',
    '🐣' => 'გამოჩეკილი წიწილა',
    '🐤' => 'პატარა წიწილა',
    '🐥' => 'პატარა წიწილა წინიდან',
    '🐦' => 'ჩიტი',
    '🐧' => 'პინგვინი',
    '🕊' => 'მტრედი',
    '🦅' => 'არწივი',
    '🦆' => 'იხვი',
    '🦢' => 'გედი',
    '🦉' => 'ბუ',
    '🦤' => 'დოდო',
    '🪶' => 'ბუმბული',
    '🦩' => 'ფლამინგო',
    '🦚' => 'ფარშევანგი',
    '🦜' => 'თუთიყუში',
    '🪽' => 'ფრთა',
    '🪿' => 'ბატი',
    '🐸' => 'ბაყაყის სახე',
    '🐊' => 'ნიანგი',
    '🐢' => 'კუ',
    '🦎' => 'ხვლიკი',
    '🐍' => 'გველი',
    '🐲' => 'დრაკონის სახე',
    '🐉' => 'დრაკონი',
    '🦕' => 'ზაუროპოდი',
    '🦖' => 'ტი-რექსი',
    '🐳' => 'ვეშაპი ჭავლით',
    '🐋' => 'ვეშაპი',
    '🐬' => 'დელფინი',
    '🫍' => 'ცელნამგალა ვეშაპი',
    '🦭' => 'სელაპი',
    '🐟' => 'თევზი',
    '🐠' => 'ტროპიკული თევზი',
    '🐡' => 'მუცელნემსა',
    '🦈' => 'ზვიგენი',
    '🐙' => 'რვაფეხა',
    '🐚' => 'სპირალური ნიჟარა',
    '🪸' => 'მარჯანი',
    '🪼' => 'მედუზა',
    '🦀' => 'კიბორჩხალა',
    '🦞' => 'კიბო',
    '🦐' => 'კრევეტი',
    '🦑' => 'კალმარი',
    '🦪' => 'ხამანწკა',
    '🐌' => 'ლოკოკინა',
    '🦋' => 'პეპელა',
    '🐛' => 'ბაღლინჯო',
    '🐜' => 'ჭიანჭველა',
    '🐝' => 'ფუტკარი',
    '🪲' => 'ხოჭო',
    '🐞' => 'ჭიამაია',
    '🦗' => 'კრიკეტი',
    '🪳' => 'ტარაკანი',
    '🕷' => 'ობობა',
    '🕸' => 'ობობის ქსელი',
    '🦂' => 'მორიელი',
    '🦟' => 'კოღო',
    '🪰' => 'ბუზი',
    '🪱' => 'მატლი',
    '🦠' => 'მიკრობი',
    '💐' => 'თაიგული',
    '🌸' => 'აყვავებული ალუბალი',
    '💮' => 'თეთრი ყვავილი',
    '🪷' => 'ლოტოსი',
    '🏵' => 'როზეტი',
    '🌹' => 'ვარდი',
    '🥀' => 'დამჭკნარი ყვავილი',
    '🌺' => 'ჰიბისკუსი',
    '🌻' => 'მზესუმზირა',
    '🌼' => 'ყვავილობა',
    '🌷' => 'ტიტა',
    '🪻' => 'ჰიაცინტი',
    '🌱' => 'ნათესარი',
    '🪴' => 'მცენარე ქოთანში',
    '🌲' => 'მარადმწვანე',
    '🌳' => 'ფოთლოვანი ხე',
    '🌴' => 'პალმა',
    '🌵' => 'კაქტუსი',
    '🌾' => 'ბრინჯის კონა',
    '🌿' => 'სამკურნალო მცენარე',
    '☘' => 'სამყურა',
    '🍀' => 'ოთხფოთლიანი სამყურა',
    '🍁' => 'ნეკერჩხლის ფოთოლი',
    '🍂' => 'ჩამოვარდნილი ფოთოლი',
    '🍃' => 'ქარში მოფარფატე ფოთოლი',
    '🪹' => 'ცარიელი ბუდე',
    '🪺' => 'ბუდე კვერცხებით',
    '🍄' => 'სოკო',
    '🪾' => 'უფოთლო ხე',
    '🍇' => 'ყურძენი',
    '🍈' => 'ნესვი',
    '🍉' => 'საზამთრო',
    '🍊' => 'მანდარინი',
    '🍋' => 'ლიმონი',
    '🍌' => 'ბანანი',
    '🍍' => 'ანანასი',
    '🥭' => 'მანგო',
    '🍎' => 'წითელი ვაშლი',
    '🍏' => 'მწვანე ვაშლი',
    '🍐' => 'მსხალი',
    '🍑' => 'ატამი',
    '🍒' => 'ალუბალი',
    '🍓' => 'მარწყვი',
    '🫐' => 'მოცვი',
    '🥝' => 'კივი',
    '🍅' => 'პამიდორი',
    '🫒' => 'ზეითუნი',
    '🥥' => 'ქოქოსი',
    '🥑' => 'ავოკადო',
    '🍆' => 'ბადრიჯანი',
    '🥔' => 'კარტოფილი',
    '🥕' => 'სტაფილო',
    '🌽' => 'სიმინდის ტარო',
    '🌶' => 'ცხარე წიწაკა',
    '🫑' => 'ბულგარული წიწაკა',
    '🥒' => 'კიტრი',
    '🥬' => 'სალათის ფოთოლი',
    '🥦' => 'ბროკოლი',
    '🧄' => 'ნიორი',
    '🧅' => 'ხახვი',
    '🥜' => 'მიწის თხილი',
    '🫘' => 'ლობიო',
    '🌰' => 'წაბლი',
    '🫚' => 'ჯანჯაფილის ფესვი',
    '🫛' => 'ბარდა',
    '🫜' => 'ბოლქვოვანი მცენარე',
    '🍞' => 'პური',
    '🥐' => 'კრუასანი',
    '🥖' => 'ბაგეტი',
    '🫓' => 'ლავაში',
    '🥨' => 'პრეცელი',
    '🥯' => 'ბეიგელი',
    '🥞' => 'ბლინები',
    '🧇' => 'ვაფლი',
    '🧀' => 'ყველის ნაჭერი',
    '🍖' => 'ხორცი ძვალზე',
    '🍗' => 'ფრინველის ფეხი',
    '🥩' => 'ხორცის ნაჭერი',
    '🥓' => 'ბეკონი',
    '🍔' => 'ჰამბურგერი',
    '🍟' => 'ფრი',
    '🍕' => 'პიცა',
    '🌭' => 'ჰოთდოგი',
    '🥪' => 'სენდვიჩი',
    '🌮' => 'ტაკო',
    '🌯' => 'ბურიტო',
    '🫔' => 'ტამალე',
    '🥙' => 'ვრაპი',
    '🧆' => 'ფალაფელი',
    '🥚' => 'კვერცხი',
    '🍳' => 'საჭმლის მომზადება',
    '🥘' => 'ტაფამწვარი',
    '🍲' => 'ქვაბი საჭმლით',
    '🫕' => 'ფონდიუ',
    '🥣' => 'თასი კოვზით',
    '🥗' => 'მწვანე სალათა',
    '🍿' => 'ბატი-ბუტი',
    '🧈' => 'კარაქი',
    '🧂' => 'მარილი',
    '🥫' => 'კონსერვი',
    '🍱' => 'ბენტო',
    '🍘' => 'ბრინჯის ორცხობილა',
    '🍙' => 'ბრინჯის ბურთი',
    '🍚' => 'მომზადებული ბრინჯი',
    '🍛' => 'ბრინჯი ქარით',
    '🍜' => 'ფიალა ორთქლით',
    '🍝' => 'სპაგეტი',
    '🍠' => 'შემწვარი ტკბილი კარტოფილი',
    '🍢' => 'ოდენი',
    '🍣' => 'სუში',
    '🍤' => 'შემწვარი კრევეტი',
    '🍥' => 'თევზის კატლეტი ხვეულათი',
    '🥮' => 'მთვარის ორცხობილა',
    '🍡' => 'დანგო',
    '🥟' => 'ხინკალი',
    '🥠' => 'იღბლიანი ორცხობილა',
    '🥡' => 'საჭმლის წამოსაღები ყუთი',
    '🍦' => 'რბილი ნაყინი',
    '🍧' => 'ნაყინის ბურთულები',
    '🍨' => 'ნაყინი',
    '🍩' => 'დონატი',
    '🍪' => 'ფხვიერი ნამცხვარი',
    '🎂' => 'დაბადების დღის ტორტი',
    '🍰' => 'შორთქეიქი',
    '🧁' => 'ქაფქეიქი',
    '🥧' => 'ნამცხვარი',
    '🍫' => 'შოკოლადის ფილა',
    '🍬' => 'კანფეტი',
    '🍭' => 'კანფეტი ჯოხზე',
    '🍮' => 'კასტარდი',
    '🍯' => 'თაფლის ქილა',
    '🍼' => 'ბავშვის ბოთლი',
    '🥛' => 'ჭიქა რძე',
    '☕' => 'ცხელი სასმელი',
    '🫖' => 'ჩაიდანი',
    '🍵' => 'ჩაის ფინჯანი სახელურის გარეშე',
    '🍶' => 'საკე',
    '🍾' => 'ბოთლი ამოვარდნილი საცობით',
    '🍷' => 'ღვინის ჭიქა',
    '🍸' => 'კოქტეილის ჭიქა',
    '🍹' => 'ტროპიკული სასმელი',
    '🍺' => 'ლუდის კათხა',
    '🍻' => 'ლუდის კათხების მიჭახუნება',
    '🥂' => 'ჭიქების მიჭახუნება',
    '🥃' => 'ბრტყელძირიანი ჭიქა',
    '🫗' => 'ასხამს თხევადს',
    '🥤' => 'ჭიქა საწრუპით',
    '🧋' => 'ბაბლ ჩაი',
    '🧃' => 'წვენი პაკეტში',
    '🧉' => 'მატე',
    '🧊' => 'ყინულის კუბი',
    '🥢' => 'ჩხირები',
    '🍽' => 'ჩანგალი და დანა თეფშთან ერთად',
    '🍴' => 'ჩანგალი და დანა',
    '🥄' => 'კოვზი',
    '🔪' => 'სამზარეულოს დანა',
    '🫙' => 'ქილა',
    '🏺' => 'ამფორა',
    '🌍' => 'გლობუსი, რომელზეც ჩანს ევროპა და აფრიკა',
    '🌎' => 'გლობუსი, რომელზეც ჩანს ამერიკა',
    '🌏' => 'გლობუსი, რომელზეც ჩანს აზია და ავსტრალია',
    '🌐' => 'გლობუსი მერიდიანებით',
    '🗺' => 'მსოფლიო რუკა',
    '🗾' => 'იაპონიის რუკა',
    '🧭' => 'კომპასი',
    '🏔' => 'თოვლით დაფარული მთა',
    '⛰' => 'მთა',
    '🛘' => 'მეწყერი',
    '🌋' => 'ვულკანი',
    '🗻' => 'მთა ფუძი',
    '🏕' => 'კემპინგი',
    '🏖' => 'პლაჟი და ქოლგა',
    '🏜' => 'უდაბნო',
    '🏝' => 'უკაცრიელი კუნძული',
    '🏞' => 'ეროვნული პარკი',
    '🏟' => 'სტადიონი',
    '🏛' => 'კლასიკური შენობა',
    '🏗' => 'შენობის მშენებლობა',
    '🧱' => 'აგური',
    '🪨' => 'კლდე',
    '🪵' => 'შეშა',
    '🛖' => 'ქოხი',
    '🏘' => 'სახლები',
    '🏚' => 'მიტოვებული საცხოვრებელი შენობა',
    '🏠' => 'საცხოვრებელი შენობა',
    '🏡' => 'სახლი ბაღით',
    '🏢' => 'ოფისის შენობა',
    '🏣' => 'იაპონური საფოსტო განყოფილება',
    '🏤' => 'საფოსტო განყოფილება',
    '🏥' => 'საავადმყოფო',
    '🏦' => 'ბანკი',
    '🏨' => 'სასტუმრო',
    '🏩' => 'სიყვარულის სასტუმრო',
    '🏪' => 'სადღეღამისო მაღაზია',
    '🏫' => 'სკოლა',
    '🏬' => 'სავაჭრო ცენტრი',
    '🏭' => 'ქარხანა',
    '🏯' => 'იაპონური სასახლე',
    '🏰' => 'სასახლე',
    '💒' => 'ქორწილი',
    '🗼' => 'ტოკიოს ტელეანძა',
    '🗽' => 'თავისუფლების ქანდაკება',
    '⛪' => 'ეკლესია',
    '🕌' => 'მეჩეთი',
    '🛕' => 'ინდუისტური ტაძარი',
    '🕍' => 'სინაგოგა',
    '⛩' => 'შინტოს ტაძარი',
    '🕋' => 'ქააბა',
    '⛲' => 'შადრევანი',
    '⛺' => 'კარავი',
    '🌁' => 'ნისლიანი ამინდი',
    '🌃' => 'ღამე ვარსკვლავებით',
    '🏙' => 'ქალაქის ხედი',
    '🌄' => 'მზის ამოსვლა მთებში',
    '🌅' => 'მზის ამოსვლა',
    '🌆' => 'ქალაქის ხედი დაბინდებისას',
    '🌇' => 'მზის ჩასვლა',
    '🌉' => 'ხიდი ღამით',
    '♨' => 'ცხელი წყაროები',
    '🎠' => 'კარუსელის ცხენი',
    '🛝' => 'სათამაშო მოედნის სლაიდი',
    '🎡' => 'ეშმაკის ბორბალი',
    '🎢' => 'ამერიკული გორაკები',
    '💈' => 'დალაქის სვეტი',
    '🎪' => 'ცირკის კარავი',
    '🚂' => 'ლოკომოტივი',
    '🚃' => 'მატარებლის ვაგონი',
    '🚄' => 'მაღალსიჩქარიანი მატარებელი',
    '🚅' => 'მაღალსიჩქარიანი მატარებელი ტყვიისებრი ბოლოთი',
    '🚆' => 'მატარებელი',
    '🚇' => 'მეტრო',
    '🚈' => 'მსუბუქი რკინიგზა',
    '🚉' => 'სადგური',
    '🚊' => 'ტრამვაი',
    '🚝' => 'მონორელსი',
    '🚞' => 'მთის რკინიგზა',
    '🚋' => 'ტრამვაის ვაგონი',
    '🚌' => 'ავტობუსი',
    '🚍' => 'მომავალი ავტობუსი',
    '🚎' => 'ტროლეიბუსი',
    '🚐' => 'სამარშრუტო ტაქსი',
    '🚑' => 'სასწრაფო მანქანა',
    '🚒' => 'სახანძრო მანქანა',
    '🚓' => 'პოლიციის მანქანა',
    '🚔' => 'მომავალი პოლიციის მანქანა',
    '🚕' => 'ტაქსი',
    '🚖' => 'მომავალი ტაქსი',
    '🚗' => 'ავტომობილი',
    '🚘' => 'მომავალი ავტომობილი',
    '🚙' => 'დასასვენებელი ტრანსპორტი',
    '🛻' => 'პიკაპი',
    '🚚' => 'მიმწოდებელი სატვირთო მანქანა',
    '🚛' => 'პატარა სატვირთო მანქანა',
    '🚜' => 'ტრაქტორი',
    '🏎' => 'სარბოლო მანქანა',
    '🏍' => 'მოტოციკლეტი',
    '🛵' => 'სკუტერი ძრავით',
    '🦽' => 'შშმ პირის მექანიკური ეტლი',
    '🦼' => 'შშმ პირის მოტორიანი ეტლი',
    '🛺' => 'ავტორიქშა',
    '🚲' => 'ველოსიპედი',
    '🛴' => 'ფეხის სკუტერი',
    '🛹' => 'სკეიტბორდი',
    '🛼' => 'გორგოლაჭიანი ციგურები',
    '🚏' => 'ავტობუსის გაჩერება',
    '🛣' => 'ავტომაგისტრალი',
    '🛤' => 'რკინიგზის ლიანდაგი',
    '🛢' => 'ნავთობპროდუქტების კასრი',
    '⛽' => 'საწვავის ტუმბო',
    '🛞' => 'ბორბალი',
    '🚨' => 'პოლიციის მანქანის სირენა',
    '🚥' => 'ჰორიზონტალური შუქნიშანი',
    '🚦' => 'ვერტიკალური შუქნიშანი',
    '🛑' => 'გაჩერების ნიშანი',
    '🚧' => 'მშენებლობა',
    '⚓' => 'ღუზა',
    '🛟' => 'ბეჭედი ბუი',
    '⛵' => 'იალქნიანი ნავი',
    '🛶' => 'კანოე',
    '🚤' => 'გლისერი',
    '🛳' => 'სამგზავრო გემი',
    '⛴' => 'ბორანი',
    '🛥' => 'მოტორიანი გემი',
    '🚢' => 'გემი',
    '✈' => 'თვითმფრინავი',
    '🛩' => 'პატარა თვითმფრინავი',
    '🛫' => 'თვითმფრინავის გაფრენა',
    '🛬' => 'თვითმფრინავის ჩამოფრენა',
    '🪂' => 'პარაშუტი',
    '💺' => 'სავარძელი',
    '🚁' => 'ვერტმფრენი',
    '🚟' => 'დაკიდული რკინიგზა',
    '🚠' => 'მთის საბაგირო',
    '🚡' => 'საბაგირო',
    '🛰' => 'თანამგზავრი',
    '🚀' => 'რაკეტა',
    '🛸' => 'მფრინავი თეფში',
    '🛎' => 'სასტუმროს ზარი',
    '🧳' => 'ბარგი',
    '⌛' => 'ქვიშის საათი',
    '⏳' => 'ქვიშის საათი ქვიშის ნაკადით',
    '⌚' => 'საათი',
    '⏰' => 'მაღვიძარა',
    '⏱' => 'წამზომი',
    '⏲' => 'ტაიმერი',
    '🕰' => 'ბუხრის საათი',
    '🕛' => 'თორმეტი საათი',
    '🕧' => 'თორმეტი ოცდაათი',
    '🕐' => 'პირველი საათი',
    '🕜' => 'ერთი ოცდაათი',
    '🕑' => 'ორი საათი',
    '🕝' => 'ორი ოცდაათი',
    '🕒' => 'სამი საათი',
    '🕞' => 'სამი ოცდაათი',
    '🕓' => 'ოთხი საათი',
    '🕟' => 'ოთხი ოცდაათი',
    '🕔' => 'ხუთი საათი',
    '🕠' => 'ხუთი ოცდაათი',
    '🕕' => 'ექვსი საათი',
    '🕡' => 'ექვსი ოცდაათი',
    '🕖' => 'შვიდი საათი',
    '🕢' => 'შვიდი ოცდაათი',
    '🕗' => 'რვა საათი',
    '🕣' => 'რვა ოცდაათი',
    '🕘' => 'ცხრა საათი',
    '🕤' => 'ცხრა ოცდაათი',
    '🕙' => 'ათი საათი',
    '🕥' => 'ათი ოცდაათი',
    '🕚' => 'თერთმეტი საათი',
    '🕦' => 'თერთმეტი ოცდაათი',
    '🌑' => 'ახალი მთვარე',
    '🌒' => 'მზარდი ნამგალა მთვარე',
    '🌓' => 'მთვარის პირველი მეოთხედი',
    '🌔' => 'მზარდი განათებული მთვარე',
    '🌕' => 'სავსე მთვარე',
    '🌖' => 'მცხრალი განათებული მთვარე',
    '🌗' => 'მთვარის ბოლო მეოთხედი',
    '🌘' => 'მცხრალი ნამგალა მთვარე',
    '🌙' => 'ნამგალა მთვარე',
    '🌚' => 'ახალი მთვარის სახე',
    '🌛' => 'მთვარის პირველი მეოთხედი სახით',
    '🌜' => 'მთვარის ბოლო მეოთხედი სახით',
    '🌡' => 'თერმომეტრი',
    '☀' => 'მზე',
    '🌝' => 'სავსე მთვარე სახით',
    '🌞' => 'მზე სახით',
    '🪐' => 'პლანეტა სარტყელით',
    '⭐' => 'საშუალო თეთრი ვარსკვლავი',
    '🌟' => 'მბრწყინავი ვარსკვლავი',
    '🌠' => 'ვარდნილი ვარსკვლავი',
    '🌌' => 'ირმის ნახტომი',
    '☁' => 'ღრუბელი',
    '⛅' => 'მზე ღრუბლის უკან',
    '⛈' => 'ღრუბელი ელვითა და წვიმით',
    '🌤' => 'მზე პატარა ღრუბლის უკან',
    '🌥' => 'მზე დიდი ღრუბლის უკან',
    '🌦' => 'მზე წვიმიანი ღრუბლის უკან',
    '🌧' => 'ღრუბელი წვიმით',
    '🌨' => 'ღრუბელი თოვლით',
    '🌩' => 'ღრუბელი ელვით',
    '🌪' => 'ტორნადო',
    '🌫' => 'ნისლი',
    '🌬' => 'ქარის სახე',
    '🌀' => 'ციკლონი',
    '🌈' => 'ცისარტყელა',
    '🌂' => 'დახურული ქოლგა',
    '☂' => 'ქოლგა',
    '☔' => 'ქოლგა წვიმის წვეთებით',
    '⛱' => 'ქოლგა მიწაში',
    '⚡' => 'მაღალი ძაბვა',
    '❄' => 'თოვლის ფანტელი',
    '☃' => 'თოვლის კაცი',
    '⛄' => 'თოვლის კაცი თოვლის გარეშე',
    '☄' => 'კომეტა',
    '🔥' => 'ცეცხლი',
    '💧' => 'წვეთი',
    '🌊' => 'წყლის ტალღა',
    '🎃' => 'ჰელოუინის გოგრა',
    '🎄' => 'საახალწლო ნაძვის ხე',
    '🎆' => 'ფოიერვერკი',
    '🎇' => 'ბრწყინვალება',
    '🧨' => 'შუშხუნა',
    '✨' => 'ნაპერწკლები',
    '🎈' => 'ბუშტი',
    '🎉' => 'ტკაცუნა',
    '🎊' => 'კონფეტი',
    '🎋' => 'ტანაბატას ხე',
    '🎍' => 'ფიჭვის დეკორაცია',
    '🎎' => 'იაპონური თოჯინები',
    '🎏' => 'კობრებიანი ალამი',
    '🎐' => 'ჩინური ზანზალაკი',
    '🎑' => 'მთვარის ცერემონია',
    '🧧' => 'წითელი კონვერტი',
    '🎀' => 'ლენტი',
    '🎁' => 'შეფუთული საჩუქარი',
    '🎗' => 'შემხსენებელი ლენტი',
    '🎟' => 'ბილეთები',
    '🎫' => 'ბილეთი',
    '🎖' => 'სამხედრო მედალი',
    '🏆' => 'პრიზი',
    '🏅' => 'სპორტული მედალი',
    '🥇' => '1-ლი ადგილის მედალი',
    '🥈' => 'მე-2 ადგილის მედალი',
    '🥉' => 'მე-3 ადგილი მედალი',
    '⚽' => 'ფეხბურთი',
    '⚾' => 'ბეისბოლი',
    '🥎' => 'სოფტბოლი',
    '🏀' => 'კალათბურთი',
    '🏐' => 'ფრენბურთი',
    '🏈' => 'ამერიკული ფეხბურთი',
    '🏉' => 'რაგბი',
    '🎾' => 'ჩოგბურთი',
    '🥏' => 'მფრინავი დისკი',
    '🎳' => 'ბოულინგი',
    '🏏' => 'კრიკეტის თამაში',
    '🏑' => 'ბალახის ჰოკეი',
    '🏒' => 'ჰოკეის ყვანჭი და შაიბა',
    '🥍' => 'ლაკროსი',
    '🏓' => 'მაგიდის ჩოგბურთი',
    '🏸' => 'ბადმინტონი',
    '🥊' => 'კრივის ხელთათმანი',
    '🥋' => 'საბრძოლო ხელოვნების უნიფორმა',
    '🥅' => 'ფეხბურთის ბადე',
    '⛳' => 'დროშა ხვრელში',
    '⛸' => 'ციგურებით სრიალი',
    '🎣' => 'სათევზაო ბოძი',
    '🤿' => 'წყლის ნიღაბი',
    '🎽' => 'სარბენი მაისური',
    '🎿' => 'თხილამურები',
    '🛷' => 'ციგა',
    '🥌' => 'კერლინგის ქვა',
    '🎯' => 'პირდაპირი მოხვედრა',
    '🪀' => 'იო-იო',
    '🪁' => 'ფრანი',
    '🔫' => 'პისტოლეტი',
    '🎱' => 'ბილიარდი',
    '🔮' => 'კრისტალის ბურთი',
    '🪄' => 'ჯადოსნური ჯოხი',
    '🎮' => 'ვიდეო თამაში',
    '🕹' => 'ჯოისტიკი',
    '🎰' => 'სლოტ-ავტომატი',
    '🎲' => 'კამათელი',
    '🧩' => 'პაზლი',
    '🧸' => 'დათუნია',
    '🪅' => 'პინიატა',
    '🪩' => 'სარკის ბურთი',
    '🪆' => 'მატრიოშკა',
    '♠' => 'ყვავები',
    '♥' => 'გულები',
    '♦' => 'აგურები',
    '♣' => 'ჯვრები',
    '♟' => 'პაიკი',
    '🃏' => 'ჯოკერი',
    '🀄' => 'მაჯონგის წითელი დრაკონი',
    '🎴' => 'ყვავილებიანი სათამაშო ბანქო',
    '🎭' => 'თეატრალური ხელოვნება',
    '🖼' => 'ჩარჩო ნახატით',
    '🎨' => 'მხატვრის პალიტრა',
    '🧵' => 'ძაფის კოჭა',
    '🪡' => 'ნემსი',
    '🧶' => 'ძაფის გორგალი',
    '🪢' => 'კვანძი',
    '👓' => 'სათვალე',
    '🕶' => 'მზის სათვალე',
    '🥽' => 'დამცავი სათვალე',
    '🥼' => 'ლაბორატორიის კოსტიუმი',
    '🦺' => 'უსაფრთხოების ჟილეტი',
    '👔' => 'ჰალსტუხი',
    '👕' => 'მაისური',
    '👖' => 'ჯინსი',
    '🧣' => 'კაშნე',
    '🧤' => 'ხელთათმანი',
    '🧥' => 'ქურთუკი',
    '🧦' => 'წინდები',
    '👗' => 'კაბა',
    '👘' => 'კიმონო',
    '🥻' => 'სარი',
    '🩱' => 'ერთიანი საცურაო კოსტიუმი',
    '🩲' => 'საცურაო ტრუსი',
    '🩳' => 'შორტები',
    '👙' => 'ბიკინი',
    '👚' => 'ქალის ტანსაცმელი',
    '🪭' => 'მარაო',
    '👛' => 'საფულე',
    '👜' => 'ხელჩანთა',
    '👝' => 'ჩანთა',
    '🛍' => 'საყიდლების პარკები',
    '🎒' => 'სკოლის ზურგჩანთა',
    '🩴' => 'თასმიანი სანდლები',
    '👞' => 'კაცის ფეხსაცმელი',
    '👟' => 'ბოტასი',
    '🥾' => 'ბათინკი',
    '🥿' => 'უქუსლო ფეხსაცმელი',
    '👠' => 'მაღალქუსლიანი ფეხსაცმელი',
    '👡' => 'ქალის სანდალი',
    '🩰' => 'პუანტები',
    '👢' => 'ქალის ჩექმა',
    '🪮' => 'სავარცხელი',
    '👑' => 'გვირგვინი',
    '👒' => 'ქალის ქუდი',
    '🎩' => 'ცილინდრი',
    '🎓' => 'გამოსაშვები ქუდი',
    '🧢' => 'ბეისბოლის კეპი',
    '🪖' => 'სამხედრო ჩაფხუტი',
    '⛑' => 'ჩაფხუტი თეთრი ჯვრით',
    '📿' => 'კრიალოსანი',
    '💄' => 'ტუჩის პომადა',
    '💍' => 'ბეჭედი',
    '💎' => 'ძვირფასი ქვა',
    '🔇' => 'დინამიკი გამორთულია',
    '🔈' => 'დინამიკი',
    '🔉' => 'დინამიკი ჩართულია',
    '🔊' => 'ხმამაღალი დინამიკი',
    '📢' => 'რუპორი',
    '📣' => 'მეგაფონი',
    '📯' => 'საფოსტო ბუკი',
    '🔔' => 'ზარი',
    '🔕' => 'ხაზგადასმული ზარი',
    '🎼' => 'მუსიკალური პარტიტურა',
    '🎵' => 'მუსიკალური ნოტი',
    '🎶' => 'მუსიკალური ნოტები',
    '🎙' => 'სტუდიური მიკროფონი',
    '🎚' => 'დონის გადამრთველი',
    '🎛' => 'მართვის ღილაკები',
    '🎤' => 'მიკროფონი',
    '🎧' => 'ყურსასმენი',
    '📻' => 'რადიო',
    '🎷' => 'საქსოფონი',
    '🎺' => 'საყვირი',
    '🪊' => 'ტრომბონი',
    '🪗' => 'აკორდეონი',
    '🎸' => 'გიტარა',
    '🎹' => 'მუსიკალური კლავიშები',
    '🎻' => 'ვიოლინო',
    '🪕' => 'ბანჯო',
    '🥁' => 'ბარაბანი',
    '🪘' => 'გრძელი დოლი',
    '🪇' => 'მარაკა',
    '🪈' => 'ფლეიტა',
    '🪉' => 'არფა',
    '📱' => 'მობილური ტელეფონი',
    '📲' => 'მობილური ტელეფონი ისრით',
    '☎' => 'ტელეფონი',
    '📞' => 'ტელეფონის ყურმილი',
    '📟' => 'პეიჯერი',
    '📠' => 'ფაქსი',
    '🔋' => 'ბატარეა',
    '🪫' => 'დამჯდარი ელემენტი',
    '🔌' => 'შტეკერი',
    '💻' => 'ლეპტოპი',
    '🖥' => 'დესკტოპი',
    '🖨' => 'პრინტერი',
    '⌨' => 'კლავიატურა',
    '🖱' => 'მაუსი',
    '🖲' => 'ბურთიანი მიმთითებელი',
    '💽' => 'მინიდისკი',
    '💾' => 'დრეკადი დისკი',
    '💿' => 'ოპტიკური დისკი',
    '📀' => 'dvd',
    '🧮' => 'საანგარიშო დაფა',
    '🎥' => 'კინოკამერა',
    '🎞' => 'კადრები',
    '📽' => 'კინოპროექტორი',
    '🎬' => 'ნუმერატორი ტკაცუნათი',
    '📺' => 'ტელევიზორი',
    '📷' => 'ფოტოაპარატი',
    '📸' => 'ფოტოაპარატი ბლიცით',
    '📹' => 'ვიდეოკამერა',
    '📼' => 'ვიდეოკასეტა',
    '🔍' => 'მარცხნივ მიმართული გამადიდებელი შუშა',
    '🔎' => 'მარჯვნივ მიმართული გამადიდებელი შუშა',
    '🕯' => 'სანთელი',
    '💡' => 'ნათურა',
    '🔦' => 'ფანარი',
    '🏮' => 'ქაღალდის წითელი ფარანი',
    '🪔' => 'ნავთის ლამპა',
    '📔' => 'რვეული დეკორატიული ყდით',
    '📕' => 'დახურული წიგნი',
    '📖' => 'გადაშლილი წიგნი',
    '📗' => 'მწვანე წიგნი',
    '📘' => 'ლურჯი წიგნი',
    '📙' => 'სტაფილოსფერი წიგნი',
    '📚' => 'წიგნები',
    '📓' => 'ნოუთბუქი',
    '📒' => 'დავთარი',
    '📃' => 'მომრგვალებული გვერდი',
    '📜' => 'გრაგნილი',
    '📄' => 'გვერდი პირით ზემოთ',
    '📰' => 'გაზეთი',
    '🗞' => 'დახვეული გაზეთი',
    '📑' => 'სანიშნი ჩანართები',
    '🔖' => 'სანიშნე',
    '🏷' => 'იარლიყი',
    '🪙' => 'მონეტა',
    '💰' => 'ფულის ტომარა',
    '🪎' => 'საგანძურის სკივრი',
    '💴' => 'იენას ბანკნოტი',
    '💵' => 'დოლარის ბანკნოტი',
    '💶' => 'ევროს ბანკნოტი',
    '💷' => 'გირვანქა სტერლინგის ბანკნოტი',
    '💸' => 'ფული ფრთებით',
    '💳' => 'საკრედიტო ბარათი',
    '🧾' => 'ქვითარი',
    '💹' => 'ზრდადი გრაფიკი იენათი',
    '✉' => 'კონვერტი',
    '📧' => 'ელფოსტა',
    '📨' => 'შემოსული კონვერტი',
    '📩' => 'კონვერტი ისრით',
    '📤' => 'გაგზავნილების კოლოფი',
    '📥' => 'შემოსულების კოლოფი',
    '📦' => 'პაკეტი',
    '📫' => 'დახურული საფოსტო ყუთი აწეული დროშით',
    '📪' => 'დახურული საფოსტო ყუთი დაწეული დროშით',
    '📬' => 'ღია საფოსტო ყუთი აწეული დროშით',
    '📭' => 'ღია საფოსტო ყუთი დაწეული დროშით',
    '📮' => 'საფოსტო ყუთი',
    '🗳' => 'საარჩევნო ურნა ბიულეტენით',
    '✏' => 'ფანქარი',
    '✒' => 'შავი კალმის წვერი',
    '🖋' => 'ბუმბულიანი კალამი',
    '🖊' => 'კალამი',
    '🖌' => 'სახატავი ფუნჯი',
    '🖍' => 'ფერადი ფანქარი',
    '📝' => 'ჩანაწერი',
    '💼' => 'პორტფელი',
    '📁' => 'საქაღალდე',
    '📂' => 'ღია საქაღალდე',
    '🗂' => 'ბარათებიანი საძიებელი გამყოფებით',
    '📅' => 'კალენდარი',
    '📆' => 'მოსახევი კალენდარი',
    '🗒' => 'სპირალიანი ბლოკნოტი',
    '🗓' => 'სპირალიანი კალენდარი',
    '📇' => 'ბარათებიანი საძიებელი',
    '📈' => 'ზრდადი გრაფიკი',
    '📉' => 'კლებადი გრაფიკი',
    '📊' => 'სვეტებიანი დიაგრამა',
    '📋' => 'მისამაგრებელი დაფა',
    '📌' => 'ჭიკარტი',
    '📍' => 'მრგვალი ჭიკარტი',
    '📎' => 'ქაღალდის სამაგრი',
    '🖇' => 'მიბმული ქაღალდის სამაგრები',
    '📏' => 'სწორი სახაზავი',
    '📐' => 'სამკუთხა სახაზავი',
    '✂' => 'მაკრატელი',
    '🗃' => 'ბარათების ყუთი',
    '🗄' => 'კარტოთეკა',
    '🗑' => 'სანაგვე ურნა',
    '🔒' => 'საკეტი',
    '🔓' => 'ღია საკეტი',
    '🔏' => 'საკეტი და კალამი',
    '🔐' => 'ჩაკეტილი საკეტი და კალამი',
    '🔑' => 'გასაღები',
    '🗝' => 'ძველი გასაღები',
    '🔨' => 'ჩაქუჩი',
    '🪓' => 'ნაჯახი',
    '⛏' => 'წერაქვი',
    '⚒' => 'ჩაქუჩი და წერაქვი',
    '🛠' => 'ჩაქუჩი და ქანჩის გასაღები',
    '🗡' => 'ხანჯალი',
    '⚔' => 'გადაკვეთილი ხმლები',
    '💣' => 'ბომბი',
    '🪃' => 'ბუმერანგი',
    '🏹' => 'მშვილდ-ისარი',
    '🛡' => 'ფარი',
    '🪚' => 'ხერხი',
    '🔧' => 'ქანჩის გასაღები',
    '🪛' => 'სახრახნისი',
    '🔩' => 'ქანჩი და ჭანჭიკი',
    '⚙' => 'კბილანა',
    '🗜' => 'კომპრესია',
    '⚖' => 'ბერკეტიანი სასწორი',
    '🦯' => 'თეთრი ჯოხი',
    '🔗' => 'ჯაჭვის რგოლი',
    '⛓' => 'ჯაჭვი',
    '🪝' => 'კაუჭი',
    '🧰' => 'ხელსაწყოები',
    '🧲' => 'მაგნიტი',
    '🪜' => 'კიბე',
    '🪏' => 'ნიჩაბი',
    '⚗' => 'გამოსახდელი აპარატი',
    '🧪' => 'სინჯარა',
    '🧫' => 'პეტრის თასი',
    '🧬' => 'დნმ',
    '🔬' => 'მიკროსკოპი',
    '🔭' => 'ტელესკოპი',
    '📡' => 'თანამგზავრული ანტენა',
    '💉' => 'შპრიცი',
    '🩸' => 'სისხლის წვეთი',
    '💊' => 'აბი',
    '🩹' => 'პლასტირი',
    '🩼' => 'ყავარჯენი',
    '🩺' => 'ფონენდოსკოპი',
    '🩻' => 'რენტგენი',
    '🚪' => 'კარი',
    '🛗' => 'ლიფტი',
    '🪞' => 'სარკე',
    '🪟' => 'ფანჯარა',
    '🛏' => 'საწოლი',
    '🛋' => 'დივანი და ლამპა',
    '🪑' => 'სკამი',
    '🚽' => 'ტუალეტი',
    '🪠' => 'დგუში',
    '🚿' => 'შხაპი',
    '🛁' => 'აბაზანა',
    '🪤' => 'სათაგური',
    '🪒' => 'ბრიტვა',
    '🧴' => 'ლოსიონის ბოთლი',
    '🧷' => 'ქინძისთავი',
    '🧹' => 'ცოცხი',
    '🧺' => 'კალათა',
    '🧻' => 'ქაღალდის გრაგნილი',
    '🪣' => 'ვედრო',
    '🧼' => 'საპონი',
    '🫧' => 'ბუშტები',
    '🪥' => 'კბილის ჯაგრისი',
    '🧽' => 'სარეცხი ღრუბელი',
    '🧯' => 'ცეცხლსაქრობი',
    '🛒' => 'საყიდლების ურიკა',
    '🚬' => 'ბოლი',
    '⚰' => 'კუბო',
    '🪦' => 'საფლავის ქვა',
    '⚱' => 'ფერფლის ურნა',
    '🧿' => 'ფატიმას თვალი',
    '🪬' => 'ჰამსა',
    '🗿' => 'მოაი',
    '🪧' => 'აფიშა',
    '🪪' => 'პირადობა',
    '🏧' => 'ბანკომატის ნიშანი',
    '🚮' => 'ურნის ნიშანი',
    '🚰' => 'სასმელი წყალი',
    '♿' => 'ინვალიდის სავარძელი',
    '🚹' => 'კაცების საპირფარეშო',
    '🚺' => 'ქალების საპირფარეშო',
    '🚻' => 'საპირფარეშო',
    '🚼' => 'ბავშვის სიმბოლო',
    '🚾' => 'საპირფარეშო ოთახი',
    '🛂' => 'საპასპორტო კონტროლი',
    '🛃' => 'საბაჟო',
    '🛄' => 'ბარგის გაცემა',
    '🛅' => 'შემნახველი კამერა',
    '⚠' => 'გაფრთხილება',
    '🚸' => 'ბავშვების გადასასვლელი',
    '⛔' => 'შესვლა აკრძალულია',
    '🚫' => 'აკრძალვა',
    '🚳' => 'ველოსიპედებისთვის შესვლა აკრძალულია',
    '🚭' => 'მოწევა აკრძალულია',
    '🚯' => 'დაბინძურება აკრძალულია',
    '🚱' => 'არასასმელი წყალი',
    '🚷' => 'ქვეითებისთვის შესვლა აკრძალულია',
    '📵' => 'მობილური ტელეფონის გამოყენება აკრძალულია',
    '🔞' => 'თვრამეტ წლამდე აკრძალულია',
    '☢' => 'რადიოაქტიური',
    '☣' => 'ბიოლოგიური საფრთხე',
    '⬆' => 'ისარი ზემოთ',
    '↗' => 'ისარი ზემოთ და მარჯვნივ',
    '➡' => 'ისარი მარჯვნივ',
    '↘' => 'ისარი ქვემოთ და მარჯვნივ',
    '⬇' => 'ისარი ქვემოთ',
    '↙' => 'ისარი ქვემოთ და მარცხნივ',
    '⬅' => 'ისარი მარცხნივ',
    '↖' => 'ისარი ზემოთ და მარცხნივ',
    '↕' => 'ისარი ზემოთ და ქვემოთ',
    '↔' => 'ისარი მარცხნივ და მარჯვნივ',
    '↩' => 'ისარი, რომელიც იმრუდება მარჯვნიდან მარცხნივ',
    '↪' => 'ისარი, რომელიც იმრუდება მარცნიდან მარჯვნივ',
    '⤴' => 'ისარი, რომელიც იმრუდება მარჯვნიდან ზემოთ',
    '⤵' => 'ისარი, რომელიც იმრუდება მარჯვნიდან ქვემოთ',
    '🔃' => 'ვერტიკალური ისრები საათის მიმართულებით',
    '🔄' => 'საათის მიმართულების საწინააღმდეგო ისრების ღილაკი',
    '🔙' => 'უკანსვლის ღილაკი',
    '🔚' => 'ბოლოში გადასვლის ისარი',
    '🔛' => 'ისარი on!',
    '🔜' => 'ისარი soon',
    '🔝' => 'ისარი top',
    '🛐' => 'სალოცავი ადგილი',
    '⚛' => 'ატომის სიმბოლო',
    '🕉' => 'ომი',
    '✡' => 'დავითის ვარსკვლავი',
    '☸' => 'დჰარმას ბორბალი',
    '☯' => 'ინი და იანი',
    '✝' => 'ლათინური ჯვარი',
    '☦' => 'მართმადიდებლური ჯვარი',
    '☪' => 'ვარსკვლავი და ნახევარმთვარე',
    '☮' => 'მშვიდობის სიმბოლო',
    '🕎' => 'მენორა',
    '🔯' => 'შემოზღუდული ექვსქიმიანი ვარსკვლავი',
    '🪯' => 'ხანდა',
    '♈' => 'ვერძი',
    '♉' => 'კურო',
    '♊' => 'ტყუპები',
    '♋' => 'კირჩხიბი',
    '♌' => 'ლომი',
    '♍' => 'ქალწული',
    '♎' => 'სასწორი',
    '♏' => 'ღრიანკალი',
    '♐' => 'მშვილდოსანი',
    '♑' => 'თხის რქა',
    '♒' => 'მერწყული',
    '♓' => 'თევზები',
    '⛎' => 'გველისმჭერი',
    '🔀' => 'ჩანაწერების შემთხვევით არჩევის ღილაკი',
    '🔁' => 'გამეორების ღილაკი',
    '🔂' => 'ერთხელ გამეორების ღილაკი',
    '▶' => 'დაკვრის ღილაკი',
    '⏩' => 'წინ გადახვევის ღილაკი',
    '⏭' => 'შემდეგ ჩანაწერზე გადასვლის ღილაკი',
    '⏯' => 'დაკვრის ან დაპაუზების ღილაკი',
    '◀' => 'გადახვევის ღილაკი',
    '⏪' => 'უკან გადახვევის ღილაკი',
    '⏮' => 'წინა ჩანაწერზე გადასვლის ღილაკი',
    '🔼' => 'ღილაკი ზემოთ',
    '⏫' => 'ღილაკი სწრაფად ზემოთ',
    '🔽' => 'ღილაკი ქვემოთ',
    '⏬' => 'ღილაკი სწრაფად ქვემოთ',
    '⏸' => 'პაუზის ღილაკი',
    '⏹' => 'შეჩერების ღილაკი',
    '⏺' => 'ჩაწერის ღილაკი',
    '⏏' => 'ამოღების ღილაკი',
    '🎦' => 'კინოთეატრი',
    '🔅' => 'გამქრქალების ღილაკი',
    '🔆' => 'სიკაშკაშის ღილაკი',
    '📶' => 'ანტენის ზოლები',
    '🛜' => 'უსადენო',
    '📳' => 'ვიბრაციის რეჟიმი',
    '📴' => 'მობილური ტელეფონი გამორთულია',
    '♀' => 'მდედრობითი',
    '♂' => 'მამრობითი',
    '⚧' => 'ტრანსგენდერი სიმბოლო',
    '✖' => 'გამრავლება',
    '➕' => 'პლუსი',
    '➖' => 'მინუსი',
    '➗' => 'გაყოფა',
    '🟰' => 'მუქი ტოლობის ნიშანი',
    '♾' => 'უსასრულობა',
    '‼' => 'ორმაგი ძახილის ნიშანი',
    '⁉' => 'კითხვა-ძახილის ნიშანი',
    '❓' => 'წითელი კითხვის ნიშანი',
    '❔' => 'თეთრი კითხვის ნიშანი',
    '❕' => 'თეთრი ძახილის ნიშანი',
    '❗' => 'წითელი ძახილის ნიშანი',
    '〰' => 'ტალღოვანი ტირე',
    '💱' => 'ვალუტის გადაცვლა',
    '💲' => 'მსხვილი დოლარის ნიშანი',
    '⚕' => 'სამედიცინო ნიშანი',
    '♻' => 'გადამუშავების სიმბოლო',
    '⚜' => 'ჰერალდიკური შროშანი',
    '🔱' => 'სამკბილა ემბლემა',
    '📛' => 'სახელიანი ბეჯი',
    '🔰' => 'იაპონური დამწყების სიმბოლო',
    '⭕' => 'მსხვილი დიდი წრე',
    '✅' => 'მსხვილი თეთრი მონიშვნის ნიშანი',
    '☑' => 'მონიშნული მოსანიშნი უჯრა',
    '✔' => 'მსხვილი მონიშვნის ნიშანი',
    '❌' => 'ჯვრით მონიშვნა',
    '❎' => 'ჯვრით მონიშვნის ღილაკი',
    '➰' => 'ხვეული მარყუჟი',
    '➿' => 'ორმაგი ხვეული მარყუჟი',
    '〽' => 'ჯერის ცვლის ნიშანი',
    '✳' => 'რვაქიმიანი ასტერისკი',
    '✴' => 'რვაქიმიანი ვარსკვლავი',
    '❇' => 'ნაპერწკალი',
    '™' => 'სავაჭრო ნიშანი',
    '🫟' => 'შხეფი',
    '🔠' => 'მთავრული ლათინური ასოების შეყვანა',
    '🔡' => 'ნუსხური ლათინური ასოების შეყვანა',
    '🔢' => 'რიცხვების შეყვანა',
    '🔣' => 'სიმბოლოების შეყვანა',
    '🔤' => 'ლათინური ასოების შეყვანა',
    '🅰' => 'ღილაკი A (სისხლის ტიპი)',
    '🆎' => 'ღილაკი AB (სისხლის ტიპი)',
    '🅱' => 'ღილაკი B (სისხლის ტიპი)',
    '🆑' => 'ღილაკი CL',
    '🆒' => 'ღილაკი COOL',
    '🆓' => 'free კვადრატში',
    'ℹ' => 'ინფორმაცია',
    '🆔' => 'ღილაკი ID',
    'Ⓜ' => 'ასო m წრეში',
    '🆕' => 'ღილაკი NEW',
    '🆖' => 'ღილაკი NG',
    '🅾' => 'ღილაკი O (სისხლის ტიპი)',
    '🆗' => 'ღილაკი OK',
    '🅿' => 'ღილაკი p',
    '🆘' => 'ღილაკი SOS',
    '🆙' => 'ღილაკი up!',
    '🆚' => 'vs კვადრატში',
    '🈁' => 'იაპონური ღილაკი "აქ"',
    '🈂' => 'იაპონური ღილაკი „სერვისის გადასახადი“',
    '🈷' => 'მთვარის იდეოგრამა კვადრატში',
    '🈶' => 'არსებობის იდეოგრამა კვადრატში',
    '🈯' => 'თითის იდეოგრამა კვადრატში',
    '🉐' => 'უპირატესობის იდეოგრამა წრეში',
    '🈹' => 'გაყოფის იდეოგრამა კვადრატში',
    '🈚' => 'უარყოფის იდეოგრამა კვადრატში',
    '🈲' => 'აკრძალვის იდეოგრამა კვადრატში',
    '🉑' => 'მიღების იდეოგრამა წრეში',
    '🈸' => 'გამოყენების იდეოგრამა კვადრატში',
    '🈴' => 'ერთად ყოფნის იდეოგრამა კვადრატში',
    '🈳' => 'სიცარიელის იდეოგრამა კვადრატში',
    '㊗' => 'მილოცვის იდეოგრამა წრეში',
    '㊙' => 'საიდუმლოს იდეოგრამა წრეში',
    '🈺' => 'მოქმედების იდეოგრამა კვადრატში',
    '🈵' => 'სისრულის იდეოგრამა კვადრატში',
    '🔴' => 'წითელი წრე',
    '🟠' => 'ნარინჯისფერი წრე',
    '🟡' => 'ყვითელი წრე',
    '🟢' => 'მწვანე წრე',
    '🔵' => 'ლურჯი წრე',
    '🟣' => 'იისფერი წრე',
    '🟤' => 'ყავისფერი წრე',
    '⚫' => 'შავი წრე',
    '⚪' => 'თეთრი წრე',
    '🟥' => 'წითელი კვადრატი',
    '🟧' => 'ნარინჯისფერი კვადრატი',
    '🟨' => 'ყვითელი კვადრატი',
    '🟩' => 'მწვანე კვადრატი',
    '🟦' => 'ლურჯი კვადრატი',
    '🟪' => 'იისფერი კვადრატი',
    '🟫' => 'ყავისფერი კვადრატი',
    '⬛' => 'დიდი შავი კვადრატი',
    '⬜' => 'დიდი თეთრი კვადრატი',
    '◼' => 'საშუალო შავი კვადრატი',
    '◻' => 'საშუალო თეთრი კვადრატი',
    '◾' => 'საშუალო-პატარა შავი კვადრატი',
    '◽' => 'საშუალო-პატარა თეთრი კვადრატი',
    '▪' => 'პატარა შავი კვადრატი',
    '▫' => 'პატარა თეთრი კვადრატი',
    '🔶' => 'დიდი სტაფილოსფერი რომბი',
    '🔷' => 'დიდი ლურჯი რომბი',
    '🔸' => 'პატარა სტაფილოსფერი რომბი',
    '🔹' => 'პატარა ლურჯი რომბი',
    '🔺' => 'მაღლა მიმართული წითელი სამკუთხედი',
    '🔻' => 'დაბლა მიმართული წითელი სამკუთხედი',
    '💠' => 'რომბი წერტილით',
    '🔘' => 'რადიო ღილაკი',
    '🔳' => 'თეთრი კვადრატული ღილაკი',
    '🔲' => 'შავი კვადრატული ღილაკი',
    '🏁' => 'უჯრედებიანი დროშა',
    '🚩' => 'სამკუთხა დროშა',
    '🎌' => 'გადაკვეთილი დროშები',
    '🏴' => 'გაშლილი შავი დროშა',
    '🏳' => 'გაშლილი თეთრი დროშა',
];
