<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'musu: pertsona, pertsona, 1–2. mota eta 3. mota',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'musu: pertsona, pertsona, 1–2. mota eta bitarteko azal-tonua',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'musu: pertsona, pertsona, 1–2. mota eta 5. mota',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'musu: pertsona, pertsona, 1–2. mota eta 6. mota',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'musu: pertsona, pertsona, 3. mota eta 1–2. mota',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'musu: pertsona, pertsona, 3. mota eta bitarteko azal-tonua',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'musu: pertsona, pertsona, 3. mota eta 5. mota',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'musu: pertsona, pertsona, 3. mota eta 6. mota',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'musu: pertsona, pertsona, bitarteko azal-tonua eta 1–2. mota',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'musu: pertsona, pertsona, bitarteko azal-tonua eta 3. mota',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'musu: pertsona, pertsona, bitarteko azal-tonua eta 5. mota',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'musu: pertsona, pertsona, bitarteko azal-tonua eta 6. mota',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'musu: pertsona, pertsona, 5. mota eta 1–2. mota',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'musu: pertsona, pertsona, 5. mota eta 3. mota',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'musu: pertsona, pertsona, 5. mota eta bitarteko azal-tonua',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'musu: pertsona, pertsona, 5. mota eta 6. mota',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'musu: pertsona, pertsona, 6. mota eta 1–2. mota',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'musu: pertsona, pertsona, 6. mota eta 3. mota',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'musu: pertsona, pertsona, 6. mota eta bitarteko azal-tonua',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'musu: pertsona, pertsona, 6. mota eta 5. mota',
    '👨🏻‍❤‍💋‍👨🏻' => 'musu: gizona, gizona eta 1–2. mota',
    '👨🏻‍❤‍💋‍👨🏼' => 'musu: gizona, gizona, 1–2. mota eta 3. mota',
    '👨🏻‍❤‍💋‍👨🏽' => 'musu: gizona, gizona, 1–2. mota eta bitarteko azal-tonua',
    '👨🏻‍❤‍💋‍👨🏾' => 'musu: gizona, gizona, 1–2. mota eta 5. mota',
    '👨🏻‍❤‍💋‍👨🏿' => 'musu: gizona, gizona, 1–2. mota eta 6. mota',
    '👨🏼‍❤‍💋‍👨🏻' => 'musu: gizona, gizona, 3. mota eta 1–2. mota',
    '👨🏼‍❤‍💋‍👨🏼' => 'musu: gizona, gizona eta 3. mota',
    '👨🏼‍❤‍💋‍👨🏽' => 'musu: gizona, gizona, 3. mota eta bitarteko azal-tonua',
    '👨🏼‍❤‍💋‍👨🏾' => 'musu: gizona, gizona, 3. mota eta 5. mota',
    '👨🏼‍❤‍💋‍👨🏿' => 'musu: gizona, gizona, 3. mota eta 6. mota',
    '👨🏽‍❤‍💋‍👨🏻' => 'musu: gizona, gizona, bitarteko azal-tonua eta 1–2. mota',
    '👨🏽‍❤‍💋‍👨🏼' => 'musu: gizona, gizona, bitarteko azal-tonua eta 3. mota',
    '👨🏽‍❤‍💋‍👨🏽' => 'musu: gizona, gizona eta bitarteko azal-tonua',
    '👨🏽‍❤‍💋‍👨🏾' => 'musu: gizona, gizona, bitarteko azal-tonua eta 5. mota',
    '👨🏽‍❤‍💋‍👨🏿' => 'musu: gizona, gizona, bitarteko azal-tonua eta 6. mota',
    '👨🏾‍❤‍💋‍👨🏻' => 'musu: gizona, gizona, 5. mota eta 1–2. mota',
    '👨🏾‍❤‍💋‍👨🏼' => 'musu: gizona, gizona, 5. mota eta 3. mota',
    '👨🏾‍❤‍💋‍👨🏽' => 'musu: gizona, gizona, 5. mota eta bitarteko azal-tonua',
    '👨🏾‍❤‍💋‍👨🏾' => 'musu: gizona, gizona eta 5. mota',
    '👨🏾‍❤‍💋‍👨🏿' => 'musu: gizona, gizona, 5. mota eta 6. mota',
    '👨🏿‍❤‍💋‍👨🏻' => 'musu: gizona, gizona, 6. mota eta 1–2. mota',
    '👨🏿‍❤‍💋‍👨🏼' => 'musu: gizona, gizona, 6. mota eta 3. mota',
    '👨🏿‍❤‍💋‍👨🏽' => 'musu: gizona, gizona, 6. mota eta bitarteko azal-tonua',
    '👨🏿‍❤‍💋‍👨🏾' => 'musu: gizona, gizona, 6. mota eta 5. mota',
    '👨🏿‍❤‍💋‍👨🏿' => 'musu: gizona, gizona eta 6. mota',
    '👩🏻‍❤‍💋‍👨🏻' => 'musu: emakumea, gizona eta 1–2. mota',
    '👩🏻‍❤‍💋‍👨🏼' => 'musu: emakumea, gizona, 1–2. mota eta 3. mota',
    '👩🏻‍❤‍💋‍👨🏽' => 'musu: emakumea, gizona, 1–2. mota eta bitarteko azal-tonua',
    '👩🏻‍❤‍💋‍👨🏾' => 'musu: emakumea, gizona, 1–2. mota eta 5. mota',
    '👩🏻‍❤‍💋‍👨🏿' => 'musu: emakumea, gizona, 1–2. mota eta 6. mota',
    '👩🏼‍❤‍💋‍👨🏻' => 'musu: emakumea, gizona, 3. mota eta 1–2. mota',
    '👩🏼‍❤‍💋‍👨🏼' => 'musu: emakumea, gizona eta 3. mota',
    '👩🏼‍❤‍💋‍👨🏽' => 'musu: emakumea, gizona, 3. mota eta bitarteko azal-tonua',
    '👩🏼‍❤‍💋‍👨🏾' => 'musu: emakumea, gizona, 3. mota eta 5. mota',
    '👩🏼‍❤‍💋‍👨🏿' => 'musu: emakumea, gizona, 3. mota eta 6. mota',
    '👩🏽‍❤‍💋‍👨🏻' => 'musu: emakumea, gizona, bitarteko azal-tonua eta 1–2. mota',
    '👩🏽‍❤‍💋‍👨🏼' => 'musu: emakumea, gizona, bitarteko azal-tonua eta 3. mota',
    '👩🏽‍❤‍💋‍👨🏽' => 'musu: emakumea, gizona eta bitarteko azal-tonua',
    '👩🏽‍❤‍💋‍👨🏾' => 'musu: emakumea, gizona, bitarteko azal-tonua eta 5. mota',
    '👩🏽‍❤‍💋‍👨🏿' => 'musu: emakumea, gizona, bitarteko azal-tonua eta 6. mota',
    '👩🏾‍❤‍💋‍👨🏻' => 'musu: emakumea, gizona, 5. mota eta 1–2. mota',
    '👩🏾‍❤‍💋‍👨🏼' => 'musu: emakumea, gizona, 5. mota eta 3. mota',
    '👩🏾‍❤‍💋‍👨🏽' => 'musu: emakumea, gizona, 5. mota eta bitarteko azal-tonua',
    '👩🏾‍❤‍💋‍👨🏾' => 'musu: emakumea, gizona eta 5. mota',
    '👩🏾‍❤‍💋‍👨🏿' => 'musu: emakumea, gizona, 5. mota eta 6. mota',
    '👩🏿‍❤‍💋‍👨🏻' => 'musu: emakumea, gizona, 6. mota eta 1–2. mota',
    '👩🏿‍❤‍💋‍👨🏼' => 'musu: emakumea, gizona, 6. mota eta 3. mota',
    '👩🏿‍❤‍💋‍👨🏽' => 'musu: emakumea, gizona, 6. mota eta bitarteko azal-tonua',
    '👩🏿‍❤‍💋‍👨🏾' => 'musu: emakumea, gizona, 6. mota eta 5. mota',
    '👩🏿‍❤‍💋‍👨🏿' => 'musu: emakumea, gizona eta 6. mota',
    '👩🏻‍❤‍💋‍👩🏻' => 'musu: emakumea, emakumea eta 1–2. mota',
    '👩🏻‍❤‍💋‍👩🏼' => 'musu: emakumea, emakumea, 1–2. mota eta 3. mota',
    '👩🏻‍❤‍💋‍👩🏽' => 'musu: emakumea, emakumea, 1–2. mota eta bitarteko azal-tonua',
    '👩🏻‍❤‍💋‍👩🏾' => 'musu: emakumea, emakumea, 1–2. mota eta 5. mota',
    '👩🏻‍❤‍💋‍👩🏿' => 'musu: emakumea, emakumea, 1–2. mota eta 6. mota',
    '👩🏼‍❤‍💋‍👩🏻' => 'musu: emakumea, emakumea, 3. mota eta 1–2. mota',
    '👩🏼‍❤‍💋‍👩🏼' => 'musu: emakumea, emakumea eta 3. mota',
    '👩🏼‍❤‍💋‍👩🏽' => 'musu: emakumea, emakumea, 3. mota eta bitarteko azal-tonua',
    '👩🏼‍❤‍💋‍👩🏾' => 'musu: emakumea, emakumea, 3. mota eta 5. mota',
    '👩🏼‍❤‍💋‍👩🏿' => 'musu: emakumea, emakumea, 3. mota eta 6. mota',
    '👩🏽‍❤‍💋‍👩🏻' => 'musu: emakumea, emakumea, bitarteko azal-tonua eta 1–2. mota',
    '👩🏽‍❤‍💋‍👩🏼' => 'musu: emakumea, emakumea, bitarteko azal-tonua eta 3. mota',
    '👩🏽‍❤‍💋‍👩🏽' => 'musu: emakumea, emakumea eta bitarteko azal-tonua',
    '👩🏽‍❤‍💋‍👩🏾' => 'musu: emakumea, emakumea, bitarteko azal-tonua eta 5. mota',
    '👩🏽‍❤‍💋‍👩🏿' => 'musu: emakumea, emakumea, bitarteko azal-tonua eta 6. mota',
    '👩🏾‍❤‍💋‍👩🏻' => 'musu: emakumea, emakumea, 5. mota eta 1–2. mota',
    '👩🏾‍❤‍💋‍👩🏼' => 'musu: emakumea, emakumea, 5. mota eta 3. mota',
    '👩🏾‍❤‍💋‍👩🏽' => 'musu: emakumea, emakumea, 5. mota eta bitarteko azal-tonua',
    '👩🏾‍❤‍💋‍👩🏾' => 'musu: emakumea, emakumea eta 5. mota',
    '👩🏾‍❤‍💋‍👩🏿' => 'musu: emakumea, emakumea, 5. mota eta 6. mota',
    '👩🏿‍❤‍💋‍👩🏻' => 'musu: emakumea, emakumea, 6. mota eta 1–2. mota',
    '👩🏿‍❤‍💋‍👩🏼' => 'musu: emakumea, emakumea, 6. mota eta 3. mota',
    '👩🏿‍❤‍💋‍👩🏽' => 'musu: emakumea, emakumea, 6. mota eta bitarteko azal-tonua',
    '👩🏿‍❤‍💋‍👩🏾' => 'musu: emakumea, emakumea, 6. mota eta 5. mota',
    '👩🏿‍❤‍💋‍👩🏿' => 'musu: emakumea, emakumea eta 6. mota',
    '🧑🏻‍🫯‍🧑🏼' => 'borrokalariak: 1–2. mota eta 3. mota',
    '🧑🏻‍🫯‍🧑🏽' => 'borrokalariak: 1–2. mota eta bitarteko azal-tonua',
    '🧑🏻‍🫯‍🧑🏾' => 'borrokalariak: 1–2. mota eta 5. mota',
    '🧑🏻‍🫯‍🧑🏿' => 'borrokalariak: 1–2. mota eta 6. mota',
    '🧑🏼‍🫯‍🧑🏻' => 'borrokalariak: 3. mota eta 1–2. mota',
    '🧑🏼‍🫯‍🧑🏽' => 'borrokalariak: 3. mota eta bitarteko azal-tonua',
    '🧑🏼‍🫯‍🧑🏾' => 'borrokalariak: 3. mota eta 5. mota',
    '🧑🏼‍🫯‍🧑🏿' => 'borrokalariak: 3. mota eta 6. mota',
    '🧑🏽‍🫯‍🧑🏻' => 'borrokalariak: bitarteko azal-tonua eta 1–2. mota',
    '🧑🏽‍🫯‍🧑🏼' => 'borrokalariak: bitarteko azal-tonua eta 3. mota',
    '🧑🏽‍🫯‍🧑🏾' => 'borrokalariak: bitarteko azal-tonua eta 5. mota',
    '🧑🏽‍🫯‍🧑🏿' => 'borrokalariak: bitarteko azal-tonua eta 6. mota',
    '🧑🏾‍🫯‍🧑🏻' => 'borrokalariak: 5. mota eta 1–2. mota',
    '🧑🏾‍🫯‍🧑🏼' => 'borrokalariak: 5. mota eta 3. mota',
    '🧑🏾‍🫯‍🧑🏽' => 'borrokalariak: 5. mota eta bitarteko azal-tonua',
    '🧑🏾‍🫯‍🧑🏿' => 'borrokalariak: 5. mota eta 6. mota',
    '🧑🏿‍🫯‍🧑🏻' => 'borrokalariak: 6. mota eta 1–2. mota',
    '🧑🏿‍🫯‍🧑🏼' => 'borrokalariak: 6. mota eta 3. mota',
    '🧑🏿‍🫯‍🧑🏽' => 'borrokalariak: 6. mota eta bitarteko azal-tonua',
    '🧑🏿‍🫯‍🧑🏾' => 'borrokalariak: 6. mota eta 5. mota',
    '🧑🏻‍❤‍🧑🏼' => 'bihotza erdian duen bikotea: pertsona, pertsona, 1–2. mota eta 3. mota',
    '🧑🏻‍❤‍🧑🏽' => 'bihotza erdian duen bikotea: pertsona, pertsona, 1–2. mota eta bitarteko azal-tonua',
    '🧑🏻‍❤‍🧑🏾' => 'bihotza erdian duen bikotea: pertsona, pertsona, 1–2. mota eta 5. mota',
    '🧑🏻‍❤‍🧑🏿' => 'bihotza erdian duen bikotea: pertsona, pertsona, 1–2. mota eta 6. mota',
    '🧑🏼‍❤‍🧑🏻' => 'bihotza erdian duen bikotea: pertsona, pertsona, 3. mota eta 1–2. mota',
    '🧑🏼‍❤‍🧑🏽' => 'bihotza erdian duen bikotea: pertsona, pertsona, 3. mota eta bitarteko azal-tonua',
    '🧑🏼‍❤‍🧑🏾' => 'bihotza erdian duen bikotea: pertsona, pertsona, 3. mota eta 5. mota',
    '🧑🏼‍❤‍🧑🏿' => 'bihotza erdian duen bikotea: pertsona, pertsona, 3. mota eta 6. mota',
    '🧑🏽‍❤‍🧑🏻' => 'bihotza erdian duen bikotea: pertsona, pertsona, bitarteko azal-tonua eta 1–2. mota',
    '🧑🏽‍❤‍🧑🏼' => 'bihotza erdian duen bikotea: pertsona, pertsona, bitarteko azal-tonua eta 3. mota',
    '🧑🏽‍❤‍🧑🏾' => 'bihotza erdian duen bikotea: pertsona, pertsona, bitarteko azal-tonua eta 5. mota',
    '🧑🏽‍❤‍🧑🏿' => 'bihotza erdian duen bikotea: pertsona, pertsona, bitarteko azal-tonua eta 6. mota',
    '🧑🏾‍❤‍🧑🏻' => 'bihotza erdian duen bikotea: pertsona, pertsona, 5. mota eta 1–2. mota',
    '🧑🏾‍❤‍🧑🏼' => 'bihotza erdian duen bikotea: pertsona, pertsona, 5. mota eta 3. mota',
    '🧑🏾‍❤‍🧑🏽' => 'bihotza erdian duen bikotea: pertsona, pertsona, 5. mota eta bitarteko azal-tonua',
    '🧑🏾‍❤‍🧑🏿' => 'bihotza erdian duen bikotea: pertsona, pertsona, 5. mota eta 6. mota',
    '🧑🏿‍❤‍🧑🏻' => 'bihotza erdian duen bikotea: pertsona, pertsona, 6. mota eta 1–2. mota',
    '🧑🏿‍❤‍🧑🏼' => 'bihotza erdian duen bikotea: pertsona, pertsona, 6. mota eta 3. mota',
    '🧑🏿‍❤‍🧑🏽' => 'bihotza erdian duen bikotea: pertsona, pertsona, 6. mota eta bitarteko azal-tonua',
    '🧑🏿‍❤‍🧑🏾' => 'bihotza erdian duen bikotea: pertsona, pertsona, 6. mota eta 5. mota',
    '🧑🏻‍🐰‍🧑🏼' => 'jendea untxi-belarriak jantzita: 1–2. mota eta 3. mota',
    '🧑🏻‍🐰‍🧑🏽' => 'jendea untxi-belarriak jantzita: 1–2. mota eta bitarteko azal-tonua',
    '🧑🏻‍🐰‍🧑🏾' => 'jendea untxi-belarriak jantzita: 1–2. mota eta 5. mota',
    '🧑🏻‍🐰‍🧑🏿' => 'jendea untxi-belarriak jantzita: 1–2. mota eta 6. mota',
    '🧑🏼‍🐰‍🧑🏻' => 'jendea untxi-belarriak jantzita: 3. mota eta 1–2. mota',
    '🧑🏼‍🐰‍🧑🏽' => 'jendea untxi-belarriak jantzita: 3. mota eta bitarteko azal-tonua',
    '🧑🏼‍🐰‍🧑🏾' => 'jendea untxi-belarriak jantzita: 3. mota eta 5. mota',
    '🧑🏼‍🐰‍🧑🏿' => 'jendea untxi-belarriak jantzita: 3. mota eta 6. mota',
    '🧑🏽‍🐰‍🧑🏻' => 'jendea untxi-belarriak jantzita: bitarteko azal-tonua eta 1–2. mota',
    '🧑🏽‍🐰‍🧑🏼' => 'jendea untxi-belarriak jantzita: bitarteko azal-tonua eta 3. mota',
    '🧑🏽‍🐰‍🧑🏾' => 'jendea untxi-belarriak jantzita: bitarteko azal-tonua eta 5. mota',
    '🧑🏽‍🐰‍🧑🏿' => 'jendea untxi-belarriak jantzita: bitarteko azal-tonua eta 6. mota',
    '🧑🏾‍🐰‍🧑🏻' => 'jendea untxi-belarriak jantzita: 5. mota eta 1–2. mota',
    '🧑🏾‍🐰‍🧑🏼' => 'jendea untxi-belarriak jantzita: 5. mota eta 3. mota',
    '🧑🏾‍🐰‍🧑🏽' => 'jendea untxi-belarriak jantzita: 5. mota eta bitarteko azal-tonua',
    '🧑🏾‍🐰‍🧑🏿' => 'jendea untxi-belarriak jantzita: 5. mota eta 6. mota',
    '🧑🏿‍🐰‍🧑🏻' => 'jendea untxi-belarriak jantzita: 6. mota eta 1–2. mota',
    '🧑🏿‍🐰‍🧑🏼' => 'jendea untxi-belarriak jantzita: 6. mota eta 3. mota',
    '🧑🏿‍🐰‍🧑🏽' => 'jendea untxi-belarriak jantzita: 6. mota eta bitarteko azal-tonua',
    '🧑🏿‍🐰‍🧑🏾' => 'jendea untxi-belarriak jantzita: 6. mota eta 5. mota',
    '👨🏻‍🫯‍👨🏼' => 'gizonak borrokan: 1–2. mota eta 3. mota',
    '👨🏻‍🫯‍👨🏽' => 'gizonak borrokan: 1–2. mota eta bitarteko azal-tonua',
    '👨🏻‍🫯‍👨🏾' => 'gizonak borrokan: 1–2. mota eta 5. mota',
    '👨🏻‍🫯‍👨🏿' => 'gizonak borrokan: 1–2. mota eta 6. mota',
    '👨🏼‍🫯‍👨🏻' => 'gizonak borrokan: 3. mota eta 1–2. mota',
    '👨🏼‍🫯‍👨🏽' => 'gizonak borrokan: 3. mota eta bitarteko azal-tonua',
    '👨🏼‍🫯‍👨🏾' => 'gizonak borrokan: 3. mota eta 5. mota',
    '👨🏼‍🫯‍👨🏿' => 'gizonak borrokan: 3. mota eta 6. mota',
    '👨🏽‍🫯‍👨🏻' => 'gizonak borrokan: bitarteko azal-tonua eta 1–2. mota',
    '👨🏽‍🫯‍👨🏼' => 'gizonak borrokan: bitarteko azal-tonua eta 3. mota',
    '👨🏽‍🫯‍👨🏾' => 'gizonak borrokan: bitarteko azal-tonua eta 5. mota',
    '👨🏽‍🫯‍👨🏿' => 'gizonak borrokan: bitarteko azal-tonua eta 6. mota',
    '👨🏾‍🫯‍👨🏻' => 'gizonak borrokan: 5. mota eta 1–2. mota',
    '👨🏾‍🫯‍👨🏼' => 'gizonak borrokan: 5. mota eta 3. mota',
    '👨🏾‍🫯‍👨🏽' => 'gizonak borrokan: 5. mota eta bitarteko azal-tonua',
    '👨🏾‍🫯‍👨🏿' => 'gizonak borrokan: 5. mota eta 6. mota',
    '👨🏿‍🫯‍👨🏻' => 'gizonak borrokan: 6. mota eta 1–2. mota',
    '👨🏿‍🫯‍👨🏼' => 'gizonak borrokan: 6. mota eta 3. mota',
    '👨🏿‍🫯‍👨🏽' => 'gizonak borrokan: 6. mota eta bitarteko azal-tonua',
    '👨🏿‍🫯‍👨🏾' => 'gizonak borrokan: 6. mota eta 5. mota',
    '👨🏻‍❤‍👨🏻' => 'bihotza erdian duen bikotea: gizona, gizona eta 1–2. mota',
    '👨🏻‍❤‍👨🏼' => 'bihotza erdian duen bikotea: gizona, gizona, 1–2. mota eta 3. mota',
    '👨🏻‍❤‍👨🏽' => 'bihotza erdian duen bikotea: gizona, gizona, 1–2. mota eta bitarteko azal-tonua',
    '👨🏻‍❤‍👨🏾' => 'bihotza erdian duen bikotea: gizona, gizona, 1–2. mota eta 5. mota',
    '👨🏻‍❤‍👨🏿' => 'bihotza erdian duen bikotea: gizona, gizona, 1–2. mota eta 6. mota',
    '👨🏼‍❤‍👨🏻' => 'bihotza erdian duen bikotea: gizona, gizona, 3. mota eta 1–2. mota',
    '👨🏼‍❤‍👨🏼' => 'bihotza erdian duen bikotea: gizona, gizona eta 3. mota',
    '👨🏼‍❤‍👨🏽' => 'bihotza erdian duen bikotea: gizona, gizona, 3. mota eta bitarteko azal-tonua',
    '👨🏼‍❤‍👨🏾' => 'bihotza erdian duen bikotea: gizona, gizona, 3. mota eta 5. mota',
    '👨🏼‍❤‍👨🏿' => 'bihotza erdian duen bikotea: gizona, gizona, 3. mota eta 6. mota',
    '👨🏽‍❤‍👨🏻' => 'bihotza erdian duen bikotea: gizona, gizona, bitarteko azal-tonua eta 1–2. mota',
    '👨🏽‍❤‍👨🏼' => 'bihotza erdian duen bikotea: gizona, gizona, bitarteko azal-tonua eta 3. mota',
    '👨🏽‍❤‍👨🏽' => 'bihotza erdian duen bikotea: gizona, gizona eta bitarteko azal-tonua',
    '👨🏽‍❤‍👨🏾' => 'bihotza erdian duen bikotea: gizona, gizona, bitarteko azal-tonua eta 5. mota',
    '👨🏽‍❤‍👨🏿' => 'bihotza erdian duen bikotea: gizona, gizona, bitarteko azal-tonua eta 6. mota',
    '👨🏾‍❤‍👨🏻' => 'bihotza erdian duen bikotea: gizona, gizona, 5. mota eta 1–2. mota',
    '👨🏾‍❤‍👨🏼' => 'bihotza erdian duen bikotea: gizona, gizona, 5. mota eta 3. mota',
    '👨🏾‍❤‍👨🏽' => 'bihotza erdian duen bikotea: gizona, gizona, 5. mota eta bitarteko azal-tonua',
    '👨🏾‍❤‍👨🏾' => 'bihotza erdian duen bikotea: gizona, gizona eta 5. mota',
    '👨🏾‍❤‍👨🏿' => 'bihotza erdian duen bikotea: gizona, gizona, 5. mota eta 6. mota',
    '👨🏿‍❤‍👨🏻' => 'bihotza erdian duen bikotea: gizona, gizona, 6. mota eta 1–2. mota',
    '👨🏿‍❤‍👨🏼' => 'bihotza erdian duen bikotea: gizona, gizona, 6. mota eta 3. mota',
    '👨🏿‍❤‍👨🏽' => 'bihotza erdian duen bikotea: gizona, gizona, 6. mota eta bitarteko azal-tonua',
    '👨🏿‍❤‍👨🏾' => 'bihotza erdian duen bikotea: gizona, gizona, 6. mota eta 5. mota',
    '👨🏿‍❤‍👨🏿' => 'bihotza erdian duen bikotea: gizona, gizona eta 6. mota',
    '👨🏻‍🐰‍👨🏼' => 'gizonak untxi-belarriak jantzita: 1–2. mota eta 3. mota',
    '👨🏻‍🐰‍👨🏽' => 'gizonak untxi-belarriak jantzita: 1–2. mota eta bitarteko azal-tonua',
    '👨🏻‍🐰‍👨🏾' => 'gizonak untxi-belarriak jantzita: 1–2. mota eta 5. mota',
    '👨🏻‍🐰‍👨🏿' => 'gizonak untxi-belarriak jantzita: 1–2. mota eta 6. mota',
    '👨🏼‍🐰‍👨🏻' => 'gizonak untxi-belarriak jantzita: 3. mota eta 1–2. mota',
    '👨🏼‍🐰‍👨🏽' => 'gizonak untxi-belarriak jantzita: 3. mota eta bitarteko azal-tonua',
    '👨🏼‍🐰‍👨🏾' => 'gizonak untxi-belarriak jantzita: 3. mota eta 5. mota',
    '👨🏼‍🐰‍👨🏿' => 'gizonak untxi-belarriak jantzita: 3. mota eta 6. mota',
    '👨🏽‍🐰‍👨🏻' => 'gizonak untxi-belarriak jantzita: bitarteko azal-tonua eta 1–2. mota',
    '👨🏽‍🐰‍👨🏼' => 'gizonak untxi-belarriak jantzita: bitarteko azal-tonua eta 3. mota',
    '👨🏽‍🐰‍👨🏾' => 'gizonak untxi-belarriak jantzita: bitarteko azal-tonua eta 5. mota',
    '👨🏽‍🐰‍👨🏿' => 'gizonak untxi-belarriak jantzita: bitarteko azal-tonua eta 6. mota',
    '👨🏾‍🐰‍👨🏻' => 'gizonak untxi-belarriak jantzita: 5. mota eta 1–2. mota',
    '👨🏾‍🐰‍👨🏼' => 'gizonak untxi-belarriak jantzita: 5. mota eta 3. mota',
    '👨🏾‍🐰‍👨🏽' => 'gizonak untxi-belarriak jantzita: 5. mota eta bitarteko azal-tonua',
    '👨🏾‍🐰‍👨🏿' => 'gizonak untxi-belarriak jantzita: 5. mota eta 6. mota',
    '👨🏿‍🐰‍👨🏻' => 'gizonak untxi-belarriak jantzita: 6. mota eta 1–2. mota',
    '👨🏿‍🐰‍👨🏼' => 'gizonak untxi-belarriak jantzita: 6. mota eta 3. mota',
    '👨🏿‍🐰‍👨🏽' => 'gizonak untxi-belarriak jantzita: 6. mota eta bitarteko azal-tonua',
    '👨🏿‍🐰‍👨🏾' => 'gizonak untxi-belarriak jantzita: 6. mota eta 5. mota',
    '👩🏻‍🫯‍👩🏼' => 'emakumeak borrokan: 1–2. mota eta 3. mota',
    '👩🏻‍🫯‍👩🏽' => 'emakumeak borrokan: 1–2. mota eta bitarteko azal-tonua',
    '👩🏻‍🫯‍👩🏾' => 'emakumeak borrokan: 1–2. mota eta 5. mota',
    '👩🏻‍🫯‍👩🏿' => 'emakumeak borrokan: 1–2. mota eta 6. mota',
    '👩🏼‍🫯‍👩🏻' => 'emakumeak borrokan: 3. mota eta 1–2. mota',
    '👩🏼‍🫯‍👩🏽' => 'emakumeak borrokan: 3. mota eta bitarteko azal-tonua',
    '👩🏼‍🫯‍👩🏾' => 'emakumeak borrokan: 3. mota eta 5. mota',
    '👩🏼‍🫯‍👩🏿' => 'emakumeak borrokan: 3. mota eta 6. mota',
    '👩🏽‍🫯‍👩🏻' => 'emakumeak borrokan: bitarteko azal-tonua eta 1–2. mota',
    '👩🏽‍🫯‍👩🏼' => 'emakumeak borrokan: bitarteko azal-tonua eta 3. mota',
    '👩🏽‍🫯‍👩🏾' => 'emakumeak borrokan: bitarteko azal-tonua eta 5. mota',
    '👩🏽‍🫯‍👩🏿' => 'emakumeak borrokan: bitarteko azal-tonua eta 6. mota',
    '👩🏾‍🫯‍👩🏻' => 'emakumeak borrokan: 5. mota eta 1–2. mota',
    '👩🏾‍🫯‍👩🏼' => 'emakumeak borrokan: 5. mota eta 3. mota',
    '👩🏾‍🫯‍👩🏽' => 'emakumeak borrokan: 5. mota eta bitarteko azal-tonua',
    '👩🏾‍🫯‍👩🏿' => 'emakumeak borrokan: 5. mota eta 6. mota',
    '👩🏿‍🫯‍👩🏻' => 'emakumeak borrokan: 6. mota eta 1–2. mota',
    '👩🏿‍🫯‍👩🏼' => 'emakumeak borrokan: 6. mota eta 3. mota',
    '👩🏿‍🫯‍👩🏽' => 'emakumeak borrokan: 6. mota eta bitarteko azal-tonua',
    '👩🏿‍🫯‍👩🏾' => 'emakumeak borrokan: 6. mota eta 5. mota',
    '👩🏻‍❤‍👨🏻' => 'bihotza erdian duen bikotea: emakumea, gizona eta 1–2. mota',
    '👩🏻‍❤‍👨🏼' => 'bihotza erdian duen bikotea: emakumea, gizona, 1–2. mota eta 3. mota',
    '👩🏻‍❤‍👨🏽' => 'bihotza erdian duen bikotea: emakumea, gizona, 1–2. mota eta bitarteko azal-tonua',
    '👩🏻‍❤‍👨🏾' => 'bihotza erdian duen bikotea: emakumea, gizona, 1–2. mota eta 5. mota',
    '👩🏻‍❤‍👨🏿' => 'bihotza erdian duen bikotea: emakumea, gizona, 1–2. mota eta 6. mota',
    '👩🏼‍❤‍👨🏻' => 'bihotza erdian duen bikotea: emakumea, gizona, 3. mota eta 1–2. mota',
    '👩🏼‍❤‍👨🏼' => 'bihotza erdian duen bikotea: emakumea, gizona eta 3. mota',
    '👩🏼‍❤‍👨🏽' => 'bihotza erdian duen bikotea: emakumea, gizona, 3. mota eta bitarteko azal-tonua',
    '👩🏼‍❤‍👨🏾' => 'bihotza erdian duen bikotea: emakumea, gizona, 3. mota eta 5. mota',
    '👩🏼‍❤‍👨🏿' => 'bihotza erdian duen bikotea: emakumea, gizona, 3. mota eta 6. mota',
    '👩🏽‍❤‍👨🏻' => 'bihotza erdian duen bikotea: emakumea, gizona, bitarteko azal-tonua eta 1–2. mota',
    '👩🏽‍❤‍👨🏼' => 'bihotza erdian duen bikotea: emakumea, gizona, bitarteko azal-tonua eta 3. mota',
    '👩🏽‍❤‍👨🏽' => 'bihotza erdian duen bikotea: emakumea, gizona eta bitarteko azal-tonua',
    '👩🏽‍❤‍👨🏾' => 'bihotza erdian duen bikotea: emakumea, gizona, bitarteko azal-tonua eta 5. mota',
    '👩🏽‍❤‍👨🏿' => 'bihotza erdian duen bikotea: emakumea, gizona, bitarteko azal-tonua eta 6. mota',
    '👩🏾‍❤‍👨🏻' => 'bihotza erdian duen bikotea: emakumea, gizona, 5. mota eta 1–2. mota',
    '👩🏾‍❤‍👨🏼' => 'bihotza erdian duen bikotea: emakumea, gizona, 5. mota eta 3. mota',
    '👩🏾‍❤‍👨🏽' => 'bihotza erdian duen bikotea: emakumea, gizona, 5. mota eta bitarteko azal-tonua',
    '👩🏾‍❤‍👨🏾' => 'bihotza erdian duen bikotea: emakumea, gizona eta 5. mota',
    '👩🏾‍❤‍👨🏿' => 'bihotza erdian duen bikotea: emakumea, gizona, 5. mota eta 6. mota',
    '👩🏿‍❤‍👨🏻' => 'bihotza erdian duen bikotea: emakumea, gizona, 6. mota eta 1–2. mota',
    '👩🏿‍❤‍👨🏼' => 'bihotza erdian duen bikotea: emakumea, gizona, 6. mota eta 3. mota',
    '👩🏿‍❤‍👨🏽' => 'bihotza erdian duen bikotea: emakumea, gizona, 6. mota eta bitarteko azal-tonua',
    '👩🏿‍❤‍👨🏾' => 'bihotza erdian duen bikotea: emakumea, gizona, 6. mota eta 5. mota',
    '👩🏿‍❤‍👨🏿' => 'bihotza erdian duen bikotea: emakumea, gizona eta 6. mota',
    '👩🏻‍❤‍👩🏻' => 'bihotza erdian duen bikotea: emakumea, emakumea eta 1–2. mota',
    '👩🏻‍❤‍👩🏼' => 'bihotza erdian duen bikotea: emakumea, emakumea, 1–2. mota eta 3. mota',
    '👩🏻‍❤‍👩🏽' => 'bihotza erdian duen bikotea: emakumea, emakumea, 1–2. mota eta bitarteko azal-tonua',
    '👩🏻‍❤‍👩🏾' => 'bihotza erdian duen bikotea: emakumea, emakumea, 1–2. mota eta 5. mota',
    '👩🏻‍❤‍👩🏿' => 'bihotza erdian duen bikotea: emakumea, emakumea, 1–2. mota eta 6. mota',
    '👩🏼‍❤‍👩🏻' => 'bihotza erdian duen bikotea: emakumea, emakumea, 3. mota eta 1–2. mota',
    '👩🏼‍❤‍👩🏼' => 'bihotza erdian duen bikotea: emakumea, emakumea eta 3. mota',
    '👩🏼‍❤‍👩🏽' => 'bihotza erdian duen bikotea: emakumea, emakumea, 3. mota eta bitarteko azal-tonua',
    '👩🏼‍❤‍👩🏾' => 'bihotza erdian duen bikotea: emakumea, emakumea, 3. mota eta 5. mota',
    '👩🏼‍❤‍👩🏿' => 'bihotza erdian duen bikotea: emakumea, emakumea, 3. mota eta 6. mota',
    '👩🏽‍❤‍👩🏻' => 'bihotza erdian duen bikotea: emakumea, emakumea, bitarteko azal-tonua eta 1–2. mota',
    '👩🏽‍❤‍👩🏼' => 'bihotza erdian duen bikotea: emakumea, emakumea, bitarteko azal-tonua eta 3. mota',
    '👩🏽‍❤‍👩🏽' => 'bihotza erdian duen bikotea: emakumea, emakumea eta bitarteko azal-tonua',
    '👩🏽‍❤‍👩🏾' => 'bihotza erdian duen bikotea: emakumea, emakumea, bitarteko azal-tonua eta 5. mota',
    '👩🏽‍❤‍👩🏿' => 'bihotza erdian duen bikotea: emakumea, emakumea, bitarteko azal-tonua eta 6. mota',
    '👩🏾‍❤‍👩🏻' => 'bihotza erdian duen bikotea: emakumea, emakumea, 5. mota eta 1–2. mota',
    '👩🏾‍❤‍👩🏼' => 'bihotza erdian duen bikotea: emakumea, emakumea, 5. mota eta 3. mota',
    '👩🏾‍❤‍👩🏽' => 'bihotza erdian duen bikotea: emakumea, emakumea, 5. mota eta bitarteko azal-tonua',
    '👩🏾‍❤‍👩🏾' => 'bihotza erdian duen bikotea: emakumea, emakumea eta 5. mota',
    '👩🏾‍❤‍👩🏿' => 'bihotza erdian duen bikotea: emakumea, emakumea, 5. mota eta 6. mota',
    '👩🏿‍❤‍👩🏻' => 'bihotza erdian duen bikotea: emakumea, emakumea, 6. mota eta 1–2. mota',
    '👩🏿‍❤‍👩🏼' => 'bihotza erdian duen bikotea: emakumea, emakumea, 6. mota eta 3. mota',
    '👩🏿‍❤‍👩🏽' => 'bihotza erdian duen bikotea: emakumea, emakumea, 6. mota eta bitarteko azal-tonua',
    '👩🏿‍❤‍👩🏾' => 'bihotza erdian duen bikotea: emakumea, emakumea, 6. mota eta 5. mota',
    '👩🏿‍❤‍👩🏿' => 'bihotza erdian duen bikotea: emakumea, emakumea eta 6. mota',
    '👩🏻‍🐰‍👩🏼' => 'emakumeak jendea untxi-belarriak jantzita: 1–2. mota eta 3. mota',
    '👩🏻‍🐰‍👩🏽' => 'emakumeak jendea untxi-belarriak jantzita: 1–2. mota eta bitarteko azal-tonua',
    '👩🏻‍🐰‍👩🏾' => 'emakumeak jendea untxi-belarriak jantzita: 1–2. mota eta 5. mota',
    '👩🏻‍🐰‍👩🏿' => 'emakumeak jendea untxi-belarriak jantzita: 1–2. mota eta 6. mota',
    '👩🏼‍🐰‍👩🏻' => 'emakumeak jendea untxi-belarriak jantzita: 3. mota eta 1–2. mota',
    '👩🏼‍🐰‍👩🏽' => 'emakumeak jendea untxi-belarriak jantzita: 3. mota eta bitarteko azal-tonua',
    '👩🏼‍🐰‍👩🏾' => 'emakumeak jendea untxi-belarriak jantzita: 3. mota eta 5. mota',
    '👩🏼‍🐰‍👩🏿' => 'emakumeak jendea untxi-belarriak jantzita: 3. mota eta 6. mota',
    '👩🏽‍🐰‍👩🏻' => 'emakumeak jendea untxi-belarriak jantzita: bitarteko azal-tonua eta 1–2. mota',
    '👩🏽‍🐰‍👩🏼' => 'emakumeak jendea untxi-belarriak jantzita: bitarteko azal-tonua eta 3. mota',
    '👩🏽‍🐰‍👩🏾' => 'emakumeak jendea untxi-belarriak jantzita: bitarteko azal-tonua eta 5. mota',
    '👩🏽‍🐰‍👩🏿' => 'emakumeak jendea untxi-belarriak jantzita: bitarteko azal-tonua eta 6. mota',
    '👩🏾‍🐰‍👩🏻' => 'emakumeak jendea untxi-belarriak jantzita: 5. mota eta 1–2. mota',
    '👩🏾‍🐰‍👩🏼' => 'emakumeak jendea untxi-belarriak jantzita: 5. mota eta 3. mota',
    '👩🏾‍🐰‍👩🏽' => 'emakumeak jendea untxi-belarriak jantzita: 5. mota eta bitarteko azal-tonua',
    '👩🏾‍🐰‍👩🏿' => 'emakumeak jendea untxi-belarriak jantzita: 5. mota eta 6. mota',
    '👩🏿‍🐰‍👩🏻' => 'emakumeak jendea untxi-belarriak jantzita: 6. mota eta 1–2. mota',
    '👩🏿‍🐰‍👩🏼' => 'emakumeak jendea untxi-belarriak jantzita: 6. mota eta 3. mota',
    '👩🏿‍🐰‍👩🏽' => 'emakumeak jendea untxi-belarriak jantzita: 6. mota eta bitarteko azal-tonua',
    '👩🏿‍🐰‍👩🏾' => 'emakumeak jendea untxi-belarriak jantzita: 6. mota eta 5. mota',
    '🧑🏻‍🤝‍🧑🏻' => 'bi pertsona elkarri eskua ematen: 1–2. mota',
    '🧑🏻‍🤝‍🧑🏼' => 'bi pertsona elkarri eskua ematen: 1–2. mota eta 3. mota',
    '🧑🏻‍🤝‍🧑🏽' => 'bi pertsona elkarri eskua ematen: 1–2. mota eta bitarteko azal-tonua',
    '🧑🏻‍🤝‍🧑🏾' => 'bi pertsona elkarri eskua ematen: 1–2. mota eta 5. mota',
    '🧑🏻‍🤝‍🧑🏿' => 'bi pertsona elkarri eskua ematen: 1–2. mota eta 6. mota',
    '🧑🏼‍🤝‍🧑🏻' => 'bi pertsona elkarri eskua ematen: 3. mota eta 1–2. mota',
    '🧑🏼‍🤝‍🧑🏼' => 'bi pertsona elkarri eskua ematen: 3. mota',
    '🧑🏼‍🤝‍🧑🏽' => 'bi pertsona elkarri eskua ematen: 3. mota eta bitarteko azal-tonua',
    '🧑🏼‍🤝‍🧑🏾' => 'bi pertsona elkarri eskua ematen: 3. mota eta 5. mota',
    '🧑🏼‍🤝‍🧑🏿' => 'bi pertsona elkarri eskua ematen: 3. mota eta 6. mota',
    '🧑🏽‍🤝‍🧑🏻' => 'bi pertsona elkarri eskua ematen: bitarteko azal-tonua eta 1–2. mota',
    '🧑🏽‍🤝‍🧑🏼' => 'bi pertsona elkarri eskua ematen: bitarteko azal-tonua eta 3. mota',
    '🧑🏽‍🤝‍🧑🏽' => 'bi pertsona elkarri eskua ematen: bitarteko azal-tonua',
    '🧑🏽‍🤝‍🧑🏾' => 'bi pertsona elkarri eskua ematen: bitarteko azal-tonua eta 5. mota',
    '🧑🏽‍🤝‍🧑🏿' => 'bi pertsona elkarri eskua ematen: bitarteko azal-tonua eta 6. mota',
    '🧑🏾‍🤝‍🧑🏻' => 'bi pertsona elkarri eskua ematen: 5. mota eta 1–2. mota',
    '🧑🏾‍🤝‍🧑🏼' => 'bi pertsona elkarri eskua ematen: 5. mota eta 3. mota',
    '🧑🏾‍🤝‍🧑🏽' => 'bi pertsona elkarri eskua ematen: 5. mota eta bitarteko azal-tonua',
    '🧑🏾‍🤝‍🧑🏾' => 'bi pertsona elkarri eskua ematen: 5. mota',
    '🧑🏾‍🤝‍🧑🏿' => 'bi pertsona elkarri eskua ematen: 5. mota eta 6. mota',
    '🧑🏿‍🤝‍🧑🏻' => 'bi pertsona elkarri eskua ematen: 6. mota eta 1–2. mota',
    '🧑🏿‍🤝‍🧑🏼' => 'bi pertsona elkarri eskua ematen: 6. mota eta 3. mota',
    '🧑🏿‍🤝‍🧑🏽' => 'bi pertsona elkarri eskua ematen: 6. mota eta bitarteko azal-tonua',
    '🧑🏿‍🤝‍🧑🏾' => 'bi pertsona elkarri eskua ematen: 6. mota eta 5. mota',
    '🧑🏿‍🤝‍🧑🏿' => 'bi pertsona elkarri eskua ematen: 6. mota',
    '👩🏻‍🤝‍👩🏼' => 'bi emakume elkarri eskua ematen: 1–2. mota eta 3. mota',
    '👩🏻‍🤝‍👩🏽' => 'bi emakume elkarri eskua ematen: 1–2. mota eta bitarteko azal-tonua',
    '👩🏻‍🤝‍👩🏾' => 'bi emakume elkarri eskua ematen: 1–2. mota eta 5. mota',
    '👩🏻‍🤝‍👩🏿' => 'bi emakume elkarri eskua ematen: 1–2. mota eta 6. mota',
    '👩🏼‍🤝‍👩🏻' => 'bi emakume elkarri eskua ematen: 3. mota eta 1–2. mota',
    '👩🏼‍🤝‍👩🏽' => 'bi emakume elkarri eskua ematen: 3. mota eta bitarteko azal-tonua',
    '👩🏼‍🤝‍👩🏾' => 'bi emakume elkarri eskua ematen: 3. mota eta 5. mota',
    '👩🏼‍🤝‍👩🏿' => 'bi emakume elkarri eskua ematen: 3. mota eta 6. mota',
    '👩🏽‍🤝‍👩🏻' => 'bi emakume elkarri eskua ematen: bitarteko azal-tonua eta 1–2. mota',
    '👩🏽‍🤝‍👩🏼' => 'bi emakume elkarri eskua ematen: bitarteko azal-tonua eta 3. mota',
    '👩🏽‍🤝‍👩🏾' => 'bi emakume elkarri eskua ematen: bitarteko azal-tonua eta 5. mota',
    '👩🏽‍🤝‍👩🏿' => 'bi emakume elkarri eskua ematen: bitarteko azal-tonua eta 6. mota',
    '👩🏾‍🤝‍👩🏻' => 'bi emakume elkarri eskua ematen: 5. mota eta 1–2. mota',
    '👩🏾‍🤝‍👩🏼' => 'bi emakume elkarri eskua ematen: 5. mota eta 3. mota',
    '👩🏾‍🤝‍👩🏽' => 'bi emakume elkarri eskua ematen: 5. mota eta bitarteko azal-tonua',
    '👩🏾‍🤝‍👩🏿' => 'bi emakume elkarri eskua ematen: 5. mota eta 6. mota',
    '👩🏿‍🤝‍👩🏻' => 'bi emakume elkarri eskua ematen: 6. mota eta 1–2. mota',
    '👩🏿‍🤝‍👩🏼' => 'bi emakume elkarri eskua ematen: 6. mota eta 3. mota',
    '👩🏿‍🤝‍👩🏽' => 'bi emakume elkarri eskua ematen: 6. mota eta bitarteko azal-tonua',
    '👩🏿‍🤝‍👩🏾' => 'bi emakume elkarri eskua ematen: 6. mota eta 5. mota',
    '👩🏻‍🤝‍👨🏼' => 'gizon-emakumeak elkarri eskua ematen: 1–2. mota eta 3. mota',
    '👩🏻‍🤝‍👨🏽' => 'gizon-emakumeak elkarri eskua ematen: 1–2. mota eta bitarteko azal-tonua',
    '👩🏻‍🤝‍👨🏾' => 'gizon-emakumeak elkarri eskua ematen: 1–2. mota eta 5. mota',
    '👩🏻‍🤝‍👨🏿' => 'gizon-emakumeak elkarri eskua ematen: 1–2. mota eta 6. mota',
    '👩🏼‍🤝‍👨🏻' => 'gizon-emakumeak elkarri eskua ematen: 3. mota eta 1–2. mota',
    '👩🏼‍🤝‍👨🏽' => 'gizon-emakumeak elkarri eskua ematen: 3. mota eta bitarteko azal-tonua',
    '👩🏼‍🤝‍👨🏾' => 'gizon-emakumeak elkarri eskua ematen: 3. mota eta 5. mota',
    '👩🏼‍🤝‍👨🏿' => 'gizon-emakumeak elkarri eskua ematen: 3. mota eta 6. mota',
    '👩🏽‍🤝‍👨🏻' => 'gizon-emakumeak elkarri eskua ematen: bitarteko azal-tonua eta 1–2. mota',
    '👩🏽‍🤝‍👨🏼' => 'gizon-emakumeak elkarri eskua ematen: bitarteko azal-tonua eta 3. mota',
    '👩🏽‍🤝‍👨🏾' => 'gizon-emakumeak elkarri eskua ematen: bitarteko azal-tonua eta 5. mota',
    '👩🏽‍🤝‍👨🏿' => 'gizon-emakumeak elkarri eskua ematen: bitarteko azal-tonua eta 6. mota',
    '👩🏾‍🤝‍👨🏻' => 'gizon-emakumeak elkarri eskua ematen: 5. mota eta 1–2. mota',
    '👩🏾‍🤝‍👨🏼' => 'gizon-emakumeak elkarri eskua ematen: 5. mota eta 3. mota',
    '👩🏾‍🤝‍👨🏽' => 'gizon-emakumeak elkarri eskua ematen: 5. mota eta bitarteko azal-tonua',
    '👩🏾‍🤝‍👨🏿' => 'gizon-emakumeak elkarri eskua ematen: 5. mota eta 6. mota',
    '👩🏿‍🤝‍👨🏻' => 'gizon-emakumeak elkarri eskua ematen: 6. mota eta 1–2. mota',
    '👩🏿‍🤝‍👨🏼' => 'gizon-emakumeak elkarri eskua ematen: 6. mota eta 3. mota',
    '👩🏿‍🤝‍👨🏽' => 'gizon-emakumeak elkarri eskua ematen: 6. mota eta bitarteko azal-tonua',
    '👩🏿‍🤝‍👨🏾' => 'gizon-emakumeak elkarri eskua ematen: 6. mota eta 5. mota',
    '👨🏻‍🤝‍👨🏼' => 'bi gizon elkarri eskua ematen: 1–2. mota eta 3. mota',
    '👨🏻‍🤝‍👨🏽' => 'bi gizon elkarri eskua ematen: 1–2. mota eta bitarteko azal-tonua',
    '👨🏻‍🤝‍👨🏾' => 'bi gizon elkarri eskua ematen: 1–2. mota eta 5. mota',
    '👨🏻‍🤝‍👨🏿' => 'bi gizon elkarri eskua ematen: 1–2. mota eta 6. mota',
    '👨🏼‍🤝‍👨🏻' => 'bi gizon elkarri eskua ematen: 3. mota eta 1–2. mota',
    '👨🏼‍🤝‍👨🏽' => 'bi gizon elkarri eskua ematen: 3. mota eta bitarteko azal-tonua',
    '👨🏼‍🤝‍👨🏾' => 'bi gizon elkarri eskua ematen: 3. mota eta 5. mota',
    '👨🏼‍🤝‍👨🏿' => 'bi gizon elkarri eskua ematen: 3. mota eta 6. mota',
    '👨🏽‍🤝‍👨🏻' => 'bi gizon elkarri eskua ematen: bitarteko azal-tonua eta 1–2. mota',
    '👨🏽‍🤝‍👨🏼' => 'bi gizon elkarri eskua ematen: bitarteko azal-tonua eta 3. mota',
    '👨🏽‍🤝‍👨🏾' => 'bi gizon elkarri eskua ematen: bitarteko azal-tonua eta 5. mota',
    '👨🏽‍🤝‍👨🏿' => 'bi gizon elkarri eskua ematen: bitarteko azal-tonua eta 6. mota',
    '👨🏾‍🤝‍👨🏻' => 'bi gizon elkarri eskua ematen: 5. mota eta 1–2. mota',
    '👨🏾‍🤝‍👨🏼' => 'bi gizon elkarri eskua ematen: 5. mota eta 3. mota',
    '👨🏾‍🤝‍👨🏽' => 'bi gizon elkarri eskua ematen: 5. mota eta bitarteko azal-tonua',
    '👨🏾‍🤝‍👨🏿' => 'bi gizon elkarri eskua ematen: 5. mota eta 6. mota',
    '👨🏿‍🤝‍👨🏻' => 'bi gizon elkarri eskua ematen: 6. mota eta 1–2. mota',
    '👨🏿‍🤝‍👨🏼' => 'bi gizon elkarri eskua ematen: 6. mota eta 3. mota',
    '👨🏿‍🤝‍👨🏽' => 'bi gizon elkarri eskua ematen: 6. mota eta bitarteko azal-tonua',
    '👨🏿‍🤝‍👨🏾' => 'bi gizon elkarri eskua ematen: 6. mota eta 5. mota',
    '👩‍❤‍💋‍👨' => 'musu: emakumea eta gizona',
    '👨‍❤‍💋‍👨' => 'musu: gizona eta gizona',
    '👩‍❤‍💋‍👩' => 'musu: emakumea eta emakumea',
    '👨‍👩‍👧‍👦' => 'familia: gizona, emakumea, neska eta mutila',
    '👨‍👩‍👦‍👦' => 'familia: gizona, emakumea, mutila eta mutila',
    '👨‍👩‍👧‍👧' => 'familia: gizona, emakumea, neska eta neska',
    '👨‍👨‍👧‍👦' => 'familia: gizona, gizona, neska eta mutila',
    '👨‍👨‍👦‍👦' => 'familia: gizona, gizona, mutila eta mutila',
    '👨‍👨‍👧‍👧' => 'familia: gizona, gizona, neska eta neska',
    '👩‍👩‍👧‍👦' => 'familia: emakumea, emakumea, neska eta mutila',
    '👩‍👩‍👦‍👦' => 'familia: emakumea, emakumea, mutila eta mutila',
    '👩‍👩‍👧‍👧' => 'familia: emakumea, emakumea, neska eta neska',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'Bandera: Ingalaterra',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'Bandera: Eskozia',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'Bandera: Gales',
    '🧑‍🧑‍🧒‍🧒' => 'familia: nagusia, nagusia, haurra, haurra',
    '🚶🏻‍♀‍➡' => 'oinez ari den emakumea: 1–2. mota eta eskuinera begira',
    '🚶🏼‍♀‍➡' => 'oinez ari den emakumea: 3. mota eta eskuinera begira',
    '🚶🏽‍♀‍➡' => 'oinez ari den emakumea: bitarteko azal-tonua eta eskuinera begira',
    '🚶🏾‍♀‍➡' => 'oinez ari den emakumea: 5. mota eta eskuinera begira',
    '🚶🏿‍♀‍➡' => 'oinez ari den emakumea: 6. mota eta eskuinera begira',
    '🚶🏻‍♂‍➡' => 'oinez ari den gizona: 1–2. mota eta eskuinera begira',
    '🚶🏼‍♂‍➡' => 'oinez ari den gizona: 3. mota eta eskuinera begira',
    '🚶🏽‍♂‍➡' => 'oinez ari den gizona: bitarteko azal-tonua eta eskuinera begira',
    '🚶🏾‍♂‍➡' => 'oinez ari den gizona: 5. mota eta eskuinera begira',
    '🚶🏿‍♂‍➡' => 'oinez ari den gizona: 6. mota eta eskuinera begira',
    '🧎🏻‍♀‍➡' => 'belauniko dagoen emakumea: 1–2. mota eta eskuinera begira',
    '🧎🏼‍♀‍➡' => 'belauniko dagoen emakumea: 3. mota eta eskuinera begira',
    '🧎🏽‍♀‍➡' => 'belauniko dagoen emakumea: bitarteko azal-tonua eta eskuinera begira',
    '🧎🏾‍♀‍➡' => 'belauniko dagoen emakumea: 5. mota eta eskuinera begira',
    '🧎🏿‍♀‍➡' => 'belauniko dagoen emakumea: 6. mota eta eskuinera begira',
    '🧎🏻‍♂‍➡' => 'belauniko dagoen gizona: 1–2. mota eta eskuinera begira',
    '🧎🏼‍♂‍➡' => 'belauniko dagoen gizona: 3. mota eta eskuinera begira',
    '🧎🏽‍♂‍➡' => 'belauniko dagoen gizona: bitarteko azal-tonua eta eskuinera begira',
    '🧎🏾‍♂‍➡' => 'belauniko dagoen gizona: 5. mota eta eskuinera begira',
    '🧎🏿‍♂‍➡' => 'belauniko dagoen gizona: 6. mota eta eskuinera begira',
    '🧑🏻‍🦯‍➡' => 'itsu-makila daraman pertsona: 1–2. mota eta eskuinera begira',
    '🧑🏼‍🦯‍➡' => 'itsu-makila daraman pertsona: 3. mota eta eskuinera begira',
    '🧑🏽‍🦯‍➡' => 'itsu-makila daraman pertsona: bitarteko azal-tonua eta eskuinera begira',
    '🧑🏾‍🦯‍➡' => 'itsu-makila daraman pertsona: 5. mota eta eskuinera begira',
    '🧑🏿‍🦯‍➡' => 'itsu-makila daraman pertsona: 6. mota eta eskuinera begira',
    '👨🏻‍🦯‍➡' => 'itsu-makila daraman gizona: 1–2. mota eta eskuinera begira',
    '👨🏼‍🦯‍➡' => 'itsu-makila daraman gizona: 3. mota eta eskuinera begira',
    '👨🏽‍🦯‍➡' => 'itsu-makila daraman gizona: bitarteko azal-tonua eta eskuinera begira',
    '👨🏾‍🦯‍➡' => 'itsu-makila daraman gizona: 5. mota eta eskuinera begira',
    '👨🏿‍🦯‍➡' => 'itsu-makila daraman gizona: 6. mota eta eskuinera begira',
    '👩🏻‍🦯‍➡' => 'itsu-makila daraman emakumea: 1–2. mota eta eskuinera begira',
    '👩🏼‍🦯‍➡' => 'itsu-makila daraman emakumea: 3. mota eta eskuinera begira',
    '👩🏽‍🦯‍➡' => 'itsu-makila daraman emakumea: bitarteko azal-tonua eta eskuinera begira',
    '👩🏾‍🦯‍➡' => 'itsu-makila daraman emakumea: 5. mota eta eskuinera begira',
    '👩🏿‍🦯‍➡' => 'itsu-makila daraman emakumea: 6. mota eta eskuinera begira',
    '🧑🏻‍🦼‍➡' => 'gurpil-aulki motordunean doan pertsona: 1–2. mota eta eskuinera begira',
    '🧑🏼‍🦼‍➡' => 'gurpil-aulki motordunean doan pertsona: 3. mota eta eskuinera begira',
    '🧑🏽‍🦼‍➡' => 'gurpil-aulki motordunean doan pertsona: bitarteko azal-tonua eta eskuinera begira',
    '🧑🏾‍🦼‍➡' => 'gurpil-aulki motordunean doan pertsona: 5. mota eta eskuinera begira',
    '🧑🏿‍🦼‍➡' => 'gurpil-aulki motordunean doan pertsona: 6. mota eta eskuinera begira',
    '👨🏻‍🦼‍➡' => 'gurpil-aulki motordunean doan gizona: 1–2. mota eta eskuinera begira',
    '👨🏼‍🦼‍➡' => 'gurpil-aulki motordunean doan gizona: 3. mota eta eskuinera begira',
    '👨🏽‍🦼‍➡' => 'gurpil-aulki motordunean doan gizona: bitarteko azal-tonua eta eskuinera begira',
    '👨🏾‍🦼‍➡' => 'gurpil-aulki motordunean doan gizona: 5. mota eta eskuinera begira',
    '👨🏿‍🦼‍➡' => 'gurpil-aulki motordunean doan gizona: 6. mota eta eskuinera begira',
    '👩🏻‍🦼‍➡' => 'gurpil-aulki motordunean doan emakumea: 1–2. mota eta eskuinera begira',
    '👩🏼‍🦼‍➡' => 'gurpil-aulki motordunean doan emakumea: 3. mota eta eskuinera begira',
    '👩🏽‍🦼‍➡' => 'gurpil-aulki motordunean doan emakumea: bitarteko azal-tonua eta eskuinera begira',
    '👩🏾‍🦼‍➡' => 'gurpil-aulki motordunean doan emakumea: 5. mota eta eskuinera begira',
    '👩🏿‍🦼‍➡' => 'gurpil-aulki motordunean doan emakumea: 6. mota eta eskuinera begira',
    '🧑🏻‍🦽‍➡' => 'eskuzko gurpil-aulkian doan pertsona: 1–2. mota eta eskuinera begira',
    '🧑🏼‍🦽‍➡' => 'eskuzko gurpil-aulkian doan pertsona: 3. mota eta eskuinera begira',
    '🧑🏽‍🦽‍➡' => 'eskuzko gurpil-aulkian doan pertsona: bitarteko azal-tonua eta eskuinera begira',
    '🧑🏾‍🦽‍➡' => 'eskuzko gurpil-aulkian doan pertsona: 5. mota eta eskuinera begira',
    '🧑🏿‍🦽‍➡' => 'eskuzko gurpil-aulkian doan pertsona: 6. mota eta eskuinera begira',
    '👨🏻‍🦽‍➡' => 'eskuzko gurpil-aulkian doan gizona: 1–2. mota eta eskuinera begira',
    '👨🏼‍🦽‍➡' => 'eskuzko gurpil-aulkian doan gizona: 3. mota eta eskuinera begira',
    '👨🏽‍🦽‍➡' => 'eskuzko gurpil-aulkian doan gizona: bitarteko azal-tonua eta eskuinera begira',
    '👨🏾‍🦽‍➡' => 'eskuzko gurpil-aulkian doan gizona: 5. mota eta eskuinera begira',
    '👨🏿‍🦽‍➡' => 'eskuzko gurpil-aulkian doan gizona: 6. mota eta eskuinera begira',
    '👩🏻‍🦽‍➡' => 'eskuzko gurpil-aulkian doan emakumea: 1–2. mota eta eskuinera begira',
    '👩🏼‍🦽‍➡' => 'eskuzko gurpil-aulkian doan emakumea: 3. mota eta eskuinera begira',
    '👩🏽‍🦽‍➡' => 'eskuzko gurpil-aulkian doan emakumea: bitarteko azal-tonua eta eskuinera begira',
    '👩🏾‍🦽‍➡' => 'eskuzko gurpil-aulkian doan emakumea: 5. mota eta eskuinera begira',
    '👩🏿‍🦽‍➡' => 'eskuzko gurpil-aulkian doan emakumea: 6. mota eta eskuinera begira',
    '🏃🏻‍♀‍➡' => 'korrika ari den emakumea: 1–2. mota eta eskuinera begira',
    '🏃🏼‍♀‍➡' => 'korrika ari den emakumea: 3. mota eta eskuinera begira',
    '🏃🏽‍♀‍➡' => 'korrika ari den emakumea: bitarteko azal-tonua eta eskuinera begira',
    '🏃🏾‍♀‍➡' => 'korrika ari den emakumea: 5. mota eta eskuinera begira',
    '🏃🏿‍♀‍➡' => 'korrika ari den emakumea: 6. mota eta eskuinera begira',
    '🏃🏻‍♂‍➡' => 'korrika ari den gizona: 1–2. mota eta eskuinera begira',
    '🏃🏼‍♂‍➡' => 'korrika ari den gizona: 3. mota eta eskuinera begira',
    '🏃🏽‍♂‍➡' => 'korrika ari den gizona: bitarteko azal-tonua eta eskuinera begira',
    '🏃🏾‍♂‍➡' => 'korrika ari den gizona: 5. mota eta eskuinera begira',
    '🏃🏿‍♂‍➡' => 'korrika ari den gizona: 6. mota eta eskuinera begira',
    '🫱🏻‍🫲🏼' => 'esku-ematea: 1–2. mota eta 3. mota',
    '🫱🏻‍🫲🏽' => 'esku-ematea: 1–2. mota eta bitarteko azal-tonua',
    '🫱🏻‍🫲🏾' => 'esku-ematea: 1–2. mota eta 5. mota',
    '🫱🏻‍🫲🏿' => 'esku-ematea: 1–2. mota eta 6. mota',
    '🫱🏼‍🫲🏻' => 'esku-ematea: 3. mota eta 1–2. mota',
    '🫱🏼‍🫲🏽' => 'esku-ematea: 3. mota eta bitarteko azal-tonua',
    '🫱🏼‍🫲🏾' => 'esku-ematea: 3. mota eta 5. mota',
    '🫱🏼‍🫲🏿' => 'esku-ematea: 3. mota eta 6. mota',
    '🫱🏽‍🫲🏻' => 'esku-ematea: bitarteko azal-tonua eta 1–2. mota',
    '🫱🏽‍🫲🏼' => 'esku-ematea: bitarteko azal-tonua eta 3. mota',
    '🫱🏽‍🫲🏾' => 'esku-ematea: bitarteko azal-tonua eta 5. mota',
    '🫱🏽‍🫲🏿' => 'esku-ematea: bitarteko azal-tonua eta 6. mota',
    '🫱🏾‍🫲🏻' => 'esku-ematea: 5. mota eta 1–2. mota',
    '🫱🏾‍🫲🏼' => 'esku-ematea: 5. mota eta 3. mota',
    '🫱🏾‍🫲🏽' => 'esku-ematea: 5. mota eta bitarteko azal-tonua',
    '🫱🏾‍🫲🏿' => 'esku-ematea: 5. mota eta 6. mota',
    '🫱🏿‍🫲🏻' => 'esku-ematea: 6. mota eta 1–2. mota',
    '🫱🏿‍🫲🏼' => 'esku-ematea: 6. mota eta 3. mota',
    '🫱🏿‍🫲🏽' => 'esku-ematea: 6. mota eta bitarteko azal-tonua',
    '🫱🏿‍🫲🏾' => 'esku-ematea: 6. mota eta 5. mota',
    '🚶‍♀‍➡' => 'oinez ari den emakumea: eskuinera begira',
    '🚶‍♂‍➡' => 'oinez ari den gizona: eskuinera begira',
    '🧎‍♀‍➡' => 'belauniko dagoen emakumea: eskuinera begira',
    '🧎‍♂‍➡' => 'belauniko dagoen gizona: eskuinera begira',
    '🧑‍🦯‍➡' => 'itsu-makila daraman pertsona: eskuinera begira',
    '👨‍🦯‍➡' => 'itsu-makila daraman gizona: eskuinera begira',
    '👩‍🦯‍➡' => 'itsu-makila daraman emakumea: eskuinera begira',
    '🧑‍🦼‍➡' => 'gurpil-aulki motordunean doan pertsona: eskuinera begira',
    '👨‍🦼‍➡' => 'gurpil-aulki motordunean doan gizona: eskuinera begira',
    '👩‍🦼‍➡' => 'gurpil-aulki motordunean doan emakumea: eskuinera begira',
    '🧑‍🦽‍➡' => 'eskuzko gurpil-aulkian doan pertsona: eskuinera begira',
    '👨‍🦽‍➡' => 'eskuzko gurpil-aulkian doan gizona: eskuinera begira',
    '👩‍🦽‍➡' => 'eskuzko gurpil-aulkian doan emakumea: eskuinera begira',
    '🏃‍♀‍➡' => 'korrika ari den emakumea: eskuinera begira',
    '🏃‍♂‍➡' => 'korrika ari den gizona: eskuinera begira',
    '👩‍❤‍👨' => 'bihotza erdian duen bikotea: emakumea eta gizona',
    '👨‍❤‍👨' => 'bihotza erdian duen bikotea: gizona eta gizona',
    '👩‍❤‍👩' => 'bihotza erdian duen bikotea: emakumea eta emakumea',
    '👨‍👩‍👦' => 'familia: gizona, emakumea eta mutila',
    '👨‍👩‍👧' => 'familia: gizona, emakumea eta neska',
    '👨‍👨‍👦' => 'familia: gizona, gizona eta mutila',
    '👨‍👨‍👧' => 'familia: gizona, gizona eta neska',
    '👩‍👩‍👦' => 'familia: emakumea, emakumea eta mutila',
    '👩‍👩‍👧' => 'familia: emakumea, emakumea eta neska',
    '👨‍👦‍👦' => 'familia: gizona, mutila eta mutila',
    '👨‍👧‍👦' => 'familia: gizona, neska eta mutila',
    '👨‍👧‍👧' => 'familia: gizona, neska eta neska',
    '👩‍👦‍👦' => 'familia: emakumea, mutila eta mutila',
    '👩‍👧‍👦' => 'familia: emakumea, neska eta mutila',
    '👩‍👧‍👧' => 'familia: emakumea, neska eta neska',
    '🧑‍🤝‍🧑' => 'bi pertsona elkarri eskua ematen',
    '🧑‍🧑‍🧒' => 'familia: nagusia, nagusia, haurra',
    '🧑‍🧒‍🧒' => 'familia: nagusia, haurra, haurra',
    '🧑🏻‍🦰' => 'pertsona: 1–2. mota eta ilegorri',
    '🧑🏼‍🦰' => 'pertsona: 3. mota eta ilegorri',
    '🧑🏽‍🦰' => 'pertsona: bitarteko azal-tonua eta ilegorri',
    '🧑🏾‍🦰' => 'pertsona: 5. mota eta ilegorri',
    '🧑🏿‍🦰' => 'pertsona: 6. mota eta ilegorri',
    '🧑🏻‍🦱' => 'pertsona: 1–2. mota eta ile kizkur',
    '🧑🏼‍🦱' => 'pertsona: 3. mota eta ile kizkur',
    '🧑🏽‍🦱' => 'pertsona: bitarteko azal-tonua eta ile kizkur',
    '🧑🏾‍🦱' => 'pertsona: 5. mota eta ile kizkur',
    '🧑🏿‍🦱' => 'pertsona: 6. mota eta ile kizkur',
    '🧑🏻‍🦳' => 'pertsona: 1–2. mota eta ilezuri',
    '🧑🏼‍🦳' => 'pertsona: 3. mota eta ilezuri',
    '🧑🏽‍🦳' => 'pertsona: bitarteko azal-tonua eta ilezuri',
    '🧑🏾‍🦳' => 'pertsona: 5. mota eta ilezuri',
    '🧑🏿‍🦳' => 'pertsona: 6. mota eta ilezuri',
    '🧑🏻‍🦲' => 'pertsona: 1–2. mota eta burusoil',
    '🧑🏼‍🦲' => 'pertsona: 3. mota eta burusoil',
    '🧑🏽‍🦲' => 'pertsona: bitarteko azal-tonua eta burusoil',
    '🧑🏾‍🦲' => 'pertsona: 5. mota eta burusoil',
    '🧑🏿‍🦲' => 'pertsona: 6. mota eta burusoil',
    '🧑🏻‍🩰' => 'ballet-dantzaria: 1–2. mota',
    '🧑🏼‍🩰' => 'ballet-dantzaria: 3. mota',
    '🧑🏽‍🩰' => 'ballet-dantzaria: bitarteko azal-tonua',
    '🧑🏾‍🩰' => 'ballet-dantzaria: 5. mota',
    '🧑🏿‍🩰' => 'ballet-dantzaria: 6. mota',
    '🧔🏻‍♂' => 'gizona: 1–2. mota eta bizarra',
    '🧔🏼‍♂' => 'gizona: 3. mota eta bizarra',
    '🧔🏽‍♂' => 'gizona: bitarteko azal-tonua eta bizarra',
    '🧔🏾‍♂' => 'gizona: 5. mota eta bizarra',
    '🧔🏿‍♂' => 'gizona: 6. mota eta bizarra',
    '👱🏻‍♂' => 'gizon ilehoria: 1–2. mota',
    '👱🏼‍♂' => 'gizon ilehoria: 3. mota',
    '👱🏽‍♂' => 'gizon ilehoria: bitarteko azal-tonua',
    '👱🏾‍♂' => 'gizon ilehoria: 5. mota',
    '👱🏿‍♂' => 'gizon ilehoria: 6. mota',
    '👨🏻‍🦰' => 'gizona: 1–2. mota eta ilegorri',
    '👨🏼‍🦰' => 'gizona: 3. mota eta ilegorri',
    '👨🏽‍🦰' => 'gizona: bitarteko azal-tonua eta ilegorri',
    '👨🏾‍🦰' => 'gizona: 5. mota eta ilegorri',
    '👨🏿‍🦰' => 'gizona: 6. mota eta ilegorri',
    '👨🏻‍🦱' => 'gizona: 1–2. mota eta ile kizkur',
    '👨🏼‍🦱' => 'gizona: 3. mota eta ile kizkur',
    '👨🏽‍🦱' => 'gizona: bitarteko azal-tonua eta ile kizkur',
    '👨🏾‍🦱' => 'gizona: 5. mota eta ile kizkur',
    '👨🏿‍🦱' => 'gizona: 6. mota eta ile kizkur',
    '👨🏻‍🦳' => 'gizona: 1–2. mota eta ilezuri',
    '👨🏼‍🦳' => 'gizona: 3. mota eta ilezuri',
    '👨🏽‍🦳' => 'gizona: bitarteko azal-tonua eta ilezuri',
    '👨🏾‍🦳' => 'gizona: 5. mota eta ilezuri',
    '👨🏿‍🦳' => 'gizona: 6. mota eta ilezuri',
    '👨🏻‍🦲' => 'gizona: 1–2. mota eta burusoil',
    '👨🏼‍🦲' => 'gizona: 3. mota eta burusoil',
    '👨🏽‍🦲' => 'gizona: bitarteko azal-tonua eta burusoil',
    '👨🏾‍🦲' => 'gizona: 5. mota eta burusoil',
    '👨🏿‍🦲' => 'gizona: 6. mota eta burusoil',
    '🧔🏻‍♀' => 'emakumea: 1–2. mota eta bizarra',
    '🧔🏼‍♀' => 'emakumea: 3. mota eta bizarra',
    '🧔🏽‍♀' => 'emakumea: bitarteko azal-tonua eta bizarra',
    '🧔🏾‍♀' => 'emakumea: 5. mota eta bizarra',
    '🧔🏿‍♀' => 'emakumea: 6. mota eta bizarra',
    '👱🏻‍♀' => 'emakume ilehoria: 1–2. mota',
    '👱🏼‍♀' => 'emakume ilehoria: 3. mota',
    '👱🏽‍♀' => 'emakume ilehoria: bitarteko azal-tonua',
    '👱🏾‍♀' => 'emakume ilehoria: 5. mota',
    '👱🏿‍♀' => 'emakume ilehoria: 6. mota',
    '👩🏻‍🦰' => 'emakumea: 1–2. mota eta ilegorri',
    '👩🏼‍🦰' => 'emakumea: 3. mota eta ilegorri',
    '👩🏽‍🦰' => 'emakumea: bitarteko azal-tonua eta ilegorri',
    '👩🏾‍🦰' => 'emakumea: 5. mota eta ilegorri',
    '👩🏿‍🦰' => 'emakumea: 6. mota eta ilegorri',
    '👩🏻‍🦱' => 'emakumea: 1–2. mota eta ile kizkur',
    '👩🏼‍🦱' => 'emakumea: 3. mota eta ile kizkur',
    '👩🏽‍🦱' => 'emakumea: bitarteko azal-tonua eta ile kizkur',
    '👩🏾‍🦱' => 'emakumea: 5. mota eta ile kizkur',
    '👩🏿‍🦱' => 'emakumea: 6. mota eta ile kizkur',
    '👩🏻‍🦳' => 'emakumea: 1–2. mota eta ilezuri',
    '👩🏼‍🦳' => 'emakumea: 3. mota eta ilezuri',
    '👩🏽‍🦳' => 'emakumea: bitarteko azal-tonua eta ilezuri',
    '👩🏾‍🦳' => 'emakumea: 5. mota eta ilezuri',
    '👩🏿‍🦳' => 'emakumea: 6. mota eta ilezuri',
    '👩🏻‍🦲' => 'emakumea: 1–2. mota eta burusoil',
    '👩🏼‍🦲' => 'emakumea: 3. mota eta burusoil',
    '👩🏽‍🦲' => 'emakumea: bitarteko azal-tonua eta burusoil',
    '👩🏾‍🦲' => 'emakumea: 5. mota eta burusoil',
    '👩🏿‍🦲' => 'emakumea: 6. mota eta burusoil',
    '🙍🏻‍♂' => 'kopeta zimurtzen ari den gizona: 1–2. mota',
    '🙍🏼‍♂' => 'kopeta zimurtzen ari den gizona: 3. mota',
    '🙍🏽‍♂' => 'kopeta zimurtzen ari den gizona: bitarteko azal-tonua',
    '🙍🏾‍♂' => 'kopeta zimurtzen ari den gizona: 5. mota',
    '🙍🏿‍♂' => 'kopeta zimurtzen ari den gizona: 6. mota',
    '🙍🏻‍♀' => 'kopeta zimurtzen ari den emakumea: 1–2. mota',
    '🙍🏼‍♀' => 'kopeta zimurtzen ari den emakumea: 3. mota',
    '🙍🏽‍♀' => 'kopeta zimurtzen ari den emakumea: bitarteko azal-tonua',
    '🙍🏾‍♀' => 'kopeta zimurtzen ari den emakumea: 5. mota',
    '🙍🏿‍♀' => 'kopeta zimurtzen ari den emakumea: 6. mota',
    '🙎🏻‍♂' => 'gizon muturtua: 1–2. mota',
    '🙎🏼‍♂' => 'gizon muturtua: 3. mota',
    '🙎🏽‍♂' => 'gizon muturtua: bitarteko azal-tonua',
    '🙎🏾‍♂' => 'gizon muturtua: 5. mota',
    '🙎🏿‍♂' => 'gizon muturtua: 6. mota',
    '🙎🏻‍♀' => 'emakume muturtua: 1–2. mota',
    '🙎🏼‍♀' => 'emakume muturtua: 3. mota',
    '🙎🏽‍♀' => 'emakume muturtua: bitarteko azal-tonua',
    '🙎🏾‍♀' => 'emakume muturtua: 5. mota',
    '🙎🏿‍♀' => 'emakume muturtua: 6. mota',
    '🙅🏻‍♂' => 'ados ez dagoela adierazten ari den gizona: 1–2. mota',
    '🙅🏼‍♂' => 'ados ez dagoela adierazten ari den gizona: 3. mota',
    '🙅🏽‍♂' => 'ados ez dagoela adierazten ari den gizona: bitarteko azal-tonua',
    '🙅🏾‍♂' => 'ados ez dagoela adierazten ari den gizona: 5. mota',
    '🙅🏿‍♂' => 'ados ez dagoela adierazten ari den gizona: 6. mota',
    '🙅🏻‍♀' => 'ezezko keinua egiten ari den emakumea: 1–2. mota',
    '🙅🏼‍♀' => 'ezezko keinua egiten ari den emakumea: 3. mota',
    '🙅🏽‍♀' => 'ezezko keinua egiten ari den emakumea: bitarteko azal-tonua',
    '🙅🏾‍♀' => 'ezezko keinua egiten ari den emakumea: 5. mota',
    '🙅🏿‍♀' => 'ezezko keinua egiten ari den emakumea: 6. mota',
    '🙆🏻‍♂' => 'ados dagoela adierazten ari den gizona: 1–2. mota',
    '🙆🏼‍♂' => 'ados dagoela adierazten ari den gizona: 3. mota',
    '🙆🏽‍♂' => 'ados dagoela adierazten ari den gizona: bitarteko azal-tonua',
    '🙆🏾‍♂' => 'ados dagoela adierazten ari den gizona: 5. mota',
    '🙆🏿‍♂' => 'ados dagoela adierazten ari den gizona: 6. mota',
    '🙆🏻‍♀' => 'ados dagoela adierazten ari den emakumea: 1–2. mota',
    '🙆🏼‍♀' => 'ados dagoela adierazten ari den emakumea: 3. mota',
    '🙆🏽‍♀' => 'ados dagoela adierazten ari den emakumea: bitarteko azal-tonua',
    '🙆🏾‍♀' => 'ados dagoela adierazten ari den emakumea: 5. mota',
    '🙆🏿‍♀' => 'ados dagoela adierazten ari den emakumea: 6. mota',
    '💁🏻‍♂' => 'eskean dabilen gizona: 1–2. mota',
    '💁🏼‍♂' => 'eskean dabilen gizona: 3. mota',
    '💁🏽‍♂' => 'eskean dabilen gizona: bitarteko azal-tonua',
    '💁🏾‍♂' => 'eskean dabilen gizona: 5. mota',
    '💁🏿‍♂' => 'eskean dabilen gizona: 6. mota',
    '💁🏻‍♀' => 'eskean dabilen emakumea: 1–2. mota',
    '💁🏼‍♀' => 'eskean dabilen emakumea: 3. mota',
    '💁🏽‍♀' => 'eskean dabilen emakumea: bitarteko azal-tonua',
    '💁🏾‍♀' => 'eskean dabilen emakumea: 5. mota',
    '💁🏿‍♀' => 'eskean dabilen emakumea: 6. mota',
    '🙋🏻‍♂' => 'eskua altxatzen ari den gizona: 1–2. mota',
    '🙋🏼‍♂' => 'eskua altxatzen ari den gizona: 3. mota',
    '🙋🏽‍♂' => 'eskua altxatzen ari den gizona: bitarteko azal-tonua',
    '🙋🏾‍♂' => 'eskua altxatzen ari den gizona: 5. mota',
    '🙋🏿‍♂' => 'eskua altxatzen ari den gizona: 6. mota',
    '🙋🏻‍♀' => 'eskua altxatzen ari den emakumea: 1–2. mota',
    '🙋🏼‍♀' => 'eskua altxatzen ari den emakumea: 3. mota',
    '🙋🏽‍♀' => 'eskua altxatzen ari den emakumea: bitarteko azal-tonua',
    '🙋🏾‍♀' => 'eskua altxatzen ari den emakumea: 5. mota',
    '🙋🏿‍♀' => 'eskua altxatzen ari den emakumea: 6. mota',
    '🧏🏻‍♂' => 'gizon gorra: 1–2. mota',
    '🧏🏼‍♂' => 'gizon gorra: 3. mota',
    '🧏🏽‍♂' => 'gizon gorra: bitarteko azal-tonua',
    '🧏🏾‍♂' => 'gizon gorra: 5. mota',
    '🧏🏿‍♂' => 'gizon gorra: 6. mota',
    '🧏🏻‍♀' => 'emakume gorra: 1–2. mota',
    '🧏🏼‍♀' => 'emakume gorra: 3. mota',
    '🧏🏽‍♀' => 'emakume gorra: bitarteko azal-tonua',
    '🧏🏾‍♀' => 'emakume gorra: 5. mota',
    '🧏🏿‍♀' => 'emakume gorra: 6. mota',
    '🙇🏻‍♂' => 'burua makurtzen ari den gizona: 1–2. mota',
    '🙇🏼‍♂' => 'burua makurtzen ari den gizona: 3. mota',
    '🙇🏽‍♂' => 'burua makurtzen ari den gizona: bitarteko azal-tonua',
    '🙇🏾‍♂' => 'burua makurtzen ari den gizona: 5. mota',
    '🙇🏿‍♂' => 'burua makurtzen ari den gizona: 6. mota',
    '🙇🏻‍♀' => 'burua makurtzen ari den emakumea: 1–2. mota',
    '🙇🏼‍♀' => 'burua makurtzen ari den emakumea: 3. mota',
    '🙇🏽‍♀' => 'burua makurtzen ari den emakumea: bitarteko azal-tonua',
    '🙇🏾‍♀' => 'burua makurtzen ari den emakumea: 5. mota',
    '🙇🏿‍♀' => 'burua makurtzen ari den emakumea: 6. mota',
    '🤦🏻‍♂' => 'esku-azpia aurpegian duen gizona: 1–2. mota',
    '🤦🏼‍♂' => 'esku-azpia aurpegian duen gizona: 3. mota',
    '🤦🏽‍♂' => 'esku-azpia aurpegian duen gizona: bitarteko azal-tonua',
    '🤦🏾‍♂' => 'esku-azpia aurpegian duen gizona: 5. mota',
    '🤦🏿‍♂' => 'esku-azpia aurpegian duen gizona: 6. mota',
    '🤦🏻‍♀' => 'esku-azpia aurpegian duen emakumea: 1–2. mota',
    '🤦🏼‍♀' => 'esku-azpia aurpegian duen emakumea: 3. mota',
    '🤦🏽‍♀' => 'esku-azpia aurpegian duen emakumea: bitarteko azal-tonua',
    '🤦🏾‍♀' => 'esku-azpia aurpegian duen emakumea: 5. mota',
    '🤦🏿‍♀' => 'esku-azpia aurpegian duen emakumea: 6. mota',
    '🤷🏻‍♂' => 'sorbaldak altxatzen ari den gizona: 1–2. mota',
    '🤷🏼‍♂' => 'sorbaldak altxatzen ari den gizona: 3. mota',
    '🤷🏽‍♂' => 'sorbaldak altxatzen ari den gizona: bitarteko azal-tonua',
    '🤷🏾‍♂' => 'sorbaldak altxatzen ari den gizona: 5. mota',
    '🤷🏿‍♂' => 'sorbaldak altxatzen ari den gizona: 6. mota',
    '🤷🏻‍♀' => 'sorbaldak altxatzen ari den emakumea: 1–2. mota',
    '🤷🏼‍♀' => 'sorbaldak altxatzen ari den emakumea: 3. mota',
    '🤷🏽‍♀' => 'sorbaldak altxatzen ari den emakumea: bitarteko azal-tonua',
    '🤷🏾‍♀' => 'sorbaldak altxatzen ari den emakumea: 5. mota',
    '🤷🏿‍♀' => 'sorbaldak altxatzen ari den emakumea: 6. mota',
    '🧑🏻‍⚕' => 'sendagilea: 1–2. mota',
    '🧑🏼‍⚕' => 'sendagilea: 3. mota',
    '🧑🏽‍⚕' => 'sendagilea: bitarteko azal-tonua',
    '🧑🏾‍⚕' => 'sendagilea: 5. mota',
    '🧑🏿‍⚕' => 'sendagilea: 6. mota',
    '👨🏻‍⚕' => 'gizon sendagilea: 1–2. mota',
    '👨🏼‍⚕' => 'gizon sendagilea: 3. mota',
    '👨🏽‍⚕' => 'gizon sendagilea: bitarteko azal-tonua',
    '👨🏾‍⚕' => 'gizon sendagilea: 5. mota',
    '👨🏿‍⚕' => 'gizon sendagilea: 6. mota',
    '👩🏻‍⚕' => 'emakume sendagilea: 1–2. mota',
    '👩🏼‍⚕' => 'emakume sendagilea: 3. mota',
    '👩🏽‍⚕' => 'emakume sendagilea: bitarteko azal-tonua',
    '👩🏾‍⚕' => 'emakume sendagilea: 5. mota',
    '👩🏿‍⚕' => 'emakume sendagilea: 6. mota',
    '🧑🏻‍🎓' => 'ikaslea: 1–2. mota',
    '🧑🏼‍🎓' => 'ikaslea: 3. mota',
    '🧑🏽‍🎓' => 'ikaslea: bitarteko azal-tonua',
    '🧑🏾‍🎓' => 'ikaslea: 5. mota',
    '🧑🏿‍🎓' => 'ikaslea: 6. mota',
    '👨🏻‍🎓' => 'mutil ikaslea: 1–2. mota',
    '👨🏼‍🎓' => 'mutil ikaslea: 3. mota',
    '👨🏽‍🎓' => 'mutil ikaslea: bitarteko azal-tonua',
    '👨🏾‍🎓' => 'mutil ikaslea: 5. mota',
    '👨🏿‍🎓' => 'mutil ikaslea: 6. mota',
    '👩🏻‍🎓' => 'neska ikaslea: 1–2. mota',
    '👩🏼‍🎓' => 'neska ikaslea: 3. mota',
    '👩🏽‍🎓' => 'neska ikaslea: bitarteko azal-tonua',
    '👩🏾‍🎓' => 'neska ikaslea: 5. mota',
    '👩🏿‍🎓' => 'neska ikaslea: 6. mota',
    '🧑🏻‍🏫' => 'irakaslea: 1–2. mota',
    '🧑🏼‍🏫' => 'irakaslea: 3. mota',
    '🧑🏽‍🏫' => 'irakaslea: bitarteko azal-tonua',
    '🧑🏾‍🏫' => 'irakaslea: 5. mota',
    '🧑🏿‍🏫' => 'irakaslea: 6. mota',
    '👨🏻‍🏫' => 'gizon irakaslea: 1–2. mota',
    '👨🏼‍🏫' => 'gizon irakaslea: 3. mota',
    '👨🏽‍🏫' => 'gizon irakaslea: bitarteko azal-tonua',
    '👨🏾‍🏫' => 'gizon irakaslea: 5. mota',
    '👨🏿‍🏫' => 'gizon irakaslea: 6. mota',
    '👩🏻‍🏫' => 'emakume irakaslea: 1–2. mota',
    '👩🏼‍🏫' => 'emakume irakaslea: 3. mota',
    '👩🏽‍🏫' => 'emakume irakaslea: bitarteko azal-tonua',
    '👩🏾‍🏫' => 'emakume irakaslea: 5. mota',
    '👩🏿‍🏫' => 'emakume irakaslea: 6. mota',
    '🧑🏻‍⚖' => 'epailea: 1–2. mota',
    '🧑🏼‍⚖' => 'epailea: 3. mota',
    '🧑🏽‍⚖' => 'epailea: bitarteko azal-tonua',
    '🧑🏾‍⚖' => 'epailea: 5. mota',
    '🧑🏿‍⚖' => 'epailea: 6. mota',
    '👨🏻‍⚖' => 'gizon epailea: 1–2. mota',
    '👨🏼‍⚖' => 'gizon epailea: 3. mota',
    '👨🏽‍⚖' => 'gizon epailea: bitarteko azal-tonua',
    '👨🏾‍⚖' => 'gizon epailea: 5. mota',
    '👨🏿‍⚖' => 'gizon epailea: 6. mota',
    '👩🏻‍⚖' => 'emakume epailea: 1–2. mota',
    '👩🏼‍⚖' => 'emakume epailea: 3. mota',
    '👩🏽‍⚖' => 'emakume epailea: bitarteko azal-tonua',
    '👩🏾‍⚖' => 'emakume epailea: 5. mota',
    '👩🏿‍⚖' => 'emakume epailea: 6. mota',
    '🧑🏻‍🌾' => 'nekazaria: 1–2. mota',
    '🧑🏼‍🌾' => 'nekazaria: 3. mota',
    '🧑🏽‍🌾' => 'nekazaria: bitarteko azal-tonua',
    '🧑🏾‍🌾' => 'nekazaria: 5. mota',
    '🧑🏿‍🌾' => 'nekazaria: 6. mota',
    '👨🏻‍🌾' => 'gizon nekazaria: 1–2. mota',
    '👨🏼‍🌾' => 'gizon nekazaria: 3. mota',
    '👨🏽‍🌾' => 'gizon nekazaria: bitarteko azal-tonua',
    '👨🏾‍🌾' => 'gizon nekazaria: 5. mota',
    '👨🏿‍🌾' => 'gizon nekazaria: 6. mota',
    '👩🏻‍🌾' => 'emakume nekazaria: 1–2. mota',
    '👩🏼‍🌾' => 'emakume nekazaria: 3. mota',
    '👩🏽‍🌾' => 'emakume nekazaria: bitarteko azal-tonua',
    '👩🏾‍🌾' => 'emakume nekazaria: 5. mota',
    '👩🏿‍🌾' => 'emakume nekazaria: 6. mota',
    '🧑🏻‍🍳' => 'sukaldaria: 1–2. mota',
    '🧑🏼‍🍳' => 'sukaldaria: 3. mota',
    '🧑🏽‍🍳' => 'sukaldaria: bitarteko azal-tonua',
    '🧑🏾‍🍳' => 'sukaldaria: 5. mota',
    '🧑🏿‍🍳' => 'sukaldaria: 6. mota',
    '👨🏻‍🍳' => 'gizon sukaldaria: 1–2. mota',
    '👨🏼‍🍳' => 'gizon sukaldaria: 3. mota',
    '👨🏽‍🍳' => 'gizon sukaldaria: bitarteko azal-tonua',
    '👨🏾‍🍳' => 'gizon sukaldaria: 5. mota',
    '👨🏿‍🍳' => 'gizon sukaldaria: 6. mota',
    '👩🏻‍🍳' => 'emakume sukaldaria: 1–2. mota',
    '👩🏼‍🍳' => 'emakume sukaldaria: 3. mota',
    '👩🏽‍🍳' => 'emakume sukaldaria: bitarteko azal-tonua',
    '👩🏾‍🍳' => 'emakume sukaldaria: 5. mota',
    '👩🏿‍🍳' => 'emakume sukaldaria: 6. mota',
    '🧑🏻‍🔧' => 'mekanikaria: 1–2. mota',
    '🧑🏼‍🔧' => 'mekanikaria: 3. mota',
    '🧑🏽‍🔧' => 'mekanikaria: bitarteko azal-tonua',
    '🧑🏾‍🔧' => 'mekanikaria: 5. mota',
    '🧑🏿‍🔧' => 'mekanikaria: 6. mota',
    '👨🏻‍🔧' => 'gizon mekanikaria: 1–2. mota',
    '👨🏼‍🔧' => 'gizon mekanikaria: 3. mota',
    '👨🏽‍🔧' => 'gizon mekanikaria: bitarteko azal-tonua',
    '👨🏾‍🔧' => 'gizon mekanikaria: 5. mota',
    '👨🏿‍🔧' => 'gizon mekanikaria: 6. mota',
    '👩🏻‍🔧' => 'emakume mekanikaria: 1–2. mota',
    '👩🏼‍🔧' => 'emakume mekanikaria: 3. mota',
    '👩🏽‍🔧' => 'emakume mekanikaria: bitarteko azal-tonua',
    '👩🏾‍🔧' => 'emakume mekanikaria: 5. mota',
    '👩🏿‍🔧' => 'emakume mekanikaria: 6. mota',
    '🧑🏻‍🏭' => 'fabrikako langilea: 1–2. mota',
    '🧑🏼‍🏭' => 'fabrikako langilea: 3. mota',
    '🧑🏽‍🏭' => 'fabrikako langilea: bitarteko azal-tonua',
    '🧑🏾‍🏭' => 'fabrikako langilea: 5. mota',
    '🧑🏿‍🏭' => 'fabrikako langilea: 6. mota',
    '👨🏻‍🏭' => 'fabrikako gizon langilea: 1–2. mota',
    '👨🏼‍🏭' => 'fabrikako gizon langilea: 3. mota',
    '👨🏽‍🏭' => 'fabrikako gizon langilea: bitarteko azal-tonua',
    '👨🏾‍🏭' => 'fabrikako gizon langilea: 5. mota',
    '👨🏿‍🏭' => 'fabrikako gizon langilea: 6. mota',
    '👩🏻‍🏭' => 'fabrikako emakume langilea: 1–2. mota',
    '👩🏼‍🏭' => 'fabrikako emakume langilea: 3. mota',
    '👩🏽‍🏭' => 'fabrikako emakume langilea: bitarteko azal-tonua',
    '👩🏾‍🏭' => 'fabrikako emakume langilea: 5. mota',
    '👩🏿‍🏭' => 'fabrikako emakume langilea: 6. mota',
    '🧑🏻‍💼' => 'bulegaria: 1–2. mota',
    '🧑🏼‍💼' => 'bulegaria: 3. mota',
    '🧑🏽‍💼' => 'bulegaria: bitarteko azal-tonua',
    '🧑🏾‍💼' => 'bulegaria: 5. mota',
    '🧑🏿‍💼' => 'bulegaria: 6. mota',
    '👨🏻‍💼' => 'gizon bulegaria: 1–2. mota',
    '👨🏼‍💼' => 'gizon bulegaria: 3. mota',
    '👨🏽‍💼' => 'gizon bulegaria: bitarteko azal-tonua',
    '👨🏾‍💼' => 'gizon bulegaria: 5. mota',
    '👨🏿‍💼' => 'gizon bulegaria: 6. mota',
    '👩🏻‍💼' => 'emakume bulegaria: 1–2. mota',
    '👩🏼‍💼' => 'emakume bulegaria: 3. mota',
    '👩🏽‍💼' => 'emakume bulegaria: bitarteko azal-tonua',
    '👩🏾‍💼' => 'emakume bulegaria: 5. mota',
    '👩🏿‍💼' => 'emakume bulegaria: 6. mota',
    '🧑🏻‍🔬' => 'zientzialaria: 1–2. mota',
    '🧑🏼‍🔬' => 'zientzialaria: 3. mota',
    '🧑🏽‍🔬' => 'zientzialaria: bitarteko azal-tonua',
    '🧑🏾‍🔬' => 'zientzialaria: 5. mota',
    '🧑🏿‍🔬' => 'zientzialaria: 6. mota',
    '👨🏻‍🔬' => 'gizon zientzialaria: 1–2. mota',
    '👨🏼‍🔬' => 'gizon zientzialaria: 3. mota',
    '👨🏽‍🔬' => 'gizon zientzialaria: bitarteko azal-tonua',
    '👨🏾‍🔬' => 'gizon zientzialaria: 5. mota',
    '👨🏿‍🔬' => 'gizon zientzialaria: 6. mota',
    '👩🏻‍🔬' => 'emakume zientzialaria: 1–2. mota',
    '👩🏼‍🔬' => 'emakume zientzialaria: 3. mota',
    '👩🏽‍🔬' => 'emakume zientzialaria: bitarteko azal-tonua',
    '👩🏾‍🔬' => 'emakume zientzialaria: 5. mota',
    '👩🏿‍🔬' => 'emakume zientzialaria: 6. mota',
    '🧑🏻‍💻' => 'teknologialaria: 1–2. mota',
    '🧑🏼‍💻' => 'teknologialaria: 3. mota',
    '🧑🏽‍💻' => 'teknologialaria: bitarteko azal-tonua',
    '🧑🏾‍💻' => 'teknologialaria: 5. mota',
    '🧑🏿‍💻' => 'teknologialaria: 6. mota',
    '👨🏻‍💻' => 'gizon teknologialaria: 1–2. mota',
    '👨🏼‍💻' => 'gizon teknologialaria: 3. mota',
    '👨🏽‍💻' => 'gizon teknologialaria: bitarteko azal-tonua',
    '👨🏾‍💻' => 'gizon teknologialaria: 5. mota',
    '👨🏿‍💻' => 'gizon teknologialaria: 6. mota',
    '👩🏻‍💻' => 'emakume teknologialaria: 1–2. mota',
    '👩🏼‍💻' => 'emakume teknologialaria: 3. mota',
    '👩🏽‍💻' => 'emakume teknologialaria: bitarteko azal-tonua',
    '👩🏾‍💻' => 'emakume teknologialaria: 5. mota',
    '👩🏿‍💻' => 'emakume teknologialaria: 6. mota',
    '🧑🏻‍🎤' => 'abeslaria: 1–2. mota',
    '🧑🏼‍🎤' => 'abeslaria: 3. mota',
    '🧑🏽‍🎤' => 'abeslaria: bitarteko azal-tonua',
    '🧑🏾‍🎤' => 'abeslaria: 5. mota',
    '🧑🏿‍🎤' => 'abeslaria: 6. mota',
    '👨🏻‍🎤' => 'gizon abeslaria: 1–2. mota',
    '👨🏼‍🎤' => 'gizon abeslaria: 3. mota',
    '👨🏽‍🎤' => 'gizon abeslaria: bitarteko azal-tonua',
    '👨🏾‍🎤' => 'gizon abeslaria: 5. mota',
    '👨🏿‍🎤' => 'gizon abeslaria: 6. mota',
    '👩🏻‍🎤' => 'emakume abeslaria: 1–2. mota',
    '👩🏼‍🎤' => 'emakume abeslaria: 3. mota',
    '👩🏽‍🎤' => 'emakume abeslaria: bitarteko azal-tonua',
    '👩🏾‍🎤' => 'emakume abeslaria: 5. mota',
    '👩🏿‍🎤' => 'emakume abeslaria: 6. mota',
    '🧑🏻‍🎨' => 'artista: 1–2. mota',
    '🧑🏼‍🎨' => 'artista: 3. mota',
    '🧑🏽‍🎨' => 'artista: bitarteko azal-tonua',
    '🧑🏾‍🎨' => 'artista: 5. mota',
    '🧑🏿‍🎨' => 'artista: 6. mota',
    '👨🏻‍🎨' => 'gizon artista: 1–2. mota',
    '👨🏼‍🎨' => 'gizon artista: 3. mota',
    '👨🏽‍🎨' => 'gizon artista: bitarteko azal-tonua',
    '👨🏾‍🎨' => 'gizon artista: 5. mota',
    '👨🏿‍🎨' => 'gizon artista: 6. mota',
    '👩🏻‍🎨' => 'emakume artista: 1–2. mota',
    '👩🏼‍🎨' => 'emakume artista: 3. mota',
    '👩🏽‍🎨' => 'emakume artista: bitarteko azal-tonua',
    '👩🏾‍🎨' => 'emakume artista: 5. mota',
    '👩🏿‍🎨' => 'emakume artista: 6. mota',
    '🧑🏻‍✈' => 'pilotua: 1–2. mota',
    '🧑🏼‍✈' => 'pilotua: 3. mota',
    '🧑🏽‍✈' => 'pilotua: bitarteko azal-tonua',
    '🧑🏾‍✈' => 'pilotua: 5. mota',
    '🧑🏿‍✈' => 'pilotua: 6. mota',
    '👨🏻‍✈' => 'gizon pilotua: 1–2. mota',
    '👨🏼‍✈' => 'gizon pilotua: 3. mota',
    '👨🏽‍✈' => 'gizon pilotua: bitarteko azal-tonua',
    '👨🏾‍✈' => 'gizon pilotua: 5. mota',
    '👨🏿‍✈' => 'gizon pilotua: 6. mota',
    '👩🏻‍✈' => 'emakume pilotua: 1–2. mota',
    '👩🏼‍✈' => 'emakume pilotua: 3. mota',
    '👩🏽‍✈' => 'emakume pilotua: bitarteko azal-tonua',
    '👩🏾‍✈' => 'emakume pilotua: 5. mota',
    '👩🏿‍✈' => 'emakume pilotua: 6. mota',
    '🧑🏻‍🚀' => 'astronauta: 1–2. mota',
    '🧑🏼‍🚀' => 'astronauta: 3. mota',
    '🧑🏽‍🚀' => 'astronauta: bitarteko azal-tonua',
    '🧑🏾‍🚀' => 'astronauta: 5. mota',
    '🧑🏿‍🚀' => 'astronauta: 6. mota',
    '👨🏻‍🚀' => 'gizon astronauta: 1–2. mota',
    '👨🏼‍🚀' => 'gizon astronauta: 3. mota',
    '👨🏽‍🚀' => 'gizon astronauta: bitarteko azal-tonua',
    '👨🏾‍🚀' => 'gizon astronauta: 5. mota',
    '👨🏿‍🚀' => 'gizon astronauta: 6. mota',
    '👩🏻‍🚀' => 'emakume astronauta: 1–2. mota',
    '👩🏼‍🚀' => 'emakume astronauta: 3. mota',
    '👩🏽‍🚀' => 'emakume astronauta: bitarteko azal-tonua',
    '👩🏾‍🚀' => 'emakume astronauta: 5. mota',
    '👩🏿‍🚀' => 'emakume astronauta: 6. mota',
    '🧑🏻‍🚒' => 'suhiltzailea: 1–2. mota',
    '🧑🏼‍🚒' => 'suhiltzailea: 3. mota',
    '🧑🏽‍🚒' => 'suhiltzailea: bitarteko azal-tonua',
    '🧑🏾‍🚒' => 'suhiltzailea: 5. mota',
    '🧑🏿‍🚒' => 'suhiltzailea: 6. mota',
    '👨🏻‍🚒' => 'gizon suhiltzailea: 1–2. mota',
    '👨🏼‍🚒' => 'gizon suhiltzailea: 3. mota',
    '👨🏽‍🚒' => 'gizon suhiltzailea: bitarteko azal-tonua',
    '👨🏾‍🚒' => 'gizon suhiltzailea: 5. mota',
    '👨🏿‍🚒' => 'gizon suhiltzailea: 6. mota',
    '👩🏻‍🚒' => 'emakume suhiltzailea: 1–2. mota',
    '👩🏼‍🚒' => 'emakume suhiltzailea: 3. mota',
    '👩🏽‍🚒' => 'emakume suhiltzailea: bitarteko azal-tonua',
    '👩🏾‍🚒' => 'emakume suhiltzailea: 5. mota',
    '👩🏿‍🚒' => 'emakume suhiltzailea: 6. mota',
    '👮🏻‍♂' => 'gizon polizia: 1–2. mota',
    '👮🏼‍♂' => 'gizon polizia: 3. mota',
    '👮🏽‍♂' => 'gizon polizia: bitarteko azal-tonua',
    '👮🏾‍♂' => 'gizon polizia: 5. mota',
    '👮🏿‍♂' => 'gizon polizia: 6. mota',
    '👮🏻‍♀' => 'emakume polizia: 1–2. mota',
    '👮🏼‍♀' => 'emakume polizia: 3. mota',
    '👮🏽‍♀' => 'emakume polizia: bitarteko azal-tonua',
    '👮🏾‍♀' => 'emakume polizia: 5. mota',
    '👮🏿‍♀' => 'emakume polizia: 6. mota',
    '🕵🏻‍♂' => 'gizon detektibea: 1–2. mota',
    '🕵🏼‍♂' => 'gizon detektibea: 3. mota',
    '🕵🏽‍♂' => 'gizon detektibea: bitarteko azal-tonua',
    '🕵🏾‍♂' => 'gizon detektibea: 5. mota',
    '🕵🏿‍♂' => 'gizon detektibea: 6. mota',
    '🕵🏻‍♀' => 'emakume detektibea: 1–2. mota',
    '🕵🏼‍♀' => 'emakume detektibea: 3. mota',
    '🕵🏽‍♀' => 'emakume detektibea: bitarteko azal-tonua',
    '🕵🏾‍♀' => 'emakume detektibea: 5. mota',
    '🕵🏿‍♀' => 'emakume detektibea: 6. mota',
    '💂🏻‍♂' => 'gizon zaindaria: 1–2. mota',
    '💂🏼‍♂' => 'gizon zaindaria: 3. mota',
    '💂🏽‍♂' => 'gizon zaindaria: bitarteko azal-tonua',
    '💂🏾‍♂' => 'gizon zaindaria: 5. mota',
    '💂🏿‍♂' => 'gizon zaindaria: 6. mota',
    '💂🏻‍♀' => 'emakume zaindaria: 1–2. mota',
    '💂🏼‍♀' => 'emakume zaindaria: 3. mota',
    '💂🏽‍♀' => 'emakume zaindaria: bitarteko azal-tonua',
    '💂🏾‍♀' => 'emakume zaindaria: 5. mota',
    '💂🏿‍♀' => 'emakume zaindaria: 6. mota',
    '👷🏻‍♂' => 'gizon eskulangilea: 1–2. mota',
    '👷🏼‍♂' => 'gizon eskulangilea: 3. mota',
    '👷🏽‍♂' => 'gizon eskulangilea: bitarteko azal-tonua',
    '👷🏾‍♂' => 'gizon eskulangilea: 5. mota',
    '👷🏿‍♂' => 'gizon eskulangilea: 6. mota',
    '👷🏻‍♀' => 'emakume eskulangilea: 1–2. mota',
    '👷🏼‍♀' => 'emakume eskulangilea: 3. mota',
    '👷🏽‍♀' => 'emakume eskulangilea: bitarteko azal-tonua',
    '👷🏾‍♀' => 'emakume eskulangilea: 5. mota',
    '👷🏿‍♀' => 'emakume eskulangilea: 6. mota',
    '👳🏻‍♂' => 'turbantea duen gizona: 1–2. mota',
    '👳🏼‍♂' => 'turbantea duen gizona: 3. mota',
    '👳🏽‍♂' => 'turbantea duen gizona: bitarteko azal-tonua',
    '👳🏾‍♂' => 'turbantea duen gizona: 5. mota',
    '👳🏿‍♂' => 'turbantea duen gizona: 6. mota',
    '👳🏻‍♀' => 'turbantea duen emakumea: 1–2. mota',
    '👳🏼‍♀' => 'turbantea duen emakumea: 3. mota',
    '👳🏽‍♀' => 'turbantea duen emakumea: bitarteko azal-tonua',
    '👳🏾‍♀' => 'turbantea duen emakumea: 5. mota',
    '👳🏿‍♀' => 'turbantea duen emakumea: 6. mota',
    '🤵🏻‍♂' => 'gizona esmokinean: 1–2. mota',
    '🤵🏼‍♂' => 'gizona esmokinean: 3. mota',
    '🤵🏽‍♂' => 'gizona esmokinean: bitarteko azal-tonua',
    '🤵🏾‍♂' => 'gizona esmokinean: 5. mota',
    '🤵🏿‍♂' => 'gizona esmokinean: 6. mota',
    '🤵🏻‍♀' => 'emakumea esmokinean: 1–2. mota',
    '🤵🏼‍♀' => 'emakumea esmokinean: 3. mota',
    '🤵🏽‍♀' => 'emakumea esmokinean: bitarteko azal-tonua',
    '🤵🏾‍♀' => 'emakumea esmokinean: 5. mota',
    '🤵🏿‍♀' => 'emakumea esmokinean: 6. mota',
    '👰🏻‍♂' => 'beloa daraman gizona: 1–2. mota',
    '👰🏼‍♂' => 'beloa daraman gizona: 3. mota',
    '👰🏽‍♂' => 'beloa daraman gizona: bitarteko azal-tonua',
    '👰🏾‍♂' => 'beloa daraman gizona: 5. mota',
    '👰🏿‍♂' => 'beloa daraman gizona: 6. mota',
    '👰🏻‍♀' => 'beloa daraman emakumea: 1–2. mota',
    '👰🏼‍♀' => 'beloa daraman emakumea: 3. mota',
    '👰🏽‍♀' => 'beloa daraman emakumea: bitarteko azal-tonua',
    '👰🏾‍♀' => 'beloa daraman emakumea: 5. mota',
    '👰🏿‍♀' => 'beloa daraman emakumea: 6. mota',
    '👩🏻‍🍼' => 'emakumea bularra ematen: 1–2. mota',
    '👩🏼‍🍼' => 'emakumea bularra ematen: 3. mota',
    '👩🏽‍🍼' => 'emakumea bularra ematen: bitarteko azal-tonua',
    '👩🏾‍🍼' => 'emakumea bularra ematen: 5. mota',
    '👩🏿‍🍼' => 'emakumea bularra ematen: 6. mota',
    '👨🏻‍🍼' => 'gizona haurrari janaria ematen: 1–2. mota',
    '👨🏼‍🍼' => 'gizona haurrari janaria ematen: 3. mota',
    '👨🏽‍🍼' => 'gizona haurrari janaria ematen: bitarteko azal-tonua',
    '👨🏾‍🍼' => 'gizona haurrari janaria ematen: 5. mota',
    '👨🏿‍🍼' => 'gizona haurrari janaria ematen: 6. mota',
    '🧑🏻‍🍼' => 'haurra elikatzen: 1–2. mota',
    '🧑🏼‍🍼' => 'haurra elikatzen: 3. mota',
    '🧑🏽‍🍼' => 'haurra elikatzen: bitarteko azal-tonua',
    '🧑🏾‍🍼' => 'haurra elikatzen: 5. mota',
    '🧑🏿‍🍼' => 'haurra elikatzen: 6. mota',
    '🧑🏻‍🎄' => 'bizarzuri: 1–2. mota',
    '🧑🏼‍🎄' => 'bizarzuri: 3. mota',
    '🧑🏽‍🎄' => 'bizarzuri: bitarteko azal-tonua',
    '🧑🏾‍🎄' => 'bizarzuri: 5. mota',
    '🧑🏿‍🎄' => 'bizarzuri: 6. mota',
    '🦸🏻‍♂' => 'gizonezko superheroi: 1–2. mota',
    '🦸🏼‍♂' => 'gizonezko superheroi: 3. mota',
    '🦸🏽‍♂' => 'gizonezko superheroi: bitarteko azal-tonua',
    '🦸🏾‍♂' => 'gizonezko superheroi: 5. mota',
    '🦸🏿‍♂' => 'gizonezko superheroi: 6. mota',
    '🦸🏻‍♀' => 'emakumezko superheroi: 1–2. mota',
    '🦸🏼‍♀' => 'emakumezko superheroi: 3. mota',
    '🦸🏽‍♀' => 'emakumezko superheroi: bitarteko azal-tonua',
    '🦸🏾‍♀' => 'emakumezko superheroi: 5. mota',
    '🦸🏿‍♀' => 'emakumezko superheroi: 6. mota',
    '🦹🏻‍♂' => 'gizonezko superbilau: 1–2. mota',
    '🦹🏼‍♂' => 'gizonezko superbilau: 3. mota',
    '🦹🏽‍♂' => 'gizonezko superbilau: bitarteko azal-tonua',
    '🦹🏾‍♂' => 'gizonezko superbilau: 5. mota',
    '🦹🏿‍♂' => 'gizonezko superbilau: 6. mota',
    '🦹🏻‍♀' => 'emakumezko superbilau: 1–2. mota',
    '🦹🏼‍♀' => 'emakumezko superbilau: 3. mota',
    '🦹🏽‍♀' => 'emakumezko superbilau: bitarteko azal-tonua',
    '🦹🏾‍♀' => 'emakumezko superbilau: 5. mota',
    '🦹🏿‍♀' => 'emakumezko superbilau: 6. mota',
    '🧙🏻‍♂' => 'gizon mago: 1–2. mota',
    '🧙🏼‍♂' => 'gizon mago: 3. mota',
    '🧙🏽‍♂' => 'gizon mago: bitarteko azal-tonua',
    '🧙🏾‍♂' => 'gizon mago: 5. mota',
    '🧙🏿‍♂' => 'gizon mago: 6. mota',
    '🧙🏻‍♀' => 'emakume mago: 1–2. mota',
    '🧙🏼‍♀' => 'emakume mago: 3. mota',
    '🧙🏽‍♀' => 'emakume mago: bitarteko azal-tonua',
    '🧙🏾‍♀' => 'emakume mago: 5. mota',
    '🧙🏿‍♀' => 'emakume mago: 6. mota',
    '🧚🏻‍♂' => '(gizon) maitagarri: 1–2. mota',
    '🧚🏼‍♂' => '(gizon) maitagarri: 3. mota',
    '🧚🏽‍♂' => '(gizon) maitagarri: bitarteko azal-tonua',
    '🧚🏾‍♂' => '(gizon) maitagarri: 5. mota',
    '🧚🏿‍♂' => '(gizon) maitagarri: 6. mota',
    '🧚🏻‍♀' => '(emakume) maitagarri: 1–2. mota',
    '🧚🏼‍♀' => '(emakume) maitagarri: 3. mota',
    '🧚🏽‍♀' => '(emakume) maitagarri: bitarteko azal-tonua',
    '🧚🏾‍♀' => '(emakume) maitagarri: 5. mota',
    '🧚🏿‍♀' => '(emakume) maitagarri: 6. mota',
    '🧛🏻‍♂' => 'gizon banpiro: 1–2. mota',
    '🧛🏼‍♂' => 'gizon banpiro: 3. mota',
    '🧛🏽‍♂' => 'gizon banpiro: bitarteko azal-tonua',
    '🧛🏾‍♂' => 'gizon banpiro: 5. mota',
    '🧛🏿‍♂' => 'gizon banpiro: 6. mota',
    '🧛🏻‍♀' => 'emakume banpiro: 1–2. mota',
    '🧛🏼‍♀' => 'emakume banpiro: 3. mota',
    '🧛🏽‍♀' => 'emakume banpiro: bitarteko azal-tonua',
    '🧛🏾‍♀' => 'emakume banpiro: 5. mota',
    '🧛🏿‍♀' => 'emakume banpiro: 6. mota',
    '🧜🏻‍♂' => 'gizon-itxurako itsas izaki: 1–2. mota',
    '🧜🏼‍♂' => 'gizon-itxurako itsas izaki: 3. mota',
    '🧜🏽‍♂' => 'gizon-itxurako itsas izaki: bitarteko azal-tonua',
    '🧜🏾‍♂' => 'gizon-itxurako itsas izaki: 5. mota',
    '🧜🏿‍♂' => 'gizon-itxurako itsas izaki: 6. mota',
    '🧜🏻‍♀' => 'lamina: 1–2. mota',
    '🧜🏼‍♀' => 'lamina: 3. mota',
    '🧜🏽‍♀' => 'lamina: bitarteko azal-tonua',
    '🧜🏾‍♀' => 'lamina: 5. mota',
    '🧜🏿‍♀' => 'lamina: 6. mota',
    '🧝🏻‍♂' => 'gizon elfo: 1–2. mota',
    '🧝🏼‍♂' => 'gizon elfo: 3. mota',
    '🧝🏽‍♂' => 'gizon elfo: bitarteko azal-tonua',
    '🧝🏾‍♂' => 'gizon elfo: 5. mota',
    '🧝🏿‍♂' => 'gizon elfo: 6. mota',
    '🧝🏻‍♀' => 'emakume elfo: 1–2. mota',
    '🧝🏼‍♀' => 'emakume elfo: 3. mota',
    '🧝🏽‍♀' => 'emakume elfo: bitarteko azal-tonua',
    '🧝🏾‍♀' => 'emakume elfo: 5. mota',
    '🧝🏿‍♀' => 'emakume elfo: 6. mota',
    '💆🏻‍♂' => 'masajea jasotzen ari den pertsona: 1–2. mota',
    '💆🏼‍♂' => 'masajea jasotzen ari den pertsona: 3. mota',
    '💆🏽‍♂' => 'masajea jasotzen ari den pertsona: bitarteko azal-tonua',
    '💆🏾‍♂' => 'masajea jasotzen ari den pertsona: 5. mota',
    '💆🏿‍♂' => 'masajea jasotzen ari den pertsona: 6. mota',
    '💆🏻‍♀' => 'masajea jasotzen ari den emakumea: 1–2. mota',
    '💆🏼‍♀' => 'masajea jasotzen ari den emakumea: 3. mota',
    '💆🏽‍♀' => 'masajea jasotzen ari den emakumea: bitarteko azal-tonua',
    '💆🏾‍♀' => 'masajea jasotzen ari den emakumea: 5. mota',
    '💆🏿‍♀' => 'masajea jasotzen ari den emakumea: 6. mota',
    '💇🏻‍♂' => 'ilea mozten ari dioten gizona: 1–2. mota',
    '💇🏼‍♂' => 'ilea mozten ari dioten gizona: 3. mota',
    '💇🏽‍♂' => 'ilea mozten ari dioten gizona: bitarteko azal-tonua',
    '💇🏾‍♂' => 'ilea mozten ari dioten gizona: 5. mota',
    '💇🏿‍♂' => 'ilea mozten ari dioten gizona: 6. mota',
    '💇🏻‍♀' => 'ilea mozten ari dioten emakumea: 1–2. mota',
    '💇🏼‍♀' => 'ilea mozten ari dioten emakumea: 3. mota',
    '💇🏽‍♀' => 'ilea mozten ari dioten emakumea: bitarteko azal-tonua',
    '💇🏾‍♀' => 'ilea mozten ari dioten emakumea: 5. mota',
    '💇🏿‍♀' => 'ilea mozten ari dioten emakumea: 6. mota',
    '🚶🏻‍♂' => 'oinez ari den gizona: 1–2. mota',
    '🚶🏼‍♂' => 'oinez ari den gizona: 3. mota',
    '🚶🏽‍♂' => 'oinez ari den gizona: bitarteko azal-tonua',
    '🚶🏾‍♂' => 'oinez ari den gizona: 5. mota',
    '🚶🏿‍♂' => 'oinez ari den gizona: 6. mota',
    '🚶🏻‍♀' => 'oinez ari den emakumea: 1–2. mota',
    '🚶🏼‍♀' => 'oinez ari den emakumea: 3. mota',
    '🚶🏽‍♀' => 'oinez ari den emakumea: bitarteko azal-tonua',
    '🚶🏾‍♀' => 'oinez ari den emakumea: 5. mota',
    '🚶🏿‍♀' => 'oinez ari den emakumea: 6. mota',
    '🚶🏻‍➡' => 'oinez ari den pertsona: 1–2. mota eta eskuinera begira',
    '🚶🏼‍➡' => 'oinez ari den pertsona: 3. mota eta eskuinera begira',
    '🚶🏽‍➡' => 'oinez ari den pertsona: bitarteko azal-tonua eta eskuinera begira',
    '🚶🏾‍➡' => 'oinez ari den pertsona: 5. mota eta eskuinera begira',
    '🚶🏿‍➡' => 'oinez ari den pertsona: 6. mota eta eskuinera begira',
    '🧍🏻‍♂' => 'zutik dagoen gizona: 1–2. mota',
    '🧍🏼‍♂' => 'zutik dagoen gizona: 3. mota',
    '🧍🏽‍♂' => 'zutik dagoen gizona: bitarteko azal-tonua',
    '🧍🏾‍♂' => 'zutik dagoen gizona: 5. mota',
    '🧍🏿‍♂' => 'zutik dagoen gizona: 6. mota',
    '🧍🏻‍♀' => 'zutik dagoen emakumea: 1–2. mota',
    '🧍🏼‍♀' => 'zutik dagoen emakumea: 3. mota',
    '🧍🏽‍♀' => 'zutik dagoen emakumea: bitarteko azal-tonua',
    '🧍🏾‍♀' => 'zutik dagoen emakumea: 5. mota',
    '🧍🏿‍♀' => 'zutik dagoen emakumea: 6. mota',
    '🧎🏻‍♂' => 'belauniko dagoen gizona: 1–2. mota',
    '🧎🏼‍♂' => 'belauniko dagoen gizona: 3. mota',
    '🧎🏽‍♂' => 'belauniko dagoen gizona: bitarteko azal-tonua',
    '🧎🏾‍♂' => 'belauniko dagoen gizona: 5. mota',
    '🧎🏿‍♂' => 'belauniko dagoen gizona: 6. mota',
    '🧎🏻‍♀' => 'belauniko dagoen emakumea: 1–2. mota',
    '🧎🏼‍♀' => 'belauniko dagoen emakumea: 3. mota',
    '🧎🏽‍♀' => 'belauniko dagoen emakumea: bitarteko azal-tonua',
    '🧎🏾‍♀' => 'belauniko dagoen emakumea: 5. mota',
    '🧎🏿‍♀' => 'belauniko dagoen emakumea: 6. mota',
    '🧎🏻‍➡' => 'belauniko dagoen pertsona: 1–2. mota eta eskuinera begira',
    '🧎🏼‍➡' => 'belauniko dagoen pertsona: 3. mota eta eskuinera begira',
    '🧎🏽‍➡' => 'belauniko dagoen pertsona: bitarteko azal-tonua eta eskuinera begira',
    '🧎🏾‍➡' => 'belauniko dagoen pertsona: 5. mota eta eskuinera begira',
    '🧎🏿‍➡' => 'belauniko dagoen pertsona: 6. mota eta eskuinera begira',
    '🧑🏻‍🦯' => 'itsu-makila daraman pertsona: 1–2. mota',
    '🧑🏼‍🦯' => 'itsu-makila daraman pertsona: 3. mota',
    '🧑🏽‍🦯' => 'itsu-makila daraman pertsona: bitarteko azal-tonua',
    '🧑🏾‍🦯' => 'itsu-makila daraman pertsona: 5. mota',
    '🧑🏿‍🦯' => 'itsu-makila daraman pertsona: 6. mota',
    '👨🏻‍🦯' => 'itsu-makila daraman gizona: 1–2. mota',
    '👨🏼‍🦯' => 'itsu-makila daraman gizona: 3. mota',
    '👨🏽‍🦯' => 'itsu-makila daraman gizona: bitarteko azal-tonua',
    '👨🏾‍🦯' => 'itsu-makila daraman gizona: 5. mota',
    '👨🏿‍🦯' => 'itsu-makila daraman gizona: 6. mota',
    '👩🏻‍🦯' => 'itsu-makila daraman emakumea: 1–2. mota',
    '👩🏼‍🦯' => 'itsu-makila daraman emakumea: 3. mota',
    '👩🏽‍🦯' => 'itsu-makila daraman emakumea: bitarteko azal-tonua',
    '👩🏾‍🦯' => 'itsu-makila daraman emakumea: 5. mota',
    '👩🏿‍🦯' => 'itsu-makila daraman emakumea: 6. mota',
    '🧑🏻‍🦼' => 'gurpil-aulki motordunean doan pertsona: 1–2. mota',
    '🧑🏼‍🦼' => 'gurpil-aulki motordunean doan pertsona: 3. mota',
    '🧑🏽‍🦼' => 'gurpil-aulki motordunean doan pertsona: bitarteko azal-tonua',
    '🧑🏾‍🦼' => 'gurpil-aulki motordunean doan pertsona: 5. mota',
    '🧑🏿‍🦼' => 'gurpil-aulki motordunean doan pertsona: 6. mota',
    '👨🏻‍🦼' => 'gurpil-aulki motordunean doan gizona: 1–2. mota',
    '👨🏼‍🦼' => 'gurpil-aulki motordunean doan gizona: 3. mota',
    '👨🏽‍🦼' => 'gurpil-aulki motordunean doan gizona: bitarteko azal-tonua',
    '👨🏾‍🦼' => 'gurpil-aulki motordunean doan gizona: 5. mota',
    '👨🏿‍🦼' => 'gurpil-aulki motordunean doan gizona: 6. mota',
    '👩🏻‍🦼' => 'gurpil-aulki motordunean doan emakumea: 1–2. mota',
    '👩🏼‍🦼' => 'gurpil-aulki motordunean doan emakumea: 3. mota',
    '👩🏽‍🦼' => 'gurpil-aulki motordunean doan emakumea: bitarteko azal-tonua',
    '👩🏾‍🦼' => 'gurpil-aulki motordunean doan emakumea: 5. mota',
    '👩🏿‍🦼' => 'gurpil-aulki motordunean doan emakumea: 6. mota',
    '🧑🏻‍🦽' => 'eskuzko gurpil-aulkian doan pertsona: 1–2. mota',
    '🧑🏼‍🦽' => 'eskuzko gurpil-aulkian doan pertsona: 3. mota',
    '🧑🏽‍🦽' => 'eskuzko gurpil-aulkian doan pertsona: bitarteko azal-tonua',
    '🧑🏾‍🦽' => 'eskuzko gurpil-aulkian doan pertsona: 5. mota',
    '🧑🏿‍🦽' => 'eskuzko gurpil-aulkian doan pertsona: 6. mota',
    '👨🏻‍🦽' => 'eskuzko gurpil-aulkian doan gizona: 1–2. mota',
    '👨🏼‍🦽' => 'eskuzko gurpil-aulkian doan gizona: 3. mota',
    '👨🏽‍🦽' => 'eskuzko gurpil-aulkian doan gizona: bitarteko azal-tonua',
    '👨🏾‍🦽' => 'eskuzko gurpil-aulkian doan gizona: 5. mota',
    '👨🏿‍🦽' => 'eskuzko gurpil-aulkian doan gizona: 6. mota',
    '👩🏻‍🦽' => 'eskuzko gurpil-aulkian doan emakumea: 1–2. mota',
    '👩🏼‍🦽' => 'eskuzko gurpil-aulkian doan emakumea: 3. mota',
    '👩🏽‍🦽' => 'eskuzko gurpil-aulkian doan emakumea: bitarteko azal-tonua',
    '👩🏾‍🦽' => 'eskuzko gurpil-aulkian doan emakumea: 5. mota',
    '👩🏿‍🦽' => 'eskuzko gurpil-aulkian doan emakumea: 6. mota',
    '🏃🏻‍♂' => 'korrika ari den gizona: 1–2. mota',
    '🏃🏼‍♂' => 'korrika ari den gizona: 3. mota',
    '🏃🏽‍♂' => 'korrika ari den gizona: bitarteko azal-tonua',
    '🏃🏾‍♂' => 'korrika ari den gizona: 5. mota',
    '🏃🏿‍♂' => 'korrika ari den gizona: 6. mota',
    '🏃🏻‍♀' => 'korrika ari den emakumea: 1–2. mota',
    '🏃🏼‍♀' => 'korrika ari den emakumea: 3. mota',
    '🏃🏽‍♀' => 'korrika ari den emakumea: bitarteko azal-tonua',
    '🏃🏾‍♀' => 'korrika ari den emakumea: 5. mota',
    '🏃🏿‍♀' => 'korrika ari den emakumea: 6. mota',
    '🏃🏻‍➡' => 'korrika ari den pertsona: 1–2. mota eta eskuinera begira',
    '🏃🏼‍➡' => 'korrika ari den pertsona: 3. mota eta eskuinera begira',
    '🏃🏽‍➡' => 'korrika ari den pertsona: bitarteko azal-tonua eta eskuinera begira',
    '🏃🏾‍➡' => 'korrika ari den pertsona: 5. mota eta eskuinera begira',
    '🏃🏿‍➡' => 'korrika ari den pertsona: 6. mota eta eskuinera begira',
    '👯🏻‍♀' => 'emakumeak jendea untxi-belarriak jantzita: 1–2. mota',
    '👯🏼‍♀' => 'emakumeak jendea untxi-belarriak jantzita: 3. mota',
    '👯🏽‍♀' => 'emakumeak jendea untxi-belarriak jantzita: bitarteko azal-tonua',
    '👯🏾‍♀' => 'emakumeak jendea untxi-belarriak jantzita: 5. mota',
    '👯🏿‍♀' => 'emakumeak jendea untxi-belarriak jantzita: 6. mota',
    '👯🏻‍♂' => 'gizonak untxi-belarriak jantzita: 1–2. mota',
    '👯🏼‍♂' => 'gizonak untxi-belarriak jantzita: 3. mota',
    '👯🏽‍♂' => 'gizonak untxi-belarriak jantzita: bitarteko azal-tonua',
    '👯🏾‍♂' => 'gizonak untxi-belarriak jantzita: 5. mota',
    '👯🏿‍♂' => 'gizonak untxi-belarriak jantzita: 6. mota',
    '🧖🏻‍♂' => 'gizon bat lurrun-gelan: 1–2. mota',
    '🧖🏼‍♂' => 'gizon bat lurrun-gelan: 3. mota',
    '🧖🏽‍♂' => 'gizon bat lurrun-gelan: bitarteko azal-tonua',
    '🧖🏾‍♂' => 'gizon bat lurrun-gelan: 5. mota',
    '🧖🏿‍♂' => 'gizon bat lurrun-gelan: 6. mota',
    '🧖🏻‍♀' => 'emakume bat lurrun-gelan: 1–2. mota',
    '🧖🏼‍♀' => 'emakume bat lurrun-gelan: 3. mota',
    '🧖🏽‍♀' => 'emakume bat lurrun-gelan: bitarteko azal-tonua',
    '🧖🏾‍♀' => 'emakume bat lurrun-gelan: 5. mota',
    '🧖🏿‍♀' => 'emakume bat lurrun-gelan: 6. mota',
    '🧗🏻‍♂' => 'gizon eskalatzaile: 1–2. mota',
    '🧗🏼‍♂' => 'gizon eskalatzaile: 3. mota',
    '🧗🏽‍♂' => 'gizon eskalatzaile: bitarteko azal-tonua',
    '🧗🏾‍♂' => 'gizon eskalatzaile: 5. mota',
    '🧗🏿‍♂' => 'gizon eskalatzaile: 6. mota',
    '🧗🏻‍♀' => 'emakume eskalatzaile: 1–2. mota',
    '🧗🏼‍♀' => 'emakume eskalatzaile: 3. mota',
    '🧗🏽‍♀' => 'emakume eskalatzaile: bitarteko azal-tonua',
    '🧗🏾‍♀' => 'emakume eskalatzaile: 5. mota',
    '🧗🏿‍♀' => 'emakume eskalatzaile: 6. mota',
    '🏌🏻‍♂' => 'gizon golflaria: 1–2. mota',
    '🏌🏼‍♂' => 'gizon golflaria: 3. mota',
    '🏌🏽‍♂' => 'gizon golflaria: bitarteko azal-tonua',
    '🏌🏾‍♂' => 'gizon golflaria: 5. mota',
    '🏌🏿‍♂' => 'gizon golflaria: 6. mota',
    '🏌🏻‍♀' => 'emakume golflaria: 1–2. mota',
    '🏌🏼‍♀' => 'emakume golflaria: 3. mota',
    '🏌🏽‍♀' => 'emakume golflaria: bitarteko azal-tonua',
    '🏌🏾‍♀' => 'emakume golflaria: 5. mota',
    '🏌🏿‍♀' => 'emakume golflaria: 6. mota',
    '🏄🏻‍♂' => 'gizon surflaria: 1–2. mota',
    '🏄🏼‍♂' => 'gizon surflaria: 3. mota',
    '🏄🏽‍♂' => 'gizon surflaria: bitarteko azal-tonua',
    '🏄🏾‍♂' => 'gizon surflaria: 5. mota',
    '🏄🏿‍♂' => 'gizon surflaria: 6. mota',
    '🏄🏻‍♀' => 'emakume surflaria: 1–2. mota',
    '🏄🏼‍♀' => 'emakume surflaria: 3. mota',
    '🏄🏽‍♀' => 'emakume surflaria: bitarteko azal-tonua',
    '🏄🏾‍♀' => 'emakume surflaria: 5. mota',
    '🏄🏿‍♀' => 'emakume surflaria: 6. mota',
    '🚣🏻‍♂' => 'gizon arraunlaria: 1–2. mota',
    '🚣🏼‍♂' => 'gizon arraunlaria: 3. mota',
    '🚣🏽‍♂' => 'gizon arraunlaria: bitarteko azal-tonua',
    '🚣🏾‍♂' => 'gizon arraunlaria: 5. mota',
    '🚣🏿‍♂' => 'gizon arraunlaria: 6. mota',
    '🚣🏻‍♀' => 'emakume arraunlaria: 1–2. mota',
    '🚣🏼‍♀' => 'emakume arraunlaria: 3. mota',
    '🚣🏽‍♀' => 'emakume arraunlaria: bitarteko azal-tonua',
    '🚣🏾‍♀' => 'emakume arraunlaria: 5. mota',
    '🚣🏿‍♀' => 'emakume arraunlaria: 6. mota',
    '🏊🏻‍♂' => 'gizon igerilaria: 1–2. mota',
    '🏊🏼‍♂' => 'gizon igerilaria: 3. mota',
    '🏊🏽‍♂' => 'gizon igerilaria: bitarteko azal-tonua',
    '🏊🏾‍♂' => 'gizon igerilaria: 5. mota',
    '🏊🏿‍♂' => 'gizon igerilaria: 6. mota',
    '🏊🏻‍♀' => 'emakume igerilaria: 1–2. mota',
    '🏊🏼‍♀' => 'emakume igerilaria: 3. mota',
    '🏊🏽‍♀' => 'emakume igerilaria: bitarteko azal-tonua',
    '🏊🏾‍♀' => 'emakume igerilaria: 5. mota',
    '🏊🏿‍♀' => 'emakume igerilaria: 6. mota',
    '⛹🏻‍♂' => 'baloi bat duen gizona: 1–2. mota',
    '⛹🏼‍♂' => 'baloi bat duen gizona: 3. mota',
    '⛹🏽‍♂' => 'baloi bat duen gizona: bitarteko azal-tonua',
    '⛹🏾‍♂' => 'baloi bat duen gizona: 5. mota',
    '⛹🏿‍♂' => 'baloi bat duen gizona: 6. mota',
    '⛹🏻‍♀' => 'baloi bat duen emakumea: 1–2. mota',
    '⛹🏼‍♀' => 'baloi bat duen emakumea: 3. mota',
    '⛹🏽‍♀' => 'baloi bat duen emakumea: bitarteko azal-tonua',
    '⛹🏾‍♀' => 'baloi bat duen emakumea: 5. mota',
    '⛹🏿‍♀' => 'baloi bat duen emakumea: 6. mota',
    '🏋🏻‍♂' => 'pisuak altxatzen ari den gizona: 1–2. mota',
    '🏋🏼‍♂' => 'pisuak altxatzen ari den gizona: 3. mota',
    '🏋🏽‍♂' => 'pisuak altxatzen ari den gizona: bitarteko azal-tonua',
    '🏋🏾‍♂' => 'pisuak altxatzen ari den gizona: 5. mota',
    '🏋🏿‍♂' => 'pisuak altxatzen ari den gizona: 6. mota',
    '🏋🏻‍♀' => 'pisuak altxatzen ari den emakumea: 1–2. mota',
    '🏋🏼‍♀' => 'pisuak altxatzen ari den emakumea: 3. mota',
    '🏋🏽‍♀' => 'pisuak altxatzen ari den emakumea: bitarteko azal-tonua',
    '🏋🏾‍♀' => 'pisuak altxatzen ari den emakumea: 5. mota',
    '🏋🏿‍♀' => 'pisuak altxatzen ari den emakumea: 6. mota',
    '🚴🏻‍♂' => 'gizon txirrindularia: 1–2. mota',
    '🚴🏼‍♂' => 'gizon txirrindularia: 3. mota',
    '🚴🏽‍♂' => 'gizon txirrindularia: bitarteko azal-tonua',
    '🚴🏾‍♂' => 'gizon txirrindularia: 5. mota',
    '🚴🏿‍♂' => 'gizon txirrindularia: 6. mota',
    '🚴🏻‍♀' => 'emakume txirrindularia: 1–2. mota',
    '🚴🏼‍♀' => 'emakume txirrindularia: 3. mota',
    '🚴🏽‍♀' => 'emakume txirrindularia: bitarteko azal-tonua',
    '🚴🏾‍♀' => 'emakume txirrindularia: 5. mota',
    '🚴🏿‍♀' => 'emakume txirrindularia: 6. mota',
    '🚵🏻‍♂' => 'mendiko bizikletan dabilen gizona: 1–2. mota',
    '🚵🏼‍♂' => 'mendiko bizikletan dabilen gizona: 3. mota',
    '🚵🏽‍♂' => 'mendiko bizikletan dabilen gizona: bitarteko azal-tonua',
    '🚵🏾‍♂' => 'mendiko bizikletan dabilen gizona: 5. mota',
    '🚵🏿‍♂' => 'mendiko bizikletan dabilen gizona: 6. mota',
    '🚵🏻‍♀' => 'mendiko bizikletan dabilen emakumea: 1–2. mota',
    '🚵🏼‍♀' => 'mendiko bizikletan dabilen emakumea: 3. mota',
    '🚵🏽‍♀' => 'mendiko bizikletan dabilen emakumea: bitarteko azal-tonua',
    '🚵🏾‍♀' => 'mendiko bizikletan dabilen emakumea: 5. mota',
    '🚵🏿‍♀' => 'mendiko bizikletan dabilen emakumea: 6. mota',
    '🤸🏻‍♂' => 'gurpil-ariketa egiten ari den gizona: 1–2. mota',
    '🤸🏼‍♂' => 'gurpil-ariketa egiten ari den gizona: 3. mota',
    '🤸🏽‍♂' => 'gurpil-ariketa egiten ari den gizona: bitarteko azal-tonua',
    '🤸🏾‍♂' => 'gurpil-ariketa egiten ari den gizona: 5. mota',
    '🤸🏿‍♂' => 'gurpil-ariketa egiten ari den gizona: 6. mota',
    '🤸🏻‍♀' => 'gurpil-ariketa egiten ari den emakumea: 1–2. mota',
    '🤸🏼‍♀' => 'gurpil-ariketa egiten ari den emakumea: 3. mota',
    '🤸🏽‍♀' => 'gurpil-ariketa egiten ari den emakumea: bitarteko azal-tonua',
    '🤸🏾‍♀' => 'gurpil-ariketa egiten ari den emakumea: 5. mota',
    '🤸🏿‍♀' => 'gurpil-ariketa egiten ari den emakumea: 6. mota',
    '🤼🏻‍♀' => 'emakumeak borrokan: 1–2. mota',
    '🤼🏼‍♀' => 'emakumeak borrokan: 3. mota',
    '🤼🏽‍♀' => 'emakumeak borrokan: bitarteko azal-tonua',
    '🤼🏾‍♀' => 'emakumeak borrokan: 5. mota',
    '🤼🏿‍♀' => 'emakumeak borrokan: 6. mota',
    '🤼🏻‍♂' => 'gizonak borrokan: 1–2. mota',
    '🤼🏼‍♂' => 'gizonak borrokan: 3. mota',
    '🤼🏽‍♂' => 'gizonak borrokan: bitarteko azal-tonua',
    '🤼🏾‍♂' => 'gizonak borrokan: 5. mota',
    '🤼🏿‍♂' => 'gizonak borrokan: 6. mota',
    '🤽🏻‍♂' => 'gizona waterpoloan jolasten: 1–2. mota',
    '🤽🏼‍♂' => 'gizona waterpoloan jolasten: 3. mota',
    '🤽🏽‍♂' => 'gizona waterpoloan jolasten: bitarteko azal-tonua',
    '🤽🏾‍♂' => 'gizona waterpoloan jolasten: 5. mota',
    '🤽🏿‍♂' => 'gizona waterpoloan jolasten: 6. mota',
    '🤽🏻‍♀' => 'emakumea waterpoloan jolasten: 1–2. mota',
    '🤽🏼‍♀' => 'emakumea waterpoloan jolasten: 3. mota',
    '🤽🏽‍♀' => 'emakumea waterpoloan jolasten: bitarteko azal-tonua',
    '🤽🏾‍♀' => 'emakumea waterpoloan jolasten: 5. mota',
    '🤽🏿‍♀' => 'emakumea waterpoloan jolasten: 6. mota',
    '🤾🏻‍♂' => 'gizona eskubaloian jolasten: 1–2. mota',
    '🤾🏼‍♂' => 'gizona eskubaloian jolasten: 3. mota',
    '🤾🏽‍♂' => 'gizona eskubaloian jolasten: bitarteko azal-tonua',
    '🤾🏾‍♂' => 'gizona eskubaloian jolasten: 5. mota',
    '🤾🏿‍♂' => 'gizona eskubaloian jolasten: 6. mota',
    '🤾🏻‍♀' => 'emakumea eskubaloian jolasten: 1–2. mota',
    '🤾🏼‍♀' => 'emakumea eskubaloian jolasten: 3. mota',
    '🤾🏽‍♀' => 'emakumea eskubaloian jolasten: bitarteko azal-tonua',
    '🤾🏾‍♀' => 'emakumea eskubaloian jolasten: 5. mota',
    '🤾🏿‍♀' => 'emakumea eskubaloian jolasten: 6. mota',
    '🤹🏻‍♂' => 'gizona malabarismotan: 1–2. mota',
    '🤹🏼‍♂' => 'gizona malabarismotan: 3. mota',
    '🤹🏽‍♂' => 'gizona malabarismotan: bitarteko azal-tonua',
    '🤹🏾‍♂' => 'gizona malabarismotan: 5. mota',
    '🤹🏿‍♂' => 'gizona malabarismotan: 6. mota',
    '🤹🏻‍♀' => 'emakumea malabarismotan: 1–2. mota',
    '🤹🏼‍♀' => 'emakumea malabarismotan: 3. mota',
    '🤹🏽‍♀' => 'emakumea malabarismotan: bitarteko azal-tonua',
    '🤹🏾‍♀' => 'emakumea malabarismotan: 5. mota',
    '🤹🏿‍♀' => 'emakumea malabarismotan: 6. mota',
    '🧘🏻‍♂' => 'gizon bat loto-posizioan: 1–2. mota',
    '🧘🏼‍♂' => 'gizon bat loto-posizioan: 3. mota',
    '🧘🏽‍♂' => 'gizon bat loto-posizioan: bitarteko azal-tonua',
    '🧘🏾‍♂' => 'gizon bat loto-posizioan: 5. mota',
    '🧘🏿‍♂' => 'gizon bat loto-posizioan: 6. mota',
    '🧘🏻‍♀' => 'emakume bat loto-posizioan: 1–2. mota',
    '🧘🏼‍♀' => 'emakume bat loto-posizioan: 3. mota',
    '🧘🏽‍♀' => 'emakume bat loto-posizioan: bitarteko azal-tonua',
    '🧘🏾‍♀' => 'emakume bat loto-posizioan: 5. mota',
    '🧘🏿‍♀' => 'emakume bat loto-posizioan: 6. mota',
    '🧑‍🦰' => 'pertsona: ilegorri',
    '🧑‍🦱' => 'pertsona: ile kizkur',
    '🧑‍🦳' => 'pertsona: ilezuri',
    '🧑‍🦲' => 'pertsona: burusoil',
    '👨‍🦰' => 'gizona: ilegorri',
    '👨‍🦱' => 'gizona: ile kizkur',
    '👨‍🦳' => 'gizona: ilezuri',
    '👨‍🦲' => 'gizona: burusoil',
    '👩‍🦰' => 'emakumea: ilegorri',
    '👩‍🦱' => 'emakumea: ile kizkur',
    '👩‍🦳' => 'emakumea: ilezuri',
    '👩‍🦲' => 'emakumea: burusoil',
    '🚶‍➡' => 'oinez ari den pertsona: eskuinera begira',
    '🧎‍➡' => 'belauniko dagoen pertsona: eskuinera begira',
    '🏃‍➡' => 'korrika ari den pertsona: eskuinera begira',
    '👨‍👦' => 'familia: gizona eta mutila',
    '👨‍👧' => 'familia: gizona eta neska',
    '👩‍👦' => 'familia: emakumea eta mutila',
    '👩‍👧' => 'familia: emakumea eta neska',
    '😶‍🌫' => 'hodei artean dagoen aurpegia',
    '😮‍💨' => 'arnasa botatzen ari den aurpegia',
    '🙂‍↕' => 'bertikalki mugitzen ari den burua',
    '😵‍💫' => 'kiribil-begiak dituen aurpegia',
    '❤‍🔥' => 'sutan dagoen bihotza',
    '❤‍🩹' => 'sendatzen ari den bihotza',
    '👁‍🗨' => 'begi bat duen bunbuiloa',
    '🧔‍♂' => 'gizona: bizarra',
    '👱‍♂' => 'gizon ilehoria',
    '🧔‍♀' => 'emakumea: bizarra',
    '👱‍♀' => 'emakume ilehoria',
    '🙍‍♂' => 'kopeta zimurtzen ari den gizona',
    '🙍‍♀' => 'kopeta zimurtzen ari den emakumea',
    '🙎‍♂' => 'gizon muturtua',
    '🙎‍♀' => 'emakume muturtua',
    '🙅‍♂' => 'ados ez dagoela adierazten ari den gizona',
    '🙅‍♀' => 'ezezko keinua egiten ari den emakumea',
    '🙆‍♂' => 'ados dagoela adierazten ari den gizona',
    '🙆‍♀' => 'ados dagoela adierazten ari den emakumea',
    '💁‍♂' => 'eskean dabilen gizona',
    '💁‍♀' => 'eskean dabilen emakumea',
    '🙋‍♂' => 'eskua altxatzen ari den gizona',
    '🙋‍♀' => 'eskua altxatzen ari den emakumea',
    '🧏‍♂' => 'gizon gorra',
    '🧏‍♀' => 'emakume gorra',
    '🙇‍♂' => 'burua makurtzen ari den gizona',
    '🙇‍♀' => 'burua makurtzen ari den emakumea',
    '🤦‍♂' => 'esku-azpia aurpegian duen gizona',
    '🤦‍♀' => 'esku-azpia aurpegian duen emakumea',
    '🤷‍♂' => 'sorbaldak altxatzen ari den gizona',
    '🤷‍♀' => 'sorbaldak altxatzen ari den emakumea',
    '🧑‍⚕' => 'sendagilea',
    '👨‍⚕' => 'gizon sendagilea',
    '👩‍⚕' => 'emakume sendagilea',
    '🧑‍🎓' => 'ikaslea',
    '👨‍🎓' => 'mutil ikaslea',
    '👩‍🎓' => 'neska ikaslea',
    '🧑‍🏫' => 'irakaslea',
    '👨‍🏫' => 'gizon irakaslea',
    '👩‍🏫' => 'emakume irakaslea',
    '🧑‍⚖' => 'epailea',
    '👨‍⚖' => 'gizon epailea',
    '👩‍⚖' => 'emakume epailea',
    '🧑‍🌾' => 'nekazaria',
    '👨‍🌾' => 'gizon nekazaria',
    '👩‍🌾' => 'emakume nekazaria',
    '🧑‍🍳' => 'sukaldaria',
    '👨‍🍳' => 'gizon sukaldaria',
    '👩‍🍳' => 'emakume sukaldaria',
    '🧑‍🔧' => 'mekanikaria',
    '👨‍🔧' => 'gizon mekanikaria',
    '👩‍🔧' => 'emakume mekanikaria',
    '🧑‍🏭' => 'fabrikako langilea',
    '👨‍🏭' => 'fabrikako gizon langilea',
    '👩‍🏭' => 'fabrikako emakume langilea',
    '🧑‍💼' => 'bulegaria',
    '👨‍💼' => 'gizon bulegaria',
    '👩‍💼' => 'emakume bulegaria',
    '🧑‍🔬' => 'zientzialaria',
    '👨‍🔬' => 'gizon zientzialaria',
    '👩‍🔬' => 'emakume zientzialaria',
    '🧑‍💻' => 'teknologialaria',
    '👨‍💻' => 'gizon teknologialaria',
    '👩‍💻' => 'emakume teknologialaria',
    '🧑‍🎤' => 'abeslaria',
    '👨‍🎤' => 'gizon abeslaria',
    '👩‍🎤' => 'emakume abeslaria',
    '🧑‍🎨' => 'artista',
    '👨‍🎨' => 'gizon artista',
    '👩‍🎨' => 'emakume artista',
    '🧑‍✈' => 'pilotua',
    '👨‍✈' => 'gizon pilotua',
    '👩‍✈' => 'emakume pilotua',
    '🧑‍🚀' => 'astronauta',
    '👨‍🚀' => 'gizon astronauta',
    '👩‍🚀' => 'emakume astronauta',
    '🧑‍🚒' => 'suhiltzailea',
    '👨‍🚒' => 'gizon suhiltzailea',
    '👩‍🚒' => 'emakume suhiltzailea',
    '👮‍♂' => 'gizon polizia',
    '👮‍♀' => 'emakume polizia',
    '🕵‍♂' => 'gizon detektibea',
    '🕵‍♀' => 'emakume detektibea',
    '💂‍♂' => 'gizon zaindaria',
    '💂‍♀' => 'emakume zaindaria',
    '👷‍♂' => 'gizon eskulangilea',
    '👷‍♀' => 'emakume eskulangilea',
    '👳‍♂' => 'turbantea duen gizona',
    '👳‍♀' => 'turbantea duen emakumea',
    '🤵‍♂' => 'gizona esmokinean',
    '🤵‍♀' => 'emakumea esmokinean',
    '👰‍♂' => 'beloa daraman gizona',
    '👰‍♀' => 'beloa daraman emakumea',
    '👩‍🍼' => 'emakumea bularra ematen',
    '👨‍🍼' => 'gizona haurrari janaria ematen',
    '🧑‍🍼' => 'haurra elikatzen',
    '🧑‍🎄' => 'bizarzuri',
    '🦸‍♂' => 'gizonezko superheroi',
    '🦸‍♀' => 'emakumezko superheroi',
    '🦹‍♂' => 'gizonezko superbilau',
    '🦹‍♀' => 'emakumezko superbilau',
    '🧙‍♂' => 'gizon mago',
    '🧙‍♀' => 'emakume mago',
    '🧚‍♂' => '(gizon) maitagarri',
    '🧚‍♀' => '(emakume) maitagarri',
    '🧛‍♂' => 'gizon banpiro',
    '🧛‍♀' => 'emakume banpiro',
    '🧜‍♂' => 'gizon-itxurako itsas izaki',
    '🧜‍♀' => 'lamina',
    '🧝‍♂' => 'gizon elfo',
    '🧝‍♀' => 'emakume elfo',
    '🧞‍♂' => 'gizon iratxo',
    '🧞‍♀' => 'emakume iratxo',
    '🧟‍♂' => 'gizon zonbi',
    '🧟‍♀' => 'emakume zonbi',
    '💆‍♂' => 'masajea jasotzen ari den pertsona',
    '💆‍♀' => 'masajea jasotzen ari den emakumea',
    '💇‍♂' => 'ilea mozten ari dioten gizona',
    '💇‍♀' => 'ilea mozten ari dioten emakumea',
    '🚶‍♂' => 'oinez ari den gizona',
    '🚶‍♀' => 'oinez ari den emakumea',
    '🧍‍♂' => 'zutik dagoen gizona',
    '🧍‍♀' => 'zutik dagoen emakumea',
    '🧎‍♂' => 'belauniko dagoen gizona',
    '🧎‍♀' => 'belauniko dagoen emakumea',
    '🧑‍🦯' => 'itsu-makila daraman pertsona',
    '👨‍🦯' => 'itsu-makila daraman gizona',
    '👩‍🦯' => 'itsu-makila daraman emakumea',
    '🧑‍🦼' => 'gurpil-aulki motordunean doan pertsona',
    '👨‍🦼' => 'gurpil-aulki motordunean doan gizona',
    '👩‍🦼' => 'gurpil-aulki motordunean doan emakumea',
    '🧑‍🦽' => 'eskuzko gurpil-aulkian doan pertsona',
    '👨‍🦽' => 'eskuzko gurpil-aulkian doan gizona',
    '👩‍🦽' => 'eskuzko gurpil-aulkian doan emakumea',
    '🏃‍♂' => 'korrika ari den gizona',
    '🏃‍♀' => 'korrika ari den emakumea',
    '🧑‍🩰' => 'ballet-dantzaria',
    '👯‍♂' => 'gizonak untxi-belarriak jantzita',
    '👯‍♀' => 'emakumeak jendea untxi-belarriak jantzita',
    '🧖‍♂' => 'gizon bat lurrun-gelan',
    '🧖‍♀' => 'emakume bat lurrun-gelan',
    '🧗‍♂' => 'gizon eskalatzaile',
    '🧗‍♀' => 'emakume eskalatzaile',
    '🏌‍♂' => 'gizon golflaria',
    '🏌‍♀' => 'emakume golflaria',
    '🏄‍♂' => 'gizon surflaria',
    '🏄‍♀' => 'emakume surflaria',
    '🚣‍♂' => 'gizon arraunlaria',
    '🚣‍♀' => 'emakume arraunlaria',
    '🏊‍♂' => 'gizon igerilaria',
    '🏊‍♀' => 'emakume igerilaria',
    '⛹‍♂' => 'baloi bat duen gizona',
    '⛹‍♀' => 'baloi bat duen emakumea',
    '🏋‍♂' => 'pisuak altxatzen ari den gizona',
    '🏋‍♀' => 'pisuak altxatzen ari den emakumea',
    '🚴‍♂' => 'gizon txirrindularia',
    '🚴‍♀' => 'emakume txirrindularia',
    '🚵‍♂' => 'mendiko bizikletan dabilen gizona',
    '🚵‍♀' => 'mendiko bizikletan dabilen emakumea',
    '🤸‍♂' => 'gurpil-ariketa egiten ari den gizona',
    '🤸‍♀' => 'gurpil-ariketa egiten ari den emakumea',
    '🤼‍♂' => 'gizonak borrokan',
    '🤼‍♀' => 'emakumeak borrokan',
    '🤽‍♂' => 'gizona waterpoloan jolasten',
    '🤽‍♀' => 'emakumea waterpoloan jolasten',
    '🤾‍♂' => 'gizona eskubaloian jolasten',
    '🤾‍♀' => 'emakumea eskubaloian jolasten',
    '🤹‍♂' => 'gizona malabarismotan',
    '🤹‍♀' => 'emakumea malabarismotan',
    '🧘‍♂' => 'gizon bat loto-posizioan',
    '🧘‍♀' => 'emakume bat loto-posizioan',
    '🧑‍🧒' => 'familia: nagusia, haurra',
    '🐕‍🦺' => 'laguntza-txakurra',
    '🐈‍⬛' => 'katu beltza',
    '🐻‍❄' => 'hartz zuria',
    '🐦‍⬛' => 'txori beltza',
    '🐦‍🔥' => 'fenixa',
    '🍋‍🟩' => 'lima',
    '🍄‍🟫' => 'perretxiko marroia',
    '⛓‍💥' => 'kate hautsia',
    '🏳‍🌈' => 'ortzadarraren bandera',
    '🏳‍⚧' => 'bandera transgeneroa',
    '🏴‍☠' => 'piraten bandera',
    '👋🏻' => 'mugitzen ari den eskua: 1–2. mota',
    '👋🏼' => 'mugitzen ari den eskua: 3. mota',
    '👋🏽' => 'mugitzen ari den eskua: bitarteko azal-tonua',
    '👋🏾' => 'mugitzen ari den eskua: 5. mota',
    '👋🏿' => 'mugitzen ari den eskua: 6. mota',
    '🤚🏻' => 'esku-azpia altxatuta: 1–2. mota',
    '🤚🏼' => 'esku-azpia altxatuta: 3. mota',
    '🤚🏽' => 'esku-azpia altxatuta: bitarteko azal-tonua',
    '🤚🏾' => 'esku-azpia altxatuta: 5. mota',
    '🤚🏿' => 'esku-azpia altxatuta: 6. mota',
    '🖐🏻' => 'esku altxatua eta hatz hedatuak: 1–2. mota',
    '🖐🏼' => 'esku altxatua eta hatz hedatuak: 3. mota',
    '🖐🏽' => 'esku altxatua eta hatz hedatuak: bitarteko azal-tonua',
    '🖐🏾' => 'esku altxatua eta hatz hedatuak: 5. mota',
    '🖐🏿' => 'esku altxatua eta hatz hedatuak: 6. mota',
    '✋🏻' => 'esku altxatua: 1–2. mota',
    '✋🏼' => 'esku altxatua: 3. mota',
    '✋🏽' => 'esku altxatua: bitarteko azal-tonua',
    '✋🏾' => 'esku altxatua: 5. mota',
    '✋🏿' => 'esku altxatua: 6. mota',
    '🖖🏻' => 'vulcandar agur: 1–2. mota',
    '🖖🏼' => 'vulcandar agur: 3. mota',
    '🖖🏽' => 'vulcandar agur: bitarteko azal-tonua',
    '🖖🏾' => 'vulcandar agur: 5. mota',
    '🖖🏿' => 'vulcandar agur: 6. mota',
    '🫱🏻' => 'eskuinera begira dagoen eskua: 1–2. mota',
    '🫱🏼' => 'eskuinera begira dagoen eskua: 3. mota',
    '🫱🏽' => 'eskuinera begira dagoen eskua: bitarteko azal-tonua',
    '🫱🏾' => 'eskuinera begira dagoen eskua: 5. mota',
    '🫱🏿' => 'eskuinera begira dagoen eskua: 6. mota',
    '🫲🏻' => 'ezkerrera begira dagoen eskua: 1–2. mota',
    '🫲🏼' => 'ezkerrera begira dagoen eskua: 3. mota',
    '🫲🏽' => 'ezkerrera begira dagoen eskua: bitarteko azal-tonua',
    '🫲🏾' => 'ezkerrera begira dagoen eskua: 5. mota',
    '🫲🏿' => 'ezkerrera begira dagoen eskua: 6. mota',
    '🫳🏻' => 'esku-ahurra beherantz duen eskua: 1–2. mota',
    '🫳🏼' => 'esku-ahurra beherantz duen eskua: 3. mota',
    '🫳🏽' => 'esku-ahurra beherantz duen eskua: bitarteko azal-tonua',
    '🫳🏾' => 'esku-ahurra beherantz duen eskua: 5. mota',
    '🫳🏿' => 'esku-ahurra beherantz duen eskua: 6. mota',
    '🫴🏻' => 'esku-ahura gora begira duen eskua: 1–2. mota',
    '🫴🏼' => 'esku-ahura gora begira duen eskua: 3. mota',
    '🫴🏽' => 'esku-ahura gora begira duen eskua: bitarteko azal-tonua',
    '🫴🏾' => 'esku-ahura gora begira duen eskua: 5. mota',
    '🫴🏿' => 'esku-ahura gora begira duen eskua: 6. mota',
    '🫷🏻' => 'ezkerrerantz bultza egiten ari den eskua: 1–2. mota',
    '🫷🏼' => 'ezkerrerantz bultza egiten ari den eskua: 3. mota',
    '🫷🏽' => 'ezkerrerantz bultza egiten ari den eskua: bitarteko azal-tonua',
    '🫷🏾' => 'ezkerrerantz bultza egiten ari den eskua: 5. mota',
    '🫷🏿' => 'ezkerrerantz bultza egiten ari den eskua: 6. mota',
    '🫸🏻' => 'eskuinerantz bultza egiten ari den eskua: 1–2. mota',
    '🫸🏼' => 'eskuinerantz bultza egiten ari den eskua: 3. mota',
    '🫸🏽' => 'eskuinerantz bultza egiten ari den eskua: bitarteko azal-tonua',
    '🫸🏾' => 'eskuinerantz bultza egiten ari den eskua: 5. mota',
    '🫸🏿' => 'eskuinerantz bultza egiten ari den eskua: 6. mota',
    '👌🏻' => 'adostasuna adierazten duen eskua: 1–2. mota',
    '👌🏼' => 'adostasuna adierazten duen eskua: 3. mota',
    '👌🏽' => 'adostasuna adierazten duen eskua: bitarteko azal-tonua',
    '👌🏾' => 'adostasuna adierazten duen eskua: 5. mota',
    '👌🏿' => 'adostasuna adierazten duen eskua: 6. mota',
    '🤌🏻' => 'hatz elkartuak: 1–2. mota',
    '🤌🏼' => 'hatz elkartuak: 3. mota',
    '🤌🏽' => 'hatz elkartuak: bitarteko azal-tonua',
    '🤌🏾' => 'hatz elkartuak: 5. mota',
    '🤌🏿' => 'hatz elkartuak: 6. mota',
    '🤏🏻' => 'atximurka egiten ari den eskua: 1–2. mota',
    '🤏🏼' => 'atximurka egiten ari den eskua: 3. mota',
    '🤏🏽' => 'atximurka egiten ari den eskua: bitarteko azal-tonua',
    '🤏🏾' => 'atximurka egiten ari den eskua: 5. mota',
    '🤏🏿' => 'atximurka egiten ari den eskua: 6. mota',
    '✌🏻' => 'garaipena adierazten duen eskua: 1–2. mota',
    '✌🏼' => 'garaipena adierazten duen eskua: 3. mota',
    '✌🏽' => 'garaipena adierazten duen eskua: bitarteko azal-tonua',
    '✌🏾' => 'garaipena adierazten duen eskua: 5. mota',
    '✌🏿' => 'garaipena adierazten duen eskua: 6. mota',
    '🤞🏻' => 'hatz gurutzatuak: 1–2. mota',
    '🤞🏼' => 'hatz gurutzatuak: 3. mota',
    '🤞🏽' => 'hatz gurutzatuak: bitarteko azal-tonua',
    '🤞🏾' => 'hatz gurutzatuak: 5. mota',
    '🤞🏿' => 'hatz gurutzatuak: 6. mota',
    '🫰🏻' => 'erakuslea eta erpurua gurutzatuta: 1–2. mota',
    '🫰🏼' => 'erakuslea eta erpurua gurutzatuta: 3. mota',
    '🫰🏽' => 'erakuslea eta erpurua gurutzatuta: bitarteko azal-tonua',
    '🫰🏾' => 'erakuslea eta erpurua gurutzatuta: 5. mota',
    '🫰🏿' => 'erakuslea eta erpurua gurutzatuta: 6. mota',
    '🤟🏻' => 'adarren keinua: 1–2. mota',
    '🤟🏼' => 'adarren keinua: 3. mota',
    '🤟🏽' => 'adarren keinua: bitarteko azal-tonua',
    '🤟🏾' => 'adarren keinua: 5. mota',
    '🤟🏿' => 'adarren keinua: 6. mota',
    '🤘🏻' => 'adarrak adierazten dituen eskua: 1–2. mota',
    '🤘🏼' => 'adarrak adierazten dituen eskua: 3. mota',
    '🤘🏽' => 'adarrak adierazten dituen eskua: bitarteko azal-tonua',
    '🤘🏾' => 'adarrak adierazten dituen eskua: 5. mota',
    '🤘🏿' => 'adarrak adierazten dituen eskua: 6. mota',
    '🤙🏻' => 'deitzeko esku-keinua: 1–2. mota',
    '🤙🏼' => 'deitzeko esku-keinua: 3. mota',
    '🤙🏽' => 'deitzeko esku-keinua: bitarteko azal-tonua',
    '🤙🏾' => 'deitzeko esku-keinua: 5. mota',
    '🤙🏿' => 'deitzeko esku-keinua: 6. mota',
    '👈🏻' => 'ezkerrera seinalatzen ari den hatz erakuslea: 1–2. mota',
    '👈🏼' => 'ezkerrera seinalatzen ari den hatz erakuslea: 3. mota',
    '👈🏽' => 'ezkerrera seinalatzen ari den hatz erakuslea: bitarteko azal-tonua',
    '👈🏾' => 'ezkerrera seinalatzen ari den hatz erakuslea: 5. mota',
    '👈🏿' => 'ezkerrera seinalatzen ari den hatz erakuslea: 6. mota',
    '👉🏻' => 'eskuinera seinalatzen ari den hatz erakuslea: 1–2. mota',
    '👉🏼' => 'eskuinera seinalatzen ari den hatz erakuslea: 3. mota',
    '👉🏽' => 'eskuinera seinalatzen ari den hatz erakuslea: bitarteko azal-tonua',
    '👉🏾' => 'eskuinera seinalatzen ari den hatz erakuslea: 5. mota',
    '👉🏿' => 'eskuinera seinalatzen ari den hatz erakuslea: 6. mota',
    '👆🏻' => 'gora seinalatzen ari den hatza: 1–2. mota',
    '👆🏼' => 'gora seinalatzen ari den hatza: 3. mota',
    '👆🏽' => 'gora seinalatzen ari den hatza: bitarteko azal-tonua',
    '👆🏾' => 'gora seinalatzen ari den hatza: 5. mota',
    '👆🏿' => 'gora seinalatzen ari den hatza: 6. mota',
    '🖕🏻' => 'erdiko hatza: 1–2. mota',
    '🖕🏼' => 'erdiko hatza: 3. mota',
    '🖕🏽' => 'erdiko hatza: bitarteko azal-tonua',
    '🖕🏾' => 'erdiko hatza: 5. mota',
    '🖕🏿' => 'erdiko hatza: 6. mota',
    '👇🏻' => 'behera seinalatzen ari den hatza: 1–2. mota',
    '👇🏼' => 'behera seinalatzen ari den hatza: 3. mota',
    '👇🏽' => 'behera seinalatzen ari den hatza: bitarteko azal-tonua',
    '👇🏾' => 'behera seinalatzen ari den hatza: 5. mota',
    '👇🏿' => 'behera seinalatzen ari den hatza: 6. mota',
    '☝🏻' => 'gora seinalatzen ari den hatz erakuslea: 1–2. mota',
    '☝🏼' => 'gora seinalatzen ari den hatz erakuslea: 3. mota',
    '☝🏽' => 'gora seinalatzen ari den hatz erakuslea: bitarteko azal-tonua',
    '☝🏾' => 'gora seinalatzen ari den hatz erakuslea: 5. mota',
    '☝🏿' => 'gora seinalatzen ari den hatz erakuslea: 6. mota',
    '🫵🏻' => 'ikusleari seinalatzen dion erakuslea: 1–2. mota',
    '🫵🏼' => 'ikusleari seinalatzen dion erakuslea: 3. mota',
    '🫵🏽' => 'ikusleari seinalatzen dion erakuslea: bitarteko azal-tonua',
    '🫵🏾' => 'ikusleari seinalatzen dion erakuslea: 5. mota',
    '🫵🏿' => 'ikusleari seinalatzen dion erakuslea: 6. mota',
    '👍🏻' => 'erpurua gora: 1–2. mota',
    '👍🏼' => 'erpurua gora: 3. mota',
    '👍🏽' => 'erpurua gora: bitarteko azal-tonua',
    '👍🏾' => 'erpurua gora: 5. mota',
    '👍🏿' => 'erpurua gora: 6. mota',
    '👎🏻' => 'erpurua behera: 1–2. mota',
    '👎🏼' => 'erpurua behera: 3. mota',
    '👎🏽' => 'erpurua behera: bitarteko azal-tonua',
    '👎🏾' => 'erpurua behera: 5. mota',
    '👎🏿' => 'erpurua behera: 6. mota',
    '✊🏻' => 'ukabil altxatua: 1–2. mota',
    '✊🏼' => 'ukabil altxatua: 3. mota',
    '✊🏽' => 'ukabil altxatua: bitarteko azal-tonua',
    '✊🏾' => 'ukabil altxatua: 5. mota',
    '✊🏿' => 'ukabil altxatua: 6. mota',
    '👊🏻' => 'ukabilkada: 1–2. mota',
    '👊🏼' => 'ukabilkada: 3. mota',
    '👊🏽' => 'ukabilkada: bitarteko azal-tonua',
    '👊🏾' => 'ukabilkada: 5. mota',
    '👊🏿' => 'ukabilkada: 6. mota',
    '🤛🏻' => 'ukabila ezkerrera begira: 1–2. mota',
    '🤛🏼' => 'ukabila ezkerrera begira: 3. mota',
    '🤛🏽' => 'ukabila ezkerrera begira: bitarteko azal-tonua',
    '🤛🏾' => 'ukabila ezkerrera begira: 5. mota',
    '🤛🏿' => 'ukabila ezkerrera begira: 6. mota',
    '🤜🏻' => 'ukabila eskuinera begira: 1–2. mota',
    '🤜🏼' => 'ukabila eskuinera begira: 3. mota',
    '🤜🏽' => 'ukabila eskuinera begira: bitarteko azal-tonua',
    '🤜🏾' => 'ukabila eskuinera begira: 5. mota',
    '🤜🏿' => 'ukabila eskuinera begira: 6. mota',
    '👏🏻' => 'txaloka ari diren eskuak: 1–2. mota',
    '👏🏼' => 'txaloka ari diren eskuak: 3. mota',
    '👏🏽' => 'txaloka ari diren eskuak: bitarteko azal-tonua',
    '👏🏾' => 'txaloka ari diren eskuak: 5. mota',
    '👏🏿' => 'txaloka ari diren eskuak: 6. mota',
    '🙌🏻' => 'eskuak altxatzen ari den pertsona: 1–2. mota',
    '🙌🏼' => 'eskuak altxatzen ari den pertsona: 3. mota',
    '🙌🏽' => 'eskuak altxatzen ari den pertsona: bitarteko azal-tonua',
    '🙌🏾' => 'eskuak altxatzen ari den pertsona: 5. mota',
    '🙌🏿' => 'eskuak altxatzen ari den pertsona: 6. mota',
    '🫶🏻' => 'bihotz-forma egiten ari diren eskuak: 1–2. mota',
    '🫶🏼' => 'bihotz-forma egiten ari diren eskuak: 3. mota',
    '🫶🏽' => 'bihotz-forma egiten ari diren eskuak: bitarteko azal-tonua',
    '🫶🏾' => 'bihotz-forma egiten ari diren eskuak: 5. mota',
    '🫶🏿' => 'bihotz-forma egiten ari diren eskuak: 6. mota',
    '👐🏻' => 'esku irekiak: 1–2. mota',
    '👐🏼' => 'esku irekiak: 3. mota',
    '👐🏽' => 'esku irekiak: bitarteko azal-tonua',
    '👐🏾' => 'esku irekiak: 5. mota',
    '👐🏿' => 'esku irekiak: 6. mota',
    '🤲🏻' => 'esku-azpiak elkartuta: 1–2. mota',
    '🤲🏼' => 'esku-azpiak elkartuta: 3. mota',
    '🤲🏽' => 'esku-azpiak elkartuta: bitarteko azal-tonua',
    '🤲🏾' => 'esku-azpiak elkartuta: 5. mota',
    '🤲🏿' => 'esku-azpiak elkartuta: 6. mota',
    '🤝🏻' => 'esku-ematea: 1–2. mota',
    '🤝🏼' => 'esku-ematea: 3. mota',
    '🤝🏽' => 'esku-ematea: bitarteko azal-tonua',
    '🤝🏾' => 'esku-ematea: 5. mota',
    '🤝🏿' => 'esku-ematea: 6. mota',
    '🙏🏻' => 'erregutzen ari diren eskuak: 1–2. mota',
    '🙏🏼' => 'erregutzen ari diren eskuak: 3. mota',
    '🙏🏽' => 'erregutzen ari diren eskuak: bitarteko azal-tonua',
    '🙏🏾' => 'erregutzen ari diren eskuak: 5. mota',
    '🙏🏿' => 'erregutzen ari diren eskuak: 6. mota',
    '✍🏻' => 'idazten ari den eskua: 1–2. mota',
    '✍🏼' => 'idazten ari den eskua: 3. mota',
    '✍🏽' => 'idazten ari den eskua: bitarteko azal-tonua',
    '✍🏾' => 'idazten ari den eskua: 5. mota',
    '✍🏿' => 'idazten ari den eskua: 6. mota',
    '💅🏻' => 'azazkaletako esmaltea: 1–2. mota',
    '💅🏼' => 'azazkaletako esmaltea: 3. mota',
    '💅🏽' => 'azazkaletako esmaltea: bitarteko azal-tonua',
    '💅🏾' => 'azazkaletako esmaltea: 5. mota',
    '💅🏿' => 'azazkaletako esmaltea: 6. mota',
    '🤳🏻' => 'autoargazkia: 1–2. mota',
    '🤳🏼' => 'autoargazkia: 3. mota',
    '🤳🏽' => 'autoargazkia: bitarteko azal-tonua',
    '🤳🏾' => 'autoargazkia: 5. mota',
    '🤳🏿' => 'autoargazkia: 6. mota',
    '💪🏻' => 'bizepsak: 1–2. mota',
    '💪🏼' => 'bizepsak: 3. mota',
    '💪🏽' => 'bizepsak: bitarteko azal-tonua',
    '💪🏾' => 'bizepsak: 5. mota',
    '💪🏿' => 'bizepsak: 6. mota',
    '🦵🏻' => 'hanka: 1–2. mota',
    '🦵🏼' => 'hanka: 3. mota',
    '🦵🏽' => 'hanka: bitarteko azal-tonua',
    '🦵🏾' => 'hanka: 5. mota',
    '🦵🏿' => 'hanka: 6. mota',
    '🦶🏻' => 'oin: 1–2. mota',
    '🦶🏼' => 'oin: 3. mota',
    '🦶🏽' => 'oin: bitarteko azal-tonua',
    '🦶🏾' => 'oin: 5. mota',
    '🦶🏿' => 'oin: 6. mota',
    '👂🏻' => 'belarri: 1–2. mota',
    '👂🏼' => 'belarri: 3. mota',
    '👂🏽' => 'belarri: bitarteko azal-tonua',
    '👂🏾' => 'belarri: 5. mota',
    '👂🏿' => 'belarri: 6. mota',
    '🦻🏻' => 'audifonoa duen belarria: 1–2. mota',
    '🦻🏼' => 'audifonoa duen belarria: 3. mota',
    '🦻🏽' => 'audifonoa duen belarria: bitarteko azal-tonua',
    '🦻🏾' => 'audifonoa duen belarria: 5. mota',
    '🦻🏿' => 'audifonoa duen belarria: 6. mota',
    '👃🏻' => 'sudur: 1–2. mota',
    '👃🏼' => 'sudur: 3. mota',
    '👃🏽' => 'sudur: bitarteko azal-tonua',
    '👃🏾' => 'sudur: 5. mota',
    '👃🏿' => 'sudur: 6. mota',
    '👶🏻' => 'haurtxoa: 1–2. mota',
    '👶🏼' => 'haurtxoa: 3. mota',
    '👶🏽' => 'haurtxoa: bitarteko azal-tonua',
    '👶🏾' => 'haurtxoa: 5. mota',
    '👶🏿' => 'haurtxoa: 6. mota',
    '🧒🏻' => 'haur: 1–2. mota',
    '🧒🏼' => 'haur: 3. mota',
    '🧒🏽' => 'haur: bitarteko azal-tonua',
    '🧒🏾' => 'haur: 5. mota',
    '🧒🏿' => 'haur: 6. mota',
    '👦🏻' => 'mutila: 1–2. mota',
    '👦🏼' => 'mutila: 3. mota',
    '👦🏽' => 'mutila: bitarteko azal-tonua',
    '👦🏾' => 'mutila: 5. mota',
    '👦🏿' => 'mutila: 6. mota',
    '👧🏻' => 'neska: 1–2. mota',
    '👧🏼' => 'neska: 3. mota',
    '👧🏽' => 'neska: bitarteko azal-tonua',
    '👧🏾' => 'neska: 5. mota',
    '👧🏿' => 'neska: 6. mota',
    '🧑🏻' => 'pertsona: 1–2. mota',
    '🧑🏼' => 'pertsona: 3. mota',
    '🧑🏽' => 'pertsona: bitarteko azal-tonua',
    '🧑🏾' => 'pertsona: 5. mota',
    '🧑🏿' => 'pertsona: 6. mota',
    '👱🏻' => 'pertsona ilehoria: 1–2. mota',
    '👱🏼' => 'pertsona ilehoria: 3. mota',
    '👱🏽' => 'pertsona ilehoria: bitarteko azal-tonua',
    '👱🏾' => 'pertsona ilehoria: 5. mota',
    '👱🏿' => 'pertsona ilehoria: 6. mota',
    '👨🏻' => 'gizona: 1–2. mota',
    '👨🏼' => 'gizona: 3. mota',
    '👨🏽' => 'gizona: bitarteko azal-tonua',
    '👨🏾' => 'gizona: 5. mota',
    '👨🏿' => 'gizona: 6. mota',
    '🧔🏻' => 'pertsona bizarduna: 1–2. mota',
    '🧔🏼' => 'pertsona bizarduna: 3. mota',
    '🧔🏽' => 'pertsona bizarduna: bitarteko azal-tonua',
    '🧔🏾' => 'pertsona bizarduna: 5. mota',
    '🧔🏿' => 'pertsona bizarduna: 6. mota',
    '👩🏻' => 'emakumea: 1–2. mota',
    '👩🏼' => 'emakumea: 3. mota',
    '👩🏽' => 'emakumea: bitarteko azal-tonua',
    '👩🏾' => 'emakumea: 5. mota',
    '👩🏿' => 'emakumea: 6. mota',
    '🧓🏻' => 'agure: 1–2. mota',
    '🧓🏼' => 'agure: 3. mota',
    '🧓🏽' => 'agure: bitarteko azal-tonua',
    '🧓🏾' => 'agure: 5. mota',
    '🧓🏿' => 'agure: 6. mota',
    '👴🏻' => 'aitona: 1–2. mota',
    '👴🏼' => 'aitona: 3. mota',
    '👴🏽' => 'aitona: bitarteko azal-tonua',
    '👴🏾' => 'aitona: 5. mota',
    '👴🏿' => 'aitona: 6. mota',
    '👵🏻' => 'amona: 1–2. mota',
    '👵🏼' => 'amona: 3. mota',
    '👵🏽' => 'amona: bitarteko azal-tonua',
    '👵🏾' => 'amona: 5. mota',
    '👵🏿' => 'amona: 6. mota',
    '🙍🏻' => 'kopeta zimurtzen ari den pertsona: 1–2. mota',
    '🙍🏼' => 'kopeta zimurtzen ari den pertsona: 3. mota',
    '🙍🏽' => 'kopeta zimurtzen ari den pertsona: bitarteko azal-tonua',
    '🙍🏾' => 'kopeta zimurtzen ari den pertsona: 5. mota',
    '🙍🏿' => 'kopeta zimurtzen ari den pertsona: 6. mota',
    '🙎🏻' => 'pertsona muturtua: 1–2. mota',
    '🙎🏼' => 'pertsona muturtua: 3. mota',
    '🙎🏽' => 'pertsona muturtua: bitarteko azal-tonua',
    '🙎🏾' => 'pertsona muturtua: 5. mota',
    '🙎🏿' => 'pertsona muturtua: 6. mota',
    '🙅🏻' => 'ados ez dagoela adierazten ari den pertsona: 1–2. mota',
    '🙅🏼' => 'ados ez dagoela adierazten ari den pertsona: 3. mota',
    '🙅🏽' => 'ados ez dagoela adierazten ari den pertsona: bitarteko azal-tonua',
    '🙅🏾' => 'ados ez dagoela adierazten ari den pertsona: 5. mota',
    '🙅🏿' => 'ados ez dagoela adierazten ari den pertsona: 6. mota',
    '🙆🏻' => 'ados dagoela adierazten ari den pertsona: 1–2. mota',
    '🙆🏼' => 'ados dagoela adierazten ari den pertsona: 3. mota',
    '🙆🏽' => 'ados dagoela adierazten ari den pertsona: bitarteko azal-tonua',
    '🙆🏾' => 'ados dagoela adierazten ari den pertsona: 5. mota',
    '🙆🏿' => 'ados dagoela adierazten ari den pertsona: 6. mota',
    '💁🏻' => 'eskean dabilen pertsona: 1–2. mota',
    '💁🏼' => 'eskean dabilen pertsona: 3. mota',
    '💁🏽' => 'eskean dabilen pertsona: bitarteko azal-tonua',
    '💁🏾' => 'eskean dabilen pertsona: 5. mota',
    '💁🏿' => 'eskean dabilen pertsona: 6. mota',
    '🙋🏻' => 'eskua altxatzen ari den pertsona: 1–2. mota',
    '🙋🏼' => 'eskua altxatzen ari den pertsona: 3. mota',
    '🙋🏽' => 'eskua altxatzen ari den pertsona: bitarteko azal-tonua',
    '🙋🏾' => 'eskua altxatzen ari den pertsona: 5. mota',
    '🙋🏿' => 'eskua altxatzen ari den pertsona: 6. mota',
    '🧏🏻' => 'gorra: 1–2. mota',
    '🧏🏼' => 'gorra: 3. mota',
    '🧏🏽' => 'gorra: bitarteko azal-tonua',
    '🧏🏾' => 'gorra: 5. mota',
    '🧏🏿' => 'gorra: 6. mota',
    '🙇🏻' => 'burua makurtzen ari den pertsona: 1–2. mota',
    '🙇🏼' => 'burua makurtzen ari den pertsona: 3. mota',
    '🙇🏽' => 'burua makurtzen ari den pertsona: bitarteko azal-tonua',
    '🙇🏾' => 'burua makurtzen ari den pertsona: 5. mota',
    '🙇🏿' => 'burua makurtzen ari den pertsona: 6. mota',
    '🤦🏻' => 'esku-azpia aurpegian: 1–2. mota',
    '🤦🏼' => 'esku-azpia aurpegian: 3. mota',
    '🤦🏽' => 'esku-azpia aurpegian: bitarteko azal-tonua',
    '🤦🏾' => 'esku-azpia aurpegian: 5. mota',
    '🤦🏿' => 'esku-azpia aurpegian: 6. mota',
    '🤷🏻' => 'sorbaldak altxatu: 1–2. mota',
    '🤷🏼' => 'sorbaldak altxatu: 3. mota',
    '🤷🏽' => 'sorbaldak altxatu: bitarteko azal-tonua',
    '🤷🏾' => 'sorbaldak altxatu: 5. mota',
    '🤷🏿' => 'sorbaldak altxatu: 6. mota',
    '👮🏻' => 'polizia: 1–2. mota',
    '👮🏼' => 'polizia: 3. mota',
    '👮🏽' => 'polizia: bitarteko azal-tonua',
    '👮🏾' => 'polizia: 5. mota',
    '👮🏿' => 'polizia: 6. mota',
    '🕵🏻' => 'detektibea: 1–2. mota',
    '🕵🏼' => 'detektibea: 3. mota',
    '🕵🏽' => 'detektibea: bitarteko azal-tonua',
    '🕵🏾' => 'detektibea: 5. mota',
    '🕵🏿' => 'detektibea: 6. mota',
    '💂🏻' => 'zaindaria: 1–2. mota',
    '💂🏼' => 'zaindaria: 3. mota',
    '💂🏽' => 'zaindaria: bitarteko azal-tonua',
    '💂🏾' => 'zaindaria: 5. mota',
    '💂🏿' => 'zaindaria: 6. mota',
    '🥷🏻' => 'ninja: 1–2. mota',
    '🥷🏼' => 'ninja: 3. mota',
    '🥷🏽' => 'ninja: bitarteko azal-tonua',
    '🥷🏾' => 'ninja: 5. mota',
    '🥷🏿' => 'ninja: 6. mota',
    '👷🏻' => 'eskulangilea: 1–2. mota',
    '👷🏼' => 'eskulangilea: 3. mota',
    '👷🏽' => 'eskulangilea: bitarteko azal-tonua',
    '👷🏾' => 'eskulangilea: 5. mota',
    '👷🏿' => 'eskulangilea: 6. mota',
    '🫅🏻' => 'koroa bat duen pertsona: 1–2. mota',
    '🫅🏼' => 'koroa bat duen pertsona: 3. mota',
    '🫅🏽' => 'koroa bat duen pertsona: bitarteko azal-tonua',
    '🫅🏾' => 'koroa bat duen pertsona: 5. mota',
    '🫅🏿' => 'koroa bat duen pertsona: 6. mota',
    '🤴🏻' => 'printzea: 1–2. mota',
    '🤴🏼' => 'printzea: 3. mota',
    '🤴🏽' => 'printzea: bitarteko azal-tonua',
    '🤴🏾' => 'printzea: 5. mota',
    '🤴🏿' => 'printzea: 6. mota',
    '👸🏻' => 'printzesa: 1–2. mota',
    '👸🏼' => 'printzesa: 3. mota',
    '👸🏽' => 'printzesa: bitarteko azal-tonua',
    '👸🏾' => 'printzesa: 5. mota',
    '👸🏿' => 'printzesa: 6. mota',
    '👳🏻' => 'turbantea duen petsona: 1–2. mota',
    '👳🏼' => 'turbantea duen petsona: 3. mota',
    '👳🏽' => 'turbantea duen petsona: bitarteko azal-tonua',
    '👳🏾' => 'turbantea duen petsona: 5. mota',
    '👳🏿' => 'turbantea duen petsona: 6. mota',
    '👲🏻' => 'txano txinatarra daraman pertsona: 1–2. mota',
    '👲🏼' => 'txano txinatarra daraman pertsona: 3. mota',
    '👲🏽' => 'txano txinatarra daraman pertsona: bitarteko azal-tonua',
    '👲🏾' => 'txano txinatarra daraman pertsona: 5. mota',
    '👲🏿' => 'txano txinatarra daraman pertsona: 6. mota',
    '🧕🏻' => 'buruan zapi bat daraman emakumea: 1–2. mota',
    '🧕🏼' => 'buruan zapi bat daraman emakumea: 3. mota',
    '🧕🏽' => 'buruan zapi bat daraman emakumea: bitarteko azal-tonua',
    '🧕🏾' => 'buruan zapi bat daraman emakumea: 5. mota',
    '🧕🏿' => 'buruan zapi bat daraman emakumea: 6. mota',
    '🤵🏻' => 'pertsona esmokinean: 1–2. mota',
    '🤵🏼' => 'pertsona esmokinean: 3. mota',
    '🤵🏽' => 'pertsona esmokinean: bitarteko azal-tonua',
    '🤵🏾' => 'pertsona esmokinean: 5. mota',
    '🤵🏿' => 'pertsona esmokinean: 6. mota',
    '👰🏻' => 'beloa daraman pertsona: 1–2. mota',
    '👰🏼' => 'beloa daraman pertsona: 3. mota',
    '👰🏽' => 'beloa daraman pertsona: bitarteko azal-tonua',
    '👰🏾' => 'beloa daraman pertsona: 5. mota',
    '👰🏿' => 'beloa daraman pertsona: 6. mota',
    '🤰🏻' => 'emakumea haurdun: 1–2. mota',
    '🤰🏼' => 'emakumea haurdun: 3. mota',
    '🤰🏽' => 'emakumea haurdun: bitarteko azal-tonua',
    '🤰🏾' => 'emakumea haurdun: 5. mota',
    '🤰🏿' => 'emakumea haurdun: 6. mota',
    '🫃🏻' => 'gizona haurdun: 1–2. mota',
    '🫃🏼' => 'gizona haurdun: 3. mota',
    '🫃🏽' => 'gizona haurdun: bitarteko azal-tonua',
    '🫃🏾' => 'gizona haurdun: 5. mota',
    '🫃🏿' => 'gizona haurdun: 6. mota',
    '🫄🏻' => 'pertsona haurdun: 1–2. mota',
    '🫄🏼' => 'pertsona haurdun: 3. mota',
    '🫄🏽' => 'pertsona haurdun: bitarteko azal-tonua',
    '🫄🏾' => 'pertsona haurdun: 5. mota',
    '🫄🏿' => 'pertsona haurdun: 6. mota',
    '🤱🏻' => 'bularra ematea: 1–2. mota',
    '🤱🏼' => 'bularra ematea: 3. mota',
    '🤱🏽' => 'bularra ematea: bitarteko azal-tonua',
    '🤱🏾' => 'bularra ematea: 5. mota',
    '🤱🏿' => 'bularra ematea: 6. mota',
    '👼🏻' => 'aingeru-itxura duen haurtxoa: 1–2. mota',
    '👼🏼' => 'aingeru-itxura duen haurtxoa: 3. mota',
    '👼🏽' => 'aingeru-itxura duen haurtxoa: bitarteko azal-tonua',
    '👼🏾' => 'aingeru-itxura duen haurtxoa: 5. mota',
    '👼🏿' => 'aingeru-itxura duen haurtxoa: 6. mota',
    '🎅🏻' => 'aita noel: 1–2. mota',
    '🎅🏼' => 'aita noel: 3. mota',
    '🎅🏽' => 'aita noel: bitarteko azal-tonua',
    '🎅🏾' => 'aita noel: 5. mota',
    '🎅🏿' => 'aita noel: 6. mota',
    '🤶🏻' => 'gabonetako ama: 1–2. mota',
    '🤶🏼' => 'gabonetako ama: 3. mota',
    '🤶🏽' => 'gabonetako ama: bitarteko azal-tonua',
    '🤶🏾' => 'gabonetako ama: 5. mota',
    '🤶🏿' => 'gabonetako ama: 6. mota',
    '🦸🏻' => 'superheroi: 1–2. mota',
    '🦸🏼' => 'superheroi: 3. mota',
    '🦸🏽' => 'superheroi: bitarteko azal-tonua',
    '🦸🏾' => 'superheroi: 5. mota',
    '🦸🏿' => 'superheroi: 6. mota',
    '🦹🏻' => 'superbilau: 1–2. mota',
    '🦹🏼' => 'superbilau: 3. mota',
    '🦹🏽' => 'superbilau: bitarteko azal-tonua',
    '🦹🏾' => 'superbilau: 5. mota',
    '🦹🏿' => 'superbilau: 6. mota',
    '🧙🏻' => 'mago: 1–2. mota',
    '🧙🏼' => 'mago: 3. mota',
    '🧙🏽' => 'mago: bitarteko azal-tonua',
    '🧙🏾' => 'mago: 5. mota',
    '🧙🏿' => 'mago: 6. mota',
    '🧚🏻' => 'maitagarri: 1–2. mota',
    '🧚🏼' => 'maitagarri: 3. mota',
    '🧚🏽' => 'maitagarri: bitarteko azal-tonua',
    '🧚🏾' => 'maitagarri: 5. mota',
    '🧚🏿' => 'maitagarri: 6. mota',
    '🧛🏻' => 'banpiro: 1–2. mota',
    '🧛🏼' => 'banpiro: 3. mota',
    '🧛🏽' => 'banpiro: bitarteko azal-tonua',
    '🧛🏾' => 'banpiro: 5. mota',
    '🧛🏿' => 'banpiro: 6. mota',
    '🧜🏻' => 'itsas izaki: 1–2. mota',
    '🧜🏼' => 'itsas izaki: 3. mota',
    '🧜🏽' => 'itsas izaki: bitarteko azal-tonua',
    '🧜🏾' => 'itsas izaki: 5. mota',
    '🧜🏿' => 'itsas izaki: 6. mota',
    '🧝🏻' => 'elfo: 1–2. mota',
    '🧝🏼' => 'elfo: 3. mota',
    '🧝🏽' => 'elfo: bitarteko azal-tonua',
    '🧝🏾' => 'elfo: 5. mota',
    '🧝🏿' => 'elfo: 6. mota',
    '💆🏻' => 'masajea egiten ari dioten pertsona: 1–2. mota',
    '💆🏼' => 'masajea egiten ari dioten pertsona: 3. mota',
    '💆🏽' => 'masajea egiten ari dioten pertsona: bitarteko azal-tonua',
    '💆🏾' => 'masajea egiten ari dioten pertsona: 5. mota',
    '💆🏿' => 'masajea egiten ari dioten pertsona: 6. mota',
    '💇🏻' => 'ilea mozten ari dioten pertsona: 1–2. mota',
    '💇🏼' => 'ilea mozten ari dioten pertsona: 3. mota',
    '💇🏽' => 'ilea mozten ari dioten pertsona: bitarteko azal-tonua',
    '💇🏾' => 'ilea mozten ari dioten pertsona: 5. mota',
    '💇🏿' => 'ilea mozten ari dioten pertsona: 6. mota',
    '🚶🏻' => 'oinez ari den pertsona: 1–2. mota',
    '🚶🏼' => 'oinez ari den pertsona: 3. mota',
    '🚶🏽' => 'oinez ari den pertsona: bitarteko azal-tonua',
    '🚶🏾' => 'oinez ari den pertsona: 5. mota',
    '🚶🏿' => 'oinez ari den pertsona: 6. mota',
    '🧍🏻' => 'zutik dagoen pertsona: 1–2. mota',
    '🧍🏼' => 'zutik dagoen pertsona: 3. mota',
    '🧍🏽' => 'zutik dagoen pertsona: bitarteko azal-tonua',
    '🧍🏾' => 'zutik dagoen pertsona: 5. mota',
    '🧍🏿' => 'zutik dagoen pertsona: 6. mota',
    '🧎🏻' => 'belauniko dagoen pertsona: 1–2. mota',
    '🧎🏼' => 'belauniko dagoen pertsona: 3. mota',
    '🧎🏽' => 'belauniko dagoen pertsona: bitarteko azal-tonua',
    '🧎🏾' => 'belauniko dagoen pertsona: 5. mota',
    '🧎🏿' => 'belauniko dagoen pertsona: 6. mota',
    '🏃🏻' => 'korrika ari den pertsona: 1–2. mota',
    '🏃🏼' => 'korrika ari den pertsona: 3. mota',
    '🏃🏽' => 'korrika ari den pertsona: bitarteko azal-tonua',
    '🏃🏾' => 'korrika ari den pertsona: 5. mota',
    '🏃🏿' => 'korrika ari den pertsona: 6. mota',
    '💃🏻' => 'dantzan ari den emakumea: 1–2. mota',
    '💃🏼' => 'dantzan ari den emakumea: 3. mota',
    '💃🏽' => 'dantzan ari den emakumea: bitarteko azal-tonua',
    '💃🏾' => 'dantzan ari den emakumea: 5. mota',
    '💃🏿' => 'dantzan ari den emakumea: 6. mota',
    '🕺🏻' => 'gizona dantzan: 1–2. mota',
    '🕺🏼' => 'gizona dantzan: 3. mota',
    '🕺🏽' => 'gizona dantzan: bitarteko azal-tonua',
    '🕺🏾' => 'gizona dantzan: 5. mota',
    '🕺🏿' => 'gizona dantzan: 6. mota',
    '🕴🏻' => 'trajea daraman eta lebitatzen ari den gizona: 1–2. mota',
    '🕴🏼' => 'trajea daraman eta lebitatzen ari den gizona: 3. mota',
    '🕴🏽' => 'trajea daraman eta lebitatzen ari den gizona: bitarteko azal-tonua',
    '🕴🏾' => 'trajea daraman eta lebitatzen ari den gizona: 5. mota',
    '🕴🏿' => 'trajea daraman eta lebitatzen ari den gizona: 6. mota',
    '👯🏻' => 'jendea untxi-belarriak jantzita: 1–2. mota',
    '👯🏼' => 'jendea untxi-belarriak jantzita: 3. mota',
    '👯🏽' => 'jendea untxi-belarriak jantzita: bitarteko azal-tonua',
    '👯🏾' => 'jendea untxi-belarriak jantzita: 5. mota',
    '👯🏿' => 'jendea untxi-belarriak jantzita: 6. mota',
    '🧖🏻' => 'pertsona bat lurrun-gelan: 1–2. mota',
    '🧖🏼' => 'pertsona bat lurrun-gelan: 3. mota',
    '🧖🏽' => 'pertsona bat lurrun-gelan: bitarteko azal-tonua',
    '🧖🏾' => 'pertsona bat lurrun-gelan: 5. mota',
    '🧖🏿' => 'pertsona bat lurrun-gelan: 6. mota',
    '🧗🏻' => 'pertsona bat eskalatzen: 1–2. mota',
    '🧗🏼' => 'pertsona bat eskalatzen: 3. mota',
    '🧗🏽' => 'pertsona bat eskalatzen: bitarteko azal-tonua',
    '🧗🏾' => 'pertsona bat eskalatzen: 5. mota',
    '🧗🏿' => 'pertsona bat eskalatzen: 6. mota',
    '🏇🏻' => 'zaldi-lasterketa: 1–2. mota',
    '🏇🏼' => 'zaldi-lasterketa: 3. mota',
    '🏇🏽' => 'zaldi-lasterketa: bitarteko azal-tonua',
    '🏇🏾' => 'zaldi-lasterketa: 5. mota',
    '🏇🏿' => 'zaldi-lasterketa: 6. mota',
    '🏂🏻' => 'snowboardlaria: 1–2. mota',
    '🏂🏼' => 'snowboardlaria: 3. mota',
    '🏂🏽' => 'snowboardlaria: bitarteko azal-tonua',
    '🏂🏾' => 'snowboardlaria: 5. mota',
    '🏂🏿' => 'snowboardlaria: 6. mota',
    '🏌🏻' => 'golflaria: 1–2. mota',
    '🏌🏼' => 'golflaria: 3. mota',
    '🏌🏽' => 'golflaria: bitarteko azal-tonua',
    '🏌🏾' => 'golflaria: 5. mota',
    '🏌🏿' => 'golflaria: 6. mota',
    '🏄🏻' => 'surflaria: 1–2. mota',
    '🏄🏼' => 'surflaria: 3. mota',
    '🏄🏽' => 'surflaria: bitarteko azal-tonua',
    '🏄🏾' => 'surflaria: 5. mota',
    '🏄🏿' => 'surflaria: 6. mota',
    '🚣🏻' => 'arraunlaria: 1–2. mota',
    '🚣🏼' => 'arraunlaria: 3. mota',
    '🚣🏽' => 'arraunlaria: bitarteko azal-tonua',
    '🚣🏾' => 'arraunlaria: 5. mota',
    '🚣🏿' => 'arraunlaria: 6. mota',
    '🏊🏻' => 'igerilaria: 1–2. mota',
    '🏊🏼' => 'igerilaria: 3. mota',
    '🏊🏽' => 'igerilaria: bitarteko azal-tonua',
    '🏊🏾' => 'igerilaria: 5. mota',
    '🏊🏿' => 'igerilaria: 6. mota',
    '⛹🏻' => 'baloi bat duen pertsona: 1–2. mota',
    '⛹🏼' => 'baloi bat duen pertsona: 3. mota',
    '⛹🏽' => 'baloi bat duen pertsona: bitarteko azal-tonua',
    '⛹🏾' => 'baloi bat duen pertsona: 5. mota',
    '⛹🏿' => 'baloi bat duen pertsona: 6. mota',
    '🏋🏻' => 'pisuak altxatzen ari den pertsona: 1–2. mota',
    '🏋🏼' => 'pisuak altxatzen ari den pertsona: 3. mota',
    '🏋🏽' => 'pisuak altxatzen ari den pertsona: bitarteko azal-tonua',
    '🏋🏾' => 'pisuak altxatzen ari den pertsona: 5. mota',
    '🏋🏿' => 'pisuak altxatzen ari den pertsona: 6. mota',
    '🚴🏻' => 'txirrindularia: 1–2. mota',
    '🚴🏼' => 'txirrindularia: 3. mota',
    '🚴🏽' => 'txirrindularia: bitarteko azal-tonua',
    '🚴🏾' => 'txirrindularia: 5. mota',
    '🚴🏿' => 'txirrindularia: 6. mota',
    '🚵🏻' => 'mendiko bizikletan dabilen pertsona: 1–2. mota',
    '🚵🏼' => 'mendiko bizikletan dabilen pertsona: 3. mota',
    '🚵🏽' => 'mendiko bizikletan dabilen pertsona: bitarteko azal-tonua',
    '🚵🏾' => 'mendiko bizikletan dabilen pertsona: 5. mota',
    '🚵🏿' => 'mendiko bizikletan dabilen pertsona: 6. mota',
    '🤸🏻' => 'alboko gurpila: 1–2. mota',
    '🤸🏼' => 'alboko gurpila: 3. mota',
    '🤸🏽' => 'alboko gurpila: bitarteko azal-tonua',
    '🤸🏾' => 'alboko gurpila: 5. mota',
    '🤸🏿' => 'alboko gurpila: 6. mota',
    '🤼🏻' => 'borrokalariak: 1–2. mota',
    '🤼🏼' => 'borrokalariak: 3. mota',
    '🤼🏽' => 'borrokalariak: bitarteko azal-tonua',
    '🤼🏾' => 'borrokalariak: 5. mota',
    '🤼🏿' => 'borrokalariak: 6. mota',
    '🤽🏻' => 'waterpoloa: 1–2. mota',
    '🤽🏼' => 'waterpoloa: 3. mota',
    '🤽🏽' => 'waterpoloa: bitarteko azal-tonua',
    '🤽🏾' => 'waterpoloa: 5. mota',
    '🤽🏿' => 'waterpoloa: 6. mota',
    '🤾🏻' => 'eskubaloia: 1–2. mota',
    '🤾🏼' => 'eskubaloia: 3. mota',
    '🤾🏽' => 'eskubaloia: bitarteko azal-tonua',
    '🤾🏾' => 'eskubaloia: 5. mota',
    '🤾🏿' => 'eskubaloia: 6. mota',
    '🤹🏻' => 'malabarismoa: 1–2. mota',
    '🤹🏼' => 'malabarismoa: 3. mota',
    '🤹🏽' => 'malabarismoa: bitarteko azal-tonua',
    '🤹🏾' => 'malabarismoa: 5. mota',
    '🤹🏿' => 'malabarismoa: 6. mota',
    '🧘🏻' => 'pertsona bat loto-posizioan: 1–2. mota',
    '🧘🏼' => 'pertsona bat loto-posizioan: 3. mota',
    '🧘🏽' => 'pertsona bat loto-posizioan: bitarteko azal-tonua',
    '🧘🏾' => 'pertsona bat loto-posizioan: 5. mota',
    '🧘🏿' => 'pertsona bat loto-posizioan: 6. mota',
    '🛀🏻' => 'pertsona bat bainatzen: 1–2. mota',
    '🛀🏼' => 'pertsona bat bainatzen: 3. mota',
    '🛀🏽' => 'pertsona bat bainatzen: bitarteko azal-tonua',
    '🛀🏾' => 'pertsona bat bainatzen: 5. mota',
    '🛀🏿' => 'pertsona bat bainatzen: 6. mota',
    '🛌🏻' => 'pertsona bat ohean: 1–2. mota',
    '🛌🏼' => 'pertsona bat ohean: 3. mota',
    '🛌🏽' => 'pertsona bat ohean: bitarteko azal-tonua',
    '🛌🏾' => 'pertsona bat ohean: 5. mota',
    '🛌🏿' => 'pertsona bat ohean: 6. mota',
    '👭🏻' => 'bi emakume elkarri eskua ematen: 1–2. mota',
    '👭🏼' => 'bi emakume elkarri eskua ematen: 3. mota',
    '👭🏽' => 'bi emakume elkarri eskua ematen: bitarteko azal-tonua',
    '👭🏾' => 'bi emakume elkarri eskua ematen: 5. mota',
    '👭🏿' => 'bi emakume elkarri eskua ematen: 6. mota',
    '👫🏻' => 'gizon-emakumeak elkarri eskua ematen: 1–2. mota',
    '👫🏼' => 'gizon-emakumeak elkarri eskua ematen: 3. mota',
    '👫🏽' => 'gizon-emakumeak elkarri eskua ematen: bitarteko azal-tonua',
    '👫🏾' => 'gizon-emakumeak elkarri eskua ematen: 5. mota',
    '👫🏿' => 'gizon-emakumeak elkarri eskua ematen: 6. mota',
    '👬🏻' => 'bi gizon elkarri eskua ematen: 1–2. mota',
    '👬🏼' => 'bi gizon elkarri eskua ematen: 3. mota',
    '👬🏽' => 'bi gizon elkarri eskua ematen: bitarteko azal-tonua',
    '👬🏾' => 'bi gizon elkarri eskua ematen: 5. mota',
    '👬🏿' => 'bi gizon elkarri eskua ematen: 6. mota',
    '💏🏻' => 'musu: 1–2. mota',
    '💏🏼' => 'musu: 3. mota',
    '💏🏽' => 'musu: bitarteko azal-tonua',
    '💏🏾' => 'musu: 5. mota',
    '💏🏿' => 'musu: 6. mota',
    '💑🏻' => 'bihotza erdian duen bikotea: 1–2. mota',
    '💑🏼' => 'bihotza erdian duen bikotea: 3. mota',
    '💑🏽' => 'bihotza erdian duen bikotea: bitarteko azal-tonua',
    '💑🏾' => 'bihotza erdian duen bikotea: 5. mota',
    '💑🏿' => 'bihotza erdian duen bikotea: 6. mota',
    '🇦🇨' => 'Bandera: Ascension uhartea',
    '🇦🇩' => 'Bandera: Andorra',
    '🇦🇪' => 'Bandera: Arabiar Emirerri Batuak',
    '🇦🇫' => 'Bandera: Afganistan',
    '🇦🇬' => 'Bandera: Antigua eta Barbuda',
    '🇦🇮' => 'Bandera: Aingira',
    '🇦🇱' => 'Bandera: Albania',
    '🇦🇲' => 'Bandera: Armenia',
    '🇦🇴' => 'Bandera: Angola',
    '🇦🇶' => 'Bandera: Antartika',
    '🇦🇷' => 'Bandera: Argentina',
    '🇦🇸' => 'Bandera: Samoa Estatubatuarra',
    '🇦🇹' => 'Bandera: Austria',
    '🇦🇺' => 'Bandera: Australia',
    '🇦🇼' => 'Bandera: Aruba',
    '🇦🇽' => 'Bandera: Åland',
    '🇦🇿' => 'Bandera: Azerbaijan',
    '🇧🇦' => 'Bandera: Bosnia-Herzegovina',
    '🇧🇧' => 'Bandera: Barbados',
    '🇧🇩' => 'Bandera: Bangladesh',
    '🇧🇪' => 'Bandera: Belgika',
    '🇧🇫' => 'Bandera: Burkina Faso',
    '🇧🇬' => 'Bandera: Bulgaria',
    '🇧🇭' => 'Bandera: Bahrain',
    '🇧🇮' => 'Bandera: Burundi',
    '🇧🇯' => 'Bandera: Benin',
    '🇧🇱' => 'Bandera: Saint Barthélemy',
    '🇧🇲' => 'Bandera: Bermuda',
    '🇧🇳' => 'Bandera: Brunei',
    '🇧🇴' => 'Bandera: Bolivia',
    '🇧🇶' => 'Bandera: Karibeko Herbehereak',
    '🇧🇷' => 'Bandera: Brasil',
    '🇧🇸' => 'Bandera: Bahamak',
    '🇧🇹' => 'Bandera: Bhutan',
    '🇧🇻' => 'Bandera: Bouvet uhartea',
    '🇧🇼' => 'Bandera: Botswana',
    '🇧🇾' => 'Bandera: Bielorrusia',
    '🇧🇿' => 'Bandera: Belize',
    '🇨🇦' => 'Bandera: Kanada',
    '🇨🇨' => 'Bandera: Cocos (Keeling) uharteak',
    '🇨🇩' => 'Bandera: Kongoko Errepublika Demokratikoa',
    '🇨🇫' => 'Bandera: Afrika Erdiko Errepublika',
    '🇨🇬' => 'Bandera: Kongo',
    '🇨🇭' => 'Bandera: Suitza',
    '🇨🇮' => 'Bandera: Boli Kosta',
    '🇨🇰' => 'Bandera: Cook uharteak',
    '🇨🇱' => 'Bandera: Txile',
    '🇨🇲' => 'Bandera: Kamerun',
    '🇨🇳' => 'Bandera: Txina',
    '🇨🇴' => 'Bandera: Kolonbia',
    '🇨🇵' => 'Bandera: Clipperton uhartea',
    '🇨🇶' => 'Bandera: Sark',
    '🇨🇷' => 'Bandera: Costa Rica',
    '🇨🇺' => 'Bandera: Kuba',
    '🇨🇻' => 'Bandera: Cabo Verde',
    '🇨🇼' => 'Bandera: Curaçao',
    '🇨🇽' => 'Bandera: Christmas uhartea',
    '🇨🇾' => 'Bandera: Zipre',
    '🇨🇿' => 'Bandera: Txekia',
    '🇩🇪' => 'Bandera: Alemania',
    '🇩🇬' => 'Bandera: Diego García',
    '🇩🇯' => 'Bandera: Djibuti',
    '🇩🇰' => 'Bandera: Danimarka',
    '🇩🇲' => 'Bandera: Dominika',
    '🇩🇴' => 'Bandera: Dominikar Errepublika',
    '🇩🇿' => 'Bandera: Aljeria',
    '🇪🇦' => 'Bandera: Ceuta eta Melilla',
    '🇪🇨' => 'Bandera: Ekuador',
    '🇪🇪' => 'Bandera: Estonia',
    '🇪🇬' => 'Bandera: Egipto',
    '🇪🇭' => 'Bandera: Mendebaldeko Sahara',
    '🇪🇷' => 'Bandera: Eritrea',
    '🇪🇸' => 'Bandera: Espainia',
    '🇪🇹' => 'Bandera: Etiopia',
    '🇪🇺' => 'Bandera: Europar Batasuna',
    '🇫🇮' => 'Bandera: Finlandia',
    '🇫🇯' => 'Bandera: Fiji',
    '🇫🇰' => 'Bandera: Falklandak',
    '🇫🇲' => 'Bandera: Mikronesia',
    '🇫🇴' => 'Bandera: Faroe uharteak',
    '🇫🇷' => 'Bandera: Frantzia',
    '🇬🇦' => 'Bandera: Gabon',
    '🇬🇧' => 'Bandera: Erresuma Batua',
    '🇬🇩' => 'Bandera: Grenada',
    '🇬🇪' => 'Bandera: Georgia',
    '🇬🇫' => 'Bandera: Guyana Frantsesa',
    '🇬🇬' => 'Bandera: Guernesey',
    '🇬🇭' => 'Bandera: Ghana',
    '🇬🇮' => 'Bandera: Gibraltar',
    '🇬🇱' => 'Bandera: Groenlandia',
    '🇬🇲' => 'Bandera: Gambia',
    '🇬🇳' => 'Bandera: Ginea',
    '🇬🇵' => 'Bandera: Guadalupe',
    '🇬🇶' => 'Bandera: Ekuatore Ginea',
    '🇬🇷' => 'Bandera: Grezia',
    '🇬🇸' => 'Bandera: Hegoaldeko Georgia eta Hegoaldeko Sandwich uharteak',
    '🇬🇹' => 'Bandera: Guatemala',
    '🇬🇺' => 'Bandera: Guam',
    '🇬🇼' => 'Bandera: Ginea Bissau',
    '🇬🇾' => 'Bandera: Guyana',
    '🇭🇰' => 'Bandera: Hong Kong Txinako AEB',
    '🇭🇲' => 'Bandera: Heard eta McDonald uharteak',
    '🇭🇳' => 'Bandera: Honduras',
    '🇭🇷' => 'Bandera: Kroazia',
    '🇭🇹' => 'Bandera: Haiti',
    '🇭🇺' => 'Bandera: Hungaria',
    '🇮🇨' => 'Bandera: Kanariak',
    '🇮🇩' => 'Bandera: Indonesia',
    '🇮🇪' => 'Bandera: Irlanda',
    '🇮🇱' => 'Bandera: Israel',
    '🇮🇲' => 'Bandera: Man uhartea',
    '🇮🇳' => 'Bandera: India',
    '🇮🇴' => 'Bandera: Indiako Ozeanoko lurralde britainiarra',
    '🇮🇶' => 'Bandera: Irak',
    '🇮🇷' => 'Bandera: Iran',
    '🇮🇸' => 'Bandera: Islandia',
    '🇮🇹' => 'Bandera: Italia',
    '🇯🇪' => 'Bandera: Jersey',
    '🇯🇲' => 'Bandera: Jamaika',
    '🇯🇴' => 'Bandera: Jordania',
    '🇯🇵' => 'Bandera: Japonia',
    '🇰🇪' => 'Bandera: Kenya',
    '🇰🇬' => 'Bandera: Kirgizistan',
    '🇰🇭' => 'Bandera: Kanbodia',
    '🇰🇮' => 'Bandera: Kiribati',
    '🇰🇲' => 'Bandera: Komoreak',
    '🇰🇳' => 'Bandera: Saint Kitts eta Nevis',
    '🇰🇵' => 'Bandera: Ipar Korea',
    '🇰🇷' => 'Bandera: Hego Korea',
    '🇰🇼' => 'Bandera: Kuwait',
    '🇰🇾' => 'Bandera: Kaiman uharteak',
    '🇰🇿' => 'Bandera: Kazakhstan',
    '🇱🇦' => 'Bandera: Laos',
    '🇱🇧' => 'Bandera: Libano',
    '🇱🇨' => 'Bandera: Santa Luzia',
    '🇱🇮' => 'Bandera: Liechtenstein',
    '🇱🇰' => 'Bandera: Sri Lanka',
    '🇱🇷' => 'Bandera: Liberia',
    '🇱🇸' => 'Bandera: Lesotho',
    '🇱🇹' => 'Bandera: Lituania',
    '🇱🇺' => 'Bandera: Luxenburgo',
    '🇱🇻' => 'Bandera: Letonia',
    '🇱🇾' => 'Bandera: Libia',
    '🇲🇦' => 'Bandera: Maroko',
    '🇲🇨' => 'Bandera: Monako',
    '🇲🇩' => 'Bandera: Moldavia',
    '🇲🇪' => 'Bandera: Montenegro',
    '🇲🇫' => 'Bandera: San Martin',
    '🇲🇬' => 'Bandera: Madagaskar',
    '🇲🇭' => 'Bandera: Marshall Uharteak',
    '🇲🇰' => 'Bandera: Ipar Mazedonia',
    '🇲🇱' => 'Bandera: Mali',
    '🇲🇲' => 'Bandera: Myanmar (Birmania)',
    '🇲🇳' => 'Bandera: Mongolia',
    '🇲🇴' => 'Bandera: Macau Txinako AEB',
    '🇲🇵' => 'Bandera: Ipar Mariana uharteak',
    '🇲🇶' => 'Bandera: Martinika',
    '🇲🇷' => 'Bandera: Mauritania',
    '🇲🇸' => 'Bandera: Montserrat',
    '🇲🇹' => 'Bandera: Malta',
    '🇲🇺' => 'Bandera: Maurizio',
    '🇲🇻' => 'Bandera: Maldivak',
    '🇲🇼' => 'Bandera: Malawi',
    '🇲🇽' => 'Bandera: Mexiko',
    '🇲🇾' => 'Bandera: Malaysia',
    '🇲🇿' => 'Bandera: Mozambike',
    '🇳🇦' => 'Bandera: Namibia',
    '🇳🇨' => 'Bandera: Kaledonia Berria',
    '🇳🇪' => 'Bandera: Niger',
    '🇳🇫' => 'Bandera: Norfolk uhartea',
    '🇳🇬' => 'Bandera: Nigeria',
    '🇳🇮' => 'Bandera: Nikaragua',
    '🇳🇱' => 'Bandera: Herbehereak',
    '🇳🇴' => 'Bandera: Norvegia',
    '🇳🇵' => 'Bandera: Nepal',
    '🇳🇷' => 'Bandera: Nauru',
    '🇳🇺' => 'Bandera: Niue',
    '🇳🇿' => 'Bandera: Zeelanda Berria',
    '🇴🇲' => 'Bandera: Oman',
    '🇵🇦' => 'Bandera: Panama',
    '🇵🇪' => 'Bandera: Peru',
    '🇵🇫' => 'Bandera: Polinesia Frantsesa',
    '🇵🇬' => 'Bandera: Papua Ginea Berria',
    '🇵🇭' => 'Bandera: Filipinak',
    '🇵🇰' => 'Bandera: Pakistan',
    '🇵🇱' => 'Bandera: Polonia',
    '🇵🇲' => 'Bandera: Saint-Pierre eta Mikelune',
    '🇵🇳' => 'Bandera: Pitcairn uharteak',
    '🇵🇷' => 'Bandera: Puerto Rico',
    '🇵🇸' => 'Bandera: Palestinar Lurralde Okupatuak',
    '🇵🇹' => 'Bandera: Portugal',
    '🇵🇼' => 'Bandera: Palau',
    '🇵🇾' => 'Bandera: Paraguai',
    '🇶🇦' => 'Bandera: Qatar',
    '🇷🇪' => 'Bandera: Reunion',
    '🇷🇴' => 'Bandera: Errumania',
    '🇷🇸' => 'Bandera: Serbia',
    '🇷🇺' => 'Bandera: Errusia',
    '🇷🇼' => 'Bandera: Ruanda',
    '🇸🇦' => 'Bandera: Saudi Arabia',
    '🇸🇧' => 'Bandera: Salomon Uharteak',
    '🇸🇨' => 'Bandera: Seychelleak',
    '🇸🇩' => 'Bandera: Sudan',
    '🇸🇪' => 'Bandera: Suedia',
    '🇸🇬' => 'Bandera: Singapur',
    '🇸🇭' => 'Bandera: Santa Helena',
    '🇸🇮' => 'Bandera: Eslovenia',
    '🇸🇯' => 'Bandera: Svalbard eta Jan Mayen uharteak',
    '🇸🇰' => 'Bandera: Eslovakia',
    '🇸🇱' => 'Bandera: Sierra Leona',
    '🇸🇲' => 'Bandera: San Marino',
    '🇸🇳' => 'Bandera: Senegal',
    '🇸🇴' => 'Bandera: Somalia',
    '🇸🇷' => 'Bandera: Surinam',
    '🇸🇸' => 'Bandera: Hego Sudan',
    '🇸🇹' => 'Bandera: Sao Tome eta Principe',
    '🇸🇻' => 'Bandera: El Salvador',
    '🇸🇽' => 'Bandera: Sint Maarten',
    '🇸🇾' => 'Bandera: Siria',
    '🇸🇿' => 'Bandera: Swazilandia',
    '🇹🇦' => 'Bandera: Tristan da Cunha',
    '🇹🇨' => 'Bandera: Turk eta Caico uharteak',
    '🇹🇩' => 'Bandera: Txad',
    '🇹🇫' => 'Bandera: Hegoaldeko lurralde frantsesak',
    '🇹🇬' => 'Bandera: Togo',
    '🇹🇭' => 'Bandera: Thailandia',
    '🇹🇯' => 'Bandera: Tajikistan',
    '🇹🇰' => 'Bandera: Tokelau',
    '🇹🇱' => 'Bandera: Ekialdeko Timor',
    '🇹🇲' => 'Bandera: Turkmenistan',
    '🇹🇳' => 'Bandera: Tunisia',
    '🇹🇴' => 'Bandera: Tonga',
    '🇹🇷' => 'Bandera: Turkia',
    '🇹🇹' => 'Bandera: Trinidad eta Tobago',
    '🇹🇻' => 'Bandera: Tuvalu',
    '🇹🇼' => 'Bandera: Taiwan',
    '🇹🇿' => 'Bandera: Tanzania',
    '🇺🇦' => 'Bandera: Ukraina',
    '🇺🇬' => 'Bandera: Uganda',
    '🇺🇲' => 'Bandera: Ameriketako Estatu Batuetako Kanpoaldeko Uharte Txikiak',
    '🇺🇳' => 'Bandera: Nazio Batuak',
    '🇺🇸' => 'Bandera: Ameriketako Estatu Batuak',
    '🇺🇾' => 'Bandera: Uruguai',
    '🇺🇿' => 'Bandera: Uzbekistan',
    '🇻🇦' => 'Bandera: Vatikano Hiria',
    '🇻🇨' => 'Bandera: Saint Vincent eta Grenadinak',
    '🇻🇪' => 'Bandera: Venezuela',
    '🇻🇬' => 'Bandera: Birjina uharte britainiarrak',
    '🇻🇮' => 'Bandera: Birjina uharte amerikarrak',
    '🇻🇳' => 'Bandera: Vietnam',
    '🇻🇺' => 'Bandera: Vanuatu',
    '🇼🇫' => 'Bandera: Wallis eta Futuna',
    '🇼🇸' => 'Bandera: Samoa',
    '🇽🇰' => 'Bandera: Kosovo',
    '🇾🇪' => 'Bandera: Yemen',
    '🇾🇹' => 'Bandera: Mayotte',
    '🇿🇦' => 'Bandera: Hegoafrika',
    '🇿🇲' => 'Bandera: Zambia',
    '🇿🇼' => 'Bandera: Zimbabwe',
    '🔟' => 'Tekla: 10',
    '🏻' => '1–2. mota',
    '🏼' => '3. mota',
    '🏽' => 'bitarteko azal-tonua',
    '🏾' => '5. mota',
    '🏿' => '6. mota',
    '😀' => 'barre egiten ari den aurpegia',
    '😃' => 'barre egiten ari den aurpegia, ahoa irekita',
    '😄' => 'begiez barreka ari den aurpegia',
    '😁' => 'begiez barre egiten ari den aurpegia',
    '😆' => 'barreka ari den aurpegia, begiak itxita',
    '😅' => 'barreka ari den aurpegia, izerdi hotzarekin',
    '🤣' => 'barrez leherka',
    '😂' => 'pozez negar egiten ari den aurpegia',
    '🙂' => 'apur bat irribarre egiten ari den aurpegia',
    '🙃' => 'buruz behera dagoen aurpegia',
    '🫠' => 'urtzen ari den aurpegia',
    '😉' => 'begiaz keinu egiten ari den aurpegia',
    '😊' => 'begiez irribarre egiten ari den aurpegia',
    '😇' => 'barreka ari den aurpegia argi-koroarekin',
    '🥰' => 'irri egiten ari den aurpegia, 3 bihotzekin',
    '😍' => 'aurpegia barreka, bihotz-itxurako begiekin',
    '🤩' => 'izar',
    '😘' => 'musu bat bidaltzen ari den aurpegia',
    '😗' => 'musuka ari den aurpegia',
    '☺' => 'irribarre egiten ari den aurpegia',
    '😚' => 'musuka ari den aurpegia, begiak itxita',
    '😙' => 'musuka eta begiez barreka ari den aurpegia',
    '🥲' => 'barreka ari den aurpegia, malko batekin',
    '😋' => 'janari gozoa dastatzen ari den aurpegia',
    '😛' => 'mingaina kanpoan duen aurpegia',
    '😜' => 'mihia aterata begi-keinuka ari den aurpegia',
    '🤪' => 'ero-aurpegia',
    '😝' => 'mihia aterata eta begiak itxita dauzkan aurpegia',
    '🤑' => 'diru-itxurako mingaina duen aurpegia',
    '🤗' => 'besarkada ematen ari den aurpegia',
    '🤭' => 'eskuaz ahoa estaltzen ari den aurpegia',
    '🫢' => 'begiak irekita dauzkan eta ahoaren parean eskua duen aurpegia',
    '🫣' => 'begi batekin espiatzen ari den aurpegia',
    '🤫' => 'isiltasuna eskatzen ari den aurpegia',
    '🤔' => 'pentsatzen ari den aurpegia',
    '🫡' => 'agurtzen ari den aurpegia',
    '🤐' => 'kremaileradun ahoa duen aurpegia',
    '🤨' => 'bekaina jasota duen aurpegia',
    '😐' => 'aurpegi neutrala',
    '😑' => 'espresiorik gabeko aurpegia',
    '😶' => 'ahorik gabeko aurpegia',
    '🫥' => 'lerro etenarekin egindako aurpegia',
    '😏' => 'handitasun-aurpegia',
    '😒' => 'aspertu-aurpegia',
    '🙄' => 'begiak bueltaka dituen aurpegia',
    '😬' => 'imintzio-aurpegia',
    '🤥' => 'aurpegi gezurtia',
    '🫨' => 'dardarka ari den aurpegia',
    '😌' => 'lasaitasun-aurpegia',
    '😔' => 'aurpegi pentsakorra',
    '😪' => 'logura-aurpegia',
    '🤤' => 'aurpegia lerdea dariola',
    '😴' => 'lo dagoen aurpegia',
    '🫩' => 'begien azpian poltsak dituen aurpegia',
    '😷' => 'mediku-maskara daraman aurpegia',
    '🤒' => 'termometroa duen aurpegia',
    '🤕' => 'buruan benda daraman aurpegia',
    '🤢' => 'aurpegi zorabiatua',
    '🤮' => 'goitika ari den aurpegi',
    '🤧' => 'aurpegia mukiak kentzen',
    '🥵' => 'bero-bero dagoen aurpegia',
    '🥶' => 'aurpegi izoztu',
    '🥴' => 'tentel-aurpegia',
    '😵' => 'zorabio-aurpegia',
    '🤯' => 'lehertzear den burua',
    '🤠' => 'behizain txanodunaren aurpegia',
    '🥳' => 'parrandan dabilen aurpegia',
    '🥸' => 'mozorrotutako aurpegia',
    '😎' => 'aurpegia barreka, eguzkitako betaurrekoekin',
    '🤓' => 'arraro-aurpegia',
    '🧐' => 'monokulo bat duen aurpegia',
    '😕' => 'nahasketa-aurpegia',
    '🫤' => 'ahoa diagonalean duen aurpegia',
    '😟' => 'aurpegi kezkatua',
    '🙁' => 'aurpegi apur bat kopetiluna',
    '☹' => 'kopeta ilunduta duen aurpegia',
    '😮' => 'ahoa irekita duen aurpegia',
    '😯' => 'harridura-aurpegia',
    '😲' => 'harritu-aurpegia',
    '😳' => 'aurpegi gorritua',
    '🫪' => 'aurpegi distortsionatua',
    '🥺' => 'aurpegi erregutzailea',
    '🥹' => 'malkoak dituen begiko aurpegia',
    '😦' => 'kopeta ilun eta ahoa zabalik duen aurpegia',
    '😧' => 'estutasun-aurpegia',
    '😨' => 'ikara-aurpegia',
    '😰' => 'ahoa irekita eta izerdi hotza duen aurpegia',
    '😥' => 'desengainatuta baina lasaiago',
    '😢' => 'negarrez ari den aurpegia',
    '😭' => 'negar eta negar ari den aurpegia',
    '😱' => 'beldurrez oihuka ari den aurpegia',
    '😖' => 'hutsegite-aurpegia',
    '😣' => 'aurpegi nekaezina',
    '😞' => 'etsipen-aurpegia',
    '😓' => 'izerdi hotza duen aurpegia',
    '😩' => 'neke-aurpegia',
    '😫' => 'nekatu-aurpegia',
    '🥱' => 'aharrausi egiten ari den aurpegia',
    '😤' => 'sudurretik kea darion aurpegia',
    '😡' => 'aurpegi muturtua',
    '😠' => 'haserre-aurpegia',
    '🤬' => 'ahoan ikurrak dituen aurpegia',
    '😈' => 'irribarre egiten ari den aurpegi adarduna',
    '👿' => 'deabrua',
    '💀' => 'buru-hezurra',
    '☠' => 'buru-hezurra eta hezur gurutzatuak',
    '💩' => 'kaka-mokordoa',
    '🤡' => 'pailazo-aurpegia',
    '👹' => 'ogroa',
    '👺' => 'iratxoa',
    '👻' => 'mamua',
    '👽' => 'estralurtarra',
    '👾' => 'munstro estralurtarra',
    '🤖' => 'robot-aurpegia',
    '😺' => 'ahoa irekita duen katu-aurpegi irribarretsua',
    '😸' => 'begiez barre egiten ari den katu-aurpegia',
    '😹' => 'pozez negar ari den katu-aurpegia',
    '😻' => 'katu irribarretsua, bihotz-itxurako begiekin',
    '😼' => 'irribarre maltzurra duen katu-aurpegia',
    '😽' => 'begiak itxita musuka ari den katu-aurpegia',
    '🙀' => 'leher eginda dagoen katu-aurpegia',
    '😿' => 'negarrez ari den katu-aurpegia',
    '😾' => 'katu-aurpegi muturtua',
    '🙈' => 'gauza txarrik ikusi nahi ez duen tximua',
    '🙉' => 'gauza txarrik entzun nahi ez duen tximua',
    '🙊' => 'gauza txarrik esan nahi ez duen tximua',
    '💌' => 'maitasun-gutuna',
    '💘' => 'bihotza geziarekin',
    '💝' => 'bihotza begiztarekin',
    '💖' => 'bihotz distiratsua',
    '💗' => 'handitzen ari den bihotza',
    '💓' => 'bihotz-taupada',
    '💞' => 'biraka ari diren bihotzak',
    '💕' => 'bi bihotz',
    '💟' => 'bihotz apaindua',
    '❣' => 'bihotz-itxurako harridura-marka',
    '💔' => 'bihotz hautsia',
    '❤' => 'bihotz gorria',
    '🩷' => 'bihotz arrosa',
    '🧡' => 'bihotz laranja',
    '💛' => 'bihotz horia',
    '💚' => 'bihotz berdea',
    '💙' => 'bihotz urdina',
    '🩵' => 'bihotz urdin argia',
    '💜' => 'bihotz morea',
    '🤎' => 'bihotz marroia',
    '🖤' => 'bihotz beltza',
    '🩶' => 'bihotz grisa',
    '🤍' => 'bihotz zuria',
    '💋' => 'musu-aztarna',
    '💯' => 'ehun puntu',
    '💢' => 'amorruaren ikurra',
    '🫯' => 'borroka-hodeia',
    '💥' => 'eztanda',
    '💫' => 'zorabiatuta',
    '💦' => 'izerdi-tantatxoak',
    '💨' => 'ziztu bizian',
    '🕳' => 'zuloa',
    '💬' => 'bunbuiloa',
    '🗨' => 'ezkerrera doan bunbuiloa',
    '🗯' => 'eskuinera doan sumindura-bunbuiloa',
    '💭' => 'burutazio-bunbuiloa',
    '💤' => 'zzz',
    '👋' => 'mugitzen ari den eskua',
    '🤚' => 'esku-azpia altxatuta',
    '🖐' => 'esku altxatua eta hatz hedatuak',
    '✋' => 'esku altxatua',
    '🖖' => 'vulcandar agur',
    '🫱' => 'eskuinera begira dagoen eskua',
    '🫲' => 'ezkerrera begira dagoen eskua',
    '🫳' => 'esku-ahurra beherantz duen eskua',
    '🫴' => 'esku-ahura gora begira duen eskua',
    '🫷' => 'ezkerrerantz bultza egiten ari den eskua',
    '🫸' => 'eskuinerantz bultza egiten ari den eskua',
    '👌' => 'adostasuna adierazten duen eskua',
    '🤌' => 'hatz elkartuak',
    '🤏' => 'atximurka egiten ari den eskua',
    '✌' => 'garaipena adierazten duen eskua',
    '🤞' => 'hatz gurutzatuak',
    '🫰' => 'erakuslea eta erpurua gurutzatuta',
    '🤟' => 'adarren keinua',
    '🤘' => 'adarrak adierazten dituen eskua',
    '🤙' => 'deitzeko esku-keinua',
    '👈' => 'ezkerrera seinalatzen ari den hatz erakuslea',
    '👉' => 'eskuinera seinalatzen ari den hatz erakuslea',
    '👆' => 'gora seinalatzen ari den hatza',
    '🖕' => 'erdiko hatza',
    '👇' => 'behera seinalatzen ari den hatza',
    '☝' => 'gora seinalatzen ari den hatz erakuslea',
    '🫵' => 'ikusleari seinalatzen dion erakuslea',
    '👍' => 'erpurua gora',
    '👎' => 'erpurua behera',
    '✊' => 'ukabil altxatua',
    '👊' => 'ukabilkada',
    '🤛' => 'ukabila ezkerrera begira',
    '🤜' => 'ukabila eskuinera begira',
    '👏' => 'txaloka ari diren eskuak',
    '🙌' => 'eskuak altxatzen ari den pertsona',
    '🫶' => 'bihotz-forma egiten ari diren eskuak',
    '👐' => 'esku irekiak',
    '🤲' => 'esku-azpiak elkartuta',
    '🤝' => 'esku-ematea',
    '🙏' => 'erregutzen ari diren eskuak',
    '✍' => 'idazten ari den eskua',
    '💅' => 'azazkaletako esmaltea',
    '🤳' => 'autoargazkia',
    '💪' => 'bizepsak',
    '🦾' => 'beso mekanikoa',
    '🦿' => 'hanka mekanikoa',
    '🦵' => 'hanka',
    '🦶' => 'oin',
    '👂' => 'belarri',
    '🦻' => 'audifonoa duen belarria',
    '👃' => 'sudur',
    '🧠' => 'burmuin',
    '🫀' => 'bihotza organoa',
    '🫁' => 'birikak',
    '🦷' => 'hortz',
    '🦴' => 'hezur',
    '👀' => 'begiak',
    '👁' => 'begi',
    '👅' => 'mingain',
    '👄' => 'aho',
    '🫦' => 'ezpainei koska egiten',
    '👶' => 'haurtxoa',
    '🧒' => 'haur',
    '👦' => 'mutila',
    '👧' => 'neska',
    '🧑' => 'pertsona',
    '👱' => 'pertsona ilehoria',
    '👨' => 'gizona',
    '🧔' => 'pertsona bizarduna',
    '👩' => 'emakumea',
    '🧓' => 'agure',
    '👴' => 'aitona',
    '👵' => 'amona',
    '🙍' => 'kopeta zimurtzen ari den pertsona',
    '🙎' => 'pertsona muturtua',
    '🙅' => 'ados ez dagoela adierazten ari den pertsona',
    '🙆' => 'ados dagoela adierazten ari den pertsona',
    '💁' => 'eskean dabilen pertsona',
    '🙋' => 'eskua altxatzen ari den pertsona',
    '🧏' => 'gorra',
    '🙇' => 'burua makurtzen ari den pertsona',
    '🤦' => 'esku-azpia aurpegian',
    '🤷' => 'sorbaldak altxatu',
    '👮' => 'polizia',
    '🕵' => 'detektibea',
    '💂' => 'zaindaria',
    '🥷' => 'ninja',
    '👷' => 'eskulangilea',
    '🫅' => 'koroa bat duen pertsona',
    '🤴' => 'printzea',
    '👸' => 'printzesa',
    '👳' => 'turbantea duen petsona',
    '👲' => 'txano txinatarra daraman pertsona',
    '🧕' => 'buruan zapi bat daraman emakumea',
    '🤵' => 'pertsona esmokinean',
    '👰' => 'beloa daraman pertsona',
    '🤰' => 'emakumea haurdun',
    '🫃' => 'gizona haurdun',
    '🫄' => 'pertsona haurdun',
    '🤱' => 'bularra ematea',
    '👼' => 'aingeru-itxura duen haurtxoa',
    '🎅' => 'aita noel',
    '🤶' => 'gabonetako ama',
    '🦸' => 'superheroi',
    '🦹' => 'superbilau',
    '🧙' => 'mago',
    '🧚' => 'maitagarri',
    '🧛' => 'banpiro',
    '🧜' => 'itsas izaki',
    '🧝' => 'elfo',
    '🧞' => 'iratxo',
    '🧟' => 'zonbi',
    '🧌' => 'trolla',
    '🫈' => 'izaki iletsua',
    '💆' => 'masajea egiten ari dioten pertsona',
    '💇' => 'ilea mozten ari dioten pertsona',
    '🚶' => 'oinez ari den pertsona',
    '🧍' => 'zutik dagoen pertsona',
    '🧎' => 'belauniko dagoen pertsona',
    '🏃' => 'korrika ari den pertsona',
    '💃' => 'dantzan ari den emakumea',
    '🕺' => 'gizona dantzan',
    '🕴' => 'trajea daraman eta lebitatzen ari den gizona',
    '👯' => 'jendea untxi-belarriak jantzita',
    '🧖' => 'pertsona bat lurrun-gelan',
    '🧗' => 'pertsona bat eskalatzen',
    '🤺' => 'eskrimalaria',
    '🏇' => 'zaldi-lasterketa',
    '⛷' => 'eskiatzailea',
    '🏂' => 'snowboardlaria',
    '🏌' => 'golflaria',
    '🏄' => 'surflaria',
    '🚣' => 'arraunlaria',
    '🏊' => 'igerilaria',
    '⛹' => 'baloi bat duen pertsona',
    '🏋' => 'pisuak altxatzen ari den pertsona',
    '🚴' => 'txirrindularia',
    '🚵' => 'mendiko bizikletan dabilen pertsona',
    '🤸' => 'alboko gurpila',
    '🤼' => 'borrokalariak',
    '🤽' => 'waterpoloa',
    '🤾' => 'eskubaloia',
    '🤹' => 'malabarismoa',
    '🧘' => 'pertsona bat loto-posizioan',
    '🛀' => 'pertsona bat bainatzen',
    '🛌' => 'pertsona bat ohean',
    '👭' => 'bi emakume elkarri eskua ematen',
    '👫' => 'gizon-emakumeak elkarri eskua ematen',
    '👬' => 'bi gizon elkarri eskua ematen',
    '💏' => 'musu',
    '💑' => 'bihotza erdian duen bikotea',
    '🗣' => 'aurrera hitz egiten ari den burua',
    '👤' => 'soinaren silueta',
    '👥' => 'soinen siluetak',
    '🫂' => 'elkar besarkatzen ari den jendea',
    '👪' => 'familia',
    '👣' => 'oin-aztarnak',
    '🫆' => 'hatz-marka',
    '🦰' => 'ilegorri',
    '🦱' => 'ile kizkur',
    '🦳' => 'ilezuri',
    '🦲' => 'burusoil',
    '🐵' => 'tximu-aurpegia',
    '🐒' => 'tximua',
    '🦍' => 'gorila',
    '🦧' => 'orangutana',
    '🐶' => 'txakur-aurpegia',
    '🐕' => 'txakur',
    '🦮' => 'itsu-txakurra',
    '🐩' => 'canichea',
    '🐺' => 'otso',
    '🦊' => 'azeria',
    '🦝' => 'mapatxe',
    '🐱' => 'katu-aurpegia',
    '🐈' => 'katua',
    '🦁' => 'lehoi',
    '🐯' => 'tigre-aurpegia',
    '🐅' => 'tigrea',
    '🐆' => 'lehoinabarra',
    '🐴' => 'zaldi-aurpegia',
    '🫎' => 'altzea',
    '🫏' => 'astoa',
    '🐎' => 'zaldia',
    '🦄' => 'adarbakar',
    '🦓' => 'zebra',
    '🦌' => 'oreina',
    '🦬' => 'bisonte',
    '🐮' => 'behi-aurpegi',
    '🐂' => 'idia',
    '🐃' => 'ur-bufaloa',
    '🐄' => 'behia',
    '🐷' => 'txerri-aurpegia',
    '🐖' => 'txerria',
    '🐗' => 'basurdea',
    '🐽' => 'txerri-sudurra',
    '🐏' => 'zikiroa',
    '🐑' => 'ardi',
    '🐐' => 'ahuntza',
    '🐪' => 'gamelua',
    '🐫' => 'bi tontorreko gamelua',
    '🦙' => 'llama',
    '🦒' => 'jirafa',
    '🐘' => 'elefantea',
    '🦣' => 'mamut',
    '🦏' => 'errinozeroa',
    '🦛' => 'hipopotamo',
    '🐭' => 'sagu-aurpegia',
    '🐁' => 'sagua',
    '🐀' => 'arratoia',
    '🐹' => 'hamsterra',
    '🐰' => 'untxi-aurpegia',
    '🐇' => 'untxia',
    '🐿' => 'lurreko urtxintxa',
    '🦫' => 'kastore',
    '🦔' => 'triku',
    '🦇' => 'saguzarra',
    '🐻' => 'hartz',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'nagia',
    '🦦' => 'igaraba',
    '🦨' => 'mofeta',
    '🦘' => 'kanguru',
    '🦡' => 'azkonar',
    '🐾' => 'atzapar-aztarnak',
    '🦃' => 'indioilarra',
    '🐔' => 'oiloa',
    '🐓' => 'oilarra',
    '🐣' => 'arrautzetik irten berri den txita',
    '🐤' => 'txita',
    '🐥' => 'aurrera begira dagoen txita',
    '🐦' => 'txoria',
    '🐧' => 'pinguinoa',
    '🕊' => 'uxoa',
    '🦅' => 'arranoa',
    '🦆' => 'ahatea',
    '🦢' => 'zisne',
    '🦉' => 'hontza',
    '🦤' => 'dodoa',
    '🪶' => 'luma',
    '🦩' => 'flamenkoa',
    '🦚' => 'hegazterren',
    '🦜' => 'loro',
    '🪽' => 'hegoa',
    '🪿' => 'antzara',
    '🐸' => 'igel-aurpegia',
    '🐊' => 'krokodiloa',
    '🐢' => 'dortoka',
    '🦎' => 'sugandila',
    '🐍' => 'sugea',
    '🐲' => 'herensuge-aurpegia',
    '🐉' => 'herensugea',
    '🦕' => 'sauropodo',
    '🦖' => 'T-Rex',
    '🐳' => 'ura jaurtitzen ari den balea',
    '🐋' => 'balea',
    '🐬' => 'izurdea',
    '🫍' => 'Ezpalarta',
    '🦭' => 'itsas txakur',
    '🐟' => 'arrain',
    '🐠' => 'arrain tropikala',
    '🐡' => 'globo-arraina',
    '🦈' => 'marrazoa',
    '🐙' => 'olagarroa',
    '🐚' => 'oskol espirala',
    '🪸' => 'korala',
    '🪼' => 'marmoka',
    '🦀' => 'karramarroa',
    '🦞' => 'otarrain',
    '🦐' => 'ganba',
    '🦑' => 'txibia',
    '🦪' => 'ostra',
    '🐌' => 'barraskiloa',
    '🦋' => 'pinpilinpauxa',
    '🐛' => 'zomorroa',
    '🐜' => 'inurria',
    '🐝' => 'erlea',
    '🪲' => 'kakalardo',
    '🐞' => 'amona mantangorri',
    '🦗' => 'kilker',
    '🪳' => 'labezomorro',
    '🕷' => 'armiarma',
    '🕸' => 'armiarma-sarea',
    '🦂' => 'eskorpioia',
    '🦟' => 'eltxo',
    '🪰' => 'euli',
    '🪱' => 'zizare',
    '🦠' => 'mikrobio',
    '💐' => 'lore sorta',
    '🌸' => 'gereziondo-lorea',
    '💮' => 'lore zuria',
    '🪷' => 'lotoa',
    '🏵' => 'kondekorazioa',
    '🌹' => 'arrosa',
    '🥀' => 'lore zimela',
    '🌺' => 'hibiskoa',
    '🌻' => 'ekilorea',
    '🌼' => 'lorea',
    '🌷' => 'tulipa',
    '🪻' => 'hiazintoa',
    '🌱' => 'kimua',
    '🪴' => 'loreontziko landare',
    '🌲' => 'hosto iraukorreko zuhaitza',
    '🌳' => 'hosto erorkorreko zuhaitza',
    '🌴' => 'palmondoa',
    '🌵' => 'kaktusa',
    '🌾' => 'arroz-zurtointxoak',
    '🌿' => 'belarra',
    '☘' => 'hirusta',
    '🍀' => 'lau hostoko hirusta',
    '🍁' => 'astigarraren hostoa',
    '🍂' => 'eroritako hostoa',
    '🍃' => 'haizeaz hegan ari den hostoa',
    '🪹' => 'habi hutsa',
    '🪺' => 'habia arrautzekin',
    '🍄' => 'barrengorria',
    '🪾' => 'hosto gabeko zuhaitza',
    '🍇' => 'mahatsa',
    '🍈' => 'meloia',
    '🍉' => 'sandia',
    '🍊' => 'mandarina',
    '🍋' => 'limoia',
    '🍌' => 'banana',
    '🍍' => 'anana',
    '🥭' => 'mango',
    '🍎' => 'sagar gorria',
    '🍏' => 'sagar berdea',
    '🍐' => 'udarea',
    '🍑' => 'muxika',
    '🍒' => 'gereziak',
    '🍓' => 'marrubia',
    '🫐' => 'ahabiak',
    '🥝' => 'kiwia',
    '🍅' => 'tomatea',
    '🫒' => 'oliba',
    '🥥' => 'koko',
    '🥑' => 'ahuakatea',
    '🍆' => 'alberjinia',
    '🥔' => 'patata',
    '🥕' => 'azenarioa',
    '🌽' => 'artaburua',
    '🌶' => 'txilea',
    '🫑' => 'piper',
    '🥒' => 'pepinoa',
    '🥬' => 'barazki hostodun',
    '🥦' => 'brokoli',
    '🧄' => 'baratxuria',
    '🧅' => 'tipula',
    '🥜' => 'kakahuetea',
    '🫘' => 'babarrunak',
    '🌰' => 'gaztaina',
    '🫚' => 'jengibrea',
    '🫛' => 'ilar-zorroa',
    '🫜' => 'tuberkulua',
    '🍞' => 'ogi',
    '🥐' => 'croissanta',
    '🥖' => 'baguettea',
    '🫓' => 'ogi zapal',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'opil txikiak',
    '🧇' => 'gofrea',
    '🧀' => 'gazta zatia',
    '🍖' => 'hezurra haragiarekin',
    '🍗' => 'izterra',
    '🥩' => 'haragi-mozketa',
    '🥓' => 'hirugiharra',
    '🍔' => 'hanburgesa',
    '🍟' => 'patata frijituak',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'ogitartekoa',
    '🌮' => 'takoa',
    '🌯' => 'burritoa',
    '🫔' => 'tamal',
    '🥙' => 'ogitarteko betea',
    '🧆' => 'falafela',
    '🥚' => 'arrautza',
    '🍳' => 'janaria prestatu',
    '🥘' => 'sakonera txikiko zartagina',
    '🍲' => 'janari bete eltzea',
    '🫕' => 'fonduea',
    '🥣' => 'katilua eta koilara',
    '🥗' => 'entsalada berdea',
    '🍿' => 'krispetak',
    '🧈' => 'gurina',
    '🧂' => 'gatz',
    '🥫' => 'janaria latetan',
    '🍱' => 'bento kutxa',
    '🍘' => 'arroz-mokadua',
    '🍙' => 'arroz-bola',
    '🍚' => 'arroz egosia',
    '🍛' => 'arroza curryarekin',
    '🍜' => 'kea darion katilua',
    '🍝' => 'espagetiak',
    '🍠' => 'batata errea',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'gabardina-ganba',
    '🍥' => 'arrain-pastela zurrunbiloarekin',
    '🥮' => 'ilargi-pastel',
    '🍡' => 'dango',
    '🥟' => 'dumpling',
    '🥠' => 'zortearen gaileta',
    '🥡' => 'eramateko kaxa',
    '🍦' => 'izozki krematsua',
    '🍧' => 'izotz arraspatua',
    '🍨' => 'izozkia',
    '🍩' => 'donuta',
    '🍪' => 'gaileta',
    '🎂' => 'urtebetetze-tarta',
    '🍰' => 'opiltxoa',
    '🧁' => 'cupcake',
    '🥧' => 'tarta',
    '🍫' => 'txokolatina',
    '🍬' => 'gozokia',
    '🍭' => 'piruleta',
    '🍮' => 'natillak',
    '🍯' => 'ezti-potoa',
    '🍼' => 'biberoia',
    '🥛' => 'edalontzi bat esne',
    '☕' => 'edari beroa',
    '🫖' => 'teontzi',
    '🍵' => 'giderrik gabeko kikara',
    '🍶' => 'sake',
    '🍾' => 'kortxoa kanpoan duen botila',
    '🍷' => 'ardo-kopa',
    '🍸' => 'koktel-kopa',
    '🍹' => 'edari tropikala',
    '🍺' => 'garagardo-pitxerra',
    '🍻' => 'topa egiten ari diren garagardo-pitxerrak',
    '🥂' => 'kopak topa egiten',
    '🥃' => 'edalontzi zabala',
    '🫗' => 'likidoa isurtzen',
    '🥤' => 'kopa eta lastotxoa',
    '🧋' => 'te burbuiladun',
    '🧃' => 'edari-tetrabrika',
    '🧉' => 'matea',
    '🧊' => 'izotz zatia',
    '🥢' => 'zotzak',
    '🍽' => 'platera, sardeska eta labanarekin',
    '🍴' => 'sardeska eta labana',
    '🥄' => 'koilara',
    '🔪' => 'sukaldeko labana',
    '🫙' => 'pitxerra',
    '🏺' => 'anfora',
    '🌍' => 'europa eta afrika ikusgai dituen lur-globoa',
    '🌎' => 'america ikusgai duen lur-globoa',
    '🌏' => 'asia eta australia ikusgai dituen lur-globoa',
    '🌐' => 'globoa eta meridianoak',
    '🗺' => 'munduko mapa',
    '🗾' => 'japoniako mapa',
    '🧭' => 'iparrorratz',
    '🏔' => 'tontorrean elurra duen mendia',
    '⛰' => 'mendia',
    '🛘' => 'lur-jausia',
    '🌋' => 'sumendia',
    '🗻' => 'fuji mendia',
    '🏕' => 'kanpina',
    '🏖' => 'eguzkitakoa hondartzan',
    '🏜' => 'basamortua',
    '🏝' => 'uharte bakartia',
    '🏞' => 'parke nazionala',
    '🏟' => 'estadioa',
    '🏛' => 'eraikin historikoa',
    '🏗' => 'eraikuntza-lanak',
    '🧱' => 'adreilu',
    '🪨' => 'harria',
    '🪵' => 'egurra',
    '🛖' => 'etxola',
    '🏘' => 'etxebizitzak',
    '🏚' => 'etxe abandonatua',
    '🏠' => 'etxebizitza',
    '🏡' => 'etxea eta lorategia',
    '🏢' => 'bulego-eraikina',
    '🏣' => 'japoniako postetxea',
    '🏤' => 'postetxea',
    '🏥' => 'ospitala',
    '🏦' => 'bankua',
    '🏨' => 'hotela',
    '🏩' => 'maitasun-hotela',
    '🏪' => 'supermerkatua',
    '🏫' => 'eskola',
    '🏬' => 'merkataritza-zentroa',
    '🏭' => 'fabrika',
    '🏯' => 'gaztelu japoniarra',
    '🏰' => 'gaztelua',
    '💒' => 'ezkontza',
    '🗼' => 'tokioko dorrea',
    '🗽' => 'askatasunaren estatua',
    '⛪' => 'eliza',
    '🕌' => 'meskita',
    '🛕' => 'tenplu hindua',
    '🕍' => 'sinagoga',
    '⛩' => 'shinto santutegia',
    '🕋' => 'kaaba',
    '⛲' => 'iturria',
    '⛺' => 'denda',
    '🌁' => 'lainotu',
    '🌃' => 'gaua eta izarrak',
    '🏙' => 'hiri-paisaia',
    '🌄' => 'egunsentia mendien artean',
    '🌅' => 'egunsentia',
    '🌆' => 'hiri-paisaia ilunabarrean',
    '🌇' => 'ilunabarra',
    '🌉' => 'zubia gauez',
    '♨' => 'iturri termalak',
    '🎠' => 'karrusela',
    '🛝' => 'txirrista',
    '🎡' => 'noria',
    '🎢' => 'errusiar mendia',
    '💈' => 'bizarginaren adierazle birakaria',
    '🎪' => 'zirkoaren karpa',
    '🚂' => 'tren-makina',
    '🚃' => 'bagoia',
    '🚄' => 'abiadura handiko trena',
    '🚅' => 'bala-trena',
    '🚆' => 'trena',
    '🚇' => 'metroa',
    '🚈' => 'tren arina',
    '🚉' => 'geltokia',
    '🚊' => 'tranbia',
    '🚝' => 'monoraila',
    '🚞' => 'mendiko trenbidea',
    '🚋' => 'tranbiaren bagoi',
    '🚌' => 'autobusa',
    '🚍' => 'heldu den autobusa',
    '🚎' => 'trolebusa',
    '🚐' => 'minibusa',
    '🚑' => 'anbulantzia',
    '🚒' => 'suhiltzaileen kamioia',
    '🚓' => 'poliziaren autoa',
    '🚔' => 'heldu den poliziaren autoa',
    '🚕' => 'taxia',
    '🚖' => 'heldu den taxia',
    '🚗' => 'autoa',
    '🚘' => 'heldu den autoa',
    '🚙' => 'aisiarako ibilgailua',
    '🛻' => 'kamioneta',
    '🚚' => 'garraiatzeko kamioia',
    '🚛' => 'kamioi artikulatua',
    '🚜' => 'traktorea',
    '🏎' => 'lasterketa-autoa',
    '🏍' => 'motozikleta',
    '🛵' => 'motoa',
    '🦽' => 'eskuzko gurpil-aulkia',
    '🦼' => 'gurpil-aulki motorduna',
    '🛺' => 'rickshaw motorduna',
    '🚲' => 'ziklomotorra',
    '🛴' => 'patinetea',
    '🛹' => 'skateboard',
    '🛼' => 'gurpil-lerroko irristailu',
    '🚏' => 'autobus-geltokia',
    '🛣' => 'autobidea',
    '🛤' => 'trenbidearen erraila',
    '🛢' => 'olio-upela',
    '⛽' => 'gasolina-bonba',
    '🛞' => 'gurpila',
    '🚨' => 'poliziaren autoko argia',
    '🚥' => 'semaforo horizontala',
    '🚦' => 'semaforo bertikala',
    '🛑' => 'stop ikurra',
    '🚧' => 'lanak',
    '⚓' => 'aingura',
    '🛟' => 'sirena',
    '⛵' => 'belaontzia',
    '🛶' => 'kanoa',
    '🚤' => 'abiadura handiko txalupa',
    '🛳' => 'gurutzaontzia',
    '⛴' => 'ferrya',
    '🛥' => 'motordun txalupa',
    '🚢' => 'itsasontzia',
    '✈' => 'hegazkina',
    '🛩' => 'hegazkin txikia',
    '🛫' => 'aireratzen ari den hegazkina',
    '🛬' => 'lur hartzen ari den hegazkina',
    '🪂' => 'paraxuta',
    '💺' => 'eserlekua',
    '🚁' => 'helikopteroa',
    '🚟' => 'monorrail esekia',
    '🚠' => 'teleferikoa',
    '🚡' => 'mendiko teleferikoa',
    '🛰' => 'satelitea',
    '🚀' => 'suziria',
    '🛸' => 'plater hegalari',
    '🛎' => 'mahai gaineko txirrina',
    '🧳' => 'ekipaje',
    '⌛' => 'harea-erloju',
    '⏳' => 'harea-erlojua harea dariola',
    '⌚' => 'erlojua',
    '⏰' => 'alarma',
    '⏱' => 'kronometroa',
    '⏲' => 'tenporizadorea',
    '🕰' => 'mahai gaineko erlojua',
    '🕛' => 'hamabiak',
    '🕧' => 'hamabi eta erdiak',
    '🕐' => 'ordu bata',
    '🕜' => 'ordu bat eta erdiak',
    '🕑' => 'ordu biak',
    '🕝' => 'ordu bi eta erdiak',
    '🕒' => 'hirurak',
    '🕞' => 'hiru eta erdiak',
    '🕓' => 'laurak',
    '🕟' => 'lau eta erdiak',
    '🕔' => 'bostak',
    '🕠' => 'bost eta erdiak',
    '🕕' => 'seiak',
    '🕡' => 'sei eta erdiak',
    '🕖' => 'zazpiak',
    '🕢' => 'zazpi eta erdiak',
    '🕗' => 'zortziak',
    '🕣' => 'zortzi eta erdiak',
    '🕘' => 'bederatziak',
    '🕤' => 'bederatzi eta erdiak',
    '🕙' => 'hamarrak',
    '🕥' => 'hamar eta erdiak',
    '🕚' => 'hamaikak',
    '🕦' => 'hamaika eta erdiak',
    '🌑' => 'ilargi berria',
    '🌒' => 'ilgora',
    '🌓' => 'ilgora-erdia',
    '🌔' => 'ilgora-bukaera',
    '🌕' => 'ilargi betea',
    '🌖' => 'ilbehera-hasiera',
    '🌗' => 'ilbehera-erdia',
    '🌘' => 'ilbehera-bukaera',
    '🌙' => 'ilargi-adarra',
    '🌚' => 'ilargi berriaren aurpegia',
    '🌛' => 'lehen ilargi-laurdena aurpegiarekin',
    '🌜' => 'azken ilargi-laurdena aurpegiarekin',
    '🌡' => 'termometro',
    '☀' => 'eguzkia',
    '🌝' => 'ilargi betea aurpegiarekin',
    '🌞' => 'eguzkia aurpegiarekin',
    '🪐' => 'planeta eraztunduna',
    '⭐' => 'izarra',
    '🌟' => 'izar distiratsua',
    '🌠' => 'izar-uxoa',
    '🌌' => 'esne-bidea',
    '☁' => 'hodei',
    '⛅' => 'eguzkia hodei baten atzean',
    '⛈' => 'hodeia tximista eta euriarekin',
    '🌤' => 'eguzkia hodei txiki baten atzean',
    '🌥' => 'eguzkia hodei handi baten atzean',
    '🌦' => 'eguzkia hodei baten atzean euriarekin',
    '🌧' => 'hodeia euriarekin',
    '🌨' => 'hodeia elurrarekin',
    '🌩' => 'hodeia tximistarekin',
    '🌪' => 'tornadoa',
    '🌫' => 'lainoa',
    '🌬' => 'haize-aurpegia',
    '🌀' => 'zikloia',
    '🌈' => 'ortzadarra',
    '🌂' => 'aterki itxia',
    '☂' => 'aterki',
    '☔' => 'aterkia euri-tantekin',
    '⛱' => 'aterkia hondartzan',
    '⚡' => 'tentsio handia',
    '❄' => 'elur-maluta',
    '☃' => 'elurrezko gizona',
    '⛄' => 'elurrezko gizona elurrik gabe',
    '☄' => 'kometa',
    '🔥' => 'sua',
    '💧' => 'tantatxoa',
    '🌊' => 'olatua',
    '🎃' => 'halloweeneko kuia',
    '🎄' => 'gabonetako zuhaitza',
    '🎆' => 'su artifizialak',
    '🎇' => 'bengala',
    '🧨' => 'petardo',
    '✨' => 'distira',
    '🎈' => 'puxika',
    '🎉' => 'aire-serpentina',
    '🎊' => 'konfetiz betetako bola',
    '🎋' => 'tanabata zuhaitza',
    '🎍' => 'pinurako dekorazioa',
    '🎎' => 'panpin japoniarrak',
    '🎏' => 'karpa-itxurako banderatxoak',
    '🎐' => 'haize-kanpaia',
    '🎑' => 'ilargiaren ospakizuna',
    '🧧' => 'gutun-azal gorri',
    '🎀' => 'begizta',
    '🎁' => 'paperez inguratutako oparia',
    '🎗' => 'xingola',
    '🎟' => 'sarrera-txartelak',
    '🎫' => 'txartela',
    '🎖' => 'domina militarra',
    '🏆' => 'trofeoa',
    '🏅' => 'kirol-domina',
    '🥇' => '1. postuaren domina',
    '🥈' => '2. postuaren domina',
    '🥉' => '3. postuaren domina',
    '⚽' => 'futboleko baloia',
    '⚾' => 'beisbola',
    '🥎' => 'sofbol-pilota',
    '🏀' => 'saskibaloia',
    '🏐' => 'boleibola',
    '🏈' => 'futbol amerikarra',
    '🏉' => 'errugbia',
    '🎾' => 'tenisa',
    '🥏' => 'frisbee',
    '🎳' => 'boloak',
    '🏏' => 'kriketa',
    '🏑' => 'belar-hockeya',
    '🏒' => 'izotz-hockeyko makila eta pilota',
    '🥍' => 'lacrosse',
    '🏓' => 'ping-pong',
    '🏸' => 'badmintona',
    '🥊' => 'boxeoko eskularrua',
    '🥋' => 'arte martzialetako kimonoa',
    '🥅' => 'ateko sarea',
    '⛳' => 'bandera zuloan',
    '⛸' => 'izotz-patinajea',
    '🎣' => 'arrantza egiteko kanabera',
    '🤿' => 'urpekari-maskara',
    '🎽' => 'dortsala',
    '🎿' => 'eskiak',
    '🛷' => 'lera',
    '🥌' => 'curling-eko harri',
    '🎯' => 'itua',
    '🪀' => 'yoyoa',
    '🪁' => 'haize-parpaila',
    '🔫' => 'pistola',
    '🎱' => 'billarra',
    '🔮' => 'kristalezko bola',
    '🪄' => 'makiltxo magiko',
    '🎮' => 'bideo-jokoa',
    '🕹' => 'joko-palanka',
    '🎰' => 'txanpon-makina',
    '🎲' => 'dadoa',
    '🧩' => 'buru-hausgarri',
    '🧸' => 'hartzatxo',
    '🪅' => 'gozo-eltze',
    '🪩' => 'beirazko bola',
    '🪆' => 'matrioxka',
    '♠' => 'pika',
    '♥' => 'bihotza',
    '♦' => 'diamanteak',
    '♣' => 'hirustak',
    '♟' => 'peoi',
    '🃏' => 'komodina',
    '🀄' => 'mahjong dragoi gorria',
    '🎴' => 'loreak dituzten kartak',
    '🎭' => 'arte eszenikoak',
    '🖼' => 'koadroa markoarekin',
    '🎨' => 'margolari-paleta',
    '🧵' => 'hari',
    '🪡' => 'jostorratz',
    '🧶' => 'harilko',
    '🪢' => 'korapilo',
    '👓' => 'betaurrekoak',
    '🕶' => 'eguzkitako betaurrekoak',
    '🥽' => 'igeriketako betaurrekoak',
    '🥼' => 'laborategiko jantzia',
    '🦺' => 'segurtasun-jaka',
    '👔' => 'gorbata',
    '👕' => 'elastikoa',
    '👖' => 'galtza bakeroak',
    '🧣' => 'zapi',
    '🧤' => 'eskularruak',
    '🧥' => 'berokia',
    '🧦' => 'galtzerdiak',
    '👗' => 'soinekoa',
    '👘' => 'kimonoa',
    '🥻' => 'saria',
    '🩱' => 'bainujantzi osoa',
    '🩲' => 'galtzontzilloak',
    '🩳' => 'galtzamotzak',
    '👙' => 'bikinia',
    '👚' => 'emakumeentzako arropa',
    '🪭' => 'eskuko haizemaile tolesgarria',
    '👛' => 'diru-zorroa',
    '👜' => 'eskuko poltsa',
    '👝' => 'zorroa',
    '🛍' => 'erosketa-poltsak',
    '🎒' => 'bizkar-zorroa',
    '🩴' => 'hondartzarako sandalia',
    '👞' => 'gizonentzako oinetakoa',
    '👟' => 'korrika egiteko oinetakoa',
    '🥾' => 'mendiko bota',
    '🥿' => 'zapata laua',
    '👠' => 'oinetako takoidunak',
    '👡' => 'emakumeentzako sandalia',
    '🩰' => 'balleteko oin-puntak',
    '👢' => 'emakumeentzako bota',
    '🪮' => 'apain-orrazia',
    '👑' => 'koroa',
    '👒' => 'emakumeentzako kapelua',
    '🎩' => 'kapelu altua',
    '🎓' => 'graduatu-txanoa',
    '🧢' => 'bixera',
    '🪖' => 'kasko militarra',
    '⛑' => 'kaskoa gurutze zuriarekin',
    '📿' => 'arrosarioa',
    '💄' => 'ezpain-margoa',
    '💍' => 'eraztuna',
    '💎' => 'harribitxia',
    '🔇' => 'bozgorailua itzalita',
    '🔈' => 'bozgorailua bolumen txikian',
    '🔉' => 'bozgorailua piztuta',
    '🔊' => 'bozgorailua ozen',
    '📢' => 'bozgorailu',
    '📣' => 'megafonoa',
    '📯' => 'adarra',
    '🔔' => 'kanpaia',
    '🔕' => 'kanpai marratua',
    '🎼' => 'notazio musikala',
    '🎵' => 'nota musikala',
    '🎶' => 'nota musikalak',
    '🎙' => 'estudioko mikrofonoa',
    '🎚' => 'graduatzailea',
    '🎛' => 'kontrolak',
    '🎤' => 'mikrofonoa',
    '🎧' => 'entzungailuak',
    '📻' => 'irratia',
    '🎷' => 'saxofoia',
    '🎺' => 'tronpeta',
    '🪊' => 'tronboia',
    '🪗' => 'akordeoi',
    '🎸' => 'gitarra',
    '🎹' => 'musika-teklatua',
    '🎻' => 'biolina',
    '🪕' => 'banjoa',
    '🥁' => 'danborra',
    '🪘' => 'danbor luze',
    '🪇' => 'marakak',
    '🪈' => 'txirula',
    '🪉' => 'harpa',
    '📱' => 'telefono mugikorra',
    '📲' => 'telefono mugikorra gezi batekin',
    '☎' => 'telefonoa',
    '📞' => 'telefono-hargailua',
    '📟' => 'bilagailua',
    '📠' => 'faxa',
    '🔋' => 'bateria',
    '🪫' => 'bateria gutxi',
    '🔌' => 'entxufea',
    '💻' => 'ordenagailu eramangarria',
    '🖥' => 'mahaigaineko ordenagailua',
    '🖨' => 'inprimagailua',
    '⌨' => 'teklatua',
    '🖱' => 'ordenagailuko sagua',
    '🖲' => 'kontrolagailua',
    '💽' => 'minidisc-a',
    '💾' => 'disketea',
    '💿' => 'disko optikoa',
    '📀' => 'DVD',
    '🧮' => 'abakoa',
    '🎥' => 'bideokamera profesionala',
    '🎞' => 'filmeko fotogramak',
    '📽' => 'film-proiektorea',
    '🎬' => 'klaketa',
    '📺' => 'telebista',
    '📷' => 'kamera',
    '📸' => 'kamera flasharekin',
    '📹' => 'bideokamera',
    '📼' => 'bideo-kasetea',
    '🔍' => 'ezkerrera begira dagoen lupa',
    '🔎' => 'eskuinera begira dagoen lupa',
    '🕯' => 'kandela',
    '💡' => 'bonbilla',
    '🔦' => 'linterna',
    '🏮' => 'paper gorrizko faroltxoa',
    '🪔' => 'diya lanpara',
    '📔' => 'estalki apaingarria duen koadernoa',
    '📕' => 'liburu itxia',
    '📖' => 'liburu irekia',
    '📗' => 'liburu berdea',
    '📘' => 'liburu urdina',
    '📙' => 'liburu laranja',
    '📚' => 'liburuak',
    '📓' => 'koadernoa',
    '📒' => 'kontabilitate-liburua',
    '📃' => 'orri tolestua',
    '📜' => 'paper-biribilkia',
    '📄' => 'gora begira dagoen orria',
    '📰' => 'egunkaria',
    '🗞' => 'egunkari bildua',
    '📑' => 'laster-markak',
    '🔖' => 'laster-marka',
    '🏷' => 'etiketa',
    '🪙' => 'txanpon',
    '💰' => 'poltsa bete diru',
    '🪎' => 'altxorraren kutxa',
    '💴' => 'yen billetea',
    '💵' => 'dolar billetea',
    '💶' => 'euro billetea',
    '💷' => 'libera billetea',
    '💸' => 'dirua hegoekin',
    '💳' => 'kreditu-txartela',
    '🧾' => 'ordainagiri',
    '💹' => 'diagrama gorakorra yen-ikurrarekin',
    '✉' => 'gutun-azal',
    '📧' => 'mezu elektronikoa',
    '📨' => 'sarrerako gutun-azala',
    '📩' => 'gutun-azala gezi batekin',
    '📤' => 'irteerako erretilua',
    '📥' => 'sarrerako erretilua',
    '📦' => 'paketea',
    '📫' => 'bandera igota duen postontzi itxia',
    '📪' => 'bandera jaitsita duen postontzi itxia',
    '📬' => 'bandera igota duen postontzi irekia',
    '📭' => 'bandera jaitsita duen postontzi irekia',
    '📮' => 'postontzia',
    '🗳' => 'kutxa eta txartela',
    '✏' => 'arkatza',
    '✒' => 'luma beltza',
    '🖋' => 'luma estilografikoa',
    '🖊' => 'bolaluma',
    '🖌' => 'brotxa',
    '🖍' => 'margoa',
    '📝' => 'oharra',
    '💼' => 'maleta',
    '📁' => 'fitxategi-sailkatzailea',
    '📂' => 'fitxategi-sailkatzaile irekia',
    '🗂' => 'artxibo-bereizleak',
    '📅' => 'egutegi',
    '📆' => 'orriak kentzeko egutegia',
    '🗒' => 'koaderno kiribilduna',
    '🗓' => 'egutegi kiribilduna',
    '📇' => 'txartel-euskarria',
    '📈' => 'diagrama gorakorra',
    '📉' => 'diagrama beherakorra',
    '📊' => 'barra-diagrama',
    '📋' => 'ohar-bloka',
    '📌' => 'txintxeta',
    '📍' => 'txintxeta biribila',
    '📎' => 'klipa',
    '🖇' => 'elkarri lotutako klipak',
    '📏' => 'erregela zuzena',
    '📐' => 'kartaboia',
    '✂' => 'guraizeak',
    '🗃' => 'artxibatzeko kaxa',
    '🗄' => 'artxibategia',
    '🗑' => 'zakarrontzia',
    '🔒' => 'giltzarrapoa',
    '🔓' => 'giltzarrapo irekia',
    '🔏' => 'giltzarrapoa lumarekin',
    '🔐' => 'giltzarrapo itxia giltzarekin',
    '🔑' => 'giltza',
    '🗝' => 'giltza zaharra',
    '🔨' => 'mailua',
    '🪓' => 'aizkora',
    '⛏' => 'pikotxa',
    '⚒' => 'mailua eta pikotxa',
    '🛠' => 'mailua eta giltza ingelesa',
    '🗡' => 'daga',
    '⚔' => 'ezpata gurutzatuak',
    '💣' => 'lehergailua',
    '🪃' => 'bumeran',
    '🏹' => 'arkua eta gezia',
    '🛡' => 'ezkutua',
    '🪚' => 'zerra',
    '🔧' => 'giltza ingelesa',
    '🪛' => 'bihurkin',
    '🔩' => 'torloju eta azkoina',
    '⚙' => 'engranajea',
    '🗜' => 'konprimatzea',
    '⚖' => 'balantzak',
    '🦯' => 'makila',
    '🔗' => 'kate-maila',
    '⛓' => 'kateak',
    '🪝' => 'amu',
    '🧰' => 'erreminta-kutxa',
    '🧲' => 'iman',
    '🪜' => 'esku-eskailera',
    '🪏' => 'pala',
    '⚗' => 'alanbikea',
    '🧪' => 'saio-hodi',
    '🧫' => 'Petriren kaxa',
    '🧬' => 'DNA',
    '🔬' => 'mikroskopioa',
    '🔭' => 'teleskopioa',
    '📡' => 'satelite bidezko antena',
    '💉' => 'xiringa',
    '🩸' => 'odol tanta',
    '💊' => 'pilula',
    '🩹' => 'lotura itsaskorra',
    '🩼' => 'Makulua',
    '🩺' => 'estetoskopioa',
    '🩻' => 'z izpiak',
    '🚪' => 'atea',
    '🛗' => 'igogailua',
    '🪞' => 'ispilua',
    '🪟' => 'leihoa',
    '🛏' => 'ohea',
    '🛋' => 'sofa eta lanpara',
    '🪑' => 'aulki',
    '🚽' => 'bainugela',
    '🪠' => 'libragailu',
    '🚿' => 'dutxa',
    '🛁' => 'bainuontzia',
    '🪤' => 'sagu-arte',
    '🪒' => 'bizar-labana',
    '🧴' => 'lozio-botila',
    '🧷' => 'kateorratz',
    '🧹' => 'erratz',
    '🧺' => 'saski',
    '🧻' => 'paper-bilkari',
    '🪣' => 'perrail',
    '🧼' => 'xaboi',
    '🫧' => 'burbuilak',
    '🪥' => 'hortzetako eskuila',
    '🧽' => 'belaki',
    '🧯' => 'su-itzalgailu',
    '🛒' => 'erosketa-orga',
    '🚬' => 'erre',
    '⚰' => 'hilkutxa',
    '🪦' => 'hilarri',
    '⚱' => 'errautsak gordetzeko kutxa',
    '🧿' => 'nazar',
    '🪬' => 'hamsa',
    '🗿' => 'moaia',
    '🪧' => 'idazkun',
    '🪪' => 'nortasun-agiria',
    '🏧' => 'kutxazainaren seinalea',
    '🚮' => 'zaborra ontzira botatzeko seinalea',
    '🚰' => 'edateko ura',
    '♿' => 'gurpil-aulkia',
    '🚹' => 'gizonen komuna',
    '🚺' => 'emakumeen komuna',
    '🚻' => 'komuna',
    '🚼' => 'haurtxoen aldagela',
    '🚾' => 'komunak',
    '🛂' => 'pasaporte-kontrola',
    '🛃' => 'aduanak',
    '🛄' => 'maletak jasotzeko eremua',
    '🛅' => 'ahaztutako maletak',
    '⚠' => 'abisua',
    '🚸' => 'haurrek zeharkatzen duten errepidea',
    '⛔' => 'sarrera debekatuta',
    '🚫' => 'debekatuta',
    '🚳' => 'bizikletarik ez',
    '🚭' => 'ezin da erre',
    '🚯' => 'ezin da bota zaborra lurrera',
    '🚱' => 'edateko ez den ura',
    '🚷' => 'oinezkorik ez',
    '📵' => 'telefono mugikorrik ez',
    '🔞' => 'adingaberik ez',
    '☢' => 'erradioaktiboa',
    '☣' => 'arrisku biologikoa',
    '⬆' => 'gora gezia',
    '↗' => 'gora eta eskuinera gezia',
    '➡' => 'eskuinera gezia',
    '↘' => 'behera eta eskuinera gezia',
    '⬇' => 'behera gezia',
    '↙' => 'behera eta ezkerrera gezia',
    '⬅' => 'ezkerrera gezia',
    '↖' => 'gora eta ezkerrera gezia',
    '↕' => 'gora eta behera gezia',
    '↔' => 'ezkerrera eta eskuinera gezia',
    '↩' => 'ezkerrera okertzen den eskuinera gezia',
    '↪' => 'eskuinera okertzen den ezkerrera gezia',
    '⤴' => 'gora okertzen den eskuinera gezia',
    '⤵' => 'behera okertzen den eskuinera gezia',
    '🔃' => 'eskuinera gezi bertikalak',
    '🔄' => 'ezkerrera gezien botoia',
    '🔙' => 'atzera gezia',
    '🔚' => 'amaiera gezia',
    '🔛' => '“on” testua duen gezia',
    '🔜' => '“soon” testua duen gezia',
    '🔝' => '“top” testua duen gezia',
    '🛐' => 'otoizlekua',
    '⚛' => 'atomoaren ikurra',
    '🕉' => 'om',
    '✡' => 'daviden izarra',
    '☸' => 'dharmaren gurpila',
    '☯' => 'yin eta yang',
    '✝' => 'gurutze latindarra',
    '☦' => 'gurutze ortodoxoa',
    '☪' => 'izarra eta ilargierdia',
    '☮' => 'bakearen ikurra',
    '🕎' => 'menorah',
    '🔯' => 'erdian puntu bat duen sei puntako izarra',
    '🪯' => 'khanda',
    '♈' => 'aries',
    '♉' => 'taurus',
    '♊' => 'gemini',
    '♋' => 'cancer',
    '♌' => 'leo',
    '♍' => 'virgo',
    '♎' => 'libra',
    '♏' => 'scorpio',
    '♐' => 'sagittarius',
    '♑' => 'capricornus',
    '♒' => 'aquarius',
    '♓' => 'pisces',
    '⛎' => 'ofiuko',
    '🔀' => 'abestiak ausaz erreproduzitzeko botoia',
    '🔁' => 'errepikatzeko botoia',
    '🔂' => 'behin errepikatzeko botoia',
    '▶' => 'erreproduzitzeko botoia',
    '⏩' => 'aurrera egiteko botoia',
    '⏭' => 'hurrengo abestira joateko botoia',
    '⏯' => 'erreproduzitzeko edo pausatzeko botoia',
    '◀' => 'alderantziz erreproduzitzeko botoia',
    '⏪' => 'atzera egiteko botoia',
    '⏮' => 'azken abestia erreproduzitzeko botoia',
    '🔼' => 'gora egiteko botoia',
    '⏫' => 'gora bizkor egiteko botoia',
    '🔽' => 'behera egiteko botoia',
    '⏬' => 'behera bizkor egiteko botoia',
    '⏸' => 'pausatzeko botoia',
    '⏹' => 'gelditzeko botoia',
    '⏺' => 'grabatzeko botoia',
    '⏏' => 'ateratzeko botoia',
    '🎦' => 'zinema',
    '🔅' => 'argitasuna ahultzeko botoia',
    '🔆' => 'argitasuna igotzeko botoia',
    '📶' => 'antenen barrak',
    '🛜' => 'hari gabe',
    '📳' => 'bibrazio modua',
    '📴' => 'telefono mugikorra itzalita',
    '♀' => 'emakumeen ikurra',
    '♂' => 'gizonen ikurra',
    '⚧' => 'transgeneroen ikurra',
    '✖' => 'biderkatu',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'zatitu',
    '🟰' => 'berdin-ikur lodia',
    '♾' => 'infinitu',
    '‼' => 'harridura-marka bikoitza',
    '⁉' => 'harridura- eta galdera-ikurra',
    '❓' => 'galdera-marka gorria',
    '❔' => 'galdera-marka zuria',
    '❕' => 'harridura-marka zuria',
    '❗' => 'harridura-marka gorria',
    '〰' => 'marratxo ondulatua',
    '💱' => 'truke-tasa',
    '💲' => 'dolar-ikur lodia',
    '⚕' => 'ikur medikoa',
    '♻' => 'birziklatzeko ikurra',
    '⚜' => 'lis-lore',
    '🔱' => 'hiruhortza',
    '📛' => 'izen-bereizgarria',
    '🔰' => 'hasiberriaren japonierako ikurra',
    '⭕' => 'zirkulu gorri hutsa',
    '✅' => 'tiletaren botoia',
    '☑' => 'tileta duen koadroa',
    '✔' => 'hautamarka',
    '❌' => 'gurutze-ikurra',
    '❎' => 'gurutze-ikurraren botoia',
    '➰' => 'malgukia',
    '➿' => 'malguki bikoitza',
    '〽' => 'txanda-markatzailea',
    '✳' => 'zortzi puntako izartxoa',
    '✴' => 'zortzi puntako izarra',
    '❇' => 'txinparta',
    '™' => 'marka komertziala',
    '🫟' => 'zipriztina',
    '🔠' => 'alfabeto latindarra maiuskulaz',
    '🔡' => 'alfabeto latindarra minuskulaz',
    '🔢' => 'zenbakiak',
    '🔣' => 'ikurrak',
    '🔤' => 'hizki latindarrak',
    '🅰' => 'a botoia',
    '🆎' => 'ab botoia',
    '🅱' => 'b botoia',
    '🆑' => '“cl” testua karratu batean',
    '🆒' => '“cool” hitza karratu batean',
    '🆓' => '“free” hitza karratu batean',
    'ℹ' => 'informazio-iturburua',
    '🆔' => '“id” testua karratu batean',
    'Ⓜ' => '“m” hizkia zirkulu batean',
    '🆕' => '“new” hitza zirkulu batean',
    '🆖' => '“ng” testua karratu batean',
    '🅾' => '“o” botoia',
    '🆗' => '“ok” testua karratu batean',
    '🅿' => '“p” botoia',
    '🆘' => 'SOS botoia',
    '🆙' => 'UP! botoia',
    '🆚' => '“vs” testua karratu batean',
    '🈁' => 'katakana koko karratu batean',
    '🈂' => 'katakana sa karratu batean',
    '🈷' => 'japonierazko "hileko zenbatekoa" botoia',
    '🈶' => 'japonierazko "ez da doakoa" botoia',
    '🈯' => 'japonierazko "erreserbatuta" botoia',
    '🉐' => 'japonierazko "pagotxa" botoia',
    '🈹' => 'japonierazko "deskontua" botoia',
    '🈚' => 'japonierazko "doakoa" botoia',
    '🈲' => 'japonierazko "debekatuta" botoia',
    '🉑' => 'japonierazko "onargarria" botoia',
    '🈸' => 'japonierazko "eskaera" botoia',
    '🈴' => 'japonierazko "nahikoa" botoia',
    '🈳' => 'japonierazko "lanpostu hutsa" botoia',
    '㊗' => 'zoriontzeko ideograma zirkulu batean',
    '㊙' => 'japonierazko "sekretua" botoia',
    '🈺' => 'japonierazko "irekita" botoia',
    '🈵' => 'japonierazko "lanpostu hutsik ez" botoia',
    '🔴' => 'zirkulu gorria',
    '🟠' => 'zirkulu laranja',
    '🟡' => 'zirkulu horia',
    '🟢' => 'zirkulu berdea',
    '🔵' => 'zirkulu urdina',
    '🟣' => 'zirkulu morea',
    '🟤' => 'zirkulu marroia',
    '⚫' => 'zirkulu beltza',
    '⚪' => 'zirkulu zuria',
    '🟥' => 'karratu gorria',
    '🟧' => 'karratu laranja',
    '🟨' => 'karratu horia',
    '🟩' => 'karratu berdea',
    '🟦' => 'karratu urdina',
    '🟪' => 'karratu morea',
    '🟫' => 'karratu marroia',
    '⬛' => 'karratu beltz handia',
    '⬜' => 'karratu zuri handia',
    '◼' => 'karratu beltz ertaina',
    '◻' => 'karratu zuri ertaina',
    '◾' => 'karratu beltz ertaina/txikia',
    '◽' => 'karratu zuri ertaina/txikia',
    '▪' => 'karratu beltz txikia',
    '▫' => 'karratu zuri txikia',
    '🔶' => 'diamante laranja handia',
    '🔷' => 'diamante urdin handia',
    '🔸' => 'diamante laranja txikia',
    '🔹' => 'diamante urdin txikia',
    '🔺' => 'punta gora begira duen triangelu gorria',
    '🔻' => 'punta behera begira duen triangelu gorria',
    '💠' => 'puntu bat duen diamantea',
    '🔘' => 'kontrol-laukia',
    '🔳' => 'karratu zuri itxurako botoia',
    '🔲' => 'karratu beltz itxurako botoia',
    '🏁' => 'bandera laukiduna',
    '🚩' => 'triangelu-itxurako bandera',
    '🎌' => 'bandera gurutzatuak',
    '🏴' => 'dantzatzen ari den bandera beltza',
    '🏳' => 'dantzatzen ari den bandera zuria',
];
