<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'bacio tra coppia: persona, persona, carnagione chiara e carnagione abbastanza chiara',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'bacio tra coppia: persona, persona, carnagione chiara e carnagione olivastra',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'bacio tra coppia: persona, persona, carnagione chiara e carnagione abbastanza scura',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'bacio tra coppia: persona, persona, carnagione chiara e carnagione scura',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'bacio tra coppia: persona, persona, carnagione abbastanza chiara e carnagione chiara',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'bacio tra coppia: persona, persona, carnagione abbastanza chiara e carnagione olivastra',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'bacio tra coppia: persona, persona, carnagione abbastanza chiara e carnagione abbastanza scura',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'bacio tra coppia: persona, persona, carnagione abbastanza chiara e carnagione scura',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'bacio tra coppia: persona, persona, carnagione olivastra e carnagione chiara',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'bacio tra coppia: persona, persona, carnagione olivastra e carnagione abbastanza chiara',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'bacio tra coppia: persona, persona, carnagione olivastra e carnagione abbastanza scura',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'bacio tra coppia: persona, persona, carnagione olivastra e carnagione scura',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'bacio tra coppia: persona, persona, carnagione abbastanza scura e carnagione chiara',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'bacio tra coppia: persona, persona, carnagione abbastanza scura e carnagione abbastanza chiara',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'bacio tra coppia: persona, persona, carnagione abbastanza scura e carnagione olivastra',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'bacio tra coppia: persona, persona, carnagione abbastanza scura e carnagione scura',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'bacio tra coppia: persona, persona, carnagione scura e carnagione chiara',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'bacio tra coppia: persona, persona, carnagione scura e carnagione abbastanza chiara',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'bacio tra coppia: persona, persona, carnagione scura e carnagione olivastra',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'bacio tra coppia: persona, persona, carnagione scura e carnagione abbastanza scura',
    '👨🏻‍❤‍💋‍👨🏻' => 'bacio tra coppia: uomo, uomo e carnagione chiara',
    '👨🏻‍❤‍💋‍👨🏼' => 'bacio tra coppia: uomo, uomo, carnagione chiara e carnagione abbastanza chiara',
    '👨🏻‍❤‍💋‍👨🏽' => 'bacio tra coppia: uomo, uomo, carnagione chiara e carnagione olivastra',
    '👨🏻‍❤‍💋‍👨🏾' => 'bacio tra coppia: uomo, uomo, carnagione chiara e carnagione abbastanza scura',
    '👨🏻‍❤‍💋‍👨🏿' => 'bacio tra coppia: uomo, uomo, carnagione chiara e carnagione scura',
    '👨🏼‍❤‍💋‍👨🏻' => 'bacio tra coppia: uomo, uomo, carnagione abbastanza chiara e carnagione chiara',
    '👨🏼‍❤‍💋‍👨🏼' => 'bacio tra coppia: uomo, uomo e carnagione abbastanza chiara',
    '👨🏼‍❤‍💋‍👨🏽' => 'bacio tra coppia: uomo, uomo, carnagione abbastanza chiara e carnagione olivastra',
    '👨🏼‍❤‍💋‍👨🏾' => 'bacio tra coppia: uomo, uomo, carnagione abbastanza chiara e carnagione abbastanza scura',
    '👨🏼‍❤‍💋‍👨🏿' => 'bacio tra coppia: uomo, uomo, carnagione abbastanza chiara e carnagione scura',
    '👨🏽‍❤‍💋‍👨🏻' => 'bacio tra coppia: uomo, uomo, carnagione olivastra e carnagione chiara',
    '👨🏽‍❤‍💋‍👨🏼' => 'bacio tra coppia: uomo, uomo, carnagione olivastra e carnagione abbastanza chiara',
    '👨🏽‍❤‍💋‍👨🏽' => 'bacio tra coppia: uomo, uomo e carnagione olivastra',
    '👨🏽‍❤‍💋‍👨🏾' => 'bacio tra coppia: uomo, uomo, carnagione olivastra e carnagione abbastanza scura',
    '👨🏽‍❤‍💋‍👨🏿' => 'bacio tra coppia: uomo, uomo, carnagione olivastra e carnagione scura',
    '👨🏾‍❤‍💋‍👨🏻' => 'bacio tra coppia: uomo, uomo, carnagione abbastanza scura e carnagione chiara',
    '👨🏾‍❤‍💋‍👨🏼' => 'bacio tra coppia: uomo, uomo, carnagione abbastanza scura e carnagione abbastanza chiara',
    '👨🏾‍❤‍💋‍👨🏽' => 'bacio tra coppia: uomo, uomo, carnagione abbastanza scura e carnagione olivastra',
    '👨🏾‍❤‍💋‍👨🏾' => 'bacio tra coppia: uomo, uomo e carnagione abbastanza scura',
    '👨🏾‍❤‍💋‍👨🏿' => 'bacio tra coppia: uomo, uomo, carnagione abbastanza scura e carnagione scura',
    '👨🏿‍❤‍💋‍👨🏻' => 'bacio tra coppia: uomo, uomo, carnagione scura e carnagione chiara',
    '👨🏿‍❤‍💋‍👨🏼' => 'bacio tra coppia: uomo, uomo, carnagione scura e carnagione abbastanza chiara',
    '👨🏿‍❤‍💋‍👨🏽' => 'bacio tra coppia: uomo, uomo, carnagione scura e carnagione olivastra',
    '👨🏿‍❤‍💋‍👨🏾' => 'bacio tra coppia: uomo, uomo, carnagione scura e carnagione abbastanza scura',
    '👨🏿‍❤‍💋‍👨🏿' => 'bacio tra coppia: uomo, uomo e carnagione scura',
    '👩🏻‍❤‍💋‍👨🏻' => 'bacio tra coppia: donna, uomo e carnagione chiara',
    '👩🏻‍❤‍💋‍👨🏼' => 'bacio tra coppia: donna, uomo, carnagione chiara e carnagione abbastanza chiara',
    '👩🏻‍❤‍💋‍👨🏽' => 'bacio tra coppia: donna, uomo, carnagione chiara e carnagione olivastra',
    '👩🏻‍❤‍💋‍👨🏾' => 'bacio tra coppia: donna, uomo, carnagione chiara e carnagione abbastanza scura',
    '👩🏻‍❤‍💋‍👨🏿' => 'bacio tra coppia: donna, uomo, carnagione chiara e carnagione scura',
    '👩🏼‍❤‍💋‍👨🏻' => 'bacio tra coppia: donna, uomo, carnagione abbastanza chiara e carnagione chiara',
    '👩🏼‍❤‍💋‍👨🏼' => 'bacio tra coppia: donna, uomo e carnagione abbastanza chiara',
    '👩🏼‍❤‍💋‍👨🏽' => 'bacio tra coppia: donna, uomo, carnagione abbastanza chiara e carnagione olivastra',
    '👩🏼‍❤‍💋‍👨🏾' => 'bacio tra coppia: donna, uomo, carnagione abbastanza chiara e carnagione abbastanza scura',
    '👩🏼‍❤‍💋‍👨🏿' => 'bacio tra coppia: donna, uomo, carnagione abbastanza chiara e carnagione scura',
    '👩🏽‍❤‍💋‍👨🏻' => 'bacio tra coppia: donna, uomo, carnagione olivastra e carnagione chiara',
    '👩🏽‍❤‍💋‍👨🏼' => 'bacio tra coppia: donna, uomo, carnagione olivastra e carnagione abbastanza chiara',
    '👩🏽‍❤‍💋‍👨🏽' => 'bacio tra coppia: donna, uomo e carnagione olivastra',
    '👩🏽‍❤‍💋‍👨🏾' => 'bacio tra coppia: donna, uomo, carnagione olivastra e carnagione abbastanza scura',
    '👩🏽‍❤‍💋‍👨🏿' => 'bacio tra coppia: donna, uomo, carnagione olivastra e carnagione scura',
    '👩🏾‍❤‍💋‍👨🏻' => 'bacio tra coppia: donna, uomo, carnagione abbastanza scura e carnagione chiara',
    '👩🏾‍❤‍💋‍👨🏼' => 'bacio tra coppia: donna, uomo, carnagione abbastanza scura e carnagione abbastanza chiara',
    '👩🏾‍❤‍💋‍👨🏽' => 'bacio tra coppia: donna, uomo, carnagione abbastanza scura e carnagione olivastra',
    '👩🏾‍❤‍💋‍👨🏾' => 'bacio tra coppia: donna, uomo e carnagione abbastanza scura',
    '👩🏾‍❤‍💋‍👨🏿' => 'bacio tra coppia: donna, uomo, carnagione abbastanza scura e carnagione scura',
    '👩🏿‍❤‍💋‍👨🏻' => 'bacio tra coppia: donna, uomo, carnagione scura e carnagione chiara',
    '👩🏿‍❤‍💋‍👨🏼' => 'bacio tra coppia: donna, uomo, carnagione scura e carnagione abbastanza chiara',
    '👩🏿‍❤‍💋‍👨🏽' => 'bacio tra coppia: donna, uomo, carnagione scura e carnagione olivastra',
    '👩🏿‍❤‍💋‍👨🏾' => 'bacio tra coppia: donna, uomo, carnagione scura e carnagione abbastanza scura',
    '👩🏿‍❤‍💋‍👨🏿' => 'bacio tra coppia: donna, uomo e carnagione scura',
    '👩🏻‍❤‍💋‍👩🏻' => 'bacio tra coppia: donna, donna e carnagione chiara',
    '👩🏻‍❤‍💋‍👩🏼' => 'bacio tra coppia: donna, donna, carnagione chiara e carnagione abbastanza chiara',
    '👩🏻‍❤‍💋‍👩🏽' => 'bacio tra coppia: donna, donna, carnagione chiara e carnagione olivastra',
    '👩🏻‍❤‍💋‍👩🏾' => 'bacio tra coppia: donna, donna, carnagione chiara e carnagione abbastanza scura',
    '👩🏻‍❤‍💋‍👩🏿' => 'bacio tra coppia: donna, donna, carnagione chiara e carnagione scura',
    '👩🏼‍❤‍💋‍👩🏻' => 'bacio tra coppia: donna, donna, carnagione abbastanza chiara e carnagione chiara',
    '👩🏼‍❤‍💋‍👩🏼' => 'bacio tra coppia: donna, donna e carnagione abbastanza chiara',
    '👩🏼‍❤‍💋‍👩🏽' => 'bacio tra coppia: donna, donna, carnagione abbastanza chiara e carnagione olivastra',
    '👩🏼‍❤‍💋‍👩🏾' => 'bacio tra coppia: donna, donna, carnagione abbastanza chiara e carnagione abbastanza scura',
    '👩🏼‍❤‍💋‍👩🏿' => 'bacio tra coppia: donna, donna, carnagione abbastanza chiara e carnagione scura',
    '👩🏽‍❤‍💋‍👩🏻' => 'bacio tra coppia: donna, donna, carnagione olivastra e carnagione chiara',
    '👩🏽‍❤‍💋‍👩🏼' => 'bacio tra coppia: donna, donna, carnagione olivastra e carnagione abbastanza chiara',
    '👩🏽‍❤‍💋‍👩🏽' => 'bacio tra coppia: donna, donna e carnagione olivastra',
    '👩🏽‍❤‍💋‍👩🏾' => 'bacio tra coppia: donna, donna, carnagione olivastra e carnagione abbastanza scura',
    '👩🏽‍❤‍💋‍👩🏿' => 'bacio tra coppia: donna, donna, carnagione olivastra e carnagione scura',
    '👩🏾‍❤‍💋‍👩🏻' => 'bacio tra coppia: donna, donna, carnagione abbastanza scura e carnagione chiara',
    '👩🏾‍❤‍💋‍👩🏼' => 'bacio tra coppia: donna, donna, carnagione abbastanza scura e carnagione abbastanza chiara',
    '👩🏾‍❤‍💋‍👩🏽' => 'bacio tra coppia: donna, donna, carnagione abbastanza scura e carnagione olivastra',
    '👩🏾‍❤‍💋‍👩🏾' => 'bacio tra coppia: donna, donna e carnagione abbastanza scura',
    '👩🏾‍❤‍💋‍👩🏿' => 'bacio tra coppia: donna, donna, carnagione abbastanza scura e carnagione scura',
    '👩🏿‍❤‍💋‍👩🏻' => 'bacio tra coppia: donna, donna, carnagione scura e carnagione chiara',
    '👩🏿‍❤‍💋‍👩🏼' => 'bacio tra coppia: donna, donna, carnagione scura e carnagione abbastanza chiara',
    '👩🏿‍❤‍💋‍👩🏽' => 'bacio tra coppia: donna, donna, carnagione scura e carnagione olivastra',
    '👩🏿‍❤‍💋‍👩🏾' => 'bacio tra coppia: donna, donna, carnagione scura e carnagione abbastanza scura',
    '👩🏿‍❤‍💋‍👩🏿' => 'bacio tra coppia: donna, donna e carnagione scura',
    '🧑🏻‍🫯‍🧑🏼' => 'persone che fanno la lotta: carnagione chiara e carnagione abbastanza chiara',
    '🧑🏻‍🫯‍🧑🏽' => 'persone che fanno la lotta: carnagione chiara e carnagione olivastra',
    '🧑🏻‍🫯‍🧑🏾' => 'persone che fanno la lotta: carnagione chiara e carnagione abbastanza scura',
    '🧑🏻‍🫯‍🧑🏿' => 'persone che fanno la lotta: carnagione chiara e carnagione scura',
    '🧑🏼‍🫯‍🧑🏻' => 'persone che fanno la lotta: carnagione abbastanza chiara e carnagione chiara',
    '🧑🏼‍🫯‍🧑🏽' => 'persone che fanno la lotta: carnagione abbastanza chiara e carnagione olivastra',
    '🧑🏼‍🫯‍🧑🏾' => 'persone che fanno la lotta: carnagione abbastanza chiara e carnagione abbastanza scura',
    '🧑🏼‍🫯‍🧑🏿' => 'persone che fanno la lotta: carnagione abbastanza chiara e carnagione scura',
    '🧑🏽‍🫯‍🧑🏻' => 'persone che fanno la lotta: carnagione olivastra e carnagione chiara',
    '🧑🏽‍🫯‍🧑🏼' => 'persone che fanno la lotta: carnagione olivastra e carnagione abbastanza chiara',
    '🧑🏽‍🫯‍🧑🏾' => 'persone che fanno la lotta: carnagione olivastra e carnagione abbastanza scura',
    '🧑🏽‍🫯‍🧑🏿' => 'persone che fanno la lotta: carnagione olivastra e carnagione scura',
    '🧑🏾‍🫯‍🧑🏻' => 'persone che fanno la lotta: carnagione abbastanza scura e carnagione chiara',
    '🧑🏾‍🫯‍🧑🏼' => 'persone che fanno la lotta: carnagione abbastanza scura e carnagione abbastanza chiara',
    '🧑🏾‍🫯‍🧑🏽' => 'persone che fanno la lotta: carnagione abbastanza scura e carnagione olivastra',
    '🧑🏾‍🫯‍🧑🏿' => 'persone che fanno la lotta: carnagione abbastanza scura e carnagione scura',
    '🧑🏿‍🫯‍🧑🏻' => 'persone che fanno la lotta: carnagione scura e carnagione chiara',
    '🧑🏿‍🫯‍🧑🏼' => 'persone che fanno la lotta: carnagione scura e carnagione abbastanza chiara',
    '🧑🏿‍🫯‍🧑🏽' => 'persone che fanno la lotta: carnagione scura e carnagione olivastra',
    '🧑🏿‍🫯‍🧑🏾' => 'persone che fanno la lotta: carnagione scura e carnagione abbastanza scura',
    '🧑🏻‍❤‍🧑🏼' => 'coppia con cuore: persona, persona, carnagione chiara e carnagione abbastanza chiara',
    '🧑🏻‍❤‍🧑🏽' => 'coppia con cuore: persona, persona, carnagione chiara e carnagione olivastra',
    '🧑🏻‍❤‍🧑🏾' => 'coppia con cuore: persona, persona, carnagione chiara e carnagione abbastanza scura',
    '🧑🏻‍❤‍🧑🏿' => 'coppia con cuore: persona, persona, carnagione chiara e carnagione scura',
    '🧑🏼‍❤‍🧑🏻' => 'coppia con cuore: persona, persona, carnagione abbastanza chiara e carnagione chiara',
    '🧑🏼‍❤‍🧑🏽' => 'coppia con cuore: persona, persona, carnagione abbastanza chiara e carnagione olivastra',
    '🧑🏼‍❤‍🧑🏾' => 'coppia con cuore: persona, persona, carnagione abbastanza chiara e carnagione abbastanza scura',
    '🧑🏼‍❤‍🧑🏿' => 'coppia con cuore: persona, persona, carnagione abbastanza chiara e carnagione scura',
    '🧑🏽‍❤‍🧑🏻' => 'coppia con cuore: persona, persona, carnagione olivastra e carnagione chiara',
    '🧑🏽‍❤‍🧑🏼' => 'coppia con cuore: persona, persona, carnagione olivastra e carnagione abbastanza chiara',
    '🧑🏽‍❤‍🧑🏾' => 'coppia con cuore: persona, persona, carnagione olivastra e carnagione abbastanza scura',
    '🧑🏽‍❤‍🧑🏿' => 'coppia con cuore: persona, persona, carnagione olivastra e carnagione scura',
    '🧑🏾‍❤‍🧑🏻' => 'coppia con cuore: persona, persona, carnagione abbastanza scura e carnagione chiara',
    '🧑🏾‍❤‍🧑🏼' => 'coppia con cuore: persona, persona, carnagione abbastanza scura e carnagione abbastanza chiara',
    '🧑🏾‍❤‍🧑🏽' => 'coppia con cuore: persona, persona, carnagione abbastanza scura e carnagione olivastra',
    '🧑🏾‍❤‍🧑🏿' => 'coppia con cuore: persona, persona, carnagione abbastanza scura e carnagione scura',
    '🧑🏿‍❤‍🧑🏻' => 'coppia con cuore: persona, persona, carnagione scura e carnagione chiara',
    '🧑🏿‍❤‍🧑🏼' => 'coppia con cuore: persona, persona, carnagione scura e carnagione abbastanza chiara',
    '🧑🏿‍❤‍🧑🏽' => 'coppia con cuore: persona, persona, carnagione scura e carnagione olivastra',
    '🧑🏿‍❤‍🧑🏾' => 'coppia con cuore: persona, persona, carnagione scura e carnagione abbastanza scura',
    '🧑🏻‍🐰‍🧑🏼' => 'persone con orecchie da coniglio: carnagione chiara e carnagione abbastanza chiara',
    '🧑🏻‍🐰‍🧑🏽' => 'persone con orecchie da coniglio: carnagione chiara e carnagione olivastra',
    '🧑🏻‍🐰‍🧑🏾' => 'persone con orecchie da coniglio: carnagione chiara e carnagione abbastanza scura',
    '🧑🏻‍🐰‍🧑🏿' => 'persone con orecchie da coniglio: carnagione chiara e carnagione scura',
    '🧑🏼‍🐰‍🧑🏻' => 'persone con orecchie da coniglio: carnagione abbastanza chiara e carnagione chiara',
    '🧑🏼‍🐰‍🧑🏽' => 'persone con orecchie da coniglio: carnagione abbastanza chiara e carnagione olivastra',
    '🧑🏼‍🐰‍🧑🏾' => 'persone con orecchie da coniglio: carnagione abbastanza chiara e carnagione abbastanza scura',
    '🧑🏼‍🐰‍🧑🏿' => 'persone con orecchie da coniglio: carnagione abbastanza chiara e carnagione scura',
    '🧑🏽‍🐰‍🧑🏻' => 'persone con orecchie da coniglio: carnagione olivastra e carnagione chiara',
    '🧑🏽‍🐰‍🧑🏼' => 'persone con orecchie da coniglio: carnagione olivastra e carnagione abbastanza chiara',
    '🧑🏽‍🐰‍🧑🏾' => 'persone con orecchie da coniglio: carnagione olivastra e carnagione abbastanza scura',
    '🧑🏽‍🐰‍🧑🏿' => 'persone con orecchie da coniglio: carnagione olivastra e carnagione scura',
    '🧑🏾‍🐰‍🧑🏻' => 'persone con orecchie da coniglio: carnagione abbastanza scura e carnagione chiara',
    '🧑🏾‍🐰‍🧑🏼' => 'persone con orecchie da coniglio: carnagione abbastanza scura e carnagione abbastanza chiara',
    '🧑🏾‍🐰‍🧑🏽' => 'persone con orecchie da coniglio: carnagione abbastanza scura e carnagione olivastra',
    '🧑🏾‍🐰‍🧑🏿' => 'persone con orecchie da coniglio: carnagione abbastanza scura e carnagione scura',
    '🧑🏿‍🐰‍🧑🏻' => 'persone con orecchie da coniglio: carnagione scura e carnagione chiara',
    '🧑🏿‍🐰‍🧑🏼' => 'persone con orecchie da coniglio: carnagione scura e carnagione abbastanza chiara',
    '🧑🏿‍🐰‍🧑🏽' => 'persone con orecchie da coniglio: carnagione scura e carnagione olivastra',
    '🧑🏿‍🐰‍🧑🏾' => 'persone con orecchie da coniglio: carnagione scura e carnagione abbastanza scura',
    '👨🏻‍🫯‍👨🏼' => 'lottatori: carnagione chiara e carnagione abbastanza chiara',
    '👨🏻‍🫯‍👨🏽' => 'lottatori: carnagione chiara e carnagione olivastra',
    '👨🏻‍🫯‍👨🏾' => 'lottatori: carnagione chiara e carnagione abbastanza scura',
    '👨🏻‍🫯‍👨🏿' => 'lottatori: carnagione chiara e carnagione scura',
    '👨🏼‍🫯‍👨🏻' => 'lottatori: carnagione abbastanza chiara e carnagione chiara',
    '👨🏼‍🫯‍👨🏽' => 'lottatori: carnagione abbastanza chiara e carnagione olivastra',
    '👨🏼‍🫯‍👨🏾' => 'lottatori: carnagione abbastanza chiara e carnagione abbastanza scura',
    '👨🏼‍🫯‍👨🏿' => 'lottatori: carnagione abbastanza chiara e carnagione scura',
    '👨🏽‍🫯‍👨🏻' => 'lottatori: carnagione olivastra e carnagione chiara',
    '👨🏽‍🫯‍👨🏼' => 'lottatori: carnagione olivastra e carnagione abbastanza chiara',
    '👨🏽‍🫯‍👨🏾' => 'lottatori: carnagione olivastra e carnagione abbastanza scura',
    '👨🏽‍🫯‍👨🏿' => 'lottatori: carnagione olivastra e carnagione scura',
    '👨🏾‍🫯‍👨🏻' => 'lottatori: carnagione abbastanza scura e carnagione chiara',
    '👨🏾‍🫯‍👨🏼' => 'lottatori: carnagione abbastanza scura e carnagione abbastanza chiara',
    '👨🏾‍🫯‍👨🏽' => 'lottatori: carnagione abbastanza scura e carnagione olivastra',
    '👨🏾‍🫯‍👨🏿' => 'lottatori: carnagione abbastanza scura e carnagione scura',
    '👨🏿‍🫯‍👨🏻' => 'lottatori: carnagione scura e carnagione chiara',
    '👨🏿‍🫯‍👨🏼' => 'lottatori: carnagione scura e carnagione abbastanza chiara',
    '👨🏿‍🫯‍👨🏽' => 'lottatori: carnagione scura e carnagione olivastra',
    '👨🏿‍🫯‍👨🏾' => 'lottatori: carnagione scura e carnagione abbastanza scura',
    '👨🏻‍❤‍👨🏻' => 'coppia con cuore: uomo, uomo e carnagione chiara',
    '👨🏻‍❤‍👨🏼' => 'coppia con cuore: uomo, uomo, carnagione chiara e carnagione abbastanza chiara',
    '👨🏻‍❤‍👨🏽' => 'coppia con cuore: uomo, uomo, carnagione chiara e carnagione olivastra',
    '👨🏻‍❤‍👨🏾' => 'coppia con cuore: uomo, uomo, carnagione chiara e carnagione abbastanza scura',
    '👨🏻‍❤‍👨🏿' => 'coppia con cuore: uomo, uomo, carnagione chiara e carnagione scura',
    '👨🏼‍❤‍👨🏻' => 'coppia con cuore: uomo, uomo, carnagione abbastanza chiara e carnagione chiara',
    '👨🏼‍❤‍👨🏼' => 'coppia con cuore: uomo, uomo e carnagione abbastanza chiara',
    '👨🏼‍❤‍👨🏽' => 'coppia con cuore: uomo, uomo, carnagione abbastanza chiara e carnagione olivastra',
    '👨🏼‍❤‍👨🏾' => 'coppia con cuore: uomo, uomo, carnagione abbastanza chiara e carnagione abbastanza scura',
    '👨🏼‍❤‍👨🏿' => 'coppia con cuore: uomo, uomo, carnagione abbastanza chiara e carnagione scura',
    '👨🏽‍❤‍👨🏻' => 'coppia con cuore: uomo, uomo, carnagione olivastra e carnagione chiara',
    '👨🏽‍❤‍👨🏼' => 'coppia con cuore: uomo, uomo, carnagione olivastra e carnagione abbastanza chiara',
    '👨🏽‍❤‍👨🏽' => 'coppia con cuore: uomo, uomo e carnagione olivastra',
    '👨🏽‍❤‍👨🏾' => 'coppia con cuore: uomo, uomo, carnagione olivastra e carnagione abbastanza scura',
    '👨🏽‍❤‍👨🏿' => 'coppia con cuore: uomo, uomo, carnagione olivastra e carnagione scura',
    '👨🏾‍❤‍👨🏻' => 'coppia con cuore: uomo, uomo, carnagione abbastanza scura e carnagione chiara',
    '👨🏾‍❤‍👨🏼' => 'coppia con cuore: uomo, uomo, carnagione abbastanza scura e carnagione abbastanza chiara',
    '👨🏾‍❤‍👨🏽' => 'coppia con cuore: uomo, uomo, carnagione abbastanza scura e carnagione olivastra',
    '👨🏾‍❤‍👨🏾' => 'coppia con cuore: uomo, uomo e carnagione abbastanza scura',
    '👨🏾‍❤‍👨🏿' => 'coppia con cuore: uomo, uomo, carnagione abbastanza scura e carnagione scura',
    '👨🏿‍❤‍👨🏻' => 'coppia con cuore: uomo, uomo, carnagione scura e carnagione chiara',
    '👨🏿‍❤‍👨🏼' => 'coppia con cuore: uomo, uomo, carnagione scura e carnagione abbastanza chiara',
    '👨🏿‍❤‍👨🏽' => 'coppia con cuore: uomo, uomo, carnagione scura e carnagione olivastra',
    '👨🏿‍❤‍👨🏾' => 'coppia con cuore: uomo, uomo, carnagione scura e carnagione abbastanza scura',
    '👨🏿‍❤‍👨🏿' => 'coppia con cuore: uomo, uomo e carnagione scura',
    '👨🏻‍🐰‍👨🏼' => 'uomini con orecchie da coniglio: carnagione chiara e carnagione abbastanza chiara',
    '👨🏻‍🐰‍👨🏽' => 'uomini con orecchie da coniglio: carnagione chiara e carnagione olivastra',
    '👨🏻‍🐰‍👨🏾' => 'uomini con orecchie da coniglio: carnagione chiara e carnagione abbastanza scura',
    '👨🏻‍🐰‍👨🏿' => 'uomini con orecchie da coniglio: carnagione chiara e carnagione scura',
    '👨🏼‍🐰‍👨🏻' => 'uomini con orecchie da coniglio: carnagione abbastanza chiara e carnagione chiara',
    '👨🏼‍🐰‍👨🏽' => 'uomini con orecchie da coniglio: carnagione abbastanza chiara e carnagione olivastra',
    '👨🏼‍🐰‍👨🏾' => 'uomini con orecchie da coniglio: carnagione abbastanza chiara e carnagione abbastanza scura',
    '👨🏼‍🐰‍👨🏿' => 'uomini con orecchie da coniglio: carnagione abbastanza chiara e carnagione scura',
    '👨🏽‍🐰‍👨🏻' => 'uomini con orecchie da coniglio: carnagione olivastra e carnagione chiara',
    '👨🏽‍🐰‍👨🏼' => 'uomini con orecchie da coniglio: carnagione olivastra e carnagione abbastanza chiara',
    '👨🏽‍🐰‍👨🏾' => 'uomini con orecchie da coniglio: carnagione olivastra e carnagione abbastanza scura',
    '👨🏽‍🐰‍👨🏿' => 'uomini con orecchie da coniglio: carnagione olivastra e carnagione scura',
    '👨🏾‍🐰‍👨🏻' => 'uomini con orecchie da coniglio: carnagione abbastanza scura e carnagione chiara',
    '👨🏾‍🐰‍👨🏼' => 'uomini con orecchie da coniglio: carnagione abbastanza scura e carnagione abbastanza chiara',
    '👨🏾‍🐰‍👨🏽' => 'uomini con orecchie da coniglio: carnagione abbastanza scura e carnagione olivastra',
    '👨🏾‍🐰‍👨🏿' => 'uomini con orecchie da coniglio: carnagione abbastanza scura e carnagione scura',
    '👨🏿‍🐰‍👨🏻' => 'uomini con orecchie da coniglio: carnagione scura e carnagione chiara',
    '👨🏿‍🐰‍👨🏼' => 'uomini con orecchie da coniglio: carnagione scura e carnagione abbastanza chiara',
    '👨🏿‍🐰‍👨🏽' => 'uomini con orecchie da coniglio: carnagione scura e carnagione olivastra',
    '👨🏿‍🐰‍👨🏾' => 'uomini con orecchie da coniglio: carnagione scura e carnagione abbastanza scura',
    '👩🏻‍🫯‍👩🏼' => 'lottatrici: carnagione chiara e carnagione abbastanza chiara',
    '👩🏻‍🫯‍👩🏽' => 'lottatrici: carnagione chiara e carnagione olivastra',
    '👩🏻‍🫯‍👩🏾' => 'lottatrici: carnagione chiara e carnagione abbastanza scura',
    '👩🏻‍🫯‍👩🏿' => 'lottatrici: carnagione chiara e carnagione scura',
    '👩🏼‍🫯‍👩🏻' => 'lottatrici: carnagione abbastanza chiara e carnagione chiara',
    '👩🏼‍🫯‍👩🏽' => 'lottatrici: carnagione abbastanza chiara e carnagione olivastra',
    '👩🏼‍🫯‍👩🏾' => 'lottatrici: carnagione abbastanza chiara e carnagione abbastanza scura',
    '👩🏼‍🫯‍👩🏿' => 'lottatrici: carnagione abbastanza chiara e carnagione scura',
    '👩🏽‍🫯‍👩🏻' => 'lottatrici: carnagione olivastra e carnagione chiara',
    '👩🏽‍🫯‍👩🏼' => 'lottatrici: carnagione olivastra e carnagione abbastanza chiara',
    '👩🏽‍🫯‍👩🏾' => 'lottatrici: carnagione olivastra e carnagione abbastanza scura',
    '👩🏽‍🫯‍👩🏿' => 'lottatrici: carnagione olivastra e carnagione scura',
    '👩🏾‍🫯‍👩🏻' => 'lottatrici: carnagione abbastanza scura e carnagione chiara',
    '👩🏾‍🫯‍👩🏼' => 'lottatrici: carnagione abbastanza scura e carnagione abbastanza chiara',
    '👩🏾‍🫯‍👩🏽' => 'lottatrici: carnagione abbastanza scura e carnagione olivastra',
    '👩🏾‍🫯‍👩🏿' => 'lottatrici: carnagione abbastanza scura e carnagione scura',
    '👩🏿‍🫯‍👩🏻' => 'lottatrici: carnagione scura e carnagione chiara',
    '👩🏿‍🫯‍👩🏼' => 'lottatrici: carnagione scura e carnagione abbastanza chiara',
    '👩🏿‍🫯‍👩🏽' => 'lottatrici: carnagione scura e carnagione olivastra',
    '👩🏿‍🫯‍👩🏾' => 'lottatrici: carnagione scura e carnagione abbastanza scura',
    '👩🏻‍❤‍👨🏻' => 'coppia con cuore: donna, uomo e carnagione chiara',
    '👩🏻‍❤‍👨🏼' => 'coppia con cuore: donna, uomo, carnagione chiara e carnagione abbastanza chiara',
    '👩🏻‍❤‍👨🏽' => 'coppia con cuore: donna, uomo, carnagione chiara e carnagione olivastra',
    '👩🏻‍❤‍👨🏾' => 'coppia con cuore: donna, uomo, carnagione chiara e carnagione abbastanza scura',
    '👩🏻‍❤‍👨🏿' => 'coppia con cuore: donna, uomo, carnagione chiara e carnagione scura',
    '👩🏼‍❤‍👨🏻' => 'coppia con cuore: donna, uomo, carnagione abbastanza chiara e carnagione chiara',
    '👩🏼‍❤‍👨🏼' => 'coppia con cuore: donna, uomo e carnagione abbastanza chiara',
    '👩🏼‍❤‍👨🏽' => 'coppia con cuore: donna, uomo, carnagione abbastanza chiara e carnagione olivastra',
    '👩🏼‍❤‍👨🏾' => 'coppia con cuore: donna, uomo, carnagione abbastanza chiara e carnagione abbastanza scura',
    '👩🏼‍❤‍👨🏿' => 'coppia con cuore: donna, uomo, carnagione abbastanza chiara e carnagione scura',
    '👩🏽‍❤‍👨🏻' => 'coppia con cuore: donna, uomo, carnagione olivastra e carnagione chiara',
    '👩🏽‍❤‍👨🏼' => 'coppia con cuore: donna, uomo, carnagione olivastra e carnagione abbastanza chiara',
    '👩🏽‍❤‍👨🏽' => 'coppia con cuore: donna, uomo e carnagione olivastra',
    '👩🏽‍❤‍👨🏾' => 'coppia con cuore: donna, uomo, carnagione olivastra e carnagione abbastanza scura',
    '👩🏽‍❤‍👨🏿' => 'coppia con cuore: donna, uomo, carnagione olivastra e carnagione scura',
    '👩🏾‍❤‍👨🏻' => 'coppia con cuore: donna, uomo, carnagione abbastanza scura e carnagione chiara',
    '👩🏾‍❤‍👨🏼' => 'coppia con cuore: donna, uomo, carnagione abbastanza scura e carnagione abbastanza chiara',
    '👩🏾‍❤‍👨🏽' => 'coppia con cuore: donna, uomo, carnagione abbastanza scura e carnagione olivastra',
    '👩🏾‍❤‍👨🏾' => 'coppia con cuore: donna, uomo e carnagione abbastanza scura',
    '👩🏾‍❤‍👨🏿' => 'coppia con cuore: donna, uomo, carnagione abbastanza scura e carnagione scura',
    '👩🏿‍❤‍👨🏻' => 'coppia con cuore: donna, uomo, carnagione scura e carnagione chiara',
    '👩🏿‍❤‍👨🏼' => 'coppia con cuore: donna, uomo, carnagione scura e carnagione abbastanza chiara',
    '👩🏿‍❤‍👨🏽' => 'coppia con cuore: donna, uomo, carnagione scura e carnagione olivastra',
    '👩🏿‍❤‍👨🏾' => 'coppia con cuore: donna, uomo, carnagione scura e carnagione abbastanza scura',
    '👩🏿‍❤‍👨🏿' => 'coppia con cuore: donna, uomo e carnagione scura',
    '👩🏻‍❤‍👩🏻' => 'coppia con cuore: donna, donna e carnagione chiara',
    '👩🏻‍❤‍👩🏼' => 'coppia con cuore: donna, donna, carnagione chiara e carnagione abbastanza chiara',
    '👩🏻‍❤‍👩🏽' => 'coppia con cuore: donna, donna, carnagione chiara e carnagione olivastra',
    '👩🏻‍❤‍👩🏾' => 'coppia con cuore: donna, donna, carnagione chiara e carnagione abbastanza scura',
    '👩🏻‍❤‍👩🏿' => 'coppia con cuore: donna, donna, carnagione chiara e carnagione scura',
    '👩🏼‍❤‍👩🏻' => 'coppia con cuore: donna, donna, carnagione abbastanza chiara e carnagione chiara',
    '👩🏼‍❤‍👩🏼' => 'coppia con cuore: donna, donna e carnagione abbastanza chiara',
    '👩🏼‍❤‍👩🏽' => 'coppia con cuore: donna, donna, carnagione abbastanza chiara e carnagione olivastra',
    '👩🏼‍❤‍👩🏾' => 'coppia con cuore: donna, donna, carnagione abbastanza chiara e carnagione abbastanza scura',
    '👩🏼‍❤‍👩🏿' => 'coppia con cuore: donna, donna, carnagione abbastanza chiara e carnagione scura',
    '👩🏽‍❤‍👩🏻' => 'coppia con cuore: donna, donna, carnagione olivastra e carnagione chiara',
    '👩🏽‍❤‍👩🏼' => 'coppia con cuore: donna, donna, carnagione olivastra e carnagione abbastanza chiara',
    '👩🏽‍❤‍👩🏽' => 'coppia con cuore: donna, donna e carnagione olivastra',
    '👩🏽‍❤‍👩🏾' => 'coppia con cuore: donna, donna, carnagione olivastra e carnagione abbastanza scura',
    '👩🏽‍❤‍👩🏿' => 'coppia con cuore: donna, donna, carnagione olivastra e carnagione scura',
    '👩🏾‍❤‍👩🏻' => 'coppia con cuore: donna, donna, carnagione abbastanza scura e carnagione chiara',
    '👩🏾‍❤‍👩🏼' => 'coppia con cuore: donna, donna, carnagione abbastanza scura e carnagione abbastanza chiara',
    '👩🏾‍❤‍👩🏽' => 'coppia con cuore: donna, donna, carnagione abbastanza scura e carnagione olivastra',
    '👩🏾‍❤‍👩🏾' => 'coppia con cuore: donna, donna e carnagione abbastanza scura',
    '👩🏾‍❤‍👩🏿' => 'coppia con cuore: donna, donna, carnagione abbastanza scura e carnagione scura',
    '👩🏿‍❤‍👩🏻' => 'coppia con cuore: donna, donna, carnagione scura e carnagione chiara',
    '👩🏿‍❤‍👩🏼' => 'coppia con cuore: donna, donna, carnagione scura e carnagione abbastanza chiara',
    '👩🏿‍❤‍👩🏽' => 'coppia con cuore: donna, donna, carnagione scura e carnagione olivastra',
    '👩🏿‍❤‍👩🏾' => 'coppia con cuore: donna, donna, carnagione scura e carnagione abbastanza scura',
    '👩🏿‍❤‍👩🏿' => 'coppia con cuore: donna, donna e carnagione scura',
    '👩🏻‍🐰‍👩🏼' => 'donne con orecchie da coniglio: carnagione chiara e carnagione abbastanza chiara',
    '👩🏻‍🐰‍👩🏽' => 'donne con orecchie da coniglio: carnagione chiara e carnagione olivastra',
    '👩🏻‍🐰‍👩🏾' => 'donne con orecchie da coniglio: carnagione chiara e carnagione abbastanza scura',
    '👩🏻‍🐰‍👩🏿' => 'donne con orecchie da coniglio: carnagione chiara e carnagione scura',
    '👩🏼‍🐰‍👩🏻' => 'donne con orecchie da coniglio: carnagione abbastanza chiara e carnagione chiara',
    '👩🏼‍🐰‍👩🏽' => 'donne con orecchie da coniglio: carnagione abbastanza chiara e carnagione olivastra',
    '👩🏼‍🐰‍👩🏾' => 'donne con orecchie da coniglio: carnagione abbastanza chiara e carnagione abbastanza scura',
    '👩🏼‍🐰‍👩🏿' => 'donne con orecchie da coniglio: carnagione abbastanza chiara e carnagione scura',
    '👩🏽‍🐰‍👩🏻' => 'donne con orecchie da coniglio: carnagione olivastra e carnagione chiara',
    '👩🏽‍🐰‍👩🏼' => 'donne con orecchie da coniglio: carnagione olivastra e carnagione abbastanza chiara',
    '👩🏽‍🐰‍👩🏾' => 'donne con orecchie da coniglio: carnagione olivastra e carnagione abbastanza scura',
    '👩🏽‍🐰‍👩🏿' => 'donne con orecchie da coniglio: carnagione olivastra e carnagione scura',
    '👩🏾‍🐰‍👩🏻' => 'donne con orecchie da coniglio: carnagione abbastanza scura e carnagione chiara',
    '👩🏾‍🐰‍👩🏼' => 'donne con orecchie da coniglio: carnagione abbastanza scura e carnagione abbastanza chiara',
    '👩🏾‍🐰‍👩🏽' => 'donne con orecchie da coniglio: carnagione abbastanza scura e carnagione olivastra',
    '👩🏾‍🐰‍👩🏿' => 'donne con orecchie da coniglio: carnagione abbastanza scura e carnagione scura',
    '👩🏿‍🐰‍👩🏻' => 'donne con orecchie da coniglio: carnagione scura e carnagione chiara',
    '👩🏿‍🐰‍👩🏼' => 'donne con orecchie da coniglio: carnagione scura e carnagione abbastanza chiara',
    '👩🏿‍🐰‍👩🏽' => 'donne con orecchie da coniglio: carnagione scura e carnagione olivastra',
    '👩🏿‍🐰‍👩🏾' => 'donne con orecchie da coniglio: carnagione scura e carnagione abbastanza scura',
    '🧑🏻‍🤝‍🧑🏻' => 'persone che si tengono per mano: carnagione chiara',
    '🧑🏻‍🤝‍🧑🏼' => 'persone che si tengono per mano: carnagione chiara e carnagione abbastanza chiara',
    '🧑🏻‍🤝‍🧑🏽' => 'persone che si tengono per mano: carnagione chiara e carnagione olivastra',
    '🧑🏻‍🤝‍🧑🏾' => 'persone che si tengono per mano: carnagione chiara e carnagione abbastanza scura',
    '🧑🏻‍🤝‍🧑🏿' => 'persone che si tengono per mano: carnagione chiara e carnagione scura',
    '🧑🏼‍🤝‍🧑🏻' => 'persone che si tengono per mano: carnagione abbastanza chiara e carnagione chiara',
    '🧑🏼‍🤝‍🧑🏼' => 'persone che si tengono per mano: carnagione abbastanza chiara',
    '🧑🏼‍🤝‍🧑🏽' => 'persone che si tengono per mano: carnagione abbastanza chiara e carnagione olivastra',
    '🧑🏼‍🤝‍🧑🏾' => 'persone che si tengono per mano: carnagione abbastanza chiara e carnagione abbastanza scura',
    '🧑🏼‍🤝‍🧑🏿' => 'persone che si tengono per mano: carnagione abbastanza chiara e carnagione scura',
    '🧑🏽‍🤝‍🧑🏻' => 'persone che si tengono per mano: carnagione olivastra e carnagione chiara',
    '🧑🏽‍🤝‍🧑🏼' => 'persone che si tengono per mano: carnagione olivastra e carnagione abbastanza chiara',
    '🧑🏽‍🤝‍🧑🏽' => 'persone che si tengono per mano: carnagione olivastra',
    '🧑🏽‍🤝‍🧑🏾' => 'persone che si tengono per mano: carnagione olivastra e carnagione abbastanza scura',
    '🧑🏽‍🤝‍🧑🏿' => 'persone che si tengono per mano: carnagione olivastra e carnagione scura',
    '🧑🏾‍🤝‍🧑🏻' => 'persone che si tengono per mano: carnagione abbastanza scura e carnagione chiara',
    '🧑🏾‍🤝‍🧑🏼' => 'persone che si tengono per mano: carnagione abbastanza scura e carnagione abbastanza chiara',
    '🧑🏾‍🤝‍🧑🏽' => 'persone che si tengono per mano: carnagione abbastanza scura e carnagione olivastra',
    '🧑🏾‍🤝‍🧑🏾' => 'persone che si tengono per mano: carnagione abbastanza scura',
    '🧑🏾‍🤝‍🧑🏿' => 'persone che si tengono per mano: carnagione abbastanza scura e carnagione scura',
    '🧑🏿‍🤝‍🧑🏻' => 'persone che si tengono per mano: carnagione scura e carnagione chiara',
    '🧑🏿‍🤝‍🧑🏼' => 'persone che si tengono per mano: carnagione scura e carnagione abbastanza chiara',
    '🧑🏿‍🤝‍🧑🏽' => 'persone che si tengono per mano: carnagione scura e carnagione olivastra',
    '🧑🏿‍🤝‍🧑🏾' => 'persone che si tengono per mano: carnagione scura e carnagione abbastanza scura',
    '🧑🏿‍🤝‍🧑🏿' => 'persone che si tengono per mano: carnagione scura',
    '👩🏻‍🤝‍👩🏼' => 'due donne che si tengono per mano: carnagione chiara e carnagione abbastanza chiara',
    '👩🏻‍🤝‍👩🏽' => 'due donne che si tengono per mano: carnagione chiara e carnagione olivastra',
    '👩🏻‍🤝‍👩🏾' => 'due donne che si tengono per mano: carnagione chiara e carnagione abbastanza scura',
    '👩🏻‍🤝‍👩🏿' => 'due donne che si tengono per mano: carnagione chiara e carnagione scura',
    '👩🏼‍🤝‍👩🏻' => 'due donne che si tengono per mano: carnagione abbastanza chiara e carnagione chiara',
    '👩🏼‍🤝‍👩🏽' => 'due donne che si tengono per mano: carnagione abbastanza chiara e carnagione olivastra',
    '👩🏼‍🤝‍👩🏾' => 'due donne che si tengono per mano: carnagione abbastanza chiara e carnagione abbastanza scura',
    '👩🏼‍🤝‍👩🏿' => 'due donne che si tengono per mano: carnagione abbastanza chiara e carnagione scura',
    '👩🏽‍🤝‍👩🏻' => 'due donne che si tengono per mano: carnagione olivastra e carnagione chiara',
    '👩🏽‍🤝‍👩🏼' => 'due donne che si tengono per mano: carnagione olivastra e carnagione abbastanza chiara',
    '👩🏽‍🤝‍👩🏾' => 'due donne che si tengono per mano: carnagione olivastra e carnagione abbastanza scura',
    '👩🏽‍🤝‍👩🏿' => 'due donne che si tengono per mano: carnagione olivastra e carnagione scura',
    '👩🏾‍🤝‍👩🏻' => 'due donne che si tengono per mano: carnagione abbastanza scura e carnagione chiara',
    '👩🏾‍🤝‍👩🏼' => 'due donne che si tengono per mano: carnagione abbastanza scura e carnagione abbastanza chiara',
    '👩🏾‍🤝‍👩🏽' => 'due donne che si tengono per mano: carnagione abbastanza scura e carnagione olivastra',
    '👩🏾‍🤝‍👩🏿' => 'due donne che si tengono per mano: carnagione abbastanza scura e carnagione scura',
    '👩🏿‍🤝‍👩🏻' => 'due donne che si tengono per mano: carnagione scura e carnagione chiara',
    '👩🏿‍🤝‍👩🏼' => 'due donne che si tengono per mano: carnagione scura e carnagione abbastanza chiara',
    '👩🏿‍🤝‍👩🏽' => 'due donne che si tengono per mano: carnagione scura e carnagione olivastra',
    '👩🏿‍🤝‍👩🏾' => 'due donne che si tengono per mano: carnagione scura e carnagione abbastanza scura',
    '👩🏻‍🤝‍👨🏼' => 'uomo e donna che si tengono per mano: carnagione chiara e carnagione abbastanza chiara',
    '👩🏻‍🤝‍👨🏽' => 'uomo e donna che si tengono per mano: carnagione chiara e carnagione olivastra',
    '👩🏻‍🤝‍👨🏾' => 'uomo e donna che si tengono per mano: carnagione chiara e carnagione abbastanza scura',
    '👩🏻‍🤝‍👨🏿' => 'uomo e donna che si tengono per mano: carnagione chiara e carnagione scura',
    '👩🏼‍🤝‍👨🏻' => 'uomo e donna che si tengono per mano: carnagione abbastanza chiara e carnagione chiara',
    '👩🏼‍🤝‍👨🏽' => 'uomo e donna che si tengono per mano: carnagione abbastanza chiara e carnagione olivastra',
    '👩🏼‍🤝‍👨🏾' => 'uomo e donna che si tengono per mano: carnagione abbastanza chiara e carnagione abbastanza scura',
    '👩🏼‍🤝‍👨🏿' => 'uomo e donna che si tengono per mano: carnagione abbastanza chiara e carnagione scura',
    '👩🏽‍🤝‍👨🏻' => 'uomo e donna che si tengono per mano: carnagione olivastra e carnagione chiara',
    '👩🏽‍🤝‍👨🏼' => 'uomo e donna che si tengono per mano: carnagione olivastra e carnagione abbastanza chiara',
    '👩🏽‍🤝‍👨🏾' => 'uomo e donna che si tengono per mano: carnagione olivastra e carnagione abbastanza scura',
    '👩🏽‍🤝‍👨🏿' => 'uomo e donna che si tengono per mano: carnagione olivastra e carnagione scura',
    '👩🏾‍🤝‍👨🏻' => 'uomo e donna che si tengono per mano: carnagione abbastanza scura e carnagione chiara',
    '👩🏾‍🤝‍👨🏼' => 'uomo e donna che si tengono per mano: carnagione abbastanza scura e carnagione abbastanza chiara',
    '👩🏾‍🤝‍👨🏽' => 'uomo e donna che si tengono per mano: carnagione abbastanza scura e carnagione olivastra',
    '👩🏾‍🤝‍👨🏿' => 'uomo e donna che si tengono per mano: carnagione abbastanza scura e carnagione scura',
    '👩🏿‍🤝‍👨🏻' => 'uomo e donna che si tengono per mano: carnagione scura e carnagione chiara',
    '👩🏿‍🤝‍👨🏼' => 'uomo e donna che si tengono per mano: carnagione scura e carnagione abbastanza chiara',
    '👩🏿‍🤝‍👨🏽' => 'uomo e donna che si tengono per mano: carnagione scura e carnagione olivastra',
    '👩🏿‍🤝‍👨🏾' => 'uomo e donna che si tengono per mano: carnagione scura e carnagione abbastanza scura',
    '👨🏻‍🤝‍👨🏼' => 'due uomini che si tengono per mano: carnagione chiara e carnagione abbastanza chiara',
    '👨🏻‍🤝‍👨🏽' => 'due uomini che si tengono per mano: carnagione chiara e carnagione olivastra',
    '👨🏻‍🤝‍👨🏾' => 'due uomini che si tengono per mano: carnagione chiara e carnagione abbastanza scura',
    '👨🏻‍🤝‍👨🏿' => 'due uomini che si tengono per mano: carnagione chiara e carnagione scura',
    '👨🏼‍🤝‍👨🏻' => 'due uomini che si tengono per mano: carnagione abbastanza chiara e carnagione chiara',
    '👨🏼‍🤝‍👨🏽' => 'due uomini che si tengono per mano: carnagione abbastanza chiara e carnagione olivastra',
    '👨🏼‍🤝‍👨🏾' => 'due uomini che si tengono per mano: carnagione abbastanza chiara e carnagione abbastanza scura',
    '👨🏼‍🤝‍👨🏿' => 'due uomini che si tengono per mano: carnagione abbastanza chiara e carnagione scura',
    '👨🏽‍🤝‍👨🏻' => 'due uomini che si tengono per mano: carnagione olivastra e carnagione chiara',
    '👨🏽‍🤝‍👨🏼' => 'due uomini che si tengono per mano: carnagione olivastra e carnagione abbastanza chiara',
    '👨🏽‍🤝‍👨🏾' => 'due uomini che si tengono per mano: carnagione olivastra e carnagione abbastanza scura',
    '👨🏽‍🤝‍👨🏿' => 'due uomini che si tengono per mano: carnagione olivastra e carnagione scura',
    '👨🏾‍🤝‍👨🏻' => 'due uomini che si tengono per mano: carnagione abbastanza scura e carnagione chiara',
    '👨🏾‍🤝‍👨🏼' => 'due uomini che si tengono per mano: carnagione abbastanza scura e carnagione abbastanza chiara',
    '👨🏾‍🤝‍👨🏽' => 'due uomini che si tengono per mano: carnagione abbastanza scura e carnagione olivastra',
    '👨🏾‍🤝‍👨🏿' => 'due uomini che si tengono per mano: carnagione abbastanza scura e carnagione scura',
    '👨🏿‍🤝‍👨🏻' => 'due uomini che si tengono per mano: carnagione scura e carnagione chiara',
    '👨🏿‍🤝‍👨🏼' => 'due uomini che si tengono per mano: carnagione scura e carnagione abbastanza chiara',
    '👨🏿‍🤝‍👨🏽' => 'due uomini che si tengono per mano: carnagione scura e carnagione olivastra',
    '👨🏿‍🤝‍👨🏾' => 'due uomini che si tengono per mano: carnagione scura e carnagione abbastanza scura',
    '👩‍❤‍💋‍👨' => 'bacio tra coppia: donna e uomo',
    '👨‍❤‍💋‍👨' => 'bacio tra coppia: uomo e uomo',
    '👩‍❤‍💋‍👩' => 'bacio tra coppia: donna e donna',
    '👨‍👩‍👧‍👦' => 'famiglia: uomo, donna, bambina e bambino',
    '👨‍👩‍👦‍👦' => 'famiglia: uomo, donna, bambino e bambino',
    '👨‍👩‍👧‍👧' => 'famiglia: uomo, donna, bambina e bambina',
    '👨‍👨‍👧‍👦' => 'famiglia: uomo, uomo, bambina e bambino',
    '👨‍👨‍👦‍👦' => 'famiglia: uomo, uomo, bambino e bambino',
    '👨‍👨‍👧‍👧' => 'famiglia: uomo, uomo, bambina e bambina',
    '👩‍👩‍👧‍👦' => 'famiglia: donna, donna, bambina e bambino',
    '👩‍👩‍👦‍👦' => 'famiglia: donna, donna, bambino e bambino',
    '👩‍👩‍👧‍👧' => 'famiglia: donna, donna, bambina e bambina',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'bandiera: Inghilterra',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'bandiera: Scozia',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'bandiera: Galles',
    '🧑‍🧑‍🧒‍🧒' => 'famiglia: persone adulte, minori',
    '🚶🏻‍♀‍➡' => 'donna che cammina: carnagione chiara e a destra',
    '🚶🏼‍♀‍➡' => 'donna che cammina: carnagione abbastanza chiara e a destra',
    '🚶🏽‍♀‍➡' => 'donna che cammina: carnagione olivastra e a destra',
    '🚶🏾‍♀‍➡' => 'donna che cammina: carnagione abbastanza scura e a destra',
    '🚶🏿‍♀‍➡' => 'donna che cammina: carnagione scura e a destra',
    '🚶🏻‍♂‍➡' => 'uomo che cammina: carnagione chiara e a destra',
    '🚶🏼‍♂‍➡' => 'uomo che cammina: carnagione abbastanza chiara e a destra',
    '🚶🏽‍♂‍➡' => 'uomo che cammina: carnagione olivastra e a destra',
    '🚶🏾‍♂‍➡' => 'uomo che cammina: carnagione abbastanza scura e a destra',
    '🚶🏿‍♂‍➡' => 'uomo che cammina: carnagione scura e a destra',
    '🧎🏻‍♀‍➡' => 'donna inginocchiata: carnagione chiara e a destra',
    '🧎🏼‍♀‍➡' => 'donna inginocchiata: carnagione abbastanza chiara e a destra',
    '🧎🏽‍♀‍➡' => 'donna inginocchiata: carnagione olivastra e a destra',
    '🧎🏾‍♀‍➡' => 'donna inginocchiata: carnagione abbastanza scura e a destra',
    '🧎🏿‍♀‍➡' => 'donna inginocchiata: carnagione scura e a destra',
    '🧎🏻‍♂‍➡' => 'uomo inginocchiato: carnagione chiara e a destra',
    '🧎🏼‍♂‍➡' => 'uomo inginocchiato: carnagione abbastanza chiara e a destra',
    '🧎🏽‍♂‍➡' => 'uomo inginocchiato: carnagione olivastra e a destra',
    '🧎🏾‍♂‍➡' => 'uomo inginocchiato: carnagione abbastanza scura e a destra',
    '🧎🏿‍♂‍➡' => 'uomo inginocchiato: carnagione scura e a destra',
    '🧑🏻‍🦯‍➡' => 'persona con bastone di orientamento: carnagione chiara e a destra',
    '🧑🏼‍🦯‍➡' => 'persona con bastone di orientamento: carnagione abbastanza chiara e a destra',
    '🧑🏽‍🦯‍➡' => 'persona con bastone di orientamento: carnagione olivastra e a destra',
    '🧑🏾‍🦯‍➡' => 'persona con bastone di orientamento: carnagione abbastanza scura e a destra',
    '🧑🏿‍🦯‍➡' => 'persona con bastone di orientamento: carnagione scura e a destra',
    '👨🏻‍🦯‍➡' => 'uomo con bastone bianco di orientamento: carnagione chiara e a destra',
    '👨🏼‍🦯‍➡' => 'uomo con bastone bianco di orientamento: carnagione abbastanza chiara e a destra',
    '👨🏽‍🦯‍➡' => 'uomo con bastone bianco di orientamento: carnagione olivastra e a destra',
    '👨🏾‍🦯‍➡' => 'uomo con bastone bianco di orientamento: carnagione abbastanza scura e a destra',
    '👨🏿‍🦯‍➡' => 'uomo con bastone bianco di orientamento: carnagione scura e a destra',
    '👩🏻‍🦯‍➡' => 'donna con bastone bianco di orientamento: carnagione chiara e a destra',
    '👩🏼‍🦯‍➡' => 'donna con bastone bianco di orientamento: carnagione abbastanza chiara e a destra',
    '👩🏽‍🦯‍➡' => 'donna con bastone bianco di orientamento: carnagione olivastra e a destra',
    '👩🏾‍🦯‍➡' => 'donna con bastone bianco di orientamento: carnagione abbastanza scura e a destra',
    '👩🏿‍🦯‍➡' => 'donna con bastone bianco di orientamento: carnagione scura e a destra',
    '🧑🏻‍🦼‍➡' => 'persona su sedia a rotelle motorizzata: carnagione chiara e a destra',
    '🧑🏼‍🦼‍➡' => 'persona su sedia a rotelle motorizzata: carnagione abbastanza chiara e a destra',
    '🧑🏽‍🦼‍➡' => 'persona su sedia a rotelle motorizzata: carnagione olivastra e a destra',
    '🧑🏾‍🦼‍➡' => 'persona su sedia a rotelle motorizzata: carnagione abbastanza scura e a destra',
    '🧑🏿‍🦼‍➡' => 'persona su sedia a rotelle motorizzata: carnagione scura e a destra',
    '👨🏻‍🦼‍➡' => 'uomo su sedia a rotelle motorizzata: carnagione chiara e a destra',
    '👨🏼‍🦼‍➡' => 'uomo su sedia a rotelle motorizzata: carnagione abbastanza chiara e a destra',
    '👨🏽‍🦼‍➡' => 'uomo su sedia a rotelle motorizzata: carnagione olivastra e a destra',
    '👨🏾‍🦼‍➡' => 'uomo su sedia a rotelle motorizzata: carnagione abbastanza scura e a destra',
    '👨🏿‍🦼‍➡' => 'uomo su sedia a rotelle motorizzata: carnagione scura e a destra',
    '👩🏻‍🦼‍➡' => 'donna su sedia a rotelle motorizzata: carnagione chiara e a destra',
    '👩🏼‍🦼‍➡' => 'donna su sedia a rotelle motorizzata: carnagione abbastanza chiara e a destra',
    '👩🏽‍🦼‍➡' => 'donna su sedia a rotelle motorizzata: carnagione olivastra e a destra',
    '👩🏾‍🦼‍➡' => 'donna su sedia a rotelle motorizzata: carnagione abbastanza scura e a destra',
    '👩🏿‍🦼‍➡' => 'donna su sedia a rotelle motorizzata: carnagione scura e a destra',
    '🧑🏻‍🦽‍➡' => 'persona su sedia a rotelle manuale: carnagione chiara e a destra',
    '🧑🏼‍🦽‍➡' => 'persona su sedia a rotelle manuale: carnagione abbastanza chiara e a destra',
    '🧑🏽‍🦽‍➡' => 'persona su sedia a rotelle manuale: carnagione olivastra e a destra',
    '🧑🏾‍🦽‍➡' => 'persona su sedia a rotelle manuale: carnagione abbastanza scura e a destra',
    '🧑🏿‍🦽‍➡' => 'persona su sedia a rotelle manuale: carnagione scura e a destra',
    '👨🏻‍🦽‍➡' => 'uomo su sedia a rotelle manuale: carnagione chiara e a destra',
    '👨🏼‍🦽‍➡' => 'uomo su sedia a rotelle manuale: carnagione abbastanza chiara e a destra',
    '👨🏽‍🦽‍➡' => 'uomo su sedia a rotelle manuale: carnagione olivastra e a destra',
    '👨🏾‍🦽‍➡' => 'uomo su sedia a rotelle manuale: carnagione abbastanza scura e a destra',
    '👨🏿‍🦽‍➡' => 'uomo su sedia a rotelle manuale: carnagione scura e a destra',
    '👩🏻‍🦽‍➡' => 'donna su sedia a rotelle manuale: carnagione chiara e a destra',
    '👩🏼‍🦽‍➡' => 'donna su sedia a rotelle manuale: carnagione abbastanza chiara e a destra',
    '👩🏽‍🦽‍➡' => 'donna su sedia a rotelle manuale: carnagione olivastra e a destra',
    '👩🏾‍🦽‍➡' => 'donna su sedia a rotelle manuale: carnagione abbastanza scura e a destra',
    '👩🏿‍🦽‍➡' => 'donna su sedia a rotelle manuale: carnagione scura e a destra',
    '🏃🏻‍♀‍➡' => 'donna che corre: carnagione chiara e a destra',
    '🏃🏼‍♀‍➡' => 'donna che corre: carnagione abbastanza chiara e a destra',
    '🏃🏽‍♀‍➡' => 'donna che corre: carnagione olivastra e a destra',
    '🏃🏾‍♀‍➡' => 'donna che corre: carnagione abbastanza scura e a destra',
    '🏃🏿‍♀‍➡' => 'donna che corre: carnagione scura e a destra',
    '🏃🏻‍♂‍➡' => 'uomo che corre: carnagione chiara e a destra',
    '🏃🏼‍♂‍➡' => 'uomo che corre: carnagione abbastanza chiara e a destra',
    '🏃🏽‍♂‍➡' => 'uomo che corre: carnagione olivastra e a destra',
    '🏃🏾‍♂‍➡' => 'uomo che corre: carnagione abbastanza scura e a destra',
    '🏃🏿‍♂‍➡' => 'uomo che corre: carnagione scura e a destra',
    '🫱🏻‍🫲🏼' => 'stretta di mano: carnagione chiara e carnagione abbastanza chiara',
    '🫱🏻‍🫲🏽' => 'stretta di mano: carnagione chiara e carnagione olivastra',
    '🫱🏻‍🫲🏾' => 'stretta di mano: carnagione chiara e carnagione abbastanza scura',
    '🫱🏻‍🫲🏿' => 'stretta di mano: carnagione chiara e carnagione scura',
    '🫱🏼‍🫲🏻' => 'stretta di mano: carnagione abbastanza chiara e carnagione chiara',
    '🫱🏼‍🫲🏽' => 'stretta di mano: carnagione abbastanza chiara e carnagione olivastra',
    '🫱🏼‍🫲🏾' => 'stretta di mano: carnagione abbastanza chiara e carnagione abbastanza scura',
    '🫱🏼‍🫲🏿' => 'stretta di mano: carnagione abbastanza chiara e carnagione scura',
    '🫱🏽‍🫲🏻' => 'stretta di mano: carnagione olivastra e carnagione chiara',
    '🫱🏽‍🫲🏼' => 'stretta di mano: carnagione olivastra e carnagione abbastanza chiara',
    '🫱🏽‍🫲🏾' => 'stretta di mano: carnagione olivastra e carnagione abbastanza scura',
    '🫱🏽‍🫲🏿' => 'stretta di mano: carnagione olivastra e carnagione scura',
    '🫱🏾‍🫲🏻' => 'stretta di mano: carnagione abbastanza scura e carnagione chiara',
    '🫱🏾‍🫲🏼' => 'stretta di mano: carnagione abbastanza scura e carnagione abbastanza chiara',
    '🫱🏾‍🫲🏽' => 'stretta di mano: carnagione abbastanza scura e carnagione olivastra',
    '🫱🏾‍🫲🏿' => 'stretta di mano: carnagione abbastanza scura e carnagione scura',
    '🫱🏿‍🫲🏻' => 'stretta di mano: carnagione scura e carnagione chiara',
    '🫱🏿‍🫲🏼' => 'stretta di mano: carnagione scura e carnagione abbastanza chiara',
    '🫱🏿‍🫲🏽' => 'stretta di mano: carnagione scura e carnagione olivastra',
    '🫱🏿‍🫲🏾' => 'stretta di mano: carnagione scura e carnagione abbastanza scura',
    '🚶‍♀‍➡' => 'donna che cammina: a destra',
    '🚶‍♂‍➡' => 'uomo che cammina: a destra',
    '🧎‍♀‍➡' => 'donna inginocchiata: a destra',
    '🧎‍♂‍➡' => 'uomo inginocchiato: a destra',
    '🧑‍🦯‍➡' => 'persona con bastone di orientamento: a destra',
    '👨‍🦯‍➡' => 'uomo con bastone bianco di orientamento: a destra',
    '👩‍🦯‍➡' => 'donna con bastone bianco di orientamento: a destra',
    '🧑‍🦼‍➡' => 'persona su sedia a rotelle motorizzata: a destra',
    '👨‍🦼‍➡' => 'uomo su sedia a rotelle motorizzata: a destra',
    '👩‍🦼‍➡' => 'donna su sedia a rotelle motorizzata: a destra',
    '🧑‍🦽‍➡' => 'persona su sedia a rotelle manuale: a destra',
    '👨‍🦽‍➡' => 'uomo su sedia a rotelle manuale: a destra',
    '👩‍🦽‍➡' => 'donna su sedia a rotelle manuale: a destra',
    '🏃‍♀‍➡' => 'donna che corre: a destra',
    '🏃‍♂‍➡' => 'uomo che corre: a destra',
    '👩‍❤‍👨' => 'coppia con cuore: donna e uomo',
    '👨‍❤‍👨' => 'coppia con cuore: uomo e uomo',
    '👩‍❤‍👩' => 'coppia con cuore: donna e donna',
    '👨‍👩‍👦' => 'famiglia: uomo, donna e bambino',
    '👨‍👩‍👧' => 'famiglia: uomo, donna e bambina',
    '👨‍👨‍👦' => 'famiglia: uomo, uomo e bambino',
    '👨‍👨‍👧' => 'famiglia: uomo, uomo e bambina',
    '👩‍👩‍👦' => 'famiglia: donna, donna e bambino',
    '👩‍👩‍👧' => 'famiglia: donna, donna e bambina',
    '👨‍👦‍👦' => 'famiglia: uomo, bambino e bambino',
    '👨‍👧‍👦' => 'famiglia: uomo, bambina e bambino',
    '👨‍👧‍👧' => 'famiglia: uomo, bambina e bambina',
    '👩‍👦‍👦' => 'famiglia: donna, bambino e bambino',
    '👩‍👧‍👦' => 'famiglia: donna, bambina e bambino',
    '👩‍👧‍👧' => 'famiglia: donna, bambina e bambina',
    '🧑‍🤝‍🧑' => 'persone che si tengono per mano',
    '🧑‍🧑‍🧒' => 'famiglia: persone adulte, minore',
    '🧑‍🧒‍🧒' => 'famiglia: persona adulta, minore, minore',
    '🧑🏻‍🦰' => 'persona: carnagione chiara e capelli rossi',
    '🧑🏼‍🦰' => 'persona: carnagione abbastanza chiara e capelli rossi',
    '🧑🏽‍🦰' => 'persona: carnagione olivastra e capelli rossi',
    '🧑🏾‍🦰' => 'persona: carnagione abbastanza scura e capelli rossi',
    '🧑🏿‍🦰' => 'persona: carnagione scura e capelli rossi',
    '🧑🏻‍🦱' => 'persona: carnagione chiara e capelli ricci',
    '🧑🏼‍🦱' => 'persona: carnagione abbastanza chiara e capelli ricci',
    '🧑🏽‍🦱' => 'persona: carnagione olivastra e capelli ricci',
    '🧑🏾‍🦱' => 'persona: carnagione abbastanza scura e capelli ricci',
    '🧑🏿‍🦱' => 'persona: carnagione scura e capelli ricci',
    '🧑🏻‍🦳' => 'persona: carnagione chiara e capelli bianchi',
    '🧑🏼‍🦳' => 'persona: carnagione abbastanza chiara e capelli bianchi',
    '🧑🏽‍🦳' => 'persona: carnagione olivastra e capelli bianchi',
    '🧑🏾‍🦳' => 'persona: carnagione abbastanza scura e capelli bianchi',
    '🧑🏿‍🦳' => 'persona: carnagione scura e capelli bianchi',
    '🧑🏻‍🦲' => 'persona: carnagione chiara e calvo',
    '🧑🏼‍🦲' => 'persona: carnagione abbastanza chiara e calvo',
    '🧑🏽‍🦲' => 'persona: carnagione olivastra e calvo',
    '🧑🏾‍🦲' => 'persona: carnagione abbastanza scura e calvo',
    '🧑🏿‍🦲' => 'persona: carnagione scura e calvo',
    '🧑🏻‍🩰' => 'persona che danza: carnagione chiara',
    '🧑🏼‍🩰' => 'persona che danza: carnagione abbastanza chiara',
    '🧑🏽‍🩰' => 'persona che danza: carnagione olivastra',
    '🧑🏾‍🩰' => 'persona che danza: carnagione abbastanza scura',
    '🧑🏿‍🩰' => 'persona che danza: carnagione scura',
    '🧔🏻‍♂' => 'uomo con la barba: carnagione chiara',
    '🧔🏼‍♂' => 'uomo con la barba: carnagione abbastanza chiara',
    '🧔🏽‍♂' => 'uomo con la barba: carnagione olivastra',
    '🧔🏾‍♂' => 'uomo con la barba: carnagione abbastanza scura',
    '🧔🏿‍♂' => 'uomo con la barba: carnagione scura',
    '👱🏻‍♂' => 'uomo biondo: carnagione chiara',
    '👱🏼‍♂' => 'uomo biondo: carnagione abbastanza chiara',
    '👱🏽‍♂' => 'uomo biondo: carnagione olivastra',
    '👱🏾‍♂' => 'uomo biondo: carnagione abbastanza scura',
    '👱🏿‍♂' => 'uomo biondo: carnagione scura',
    '👨🏻‍🦰' => 'uomo: carnagione chiara e capelli rossi',
    '👨🏼‍🦰' => 'uomo: carnagione abbastanza chiara e capelli rossi',
    '👨🏽‍🦰' => 'uomo: carnagione olivastra e capelli rossi',
    '👨🏾‍🦰' => 'uomo: carnagione abbastanza scura e capelli rossi',
    '👨🏿‍🦰' => 'uomo: carnagione scura e capelli rossi',
    '👨🏻‍🦱' => 'uomo: carnagione chiara e capelli ricci',
    '👨🏼‍🦱' => 'uomo: carnagione abbastanza chiara e capelli ricci',
    '👨🏽‍🦱' => 'uomo: carnagione olivastra e capelli ricci',
    '👨🏾‍🦱' => 'uomo: carnagione abbastanza scura e capelli ricci',
    '👨🏿‍🦱' => 'uomo: carnagione scura e capelli ricci',
    '👨🏻‍🦳' => 'uomo: carnagione chiara e capelli bianchi',
    '👨🏼‍🦳' => 'uomo: carnagione abbastanza chiara e capelli bianchi',
    '👨🏽‍🦳' => 'uomo: carnagione olivastra e capelli bianchi',
    '👨🏾‍🦳' => 'uomo: carnagione abbastanza scura e capelli bianchi',
    '👨🏿‍🦳' => 'uomo: carnagione scura e capelli bianchi',
    '👨🏻‍🦲' => 'uomo: carnagione chiara e calvo',
    '👨🏼‍🦲' => 'uomo: carnagione abbastanza chiara e calvo',
    '👨🏽‍🦲' => 'uomo: carnagione olivastra e calvo',
    '👨🏾‍🦲' => 'uomo: carnagione abbastanza scura e calvo',
    '👨🏿‍🦲' => 'uomo: carnagione scura e calvo',
    '🧔🏻‍♀' => 'donna con la barba: carnagione chiara',
    '🧔🏼‍♀' => 'donna con la barba: carnagione abbastanza chiara',
    '🧔🏽‍♀' => 'donna con la barba: carnagione olivastra',
    '🧔🏾‍♀' => 'donna con la barba: carnagione abbastanza scura',
    '🧔🏿‍♀' => 'donna con la barba: carnagione scura',
    '👱🏻‍♀' => 'donna bionda: carnagione chiara',
    '👱🏼‍♀' => 'donna bionda: carnagione abbastanza chiara',
    '👱🏽‍♀' => 'donna bionda: carnagione olivastra',
    '👱🏾‍♀' => 'donna bionda: carnagione abbastanza scura',
    '👱🏿‍♀' => 'donna bionda: carnagione scura',
    '👩🏻‍🦰' => 'donna: carnagione chiara e capelli rossi',
    '👩🏼‍🦰' => 'donna: carnagione abbastanza chiara e capelli rossi',
    '👩🏽‍🦰' => 'donna: carnagione olivastra e capelli rossi',
    '👩🏾‍🦰' => 'donna: carnagione abbastanza scura e capelli rossi',
    '👩🏿‍🦰' => 'donna: carnagione scura e capelli rossi',
    '👩🏻‍🦱' => 'donna: carnagione chiara e capelli ricci',
    '👩🏼‍🦱' => 'donna: carnagione abbastanza chiara e capelli ricci',
    '👩🏽‍🦱' => 'donna: carnagione olivastra e capelli ricci',
    '👩🏾‍🦱' => 'donna: carnagione abbastanza scura e capelli ricci',
    '👩🏿‍🦱' => 'donna: carnagione scura e capelli ricci',
    '👩🏻‍🦳' => 'donna: carnagione chiara e capelli bianchi',
    '👩🏼‍🦳' => 'donna: carnagione abbastanza chiara e capelli bianchi',
    '👩🏽‍🦳' => 'donna: carnagione olivastra e capelli bianchi',
    '👩🏾‍🦳' => 'donna: carnagione abbastanza scura e capelli bianchi',
    '👩🏿‍🦳' => 'donna: carnagione scura e capelli bianchi',
    '👩🏻‍🦲' => 'donna: carnagione chiara e calvo',
    '👩🏼‍🦲' => 'donna: carnagione abbastanza chiara e calvo',
    '👩🏽‍🦲' => 'donna: carnagione olivastra e calvo',
    '👩🏾‍🦲' => 'donna: carnagione abbastanza scura e calvo',
    '👩🏿‍🦲' => 'donna: carnagione scura e calvo',
    '🙍🏻‍♂' => 'uomo corrucciato: carnagione chiara',
    '🙍🏼‍♂' => 'uomo corrucciato: carnagione abbastanza chiara',
    '🙍🏽‍♂' => 'uomo corrucciato: carnagione olivastra',
    '🙍🏾‍♂' => 'uomo corrucciato: carnagione abbastanza scura',
    '🙍🏿‍♂' => 'uomo corrucciato: carnagione scura',
    '🙍🏻‍♀' => 'donna corrucciata: carnagione chiara',
    '🙍🏼‍♀' => 'donna corrucciata: carnagione abbastanza chiara',
    '🙍🏽‍♀' => 'donna corrucciata: carnagione olivastra',
    '🙍🏾‍♀' => 'donna corrucciata: carnagione abbastanza scura',
    '🙍🏿‍♀' => 'donna corrucciata: carnagione scura',
    '🙎🏻‍♂' => 'uomo imbronciato: carnagione chiara',
    '🙎🏼‍♂' => 'uomo imbronciato: carnagione abbastanza chiara',
    '🙎🏽‍♂' => 'uomo imbronciato: carnagione olivastra',
    '🙎🏾‍♂' => 'uomo imbronciato: carnagione abbastanza scura',
    '🙎🏿‍♂' => 'uomo imbronciato: carnagione scura',
    '🙎🏻‍♀' => 'donna imbronciata: carnagione chiara',
    '🙎🏼‍♀' => 'donna imbronciata: carnagione abbastanza chiara',
    '🙎🏽‍♀' => 'donna imbronciata: carnagione olivastra',
    '🙎🏾‍♀' => 'donna imbronciata: carnagione abbastanza scura',
    '🙎🏿‍♀' => 'donna imbronciata: carnagione scura',
    '🙅🏻‍♂' => 'uomo con gesto di rifiuto: carnagione chiara',
    '🙅🏼‍♂' => 'uomo con gesto di rifiuto: carnagione abbastanza chiara',
    '🙅🏽‍♂' => 'uomo con gesto di rifiuto: carnagione olivastra',
    '🙅🏾‍♂' => 'uomo con gesto di rifiuto: carnagione abbastanza scura',
    '🙅🏿‍♂' => 'uomo con gesto di rifiuto: carnagione scura',
    '🙅🏻‍♀' => 'donna con gesto di rifiuto: carnagione chiara',
    '🙅🏼‍♀' => 'donna con gesto di rifiuto: carnagione abbastanza chiara',
    '🙅🏽‍♀' => 'donna con gesto di rifiuto: carnagione olivastra',
    '🙅🏾‍♀' => 'donna con gesto di rifiuto: carnagione abbastanza scura',
    '🙅🏿‍♀' => 'donna con gesto di rifiuto: carnagione scura',
    '🙆🏻‍♂' => 'uomo con gesto OK: carnagione chiara',
    '🙆🏼‍♂' => 'uomo con gesto OK: carnagione abbastanza chiara',
    '🙆🏽‍♂' => 'uomo con gesto OK: carnagione olivastra',
    '🙆🏾‍♂' => 'uomo con gesto OK: carnagione abbastanza scura',
    '🙆🏿‍♂' => 'uomo con gesto OK: carnagione scura',
    '🙆🏻‍♀' => 'donna con gesto OK: carnagione chiara',
    '🙆🏼‍♀' => 'donna con gesto OK: carnagione abbastanza chiara',
    '🙆🏽‍♀' => 'donna con gesto OK: carnagione olivastra',
    '🙆🏾‍♀' => 'donna con gesto OK: carnagione abbastanza scura',
    '🙆🏿‍♀' => 'donna con gesto OK: carnagione scura',
    '💁🏻‍♂' => 'uomo con mano capovolta: carnagione chiara',
    '💁🏼‍♂' => 'uomo con mano capovolta: carnagione abbastanza chiara',
    '💁🏽‍♂' => 'uomo con mano capovolta: carnagione olivastra',
    '💁🏾‍♂' => 'uomo con mano capovolta: carnagione abbastanza scura',
    '💁🏿‍♂' => 'uomo con mano capovolta: carnagione scura',
    '💁🏻‍♀' => 'donna con mano capovolta: carnagione chiara',
    '💁🏼‍♀' => 'donna con mano capovolta: carnagione abbastanza chiara',
    '💁🏽‍♀' => 'donna con mano capovolta: carnagione olivastra',
    '💁🏾‍♀' => 'donna con mano capovolta: carnagione abbastanza scura',
    '💁🏿‍♀' => 'donna con mano capovolta: carnagione scura',
    '🙋🏻‍♂' => 'uomo con mano alzata: carnagione chiara',
    '🙋🏼‍♂' => 'uomo con mano alzata: carnagione abbastanza chiara',
    '🙋🏽‍♂' => 'uomo con mano alzata: carnagione olivastra',
    '🙋🏾‍♂' => 'uomo con mano alzata: carnagione abbastanza scura',
    '🙋🏿‍♂' => 'uomo con mano alzata: carnagione scura',
    '🙋🏻‍♀' => 'donna con mano alzata: carnagione chiara',
    '🙋🏼‍♀' => 'donna con mano alzata: carnagione abbastanza chiara',
    '🙋🏽‍♀' => 'donna con mano alzata: carnagione olivastra',
    '🙋🏾‍♀' => 'donna con mano alzata: carnagione abbastanza scura',
    '🙋🏿‍♀' => 'donna con mano alzata: carnagione scura',
    '🧏🏻‍♂' => 'uomo con problemi di udito: carnagione chiara',
    '🧏🏼‍♂' => 'uomo con problemi di udito: carnagione abbastanza chiara',
    '🧏🏽‍♂' => 'uomo con problemi di udito: carnagione olivastra',
    '🧏🏾‍♂' => 'uomo con problemi di udito: carnagione abbastanza scura',
    '🧏🏿‍♂' => 'uomo con problemi di udito: carnagione scura',
    '🧏🏻‍♀' => 'donna con problemi di udito: carnagione chiara',
    '🧏🏼‍♀' => 'donna con problemi di udito: carnagione abbastanza chiara',
    '🧏🏽‍♀' => 'donna con problemi di udito: carnagione olivastra',
    '🧏🏾‍♀' => 'donna con problemi di udito: carnagione abbastanza scura',
    '🧏🏿‍♀' => 'donna con problemi di udito: carnagione scura',
    '🙇🏻‍♂' => 'uomo che fa inchino profondo: carnagione chiara',
    '🙇🏼‍♂' => 'uomo che fa inchino profondo: carnagione abbastanza chiara',
    '🙇🏽‍♂' => 'uomo che fa inchino profondo: carnagione olivastra',
    '🙇🏾‍♂' => 'uomo che fa inchino profondo: carnagione abbastanza scura',
    '🙇🏿‍♂' => 'uomo che fa inchino profondo: carnagione scura',
    '🙇🏻‍♀' => 'donna che fa inchino profondo: carnagione chiara',
    '🙇🏼‍♀' => 'donna che fa inchino profondo: carnagione abbastanza chiara',
    '🙇🏽‍♀' => 'donna che fa inchino profondo: carnagione olivastra',
    '🙇🏾‍♀' => 'donna che fa inchino profondo: carnagione abbastanza scura',
    '🙇🏿‍♀' => 'donna che fa inchino profondo: carnagione scura',
    '🤦🏻‍♂' => 'uomo esasperato: carnagione chiara',
    '🤦🏼‍♂' => 'uomo esasperato: carnagione abbastanza chiara',
    '🤦🏽‍♂' => 'uomo esasperato: carnagione olivastra',
    '🤦🏾‍♂' => 'uomo esasperato: carnagione abbastanza scura',
    '🤦🏿‍♂' => 'uomo esasperato: carnagione scura',
    '🤦🏻‍♀' => 'donna esasperata: carnagione chiara',
    '🤦🏼‍♀' => 'donna esasperata: carnagione abbastanza chiara',
    '🤦🏽‍♀' => 'donna esasperata: carnagione olivastra',
    '🤦🏾‍♀' => 'donna esasperata: carnagione abbastanza scura',
    '🤦🏿‍♀' => 'donna esasperata: carnagione scura',
    '🤷🏻‍♂' => 'uomo che scrolla le spalle: carnagione chiara',
    '🤷🏼‍♂' => 'uomo che scrolla le spalle: carnagione abbastanza chiara',
    '🤷🏽‍♂' => 'uomo che scrolla le spalle: carnagione olivastra',
    '🤷🏾‍♂' => 'uomo che scrolla le spalle: carnagione abbastanza scura',
    '🤷🏿‍♂' => 'uomo che scrolla le spalle: carnagione scura',
    '🤷🏻‍♀' => 'donna che scrolla le spalle: carnagione chiara',
    '🤷🏼‍♀' => 'donna che scrolla le spalle: carnagione abbastanza chiara',
    '🤷🏽‍♀' => 'donna che scrolla le spalle: carnagione olivastra',
    '🤷🏾‍♀' => 'donna che scrolla le spalle: carnagione abbastanza scura',
    '🤷🏿‍♀' => 'donna che scrolla le spalle: carnagione scura',
    '🧑🏻‍⚕' => 'persona che lavora nella sanità: carnagione chiara',
    '🧑🏼‍⚕' => 'persona che lavora nella sanità: carnagione abbastanza chiara',
    '🧑🏽‍⚕' => 'persona che lavora nella sanità: carnagione olivastra',
    '🧑🏾‍⚕' => 'persona che lavora nella sanità: carnagione abbastanza scura',
    '🧑🏿‍⚕' => 'persona che lavora nella sanità: carnagione scura',
    '👨🏻‍⚕' => 'operatore sanitario: carnagione chiara',
    '👨🏼‍⚕' => 'operatore sanitario: carnagione abbastanza chiara',
    '👨🏽‍⚕' => 'operatore sanitario: carnagione olivastra',
    '👨🏾‍⚕' => 'operatore sanitario: carnagione abbastanza scura',
    '👨🏿‍⚕' => 'operatore sanitario: carnagione scura',
    '👩🏻‍⚕' => 'operatrice sanitaria: carnagione chiara',
    '👩🏼‍⚕' => 'operatrice sanitaria: carnagione abbastanza chiara',
    '👩🏽‍⚕' => 'operatrice sanitaria: carnagione olivastra',
    '👩🏾‍⚕' => 'operatrice sanitaria: carnagione abbastanza scura',
    '👩🏿‍⚕' => 'operatrice sanitaria: carnagione scura',
    '🧑🏻‍🎓' => 'studente: carnagione chiara',
    '🧑🏼‍🎓' => 'studente: carnagione abbastanza chiara',
    '🧑🏽‍🎓' => 'studente: carnagione olivastra',
    '🧑🏾‍🎓' => 'studente: carnagione abbastanza scura',
    '🧑🏿‍🎓' => 'studente: carnagione scura',
    '👨🏻‍🎓' => 'studente maschio: carnagione chiara',
    '👨🏼‍🎓' => 'studente maschio: carnagione abbastanza chiara',
    '👨🏽‍🎓' => 'studente maschio: carnagione olivastra',
    '👨🏾‍🎓' => 'studente maschio: carnagione abbastanza scura',
    '👨🏿‍🎓' => 'studente maschio: carnagione scura',
    '👩🏻‍🎓' => 'studentessa: carnagione chiara',
    '👩🏼‍🎓' => 'studentessa: carnagione abbastanza chiara',
    '👩🏽‍🎓' => 'studentessa: carnagione olivastra',
    '👩🏾‍🎓' => 'studentessa: carnagione abbastanza scura',
    '👩🏿‍🎓' => 'studentessa: carnagione scura',
    '🧑🏻‍🏫' => 'insegnante: carnagione chiara',
    '🧑🏼‍🏫' => 'insegnante: carnagione abbastanza chiara',
    '🧑🏽‍🏫' => 'insegnante: carnagione olivastra',
    '🧑🏾‍🏫' => 'insegnante: carnagione abbastanza scura',
    '🧑🏿‍🏫' => 'insegnante: carnagione scura',
    '👨🏻‍🏫' => 'professore: carnagione chiara',
    '👨🏼‍🏫' => 'professore: carnagione abbastanza chiara',
    '👨🏽‍🏫' => 'professore: carnagione olivastra',
    '👨🏾‍🏫' => 'professore: carnagione abbastanza scura',
    '👨🏿‍🏫' => 'professore: carnagione scura',
    '👩🏻‍🏫' => 'professoressa: carnagione chiara',
    '👩🏼‍🏫' => 'professoressa: carnagione abbastanza chiara',
    '👩🏽‍🏫' => 'professoressa: carnagione olivastra',
    '👩🏾‍🏫' => 'professoressa: carnagione abbastanza scura',
    '👩🏿‍🏫' => 'professoressa: carnagione scura',
    '🧑🏻‍⚖' => 'giudice: carnagione chiara',
    '🧑🏼‍⚖' => 'giudice: carnagione abbastanza chiara',
    '🧑🏽‍⚖' => 'giudice: carnagione olivastra',
    '🧑🏾‍⚖' => 'giudice: carnagione abbastanza scura',
    '🧑🏿‍⚖' => 'giudice: carnagione scura',
    '👨🏻‍⚖' => 'giudice uomo: carnagione chiara',
    '👨🏼‍⚖' => 'giudice uomo: carnagione abbastanza chiara',
    '👨🏽‍⚖' => 'giudice uomo: carnagione olivastra',
    '👨🏾‍⚖' => 'giudice uomo: carnagione abbastanza scura',
    '👨🏿‍⚖' => 'giudice uomo: carnagione scura',
    '👩🏻‍⚖' => 'giudice donna: carnagione chiara',
    '👩🏼‍⚖' => 'giudice donna: carnagione abbastanza chiara',
    '👩🏽‍⚖' => 'giudice donna: carnagione olivastra',
    '👩🏾‍⚖' => 'giudice donna: carnagione abbastanza scura',
    '👩🏿‍⚖' => 'giudice donna: carnagione scura',
    '🧑🏻‍🌾' => 'agricoltore: carnagione chiara',
    '🧑🏼‍🌾' => 'agricoltore: carnagione abbastanza chiara',
    '🧑🏽‍🌾' => 'agricoltore: carnagione olivastra',
    '🧑🏾‍🌾' => 'agricoltore: carnagione abbastanza scura',
    '🧑🏿‍🌾' => 'agricoltore: carnagione scura',
    '👨🏻‍🌾' => 'contadino: carnagione chiara',
    '👨🏼‍🌾' => 'contadino: carnagione abbastanza chiara',
    '👨🏽‍🌾' => 'contadino: carnagione olivastra',
    '👨🏾‍🌾' => 'contadino: carnagione abbastanza scura',
    '👨🏿‍🌾' => 'contadino: carnagione scura',
    '👩🏻‍🌾' => 'contadina: carnagione chiara',
    '👩🏼‍🌾' => 'contadina: carnagione abbastanza chiara',
    '👩🏽‍🌾' => 'contadina: carnagione olivastra',
    '👩🏾‍🌾' => 'contadina: carnagione abbastanza scura',
    '👩🏿‍🌾' => 'contadina: carnagione scura',
    '🧑🏻‍🍳' => 'persona che cucina: carnagione chiara',
    '🧑🏼‍🍳' => 'persona che cucina: carnagione abbastanza chiara',
    '🧑🏽‍🍳' => 'persona che cucina: carnagione olivastra',
    '🧑🏾‍🍳' => 'persona che cucina: carnagione abbastanza scura',
    '🧑🏿‍🍳' => 'persona che cucina: carnagione scura',
    '👨🏻‍🍳' => 'cuoco: carnagione chiara',
    '👨🏼‍🍳' => 'cuoco: carnagione abbastanza chiara',
    '👨🏽‍🍳' => 'cuoco: carnagione olivastra',
    '👨🏾‍🍳' => 'cuoco: carnagione abbastanza scura',
    '👨🏿‍🍳' => 'cuoco: carnagione scura',
    '👩🏻‍🍳' => 'cuoca: carnagione chiara',
    '👩🏼‍🍳' => 'cuoca: carnagione abbastanza chiara',
    '👩🏽‍🍳' => 'cuoca: carnagione olivastra',
    '👩🏾‍🍳' => 'cuoca: carnagione abbastanza scura',
    '👩🏿‍🍳' => 'cuoca: carnagione scura',
    '🧑🏻‍🔧' => 'meccanico: carnagione chiara',
    '🧑🏼‍🔧' => 'meccanico: carnagione abbastanza chiara',
    '🧑🏽‍🔧' => 'meccanico: carnagione olivastra',
    '🧑🏾‍🔧' => 'meccanico: carnagione abbastanza scura',
    '🧑🏿‍🔧' => 'meccanico: carnagione scura',
    '👨🏻‍🔧' => 'meccanico uomo: carnagione chiara',
    '👨🏼‍🔧' => 'meccanico uomo: carnagione abbastanza chiara',
    '👨🏽‍🔧' => 'meccanico uomo: carnagione olivastra',
    '👨🏾‍🔧' => 'meccanico uomo: carnagione abbastanza scura',
    '👨🏿‍🔧' => 'meccanico uomo: carnagione scura',
    '👩🏻‍🔧' => 'meccanico donna: carnagione chiara',
    '👩🏼‍🔧' => 'meccanico donna: carnagione abbastanza chiara',
    '👩🏽‍🔧' => 'meccanico donna: carnagione olivastra',
    '👩🏾‍🔧' => 'meccanico donna: carnagione abbastanza scura',
    '👩🏿‍🔧' => 'meccanico donna: carnagione scura',
    '🧑🏻‍🏭' => 'persona che lavora in fabbrica: carnagione chiara',
    '🧑🏼‍🏭' => 'persona che lavora in fabbrica: carnagione abbastanza chiara',
    '🧑🏽‍🏭' => 'persona che lavora in fabbrica: carnagione olivastra',
    '🧑🏾‍🏭' => 'persona che lavora in fabbrica: carnagione abbastanza scura',
    '🧑🏿‍🏭' => 'persona che lavora in fabbrica: carnagione scura',
    '👨🏻‍🏭' => 'operaio: carnagione chiara',
    '👨🏼‍🏭' => 'operaio: carnagione abbastanza chiara',
    '👨🏽‍🏭' => 'operaio: carnagione olivastra',
    '👨🏾‍🏭' => 'operaio: carnagione abbastanza scura',
    '👨🏿‍🏭' => 'operaio: carnagione scura',
    '👩🏻‍🏭' => 'operaia: carnagione chiara',
    '👩🏼‍🏭' => 'operaia: carnagione abbastanza chiara',
    '👩🏽‍🏭' => 'operaia: carnagione olivastra',
    '👩🏾‍🏭' => 'operaia: carnagione abbastanza scura',
    '👩🏿‍🏭' => 'operaia: carnagione scura',
    '🧑🏻‍💼' => 'persona che fa un lavoro d’ufficio: carnagione chiara',
    '🧑🏼‍💼' => 'persona che fa un lavoro d’ufficio: carnagione abbastanza chiara',
    '🧑🏽‍💼' => 'persona che fa un lavoro d’ufficio: carnagione olivastra',
    '🧑🏾‍💼' => 'persona che fa un lavoro d’ufficio: carnagione abbastanza scura',
    '🧑🏿‍💼' => 'persona che fa un lavoro d’ufficio: carnagione scura',
    '👨🏻‍💼' => 'impiegato: carnagione chiara',
    '👨🏼‍💼' => 'impiegato: carnagione abbastanza chiara',
    '👨🏽‍💼' => 'impiegato: carnagione olivastra',
    '👨🏾‍💼' => 'impiegato: carnagione abbastanza scura',
    '👨🏿‍💼' => 'impiegato: carnagione scura',
    '👩🏻‍💼' => 'impiegata: carnagione chiara',
    '👩🏼‍💼' => 'impiegata: carnagione abbastanza chiara',
    '👩🏽‍💼' => 'impiegata: carnagione olivastra',
    '👩🏾‍💼' => 'impiegata: carnagione abbastanza scura',
    '👩🏿‍💼' => 'impiegata: carnagione scura',
    '🧑🏻‍🔬' => 'persona che lavora in campo scientifico: carnagione chiara',
    '🧑🏼‍🔬' => 'persona che lavora in campo scientifico: carnagione abbastanza chiara',
    '🧑🏽‍🔬' => 'persona che lavora in campo scientifico: carnagione olivastra',
    '🧑🏾‍🔬' => 'persona che lavora in campo scientifico: carnagione abbastanza scura',
    '🧑🏿‍🔬' => 'persona che lavora in campo scientifico: carnagione scura',
    '👨🏻‍🔬' => 'scienziato: carnagione chiara',
    '👨🏼‍🔬' => 'scienziato: carnagione abbastanza chiara',
    '👨🏽‍🔬' => 'scienziato: carnagione olivastra',
    '👨🏾‍🔬' => 'scienziato: carnagione abbastanza scura',
    '👨🏿‍🔬' => 'scienziato: carnagione scura',
    '👩🏻‍🔬' => 'scienziata: carnagione chiara',
    '👩🏼‍🔬' => 'scienziata: carnagione abbastanza chiara',
    '👩🏽‍🔬' => 'scienziata: carnagione olivastra',
    '👩🏾‍🔬' => 'scienziata: carnagione abbastanza scura',
    '👩🏿‍🔬' => 'scienziata: carnagione scura',
    '🧑🏻‍💻' => 'persona esperta di tecnologia: carnagione chiara',
    '🧑🏼‍💻' => 'persona esperta di tecnologia: carnagione abbastanza chiara',
    '🧑🏽‍💻' => 'persona esperta di tecnologia: carnagione olivastra',
    '🧑🏾‍💻' => 'persona esperta di tecnologia: carnagione abbastanza scura',
    '🧑🏿‍💻' => 'persona esperta di tecnologia: carnagione scura',
    '👨🏻‍💻' => 'tecnologo: carnagione chiara',
    '👨🏼‍💻' => 'tecnologo: carnagione abbastanza chiara',
    '👨🏽‍💻' => 'tecnologo: carnagione olivastra',
    '👨🏾‍💻' => 'tecnologo: carnagione abbastanza scura',
    '👨🏿‍💻' => 'tecnologo: carnagione scura',
    '👩🏻‍💻' => 'tecnologa: carnagione chiara',
    '👩🏼‍💻' => 'tecnologa: carnagione abbastanza chiara',
    '👩🏽‍💻' => 'tecnologa: carnagione olivastra',
    '👩🏾‍💻' => 'tecnologa: carnagione abbastanza scura',
    '👩🏿‍💻' => 'tecnologa: carnagione scura',
    '🧑🏻‍🎤' => 'cantante: carnagione chiara',
    '🧑🏼‍🎤' => 'cantante: carnagione abbastanza chiara',
    '🧑🏽‍🎤' => 'cantante: carnagione olivastra',
    '🧑🏾‍🎤' => 'cantante: carnagione abbastanza scura',
    '🧑🏿‍🎤' => 'cantante: carnagione scura',
    '👨🏻‍🎤' => 'cantante uomo: carnagione chiara',
    '👨🏼‍🎤' => 'cantante uomo: carnagione abbastanza chiara',
    '👨🏽‍🎤' => 'cantante uomo: carnagione olivastra',
    '👨🏾‍🎤' => 'cantante uomo: carnagione abbastanza scura',
    '👨🏿‍🎤' => 'cantante uomo: carnagione scura',
    '👩🏻‍🎤' => 'cantante donna: carnagione chiara',
    '👩🏼‍🎤' => 'cantante donna: carnagione abbastanza chiara',
    '👩🏽‍🎤' => 'cantante donna: carnagione olivastra',
    '👩🏾‍🎤' => 'cantante donna: carnagione abbastanza scura',
    '👩🏿‍🎤' => 'cantante donna: carnagione scura',
    '🧑🏻‍🎨' => 'artista: carnagione chiara',
    '🧑🏼‍🎨' => 'artista: carnagione abbastanza chiara',
    '🧑🏽‍🎨' => 'artista: carnagione olivastra',
    '🧑🏾‍🎨' => 'artista: carnagione abbastanza scura',
    '🧑🏿‍🎨' => 'artista: carnagione scura',
    '👨🏻‍🎨' => 'artista uomo: carnagione chiara',
    '👨🏼‍🎨' => 'artista uomo: carnagione abbastanza chiara',
    '👨🏽‍🎨' => 'artista uomo: carnagione olivastra',
    '👨🏾‍🎨' => 'artista uomo: carnagione abbastanza scura',
    '👨🏿‍🎨' => 'artista uomo: carnagione scura',
    '👩🏻‍🎨' => 'artista donna: carnagione chiara',
    '👩🏼‍🎨' => 'artista donna: carnagione abbastanza chiara',
    '👩🏽‍🎨' => 'artista donna: carnagione olivastra',
    '👩🏾‍🎨' => 'artista donna: carnagione abbastanza scura',
    '👩🏿‍🎨' => 'artista donna: carnagione scura',
    '🧑🏻‍✈' => 'pilota: carnagione chiara',
    '🧑🏼‍✈' => 'pilota: carnagione abbastanza chiara',
    '🧑🏽‍✈' => 'pilota: carnagione olivastra',
    '🧑🏾‍✈' => 'pilota: carnagione abbastanza scura',
    '🧑🏿‍✈' => 'pilota: carnagione scura',
    '👨🏻‍✈' => 'pilota uomo: carnagione chiara',
    '👨🏼‍✈' => 'pilota uomo: carnagione abbastanza chiara',
    '👨🏽‍✈' => 'pilota uomo: carnagione olivastra',
    '👨🏾‍✈' => 'pilota uomo: carnagione abbastanza scura',
    '👨🏿‍✈' => 'pilota uomo: carnagione scura',
    '👩🏻‍✈' => 'pilota donna: carnagione chiara',
    '👩🏼‍✈' => 'pilota donna: carnagione abbastanza chiara',
    '👩🏽‍✈' => 'pilota donna: carnagione olivastra',
    '👩🏾‍✈' => 'pilota donna: carnagione abbastanza scura',
    '👩🏿‍✈' => 'pilota donna: carnagione scura',
    '🧑🏻‍🚀' => 'astronauta: carnagione chiara',
    '🧑🏼‍🚀' => 'astronauta: carnagione abbastanza chiara',
    '🧑🏽‍🚀' => 'astronauta: carnagione olivastra',
    '🧑🏾‍🚀' => 'astronauta: carnagione abbastanza scura',
    '🧑🏿‍🚀' => 'astronauta: carnagione scura',
    '👨🏻‍🚀' => 'astronauta uomo: carnagione chiara',
    '👨🏼‍🚀' => 'astronauta uomo: carnagione abbastanza chiara',
    '👨🏽‍🚀' => 'astronauta uomo: carnagione olivastra',
    '👨🏾‍🚀' => 'astronauta uomo: carnagione abbastanza scura',
    '👨🏿‍🚀' => 'astronauta uomo: carnagione scura',
    '👩🏻‍🚀' => 'astronauta donna: carnagione chiara',
    '👩🏼‍🚀' => 'astronauta donna: carnagione abbastanza chiara',
    '👩🏽‍🚀' => 'astronauta donna: carnagione olivastra',
    '👩🏾‍🚀' => 'astronauta donna: carnagione abbastanza scura',
    '👩🏿‍🚀' => 'astronauta donna: carnagione scura',
    '🧑🏻‍🚒' => 'pompiere: carnagione chiara',
    '🧑🏼‍🚒' => 'pompiere: carnagione abbastanza chiara',
    '🧑🏽‍🚒' => 'pompiere: carnagione olivastra',
    '🧑🏾‍🚒' => 'pompiere: carnagione abbastanza scura',
    '🧑🏿‍🚒' => 'pompiere: carnagione scura',
    '👨🏻‍🚒' => 'pompiere uomo: carnagione chiara',
    '👨🏼‍🚒' => 'pompiere uomo: carnagione abbastanza chiara',
    '👨🏽‍🚒' => 'pompiere uomo: carnagione olivastra',
    '👨🏾‍🚒' => 'pompiere uomo: carnagione abbastanza scura',
    '👨🏿‍🚒' => 'pompiere uomo: carnagione scura',
    '👩🏻‍🚒' => 'pompiere donna: carnagione chiara',
    '👩🏼‍🚒' => 'pompiere donna: carnagione abbastanza chiara',
    '👩🏽‍🚒' => 'pompiere donna: carnagione olivastra',
    '👩🏾‍🚒' => 'pompiere donna: carnagione abbastanza scura',
    '👩🏿‍🚒' => 'pompiere donna: carnagione scura',
    '👮🏻‍♂' => 'poliziotto: carnagione chiara',
    '👮🏼‍♂' => 'poliziotto: carnagione abbastanza chiara',
    '👮🏽‍♂' => 'poliziotto: carnagione olivastra',
    '👮🏾‍♂' => 'poliziotto: carnagione abbastanza scura',
    '👮🏿‍♂' => 'poliziotto: carnagione scura',
    '👮🏻‍♀' => 'poliziotta: carnagione chiara',
    '👮🏼‍♀' => 'poliziotta: carnagione abbastanza chiara',
    '👮🏽‍♀' => 'poliziotta: carnagione olivastra',
    '👮🏾‍♀' => 'poliziotta: carnagione abbastanza scura',
    '👮🏿‍♀' => 'poliziotta: carnagione scura',
    '🕵🏻‍♂' => 'investigatore: carnagione chiara',
    '🕵🏼‍♂' => 'investigatore: carnagione abbastanza chiara',
    '🕵🏽‍♂' => 'investigatore: carnagione olivastra',
    '🕵🏾‍♂' => 'investigatore: carnagione abbastanza scura',
    '🕵🏿‍♂' => 'investigatore: carnagione scura',
    '🕵🏻‍♀' => 'investigatrice: carnagione chiara',
    '🕵🏼‍♀' => 'investigatrice: carnagione abbastanza chiara',
    '🕵🏽‍♀' => 'investigatrice: carnagione olivastra',
    '🕵🏾‍♀' => 'investigatrice: carnagione abbastanza scura',
    '🕵🏿‍♀' => 'investigatrice: carnagione scura',
    '💂🏻‍♂' => 'guardia uomo: carnagione chiara',
    '💂🏼‍♂' => 'guardia uomo: carnagione abbastanza chiara',
    '💂🏽‍♂' => 'guardia uomo: carnagione olivastra',
    '💂🏾‍♂' => 'guardia uomo: carnagione abbastanza scura',
    '💂🏿‍♂' => 'guardia uomo: carnagione scura',
    '💂🏻‍♀' => 'guardia donna: carnagione chiara',
    '💂🏼‍♀' => 'guardia donna: carnagione abbastanza chiara',
    '💂🏽‍♀' => 'guardia donna: carnagione olivastra',
    '💂🏾‍♀' => 'guardia donna: carnagione abbastanza scura',
    '💂🏿‍♀' => 'guardia donna: carnagione scura',
    '👷🏻‍♂' => 'operaio edile uomo: carnagione chiara',
    '👷🏼‍♂' => 'operaio edile uomo: carnagione abbastanza chiara',
    '👷🏽‍♂' => 'operaio edile uomo: carnagione olivastra',
    '👷🏾‍♂' => 'operaio edile uomo: carnagione abbastanza scura',
    '👷🏿‍♂' => 'operaio edile uomo: carnagione scura',
    '👷🏻‍♀' => 'operaia edile: carnagione chiara',
    '👷🏼‍♀' => 'operaia edile: carnagione abbastanza chiara',
    '👷🏽‍♀' => 'operaia edile: carnagione olivastra',
    '👷🏾‍♀' => 'operaia edile: carnagione abbastanza scura',
    '👷🏿‍♀' => 'operaia edile: carnagione scura',
    '👳🏻‍♂' => 'uomo con turbante: carnagione chiara',
    '👳🏼‍♂' => 'uomo con turbante: carnagione abbastanza chiara',
    '👳🏽‍♂' => 'uomo con turbante: carnagione olivastra',
    '👳🏾‍♂' => 'uomo con turbante: carnagione abbastanza scura',
    '👳🏿‍♂' => 'uomo con turbante: carnagione scura',
    '👳🏻‍♀' => 'donna con turbante: carnagione chiara',
    '👳🏼‍♀' => 'donna con turbante: carnagione abbastanza chiara',
    '👳🏽‍♀' => 'donna con turbante: carnagione olivastra',
    '👳🏾‍♀' => 'donna con turbante: carnagione abbastanza scura',
    '👳🏿‍♀' => 'donna con turbante: carnagione scura',
    '🤵🏻‍♂' => 'uomo in smoking: carnagione chiara',
    '🤵🏼‍♂' => 'uomo in smoking: carnagione abbastanza chiara',
    '🤵🏽‍♂' => 'uomo in smoking: carnagione olivastra',
    '🤵🏾‍♂' => 'uomo in smoking: carnagione abbastanza scura',
    '🤵🏿‍♂' => 'uomo in smoking: carnagione scura',
    '🤵🏻‍♀' => 'donna in smoking: carnagione chiara',
    '🤵🏼‍♀' => 'donna in smoking: carnagione abbastanza chiara',
    '🤵🏽‍♀' => 'donna in smoking: carnagione olivastra',
    '🤵🏾‍♀' => 'donna in smoking: carnagione abbastanza scura',
    '🤵🏿‍♀' => 'donna in smoking: carnagione scura',
    '👰🏻‍♂' => 'sposo con velo: carnagione chiara',
    '👰🏼‍♂' => 'sposo con velo: carnagione abbastanza chiara',
    '👰🏽‍♂' => 'sposo con velo: carnagione olivastra',
    '👰🏾‍♂' => 'sposo con velo: carnagione abbastanza scura',
    '👰🏿‍♂' => 'sposo con velo: carnagione scura',
    '👰🏻‍♀' => 'sposa con velo: carnagione chiara',
    '👰🏼‍♀' => 'sposa con velo: carnagione abbastanza chiara',
    '👰🏽‍♀' => 'sposa con velo: carnagione olivastra',
    '👰🏾‍♀' => 'sposa con velo: carnagione abbastanza scura',
    '👰🏿‍♀' => 'sposa con velo: carnagione scura',
    '👩🏻‍🍼' => 'donna che allatta: carnagione chiara',
    '👩🏼‍🍼' => 'donna che allatta: carnagione abbastanza chiara',
    '👩🏽‍🍼' => 'donna che allatta: carnagione olivastra',
    '👩🏾‍🍼' => 'donna che allatta: carnagione abbastanza scura',
    '👩🏿‍🍼' => 'donna che allatta: carnagione scura',
    '👨🏻‍🍼' => 'uomo che allatta: carnagione chiara',
    '👨🏼‍🍼' => 'uomo che allatta: carnagione abbastanza chiara',
    '👨🏽‍🍼' => 'uomo che allatta: carnagione olivastra',
    '👨🏾‍🍼' => 'uomo che allatta: carnagione abbastanza scura',
    '👨🏿‍🍼' => 'uomo che allatta: carnagione scura',
    '🧑🏻‍🍼' => 'persona che allatta: carnagione chiara',
    '🧑🏼‍🍼' => 'persona che allatta: carnagione abbastanza chiara',
    '🧑🏽‍🍼' => 'persona che allatta: carnagione olivastra',
    '🧑🏾‍🍼' => 'persona che allatta: carnagione abbastanza scura',
    '🧑🏿‍🍼' => 'persona che allatta: carnagione scura',
    '🧑🏻‍🎄' => 'Santa Claus: carnagione chiara',
    '🧑🏼‍🎄' => 'Santa Claus: carnagione abbastanza chiara',
    '🧑🏽‍🎄' => 'Santa Claus: carnagione olivastra',
    '🧑🏾‍🎄' => 'Santa Claus: carnagione abbastanza scura',
    '🧑🏿‍🎄' => 'Santa Claus: carnagione scura',
    '🦸🏻‍♂' => 'supereroe uomo: carnagione chiara',
    '🦸🏼‍♂' => 'supereroe uomo: carnagione abbastanza chiara',
    '🦸🏽‍♂' => 'supereroe uomo: carnagione olivastra',
    '🦸🏾‍♂' => 'supereroe uomo: carnagione abbastanza scura',
    '🦸🏿‍♂' => 'supereroe uomo: carnagione scura',
    '🦸🏻‍♀' => 'supereroina: carnagione chiara',
    '🦸🏼‍♀' => 'supereroina: carnagione abbastanza chiara',
    '🦸🏽‍♀' => 'supereroina: carnagione olivastra',
    '🦸🏾‍♀' => 'supereroina: carnagione abbastanza scura',
    '🦸🏿‍♀' => 'supereroina: carnagione scura',
    '🦹🏻‍♂' => 'supercattivo uomo: carnagione chiara',
    '🦹🏼‍♂' => 'supercattivo uomo: carnagione abbastanza chiara',
    '🦹🏽‍♂' => 'supercattivo uomo: carnagione olivastra',
    '🦹🏾‍♂' => 'supercattivo uomo: carnagione abbastanza scura',
    '🦹🏿‍♂' => 'supercattivo uomo: carnagione scura',
    '🦹🏻‍♀' => 'supercattiva: carnagione chiara',
    '🦹🏼‍♀' => 'supercattiva: carnagione abbastanza chiara',
    '🦹🏽‍♀' => 'supercattiva: carnagione olivastra',
    '🦹🏾‍♀' => 'supercattiva: carnagione abbastanza scura',
    '🦹🏿‍♀' => 'supercattiva: carnagione scura',
    '🧙🏻‍♂' => 'mago uomo: carnagione chiara',
    '🧙🏼‍♂' => 'mago uomo: carnagione abbastanza chiara',
    '🧙🏽‍♂' => 'mago uomo: carnagione olivastra',
    '🧙🏾‍♂' => 'mago uomo: carnagione abbastanza scura',
    '🧙🏿‍♂' => 'mago uomo: carnagione scura',
    '🧙🏻‍♀' => 'maga: carnagione chiara',
    '🧙🏼‍♀' => 'maga: carnagione abbastanza chiara',
    '🧙🏽‍♀' => 'maga: carnagione olivastra',
    '🧙🏾‍♀' => 'maga: carnagione abbastanza scura',
    '🧙🏿‍♀' => 'maga: carnagione scura',
    '🧚🏻‍♂' => 'folletto alato: carnagione chiara',
    '🧚🏼‍♂' => 'folletto alato: carnagione abbastanza chiara',
    '🧚🏽‍♂' => 'folletto alato: carnagione olivastra',
    '🧚🏾‍♂' => 'folletto alato: carnagione abbastanza scura',
    '🧚🏿‍♂' => 'folletto alato: carnagione scura',
    '🧚🏻‍♀' => 'fata donna: carnagione chiara',
    '🧚🏼‍♀' => 'fata donna: carnagione abbastanza chiara',
    '🧚🏽‍♀' => 'fata donna: carnagione olivastra',
    '🧚🏾‍♀' => 'fata donna: carnagione abbastanza scura',
    '🧚🏿‍♀' => 'fata donna: carnagione scura',
    '🧛🏻‍♂' => 'vampiro uomo: carnagione chiara',
    '🧛🏼‍♂' => 'vampiro uomo: carnagione abbastanza chiara',
    '🧛🏽‍♂' => 'vampiro uomo: carnagione olivastra',
    '🧛🏾‍♂' => 'vampiro uomo: carnagione abbastanza scura',
    '🧛🏿‍♂' => 'vampiro uomo: carnagione scura',
    '🧛🏻‍♀' => 'vampira: carnagione chiara',
    '🧛🏼‍♀' => 'vampira: carnagione abbastanza chiara',
    '🧛🏽‍♀' => 'vampira: carnagione olivastra',
    '🧛🏾‍♀' => 'vampira: carnagione abbastanza scura',
    '🧛🏿‍♀' => 'vampira: carnagione scura',
    '🧜🏻‍♂' => 'tritone: carnagione chiara',
    '🧜🏼‍♂' => 'tritone: carnagione abbastanza chiara',
    '🧜🏽‍♂' => 'tritone: carnagione olivastra',
    '🧜🏾‍♂' => 'tritone: carnagione abbastanza scura',
    '🧜🏿‍♂' => 'tritone: carnagione scura',
    '🧜🏻‍♀' => 'sirena donna: carnagione chiara',
    '🧜🏼‍♀' => 'sirena donna: carnagione abbastanza chiara',
    '🧜🏽‍♀' => 'sirena donna: carnagione olivastra',
    '🧜🏾‍♀' => 'sirena donna: carnagione abbastanza scura',
    '🧜🏿‍♀' => 'sirena donna: carnagione scura',
    '🧝🏻‍♂' => 'elfo uomo: carnagione chiara',
    '🧝🏼‍♂' => 'elfo uomo: carnagione abbastanza chiara',
    '🧝🏽‍♂' => 'elfo uomo: carnagione olivastra',
    '🧝🏾‍♂' => 'elfo uomo: carnagione abbastanza scura',
    '🧝🏿‍♂' => 'elfo uomo: carnagione scura',
    '🧝🏻‍♀' => 'elfo donna: carnagione chiara',
    '🧝🏼‍♀' => 'elfo donna: carnagione abbastanza chiara',
    '🧝🏽‍♀' => 'elfo donna: carnagione olivastra',
    '🧝🏾‍♀' => 'elfo donna: carnagione abbastanza scura',
    '🧝🏿‍♀' => 'elfo donna: carnagione scura',
    '💆🏻‍♂' => 'uomo che riceve un massaggio: carnagione chiara',
    '💆🏼‍♂' => 'uomo che riceve un massaggio: carnagione abbastanza chiara',
    '💆🏽‍♂' => 'uomo che riceve un massaggio: carnagione olivastra',
    '💆🏾‍♂' => 'uomo che riceve un massaggio: carnagione abbastanza scura',
    '💆🏿‍♂' => 'uomo che riceve un massaggio: carnagione scura',
    '💆🏻‍♀' => 'donna che riceve un massaggio: carnagione chiara',
    '💆🏼‍♀' => 'donna che riceve un massaggio: carnagione abbastanza chiara',
    '💆🏽‍♀' => 'donna che riceve un massaggio: carnagione olivastra',
    '💆🏾‍♀' => 'donna che riceve un massaggio: carnagione abbastanza scura',
    '💆🏿‍♀' => 'donna che riceve un massaggio: carnagione scura',
    '💇🏻‍♂' => 'taglio di capelli per uomo: carnagione chiara',
    '💇🏼‍♂' => 'taglio di capelli per uomo: carnagione abbastanza chiara',
    '💇🏽‍♂' => 'taglio di capelli per uomo: carnagione olivastra',
    '💇🏾‍♂' => 'taglio di capelli per uomo: carnagione abbastanza scura',
    '💇🏿‍♂' => 'taglio di capelli per uomo: carnagione scura',
    '💇🏻‍♀' => 'taglio di capelli per donna: carnagione chiara',
    '💇🏼‍♀' => 'taglio di capelli per donna: carnagione abbastanza chiara',
    '💇🏽‍♀' => 'taglio di capelli per donna: carnagione olivastra',
    '💇🏾‍♀' => 'taglio di capelli per donna: carnagione abbastanza scura',
    '💇🏿‍♀' => 'taglio di capelli per donna: carnagione scura',
    '🚶🏻‍♂' => 'uomo che cammina: carnagione chiara',
    '🚶🏼‍♂' => 'uomo che cammina: carnagione abbastanza chiara',
    '🚶🏽‍♂' => 'uomo che cammina: carnagione olivastra',
    '🚶🏾‍♂' => 'uomo che cammina: carnagione abbastanza scura',
    '🚶🏿‍♂' => 'uomo che cammina: carnagione scura',
    '🚶🏻‍♀' => 'donna che cammina: carnagione chiara',
    '🚶🏼‍♀' => 'donna che cammina: carnagione abbastanza chiara',
    '🚶🏽‍♀' => 'donna che cammina: carnagione olivastra',
    '🚶🏾‍♀' => 'donna che cammina: carnagione abbastanza scura',
    '🚶🏿‍♀' => 'donna che cammina: carnagione scura',
    '🚶🏻‍➡' => 'pedone: carnagione chiara e a destra',
    '🚶🏼‍➡' => 'pedone: carnagione abbastanza chiara e a destra',
    '🚶🏽‍➡' => 'pedone: carnagione olivastra e a destra',
    '🚶🏾‍➡' => 'pedone: carnagione abbastanza scura e a destra',
    '🚶🏿‍➡' => 'pedone: carnagione scura e a destra',
    '🧍🏻‍♂' => 'uomo in piedi: carnagione chiara',
    '🧍🏼‍♂' => 'uomo in piedi: carnagione abbastanza chiara',
    '🧍🏽‍♂' => 'uomo in piedi: carnagione olivastra',
    '🧍🏾‍♂' => 'uomo in piedi: carnagione abbastanza scura',
    '🧍🏿‍♂' => 'uomo in piedi: carnagione scura',
    '🧍🏻‍♀' => 'donna in piedi: carnagione chiara',
    '🧍🏼‍♀' => 'donna in piedi: carnagione abbastanza chiara',
    '🧍🏽‍♀' => 'donna in piedi: carnagione olivastra',
    '🧍🏾‍♀' => 'donna in piedi: carnagione abbastanza scura',
    '🧍🏿‍♀' => 'donna in piedi: carnagione scura',
    '🧎🏻‍♂' => 'uomo inginocchiato: carnagione chiara',
    '🧎🏼‍♂' => 'uomo inginocchiato: carnagione abbastanza chiara',
    '🧎🏽‍♂' => 'uomo inginocchiato: carnagione olivastra',
    '🧎🏾‍♂' => 'uomo inginocchiato: carnagione abbastanza scura',
    '🧎🏿‍♂' => 'uomo inginocchiato: carnagione scura',
    '🧎🏻‍♀' => 'donna inginocchiata: carnagione chiara',
    '🧎🏼‍♀' => 'donna inginocchiata: carnagione abbastanza chiara',
    '🧎🏽‍♀' => 'donna inginocchiata: carnagione olivastra',
    '🧎🏾‍♀' => 'donna inginocchiata: carnagione abbastanza scura',
    '🧎🏿‍♀' => 'donna inginocchiata: carnagione scura',
    '🧎🏻‍➡' => 'persona inginocchiata: carnagione chiara e a destra',
    '🧎🏼‍➡' => 'persona inginocchiata: carnagione abbastanza chiara e a destra',
    '🧎🏽‍➡' => 'persona inginocchiata: carnagione olivastra e a destra',
    '🧎🏾‍➡' => 'persona inginocchiata: carnagione abbastanza scura e a destra',
    '🧎🏿‍➡' => 'persona inginocchiata: carnagione scura e a destra',
    '🧑🏻‍🦯' => 'persona con bastone di orientamento: carnagione chiara',
    '🧑🏼‍🦯' => 'persona con bastone di orientamento: carnagione abbastanza chiara',
    '🧑🏽‍🦯' => 'persona con bastone di orientamento: carnagione olivastra',
    '🧑🏾‍🦯' => 'persona con bastone di orientamento: carnagione abbastanza scura',
    '🧑🏿‍🦯' => 'persona con bastone di orientamento: carnagione scura',
    '👨🏻‍🦯' => 'uomo con bastone bianco di orientamento: carnagione chiara',
    '👨🏼‍🦯' => 'uomo con bastone bianco di orientamento: carnagione abbastanza chiara',
    '👨🏽‍🦯' => 'uomo con bastone bianco di orientamento: carnagione olivastra',
    '👨🏾‍🦯' => 'uomo con bastone bianco di orientamento: carnagione abbastanza scura',
    '👨🏿‍🦯' => 'uomo con bastone bianco di orientamento: carnagione scura',
    '👩🏻‍🦯' => 'donna con bastone bianco di orientamento: carnagione chiara',
    '👩🏼‍🦯' => 'donna con bastone bianco di orientamento: carnagione abbastanza chiara',
    '👩🏽‍🦯' => 'donna con bastone bianco di orientamento: carnagione olivastra',
    '👩🏾‍🦯' => 'donna con bastone bianco di orientamento: carnagione abbastanza scura',
    '👩🏿‍🦯' => 'donna con bastone bianco di orientamento: carnagione scura',
    '🧑🏻‍🦼' => 'persona su sedia a rotelle motorizzata: carnagione chiara',
    '🧑🏼‍🦼' => 'persona su sedia a rotelle motorizzata: carnagione abbastanza chiara',
    '🧑🏽‍🦼' => 'persona su sedia a rotelle motorizzata: carnagione olivastra',
    '🧑🏾‍🦼' => 'persona su sedia a rotelle motorizzata: carnagione abbastanza scura',
    '🧑🏿‍🦼' => 'persona su sedia a rotelle motorizzata: carnagione scura',
    '👨🏻‍🦼' => 'uomo su sedia a rotelle motorizzata: carnagione chiara',
    '👨🏼‍🦼' => 'uomo su sedia a rotelle motorizzata: carnagione abbastanza chiara',
    '👨🏽‍🦼' => 'uomo su sedia a rotelle motorizzata: carnagione olivastra',
    '👨🏾‍🦼' => 'uomo su sedia a rotelle motorizzata: carnagione abbastanza scura',
    '👨🏿‍🦼' => 'uomo su sedia a rotelle motorizzata: carnagione scura',
    '👩🏻‍🦼' => 'donna su sedia a rotelle motorizzata: carnagione chiara',
    '👩🏼‍🦼' => 'donna su sedia a rotelle motorizzata: carnagione abbastanza chiara',
    '👩🏽‍🦼' => 'donna su sedia a rotelle motorizzata: carnagione olivastra',
    '👩🏾‍🦼' => 'donna su sedia a rotelle motorizzata: carnagione abbastanza scura',
    '👩🏿‍🦼' => 'donna su sedia a rotelle motorizzata: carnagione scura',
    '🧑🏻‍🦽' => 'persona su sedia a rotelle manuale: carnagione chiara',
    '🧑🏼‍🦽' => 'persona su sedia a rotelle manuale: carnagione abbastanza chiara',
    '🧑🏽‍🦽' => 'persona su sedia a rotelle manuale: carnagione olivastra',
    '🧑🏾‍🦽' => 'persona su sedia a rotelle manuale: carnagione abbastanza scura',
    '🧑🏿‍🦽' => 'persona su sedia a rotelle manuale: carnagione scura',
    '👨🏻‍🦽' => 'uomo su sedia a rotelle manuale: carnagione chiara',
    '👨🏼‍🦽' => 'uomo su sedia a rotelle manuale: carnagione abbastanza chiara',
    '👨🏽‍🦽' => 'uomo su sedia a rotelle manuale: carnagione olivastra',
    '👨🏾‍🦽' => 'uomo su sedia a rotelle manuale: carnagione abbastanza scura',
    '👨🏿‍🦽' => 'uomo su sedia a rotelle manuale: carnagione scura',
    '👩🏻‍🦽' => 'donna su sedia a rotelle manuale: carnagione chiara',
    '👩🏼‍🦽' => 'donna su sedia a rotelle manuale: carnagione abbastanza chiara',
    '👩🏽‍🦽' => 'donna su sedia a rotelle manuale: carnagione olivastra',
    '👩🏾‍🦽' => 'donna su sedia a rotelle manuale: carnagione abbastanza scura',
    '👩🏿‍🦽' => 'donna su sedia a rotelle manuale: carnagione scura',
    '🏃🏻‍♂' => 'uomo che corre: carnagione chiara',
    '🏃🏼‍♂' => 'uomo che corre: carnagione abbastanza chiara',
    '🏃🏽‍♂' => 'uomo che corre: carnagione olivastra',
    '🏃🏾‍♂' => 'uomo che corre: carnagione abbastanza scura',
    '🏃🏿‍♂' => 'uomo che corre: carnagione scura',
    '🏃🏻‍♀' => 'donna che corre: carnagione chiara',
    '🏃🏼‍♀' => 'donna che corre: carnagione abbastanza chiara',
    '🏃🏽‍♀' => 'donna che corre: carnagione olivastra',
    '🏃🏾‍♀' => 'donna che corre: carnagione abbastanza scura',
    '🏃🏿‍♀' => 'donna che corre: carnagione scura',
    '🏃🏻‍➡' => 'persona che corre: carnagione chiara e a destra',
    '🏃🏼‍➡' => 'persona che corre: carnagione abbastanza chiara e a destra',
    '🏃🏽‍➡' => 'persona che corre: carnagione olivastra e a destra',
    '🏃🏾‍➡' => 'persona che corre: carnagione abbastanza scura e a destra',
    '🏃🏿‍➡' => 'persona che corre: carnagione scura e a destra',
    '👯🏻‍♀' => 'donne con orecchie da coniglio: carnagione chiara',
    '👯🏼‍♀' => 'donne con orecchie da coniglio: carnagione abbastanza chiara',
    '👯🏽‍♀' => 'donne con orecchie da coniglio: carnagione olivastra',
    '👯🏾‍♀' => 'donne con orecchie da coniglio: carnagione abbastanza scura',
    '👯🏿‍♀' => 'donne con orecchie da coniglio: carnagione scura',
    '👯🏻‍♂' => 'uomini con orecchie da coniglio: carnagione chiara',
    '👯🏼‍♂' => 'uomini con orecchie da coniglio: carnagione abbastanza chiara',
    '👯🏽‍♂' => 'uomini con orecchie da coniglio: carnagione olivastra',
    '👯🏾‍♂' => 'uomini con orecchie da coniglio: carnagione abbastanza scura',
    '👯🏿‍♂' => 'uomini con orecchie da coniglio: carnagione scura',
    '🧖🏻‍♂' => 'uomo in sauna: carnagione chiara',
    '🧖🏼‍♂' => 'uomo in sauna: carnagione abbastanza chiara',
    '🧖🏽‍♂' => 'uomo in sauna: carnagione olivastra',
    '🧖🏾‍♂' => 'uomo in sauna: carnagione abbastanza scura',
    '🧖🏿‍♂' => 'uomo in sauna: carnagione scura',
    '🧖🏻‍♀' => 'donna in sauna: carnagione chiara',
    '🧖🏼‍♀' => 'donna in sauna: carnagione abbastanza chiara',
    '🧖🏽‍♀' => 'donna in sauna: carnagione olivastra',
    '🧖🏾‍♀' => 'donna in sauna: carnagione abbastanza scura',
    '🧖🏿‍♀' => 'donna in sauna: carnagione scura',
    '🧗🏻‍♂' => 'scalatore: carnagione chiara',
    '🧗🏼‍♂' => 'scalatore: carnagione abbastanza chiara',
    '🧗🏽‍♂' => 'scalatore: carnagione olivastra',
    '🧗🏾‍♂' => 'scalatore: carnagione abbastanza scura',
    '🧗🏿‍♂' => 'scalatore: carnagione scura',
    '🧗🏻‍♀' => 'scalatrice: carnagione chiara',
    '🧗🏼‍♀' => 'scalatrice: carnagione abbastanza chiara',
    '🧗🏽‍♀' => 'scalatrice: carnagione olivastra',
    '🧗🏾‍♀' => 'scalatrice: carnagione abbastanza scura',
    '🧗🏿‍♀' => 'scalatrice: carnagione scura',
    '🏌🏻‍♂' => 'golfista uomo: carnagione chiara',
    '🏌🏼‍♂' => 'golfista uomo: carnagione abbastanza chiara',
    '🏌🏽‍♂' => 'golfista uomo: carnagione olivastra',
    '🏌🏾‍♂' => 'golfista uomo: carnagione abbastanza scura',
    '🏌🏿‍♂' => 'golfista uomo: carnagione scura',
    '🏌🏻‍♀' => 'golfista donna: carnagione chiara',
    '🏌🏼‍♀' => 'golfista donna: carnagione abbastanza chiara',
    '🏌🏽‍♀' => 'golfista donna: carnagione olivastra',
    '🏌🏾‍♀' => 'golfista donna: carnagione abbastanza scura',
    '🏌🏿‍♀' => 'golfista donna: carnagione scura',
    '🏄🏻‍♂' => 'surfista uomo: carnagione chiara',
    '🏄🏼‍♂' => 'surfista uomo: carnagione abbastanza chiara',
    '🏄🏽‍♂' => 'surfista uomo: carnagione olivastra',
    '🏄🏾‍♂' => 'surfista uomo: carnagione abbastanza scura',
    '🏄🏿‍♂' => 'surfista uomo: carnagione scura',
    '🏄🏻‍♀' => 'surfista donna: carnagione chiara',
    '🏄🏼‍♀' => 'surfista donna: carnagione abbastanza chiara',
    '🏄🏽‍♀' => 'surfista donna: carnagione olivastra',
    '🏄🏾‍♀' => 'surfista donna: carnagione abbastanza scura',
    '🏄🏿‍♀' => 'surfista donna: carnagione scura',
    '🚣🏻‍♂' => 'uomo in barca a remi: carnagione chiara',
    '🚣🏼‍♂' => 'uomo in barca a remi: carnagione abbastanza chiara',
    '🚣🏽‍♂' => 'uomo in barca a remi: carnagione olivastra',
    '🚣🏾‍♂' => 'uomo in barca a remi: carnagione abbastanza scura',
    '🚣🏿‍♂' => 'uomo in barca a remi: carnagione scura',
    '🚣🏻‍♀' => 'donna in barca a remi: carnagione chiara',
    '🚣🏼‍♀' => 'donna in barca a remi: carnagione abbastanza chiara',
    '🚣🏽‍♀' => 'donna in barca a remi: carnagione olivastra',
    '🚣🏾‍♀' => 'donna in barca a remi: carnagione abbastanza scura',
    '🚣🏿‍♀' => 'donna in barca a remi: carnagione scura',
    '🏊🏻‍♂' => 'nuotatore: carnagione chiara',
    '🏊🏼‍♂' => 'nuotatore: carnagione abbastanza chiara',
    '🏊🏽‍♂' => 'nuotatore: carnagione olivastra',
    '🏊🏾‍♂' => 'nuotatore: carnagione abbastanza scura',
    '🏊🏿‍♂' => 'nuotatore: carnagione scura',
    '🏊🏻‍♀' => 'nuotatrice: carnagione chiara',
    '🏊🏼‍♀' => 'nuotatrice: carnagione abbastanza chiara',
    '🏊🏽‍♀' => 'nuotatrice: carnagione olivastra',
    '🏊🏾‍♀' => 'nuotatrice: carnagione abbastanza scura',
    '🏊🏿‍♀' => 'nuotatrice: carnagione scura',
    '⛹🏻‍♂' => 'uomo che fa rimbalzare una palla: carnagione chiara',
    '⛹🏼‍♂' => 'uomo che fa rimbalzare una palla: carnagione abbastanza chiara',
    '⛹🏽‍♂' => 'uomo che fa rimbalzare una palla: carnagione olivastra',
    '⛹🏾‍♂' => 'uomo che fa rimbalzare una palla: carnagione abbastanza scura',
    '⛹🏿‍♂' => 'uomo che fa rimbalzare una palla: carnagione scura',
    '⛹🏻‍♀' => 'donna che fa rimbalzare una palla: carnagione chiara',
    '⛹🏼‍♀' => 'donna che fa rimbalzare una palla: carnagione abbastanza chiara',
    '⛹🏽‍♀' => 'donna che fa rimbalzare una palla: carnagione olivastra',
    '⛹🏾‍♀' => 'donna che fa rimbalzare una palla: carnagione abbastanza scura',
    '⛹🏿‍♀' => 'donna che fa rimbalzare una palla: carnagione scura',
    '🏋🏻‍♂' => 'uomo che solleva pesi: carnagione chiara',
    '🏋🏼‍♂' => 'uomo che solleva pesi: carnagione abbastanza chiara',
    '🏋🏽‍♂' => 'uomo che solleva pesi: carnagione olivastra',
    '🏋🏾‍♂' => 'uomo che solleva pesi: carnagione abbastanza scura',
    '🏋🏿‍♂' => 'uomo che solleva pesi: carnagione scura',
    '🏋🏻‍♀' => 'donna che solleva pesi: carnagione chiara',
    '🏋🏼‍♀' => 'donna che solleva pesi: carnagione abbastanza chiara',
    '🏋🏽‍♀' => 'donna che solleva pesi: carnagione olivastra',
    '🏋🏾‍♀' => 'donna che solleva pesi: carnagione abbastanza scura',
    '🏋🏿‍♀' => 'donna che solleva pesi: carnagione scura',
    '🚴🏻‍♂' => 'ciclista uomo: carnagione chiara',
    '🚴🏼‍♂' => 'ciclista uomo: carnagione abbastanza chiara',
    '🚴🏽‍♂' => 'ciclista uomo: carnagione olivastra',
    '🚴🏾‍♂' => 'ciclista uomo: carnagione abbastanza scura',
    '🚴🏿‍♂' => 'ciclista uomo: carnagione scura',
    '🚴🏻‍♀' => 'ciclista donna: carnagione chiara',
    '🚴🏼‍♀' => 'ciclista donna: carnagione abbastanza chiara',
    '🚴🏽‍♀' => 'ciclista donna: carnagione olivastra',
    '🚴🏾‍♀' => 'ciclista donna: carnagione abbastanza scura',
    '🚴🏿‍♀' => 'ciclista donna: carnagione scura',
    '🚵🏻‍♂' => 'ciclista uomo di mountain bike: carnagione chiara',
    '🚵🏼‍♂' => 'ciclista uomo di mountain bike: carnagione abbastanza chiara',
    '🚵🏽‍♂' => 'ciclista uomo di mountain bike: carnagione olivastra',
    '🚵🏾‍♂' => 'ciclista uomo di mountain bike: carnagione abbastanza scura',
    '🚵🏿‍♂' => 'ciclista uomo di mountain bike: carnagione scura',
    '🚵🏻‍♀' => 'ciclista donna di mountain bike: carnagione chiara',
    '🚵🏼‍♀' => 'ciclista donna di mountain bike: carnagione abbastanza chiara',
    '🚵🏽‍♀' => 'ciclista donna di mountain bike: carnagione olivastra',
    '🚵🏾‍♀' => 'ciclista donna di mountain bike: carnagione abbastanza scura',
    '🚵🏿‍♀' => 'ciclista donna di mountain bike: carnagione scura',
    '🤸🏻‍♂' => 'uomo che fa la ruota: carnagione chiara',
    '🤸🏼‍♂' => 'uomo che fa la ruota: carnagione abbastanza chiara',
    '🤸🏽‍♂' => 'uomo che fa la ruota: carnagione olivastra',
    '🤸🏾‍♂' => 'uomo che fa la ruota: carnagione abbastanza scura',
    '🤸🏿‍♂' => 'uomo che fa la ruota: carnagione scura',
    '🤸🏻‍♀' => 'donna che fa la ruota: carnagione chiara',
    '🤸🏼‍♀' => 'donna che fa la ruota: carnagione abbastanza chiara',
    '🤸🏽‍♀' => 'donna che fa la ruota: carnagione olivastra',
    '🤸🏾‍♀' => 'donna che fa la ruota: carnagione abbastanza scura',
    '🤸🏿‍♀' => 'donna che fa la ruota: carnagione scura',
    '🤼🏻‍♀' => 'lottatrici: carnagione chiara',
    '🤼🏼‍♀' => 'lottatrici: carnagione abbastanza chiara',
    '🤼🏽‍♀' => 'lottatrici: carnagione olivastra',
    '🤼🏾‍♀' => 'lottatrici: carnagione abbastanza scura',
    '🤼🏿‍♀' => 'lottatrici: carnagione scura',
    '🤼🏻‍♂' => 'lottatori: carnagione chiara',
    '🤼🏼‍♂' => 'lottatori: carnagione abbastanza chiara',
    '🤼🏽‍♂' => 'lottatori: carnagione olivastra',
    '🤼🏾‍♂' => 'lottatori: carnagione abbastanza scura',
    '🤼🏿‍♂' => 'lottatori: carnagione scura',
    '🤽🏻‍♂' => 'pallanuotista uomo: carnagione chiara',
    '🤽🏼‍♂' => 'pallanuotista uomo: carnagione abbastanza chiara',
    '🤽🏽‍♂' => 'pallanuotista uomo: carnagione olivastra',
    '🤽🏾‍♂' => 'pallanuotista uomo: carnagione abbastanza scura',
    '🤽🏿‍♂' => 'pallanuotista uomo: carnagione scura',
    '🤽🏻‍♀' => 'pallanuotista donna: carnagione chiara',
    '🤽🏼‍♀' => 'pallanuotista donna: carnagione abbastanza chiara',
    '🤽🏽‍♀' => 'pallanuotista donna: carnagione olivastra',
    '🤽🏾‍♀' => 'pallanuotista donna: carnagione abbastanza scura',
    '🤽🏿‍♀' => 'pallanuotista donna: carnagione scura',
    '🤾🏻‍♂' => 'pallamanista uomo: carnagione chiara',
    '🤾🏼‍♂' => 'pallamanista uomo: carnagione abbastanza chiara',
    '🤾🏽‍♂' => 'pallamanista uomo: carnagione olivastra',
    '🤾🏾‍♂' => 'pallamanista uomo: carnagione abbastanza scura',
    '🤾🏿‍♂' => 'pallamanista uomo: carnagione scura',
    '🤾🏻‍♀' => 'pallamanista donna: carnagione chiara',
    '🤾🏼‍♀' => 'pallamanista donna: carnagione abbastanza chiara',
    '🤾🏽‍♀' => 'pallamanista donna: carnagione olivastra',
    '🤾🏾‍♀' => 'pallamanista donna: carnagione abbastanza scura',
    '🤾🏿‍♀' => 'pallamanista donna: carnagione scura',
    '🤹🏻‍♂' => 'giocoliere uomo: carnagione chiara',
    '🤹🏼‍♂' => 'giocoliere uomo: carnagione abbastanza chiara',
    '🤹🏽‍♂' => 'giocoliere uomo: carnagione olivastra',
    '🤹🏾‍♂' => 'giocoliere uomo: carnagione abbastanza scura',
    '🤹🏿‍♂' => 'giocoliere uomo: carnagione scura',
    '🤹🏻‍♀' => 'giocoliere donna: carnagione chiara',
    '🤹🏼‍♀' => 'giocoliere donna: carnagione abbastanza chiara',
    '🤹🏽‍♀' => 'giocoliere donna: carnagione olivastra',
    '🤹🏾‍♀' => 'giocoliere donna: carnagione abbastanza scura',
    '🤹🏿‍♀' => 'giocoliere donna: carnagione scura',
    '🧘🏻‍♂' => 'uomo in posizione del loto: carnagione chiara',
    '🧘🏼‍♂' => 'uomo in posizione del loto: carnagione abbastanza chiara',
    '🧘🏽‍♂' => 'uomo in posizione del loto: carnagione olivastra',
    '🧘🏾‍♂' => 'uomo in posizione del loto: carnagione abbastanza scura',
    '🧘🏿‍♂' => 'uomo in posizione del loto: carnagione scura',
    '🧘🏻‍♀' => 'donna in posizione del loto: carnagione chiara',
    '🧘🏼‍♀' => 'donna in posizione del loto: carnagione abbastanza chiara',
    '🧘🏽‍♀' => 'donna in posizione del loto: carnagione olivastra',
    '🧘🏾‍♀' => 'donna in posizione del loto: carnagione abbastanza scura',
    '🧘🏿‍♀' => 'donna in posizione del loto: carnagione scura',
    '🧑‍🦰' => 'persona: capelli rossi',
    '🧑‍🦱' => 'persona: capelli ricci',
    '🧑‍🦳' => 'persona: capelli bianchi',
    '🧑‍🦲' => 'persona: calvo',
    '👨‍🦰' => 'uomo: capelli rossi',
    '👨‍🦱' => 'uomo: capelli ricci',
    '👨‍🦳' => 'uomo: capelli bianchi',
    '👨‍🦲' => 'uomo: calvo',
    '👩‍🦰' => 'donna: capelli rossi',
    '👩‍🦱' => 'donna: capelli ricci',
    '👩‍🦳' => 'donna: capelli bianchi',
    '👩‍🦲' => 'donna: calvo',
    '🚶‍➡' => 'pedone: a destra',
    '🧎‍➡' => 'persona inginocchiata: a destra',
    '🏃‍➡' => 'persona che corre: a destra',
    '👨‍👦' => 'famiglia: uomo e bambino',
    '👨‍👧' => 'famiglia: uomo e bambina',
    '👩‍👦' => 'famiglia: donna e bambino',
    '👩‍👧' => 'famiglia: donna e bambina',
    '😶‍🌫' => 'testa tra le nuvole',
    '😮‍💨' => 'faccina che espira',
    '🙂‍↕' => 'scuotere la testa in senso verticale',
    '😵‍💫' => 'faccina con occhi a spirale',
    '❤‍🔥' => 'cuore in fiamme',
    '❤‍🩹' => 'cuore guarito',
    '👁‍🗨' => 'occhio nel fumetto',
    '🧔‍♂' => 'uomo con la barba',
    '👱‍♂' => 'uomo biondo',
    '🧔‍♀' => 'donna con la barba',
    '👱‍♀' => 'donna bionda',
    '🙍‍♂' => 'uomo corrucciato',
    '🙍‍♀' => 'donna corrucciata',
    '🙎‍♂' => 'uomo imbronciato',
    '🙎‍♀' => 'donna imbronciata',
    '🙅‍♂' => 'uomo con gesto di rifiuto',
    '🙅‍♀' => 'donna con gesto di rifiuto',
    '🙆‍♂' => 'uomo con gesto OK',
    '🙆‍♀' => 'donna con gesto OK',
    '💁‍♂' => 'uomo con mano capovolta',
    '💁‍♀' => 'donna con mano capovolta',
    '🙋‍♂' => 'uomo con mano alzata',
    '🙋‍♀' => 'donna con mano alzata',
    '🧏‍♂' => 'uomo con problemi di udito',
    '🧏‍♀' => 'donna con problemi di udito',
    '🙇‍♂' => 'uomo che fa inchino profondo',
    '🙇‍♀' => 'donna che fa inchino profondo',
    '🤦‍♂' => 'uomo esasperato',
    '🤦‍♀' => 'donna esasperata',
    '🤷‍♂' => 'uomo che scrolla le spalle',
    '🤷‍♀' => 'donna che scrolla le spalle',
    '🧑‍⚕' => 'persona che lavora nella sanità',
    '👨‍⚕' => 'operatore sanitario',
    '👩‍⚕' => 'operatrice sanitaria',
    '🧑‍🎓' => 'studente',
    '👨‍🎓' => 'studente maschio',
    '👩‍🎓' => 'studentessa',
    '🧑‍🏫' => 'insegnante',
    '👨‍🏫' => 'professore',
    '👩‍🏫' => 'professoressa',
    '🧑‍⚖' => 'giudice',
    '👨‍⚖' => 'giudice uomo',
    '👩‍⚖' => 'giudice donna',
    '🧑‍🌾' => 'agricoltore',
    '👨‍🌾' => 'contadino',
    '👩‍🌾' => 'contadina',
    '🧑‍🍳' => 'persona che cucina',
    '👨‍🍳' => 'cuoco',
    '👩‍🍳' => 'cuoca',
    '🧑‍🔧' => 'meccanico',
    '👨‍🔧' => 'meccanico uomo',
    '👩‍🔧' => 'meccanico donna',
    '🧑‍🏭' => 'persona che lavora in fabbrica',
    '👨‍🏭' => 'operaio',
    '👩‍🏭' => 'operaia',
    '🧑‍💼' => 'persona che fa un lavoro d’ufficio',
    '👨‍💼' => 'impiegato',
    '👩‍💼' => 'impiegata',
    '🧑‍🔬' => 'persona che lavora in campo scientifico',
    '👨‍🔬' => 'scienziato',
    '👩‍🔬' => 'scienziata',
    '🧑‍💻' => 'persona esperta di tecnologia',
    '👨‍💻' => 'tecnologo',
    '👩‍💻' => 'tecnologa',
    '🧑‍🎤' => 'cantante',
    '👨‍🎤' => 'cantante uomo',
    '👩‍🎤' => 'cantante donna',
    '🧑‍🎨' => 'artista',
    '👨‍🎨' => 'artista uomo',
    '👩‍🎨' => 'artista donna',
    '🧑‍✈' => 'pilota',
    '👨‍✈' => 'pilota uomo',
    '👩‍✈' => 'pilota donna',
    '🧑‍🚀' => 'astronauta',
    '👨‍🚀' => 'astronauta uomo',
    '👩‍🚀' => 'astronauta donna',
    '🧑‍🚒' => 'pompiere',
    '👨‍🚒' => 'pompiere uomo',
    '👩‍🚒' => 'pompiere donna',
    '👮‍♂' => 'poliziotto',
    '👮‍♀' => 'poliziotta',
    '🕵‍♂' => 'investigatore',
    '🕵‍♀' => 'investigatrice',
    '💂‍♂' => 'guardia uomo',
    '💂‍♀' => 'guardia donna',
    '👷‍♂' => 'operaio edile uomo',
    '👷‍♀' => 'operaia edile',
    '👳‍♂' => 'uomo con turbante',
    '👳‍♀' => 'donna con turbante',
    '🤵‍♂' => 'uomo in smoking',
    '🤵‍♀' => 'donna in smoking',
    '👰‍♂' => 'sposo con velo',
    '👰‍♀' => 'sposa con velo',
    '👩‍🍼' => 'donna che allatta',
    '👨‍🍼' => 'uomo che allatta',
    '🧑‍🍼' => 'persona che allatta',
    '🧑‍🎄' => 'Santa Claus',
    '🦸‍♂' => 'supereroe uomo',
    '🦸‍♀' => 'supereroina',
    '🦹‍♂' => 'supercattivo uomo',
    '🦹‍♀' => 'supercattiva',
    '🧙‍♂' => 'mago uomo',
    '🧙‍♀' => 'maga',
    '🧚‍♂' => 'folletto alato',
    '🧚‍♀' => 'fata donna',
    '🧛‍♂' => 'vampiro uomo',
    '🧛‍♀' => 'vampira',
    '🧜‍♂' => 'tritone',
    '🧜‍♀' => 'sirena donna',
    '🧝‍♂' => 'elfo uomo',
    '🧝‍♀' => 'elfo donna',
    '🧞‍♂' => 'genio uomo',
    '🧞‍♀' => 'genio donna',
    '🧟‍♂' => 'zombie uomo',
    '🧟‍♀' => 'zombie donna',
    '💆‍♂' => 'uomo che riceve un massaggio',
    '💆‍♀' => 'donna che riceve un massaggio',
    '💇‍♂' => 'taglio di capelli per uomo',
    '💇‍♀' => 'taglio di capelli per donna',
    '🚶‍♂' => 'uomo che cammina',
    '🚶‍♀' => 'donna che cammina',
    '🧍‍♂' => 'uomo in piedi',
    '🧍‍♀' => 'donna in piedi',
    '🧎‍♂' => 'uomo inginocchiato',
    '🧎‍♀' => 'donna inginocchiata',
    '🧑‍🦯' => 'persona con bastone di orientamento',
    '👨‍🦯' => 'uomo con bastone bianco di orientamento',
    '👩‍🦯' => 'donna con bastone bianco di orientamento',
    '🧑‍🦼' => 'persona su sedia a rotelle motorizzata',
    '👨‍🦼' => 'uomo su sedia a rotelle motorizzata',
    '👩‍🦼' => 'donna su sedia a rotelle motorizzata',
    '🧑‍🦽' => 'persona su sedia a rotelle manuale',
    '👨‍🦽' => 'uomo su sedia a rotelle manuale',
    '👩‍🦽' => 'donna su sedia a rotelle manuale',
    '🏃‍♂' => 'uomo che corre',
    '🏃‍♀' => 'donna che corre',
    '🧑‍🩰' => 'persona che danza',
    '👯‍♂' => 'uomini con orecchie da coniglio',
    '👯‍♀' => 'donne con orecchie da coniglio',
    '🧖‍♂' => 'uomo in sauna',
    '🧖‍♀' => 'donna in sauna',
    '🧗‍♂' => 'scalatore',
    '🧗‍♀' => 'scalatrice',
    '🏌‍♂' => 'golfista uomo',
    '🏌‍♀' => 'golfista donna',
    '🏄‍♂' => 'surfista uomo',
    '🏄‍♀' => 'surfista donna',
    '🚣‍♂' => 'uomo in barca a remi',
    '🚣‍♀' => 'donna in barca a remi',
    '🏊‍♂' => 'nuotatore',
    '🏊‍♀' => 'nuotatrice',
    '⛹‍♂' => 'uomo che fa rimbalzare una palla',
    '⛹‍♀' => 'donna che fa rimbalzare una palla',
    '🏋‍♂' => 'uomo che solleva pesi',
    '🏋‍♀' => 'donna che solleva pesi',
    '🚴‍♂' => 'ciclista uomo',
    '🚴‍♀' => 'ciclista donna',
    '🚵‍♂' => 'ciclista uomo di mountain bike',
    '🚵‍♀' => 'ciclista donna di mountain bike',
    '🤸‍♂' => 'uomo che fa la ruota',
    '🤸‍♀' => 'donna che fa la ruota',
    '🤼‍♂' => 'lottatori',
    '🤼‍♀' => 'lottatrici',
    '🤽‍♂' => 'pallanuotista uomo',
    '🤽‍♀' => 'pallanuotista donna',
    '🤾‍♂' => 'pallamanista uomo',
    '🤾‍♀' => 'pallamanista donna',
    '🤹‍♂' => 'giocoliere uomo',
    '🤹‍♀' => 'giocoliere donna',
    '🧘‍♂' => 'uomo in posizione del loto',
    '🧘‍♀' => 'donna in posizione del loto',
    '🧑‍🧒' => 'famiglia: persona adulta, minore',
    '🐕‍🦺' => 'cane da assistenza',
    '🐈‍⬛' => 'gatto nero',
    '🐻‍❄' => 'orso polare',
    '🐦‍⬛' => 'merlo',
    '🐦‍🔥' => 'fenice',
    '🍋‍🟩' => 'lime',
    '🍄‍🟫' => 'fungo marrone',
    '⛓‍💥' => 'catena spezzata',
    '🏳‍🌈' => 'bandiera arcobaleno',
    '🏳‍⚧' => 'bandiera transgender',
    '🏴‍☠' => 'bandiera dei pirati',
    '👋🏻' => 'mano che saluta: carnagione chiara',
    '👋🏼' => 'mano che saluta: carnagione abbastanza chiara',
    '👋🏽' => 'mano che saluta: carnagione olivastra',
    '👋🏾' => 'mano che saluta: carnagione abbastanza scura',
    '👋🏿' => 'mano che saluta: carnagione scura',
    '🤚🏻' => 'dorso mano alzata: carnagione chiara',
    '🤚🏼' => 'dorso mano alzata: carnagione abbastanza chiara',
    '🤚🏽' => 'dorso mano alzata: carnagione olivastra',
    '🤚🏾' => 'dorso mano alzata: carnagione abbastanza scura',
    '🤚🏿' => 'dorso mano alzata: carnagione scura',
    '🖐🏻' => 'mano aperta: carnagione chiara',
    '🖐🏼' => 'mano aperta: carnagione abbastanza chiara',
    '🖐🏽' => 'mano aperta: carnagione olivastra',
    '🖐🏾' => 'mano aperta: carnagione abbastanza scura',
    '🖐🏿' => 'mano aperta: carnagione scura',
    '✋🏻' => 'mano alzata: carnagione chiara',
    '✋🏼' => 'mano alzata: carnagione abbastanza chiara',
    '✋🏽' => 'mano alzata: carnagione olivastra',
    '✋🏾' => 'mano alzata: carnagione abbastanza scura',
    '✋🏿' => 'mano alzata: carnagione scura',
    '🖖🏻' => 'saluto vulcaniano: carnagione chiara',
    '🖖🏼' => 'saluto vulcaniano: carnagione abbastanza chiara',
    '🖖🏽' => 'saluto vulcaniano: carnagione olivastra',
    '🖖🏾' => 'saluto vulcaniano: carnagione abbastanza scura',
    '🖖🏿' => 'saluto vulcaniano: carnagione scura',
    '🫱🏻' => 'mano rivolta a destra: carnagione chiara',
    '🫱🏼' => 'mano rivolta a destra: carnagione abbastanza chiara',
    '🫱🏽' => 'mano rivolta a destra: carnagione olivastra',
    '🫱🏾' => 'mano rivolta a destra: carnagione abbastanza scura',
    '🫱🏿' => 'mano rivolta a destra: carnagione scura',
    '🫲🏻' => 'mano rivolta a sinistra: carnagione chiara',
    '🫲🏼' => 'mano rivolta a sinistra: carnagione abbastanza chiara',
    '🫲🏽' => 'mano rivolta a sinistra: carnagione olivastra',
    '🫲🏾' => 'mano rivolta a sinistra: carnagione abbastanza scura',
    '🫲🏿' => 'mano rivolta a sinistra: carnagione scura',
    '🫳🏻' => 'mano con il palmo verso il basso: carnagione chiara',
    '🫳🏼' => 'mano con il palmo verso il basso: carnagione abbastanza chiara',
    '🫳🏽' => 'mano con il palmo verso il basso: carnagione olivastra',
    '🫳🏾' => 'mano con il palmo verso il basso: carnagione abbastanza scura',
    '🫳🏿' => 'mano con il palmo verso il basso: carnagione scura',
    '🫴🏻' => 'mano con il palmo verso l’alto: carnagione chiara',
    '🫴🏼' => 'mano con il palmo verso l’alto: carnagione abbastanza chiara',
    '🫴🏽' => 'mano con il palmo verso l’alto: carnagione olivastra',
    '🫴🏾' => 'mano con il palmo verso l’alto: carnagione abbastanza scura',
    '🫴🏿' => 'mano con il palmo verso l’alto: carnagione scura',
    '🫷🏻' => 'mano che spinge a sinistra: carnagione chiara',
    '🫷🏼' => 'mano che spinge a sinistra: carnagione abbastanza chiara',
    '🫷🏽' => 'mano che spinge a sinistra: carnagione olivastra',
    '🫷🏾' => 'mano che spinge a sinistra: carnagione abbastanza scura',
    '🫷🏿' => 'mano che spinge a sinistra: carnagione scura',
    '🫸🏻' => 'mano che spinge a destra: carnagione chiara',
    '🫸🏼' => 'mano che spinge a destra: carnagione abbastanza chiara',
    '🫸🏽' => 'mano che spinge a destra: carnagione olivastra',
    '🫸🏾' => 'mano che spinge a destra: carnagione abbastanza scura',
    '🫸🏿' => 'mano che spinge a destra: carnagione scura',
    '👌🏻' => 'mano che fa OK: carnagione chiara',
    '👌🏼' => 'mano che fa OK: carnagione abbastanza chiara',
    '👌🏽' => 'mano che fa OK: carnagione olivastra',
    '👌🏾' => 'mano che fa OK: carnagione abbastanza scura',
    '👌🏿' => 'mano che fa OK: carnagione scura',
    '🤌🏻' => 'mano a pigna: carnagione chiara',
    '🤌🏼' => 'mano a pigna: carnagione abbastanza chiara',
    '🤌🏽' => 'mano a pigna: carnagione olivastra',
    '🤌🏾' => 'mano a pigna: carnagione abbastanza scura',
    '🤌🏿' => 'mano a pigna: carnagione scura',
    '🤏🏻' => 'mano che fa il gesto del pizzico: carnagione chiara',
    '🤏🏼' => 'mano che fa il gesto del pizzico: carnagione abbastanza chiara',
    '🤏🏽' => 'mano che fa il gesto del pizzico: carnagione olivastra',
    '🤏🏾' => 'mano che fa il gesto del pizzico: carnagione abbastanza scura',
    '🤏🏿' => 'mano che fa il gesto del pizzico: carnagione scura',
    '✌🏻' => 'vittoria: carnagione chiara',
    '✌🏼' => 'vittoria: carnagione abbastanza chiara',
    '✌🏽' => 'vittoria: carnagione olivastra',
    '✌🏾' => 'vittoria: carnagione abbastanza scura',
    '✌🏿' => 'vittoria: carnagione scura',
    '🤞🏻' => 'dita incrociate: carnagione chiara',
    '🤞🏼' => 'dita incrociate: carnagione abbastanza chiara',
    '🤞🏽' => 'dita incrociate: carnagione olivastra',
    '🤞🏾' => 'dita incrociate: carnagione abbastanza scura',
    '🤞🏿' => 'dita incrociate: carnagione scura',
    '🫰🏻' => 'mano con indice e pollice incrociati: carnagione chiara',
    '🫰🏼' => 'mano con indice e pollice incrociati: carnagione abbastanza chiara',
    '🫰🏽' => 'mano con indice e pollice incrociati: carnagione olivastra',
    '🫰🏾' => 'mano con indice e pollice incrociati: carnagione abbastanza scura',
    '🫰🏿' => 'mano con indice e pollice incrociati: carnagione scura',
    '🤟🏻' => 'gesto ti amo: carnagione chiara',
    '🤟🏼' => 'gesto ti amo: carnagione abbastanza chiara',
    '🤟🏽' => 'gesto ti amo: carnagione olivastra',
    '🤟🏾' => 'gesto ti amo: carnagione abbastanza scura',
    '🤟🏿' => 'gesto ti amo: carnagione scura',
    '🤘🏻' => 'segno delle corna: carnagione chiara',
    '🤘🏼' => 'segno delle corna: carnagione abbastanza chiara',
    '🤘🏽' => 'segno delle corna: carnagione olivastra',
    '🤘🏾' => 'segno delle corna: carnagione abbastanza scura',
    '🤘🏿' => 'segno delle corna: carnagione scura',
    '🤙🏻' => 'mano con gesto di chiamata: carnagione chiara',
    '🤙🏼' => 'mano con gesto di chiamata: carnagione abbastanza chiara',
    '🤙🏽' => 'mano con gesto di chiamata: carnagione olivastra',
    '🤙🏾' => 'mano con gesto di chiamata: carnagione abbastanza scura',
    '🤙🏿' => 'mano con gesto di chiamata: carnagione scura',
    '👈🏻' => 'indice verso sinistra: carnagione chiara',
    '👈🏼' => 'indice verso sinistra: carnagione abbastanza chiara',
    '👈🏽' => 'indice verso sinistra: carnagione olivastra',
    '👈🏾' => 'indice verso sinistra: carnagione abbastanza scura',
    '👈🏿' => 'indice verso sinistra: carnagione scura',
    '👉🏻' => 'indice verso destra: carnagione chiara',
    '👉🏼' => 'indice verso destra: carnagione abbastanza chiara',
    '👉🏽' => 'indice verso destra: carnagione olivastra',
    '👉🏾' => 'indice verso destra: carnagione abbastanza scura',
    '👉🏿' => 'indice verso destra: carnagione scura',
    '👆🏻' => 'indice alzato: carnagione chiara',
    '👆🏼' => 'indice alzato: carnagione abbastanza chiara',
    '👆🏽' => 'indice alzato: carnagione olivastra',
    '👆🏾' => 'indice alzato: carnagione abbastanza scura',
    '👆🏿' => 'indice alzato: carnagione scura',
    '🖕🏻' => 'dito medio: carnagione chiara',
    '🖕🏼' => 'dito medio: carnagione abbastanza chiara',
    '🖕🏽' => 'dito medio: carnagione olivastra',
    '🖕🏾' => 'dito medio: carnagione abbastanza scura',
    '🖕🏿' => 'dito medio: carnagione scura',
    '👇🏻' => 'indice abbassato: carnagione chiara',
    '👇🏼' => 'indice abbassato: carnagione abbastanza chiara',
    '👇🏽' => 'indice abbassato: carnagione olivastra',
    '👇🏾' => 'indice abbassato: carnagione abbastanza scura',
    '👇🏿' => 'indice abbassato: carnagione scura',
    '☝🏻' => 'indice verso l’alto: carnagione chiara',
    '☝🏼' => 'indice verso l’alto: carnagione abbastanza chiara',
    '☝🏽' => 'indice verso l’alto: carnagione olivastra',
    '☝🏾' => 'indice verso l’alto: carnagione abbastanza scura',
    '☝🏿' => 'indice verso l’alto: carnagione scura',
    '🫵🏻' => 'indice verso l’osservatore: carnagione chiara',
    '🫵🏼' => 'indice verso l’osservatore: carnagione abbastanza chiara',
    '🫵🏽' => 'indice verso l’osservatore: carnagione olivastra',
    '🫵🏾' => 'indice verso l’osservatore: carnagione abbastanza scura',
    '🫵🏿' => 'indice verso l’osservatore: carnagione scura',
    '👍🏻' => 'pollice in su: carnagione chiara',
    '👍🏼' => 'pollice in su: carnagione abbastanza chiara',
    '👍🏽' => 'pollice in su: carnagione olivastra',
    '👍🏾' => 'pollice in su: carnagione abbastanza scura',
    '👍🏿' => 'pollice in su: carnagione scura',
    '👎🏻' => 'pollice verso: carnagione chiara',
    '👎🏼' => 'pollice verso: carnagione abbastanza chiara',
    '👎🏽' => 'pollice verso: carnagione olivastra',
    '👎🏾' => 'pollice verso: carnagione abbastanza scura',
    '👎🏿' => 'pollice verso: carnagione scura',
    '✊🏻' => 'pugno: carnagione chiara',
    '✊🏼' => 'pugno: carnagione abbastanza chiara',
    '✊🏽' => 'pugno: carnagione olivastra',
    '✊🏾' => 'pugno: carnagione abbastanza scura',
    '✊🏿' => 'pugno: carnagione scura',
    '👊🏻' => 'pugno chiuso: carnagione chiara',
    '👊🏼' => 'pugno chiuso: carnagione abbastanza chiara',
    '👊🏽' => 'pugno chiuso: carnagione olivastra',
    '👊🏾' => 'pugno chiuso: carnagione abbastanza scura',
    '👊🏿' => 'pugno chiuso: carnagione scura',
    '🤛🏻' => 'pugno a sinistra: carnagione chiara',
    '🤛🏼' => 'pugno a sinistra: carnagione abbastanza chiara',
    '🤛🏽' => 'pugno a sinistra: carnagione olivastra',
    '🤛🏾' => 'pugno a sinistra: carnagione abbastanza scura',
    '🤛🏿' => 'pugno a sinistra: carnagione scura',
    '🤜🏻' => 'pugno a destra: carnagione chiara',
    '🤜🏼' => 'pugno a destra: carnagione abbastanza chiara',
    '🤜🏽' => 'pugno a destra: carnagione olivastra',
    '🤜🏾' => 'pugno a destra: carnagione abbastanza scura',
    '🤜🏿' => 'pugno a destra: carnagione scura',
    '👏🏻' => 'mani che applaudono: carnagione chiara',
    '👏🏼' => 'mani che applaudono: carnagione abbastanza chiara',
    '👏🏽' => 'mani che applaudono: carnagione olivastra',
    '👏🏾' => 'mani che applaudono: carnagione abbastanza scura',
    '👏🏿' => 'mani che applaudono: carnagione scura',
    '🙌🏻' => 'mani alzate: carnagione chiara',
    '🙌🏼' => 'mani alzate: carnagione abbastanza chiara',
    '🙌🏽' => 'mani alzate: carnagione olivastra',
    '🙌🏾' => 'mani alzate: carnagione abbastanza scura',
    '🙌🏿' => 'mani alzate: carnagione scura',
    '🫶🏻' => 'mani a cuore: carnagione chiara',
    '🫶🏼' => 'mani a cuore: carnagione abbastanza chiara',
    '🫶🏽' => 'mani a cuore: carnagione olivastra',
    '🫶🏾' => 'mani a cuore: carnagione abbastanza scura',
    '🫶🏿' => 'mani a cuore: carnagione scura',
    '👐🏻' => 'mani aperte: carnagione chiara',
    '👐🏼' => 'mani aperte: carnagione abbastanza chiara',
    '👐🏽' => 'mani aperte: carnagione olivastra',
    '👐🏾' => 'mani aperte: carnagione abbastanza scura',
    '👐🏿' => 'mani aperte: carnagione scura',
    '🤲🏻' => 'mani unite in alto: carnagione chiara',
    '🤲🏼' => 'mani unite in alto: carnagione abbastanza chiara',
    '🤲🏽' => 'mani unite in alto: carnagione olivastra',
    '🤲🏾' => 'mani unite in alto: carnagione abbastanza scura',
    '🤲🏿' => 'mani unite in alto: carnagione scura',
    '🤝🏻' => 'stretta di mano: carnagione chiara',
    '🤝🏼' => 'stretta di mano: carnagione abbastanza chiara',
    '🤝🏽' => 'stretta di mano: carnagione olivastra',
    '🤝🏾' => 'stretta di mano: carnagione abbastanza scura',
    '🤝🏿' => 'stretta di mano: carnagione scura',
    '🙏🏻' => 'mani giunte: carnagione chiara',
    '🙏🏼' => 'mani giunte: carnagione abbastanza chiara',
    '🙏🏽' => 'mani giunte: carnagione olivastra',
    '🙏🏾' => 'mani giunte: carnagione abbastanza scura',
    '🙏🏿' => 'mani giunte: carnagione scura',
    '✍🏻' => 'mano che scrive: carnagione chiara',
    '✍🏼' => 'mano che scrive: carnagione abbastanza chiara',
    '✍🏽' => 'mano che scrive: carnagione olivastra',
    '✍🏾' => 'mano che scrive: carnagione abbastanza scura',
    '✍🏿' => 'mano che scrive: carnagione scura',
    '💅🏻' => 'smalto per unghie: carnagione chiara',
    '💅🏼' => 'smalto per unghie: carnagione abbastanza chiara',
    '💅🏽' => 'smalto per unghie: carnagione olivastra',
    '💅🏾' => 'smalto per unghie: carnagione abbastanza scura',
    '💅🏿' => 'smalto per unghie: carnagione scura',
    '🤳🏻' => 'selfie: carnagione chiara',
    '🤳🏼' => 'selfie: carnagione abbastanza chiara',
    '🤳🏽' => 'selfie: carnagione olivastra',
    '🤳🏾' => 'selfie: carnagione abbastanza scura',
    '🤳🏿' => 'selfie: carnagione scura',
    '💪🏻' => 'bicipite: carnagione chiara',
    '💪🏼' => 'bicipite: carnagione abbastanza chiara',
    '💪🏽' => 'bicipite: carnagione olivastra',
    '💪🏾' => 'bicipite: carnagione abbastanza scura',
    '💪🏿' => 'bicipite: carnagione scura',
    '🦵🏻' => 'gamba: carnagione chiara',
    '🦵🏼' => 'gamba: carnagione abbastanza chiara',
    '🦵🏽' => 'gamba: carnagione olivastra',
    '🦵🏾' => 'gamba: carnagione abbastanza scura',
    '🦵🏿' => 'gamba: carnagione scura',
    '🦶🏻' => 'piede: carnagione chiara',
    '🦶🏼' => 'piede: carnagione abbastanza chiara',
    '🦶🏽' => 'piede: carnagione olivastra',
    '🦶🏾' => 'piede: carnagione abbastanza scura',
    '🦶🏿' => 'piede: carnagione scura',
    '👂🏻' => 'orecchio: carnagione chiara',
    '👂🏼' => 'orecchio: carnagione abbastanza chiara',
    '👂🏽' => 'orecchio: carnagione olivastra',
    '👂🏾' => 'orecchio: carnagione abbastanza scura',
    '👂🏿' => 'orecchio: carnagione scura',
    '🦻🏻' => 'orecchio con apparecchio acustico: carnagione chiara',
    '🦻🏼' => 'orecchio con apparecchio acustico: carnagione abbastanza chiara',
    '🦻🏽' => 'orecchio con apparecchio acustico: carnagione olivastra',
    '🦻🏾' => 'orecchio con apparecchio acustico: carnagione abbastanza scura',
    '🦻🏿' => 'orecchio con apparecchio acustico: carnagione scura',
    '👃🏻' => 'naso: carnagione chiara',
    '👃🏼' => 'naso: carnagione abbastanza chiara',
    '👃🏽' => 'naso: carnagione olivastra',
    '👃🏾' => 'naso: carnagione abbastanza scura',
    '👃🏿' => 'naso: carnagione scura',
    '👶🏻' => 'neonato: carnagione chiara',
    '👶🏼' => 'neonato: carnagione abbastanza chiara',
    '👶🏽' => 'neonato: carnagione olivastra',
    '👶🏾' => 'neonato: carnagione abbastanza scura',
    '👶🏿' => 'neonato: carnagione scura',
    '🧒🏻' => 'bimbo: carnagione chiara',
    '🧒🏼' => 'bimbo: carnagione abbastanza chiara',
    '🧒🏽' => 'bimbo: carnagione olivastra',
    '🧒🏾' => 'bimbo: carnagione abbastanza scura',
    '🧒🏿' => 'bimbo: carnagione scura',
    '👦🏻' => 'bambino: carnagione chiara',
    '👦🏼' => 'bambino: carnagione abbastanza chiara',
    '👦🏽' => 'bambino: carnagione olivastra',
    '👦🏾' => 'bambino: carnagione abbastanza scura',
    '👦🏿' => 'bambino: carnagione scura',
    '👧🏻' => 'bambina: carnagione chiara',
    '👧🏼' => 'bambina: carnagione abbastanza chiara',
    '👧🏽' => 'bambina: carnagione olivastra',
    '👧🏾' => 'bambina: carnagione abbastanza scura',
    '👧🏿' => 'bambina: carnagione scura',
    '🧑🏻' => 'persona: carnagione chiara',
    '🧑🏼' => 'persona: carnagione abbastanza chiara',
    '🧑🏽' => 'persona: carnagione olivastra',
    '🧑🏾' => 'persona: carnagione abbastanza scura',
    '🧑🏿' => 'persona: carnagione scura',
    '👱🏻' => 'persona bionda: carnagione chiara',
    '👱🏼' => 'persona bionda: carnagione abbastanza chiara',
    '👱🏽' => 'persona bionda: carnagione olivastra',
    '👱🏾' => 'persona bionda: carnagione abbastanza scura',
    '👱🏿' => 'persona bionda: carnagione scura',
    '👨🏻' => 'uomo: carnagione chiara',
    '👨🏼' => 'uomo: carnagione abbastanza chiara',
    '👨🏽' => 'uomo: carnagione olivastra',
    '👨🏾' => 'uomo: carnagione abbastanza scura',
    '👨🏿' => 'uomo: carnagione scura',
    '🧔🏻' => 'persona con la barba: carnagione chiara',
    '🧔🏼' => 'persona con la barba: carnagione abbastanza chiara',
    '🧔🏽' => 'persona con la barba: carnagione olivastra',
    '🧔🏾' => 'persona con la barba: carnagione abbastanza scura',
    '🧔🏿' => 'persona con la barba: carnagione scura',
    '👩🏻' => 'donna: carnagione chiara',
    '👩🏼' => 'donna: carnagione abbastanza chiara',
    '👩🏽' => 'donna: carnagione olivastra',
    '👩🏾' => 'donna: carnagione abbastanza scura',
    '👩🏿' => 'donna: carnagione scura',
    '🧓🏻' => 'persona anziana: carnagione chiara',
    '🧓🏼' => 'persona anziana: carnagione abbastanza chiara',
    '🧓🏽' => 'persona anziana: carnagione olivastra',
    '🧓🏾' => 'persona anziana: carnagione abbastanza scura',
    '🧓🏿' => 'persona anziana: carnagione scura',
    '👴🏻' => 'uomo anziano: carnagione chiara',
    '👴🏼' => 'uomo anziano: carnagione abbastanza chiara',
    '👴🏽' => 'uomo anziano: carnagione olivastra',
    '👴🏾' => 'uomo anziano: carnagione abbastanza scura',
    '👴🏿' => 'uomo anziano: carnagione scura',
    '👵🏻' => 'donna anziana: carnagione chiara',
    '👵🏼' => 'donna anziana: carnagione abbastanza chiara',
    '👵🏽' => 'donna anziana: carnagione olivastra',
    '👵🏾' => 'donna anziana: carnagione abbastanza scura',
    '👵🏿' => 'donna anziana: carnagione scura',
    '🙍🏻' => 'persona corrucciata: carnagione chiara',
    '🙍🏼' => 'persona corrucciata: carnagione abbastanza chiara',
    '🙍🏽' => 'persona corrucciata: carnagione olivastra',
    '🙍🏾' => 'persona corrucciata: carnagione abbastanza scura',
    '🙍🏿' => 'persona corrucciata: carnagione scura',
    '🙎🏻' => 'persona imbronciata: carnagione chiara',
    '🙎🏼' => 'persona imbronciata: carnagione abbastanza chiara',
    '🙎🏽' => 'persona imbronciata: carnagione olivastra',
    '🙎🏾' => 'persona imbronciata: carnagione abbastanza scura',
    '🙎🏿' => 'persona imbronciata: carnagione scura',
    '🙅🏻' => 'persona che fa segno di no: carnagione chiara',
    '🙅🏼' => 'persona che fa segno di no: carnagione abbastanza chiara',
    '🙅🏽' => 'persona che fa segno di no: carnagione olivastra',
    '🙅🏾' => 'persona che fa segno di no: carnagione abbastanza scura',
    '🙅🏿' => 'persona che fa segno di no: carnagione scura',
    '🙆🏻' => 'persona con gesto OK: carnagione chiara',
    '🙆🏼' => 'persona con gesto OK: carnagione abbastanza chiara',
    '🙆🏽' => 'persona con gesto OK: carnagione olivastra',
    '🙆🏾' => 'persona con gesto OK: carnagione abbastanza scura',
    '🙆🏿' => 'persona con gesto OK: carnagione scura',
    '💁🏻' => 'persona con mano capovolta: carnagione chiara',
    '💁🏼' => 'persona con mano capovolta: carnagione abbastanza chiara',
    '💁🏽' => 'persona con mano capovolta: carnagione olivastra',
    '💁🏾' => 'persona con mano capovolta: carnagione abbastanza scura',
    '💁🏿' => 'persona con mano capovolta: carnagione scura',
    '🙋🏻' => 'persona con mano alzata: carnagione chiara',
    '🙋🏼' => 'persona con mano alzata: carnagione abbastanza chiara',
    '🙋🏽' => 'persona con mano alzata: carnagione olivastra',
    '🙋🏾' => 'persona con mano alzata: carnagione abbastanza scura',
    '🙋🏿' => 'persona con mano alzata: carnagione scura',
    '🧏🏻' => 'persona con problemi di udito: carnagione chiara',
    '🧏🏼' => 'persona con problemi di udito: carnagione abbastanza chiara',
    '🧏🏽' => 'persona con problemi di udito: carnagione olivastra',
    '🧏🏾' => 'persona con problemi di udito: carnagione abbastanza scura',
    '🧏🏿' => 'persona con problemi di udito: carnagione scura',
    '🙇🏻' => 'persona che fa un inchino profondo: carnagione chiara',
    '🙇🏼' => 'persona che fa un inchino profondo: carnagione abbastanza chiara',
    '🙇🏽' => 'persona che fa un inchino profondo: carnagione olivastra',
    '🙇🏾' => 'persona che fa un inchino profondo: carnagione abbastanza scura',
    '🙇🏿' => 'persona che fa un inchino profondo: carnagione scura',
    '🤦🏻' => 'persona esasperata: carnagione chiara',
    '🤦🏼' => 'persona esasperata: carnagione abbastanza chiara',
    '🤦🏽' => 'persona esasperata: carnagione olivastra',
    '🤦🏾' => 'persona esasperata: carnagione abbastanza scura',
    '🤦🏿' => 'persona esasperata: carnagione scura',
    '🤷🏻' => 'persona che scrolla le spalle: carnagione chiara',
    '🤷🏼' => 'persona che scrolla le spalle: carnagione abbastanza chiara',
    '🤷🏽' => 'persona che scrolla le spalle: carnagione olivastra',
    '🤷🏾' => 'persona che scrolla le spalle: carnagione abbastanza scura',
    '🤷🏿' => 'persona che scrolla le spalle: carnagione scura',
    '👮🏻' => 'agente di polizia: carnagione chiara',
    '👮🏼' => 'agente di polizia: carnagione abbastanza chiara',
    '👮🏽' => 'agente di polizia: carnagione olivastra',
    '👮🏾' => 'agente di polizia: carnagione abbastanza scura',
    '👮🏿' => 'agente di polizia: carnagione scura',
    '🕵🏻' => 'detective: carnagione chiara',
    '🕵🏼' => 'detective: carnagione abbastanza chiara',
    '🕵🏽' => 'detective: carnagione olivastra',
    '🕵🏾' => 'detective: carnagione abbastanza scura',
    '🕵🏿' => 'detective: carnagione scura',
    '💂🏻' => 'guardia: carnagione chiara',
    '💂🏼' => 'guardia: carnagione abbastanza chiara',
    '💂🏽' => 'guardia: carnagione olivastra',
    '💂🏾' => 'guardia: carnagione abbastanza scura',
    '💂🏿' => 'guardia: carnagione scura',
    '🥷🏻' => 'ninja: carnagione chiara',
    '🥷🏼' => 'ninja: carnagione abbastanza chiara',
    '🥷🏽' => 'ninja: carnagione olivastra',
    '🥷🏾' => 'ninja: carnagione abbastanza scura',
    '🥷🏿' => 'ninja: carnagione scura',
    '👷🏻' => 'operaio edile: carnagione chiara',
    '👷🏼' => 'operaio edile: carnagione abbastanza chiara',
    '👷🏽' => 'operaio edile: carnagione olivastra',
    '👷🏾' => 'operaio edile: carnagione abbastanza scura',
    '👷🏿' => 'operaio edile: carnagione scura',
    '🫅🏻' => 'persona con corona: carnagione chiara',
    '🫅🏼' => 'persona con corona: carnagione abbastanza chiara',
    '🫅🏽' => 'persona con corona: carnagione olivastra',
    '🫅🏾' => 'persona con corona: carnagione abbastanza scura',
    '🫅🏿' => 'persona con corona: carnagione scura',
    '🤴🏻' => 'principe: carnagione chiara',
    '🤴🏼' => 'principe: carnagione abbastanza chiara',
    '🤴🏽' => 'principe: carnagione olivastra',
    '🤴🏾' => 'principe: carnagione abbastanza scura',
    '🤴🏿' => 'principe: carnagione scura',
    '👸🏻' => 'principessa: carnagione chiara',
    '👸🏼' => 'principessa: carnagione abbastanza chiara',
    '👸🏽' => 'principessa: carnagione olivastra',
    '👸🏾' => 'principessa: carnagione abbastanza scura',
    '👸🏿' => 'principessa: carnagione scura',
    '👳🏻' => 'persona con turbante: carnagione chiara',
    '👳🏼' => 'persona con turbante: carnagione abbastanza chiara',
    '👳🏽' => 'persona con turbante: carnagione olivastra',
    '👳🏾' => 'persona con turbante: carnagione abbastanza scura',
    '👳🏿' => 'persona con turbante: carnagione scura',
    '👲🏻' => 'uomo con zucchetto cinese: carnagione chiara',
    '👲🏼' => 'uomo con zucchetto cinese: carnagione abbastanza chiara',
    '👲🏽' => 'uomo con zucchetto cinese: carnagione olivastra',
    '👲🏾' => 'uomo con zucchetto cinese: carnagione abbastanza scura',
    '👲🏿' => 'uomo con zucchetto cinese: carnagione scura',
    '🧕🏻' => 'donna con velo: carnagione chiara',
    '🧕🏼' => 'donna con velo: carnagione abbastanza chiara',
    '🧕🏽' => 'donna con velo: carnagione olivastra',
    '🧕🏾' => 'donna con velo: carnagione abbastanza scura',
    '🧕🏿' => 'donna con velo: carnagione scura',
    '🤵🏻' => 'persona in smoking: carnagione chiara',
    '🤵🏼' => 'persona in smoking: carnagione abbastanza chiara',
    '🤵🏽' => 'persona in smoking: carnagione olivastra',
    '🤵🏾' => 'persona in smoking: carnagione abbastanza scura',
    '🤵🏿' => 'persona in smoking: carnagione scura',
    '👰🏻' => 'persona con velo: carnagione chiara',
    '👰🏼' => 'persona con velo: carnagione abbastanza chiara',
    '👰🏽' => 'persona con velo: carnagione olivastra',
    '👰🏾' => 'persona con velo: carnagione abbastanza scura',
    '👰🏿' => 'persona con velo: carnagione scura',
    '🤰🏻' => 'donna incinta: carnagione chiara',
    '🤰🏼' => 'donna incinta: carnagione abbastanza chiara',
    '🤰🏽' => 'donna incinta: carnagione olivastra',
    '🤰🏾' => 'donna incinta: carnagione abbastanza scura',
    '🤰🏿' => 'donna incinta: carnagione scura',
    '🫃🏻' => 'uomo incinto: carnagione chiara',
    '🫃🏼' => 'uomo incinto: carnagione abbastanza chiara',
    '🫃🏽' => 'uomo incinto: carnagione olivastra',
    '🫃🏾' => 'uomo incinto: carnagione abbastanza scura',
    '🫃🏿' => 'uomo incinto: carnagione scura',
    '🫄🏻' => 'persona incinta: carnagione chiara',
    '🫄🏼' => 'persona incinta: carnagione abbastanza chiara',
    '🫄🏽' => 'persona incinta: carnagione olivastra',
    '🫄🏾' => 'persona incinta: carnagione abbastanza scura',
    '🫄🏿' => 'persona incinta: carnagione scura',
    '🤱🏻' => 'allattare: carnagione chiara',
    '🤱🏼' => 'allattare: carnagione abbastanza chiara',
    '🤱🏽' => 'allattare: carnagione olivastra',
    '🤱🏾' => 'allattare: carnagione abbastanza scura',
    '🤱🏿' => 'allattare: carnagione scura',
    '👼🏻' => 'angioletto: carnagione chiara',
    '👼🏼' => 'angioletto: carnagione abbastanza chiara',
    '👼🏽' => 'angioletto: carnagione olivastra',
    '👼🏾' => 'angioletto: carnagione abbastanza scura',
    '👼🏿' => 'angioletto: carnagione scura',
    '🎅🏻' => 'Babbo Natale: carnagione chiara',
    '🎅🏼' => 'Babbo Natale: carnagione abbastanza chiara',
    '🎅🏽' => 'Babbo Natale: carnagione olivastra',
    '🎅🏾' => 'Babbo Natale: carnagione abbastanza scura',
    '🎅🏿' => 'Babbo Natale: carnagione scura',
    '🤶🏻' => 'Mamma Natale: carnagione chiara',
    '🤶🏼' => 'Mamma Natale: carnagione abbastanza chiara',
    '🤶🏽' => 'Mamma Natale: carnagione olivastra',
    '🤶🏾' => 'Mamma Natale: carnagione abbastanza scura',
    '🤶🏿' => 'Mamma Natale: carnagione scura',
    '🦸🏻' => 'supereroe: carnagione chiara',
    '🦸🏼' => 'supereroe: carnagione abbastanza chiara',
    '🦸🏽' => 'supereroe: carnagione olivastra',
    '🦸🏾' => 'supereroe: carnagione abbastanza scura',
    '🦸🏿' => 'supereroe: carnagione scura',
    '🦹🏻' => 'supercattivo: carnagione chiara',
    '🦹🏼' => 'supercattivo: carnagione abbastanza chiara',
    '🦹🏽' => 'supercattivo: carnagione olivastra',
    '🦹🏾' => 'supercattivo: carnagione abbastanza scura',
    '🦹🏿' => 'supercattivo: carnagione scura',
    '🧙🏻' => 'mago: carnagione chiara',
    '🧙🏼' => 'mago: carnagione abbastanza chiara',
    '🧙🏽' => 'mago: carnagione olivastra',
    '🧙🏾' => 'mago: carnagione abbastanza scura',
    '🧙🏿' => 'mago: carnagione scura',
    '🧚🏻' => 'fata: carnagione chiara',
    '🧚🏼' => 'fata: carnagione abbastanza chiara',
    '🧚🏽' => 'fata: carnagione olivastra',
    '🧚🏾' => 'fata: carnagione abbastanza scura',
    '🧚🏿' => 'fata: carnagione scura',
    '🧛🏻' => 'vampiro: carnagione chiara',
    '🧛🏼' => 'vampiro: carnagione abbastanza chiara',
    '🧛🏽' => 'vampiro: carnagione olivastra',
    '🧛🏾' => 'vampiro: carnagione abbastanza scura',
    '🧛🏿' => 'vampiro: carnagione scura',
    '🧜🏻' => 'sirena: carnagione chiara',
    '🧜🏼' => 'sirena: carnagione abbastanza chiara',
    '🧜🏽' => 'sirena: carnagione olivastra',
    '🧜🏾' => 'sirena: carnagione abbastanza scura',
    '🧜🏿' => 'sirena: carnagione scura',
    '🧝🏻' => 'elfo: carnagione chiara',
    '🧝🏼' => 'elfo: carnagione abbastanza chiara',
    '🧝🏽' => 'elfo: carnagione olivastra',
    '🧝🏾' => 'elfo: carnagione abbastanza scura',
    '🧝🏿' => 'elfo: carnagione scura',
    '💆🏻' => 'persona che riceve un massaggio: carnagione chiara',
    '💆🏼' => 'persona che riceve un massaggio: carnagione abbastanza chiara',
    '💆🏽' => 'persona che riceve un massaggio: carnagione olivastra',
    '💆🏾' => 'persona che riceve un massaggio: carnagione abbastanza scura',
    '💆🏿' => 'persona che riceve un massaggio: carnagione scura',
    '💇🏻' => 'taglio di capelli: carnagione chiara',
    '💇🏼' => 'taglio di capelli: carnagione abbastanza chiara',
    '💇🏽' => 'taglio di capelli: carnagione olivastra',
    '💇🏾' => 'taglio di capelli: carnagione abbastanza scura',
    '💇🏿' => 'taglio di capelli: carnagione scura',
    '🚶🏻' => 'pedone: carnagione chiara',
    '🚶🏼' => 'pedone: carnagione abbastanza chiara',
    '🚶🏽' => 'pedone: carnagione olivastra',
    '🚶🏾' => 'pedone: carnagione abbastanza scura',
    '🚶🏿' => 'pedone: carnagione scura',
    '🧍🏻' => 'persona in piedi: carnagione chiara',
    '🧍🏼' => 'persona in piedi: carnagione abbastanza chiara',
    '🧍🏽' => 'persona in piedi: carnagione olivastra',
    '🧍🏾' => 'persona in piedi: carnagione abbastanza scura',
    '🧍🏿' => 'persona in piedi: carnagione scura',
    '🧎🏻' => 'persona inginocchiata: carnagione chiara',
    '🧎🏼' => 'persona inginocchiata: carnagione abbastanza chiara',
    '🧎🏽' => 'persona inginocchiata: carnagione olivastra',
    '🧎🏾' => 'persona inginocchiata: carnagione abbastanza scura',
    '🧎🏿' => 'persona inginocchiata: carnagione scura',
    '🏃🏻' => 'persona che corre: carnagione chiara',
    '🏃🏼' => 'persona che corre: carnagione abbastanza chiara',
    '🏃🏽' => 'persona che corre: carnagione olivastra',
    '🏃🏾' => 'persona che corre: carnagione abbastanza scura',
    '🏃🏿' => 'persona che corre: carnagione scura',
    '💃🏻' => 'donna che balla: carnagione chiara',
    '💃🏼' => 'donna che balla: carnagione abbastanza chiara',
    '💃🏽' => 'donna che balla: carnagione olivastra',
    '💃🏾' => 'donna che balla: carnagione abbastanza scura',
    '💃🏿' => 'donna che balla: carnagione scura',
    '🕺🏻' => 'uomo che balla: carnagione chiara',
    '🕺🏼' => 'uomo che balla: carnagione abbastanza chiara',
    '🕺🏽' => 'uomo che balla: carnagione olivastra',
    '🕺🏾' => 'uomo che balla: carnagione abbastanza scura',
    '🕺🏿' => 'uomo che balla: carnagione scura',
    '🕴🏻' => 'uomo con completo che levita: carnagione chiara',
    '🕴🏼' => 'uomo con completo che levita: carnagione abbastanza chiara',
    '🕴🏽' => 'uomo con completo che levita: carnagione olivastra',
    '🕴🏾' => 'uomo con completo che levita: carnagione abbastanza scura',
    '🕴🏿' => 'uomo con completo che levita: carnagione scura',
    '👯🏻' => 'persone con orecchie da coniglio: carnagione chiara',
    '👯🏼' => 'persone con orecchie da coniglio: carnagione abbastanza chiara',
    '👯🏽' => 'persone con orecchie da coniglio: carnagione olivastra',
    '👯🏾' => 'persone con orecchie da coniglio: carnagione abbastanza scura',
    '👯🏿' => 'persone con orecchie da coniglio: carnagione scura',
    '🧖🏻' => 'persona in sauna: carnagione chiara',
    '🧖🏼' => 'persona in sauna: carnagione abbastanza chiara',
    '🧖🏽' => 'persona in sauna: carnagione olivastra',
    '🧖🏾' => 'persona in sauna: carnagione abbastanza scura',
    '🧖🏿' => 'persona in sauna: carnagione scura',
    '🧗🏻' => 'persona che scala: carnagione chiara',
    '🧗🏼' => 'persona che scala: carnagione abbastanza chiara',
    '🧗🏽' => 'persona che scala: carnagione olivastra',
    '🧗🏾' => 'persona che scala: carnagione abbastanza scura',
    '🧗🏿' => 'persona che scala: carnagione scura',
    '🏇🏻' => 'ippica: carnagione chiara',
    '🏇🏼' => 'ippica: carnagione abbastanza chiara',
    '🏇🏽' => 'ippica: carnagione olivastra',
    '🏇🏾' => 'ippica: carnagione abbastanza scura',
    '🏇🏿' => 'ippica: carnagione scura',
    '🏂🏻' => 'persona sullo snowboard: carnagione chiara',
    '🏂🏼' => 'persona sullo snowboard: carnagione abbastanza chiara',
    '🏂🏽' => 'persona sullo snowboard: carnagione olivastra',
    '🏂🏾' => 'persona sullo snowboard: carnagione abbastanza scura',
    '🏂🏿' => 'persona sullo snowboard: carnagione scura',
    '🏌🏻' => 'persona che gioca a golf: carnagione chiara',
    '🏌🏼' => 'persona che gioca a golf: carnagione abbastanza chiara',
    '🏌🏽' => 'persona che gioca a golf: carnagione olivastra',
    '🏌🏾' => 'persona che gioca a golf: carnagione abbastanza scura',
    '🏌🏿' => 'persona che gioca a golf: carnagione scura',
    '🏄🏻' => 'persona che fa surf: carnagione chiara',
    '🏄🏼' => 'persona che fa surf: carnagione abbastanza chiara',
    '🏄🏽' => 'persona che fa surf: carnagione olivastra',
    '🏄🏾' => 'persona che fa surf: carnagione abbastanza scura',
    '🏄🏿' => 'persona che fa surf: carnagione scura',
    '🚣🏻' => 'persona in barca a remi: carnagione chiara',
    '🚣🏼' => 'persona in barca a remi: carnagione abbastanza chiara',
    '🚣🏽' => 'persona in barca a remi: carnagione olivastra',
    '🚣🏾' => 'persona in barca a remi: carnagione abbastanza scura',
    '🚣🏿' => 'persona in barca a remi: carnagione scura',
    '🏊🏻' => 'persona che nuota: carnagione chiara',
    '🏊🏼' => 'persona che nuota: carnagione abbastanza chiara',
    '🏊🏽' => 'persona che nuota: carnagione olivastra',
    '🏊🏾' => 'persona che nuota: carnagione abbastanza scura',
    '🏊🏿' => 'persona che nuota: carnagione scura',
    '⛹🏻' => 'persona che fa rimbalzare una palla: carnagione chiara',
    '⛹🏼' => 'persona che fa rimbalzare una palla: carnagione abbastanza chiara',
    '⛹🏽' => 'persona che fa rimbalzare una palla: carnagione olivastra',
    '⛹🏾' => 'persona che fa rimbalzare una palla: carnagione abbastanza scura',
    '⛹🏿' => 'persona che fa rimbalzare una palla: carnagione scura',
    '🏋🏻' => 'persona che solleva pesi: carnagione chiara',
    '🏋🏼' => 'persona che solleva pesi: carnagione abbastanza chiara',
    '🏋🏽' => 'persona che solleva pesi: carnagione olivastra',
    '🏋🏾' => 'persona che solleva pesi: carnagione abbastanza scura',
    '🏋🏿' => 'persona che solleva pesi: carnagione scura',
    '🚴🏻' => 'ciclista: carnagione chiara',
    '🚴🏼' => 'ciclista: carnagione abbastanza chiara',
    '🚴🏽' => 'ciclista: carnagione olivastra',
    '🚴🏾' => 'ciclista: carnagione abbastanza scura',
    '🚴🏿' => 'ciclista: carnagione scura',
    '🚵🏻' => 'ciclista di mountain bike: carnagione chiara',
    '🚵🏼' => 'ciclista di mountain bike: carnagione abbastanza chiara',
    '🚵🏽' => 'ciclista di mountain bike: carnagione olivastra',
    '🚵🏾' => 'ciclista di mountain bike: carnagione abbastanza scura',
    '🚵🏿' => 'ciclista di mountain bike: carnagione scura',
    '🤸🏻' => 'persona che fa la ruota: carnagione chiara',
    '🤸🏼' => 'persona che fa la ruota: carnagione abbastanza chiara',
    '🤸🏽' => 'persona che fa la ruota: carnagione olivastra',
    '🤸🏾' => 'persona che fa la ruota: carnagione abbastanza scura',
    '🤸🏿' => 'persona che fa la ruota: carnagione scura',
    '🤼🏻' => 'persone che fanno la lotta: carnagione chiara',
    '🤼🏼' => 'persone che fanno la lotta: carnagione abbastanza chiara',
    '🤼🏽' => 'persone che fanno la lotta: carnagione olivastra',
    '🤼🏾' => 'persone che fanno la lotta: carnagione abbastanza scura',
    '🤼🏿' => 'persone che fanno la lotta: carnagione scura',
    '🤽🏻' => 'persona che gioca a pallanuoto: carnagione chiara',
    '🤽🏼' => 'persona che gioca a pallanuoto: carnagione abbastanza chiara',
    '🤽🏽' => 'persona che gioca a pallanuoto: carnagione olivastra',
    '🤽🏾' => 'persona che gioca a pallanuoto: carnagione abbastanza scura',
    '🤽🏿' => 'persona che gioca a pallanuoto: carnagione scura',
    '🤾🏻' => 'persona che gioca a pallamano: carnagione chiara',
    '🤾🏼' => 'persona che gioca a pallamano: carnagione abbastanza chiara',
    '🤾🏽' => 'persona che gioca a pallamano: carnagione olivastra',
    '🤾🏾' => 'persona che gioca a pallamano: carnagione abbastanza scura',
    '🤾🏿' => 'persona che gioca a pallamano: carnagione scura',
    '🤹🏻' => 'persona che fa giocoleria: carnagione chiara',
    '🤹🏼' => 'persona che fa giocoleria: carnagione abbastanza chiara',
    '🤹🏽' => 'persona che fa giocoleria: carnagione olivastra',
    '🤹🏾' => 'persona che fa giocoleria: carnagione abbastanza scura',
    '🤹🏿' => 'persona che fa giocoleria: carnagione scura',
    '🧘🏻' => 'persona in posizione del loto: carnagione chiara',
    '🧘🏼' => 'persona in posizione del loto: carnagione abbastanza chiara',
    '🧘🏽' => 'persona in posizione del loto: carnagione olivastra',
    '🧘🏾' => 'persona in posizione del loto: carnagione abbastanza scura',
    '🧘🏿' => 'persona in posizione del loto: carnagione scura',
    '🛀🏻' => 'persona che fa il bagno: carnagione chiara',
    '🛀🏼' => 'persona che fa il bagno: carnagione abbastanza chiara',
    '🛀🏽' => 'persona che fa il bagno: carnagione olivastra',
    '🛀🏾' => 'persona che fa il bagno: carnagione abbastanza scura',
    '🛀🏿' => 'persona che fa il bagno: carnagione scura',
    '🛌🏻' => 'persona a letto: carnagione chiara',
    '🛌🏼' => 'persona a letto: carnagione abbastanza chiara',
    '🛌🏽' => 'persona a letto: carnagione olivastra',
    '🛌🏾' => 'persona a letto: carnagione abbastanza scura',
    '🛌🏿' => 'persona a letto: carnagione scura',
    '👭🏻' => 'due donne che si tengono per mano: carnagione chiara',
    '👭🏼' => 'due donne che si tengono per mano: carnagione abbastanza chiara',
    '👭🏽' => 'due donne che si tengono per mano: carnagione olivastra',
    '👭🏾' => 'due donne che si tengono per mano: carnagione abbastanza scura',
    '👭🏿' => 'due donne che si tengono per mano: carnagione scura',
    '👫🏻' => 'uomo e donna che si tengono per mano: carnagione chiara',
    '👫🏼' => 'uomo e donna che si tengono per mano: carnagione abbastanza chiara',
    '👫🏽' => 'uomo e donna che si tengono per mano: carnagione olivastra',
    '👫🏾' => 'uomo e donna che si tengono per mano: carnagione abbastanza scura',
    '👫🏿' => 'uomo e donna che si tengono per mano: carnagione scura',
    '👬🏻' => 'due uomini che si tengono per mano: carnagione chiara',
    '👬🏼' => 'due uomini che si tengono per mano: carnagione abbastanza chiara',
    '👬🏽' => 'due uomini che si tengono per mano: carnagione olivastra',
    '👬🏾' => 'due uomini che si tengono per mano: carnagione abbastanza scura',
    '👬🏿' => 'due uomini che si tengono per mano: carnagione scura',
    '💏🏻' => 'bacio tra coppia: carnagione chiara',
    '💏🏼' => 'bacio tra coppia: carnagione abbastanza chiara',
    '💏🏽' => 'bacio tra coppia: carnagione olivastra',
    '💏🏾' => 'bacio tra coppia: carnagione abbastanza scura',
    '💏🏿' => 'bacio tra coppia: carnagione scura',
    '💑🏻' => 'coppia con cuore: carnagione chiara',
    '💑🏼' => 'coppia con cuore: carnagione abbastanza chiara',
    '💑🏽' => 'coppia con cuore: carnagione olivastra',
    '💑🏾' => 'coppia con cuore: carnagione abbastanza scura',
    '💑🏿' => 'coppia con cuore: carnagione scura',
    '🇦🇨' => 'bandiera: Isola Ascensione',
    '🇦🇩' => 'bandiera: Andorra',
    '🇦🇪' => 'bandiera: Emirati Arabi Uniti',
    '🇦🇫' => 'bandiera: Afghanistan',
    '🇦🇬' => 'bandiera: Antigua e Barbuda',
    '🇦🇮' => 'bandiera: Anguilla',
    '🇦🇱' => 'bandiera: Albania',
    '🇦🇲' => 'bandiera: Armenia',
    '🇦🇴' => 'bandiera: Angola',
    '🇦🇶' => 'bandiera: Antartide',
    '🇦🇷' => 'bandiera: Argentina',
    '🇦🇸' => 'bandiera: Samoa Americane',
    '🇦🇹' => 'bandiera: Austria',
    '🇦🇺' => 'bandiera: Australia',
    '🇦🇼' => 'bandiera: Aruba',
    '🇦🇽' => 'bandiera: Isole Åland',
    '🇦🇿' => 'bandiera: Azerbaigian',
    '🇧🇦' => 'bandiera: Bosnia ed Erzegovina',
    '🇧🇧' => 'bandiera: Barbados',
    '🇧🇩' => 'bandiera: Bangladesh',
    '🇧🇪' => 'bandiera: Belgio',
    '🇧🇫' => 'bandiera: Burkina Faso',
    '🇧🇬' => 'bandiera: Bulgaria',
    '🇧🇭' => 'bandiera: Bahrein',
    '🇧🇮' => 'bandiera: Burundi',
    '🇧🇯' => 'bandiera: Benin',
    '🇧🇱' => 'bandiera: Saint-Barthélemy',
    '🇧🇲' => 'bandiera: Bermuda',
    '🇧🇳' => 'bandiera: Brunei',
    '🇧🇴' => 'bandiera: Bolivia',
    '🇧🇶' => 'bandiera: Caraibi Olandesi',
    '🇧🇷' => 'bandiera: Brasile',
    '🇧🇸' => 'bandiera: Bahamas',
    '🇧🇹' => 'bandiera: Bhutan',
    '🇧🇻' => 'bandiera: Isola Bouvet',
    '🇧🇼' => 'bandiera: Botswana',
    '🇧🇾' => 'bandiera: Bielorussia',
    '🇧🇿' => 'bandiera: Belize',
    '🇨🇦' => 'bandiera: Canada',
    '🇨🇨' => 'bandiera: Isole Cocos (Keeling)',
    '🇨🇩' => 'bandiera: Congo - Kinshasa',
    '🇨🇫' => 'bandiera: Repubblica Centrafricana',
    '🇨🇬' => 'bandiera: Congo-Brazzaville',
    '🇨🇭' => 'bandiera: Svizzera',
    '🇨🇮' => 'bandiera: Costa d’Avorio',
    '🇨🇰' => 'bandiera: Isole Cook',
    '🇨🇱' => 'bandiera: Cile',
    '🇨🇲' => 'bandiera: Camerun',
    '🇨🇳' => 'bandiera: Cina',
    '🇨🇴' => 'bandiera: Colombia',
    '🇨🇵' => 'bandiera: Isola di Clipperton',
    '🇨🇶' => 'bandiera: Sark',
    '🇨🇷' => 'bandiera: Costa Rica',
    '🇨🇺' => 'bandiera: Cuba',
    '🇨🇻' => 'bandiera: Capo Verde',
    '🇨🇼' => 'bandiera: Curaçao',
    '🇨🇽' => 'bandiera: Isola Christmas',
    '🇨🇾' => 'bandiera: Cipro',
    '🇨🇿' => 'bandiera: Cechia',
    '🇩🇪' => 'bandiera: Germania',
    '🇩🇬' => 'bandiera: Diego Garcia',
    '🇩🇯' => 'bandiera: Gibuti',
    '🇩🇰' => 'bandiera: Danimarca',
    '🇩🇲' => 'bandiera: Dominica',
    '🇩🇴' => 'bandiera: Repubblica Dominicana',
    '🇩🇿' => 'bandiera: Algeria',
    '🇪🇦' => 'bandiera: Ceuta e Melilla',
    '🇪🇨' => 'bandiera: Ecuador',
    '🇪🇪' => 'bandiera: Estonia',
    '🇪🇬' => 'bandiera: Egitto',
    '🇪🇭' => 'bandiera: Sahara Occidentale',
    '🇪🇷' => 'bandiera: Eritrea',
    '🇪🇸' => 'bandiera: Spagna',
    '🇪🇹' => 'bandiera: Etiopia',
    '🇪🇺' => 'bandiera: Unione europea',
    '🇫🇮' => 'bandiera: Finlandia',
    '🇫🇯' => 'bandiera: Figi',
    '🇫🇰' => 'bandiera: Isole Falkland',
    '🇫🇲' => 'bandiera: Micronesia',
    '🇫🇴' => 'bandiera: Isole Fær Øer',
    '🇫🇷' => 'bandiera: Francia',
    '🇬🇦' => 'bandiera: Gabon',
    '🇬🇧' => 'bandiera: Regno Unito',
    '🇬🇩' => 'bandiera: Grenada',
    '🇬🇪' => 'bandiera: Georgia',
    '🇬🇫' => 'bandiera: Guyana Francese',
    '🇬🇬' => 'bandiera: Guernsey',
    '🇬🇭' => 'bandiera: Ghana',
    '🇬🇮' => 'bandiera: Gibilterra',
    '🇬🇱' => 'bandiera: Groenlandia',
    '🇬🇲' => 'bandiera: Gambia',
    '🇬🇳' => 'bandiera: Guinea',
    '🇬🇵' => 'bandiera: Guadalupa',
    '🇬🇶' => 'bandiera: Guinea Equatoriale',
    '🇬🇷' => 'bandiera: Grecia',
    '🇬🇸' => 'bandiera: Georgia del Sud e Sandwich Australi',
    '🇬🇹' => 'bandiera: Guatemala',
    '🇬🇺' => 'bandiera: Guam',
    '🇬🇼' => 'bandiera: Guinea-Bissau',
    '🇬🇾' => 'bandiera: Guyana',
    '🇭🇰' => 'bandiera: RAS di Hong Kong',
    '🇭🇲' => 'bandiera: Isole Heard e McDonald',
    '🇭🇳' => 'bandiera: Honduras',
    '🇭🇷' => 'bandiera: Croazia',
    '🇭🇹' => 'bandiera: Haiti',
    '🇭🇺' => 'bandiera: Ungheria',
    '🇮🇨' => 'bandiera: Isole Canarie',
    '🇮🇩' => 'bandiera: Indonesia',
    '🇮🇪' => 'bandiera: Irlanda',
    '🇮🇱' => 'bandiera: Israele',
    '🇮🇲' => 'bandiera: Isola di Man',
    '🇮🇳' => 'bandiera: India',
    '🇮🇴' => 'bandiera: Territorio Britannico dell’Oceano Indiano',
    '🇮🇶' => 'bandiera: Iraq',
    '🇮🇷' => 'bandiera: Iran',
    '🇮🇸' => 'bandiera: Islanda',
    '🇮🇹' => 'bandiera: Italia',
    '🇯🇪' => 'bandiera: Jersey',
    '🇯🇲' => 'bandiera: Giamaica',
    '🇯🇴' => 'bandiera: Giordania',
    '🇯🇵' => 'bandiera: Giappone',
    '🇰🇪' => 'bandiera: Kenya',
    '🇰🇬' => 'bandiera: Kirghizistan',
    '🇰🇭' => 'bandiera: Cambogia',
    '🇰🇮' => 'bandiera: Kiribati',
    '🇰🇲' => 'bandiera: Comore',
    '🇰🇳' => 'bandiera: Saint Kitts e Nevis',
    '🇰🇵' => 'bandiera: Corea del Nord',
    '🇰🇷' => 'bandiera: Corea del Sud',
    '🇰🇼' => 'bandiera: Kuwait',
    '🇰🇾' => 'bandiera: Isole Cayman',
    '🇰🇿' => 'bandiera: Kazakistan',
    '🇱🇦' => 'bandiera: Laos',
    '🇱🇧' => 'bandiera: Libano',
    '🇱🇨' => 'bandiera: Saint Lucia',
    '🇱🇮' => 'bandiera: Liechtenstein',
    '🇱🇰' => 'bandiera: Sri Lanka',
    '🇱🇷' => 'bandiera: Liberia',
    '🇱🇸' => 'bandiera: Lesotho',
    '🇱🇹' => 'bandiera: Lituania',
    '🇱🇺' => 'bandiera: Lussemburgo',
    '🇱🇻' => 'bandiera: Lettonia',
    '🇱🇾' => 'bandiera: Libia',
    '🇲🇦' => 'bandiera: Marocco',
    '🇲🇨' => 'bandiera: Monaco',
    '🇲🇩' => 'bandiera: Moldavia',
    '🇲🇪' => 'bandiera: Montenegro',
    '🇲🇫' => 'bandiera: Saint Martin',
    '🇲🇬' => 'bandiera: Madagascar',
    '🇲🇭' => 'bandiera: Isole Marshall',
    '🇲🇰' => 'bandiera: Macedonia del Nord',
    '🇲🇱' => 'bandiera: Mali',
    '🇲🇲' => 'bandiera: Myanmar (Birmania)',
    '🇲🇳' => 'bandiera: Mongolia',
    '🇲🇴' => 'bandiera: RAS di Macao',
    '🇲🇵' => 'bandiera: Isole Marianne Settentrionali',
    '🇲🇶' => 'bandiera: Martinica',
    '🇲🇷' => 'bandiera: Mauritania',
    '🇲🇸' => 'bandiera: Montserrat',
    '🇲🇹' => 'bandiera: Malta',
    '🇲🇺' => 'bandiera: Mauritius',
    '🇲🇻' => 'bandiera: Maldive',
    '🇲🇼' => 'bandiera: Malawi',
    '🇲🇽' => 'bandiera: Messico',
    '🇲🇾' => 'bandiera: Malaysia',
    '🇲🇿' => 'bandiera: Mozambico',
    '🇳🇦' => 'bandiera: Namibia',
    '🇳🇨' => 'bandiera: Nuova Caledonia',
    '🇳🇪' => 'bandiera: Niger',
    '🇳🇫' => 'bandiera: Isola Norfolk',
    '🇳🇬' => 'bandiera: Nigeria',
    '🇳🇮' => 'bandiera: Nicaragua',
    '🇳🇱' => 'bandiera: Paesi Bassi',
    '🇳🇴' => 'bandiera: Norvegia',
    '🇳🇵' => 'bandiera: Nepal',
    '🇳🇷' => 'bandiera: Nauru',
    '🇳🇺' => 'bandiera: Niue',
    '🇳🇿' => 'bandiera: Nuova Zelanda',
    '🇴🇲' => 'bandiera: Oman',
    '🇵🇦' => 'bandiera: Panama',
    '🇵🇪' => 'bandiera: Perù',
    '🇵🇫' => 'bandiera: Polinesia Francese',
    '🇵🇬' => 'bandiera: Papua Nuova Guinea',
    '🇵🇭' => 'bandiera: Filippine',
    '🇵🇰' => 'bandiera: Pakistan',
    '🇵🇱' => 'bandiera: Polonia',
    '🇵🇲' => 'bandiera: Saint-Pierre e Miquelon',
    '🇵🇳' => 'bandiera: Isole Pitcairn',
    '🇵🇷' => 'bandiera: Portorico',
    '🇵🇸' => 'bandiera: Territori Palestinesi',
    '🇵🇹' => 'bandiera: Portogallo',
    '🇵🇼' => 'bandiera: Palau',
    '🇵🇾' => 'bandiera: Paraguay',
    '🇶🇦' => 'bandiera: Qatar',
    '🇷🇪' => 'bandiera: Riunione',
    '🇷🇴' => 'bandiera: Romania',
    '🇷🇸' => 'bandiera: Serbia',
    '🇷🇺' => 'bandiera: Russia',
    '🇷🇼' => 'bandiera: Ruanda',
    '🇸🇦' => 'bandiera: Arabia Saudita',
    '🇸🇧' => 'bandiera: Isole Salomone',
    '🇸🇨' => 'bandiera: Seychelles',
    '🇸🇩' => 'bandiera: Sudan',
    '🇸🇪' => 'bandiera: Svezia',
    '🇸🇬' => 'bandiera: Singapore',
    '🇸🇭' => 'bandiera: Sant’Elena',
    '🇸🇮' => 'bandiera: Slovenia',
    '🇸🇯' => 'bandiera: Svalbard e Jan Mayen',
    '🇸🇰' => 'bandiera: Slovacchia',
    '🇸🇱' => 'bandiera: Sierra Leone',
    '🇸🇲' => 'bandiera: San Marino',
    '🇸🇳' => 'bandiera: Senegal',
    '🇸🇴' => 'bandiera: Somalia',
    '🇸🇷' => 'bandiera: Suriname',
    '🇸🇸' => 'bandiera: Sud Sudan',
    '🇸🇹' => 'bandiera: São Tomé e Príncipe',
    '🇸🇻' => 'bandiera: El Salvador',
    '🇸🇽' => 'bandiera: Sint Maarten',
    '🇸🇾' => 'bandiera: Siria',
    '🇸🇿' => 'bandiera: Eswatini',
    '🇹🇦' => 'bandiera: Tristan da Cunha',
    '🇹🇨' => 'bandiera: Isole Turks e Caicos',
    '🇹🇩' => 'bandiera: Ciad',
    '🇹🇫' => 'bandiera: Terre Australi Francesi',
    '🇹🇬' => 'bandiera: Togo',
    '🇹🇭' => 'bandiera: Thailandia',
    '🇹🇯' => 'bandiera: Tagikistan',
    '🇹🇰' => 'bandiera: Tokelau',
    '🇹🇱' => 'bandiera: Timor Est',
    '🇹🇲' => 'bandiera: Turkmenistan',
    '🇹🇳' => 'bandiera: Tunisia',
    '🇹🇴' => 'bandiera: Tonga',
    '🇹🇷' => 'bandiera: Turchia',
    '🇹🇹' => 'bandiera: Trinidad e Tobago',
    '🇹🇻' => 'bandiera: Tuvalu',
    '🇹🇼' => 'bandiera: Taiwan',
    '🇹🇿' => 'bandiera: Tanzania',
    '🇺🇦' => 'bandiera: Ucraina',
    '🇺🇬' => 'bandiera: Uganda',
    '🇺🇲' => 'bandiera: Isole Minori Esterne degli Stati Uniti',
    '🇺🇳' => 'bandiera: Nazioni Unite',
    '🇺🇸' => 'bandiera: Stati Uniti',
    '🇺🇾' => 'bandiera: Uruguay',
    '🇺🇿' => 'bandiera: Uzbekistan',
    '🇻🇦' => 'bandiera: Città del Vaticano',
    '🇻🇨' => 'bandiera: Saint Vincent e Grenadine',
    '🇻🇪' => 'bandiera: Venezuela',
    '🇻🇬' => 'bandiera: Isole Vergini Britanniche',
    '🇻🇮' => 'bandiera: Isole Vergini Americane',
    '🇻🇳' => 'bandiera: Vietnam',
    '🇻🇺' => 'bandiera: Vanuatu',
    '🇼🇫' => 'bandiera: Wallis e Futuna',
    '🇼🇸' => 'bandiera: Samoa',
    '🇽🇰' => 'bandiera: Kosovo',
    '🇾🇪' => 'bandiera: Yemen',
    '🇾🇹' => 'bandiera: Mayotte',
    '🇿🇦' => 'bandiera: Sudafrica',
    '🇿🇲' => 'bandiera: Zambia',
    '🇿🇼' => 'bandiera: Zimbabwe',
    '🔟' => 'tasto: 10',
    '🏻' => 'carnagione chiara',
    '🏼' => 'carnagione abbastanza chiara',
    '🏽' => 'carnagione olivastra',
    '🏾' => 'carnagione abbastanza scura',
    '🏿' => 'carnagione scura',
    '😀' => 'faccina con un gran sorriso',
    '😃' => 'faccina con sorriso e occhi spalancati',
    '😄' => 'faccina con sorriso e occhi sorridenti',
    '😁' => 'faccina raggiante con occhi felici',
    '😆' => 'sorriso a bocca aperta con occhi chiusi',
    '😅' => 'faccina con sorriso e goccia di sudore',
    '🤣' => 'ridere a crepapelle',
    '😂' => 'faccina con lacrime di gioia',
    '🙂' => 'faccina con sorriso accennato',
    '🙃' => 'faccina sottosopra',
    '🫠' => 'faccina che si scioglie',
    '😉' => 'faccina che fa l’occhiolino',
    '😊' => 'faccina con occhi sorridenti',
    '😇' => 'faccina con sorriso e aureola',
    '🥰' => 'faccina con cuoricini',
    '😍' => 'faccina con sorriso e occhi a cuore',
    '🤩' => 'colpo di fulmine',
    '😘' => 'faccina che manda un bacio',
    '😗' => 'faccina che bacia',
    '☺' => 'faccina sorridente',
    '😚' => 'faccina che bacia con occhi chiusi',
    '😙' => 'faccina che bacia con occhi sorridenti',
    '🥲' => 'faccina sorridente con lacrima',
    '😋' => 'faccina che si lecca i baffi',
    '😛' => 'faccina che mostra la lingua',
    '😜' => 'faccina che fa l’occhiolino e mostra la lingua',
    '🤪' => 'faccina impazzita',
    '😝' => 'faccina che strizza gli occhi e mostra la lingua',
    '🤑' => 'faccina avida di denaro',
    '🤗' => 'faccina che abbraccia',
    '🤭' => 'faccina con mano sulla bocca',
    '🫢' => 'faccina con occhi aperti e mano sulla bocca',
    '🫣' => 'faccina che sbircia tra le dita',
    '🤫' => 'faccina che zittisce',
    '🤔' => 'faccina concentrata',
    '🫡' => 'faccina che fa il saluto',
    '🤐' => 'faccina con bocca con cerniera',
    '🤨' => 'faccina con sopracciglia alzate',
    '😐' => 'faccina neutra',
    '😑' => 'faccina inespressiva',
    '😶' => 'faccina senza bocca',
    '🫥' => 'faccina tratteggiata',
    '😏' => 'faccina con sorrisetto',
    '😒' => 'faccina contrariata',
    '🙄' => 'faccina con occhi al cielo',
    '😬' => 'faccina con smorfia',
    '🤥' => 'faccina bugiarda',
    '🫨' => 'faccina tremante',
    '😌' => 'faccina sollevata',
    '😔' => 'faccina pensierosa',
    '😪' => 'faccina assonnata',
    '🤤' => 'faccina che sbava',
    '😴' => 'faccina che dorme',
    '🫩' => 'faccina con borse sotto gli occhi',
    '😷' => 'faccina con mascherina',
    '🤒' => 'faccina con termometro',
    '🤕' => 'faccina con la testa bendata',
    '🤢' => 'faccina nauseata',
    '🤮' => 'faccina che vomita',
    '🤧' => 'faccina che starnutisce',
    '🥵' => 'faccina accaldata',
    '🥶' => 'faccina congelata',
    '🥴' => 'faccina stordita',
    '😵' => 'faccina frastornata',
    '🤯' => 'testa che esplode',
    '🤠' => 'faccina con cappello da cowboy',
    '🥳' => 'faccina che festeggia',
    '🥸' => 'faccina travestita',
    '😎' => 'faccina con sorriso e occhiali da sole',
    '🤓' => 'faccina nerd',
    '🧐' => 'faccina con monocolo',
    '😕' => 'faccina confusa',
    '🫤' => 'faccina perplessa',
    '😟' => 'faccina preoccupata',
    '🙁' => 'faccina leggermente imbronciata',
    '☹' => 'faccina imbronciata',
    '😮' => 'faccina con bocca aperta',
    '😯' => 'faccina sorpresa',
    '😲' => 'faccina stupita',
    '😳' => 'faccina imbarazzata',
    '🫪' => 'faccina stravolta',
    '🥺' => 'faccina supplichevole',
    '🥹' => 'faccina che trattiene le lacrime',
    '😦' => 'faccina imbronciata con bocca aperta',
    '😧' => 'faccina angosciata',
    '😨' => 'faccina impaurita',
    '😰' => 'faccina sudata in ansia',
    '😥' => 'faccina delusa ma sollevata',
    '😢' => 'faccina che piange',
    '😭' => 'faccina disperata',
    '😱' => 'faccina terrorizzata',
    '😖' => 'faccina frustrata',
    '😣' => 'faccina perseverante',
    '😞' => 'faccina delusa',
    '😓' => 'faccina abbattuta sudata',
    '😩' => 'faccina esausta',
    '😫' => 'faccina stanca',
    '🥱' => 'faccina che sbadiglia',
    '😤' => 'faccina che sbuffa',
    '😡' => 'faccina accigliata',
    '😠' => 'faccina arrabbiata',
    '🤬' => 'faccina con simboli sulla bocca',
    '😈' => 'faccina con sorriso e corna',
    '👿' => 'faccina arrabbiata con corna',
    '💀' => 'teschio',
    '☠' => 'teschio con ossa incrociate',
    '💩' => 'cacca',
    '🤡' => 'faccina pagliaccio',
    '👹' => 'orco',
    '👺' => 'goblin',
    '👻' => 'fantasma',
    '👽' => 'alieno',
    '👾' => 'mostro alieno',
    '🤖' => 'faccina di robot',
    '😺' => 'gatto che sorride',
    '😸' => 'gatto che sogghigna',
    '😹' => 'gatto con lacrime di gioia',
    '😻' => 'gatto innamorato',
    '😼' => 'gatto con sorriso sarcastico',
    '😽' => 'gatto che manda baci',
    '🙀' => 'gatto esterrefatto',
    '😿' => 'gatto che piange',
    '😾' => 'gatto imbronciato',
    '🙈' => 'non vedo',
    '🙉' => 'non sento',
    '🙊' => 'non parlo',
    '💌' => 'lettera d’amore',
    '💘' => 'cuore con freccia',
    '💝' => 'cuore con fiocco',
    '💖' => 'cuore che luccica',
    '💗' => 'cuore che cresce',
    '💓' => 'cuore che batte',
    '💞' => 'cuori che girano',
    '💕' => 'due cuori',
    '💟' => 'decorazione con cuore',
    '❣' => 'punto esclamativo a cuore',
    '💔' => 'cuore infranto',
    '❤' => 'cuore rosso',
    '🩷' => 'cuore rosa',
    '🧡' => 'cuore arancione',
    '💛' => 'cuore giallo',
    '💚' => 'cuore verde',
    '💙' => 'cuore blu',
    '🩵' => 'cuore azzurro',
    '💜' => 'cuore viola',
    '🤎' => 'cuore marrone',
    '🖤' => 'cuore nero',
    '🩶' => 'cuore grigio',
    '🤍' => 'cuore bianco',
    '💋' => 'impronta della bocca',
    '💯' => '100 punti',
    '💢' => 'rabbia',
    '🫯' => 'nuvoletta di zuffa',
    '💥' => 'collisione',
    '💫' => 'stella con scia',
    '💦' => 'gocce di sudore',
    '💨' => 'nuvola di polvere',
    '🕳' => 'buco',
    '💬' => 'fumetto',
    '🗨' => 'fumetto a sinistra',
    '🗯' => 'nuvoletta rabbia',
    '💭' => 'nuvoletta',
    '💤' => 'sonno',
    '👋' => 'mano che saluta',
    '🤚' => 'dorso mano alzata',
    '🖐' => 'mano aperta',
    '✋' => 'mano alzata',
    '🖖' => 'saluto vulcaniano',
    '🫱' => 'mano rivolta a destra',
    '🫲' => 'mano rivolta a sinistra',
    '🫳' => 'mano con il palmo verso il basso',
    '🫴' => 'mano con il palmo verso l’alto',
    '🫷' => 'mano che spinge a sinistra',
    '🫸' => 'mano che spinge a destra',
    '👌' => 'mano che fa OK',
    '🤌' => 'mano a pigna',
    '🤏' => 'mano che fa il gesto del pizzico',
    '✌' => 'vittoria',
    '🤞' => 'dita incrociate',
    '🫰' => 'mano con indice e pollice incrociati',
    '🤟' => 'gesto ti amo',
    '🤘' => 'segno delle corna',
    '🤙' => 'mano con gesto di chiamata',
    '👈' => 'indice verso sinistra',
    '👉' => 'indice verso destra',
    '👆' => 'indice alzato',
    '🖕' => 'dito medio',
    '👇' => 'indice abbassato',
    '☝' => 'indice verso l’alto',
    '🫵' => 'indice verso l’osservatore',
    '👍' => 'pollice in su',
    '👎' => 'pollice verso',
    '✊' => 'pugno',
    '👊' => 'pugno chiuso',
    '🤛' => 'pugno a sinistra',
    '🤜' => 'pugno a destra',
    '👏' => 'mani che applaudono',
    '🙌' => 'mani alzate',
    '🫶' => 'mani a cuore',
    '👐' => 'mani aperte',
    '🤲' => 'mani unite in alto',
    '🤝' => 'stretta di mano',
    '🙏' => 'mani giunte',
    '✍' => 'mano che scrive',
    '💅' => 'smalto per unghie',
    '🤳' => 'selfie',
    '💪' => 'bicipite',
    '🦾' => 'protesi robotica per il braccio',
    '🦿' => 'protesi robotica per la gamba',
    '🦵' => 'gamba',
    '🦶' => 'piede',
    '👂' => 'orecchio',
    '🦻' => 'orecchio con apparecchio acustico',
    '👃' => 'naso',
    '🧠' => 'cervello',
    '🫀' => 'organo del cuore',
    '🫁' => 'polmoni',
    '🦷' => 'dente',
    '🦴' => 'osso',
    '👀' => 'occhi',
    '👁' => 'occhio',
    '👅' => 'lingua',
    '👄' => 'bocca',
    '🫦' => 'bocca che morde il labbro',
    '👶' => 'neonato',
    '🧒' => 'bimbo',
    '👦' => 'bambino',
    '👧' => 'bambina',
    '🧑' => 'persona',
    '👱' => 'persona bionda',
    '👨' => 'uomo',
    '🧔' => 'persona con la barba',
    '👩' => 'donna',
    '🧓' => 'persona anziana',
    '👴' => 'uomo anziano',
    '👵' => 'donna anziana',
    '🙍' => 'persona corrucciata',
    '🙎' => 'persona imbronciata',
    '🙅' => 'persona che fa segno di no',
    '🙆' => 'persona con gesto OK',
    '💁' => 'persona con mano capovolta',
    '🙋' => 'persona con mano alzata',
    '🧏' => 'persona con problemi di udito',
    '🙇' => 'persona che fa un inchino profondo',
    '🤦' => 'persona esasperata',
    '🤷' => 'persona che scrolla le spalle',
    '👮' => 'agente di polizia',
    '🕵' => 'detective',
    '💂' => 'guardia',
    '🥷' => 'ninja',
    '👷' => 'operaio edile',
    '🫅' => 'persona con corona',
    '🤴' => 'principe',
    '👸' => 'principessa',
    '👳' => 'persona con turbante',
    '👲' => 'uomo con zucchetto cinese',
    '🧕' => 'donna con velo',
    '🤵' => 'persona in smoking',
    '👰' => 'persona con velo',
    '🤰' => 'donna incinta',
    '🫃' => 'uomo incinto',
    '🫄' => 'persona incinta',
    '🤱' => 'allattare',
    '👼' => 'angioletto',
    '🎅' => 'Babbo Natale',
    '🤶' => 'Mamma Natale',
    '🦸' => 'supereroe',
    '🦹' => 'supercattivo',
    '🧙' => 'mago',
    '🧚' => 'fata',
    '🧛' => 'vampiro',
    '🧜' => 'sirena',
    '🧝' => 'elfo',
    '🧞' => 'genio',
    '🧟' => 'zombie',
    '🧌' => 'troll',
    '🫈' => 'creatura pelosa',
    '💆' => 'persona che riceve un massaggio',
    '💇' => 'taglio di capelli',
    '🚶' => 'pedone',
    '🧍' => 'persona in piedi',
    '🧎' => 'persona inginocchiata',
    '🏃' => 'persona che corre',
    '💃' => 'donna che balla',
    '🕺' => 'uomo che balla',
    '🕴' => 'uomo con completo che levita',
    '👯' => 'persone con orecchie da coniglio',
    '🧖' => 'persona in sauna',
    '🧗' => 'persona che scala',
    '🤺' => 'schermidore',
    '🏇' => 'ippica',
    '⛷' => 'sciatore',
    '🏂' => 'persona sullo snowboard',
    '🏌' => 'persona che gioca a golf',
    '🏄' => 'persona che fa surf',
    '🚣' => 'persona in barca a remi',
    '🏊' => 'persona che nuota',
    '⛹' => 'persona che fa rimbalzare una palla',
    '🏋' => 'persona che solleva pesi',
    '🚴' => 'ciclista',
    '🚵' => 'ciclista di mountain bike',
    '🤸' => 'persona che fa la ruota',
    '🤼' => 'persone che fanno la lotta',
    '🤽' => 'persona che gioca a pallanuoto',
    '🤾' => 'persona che gioca a pallamano',
    '🤹' => 'persona che fa giocoleria',
    '🧘' => 'persona in posizione del loto',
    '🛀' => 'persona che fa il bagno',
    '🛌' => 'persona a letto',
    '👭' => 'due donne che si tengono per mano',
    '👫' => 'uomo e donna che si tengono per mano',
    '👬' => 'due uomini che si tengono per mano',
    '💏' => 'bacio tra coppia',
    '💑' => 'coppia con cuore',
    '🗣' => 'persona che parla',
    '👤' => 'profilo di persona',
    '👥' => 'profilo di due persone',
    '🫂' => 'persone che si abbracciano',
    '👪' => 'famiglia',
    '👣' => 'impronta di piedi',
    '🫆' => 'impronta digitale',
    '🦰' => 'capelli rossi',
    '🦱' => 'capelli ricci',
    '🦳' => 'capelli bianchi',
    '🦲' => 'calvo',
    '🐵' => 'muso di scimmia',
    '🐒' => 'scimmia',
    '🦍' => 'gorilla',
    '🦧' => 'orangotango',
    '🐶' => 'muso di cane',
    '🐕' => 'cane',
    '🦮' => 'cane guida',
    '🐩' => 'barboncino',
    '🐺' => 'lupo',
    '🦊' => 'volpe',
    '🦝' => 'procione',
    '🐱' => 'muso di gatto',
    '🐈' => 'gatto',
    '🦁' => 'leone',
    '🐯' => 'muso di tigre',
    '🐅' => 'tigre',
    '🐆' => 'leopardo',
    '🐴' => 'muso di cavallo',
    '🫎' => 'alce',
    '🫏' => 'asino',
    '🐎' => 'cavallo',
    '🦄' => 'unicorno',
    '🦓' => 'zebra',
    '🦌' => 'cervo',
    '🦬' => 'bisonte',
    '🐮' => 'muso di mucca',
    '🐂' => 'bue',
    '🐃' => 'bufalo d’acqua',
    '🐄' => 'mucca',
    '🐷' => 'muso di maiale',
    '🐖' => 'maiale',
    '🐗' => 'cinghiale',
    '🐽' => 'naso da maiale',
    '🐏' => 'montone',
    '🐑' => 'pecora',
    '🐐' => 'capra',
    '🐪' => 'dromedario',
    '🐫' => 'cammello',
    '🦙' => 'lama',
    '🦒' => 'giraffa',
    '🐘' => 'elefante',
    '🦣' => 'mammut',
    '🦏' => 'rinoceronte',
    '🦛' => 'ippopotamo',
    '🐭' => 'muso di topo',
    '🐁' => 'topo',
    '🐀' => 'ratto',
    '🐹' => 'criceto',
    '🐰' => 'muso di coniglio',
    '🐇' => 'coniglio',
    '🐿' => 'scoiattolo',
    '🦫' => 'castoro',
    '🦔' => 'riccio',
    '🦇' => 'pipistrello',
    '🐻' => 'orso',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'bradipo',
    '🦦' => 'lontra',
    '🦨' => 'puzzola',
    '🦘' => 'canguro',
    '🦡' => 'tasso',
    '🐾' => 'impronte di zampe',
    '🦃' => 'tacchino',
    '🐔' => 'gallina',
    '🐓' => 'gallo',
    '🐣' => 'pulcino che nasce',
    '🐤' => 'pulcino',
    '🐥' => 'pulcino visto di fronte',
    '🐦' => 'uccello',
    '🐧' => 'pinguino',
    '🕊' => 'colomba',
    '🦅' => 'aquila',
    '🦆' => 'anatra',
    '🦢' => 'cigno',
    '🦉' => 'gufo',
    '🦤' => 'dodo',
    '🪶' => 'piuma',
    '🦩' => 'fenicottero',
    '🦚' => 'pavone',
    '🦜' => 'pappagallo',
    '🪽' => 'ala',
    '🪿' => 'oca',
    '🐸' => 'rana',
    '🐊' => 'coccodrillo',
    '🐢' => 'tartaruga',
    '🦎' => 'lucertola',
    '🐍' => 'serpente',
    '🐲' => 'testa di drago',
    '🐉' => 'drago',
    '🦕' => 'sauropode',
    '🦖' => 'T-Rex',
    '🐳' => 'balena che spruzza acqua',
    '🐋' => 'balena',
    '🐬' => 'delfino',
    '🫍' => 'orca',
    '🦭' => 'foca',
    '🐟' => 'pesce',
    '🐠' => 'pesce tropicale',
    '🐡' => 'pesce palla',
    '🦈' => 'squalo',
    '🐙' => 'polpo',
    '🐚' => 'conchiglia',
    '🪸' => 'corallo',
    '🪼' => 'medusa',
    '🦀' => 'granchio',
    '🦞' => 'aragosta',
    '🦐' => 'gamberetto',
    '🦑' => 'calamaro',
    '🦪' => 'ostrica',
    '🐌' => 'lumaca',
    '🦋' => 'farfalla',
    '🐛' => 'insetto',
    '🐜' => 'formica',
    '🐝' => 'ape',
    '🪲' => 'coleottero',
    '🐞' => 'coccinella',
    '🦗' => 'grillo',
    '🪳' => 'scarafaggio',
    '🕷' => 'ragno',
    '🕸' => 'ragnatela',
    '🦂' => 'scorpione',
    '🦟' => 'zanzara',
    '🪰' => 'mosca',
    '🪱' => 'verme',
    '🦠' => 'microbo',
    '💐' => 'mazzo di fiori',
    '🌸' => 'fiore di ciliegio',
    '💮' => 'fiore bianco',
    '🪷' => 'loto',
    '🏵' => 'rosetta',
    '🌹' => 'rosa',
    '🥀' => 'fiore appassito',
    '🌺' => 'ibisco',
    '🌻' => 'girasole',
    '🌼' => 'fiore',
    '🌷' => 'tulipano',
    '🪻' => 'giacinto',
    '🌱' => 'germoglio',
    '🪴' => 'pianta in vaso',
    '🌲' => 'albero sempreverde',
    '🌳' => 'albero deciduo',
    '🌴' => 'palma',
    '🌵' => 'cactus',
    '🌾' => 'pianta di riso',
    '🌿' => 'pianta',
    '☘' => 'trifoglio',
    '🍀' => 'quadrifoglio',
    '🍁' => 'foglia d’acero',
    '🍂' => 'foglia caduta',
    '🍃' => 'foglia al vento',
    '🪹' => 'nido vuoto',
    '🪺' => 'nido con uova',
    '🍄' => 'fungo',
    '🪾' => 'albero spoglio',
    '🍇' => 'uva',
    '🍈' => 'melone',
    '🍉' => 'anguria',
    '🍊' => 'mandarino',
    '🍋' => 'limone',
    '🍌' => 'banana',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'mela rossa',
    '🍏' => 'mela verde',
    '🍐' => 'pera',
    '🍑' => 'pesca',
    '🍒' => 'ciliegie',
    '🍓' => 'fragola',
    '🫐' => 'mirtilli',
    '🥝' => 'kiwi',
    '🍅' => 'pomodoro',
    '🫒' => 'oliva',
    '🥥' => 'cocco',
    '🥑' => 'avocado',
    '🍆' => 'melanzana',
    '🥔' => 'patata',
    '🥕' => 'carota',
    '🌽' => 'pannocchia',
    '🌶' => 'peperoncino',
    '🫑' => 'peperone',
    '🥒' => 'cetriolo',
    '🥬' => 'verdure a foglia',
    '🥦' => 'broccoli',
    '🧄' => 'aglio',
    '🧅' => 'cipolla',
    '🥜' => 'arachidi',
    '🫘' => 'fagioli',
    '🌰' => 'castagna',
    '🫚' => 'radice di zenzero',
    '🫛' => 'baccello di piselli',
    '🫜' => 'ortaggio da radice',
    '🍞' => 'pane in cassetta',
    '🥐' => 'croissant',
    '🥖' => 'baguette',
    '🫓' => 'focaccia',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'pancake',
    '🧇' => 'waffle',
    '🧀' => 'fetta di formaggio',
    '🍖' => 'carne',
    '🍗' => 'coscia di pollo',
    '🥩' => 'taglio di carne',
    '🥓' => 'pancetta',
    '🍔' => 'hamburger',
    '🍟' => 'patatine',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'sandwich',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'pita farcita',
    '🧆' => 'falafel',
    '🥚' => 'uovo',
    '🍳' => 'cucinare',
    '🥘' => 'padella con cibo',
    '🍲' => 'pentola di cibo',
    '🫕' => 'fonduta',
    '🥣' => 'ciotola con cucchiaio',
    '🥗' => 'insalata verde',
    '🍿' => 'popcorn',
    '🧈' => 'burro',
    '🧂' => 'sale',
    '🥫' => 'cibo in scatola',
    '🍱' => 'bento box',
    '🍘' => 'galletta di riso',
    '🍙' => 'onigiri',
    '🍚' => 'riso bollito',
    '🍛' => 'riso al curry',
    '🍜' => 'ciotola fumante',
    '🍝' => 'spaghetti',
    '🍠' => 'patata dolce arrosto',
    '🍢' => 'oden giapponese',
    '🍣' => 'sushi',
    '🍤' => 'gambero fritto',
    '🍥' => 'tortino di pesce a spirale',
    '🥮' => 'torta della luna',
    '🍡' => 'dango',
    '🥟' => 'raviolo',
    '🥠' => 'biscotto della fortuna',
    '🥡' => 'confezione da asporto',
    '🍦' => 'cono gelato',
    '🍧' => 'granita',
    '🍨' => 'coppa di gelato',
    '🍩' => 'ciambella',
    '🍪' => 'biscotto',
    '🎂' => 'torta di compleanno',
    '🍰' => 'fetta di torta',
    '🧁' => 'cupcake',
    '🥧' => 'torta',
    '🍫' => 'cioccolato',
    '🍬' => 'caramella',
    '🍭' => 'lecca lecca',
    '🍮' => 'budino',
    '🍯' => 'barattolo di miele',
    '🍼' => 'biberon',
    '🥛' => 'bicchiere di latte',
    '☕' => 'bevanda calda',
    '🫖' => 'teiera',
    '🍵' => 'tazza da tè senza manico',
    '🍶' => 'sakè',
    '🍾' => 'bottiglia stappata',
    '🍷' => 'bicchiere di vino',
    '🍸' => 'cocktail',
    '🍹' => 'cocktail tropicale',
    '🍺' => 'boccale di birra',
    '🍻' => 'boccali di birra',
    '🥂' => 'brindisi',
    '🥃' => 'bicchiere tumbler',
    '🫗' => 'liquido versato',
    '🥤' => 'bicchiere con cannuccia',
    '🧋' => 'bubble tea',
    '🧃' => 'bevanda monodose',
    '🧉' => 'mate',
    '🧊' => 'cubetto di ghiaccio',
    '🥢' => 'bacchette',
    '🍽' => 'piatto e posate',
    '🍴' => 'forchetta e coltello',
    '🥄' => 'cucchiaio',
    '🔪' => 'coltello da cucina',
    '🫙' => 'barattolo',
    '🏺' => 'anfora',
    '🌍' => 'Europa e Africa',
    '🌎' => 'America',
    '🌏' => 'Asia e Australia',
    '🌐' => 'globo con meridiani',
    '🗺' => 'mappa mondiale',
    '🗾' => 'mappa del Giappone',
    '🧭' => 'bussola',
    '🏔' => 'montagna innevata',
    '⛰' => 'montagna',
    '🛘' => 'frana',
    '🌋' => 'vulcano',
    '🗻' => 'Monte Fuji',
    '🏕' => 'campeggio',
    '🏖' => 'spiaggia con ombrellone',
    '🏜' => 'deserto',
    '🏝' => 'isola deserta',
    '🏞' => 'parco nazionale',
    '🏟' => 'stadio',
    '🏛' => 'edificio classico',
    '🏗' => 'edificio in costruzione',
    '🧱' => 'mattoni',
    '🪨' => 'roccia',
    '🪵' => 'legna',
    '🛖' => 'capanna',
    '🏘' => 'case',
    '🏚' => 'casa in rovina',
    '🏠' => 'casa',
    '🏡' => 'casa con giardino',
    '🏢' => 'edificio',
    '🏣' => 'ufficio postale giapponese',
    '🏤' => 'ufficio postale',
    '🏥' => 'ospedale',
    '🏦' => 'banca',
    '🏨' => 'hotel',
    '🏩' => 'love hotel',
    '🏪' => 'minimarket',
    '🏫' => 'scuola',
    '🏬' => 'grande magazzino',
    '🏭' => 'fabbrica',
    '🏯' => 'castello giapponese',
    '🏰' => 'castello',
    '💒' => 'chiesa per matrimonio',
    '🗼' => 'Torre di Tokyo',
    '🗽' => 'Statua della Libertà',
    '⛪' => 'chiesa',
    '🕌' => 'moschea',
    '🛕' => 'tempio indù',
    '🕍' => 'sinagoga',
    '⛩' => 'santuario shintoista',
    '🕋' => 'Kaaba',
    '⛲' => 'fontana',
    '⛺' => 'tenda',
    '🌁' => 'nebbioso',
    '🌃' => 'notte stellata',
    '🏙' => 'paesaggio urbano',
    '🌄' => 'alba sulle montagne',
    '🌅' => 'alba',
    '🌆' => 'città al tramonto',
    '🌇' => 'tramonto',
    '🌉' => 'ponte di notte',
    '♨' => 'sorgenti termali',
    '🎠' => 'cavallo da giostra',
    '🛝' => 'scivolo',
    '🎡' => 'ruota panoramica',
    '🎢' => 'montagne russe',
    '💈' => 'barbiere',
    '🎪' => 'circo',
    '🚂' => 'locomotiva',
    '🚃' => 'vagone',
    '🚄' => 'treno alta velocità',
    '🚅' => 'treno alta velocità punta arrotondata',
    '🚆' => 'treno',
    '🚇' => 'metropolitana',
    '🚈' => 'metrotranvia',
    '🚉' => 'stazione',
    '🚊' => 'tram',
    '🚝' => 'monorotaia',
    '🚞' => 'ferrovia di montagna',
    '🚋' => 'vagone del tram',
    '🚌' => 'bus',
    '🚍' => 'bus in arrivo',
    '🚎' => 'filobus',
    '🚐' => 'pulmino',
    '🚑' => 'ambulanza',
    '🚒' => 'camion dei pompieri',
    '🚓' => 'macchina della polizia',
    '🚔' => 'macchina della polizia in arrivo',
    '🚕' => 'taxi',
    '🚖' => 'taxi in arrivo',
    '🚗' => 'auto',
    '🚘' => 'auto in arrivo',
    '🚙' => 'SUV',
    '🛻' => 'pickup',
    '🚚' => 'camion',
    '🚛' => 'autoarticolato',
    '🚜' => 'trattore',
    '🏎' => 'auto da corsa',
    '🏍' => 'motocicletta',
    '🛵' => 'scooter',
    '🦽' => 'sedia a rotelle manuale',
    '🦼' => 'sedia a rotelle motorizzata',
    '🛺' => 'risciò a motore',
    '🚲' => 'bicicletta',
    '🛴' => 'monopattino',
    '🛹' => 'skateboard',
    '🛼' => 'pattini a rotelle',
    '🚏' => 'fermata dell’autobus',
    '🛣' => 'autostrada',
    '🛤' => 'binari',
    '🛢' => 'barile di petrolio',
    '⛽' => 'stazione di servizio',
    '🛞' => 'ruota',
    '🚨' => 'lampeggiante',
    '🚥' => 'semaforo orizzontale',
    '🚦' => 'semaforo verticale',
    '🛑' => 'segnale di stop',
    '🚧' => 'area cantiere',
    '⚓' => 'ancora',
    '🛟' => 'salvagente',
    '⛵' => 'barca a vela',
    '🛶' => 'canoa',
    '🚤' => 'motoscafo',
    '🛳' => 'nave da crociera',
    '⛴' => 'traghetto',
    '🛥' => 'barca a motore',
    '🚢' => 'nave',
    '✈' => 'aeroplano',
    '🛩' => 'aereo turistico',
    '🛫' => 'decollo',
    '🛬' => 'atterraggio',
    '🪂' => 'paracadute',
    '💺' => 'sedile',
    '🚁' => 'elicottero',
    '🚟' => 'ferrovia sospesa',
    '🚠' => 'funivia',
    '🚡' => 'funivia aerea',
    '🛰' => 'satellite',
    '🚀' => 'razzo',
    '🛸' => 'disco volante',
    '🛎' => 'campanello da hotel',
    '🧳' => 'valigia',
    '⌛' => 'clessidra',
    '⏳' => 'clessidra che scorre',
    '⌚' => 'orologio',
    '⏰' => 'sveglia',
    '⏱' => 'cronometro',
    '⏲' => 'timer',
    '🕰' => 'orologio da mensola',
    '🕛' => 'ore dodici',
    '🕧' => 'ore dodici e mezza',
    '🕐' => 'ore una',
    '🕜' => 'ore una e mezza',
    '🕑' => 'ore due',
    '🕝' => 'ore due e mezza',
    '🕒' => 'ore tre',
    '🕞' => 'ore tre e mezza',
    '🕓' => 'ore quattro',
    '🕟' => 'ore quattro e mezza',
    '🕔' => 'ore cinque',
    '🕠' => 'ore cinque e mezza',
    '🕕' => 'ore sei',
    '🕡' => 'ore sei e mezza',
    '🕖' => 'ore sette',
    '🕢' => 'ore sette e mezza',
    '🕗' => 'ore otto',
    '🕣' => 'ore otto e mezza',
    '🕘' => 'ore nove',
    '🕤' => 'ore nove e mezza',
    '🕙' => 'ore dieci',
    '🕥' => 'ore dieci e mezza',
    '🕚' => 'ore undici',
    '🕦' => 'ore undici e mezza',
    '🌑' => 'luna nuova',
    '🌒' => 'luna crescente',
    '🌓' => 'primo quarto di luna',
    '🌔' => 'luna gibbosa crescente',
    '🌕' => 'luna piena',
    '🌖' => 'luna gibbosa calante',
    '🌗' => 'ultimo quarto di luna',
    '🌘' => 'luna calante',
    '🌙' => 'spicchio di luna',
    '🌚' => 'faccina luna nuova',
    '🌛' => 'faccina primo quarto di luna',
    '🌜' => 'faccina ultimo quarto di luna',
    '🌡' => 'termometro',
    '☀' => 'sole',
    '🌝' => 'faccina luna piena',
    '🌞' => 'faccina sole',
    '🪐' => 'pianeta con satellite',
    '⭐' => 'stella',
    '🌟' => 'stella che brilla',
    '🌠' => 'stella cadente',
    '🌌' => 'Via Lattea',
    '☁' => 'nuvola',
    '⛅' => 'sole coperto',
    '⛈' => 'temporale',
    '🌤' => 'parzialmente nuvoloso',
    '🌥' => 'molto nuvoloso',
    '🌦' => 'sole coperto e pioggia',
    '🌧' => 'pioggia',
    '🌨' => 'neve',
    '🌩' => 'fulmini',
    '🌪' => 'tornado',
    '🌫' => 'nebbia',
    '🌬' => 'vento',
    '🌀' => 'ciclone',
    '🌈' => 'arcobaleno',
    '🌂' => 'ombrello chiuso',
    '☂' => 'ombrello',
    '☔' => 'ombrello con gocce di pioggia',
    '⛱' => 'ombrellone',
    '⚡' => 'alta tensione',
    '❄' => 'fiocco di neve',
    '☃' => 'pupazzo di neve',
    '⛄' => 'pupazzo di neve senza neve',
    '☄' => 'cometa',
    '🔥' => 'fuoco',
    '💧' => 'goccia',
    '🌊' => 'onda',
    '🎃' => 'zucca di Halloween',
    '🎄' => 'albero di Natale',
    '🎆' => 'fuochi d’artificio',
    '🎇' => 'stellina scintillante',
    '🧨' => 'petardo',
    '✨' => 'stelline',
    '🎈' => 'palloncino',
    '🎉' => 'spara coriandoli',
    '🎊' => 'coriandoli',
    '🎋' => 'albero di Tanabata',
    '🎍' => 'bambù decorato',
    '🎎' => 'bambole giapponesi',
    '🎏' => 'aquilone a forma di carpa',
    '🎐' => 'campana al vento',
    '🎑' => 'contemplazione della luna',
    '🧧' => 'busta hongbao',
    '🎀' => 'fiocco',
    '🎁' => 'regalo',
    '🎗' => 'nastro',
    '🎟' => 'biglietto d’ingresso',
    '🎫' => 'biglietto',
    '🎖' => 'medaglia militare',
    '🏆' => 'coppa',
    '🏅' => 'medaglia sportiva',
    '🥇' => 'medaglia d’oro',
    '🥈' => 'medaglia d’argento',
    '🥉' => 'medaglia di bronzo',
    '⚽' => 'pallone da calcio',
    '⚾' => 'palla da baseball',
    '🥎' => 'palla da softball',
    '🏀' => 'palla da pallacanestro',
    '🏐' => 'palla da pallavolo',
    '🏈' => 'football americano',
    '🏉' => 'pallone da rugby',
    '🎾' => 'tennis',
    '🥏' => 'frisbee',
    '🎳' => 'bowling',
    '🏏' => 'cricket',
    '🏑' => 'hockey su prato',
    '🏒' => 'hockey su ghiaccio',
    '🥍' => 'lacrosse',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'guantone da pugilato',
    '🥋' => 'kimono per arti marziali',
    '🥅' => 'porta da calcio',
    '⛳' => 'bandiera in buca',
    '⛸' => 'pattinaggio su ghiaccio',
    '🎣' => 'canna da pesca',
    '🤿' => 'maschera da sub',
    '🎽' => 'maglia da corsa',
    '🎿' => 'sci',
    '🛷' => 'slitta',
    '🥌' => 'stone da curling',
    '🎯' => 'bersaglio',
    '🪀' => 'yo-yo',
    '🪁' => 'aquilone',
    '🔫' => 'pistola ad acqua',
    '🎱' => 'palla da biliardo',
    '🔮' => 'sfera di cristallo',
    '🪄' => 'bacchetta magica',
    '🎮' => 'gamepad',
    '🕹' => 'joystick',
    '🎰' => 'slot machine',
    '🎲' => 'dado',
    '🧩' => 'pezzo di puzzle',
    '🧸' => 'orsetto',
    '🪅' => 'pentolaccia',
    '🪩' => 'palla da discoteca',
    '🪆' => 'matrioska',
    '♠' => 'picche',
    '♥' => 'cuori',
    '♦' => 'quadri',
    '♣' => 'fiori',
    '♟' => 'pedina degli scacchi',
    '🃏' => 'jolly',
    '🀄' => 'tessera Mahjong',
    '🎴' => 'carta da gioco Hanafuda',
    '🎭' => 'maschere',
    '🖼' => 'quadro incorniciato',
    '🎨' => 'tavolozza',
    '🧵' => 'filo',
    '🪡' => 'ago da cucito',
    '🧶' => 'gomitolo',
    '🪢' => 'nodo',
    '👓' => 'occhiali da vista',
    '🕶' => 'occhiali da sole',
    '🥽' => 'maschera',
    '🥼' => 'camice',
    '🦺' => 'gilet di sicurezza',
    '👔' => 'cravatta',
    '👕' => 't-shirt',
    '👖' => 'jeans',
    '🧣' => 'sciarpa',
    '🧤' => 'guanti',
    '🧥' => 'cappotto',
    '🧦' => 'calzini',
    '👗' => 'vestito',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'costume da bagno intero',
    '🩲' => 'slip',
    '🩳' => 'pantaloncini',
    '👙' => 'bikini',
    '👚' => 'maglietta da donna',
    '🪭' => 'ventaglio',
    '👛' => 'borsellino',
    '👜' => 'borsa',
    '👝' => 'pochette',
    '🛍' => 'borse della spesa',
    '🎒' => 'zaino',
    '🩴' => 'infradito',
    '👞' => 'scarpa da uomo',
    '👟' => 'scarpa sportiva',
    '🥾' => 'stivale da trekking',
    '🥿' => 'ballerina',
    '👠' => 'scarpa con il tacco',
    '👡' => 'sandalo da donna',
    '🩰' => 'scarpette da ballerina',
    '👢' => 'stivale da donna',
    '🪮' => 'pettine afro',
    '👑' => 'corona',
    '👒' => 'cappello da donna',
    '🎩' => 'cilindro',
    '🎓' => 'cappello da laureato',
    '🧢' => 'cappello con visiera',
    '🪖' => 'elmetto militare',
    '⛑' => 'elmetto con croce bianca',
    '📿' => 'collana da preghiera',
    '💄' => 'rossetto',
    '💍' => 'anello',
    '💎' => 'gemma',
    '🔇' => 'altoparlante disattivato',
    '🔈' => 'altoparlante a volume basso',
    '🔉' => 'altoparlante a volume intermedio',
    '🔊' => 'altoparlante a volume alto',
    '📢' => 'altoparlante',
    '📣' => 'megafono',
    '📯' => 'corno postale',
    '🔔' => 'campana',
    '🔕' => 'campana sbarrata',
    '🎼' => 'pentagramma',
    '🎵' => 'nota musicale',
    '🎶' => 'note musicali',
    '🎙' => 'microfono radiofonico',
    '🎚' => 'cursore del volume',
    '🎛' => 'manopole di controllo',
    '🎤' => 'microfono',
    '🎧' => 'cuffie',
    '📻' => 'radio',
    '🎷' => 'sassofono',
    '🎺' => 'tromba',
    '🪊' => 'trombone',
    '🪗' => 'fisarmonica',
    '🎸' => 'chitarra',
    '🎹' => 'piano',
    '🎻' => 'violino',
    '🪕' => 'banjo',
    '🥁' => 'tamburo',
    '🪘' => 'tamburo lungo',
    '🪇' => 'maracas',
    '🪈' => 'flauto',
    '🪉' => 'arpa',
    '📱' => 'telefono cellulare',
    '📲' => 'telefono cellulare con freccia',
    '☎' => 'telefono fisso',
    '📞' => 'cornetta',
    '📟' => 'cercapersone',
    '📠' => 'fax',
    '🔋' => 'batteria',
    '🪫' => 'batteria scarica',
    '🔌' => 'spina elettrica',
    '💻' => 'computer portatile',
    '🖥' => 'computer fisso',
    '🖨' => 'stampante',
    '⌨' => 'tastiera',
    '🖱' => 'mouse',
    '🖲' => 'trackball',
    '💽' => 'minidisc',
    '💾' => 'floppy disc',
    '💿' => 'disco ottico',
    '📀' => 'DVD',
    '🧮' => 'abaco',
    '🎥' => 'cinepresa',
    '🎞' => 'pellicola cinematografica',
    '📽' => 'proiettore cinematografico',
    '🎬' => 'ciak',
    '📺' => 'televisore',
    '📷' => 'fotocamera',
    '📸' => 'fotocamera con flash',
    '📹' => 'videocamera',
    '📼' => 'videocassetta',
    '🔍' => 'lente di ingrandimento rivolta a sinistra',
    '🔎' => 'lente di ingrandimento rivolta a destra',
    '🕯' => 'candela',
    '💡' => 'lampadina',
    '🔦' => 'torcia',
    '🏮' => 'lanterna rossa',
    '🪔' => 'diya',
    '📔' => 'quaderno con copertina decorata',
    '📕' => 'libro chiuso',
    '📖' => 'libro aperto',
    '📗' => 'libro verde',
    '📘' => 'libro blu',
    '📙' => 'libro arancione',
    '📚' => 'libri',
    '📓' => 'quaderno',
    '📒' => 'quaderno ad anelli',
    '📃' => 'pagina con piega',
    '📜' => 'pergamena',
    '📄' => 'pagina',
    '📰' => 'quotidiano',
    '🗞' => 'quotidiano arrotolato',
    '📑' => 'etichette segnalibro',
    '🔖' => 'segnalibro',
    '🏷' => 'etichetta',
    '🪙' => 'moneta',
    '💰' => 'sacco di soldi',
    '🪎' => 'forziere',
    '💴' => 'banconota Yen',
    '💵' => 'banconota Dollaro',
    '💶' => 'banconota Euro',
    '💷' => 'banconota Sterlina',
    '💸' => 'soldi con le ali',
    '💳' => 'carta di credito',
    '🧾' => 'scontrino',
    '💹' => 'grafico ascendente',
    '✉' => 'busta',
    '📧' => 'e-mail',
    '📨' => 'posta in arrivo',
    '📩' => 'posta in uscita',
    '📤' => 'posta inviata',
    '📥' => 'posta ricevuta',
    '📦' => 'pacco',
    '📫' => 'cassetta postale chiusa bandierina alzata',
    '📪' => 'cassetta postale chiusa bandierina abbassata',
    '📬' => 'cassetta postale aperta bandierina alzata',
    '📭' => 'cassetta postale aperta bandierina abbassata',
    '📮' => 'cassetta delle lettere',
    '🗳' => 'urna elettorale con scheda',
    '✏' => 'matita',
    '✒' => 'pennino',
    '🖋' => 'penna stilografica',
    '🖊' => 'penna a sfera',
    '🖌' => 'pennello',
    '🖍' => 'pastello a cera',
    '📝' => 'memo',
    '💼' => 'valigetta 24 ore',
    '📁' => 'cartella file',
    '📂' => 'cartella aperta',
    '🗂' => 'divisori per schedario',
    '📅' => 'calendario',
    '📆' => 'calendario a strappo',
    '🗒' => 'blocco per appunti con spirale',
    '🗓' => 'calendario a spirale',
    '📇' => 'schedario',
    '📈' => 'grafico con andamento positivo',
    '📉' => 'grafico con andamento negativo',
    '📊' => 'grafico a barre',
    '📋' => 'portablocco',
    '📌' => 'puntina',
    '📍' => 'puntina arrotondata',
    '📎' => 'graffetta',
    '🖇' => 'graffette attaccate',
    '📏' => 'righello',
    '📐' => 'squadra',
    '✂' => 'forbici',
    '🗃' => 'schedario da tavolo',
    '🗄' => 'schedario da ufficio',
    '🗑' => 'cestino',
    '🔒' => 'lucchetto chiuso',
    '🔓' => 'lucchetto aperto',
    '🔏' => 'lucchetto con penna stilo',
    '🔐' => 'lucchetto chiuso con chiave',
    '🔑' => 'chiave',
    '🗝' => 'chiave antica',
    '🔨' => 'martello',
    '🪓' => 'ascia',
    '⛏' => 'piccone',
    '⚒' => 'piccone e martello',
    '🛠' => 'martello e chiave inglese',
    '🗡' => 'pugnale',
    '⚔' => 'spade incrociate',
    '💣' => 'bomba',
    '🪃' => 'boomerang',
    '🏹' => 'arco e freccia',
    '🛡' => 'scudo',
    '🪚' => 'sega da falegname',
    '🔧' => 'chiave inglese',
    '🪛' => 'cacciavite',
    '🔩' => 'vite e bullone',
    '⚙' => 'ingranaggio',
    '🗜' => 'morsetto',
    '⚖' => 'bilancia a doppio piatto',
    '🦯' => 'bastone per non vedenti',
    '🔗' => 'collegamento',
    '⛓' => 'catene',
    '🪝' => 'gancio',
    '🧰' => 'cassetta degli attrezzi',
    '🧲' => 'calamita',
    '🪜' => 'scala',
    '🪏' => 'vanga',
    '⚗' => 'alambicco',
    '🧪' => 'provetta',
    '🧫' => 'piastra di Petri',
    '🧬' => 'dna',
    '🔬' => 'microscopio',
    '🔭' => 'telescopio',
    '📡' => 'antenna satellitare',
    '💉' => 'siringa',
    '🩸' => 'goccia di sangue',
    '💊' => 'pillola',
    '🩹' => 'cerotto',
    '🩼' => 'stampella',
    '🩺' => 'stetoscopio',
    '🩻' => 'radiografia',
    '🚪' => 'porta',
    '🛗' => 'ascensore',
    '🪞' => 'specchio',
    '🪟' => 'finestra',
    '🛏' => 'letto',
    '🛋' => 'divano e lampada',
    '🪑' => 'sedia',
    '🚽' => 'toilette',
    '🪠' => 'sturalavandini',
    '🚿' => 'doccia',
    '🛁' => 'vasca',
    '🪤' => 'trappola per topi',
    '🪒' => 'rasoio',
    '🧴' => 'flacone',
    '🧷' => 'spilla da balia',
    '🧹' => 'scopa',
    '🧺' => 'cesto',
    '🧻' => 'rotolo di carta igienica',
    '🪣' => 'secchio',
    '🧼' => 'sapone',
    '🫧' => 'bolle',
    '🪥' => 'spazzolino da denti',
    '🧽' => 'spugna',
    '🧯' => 'estintore',
    '🛒' => 'carrello',
    '🚬' => 'sigaretta',
    '⚰' => 'bara',
    '🪦' => 'lapide',
    '⚱' => 'urna funeraria',
    '🧿' => 'occhio di Allah',
    '🪬' => 'mano di Fatima',
    '🗿' => 'Moai',
    '🪧' => 'cartello',
    '🪪' => 'carta d’identità',
    '🏧' => 'simbolo dello sportello bancomat',
    '🚮' => 'simbolo per la raccolta dei rifiuti',
    '🚰' => 'acqua potabile',
    '♿' => 'simbolo della disabilità',
    '🚹' => 'simbolo del bagno degli uomini',
    '🚺' => 'simbolo del bagno delle donne',
    '🚻' => 'simbolo dei servizi igienici',
    '🚼' => 'simbolo con immagine di bambino',
    '🚾' => 'simbolo del WC',
    '🛂' => 'simbolo del controllo passaporti',
    '🛃' => 'simbolo della dogana',
    '🛄' => 'simbolo del ritiro bagagli',
    '🛅' => 'simbolo del deposito bagagli',
    '⚠' => 'simbolo di avviso',
    '🚸' => 'attraversamento bambini',
    '⛔' => 'segnale di divieto di accesso',
    '🚫' => 'segnale di divieto',
    '🚳' => 'segnale di divieto di transito delle biciclette',
    '🚭' => 'segnale di vietato fumare',
    '🚯' => 'simbolo del divieto di gettare rifiuti',
    '🚱' => 'simbolo di acqua non potabile',
    '🚷' => 'simbolo del divieto di transito pedoni',
    '📵' => 'simbolo che vieta l’uso dei cellulari',
    '🔞' => 'simbolo di divieto ai minorenni',
    '☢' => 'simbolo della radioattività',
    '☣' => 'simbolo del rischio biologico',
    '⬆' => 'freccia rivolta verso l’alto',
    '↗' => 'freccia rivolta verso destra che punta in alto',
    '➡' => 'freccia rivolta verso destra',
    '↘' => 'freccia in basso a destra',
    '⬇' => 'freccia rivolta verso il basso',
    '↙' => 'freccia in basso a sinistra',
    '⬅' => 'freccia rivolta a sinistra',
    '↖' => 'freccia in alto a sinistra',
    '↕' => 'freccia su-giù',
    '↔' => 'freccia sinistra-destra',
    '↩' => 'freccia curva a sinistra',
    '↪' => 'freccia curva a destra',
    '⤴' => 'freccia curva in alto',
    '⤵' => 'freccia curva in basso',
    '🔃' => 'frecce verticali che ruotano in senso orario',
    '🔄' => 'frecce che ruotano in senso antiorario',
    '🔙' => 'freccia BACK',
    '🔚' => 'freccia END',
    '🔛' => 'freccia ON',
    '🔜' => 'freccia SOON',
    '🔝' => 'freccia TOP',
    '🛐' => 'luogo di culto',
    '⚛' => 'simbolo dell’atomo',
    '🕉' => 'Om',
    '✡' => 'stella di David',
    '☸' => 'ruota del Dharma',
    '☯' => 'Yin e Yang',
    '✝' => 'croce latina',
    '☦' => 'croce ortodossa',
    '☪' => 'mezzaluna e stella',
    '☮' => 'simbolo della pace',
    '🕎' => 'Menorah',
    '🔯' => 'stella a sei punte',
    '🪯' => 'khanda',
    '♈' => 'Segno zodiacale dell’Ariete',
    '♉' => 'Segno zodiacale del Toro',
    '♊' => 'Segno zodiacale dei Gemelli',
    '♋' => 'Segno zodiacale del Cancro',
    '♌' => 'Segno zodiacale del Leone',
    '♍' => 'Segno zodiacale della Vergine',
    '♎' => 'Segno zodiacale della Bilancia',
    '♏' => 'Segno zodiacale dello Scorpione',
    '♐' => 'Segno zodiacale del Saggitario',
    '♑' => 'Segno zodiacale del Capricorno',
    '♒' => 'Segno zodiacale dell’Acquario',
    '♓' => 'Segno zodiacale dei Pesci',
    '⛎' => 'Segno zodiacale dell’Ofiuco',
    '🔀' => 'pulsante di riproduzione casuale',
    '🔁' => 'pulsante di ripetizione della riproduzione',
    '🔂' => 'pulsante di ripetizione della riproduzione di una traccia',
    '▶' => 'pulsante di riproduzione',
    '⏩' => 'pulsante di avanzamento rapido',
    '⏭' => 'traccia successiva',
    '⏯' => 'pulsante riproduci/pausa',
    '◀' => 'pulsante di riavvolgimento',
    '⏪' => 'pulsante di riavvolgimento rapido',
    '⏮' => 'pulsante traccia precedente',
    '🔼' => 'pulsante a triangolo rivolto verso l’alto',
    '⏫' => 'pulsante doppia freccia in alto',
    '🔽' => 'pulsante a triangolo rivolto verso il basso',
    '⏬' => 'doppia freccia in basso',
    '⏸' => 'pulsante pausa',
    '⏹' => 'pulsante stop',
    '⏺' => 'pulsante di registrazione',
    '⏏' => 'pulsante di espulsione',
    '🎦' => 'simbolo del cinema',
    '🔅' => 'luminosità bassa',
    '🔆' => 'luminosità elevata',
    '📶' => 'segnale cellulare',
    '🛜' => 'wireless',
    '📳' => 'modalità vibrazione',
    '📴' => 'cellulare spento',
    '♀' => 'simbolo genere femminile',
    '♂' => 'simbolo genere maschile',
    '⚧' => 'simbolo transgender',
    '✖' => 'moltiplicazione',
    '➕' => 'addizione',
    '➖' => 'sottrazione',
    '➗' => 'divisione',
    '🟰' => 'segno di uguaglianza',
    '♾' => 'simbolo dell’infinito',
    '‼' => 'doppio punto esclamativo',
    '⁉' => 'punto esclamativo e interrogativo',
    '❓' => 'punto interrogativo rosso',
    '❔' => 'punto interrogativo bianco',
    '❕' => 'punto esclamativo bianco',
    '❗' => 'punto esclamativo rosso',
    '〰' => 'trattino ondulato',
    '💱' => 'cambio valuta',
    '💲' => 'Dollaro',
    '⚕' => 'simbolo della medicina',
    '♻' => 'simbolo del riciclaggio',
    '⚜' => 'giglio araldico',
    '🔱' => 'tridente',
    '📛' => 'tesserino per nome',
    '🔰' => 'ideogramma giapponese di “Principiante”',
    '⭕' => 'cerchio rosso vuoto',
    '✅' => 'pulsante segno di spunta',
    '☑' => 'riquadro con spunta',
    '✔' => 'segno di spunta',
    '❌' => 'croce',
    '❎' => 'croce con quadrato',
    '➰' => 'occhiello',
    '➿' => 'doppio occhiello',
    '〽' => 'simbolo di alternanza delle parti',
    '✳' => 'asterisco',
    '✴' => 'stella stilizzata',
    '❇' => 'scintilla stilizzata',
    '™' => 'marchio',
    '🫟' => 'spruzzo',
    '🔠' => 'pulsante con lettere latine maiuscole',
    '🔡' => 'pulsante con lettere latine minuscole',
    '🔢' => 'pulsante con numeri',
    '🔣' => 'pulsante con simboli',
    '🔤' => 'pulsante con lettere latine',
    '🅰' => 'gruppo sanguigno A',
    '🆎' => 'gruppo sanguigno AB',
    '🅱' => 'gruppo sanguigno B',
    '🆑' => 'pulsante CL',
    '🆒' => 'pulsante COOL',
    '🆓' => 'pulsante FREE',
    'ℹ' => 'punto informazioni',
    '🆔' => 'pulsante ID',
    'Ⓜ' => 'pulsante M cerchiata',
    '🆕' => 'pulsante NEW',
    '🆖' => 'pulsante NG',
    '🅾' => 'gruppo sanguigno 0',
    '🆗' => 'pulsante OK',
    '🅿' => 'pulsante P',
    '🆘' => 'pulsante SOS',
    '🆙' => 'pulsante UP!',
    '🆚' => 'pulsante VS',
    '🈁' => 'ideogramma giapponese per “Qui”',
    '🈂' => 'ideogramma giapponese di “Costo del servizio”',
    '🈷' => 'ideogramma giapponese di “Importo mensile”',
    '🈶' => 'ideogramma giapponese di “A pagamento”',
    '🈯' => 'ideogramma giapponese di “Riservato”',
    '🉐' => 'ideogramma giapponese di “Occasione”',
    '🈹' => 'ideogramma giapponese di “Sconto”',
    '🈚' => 'ideogramma giapponese di “Gratis”',
    '🈲' => 'ideogramma giapponese di “Proibito”',
    '🉑' => 'ideogramma giapponese di “Accettabile”',
    '🈸' => 'ideogramma giapponese di “Candidatura”',
    '🈴' => 'ideogramma giapponese di “Voto di sufficienza”',
    '🈳' => 'ideogramma giapponese di “Posto libero”',
    '㊗' => 'ideogramma giapponese di “Congratulazioni”',
    '㊙' => 'ideogramma giapponese di “Segreto”',
    '🈺' => 'ideogramma giapponese di “Aperto al pubblico”',
    '🈵' => 'ideogramma giapponese di “Nessun posto libero”',
    '🔴' => 'cerchio rosso',
    '🟠' => 'cerchio arancione',
    '🟡' => 'cerchio giallo',
    '🟢' => 'cerchio verde',
    '🔵' => 'cerchio blu',
    '🟣' => 'cerchio viola',
    '🟤' => 'cerchio marrone',
    '⚫' => 'cerchio nero',
    '⚪' => 'cerchio bianco',
    '🟥' => 'quadrato rosso',
    '🟧' => 'quadrato arancione',
    '🟨' => 'quadrato giallo',
    '🟩' => 'quadrato verde',
    '🟦' => 'quadrato blu',
    '🟪' => 'quadrato viola',
    '🟫' => 'quadrato marrone',
    '⬛' => 'quadrato nero grande',
    '⬜' => 'quadrato bianco grande',
    '◼' => 'quadrato nero medio',
    '◻' => 'quadrato bianco medio',
    '◾' => 'quadrato nero medio-piccolo',
    '◽' => 'quadrato bianco medio-piccolo',
    '▪' => 'quadrato nero piccolo',
    '▫' => 'quadrato bianco piccolo',
    '🔶' => 'rombo arancione grande',
    '🔷' => 'rombo blu grande',
    '🔸' => 'rombo arancione piccolo',
    '🔹' => 'rombo blu piccolo',
    '🔺' => 'triangolo rosso con punta verso l’alto',
    '🔻' => 'triangolo rosso con punta verso il basso',
    '💠' => 'petalo di fiore',
    '🔘' => 'pulsante rotondo',
    '🔳' => 'tasto quadrato nero con bordo bianco',
    '🔲' => 'tasto quadrato bianco con bordo nero',
    '🏁' => 'bandiera a scacchi',
    '🚩' => 'bandierina rossa',
    '🎌' => 'bandiere del Giappone incrociate',
    '🏴' => 'bandiera nera',
    '🏳' => 'bandiera bianca',
];
