<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'bučinys: suaugusysis suaugusysis šviesios odos vidutinio gymio',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'bučinys: suaugusysis suaugusysis šviesios odos rusvos odos',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'bučinys: suaugusysis suaugusysis šviesios odos tamsios odos',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'bučinys: suaugusysis suaugusysis šviesios odos itin tamsios odos',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'bučinys: suaugusysis suaugusysis vidutinio gymio šviesios odos',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'bučinys: suaugusysis suaugusysis vidutinio gymio rusvos odos',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'bučinys: suaugusysis suaugusysis vidutinio gymio tamsios odos',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'bučinys: suaugusysis suaugusysis vidutinio gymio itin tamsios odos',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'bučinys: suaugusysis suaugusysis rusvos odos šviesios odos',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'bučinys: suaugusysis suaugusysis rusvos odos vidutinio gymio',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'bučinys: suaugusysis suaugusysis rusvos odos tamsios odos',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'bučinys: suaugusysis suaugusysis rusvos odos itin tamsios odos',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'bučinys: suaugusysis suaugusysis tamsios odos šviesios odos',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'bučinys: suaugusysis suaugusysis tamsios odos vidutinio gymio',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'bučinys: suaugusysis suaugusysis tamsios odos rusvos odos',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'bučinys: suaugusysis suaugusysis tamsios odos itin tamsios odos',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'bučinys: suaugusysis suaugusysis itin tamsios odos šviesios odos',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'bučinys: suaugusysis suaugusysis itin tamsios odos vidutinio gymio',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'bučinys: suaugusysis suaugusysis itin tamsios odos rusvos odos',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'bučinys: suaugusysis suaugusysis itin tamsios odos tamsios odos',
    '👨🏻‍❤‍💋‍👨🏻' => 'bučinys: vyras vyras šviesios odos',
    '👨🏻‍❤‍💋‍👨🏼' => 'bučinys: vyras vyras šviesios odos vidutinio gymio',
    '👨🏻‍❤‍💋‍👨🏽' => 'bučinys: vyras vyras šviesios odos rusvos odos',
    '👨🏻‍❤‍💋‍👨🏾' => 'bučinys: vyras vyras šviesios odos tamsios odos',
    '👨🏻‍❤‍💋‍👨🏿' => 'bučinys: vyras vyras šviesios odos itin tamsios odos',
    '👨🏼‍❤‍💋‍👨🏻' => 'bučinys: vyras vyras vidutinio gymio šviesios odos',
    '👨🏼‍❤‍💋‍👨🏼' => 'bučinys: vyras vyras vidutinio gymio',
    '👨🏼‍❤‍💋‍👨🏽' => 'bučinys: vyras vyras vidutinio gymio rusvos odos',
    '👨🏼‍❤‍💋‍👨🏾' => 'bučinys: vyras vyras vidutinio gymio tamsios odos',
    '👨🏼‍❤‍💋‍👨🏿' => 'bučinys: vyras vyras vidutinio gymio itin tamsios odos',
    '👨🏽‍❤‍💋‍👨🏻' => 'bučinys: vyras vyras rusvos odos šviesios odos',
    '👨🏽‍❤‍💋‍👨🏼' => 'bučinys: vyras vyras rusvos odos vidutinio gymio',
    '👨🏽‍❤‍💋‍👨🏽' => 'bučinys: vyras vyras rusvos odos',
    '👨🏽‍❤‍💋‍👨🏾' => 'bučinys: vyras vyras rusvos odos tamsios odos',
    '👨🏽‍❤‍💋‍👨🏿' => 'bučinys: vyras vyras rusvos odos itin tamsios odos',
    '👨🏾‍❤‍💋‍👨🏻' => 'bučinys: vyras vyras tamsios odos šviesios odos',
    '👨🏾‍❤‍💋‍👨🏼' => 'bučinys: vyras vyras tamsios odos vidutinio gymio',
    '👨🏾‍❤‍💋‍👨🏽' => 'bučinys: vyras vyras tamsios odos rusvos odos',
    '👨🏾‍❤‍💋‍👨🏾' => 'bučinys: vyras vyras tamsios odos',
    '👨🏾‍❤‍💋‍👨🏿' => 'bučinys: vyras vyras tamsios odos itin tamsios odos',
    '👨🏿‍❤‍💋‍👨🏻' => 'bučinys: vyras vyras itin tamsios odos šviesios odos',
    '👨🏿‍❤‍💋‍👨🏼' => 'bučinys: vyras vyras itin tamsios odos vidutinio gymio',
    '👨🏿‍❤‍💋‍👨🏽' => 'bučinys: vyras vyras itin tamsios odos rusvos odos',
    '👨🏿‍❤‍💋‍👨🏾' => 'bučinys: vyras vyras itin tamsios odos tamsios odos',
    '👨🏿‍❤‍💋‍👨🏿' => 'bučinys: vyras vyras itin tamsios odos',
    '👩🏻‍❤‍💋‍👨🏻' => 'bučinys: moteris vyras šviesios odos',
    '👩🏻‍❤‍💋‍👨🏼' => 'bučinys: moteris vyras šviesios odos vidutinio gymio',
    '👩🏻‍❤‍💋‍👨🏽' => 'bučinys: moteris vyras šviesios odos rusvos odos',
    '👩🏻‍❤‍💋‍👨🏾' => 'bučinys: moteris vyras šviesios odos tamsios odos',
    '👩🏻‍❤‍💋‍👨🏿' => 'bučinys: moteris vyras šviesios odos itin tamsios odos',
    '👩🏼‍❤‍💋‍👨🏻' => 'bučinys: moteris vyras vidutinio gymio šviesios odos',
    '👩🏼‍❤‍💋‍👨🏼' => 'bučinys: moteris vyras vidutinio gymio',
    '👩🏼‍❤‍💋‍👨🏽' => 'bučinys: moteris vyras vidutinio gymio rusvos odos',
    '👩🏼‍❤‍💋‍👨🏾' => 'bučinys: moteris vyras vidutinio gymio tamsios odos',
    '👩🏼‍❤‍💋‍👨🏿' => 'bučinys: moteris vyras vidutinio gymio itin tamsios odos',
    '👩🏽‍❤‍💋‍👨🏻' => 'bučinys: moteris vyras rusvos odos šviesios odos',
    '👩🏽‍❤‍💋‍👨🏼' => 'bučinys: moteris vyras rusvos odos vidutinio gymio',
    '👩🏽‍❤‍💋‍👨🏽' => 'bučinys: moteris vyras rusvos odos',
    '👩🏽‍❤‍💋‍👨🏾' => 'bučinys: moteris vyras rusvos odos tamsios odos',
    '👩🏽‍❤‍💋‍👨🏿' => 'bučinys: moteris vyras rusvos odos itin tamsios odos',
    '👩🏾‍❤‍💋‍👨🏻' => 'bučinys: moteris vyras tamsios odos šviesios odos',
    '👩🏾‍❤‍💋‍👨🏼' => 'bučinys: moteris vyras tamsios odos vidutinio gymio',
    '👩🏾‍❤‍💋‍👨🏽' => 'bučinys: moteris vyras tamsios odos rusvos odos',
    '👩🏾‍❤‍💋‍👨🏾' => 'bučinys: moteris vyras tamsios odos',
    '👩🏾‍❤‍💋‍👨🏿' => 'bučinys: moteris vyras tamsios odos itin tamsios odos',
    '👩🏿‍❤‍💋‍👨🏻' => 'bučinys: moteris vyras itin tamsios odos šviesios odos',
    '👩🏿‍❤‍💋‍👨🏼' => 'bučinys: moteris vyras itin tamsios odos vidutinio gymio',
    '👩🏿‍❤‍💋‍👨🏽' => 'bučinys: moteris vyras itin tamsios odos rusvos odos',
    '👩🏿‍❤‍💋‍👨🏾' => 'bučinys: moteris vyras itin tamsios odos tamsios odos',
    '👩🏿‍❤‍💋‍👨🏿' => 'bučinys: moteris vyras itin tamsios odos',
    '👩🏻‍❤‍💋‍👩🏻' => 'bučinys: moteris moteris šviesios odos',
    '👩🏻‍❤‍💋‍👩🏼' => 'bučinys: moteris moteris šviesios odos vidutinio gymio',
    '👩🏻‍❤‍💋‍👩🏽' => 'bučinys: moteris moteris šviesios odos rusvos odos',
    '👩🏻‍❤‍💋‍👩🏾' => 'bučinys: moteris moteris šviesios odos tamsios odos',
    '👩🏻‍❤‍💋‍👩🏿' => 'bučinys: moteris moteris šviesios odos itin tamsios odos',
    '👩🏼‍❤‍💋‍👩🏻' => 'bučinys: moteris moteris vidutinio gymio šviesios odos',
    '👩🏼‍❤‍💋‍👩🏼' => 'bučinys: moteris moteris vidutinio gymio',
    '👩🏼‍❤‍💋‍👩🏽' => 'bučinys: moteris moteris vidutinio gymio rusvos odos',
    '👩🏼‍❤‍💋‍👩🏾' => 'bučinys: moteris moteris vidutinio gymio tamsios odos',
    '👩🏼‍❤‍💋‍👩🏿' => 'bučinys: moteris moteris vidutinio gymio itin tamsios odos',
    '👩🏽‍❤‍💋‍👩🏻' => 'bučinys: moteris moteris rusvos odos šviesios odos',
    '👩🏽‍❤‍💋‍👩🏼' => 'bučinys: moteris moteris rusvos odos vidutinio gymio',
    '👩🏽‍❤‍💋‍👩🏽' => 'bučinys: moteris moteris rusvos odos',
    '👩🏽‍❤‍💋‍👩🏾' => 'bučinys: moteris moteris rusvos odos tamsios odos',
    '👩🏽‍❤‍💋‍👩🏿' => 'bučinys: moteris moteris rusvos odos itin tamsios odos',
    '👩🏾‍❤‍💋‍👩🏻' => 'bučinys: moteris moteris tamsios odos šviesios odos',
    '👩🏾‍❤‍💋‍👩🏼' => 'bučinys: moteris moteris tamsios odos vidutinio gymio',
    '👩🏾‍❤‍💋‍👩🏽' => 'bučinys: moteris moteris tamsios odos rusvos odos',
    '👩🏾‍❤‍💋‍👩🏾' => 'bučinys: moteris moteris tamsios odos',
    '👩🏾‍❤‍💋‍👩🏿' => 'bučinys: moteris moteris tamsios odos itin tamsios odos',
    '👩🏿‍❤‍💋‍👩🏻' => 'bučinys: moteris moteris itin tamsios odos šviesios odos',
    '👩🏿‍❤‍💋‍👩🏼' => 'bučinys: moteris moteris itin tamsios odos vidutinio gymio',
    '👩🏿‍❤‍💋‍👩🏽' => 'bučinys: moteris moteris itin tamsios odos rusvos odos',
    '👩🏿‍❤‍💋‍👩🏾' => 'bučinys: moteris moteris itin tamsios odos tamsios odos',
    '👩🏿‍❤‍💋‍👩🏿' => 'bučinys: moteris moteris itin tamsios odos',
    '🧑🏻‍🫯‍🧑🏼' => 'imtynininkai: šviesios odos vidutinio gymio',
    '🧑🏻‍🫯‍🧑🏽' => 'imtynininkai: šviesios odos rusvos odos',
    '🧑🏻‍🫯‍🧑🏾' => 'imtynininkai: šviesios odos tamsios odos',
    '🧑🏻‍🫯‍🧑🏿' => 'imtynininkai: šviesios odos itin tamsios odos',
    '🧑🏼‍🫯‍🧑🏻' => 'imtynininkai: vidutinio gymio šviesios odos',
    '🧑🏼‍🫯‍🧑🏽' => 'imtynininkai: vidutinio gymio rusvos odos',
    '🧑🏼‍🫯‍🧑🏾' => 'imtynininkai: vidutinio gymio tamsios odos',
    '🧑🏼‍🫯‍🧑🏿' => 'imtynininkai: vidutinio gymio itin tamsios odos',
    '🧑🏽‍🫯‍🧑🏻' => 'imtynininkai: rusvos odos šviesios odos',
    '🧑🏽‍🫯‍🧑🏼' => 'imtynininkai: rusvos odos vidutinio gymio',
    '🧑🏽‍🫯‍🧑🏾' => 'imtynininkai: rusvos odos tamsios odos',
    '🧑🏽‍🫯‍🧑🏿' => 'imtynininkai: rusvos odos itin tamsios odos',
    '🧑🏾‍🫯‍🧑🏻' => 'imtynininkai: tamsios odos šviesios odos',
    '🧑🏾‍🫯‍🧑🏼' => 'imtynininkai: tamsios odos vidutinio gymio',
    '🧑🏾‍🫯‍🧑🏽' => 'imtynininkai: tamsios odos rusvos odos',
    '🧑🏾‍🫯‍🧑🏿' => 'imtynininkai: tamsios odos itin tamsios odos',
    '🧑🏿‍🫯‍🧑🏻' => 'imtynininkai: itin tamsios odos šviesios odos',
    '🧑🏿‍🫯‍🧑🏼' => 'imtynininkai: itin tamsios odos vidutinio gymio',
    '🧑🏿‍🫯‍🧑🏽' => 'imtynininkai: itin tamsios odos rusvos odos',
    '🧑🏿‍🫯‍🧑🏾' => 'imtynininkai: itin tamsios odos tamsios odos',
    '🧑🏻‍❤‍🧑🏼' => 'pora su širdele: suaugusysis suaugusysis šviesios odos vidutinio gymio',
    '🧑🏻‍❤‍🧑🏽' => 'pora su širdele: suaugusysis suaugusysis šviesios odos rusvos odos',
    '🧑🏻‍❤‍🧑🏾' => 'pora su širdele: suaugusysis suaugusysis šviesios odos tamsios odos',
    '🧑🏻‍❤‍🧑🏿' => 'pora su širdele: suaugusysis suaugusysis šviesios odos itin tamsios odos',
    '🧑🏼‍❤‍🧑🏻' => 'pora su širdele: suaugusysis suaugusysis vidutinio gymio šviesios odos',
    '🧑🏼‍❤‍🧑🏽' => 'pora su širdele: suaugusysis suaugusysis vidutinio gymio rusvos odos',
    '🧑🏼‍❤‍🧑🏾' => 'pora su širdele: suaugusysis suaugusysis vidutinio gymio tamsios odos',
    '🧑🏼‍❤‍🧑🏿' => 'pora su širdele: suaugusysis suaugusysis vidutinio gymio itin tamsios odos',
    '🧑🏽‍❤‍🧑🏻' => 'pora su širdele: suaugusysis suaugusysis rusvos odos šviesios odos',
    '🧑🏽‍❤‍🧑🏼' => 'pora su širdele: suaugusysis suaugusysis rusvos odos vidutinio gymio',
    '🧑🏽‍❤‍🧑🏾' => 'pora su širdele: suaugusysis suaugusysis rusvos odos tamsios odos',
    '🧑🏽‍❤‍🧑🏿' => 'pora su širdele: suaugusysis suaugusysis rusvos odos itin tamsios odos',
    '🧑🏾‍❤‍🧑🏻' => 'pora su širdele: suaugusysis suaugusysis tamsios odos šviesios odos',
    '🧑🏾‍❤‍🧑🏼' => 'pora su širdele: suaugusysis suaugusysis tamsios odos vidutinio gymio',
    '🧑🏾‍❤‍🧑🏽' => 'pora su širdele: suaugusysis suaugusysis tamsios odos rusvos odos',
    '🧑🏾‍❤‍🧑🏿' => 'pora su širdele: suaugusysis suaugusysis tamsios odos itin tamsios odos',
    '🧑🏿‍❤‍🧑🏻' => 'pora su širdele: suaugusysis suaugusysis itin tamsios odos šviesios odos',
    '🧑🏿‍❤‍🧑🏼' => 'pora su širdele: suaugusysis suaugusysis itin tamsios odos vidutinio gymio',
    '🧑🏿‍❤‍🧑🏽' => 'pora su širdele: suaugusysis suaugusysis itin tamsios odos rusvos odos',
    '🧑🏿‍❤‍🧑🏾' => 'pora su širdele: suaugusysis suaugusysis itin tamsios odos tamsios odos',
    '🧑🏻‍🐰‍🧑🏼' => 'besilinksminančios moterys: šviesios odos vidutinio gymio',
    '🧑🏻‍🐰‍🧑🏽' => 'besilinksminančios moterys: šviesios odos rusvos odos',
    '🧑🏻‍🐰‍🧑🏾' => 'besilinksminančios moterys: šviesios odos tamsios odos',
    '🧑🏻‍🐰‍🧑🏿' => 'besilinksminančios moterys: šviesios odos itin tamsios odos',
    '🧑🏼‍🐰‍🧑🏻' => 'besilinksminančios moterys: vidutinio gymio šviesios odos',
    '🧑🏼‍🐰‍🧑🏽' => 'besilinksminančios moterys: vidutinio gymio rusvos odos',
    '🧑🏼‍🐰‍🧑🏾' => 'besilinksminančios moterys: vidutinio gymio tamsios odos',
    '🧑🏼‍🐰‍🧑🏿' => 'besilinksminančios moterys: vidutinio gymio itin tamsios odos',
    '🧑🏽‍🐰‍🧑🏻' => 'besilinksminančios moterys: rusvos odos šviesios odos',
    '🧑🏽‍🐰‍🧑🏼' => 'besilinksminančios moterys: rusvos odos vidutinio gymio',
    '🧑🏽‍🐰‍🧑🏾' => 'besilinksminančios moterys: rusvos odos tamsios odos',
    '🧑🏽‍🐰‍🧑🏿' => 'besilinksminančios moterys: rusvos odos itin tamsios odos',
    '🧑🏾‍🐰‍🧑🏻' => 'besilinksminančios moterys: tamsios odos šviesios odos',
    '🧑🏾‍🐰‍🧑🏼' => 'besilinksminančios moterys: tamsios odos vidutinio gymio',
    '🧑🏾‍🐰‍🧑🏽' => 'besilinksminančios moterys: tamsios odos rusvos odos',
    '🧑🏾‍🐰‍🧑🏿' => 'besilinksminančios moterys: tamsios odos itin tamsios odos',
    '🧑🏿‍🐰‍🧑🏻' => 'besilinksminančios moterys: itin tamsios odos šviesios odos',
    '🧑🏿‍🐰‍🧑🏼' => 'besilinksminančios moterys: itin tamsios odos vidutinio gymio',
    '🧑🏿‍🐰‍🧑🏽' => 'besilinksminančios moterys: itin tamsios odos rusvos odos',
    '🧑🏿‍🐰‍🧑🏾' => 'besilinksminančios moterys: itin tamsios odos tamsios odos',
    '👨🏻‍🫯‍👨🏼' => 'vyrų imtynės: šviesios odos vidutinio gymio',
    '👨🏻‍🫯‍👨🏽' => 'vyrų imtynės: šviesios odos rusvos odos',
    '👨🏻‍🫯‍👨🏾' => 'vyrų imtynės: šviesios odos tamsios odos',
    '👨🏻‍🫯‍👨🏿' => 'vyrų imtynės: šviesios odos itin tamsios odos',
    '👨🏼‍🫯‍👨🏻' => 'vyrų imtynės: vidutinio gymio šviesios odos',
    '👨🏼‍🫯‍👨🏽' => 'vyrų imtynės: vidutinio gymio rusvos odos',
    '👨🏼‍🫯‍👨🏾' => 'vyrų imtynės: vidutinio gymio tamsios odos',
    '👨🏼‍🫯‍👨🏿' => 'vyrų imtynės: vidutinio gymio itin tamsios odos',
    '👨🏽‍🫯‍👨🏻' => 'vyrų imtynės: rusvos odos šviesios odos',
    '👨🏽‍🫯‍👨🏼' => 'vyrų imtynės: rusvos odos vidutinio gymio',
    '👨🏽‍🫯‍👨🏾' => 'vyrų imtynės: rusvos odos tamsios odos',
    '👨🏽‍🫯‍👨🏿' => 'vyrų imtynės: rusvos odos itin tamsios odos',
    '👨🏾‍🫯‍👨🏻' => 'vyrų imtynės: tamsios odos šviesios odos',
    '👨🏾‍🫯‍👨🏼' => 'vyrų imtynės: tamsios odos vidutinio gymio',
    '👨🏾‍🫯‍👨🏽' => 'vyrų imtynės: tamsios odos rusvos odos',
    '👨🏾‍🫯‍👨🏿' => 'vyrų imtynės: tamsios odos itin tamsios odos',
    '👨🏿‍🫯‍👨🏻' => 'vyrų imtynės: itin tamsios odos šviesios odos',
    '👨🏿‍🫯‍👨🏼' => 'vyrų imtynės: itin tamsios odos vidutinio gymio',
    '👨🏿‍🫯‍👨🏽' => 'vyrų imtynės: itin tamsios odos rusvos odos',
    '👨🏿‍🫯‍👨🏾' => 'vyrų imtynės: itin tamsios odos tamsios odos',
    '👨🏻‍❤‍👨🏻' => 'pora su širdele: vyras vyras šviesios odos',
    '👨🏻‍❤‍👨🏼' => 'pora su širdele: vyras vyras šviesios odos vidutinio gymio',
    '👨🏻‍❤‍👨🏽' => 'pora su širdele: vyras vyras šviesios odos rusvos odos',
    '👨🏻‍❤‍👨🏾' => 'pora su širdele: vyras vyras šviesios odos tamsios odos',
    '👨🏻‍❤‍👨🏿' => 'pora su širdele: vyras vyras šviesios odos itin tamsios odos',
    '👨🏼‍❤‍👨🏻' => 'pora su širdele: vyras vyras vidutinio gymio šviesios odos',
    '👨🏼‍❤‍👨🏼' => 'pora su širdele: vyras vyras vidutinio gymio',
    '👨🏼‍❤‍👨🏽' => 'pora su širdele: vyras vyras vidutinio gymio rusvos odos',
    '👨🏼‍❤‍👨🏾' => 'pora su širdele: vyras vyras vidutinio gymio tamsios odos',
    '👨🏼‍❤‍👨🏿' => 'pora su širdele: vyras vyras vidutinio gymio itin tamsios odos',
    '👨🏽‍❤‍👨🏻' => 'pora su širdele: vyras vyras rusvos odos šviesios odos',
    '👨🏽‍❤‍👨🏼' => 'pora su širdele: vyras vyras rusvos odos vidutinio gymio',
    '👨🏽‍❤‍👨🏽' => 'pora su širdele: vyras vyras rusvos odos',
    '👨🏽‍❤‍👨🏾' => 'pora su širdele: vyras vyras rusvos odos tamsios odos',
    '👨🏽‍❤‍👨🏿' => 'pora su širdele: vyras vyras rusvos odos itin tamsios odos',
    '👨🏾‍❤‍👨🏻' => 'pora su širdele: vyras vyras tamsios odos šviesios odos',
    '👨🏾‍❤‍👨🏼' => 'pora su širdele: vyras vyras tamsios odos vidutinio gymio',
    '👨🏾‍❤‍👨🏽' => 'pora su širdele: vyras vyras tamsios odos rusvos odos',
    '👨🏾‍❤‍👨🏾' => 'pora su širdele: vyras vyras tamsios odos',
    '👨🏾‍❤‍👨🏿' => 'pora su širdele: vyras vyras tamsios odos itin tamsios odos',
    '👨🏿‍❤‍👨🏻' => 'pora su širdele: vyras vyras itin tamsios odos šviesios odos',
    '👨🏿‍❤‍👨🏼' => 'pora su širdele: vyras vyras itin tamsios odos vidutinio gymio',
    '👨🏿‍❤‍👨🏽' => 'pora su širdele: vyras vyras itin tamsios odos rusvos odos',
    '👨🏿‍❤‍👨🏾' => 'pora su širdele: vyras vyras itin tamsios odos tamsios odos',
    '👨🏿‍❤‍👨🏿' => 'pora su širdele: vyras vyras itin tamsios odos',
    '👨🏻‍🐰‍👨🏼' => 'vakarėlyje dalyvaujantys vyrai: šviesios odos vidutinio gymio',
    '👨🏻‍🐰‍👨🏽' => 'vakarėlyje dalyvaujantys vyrai: šviesios odos rusvos odos',
    '👨🏻‍🐰‍👨🏾' => 'vakarėlyje dalyvaujantys vyrai: šviesios odos tamsios odos',
    '👨🏻‍🐰‍👨🏿' => 'vakarėlyje dalyvaujantys vyrai: šviesios odos itin tamsios odos',
    '👨🏼‍🐰‍👨🏻' => 'vakarėlyje dalyvaujantys vyrai: vidutinio gymio šviesios odos',
    '👨🏼‍🐰‍👨🏽' => 'vakarėlyje dalyvaujantys vyrai: vidutinio gymio rusvos odos',
    '👨🏼‍🐰‍👨🏾' => 'vakarėlyje dalyvaujantys vyrai: vidutinio gymio tamsios odos',
    '👨🏼‍🐰‍👨🏿' => 'vakarėlyje dalyvaujantys vyrai: vidutinio gymio itin tamsios odos',
    '👨🏽‍🐰‍👨🏻' => 'vakarėlyje dalyvaujantys vyrai: rusvos odos šviesios odos',
    '👨🏽‍🐰‍👨🏼' => 'vakarėlyje dalyvaujantys vyrai: rusvos odos vidutinio gymio',
    '👨🏽‍🐰‍👨🏾' => 'vakarėlyje dalyvaujantys vyrai: rusvos odos tamsios odos',
    '👨🏽‍🐰‍👨🏿' => 'vakarėlyje dalyvaujantys vyrai: rusvos odos itin tamsios odos',
    '👨🏾‍🐰‍👨🏻' => 'vakarėlyje dalyvaujantys vyrai: tamsios odos šviesios odos',
    '👨🏾‍🐰‍👨🏼' => 'vakarėlyje dalyvaujantys vyrai: tamsios odos vidutinio gymio',
    '👨🏾‍🐰‍👨🏽' => 'vakarėlyje dalyvaujantys vyrai: tamsios odos rusvos odos',
    '👨🏾‍🐰‍👨🏿' => 'vakarėlyje dalyvaujantys vyrai: tamsios odos itin tamsios odos',
    '👨🏿‍🐰‍👨🏻' => 'vakarėlyje dalyvaujantys vyrai: itin tamsios odos šviesios odos',
    '👨🏿‍🐰‍👨🏼' => 'vakarėlyje dalyvaujantys vyrai: itin tamsios odos vidutinio gymio',
    '👨🏿‍🐰‍👨🏽' => 'vakarėlyje dalyvaujantys vyrai: itin tamsios odos rusvos odos',
    '👨🏿‍🐰‍👨🏾' => 'vakarėlyje dalyvaujantys vyrai: itin tamsios odos tamsios odos',
    '👩🏻‍🫯‍👩🏼' => 'moterų imtynės: šviesios odos vidutinio gymio',
    '👩🏻‍🫯‍👩🏽' => 'moterų imtynės: šviesios odos rusvos odos',
    '👩🏻‍🫯‍👩🏾' => 'moterų imtynės: šviesios odos tamsios odos',
    '👩🏻‍🫯‍👩🏿' => 'moterų imtynės: šviesios odos itin tamsios odos',
    '👩🏼‍🫯‍👩🏻' => 'moterų imtynės: vidutinio gymio šviesios odos',
    '👩🏼‍🫯‍👩🏽' => 'moterų imtynės: vidutinio gymio rusvos odos',
    '👩🏼‍🫯‍👩🏾' => 'moterų imtynės: vidutinio gymio tamsios odos',
    '👩🏼‍🫯‍👩🏿' => 'moterų imtynės: vidutinio gymio itin tamsios odos',
    '👩🏽‍🫯‍👩🏻' => 'moterų imtynės: rusvos odos šviesios odos',
    '👩🏽‍🫯‍👩🏼' => 'moterų imtynės: rusvos odos vidutinio gymio',
    '👩🏽‍🫯‍👩🏾' => 'moterų imtynės: rusvos odos tamsios odos',
    '👩🏽‍🫯‍👩🏿' => 'moterų imtynės: rusvos odos itin tamsios odos',
    '👩🏾‍🫯‍👩🏻' => 'moterų imtynės: tamsios odos šviesios odos',
    '👩🏾‍🫯‍👩🏼' => 'moterų imtynės: tamsios odos vidutinio gymio',
    '👩🏾‍🫯‍👩🏽' => 'moterų imtynės: tamsios odos rusvos odos',
    '👩🏾‍🫯‍👩🏿' => 'moterų imtynės: tamsios odos itin tamsios odos',
    '👩🏿‍🫯‍👩🏻' => 'moterų imtynės: itin tamsios odos šviesios odos',
    '👩🏿‍🫯‍👩🏼' => 'moterų imtynės: itin tamsios odos vidutinio gymio',
    '👩🏿‍🫯‍👩🏽' => 'moterų imtynės: itin tamsios odos rusvos odos',
    '👩🏿‍🫯‍👩🏾' => 'moterų imtynės: itin tamsios odos tamsios odos',
    '👩🏻‍❤‍👨🏻' => 'pora su širdele: moteris vyras šviesios odos',
    '👩🏻‍❤‍👨🏼' => 'pora su širdele: moteris vyras šviesios odos vidutinio gymio',
    '👩🏻‍❤‍👨🏽' => 'pora su širdele: moteris vyras šviesios odos rusvos odos',
    '👩🏻‍❤‍👨🏾' => 'pora su širdele: moteris vyras šviesios odos tamsios odos',
    '👩🏻‍❤‍👨🏿' => 'pora su širdele: moteris vyras šviesios odos itin tamsios odos',
    '👩🏼‍❤‍👨🏻' => 'pora su širdele: moteris vyras vidutinio gymio šviesios odos',
    '👩🏼‍❤‍👨🏼' => 'pora su širdele: moteris vyras vidutinio gymio',
    '👩🏼‍❤‍👨🏽' => 'pora su širdele: moteris vyras vidutinio gymio rusvos odos',
    '👩🏼‍❤‍👨🏾' => 'pora su širdele: moteris vyras vidutinio gymio tamsios odos',
    '👩🏼‍❤‍👨🏿' => 'pora su širdele: moteris vyras vidutinio gymio itin tamsios odos',
    '👩🏽‍❤‍👨🏻' => 'pora su širdele: moteris vyras rusvos odos šviesios odos',
    '👩🏽‍❤‍👨🏼' => 'pora su širdele: moteris vyras rusvos odos vidutinio gymio',
    '👩🏽‍❤‍👨🏽' => 'pora su širdele: moteris vyras rusvos odos',
    '👩🏽‍❤‍👨🏾' => 'pora su širdele: moteris vyras rusvos odos tamsios odos',
    '👩🏽‍❤‍👨🏿' => 'pora su širdele: moteris vyras rusvos odos itin tamsios odos',
    '👩🏾‍❤‍👨🏻' => 'pora su širdele: moteris vyras tamsios odos šviesios odos',
    '👩🏾‍❤‍👨🏼' => 'pora su širdele: moteris vyras tamsios odos vidutinio gymio',
    '👩🏾‍❤‍👨🏽' => 'pora su širdele: moteris vyras tamsios odos rusvos odos',
    '👩🏾‍❤‍👨🏾' => 'pora su širdele: moteris vyras tamsios odos',
    '👩🏾‍❤‍👨🏿' => 'pora su širdele: moteris vyras tamsios odos itin tamsios odos',
    '👩🏿‍❤‍👨🏻' => 'pora su širdele: moteris vyras itin tamsios odos šviesios odos',
    '👩🏿‍❤‍👨🏼' => 'pora su širdele: moteris vyras itin tamsios odos vidutinio gymio',
    '👩🏿‍❤‍👨🏽' => 'pora su širdele: moteris vyras itin tamsios odos rusvos odos',
    '👩🏿‍❤‍👨🏾' => 'pora su širdele: moteris vyras itin tamsios odos tamsios odos',
    '👩🏿‍❤‍👨🏿' => 'pora su širdele: moteris vyras itin tamsios odos',
    '👩🏻‍❤‍👩🏻' => 'pora su širdele: moteris moteris šviesios odos',
    '👩🏻‍❤‍👩🏼' => 'pora su širdele: moteris moteris šviesios odos vidutinio gymio',
    '👩🏻‍❤‍👩🏽' => 'pora su širdele: moteris moteris šviesios odos rusvos odos',
    '👩🏻‍❤‍👩🏾' => 'pora su širdele: moteris moteris šviesios odos tamsios odos',
    '👩🏻‍❤‍👩🏿' => 'pora su širdele: moteris moteris šviesios odos itin tamsios odos',
    '👩🏼‍❤‍👩🏻' => 'pora su širdele: moteris moteris vidutinio gymio šviesios odos',
    '👩🏼‍❤‍👩🏼' => 'pora su širdele: moteris moteris vidutinio gymio',
    '👩🏼‍❤‍👩🏽' => 'pora su širdele: moteris moteris vidutinio gymio rusvos odos',
    '👩🏼‍❤‍👩🏾' => 'pora su širdele: moteris moteris vidutinio gymio tamsios odos',
    '👩🏼‍❤‍👩🏿' => 'pora su širdele: moteris moteris vidutinio gymio itin tamsios odos',
    '👩🏽‍❤‍👩🏻' => 'pora su širdele: moteris moteris rusvos odos šviesios odos',
    '👩🏽‍❤‍👩🏼' => 'pora su širdele: moteris moteris rusvos odos vidutinio gymio',
    '👩🏽‍❤‍👩🏽' => 'pora su širdele: moteris moteris rusvos odos',
    '👩🏽‍❤‍👩🏾' => 'pora su širdele: moteris moteris rusvos odos tamsios odos',
    '👩🏽‍❤‍👩🏿' => 'pora su širdele: moteris moteris rusvos odos itin tamsios odos',
    '👩🏾‍❤‍👩🏻' => 'pora su širdele: moteris moteris tamsios odos šviesios odos',
    '👩🏾‍❤‍👩🏼' => 'pora su širdele: moteris moteris tamsios odos vidutinio gymio',
    '👩🏾‍❤‍👩🏽' => 'pora su širdele: moteris moteris tamsios odos rusvos odos',
    '👩🏾‍❤‍👩🏾' => 'pora su širdele: moteris moteris tamsios odos',
    '👩🏾‍❤‍👩🏿' => 'pora su širdele: moteris moteris tamsios odos itin tamsios odos',
    '👩🏿‍❤‍👩🏻' => 'pora su širdele: moteris moteris itin tamsios odos šviesios odos',
    '👩🏿‍❤‍👩🏼' => 'pora su širdele: moteris moteris itin tamsios odos vidutinio gymio',
    '👩🏿‍❤‍👩🏽' => 'pora su širdele: moteris moteris itin tamsios odos rusvos odos',
    '👩🏿‍❤‍👩🏾' => 'pora su širdele: moteris moteris itin tamsios odos tamsios odos',
    '👩🏿‍❤‍👩🏿' => 'pora su širdele: moteris moteris itin tamsios odos',
    '👩🏻‍🐰‍👩🏼' => 'vakarėlyje dalyvaujančios moterys: šviesios odos vidutinio gymio',
    '👩🏻‍🐰‍👩🏽' => 'vakarėlyje dalyvaujančios moterys: šviesios odos rusvos odos',
    '👩🏻‍🐰‍👩🏾' => 'vakarėlyje dalyvaujančios moterys: šviesios odos tamsios odos',
    '👩🏻‍🐰‍👩🏿' => 'vakarėlyje dalyvaujančios moterys: šviesios odos itin tamsios odos',
    '👩🏼‍🐰‍👩🏻' => 'vakarėlyje dalyvaujančios moterys: vidutinio gymio šviesios odos',
    '👩🏼‍🐰‍👩🏽' => 'vakarėlyje dalyvaujančios moterys: vidutinio gymio rusvos odos',
    '👩🏼‍🐰‍👩🏾' => 'vakarėlyje dalyvaujančios moterys: vidutinio gymio tamsios odos',
    '👩🏼‍🐰‍👩🏿' => 'vakarėlyje dalyvaujančios moterys: vidutinio gymio itin tamsios odos',
    '👩🏽‍🐰‍👩🏻' => 'vakarėlyje dalyvaujančios moterys: rusvos odos šviesios odos',
    '👩🏽‍🐰‍👩🏼' => 'vakarėlyje dalyvaujančios moterys: rusvos odos vidutinio gymio',
    '👩🏽‍🐰‍👩🏾' => 'vakarėlyje dalyvaujančios moterys: rusvos odos tamsios odos',
    '👩🏽‍🐰‍👩🏿' => 'vakarėlyje dalyvaujančios moterys: rusvos odos itin tamsios odos',
    '👩🏾‍🐰‍👩🏻' => 'vakarėlyje dalyvaujančios moterys: tamsios odos šviesios odos',
    '👩🏾‍🐰‍👩🏼' => 'vakarėlyje dalyvaujančios moterys: tamsios odos vidutinio gymio',
    '👩🏾‍🐰‍👩🏽' => 'vakarėlyje dalyvaujančios moterys: tamsios odos rusvos odos',
    '👩🏾‍🐰‍👩🏿' => 'vakarėlyje dalyvaujančios moterys: tamsios odos itin tamsios odos',
    '👩🏿‍🐰‍👩🏻' => 'vakarėlyje dalyvaujančios moterys: itin tamsios odos šviesios odos',
    '👩🏿‍🐰‍👩🏼' => 'vakarėlyje dalyvaujančios moterys: itin tamsios odos vidutinio gymio',
    '👩🏿‍🐰‍👩🏽' => 'vakarėlyje dalyvaujančios moterys: itin tamsios odos rusvos odos',
    '👩🏿‍🐰‍👩🏾' => 'vakarėlyje dalyvaujančios moterys: itin tamsios odos tamsios odos',
    '🧑🏻‍🤝‍🧑🏻' => 'rankomis susikibę žmonės: šviesios odos',
    '🧑🏻‍🤝‍🧑🏼' => 'rankomis susikibę žmonės: šviesios odos vidutinio gymio',
    '🧑🏻‍🤝‍🧑🏽' => 'rankomis susikibę žmonės: šviesios odos rusvos odos',
    '🧑🏻‍🤝‍🧑🏾' => 'rankomis susikibę žmonės: šviesios odos tamsios odos',
    '🧑🏻‍🤝‍🧑🏿' => 'rankomis susikibę žmonės: šviesios odos itin tamsios odos',
    '🧑🏼‍🤝‍🧑🏻' => 'rankomis susikibę žmonės: vidutinio gymio šviesios odos',
    '🧑🏼‍🤝‍🧑🏼' => 'rankomis susikibę žmonės: vidutinio gymio',
    '🧑🏼‍🤝‍🧑🏽' => 'rankomis susikibę žmonės: vidutinio gymio rusvos odos',
    '🧑🏼‍🤝‍🧑🏾' => 'rankomis susikibę žmonės: vidutinio gymio tamsios odos',
    '🧑🏼‍🤝‍🧑🏿' => 'rankomis susikibę žmonės: vidutinio gymio itin tamsios odos',
    '🧑🏽‍🤝‍🧑🏻' => 'rankomis susikibę žmonės: rusvos odos šviesios odos',
    '🧑🏽‍🤝‍🧑🏼' => 'rankomis susikibę žmonės: rusvos odos vidutinio gymio',
    '🧑🏽‍🤝‍🧑🏽' => 'rankomis susikibę žmonės: rusvos odos',
    '🧑🏽‍🤝‍🧑🏾' => 'rankomis susikibę žmonės: rusvos odos tamsios odos',
    '🧑🏽‍🤝‍🧑🏿' => 'rankomis susikibę žmonės: rusvos odos itin tamsios odos',
    '🧑🏾‍🤝‍🧑🏻' => 'rankomis susikibę žmonės: tamsios odos šviesios odos',
    '🧑🏾‍🤝‍🧑🏼' => 'rankomis susikibę žmonės: tamsios odos vidutinio gymio',
    '🧑🏾‍🤝‍🧑🏽' => 'rankomis susikibę žmonės: tamsios odos rusvos odos',
    '🧑🏾‍🤝‍🧑🏾' => 'rankomis susikibę žmonės: tamsios odos',
    '🧑🏾‍🤝‍🧑🏿' => 'rankomis susikibę žmonės: tamsios odos itin tamsios odos',
    '🧑🏿‍🤝‍🧑🏻' => 'rankomis susikibę žmonės: itin tamsios odos šviesios odos',
    '🧑🏿‍🤝‍🧑🏼' => 'rankomis susikibę žmonės: itin tamsios odos vidutinio gymio',
    '🧑🏿‍🤝‍🧑🏽' => 'rankomis susikibę žmonės: itin tamsios odos rusvos odos',
    '🧑🏿‍🤝‍🧑🏾' => 'rankomis susikibę žmonės: itin tamsios odos tamsios odos',
    '🧑🏿‍🤝‍🧑🏿' => 'rankomis susikibę žmonės: itin tamsios odos',
    '👩🏻‍🤝‍👩🏼' => 'dvi moterys, susikibusios už rankų: šviesios odos vidutinio gymio',
    '👩🏻‍🤝‍👩🏽' => 'dvi moterys, susikibusios už rankų: šviesios odos rusvos odos',
    '👩🏻‍🤝‍👩🏾' => 'dvi moterys, susikibusios už rankų: šviesios odos tamsios odos',
    '👩🏻‍🤝‍👩🏿' => 'dvi moterys, susikibusios už rankų: šviesios odos itin tamsios odos',
    '👩🏼‍🤝‍👩🏻' => 'dvi moterys, susikibusios už rankų: vidutinio gymio šviesios odos',
    '👩🏼‍🤝‍👩🏽' => 'dvi moterys, susikibusios už rankų: vidutinio gymio rusvos odos',
    '👩🏼‍🤝‍👩🏾' => 'dvi moterys, susikibusios už rankų: vidutinio gymio tamsios odos',
    '👩🏼‍🤝‍👩🏿' => 'dvi moterys, susikibusios už rankų: vidutinio gymio itin tamsios odos',
    '👩🏽‍🤝‍👩🏻' => 'dvi moterys, susikibusios už rankų: rusvos odos šviesios odos',
    '👩🏽‍🤝‍👩🏼' => 'dvi moterys, susikibusios už rankų: rusvos odos vidutinio gymio',
    '👩🏽‍🤝‍👩🏾' => 'dvi moterys, susikibusios už rankų: rusvos odos tamsios odos',
    '👩🏽‍🤝‍👩🏿' => 'dvi moterys, susikibusios už rankų: rusvos odos itin tamsios odos',
    '👩🏾‍🤝‍👩🏻' => 'dvi moterys, susikibusios už rankų: tamsios odos šviesios odos',
    '👩🏾‍🤝‍👩🏼' => 'dvi moterys, susikibusios už rankų: tamsios odos vidutinio gymio',
    '👩🏾‍🤝‍👩🏽' => 'dvi moterys, susikibusios už rankų: tamsios odos rusvos odos',
    '👩🏾‍🤝‍👩🏿' => 'dvi moterys, susikibusios už rankų: tamsios odos itin tamsios odos',
    '👩🏿‍🤝‍👩🏻' => 'dvi moterys, susikibusios už rankų: itin tamsios odos šviesios odos',
    '👩🏿‍🤝‍👩🏼' => 'dvi moterys, susikibusios už rankų: itin tamsios odos vidutinio gymio',
    '👩🏿‍🤝‍👩🏽' => 'dvi moterys, susikibusios už rankų: itin tamsios odos rusvos odos',
    '👩🏿‍🤝‍👩🏾' => 'dvi moterys, susikibusios už rankų: itin tamsios odos tamsios odos',
    '👩🏻‍🤝‍👨🏼' => 'vyras ir moteris, susikibę už rankų: šviesios odos vidutinio gymio',
    '👩🏻‍🤝‍👨🏽' => 'vyras ir moteris, susikibę už rankų: šviesios odos rusvos odos',
    '👩🏻‍🤝‍👨🏾' => 'vyras ir moteris, susikibę už rankų: šviesios odos tamsios odos',
    '👩🏻‍🤝‍👨🏿' => 'vyras ir moteris, susikibę už rankų: šviesios odos itin tamsios odos',
    '👩🏼‍🤝‍👨🏻' => 'vyras ir moteris, susikibę už rankų: vidutinio gymio šviesios odos',
    '👩🏼‍🤝‍👨🏽' => 'vyras ir moteris, susikibę už rankų: vidutinio gymio rusvos odos',
    '👩🏼‍🤝‍👨🏾' => 'vyras ir moteris, susikibę už rankų: vidutinio gymio tamsios odos',
    '👩🏼‍🤝‍👨🏿' => 'vyras ir moteris, susikibę už rankų: vidutinio gymio itin tamsios odos',
    '👩🏽‍🤝‍👨🏻' => 'vyras ir moteris, susikibę už rankų: rusvos odos šviesios odos',
    '👩🏽‍🤝‍👨🏼' => 'vyras ir moteris, susikibę už rankų: rusvos odos vidutinio gymio',
    '👩🏽‍🤝‍👨🏾' => 'vyras ir moteris, susikibę už rankų: rusvos odos tamsios odos',
    '👩🏽‍🤝‍👨🏿' => 'vyras ir moteris, susikibę už rankų: rusvos odos itin tamsios odos',
    '👩🏾‍🤝‍👨🏻' => 'vyras ir moteris, susikibę už rankų: tamsios odos šviesios odos',
    '👩🏾‍🤝‍👨🏼' => 'vyras ir moteris, susikibę už rankų: tamsios odos vidutinio gymio',
    '👩🏾‍🤝‍👨🏽' => 'vyras ir moteris, susikibę už rankų: tamsios odos rusvos odos',
    '👩🏾‍🤝‍👨🏿' => 'vyras ir moteris, susikibę už rankų: tamsios odos itin tamsios odos',
    '👩🏿‍🤝‍👨🏻' => 'vyras ir moteris, susikibę už rankų: itin tamsios odos šviesios odos',
    '👩🏿‍🤝‍👨🏼' => 'vyras ir moteris, susikibę už rankų: itin tamsios odos vidutinio gymio',
    '👩🏿‍🤝‍👨🏽' => 'vyras ir moteris, susikibę už rankų: itin tamsios odos rusvos odos',
    '👩🏿‍🤝‍👨🏾' => 'vyras ir moteris, susikibę už rankų: itin tamsios odos tamsios odos',
    '👨🏻‍🤝‍👨🏼' => 'du vyrai, susikibę už rankų: šviesios odos vidutinio gymio',
    '👨🏻‍🤝‍👨🏽' => 'du vyrai, susikibę už rankų: šviesios odos rusvos odos',
    '👨🏻‍🤝‍👨🏾' => 'du vyrai, susikibę už rankų: šviesios odos tamsios odos',
    '👨🏻‍🤝‍👨🏿' => 'du vyrai, susikibę už rankų: šviesios odos itin tamsios odos',
    '👨🏼‍🤝‍👨🏻' => 'du vyrai, susikibę už rankų: vidutinio gymio šviesios odos',
    '👨🏼‍🤝‍👨🏽' => 'du vyrai, susikibę už rankų: vidutinio gymio rusvos odos',
    '👨🏼‍🤝‍👨🏾' => 'du vyrai, susikibę už rankų: vidutinio gymio tamsios odos',
    '👨🏼‍🤝‍👨🏿' => 'du vyrai, susikibę už rankų: vidutinio gymio itin tamsios odos',
    '👨🏽‍🤝‍👨🏻' => 'du vyrai, susikibę už rankų: rusvos odos šviesios odos',
    '👨🏽‍🤝‍👨🏼' => 'du vyrai, susikibę už rankų: rusvos odos vidutinio gymio',
    '👨🏽‍🤝‍👨🏾' => 'du vyrai, susikibę už rankų: rusvos odos tamsios odos',
    '👨🏽‍🤝‍👨🏿' => 'du vyrai, susikibę už rankų: rusvos odos itin tamsios odos',
    '👨🏾‍🤝‍👨🏻' => 'du vyrai, susikibę už rankų: tamsios odos šviesios odos',
    '👨🏾‍🤝‍👨🏼' => 'du vyrai, susikibę už rankų: tamsios odos vidutinio gymio',
    '👨🏾‍🤝‍👨🏽' => 'du vyrai, susikibę už rankų: tamsios odos rusvos odos',
    '👨🏾‍🤝‍👨🏿' => 'du vyrai, susikibę už rankų: tamsios odos itin tamsios odos',
    '👨🏿‍🤝‍👨🏻' => 'du vyrai, susikibę už rankų: itin tamsios odos šviesios odos',
    '👨🏿‍🤝‍👨🏼' => 'du vyrai, susikibę už rankų: itin tamsios odos vidutinio gymio',
    '👨🏿‍🤝‍👨🏽' => 'du vyrai, susikibę už rankų: itin tamsios odos rusvos odos',
    '👨🏿‍🤝‍👨🏾' => 'du vyrai, susikibę už rankų: itin tamsios odos tamsios odos',
    '👩‍❤‍💋‍👨' => 'bučinys: moteris vyras',
    '👨‍❤‍💋‍👨' => 'bučinys: vyras vyras',
    '👩‍❤‍💋‍👩' => 'bučinys: moteris moteris',
    '👨‍👩‍👧‍👦' => 'šeima: vyras moteris mergaitė berniukas',
    '👨‍👩‍👦‍👦' => 'šeima: vyras moteris berniukas berniukas',
    '👨‍👩‍👧‍👧' => 'šeima: vyras moteris mergaitė mergaitė',
    '👨‍👨‍👧‍👦' => 'šeima: vyras vyras mergaitė berniukas',
    '👨‍👨‍👦‍👦' => 'šeima: vyras vyras berniukas berniukas',
    '👨‍👨‍👧‍👧' => 'šeima: vyras vyras mergaitė mergaitė',
    '👩‍👩‍👧‍👦' => 'šeima: moteris moteris mergaitė berniukas',
    '👩‍👩‍👦‍👦' => 'šeima: moteris moteris berniukas berniukas',
    '👩‍👩‍👧‍👧' => 'šeima: moteris moteris mergaitė mergaitė',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'vėliava: Anglija',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'vėliava: Škotija',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'vėliava: Velsas',
    '🧑‍🧑‍🧒‍🧒' => 'šeima: suaugusysis, suaugusysis, vaikas, vaikas',
    '🚶🏻‍♀‍➡' => 'einanti moteris: šviesios odos atsisukęs į dešinę',
    '🚶🏼‍♀‍➡' => 'einanti moteris: vidutinio gymio atsisukęs į dešinę',
    '🚶🏽‍♀‍➡' => 'einanti moteris: rusvos odos atsisukęs į dešinę',
    '🚶🏾‍♀‍➡' => 'einanti moteris: tamsios odos atsisukęs į dešinę',
    '🚶🏿‍♀‍➡' => 'einanti moteris: itin tamsios odos atsisukęs į dešinę',
    '🚶🏻‍♂‍➡' => 'einantis vyras: šviesios odos atsisukęs į dešinę',
    '🚶🏼‍♂‍➡' => 'einantis vyras: vidutinio gymio atsisukęs į dešinę',
    '🚶🏽‍♂‍➡' => 'einantis vyras: rusvos odos atsisukęs į dešinę',
    '🚶🏾‍♂‍➡' => 'einantis vyras: tamsios odos atsisukęs į dešinę',
    '🚶🏿‍♂‍➡' => 'einantis vyras: itin tamsios odos atsisukęs į dešinę',
    '🧎🏻‍♀‍➡' => 'klūpanti moteris: šviesios odos atsisukęs į dešinę',
    '🧎🏼‍♀‍➡' => 'klūpanti moteris: vidutinio gymio atsisukęs į dešinę',
    '🧎🏽‍♀‍➡' => 'klūpanti moteris: rusvos odos atsisukęs į dešinę',
    '🧎🏾‍♀‍➡' => 'klūpanti moteris: tamsios odos atsisukęs į dešinę',
    '🧎🏿‍♀‍➡' => 'klūpanti moteris: itin tamsios odos atsisukęs į dešinę',
    '🧎🏻‍♂‍➡' => 'klūpantis vyras: šviesios odos atsisukęs į dešinę',
    '🧎🏼‍♂‍➡' => 'klūpantis vyras: vidutinio gymio atsisukęs į dešinę',
    '🧎🏽‍♂‍➡' => 'klūpantis vyras: rusvos odos atsisukęs į dešinę',
    '🧎🏾‍♂‍➡' => 'klūpantis vyras: tamsios odos atsisukęs į dešinę',
    '🧎🏿‍♂‍➡' => 'klūpantis vyras: itin tamsios odos atsisukęs į dešinę',
    '🧑🏻‍🦯‍➡' => 'žmogus neregio lazdele: šviesios odos atsisukęs į dešinę',
    '🧑🏼‍🦯‍➡' => 'žmogus neregio lazdele: vidutinio gymio atsisukęs į dešinę',
    '🧑🏽‍🦯‍➡' => 'žmogus neregio lazdele: rusvos odos atsisukęs į dešinę',
    '🧑🏾‍🦯‍➡' => 'žmogus neregio lazdele: tamsios odos atsisukęs į dešinę',
    '🧑🏿‍🦯‍➡' => 'žmogus neregio lazdele: itin tamsios odos atsisukęs į dešinę',
    '👨🏻‍🦯‍➡' => 'vyras su neregio lazdele: šviesios odos atsisukęs į dešinę',
    '👨🏼‍🦯‍➡' => 'vyras su neregio lazdele: vidutinio gymio atsisukęs į dešinę',
    '👨🏽‍🦯‍➡' => 'vyras su neregio lazdele: rusvos odos atsisukęs į dešinę',
    '👨🏾‍🦯‍➡' => 'vyras su neregio lazdele: tamsios odos atsisukęs į dešinę',
    '👨🏿‍🦯‍➡' => 'vyras su neregio lazdele: itin tamsios odos atsisukęs į dešinę',
    '👩🏻‍🦯‍➡' => 'moteris su neregio lazdele: šviesios odos atsisukęs į dešinę',
    '👩🏼‍🦯‍➡' => 'moteris su neregio lazdele: vidutinio gymio atsisukęs į dešinę',
    '👩🏽‍🦯‍➡' => 'moteris su neregio lazdele: rusvos odos atsisukęs į dešinę',
    '👩🏾‍🦯‍➡' => 'moteris su neregio lazdele: tamsios odos atsisukęs į dešinę',
    '👩🏿‍🦯‍➡' => 'moteris su neregio lazdele: itin tamsios odos atsisukęs į dešinę',
    '🧑🏻‍🦼‍➡' => 'žmogus motorizuotame vežimėlyje: šviesios odos atsisukęs į dešinę',
    '🧑🏼‍🦼‍➡' => 'žmogus motorizuotame vežimėlyje: vidutinio gymio atsisukęs į dešinę',
    '🧑🏽‍🦼‍➡' => 'žmogus motorizuotame vežimėlyje: rusvos odos atsisukęs į dešinę',
    '🧑🏾‍🦼‍➡' => 'žmogus motorizuotame vežimėlyje: tamsios odos atsisukęs į dešinę',
    '🧑🏿‍🦼‍➡' => 'žmogus motorizuotame vežimėlyje: itin tamsios odos atsisukęs į dešinę',
    '👨🏻‍🦼‍➡' => 'vyras motorizuotame vežimėlyje: šviesios odos atsisukęs į dešinę',
    '👨🏼‍🦼‍➡' => 'vyras motorizuotame vežimėlyje: vidutinio gymio atsisukęs į dešinę',
    '👨🏽‍🦼‍➡' => 'vyras motorizuotame vežimėlyje: rusvos odos atsisukęs į dešinę',
    '👨🏾‍🦼‍➡' => 'vyras motorizuotame vežimėlyje: tamsios odos atsisukęs į dešinę',
    '👨🏿‍🦼‍➡' => 'vyras motorizuotame vežimėlyje: itin tamsios odos atsisukęs į dešinę',
    '👩🏻‍🦼‍➡' => 'moteris motorizuotame vežimėlyje: šviesios odos atsisukęs į dešinę',
    '👩🏼‍🦼‍➡' => 'moteris motorizuotame vežimėlyje: vidutinio gymio atsisukęs į dešinę',
    '👩🏽‍🦼‍➡' => 'moteris motorizuotame vežimėlyje: rusvos odos atsisukęs į dešinę',
    '👩🏾‍🦼‍➡' => 'moteris motorizuotame vežimėlyje: tamsios odos atsisukęs į dešinę',
    '👩🏿‍🦼‍➡' => 'moteris motorizuotame vežimėlyje: itin tamsios odos atsisukęs į dešinę',
    '🧑🏻‍🦽‍➡' => 'žmogus rankomis valdomame vežimėlyje: šviesios odos atsisukęs į dešinę',
    '🧑🏼‍🦽‍➡' => 'žmogus rankomis valdomame vežimėlyje: vidutinio gymio atsisukęs į dešinę',
    '🧑🏽‍🦽‍➡' => 'žmogus rankomis valdomame vežimėlyje: rusvos odos atsisukęs į dešinę',
    '🧑🏾‍🦽‍➡' => 'žmogus rankomis valdomame vežimėlyje: tamsios odos atsisukęs į dešinę',
    '🧑🏿‍🦽‍➡' => 'žmogus rankomis valdomame vežimėlyje: itin tamsios odos atsisukęs į dešinę',
    '👨🏻‍🦽‍➡' => 'vyras rankomis valdomame vežimėlyje: šviesios odos atsisukęs į dešinę',
    '👨🏼‍🦽‍➡' => 'vyras rankomis valdomame vežimėlyje: vidutinio gymio atsisukęs į dešinę',
    '👨🏽‍🦽‍➡' => 'vyras rankomis valdomame vežimėlyje: rusvos odos atsisukęs į dešinę',
    '👨🏾‍🦽‍➡' => 'vyras rankomis valdomame vežimėlyje: tamsios odos atsisukęs į dešinę',
    '👨🏿‍🦽‍➡' => 'vyras rankomis valdomame vežimėlyje: itin tamsios odos atsisukęs į dešinę',
    '👩🏻‍🦽‍➡' => 'moteris rankomis valdomame vežimėlyje: šviesios odos atsisukęs į dešinę',
    '👩🏼‍🦽‍➡' => 'moteris rankomis valdomame vežimėlyje: vidutinio gymio atsisukęs į dešinę',
    '👩🏽‍🦽‍➡' => 'moteris rankomis valdomame vežimėlyje: rusvos odos atsisukęs į dešinę',
    '👩🏾‍🦽‍➡' => 'moteris rankomis valdomame vežimėlyje: tamsios odos atsisukęs į dešinę',
    '👩🏿‍🦽‍➡' => 'moteris rankomis valdomame vežimėlyje: itin tamsios odos atsisukęs į dešinę',
    '🏃🏻‍♀‍➡' => 'bėganti moteris: šviesios odos atsisukęs į dešinę',
    '🏃🏼‍♀‍➡' => 'bėganti moteris: vidutinio gymio atsisukęs į dešinę',
    '🏃🏽‍♀‍➡' => 'bėganti moteris: rusvos odos atsisukęs į dešinę',
    '🏃🏾‍♀‍➡' => 'bėganti moteris: tamsios odos atsisukęs į dešinę',
    '🏃🏿‍♀‍➡' => 'bėganti moteris: itin tamsios odos atsisukęs į dešinę',
    '🏃🏻‍♂‍➡' => 'bėgantis vyras: šviesios odos atsisukęs į dešinę',
    '🏃🏼‍♂‍➡' => 'bėgantis vyras: vidutinio gymio atsisukęs į dešinę',
    '🏃🏽‍♂‍➡' => 'bėgantis vyras: rusvos odos atsisukęs į dešinę',
    '🏃🏾‍♂‍➡' => 'bėgantis vyras: tamsios odos atsisukęs į dešinę',
    '🏃🏿‍♂‍➡' => 'bėgantis vyras: itin tamsios odos atsisukęs į dešinę',
    '🫱🏻‍🫲🏼' => 'rankos paspaudimas: šviesios odos vidutinio gymio',
    '🫱🏻‍🫲🏽' => 'rankos paspaudimas: šviesios odos rusvos odos',
    '🫱🏻‍🫲🏾' => 'rankos paspaudimas: šviesios odos tamsios odos',
    '🫱🏻‍🫲🏿' => 'rankos paspaudimas: šviesios odos itin tamsios odos',
    '🫱🏼‍🫲🏻' => 'rankos paspaudimas: vidutinio gymio šviesios odos',
    '🫱🏼‍🫲🏽' => 'rankos paspaudimas: vidutinio gymio rusvos odos',
    '🫱🏼‍🫲🏾' => 'rankos paspaudimas: vidutinio gymio tamsios odos',
    '🫱🏼‍🫲🏿' => 'rankos paspaudimas: vidutinio gymio itin tamsios odos',
    '🫱🏽‍🫲🏻' => 'rankos paspaudimas: rusvos odos šviesios odos',
    '🫱🏽‍🫲🏼' => 'rankos paspaudimas: rusvos odos vidutinio gymio',
    '🫱🏽‍🫲🏾' => 'rankos paspaudimas: rusvos odos tamsios odos',
    '🫱🏽‍🫲🏿' => 'rankos paspaudimas: rusvos odos itin tamsios odos',
    '🫱🏾‍🫲🏻' => 'rankos paspaudimas: tamsios odos šviesios odos',
    '🫱🏾‍🫲🏼' => 'rankos paspaudimas: tamsios odos vidutinio gymio',
    '🫱🏾‍🫲🏽' => 'rankos paspaudimas: tamsios odos rusvos odos',
    '🫱🏾‍🫲🏿' => 'rankos paspaudimas: tamsios odos itin tamsios odos',
    '🫱🏿‍🫲🏻' => 'rankos paspaudimas: itin tamsios odos šviesios odos',
    '🫱🏿‍🫲🏼' => 'rankos paspaudimas: itin tamsios odos vidutinio gymio',
    '🫱🏿‍🫲🏽' => 'rankos paspaudimas: itin tamsios odos rusvos odos',
    '🫱🏿‍🫲🏾' => 'rankos paspaudimas: itin tamsios odos tamsios odos',
    '🚶‍♀‍➡' => 'einanti moteris: atsisukęs į dešinę',
    '🚶‍♂‍➡' => 'einantis vyras: atsisukęs į dešinę',
    '🧎‍♀‍➡' => 'klūpanti moteris: atsisukęs į dešinę',
    '🧎‍♂‍➡' => 'klūpantis vyras: atsisukęs į dešinę',
    '🧑‍🦯‍➡' => 'žmogus neregio lazdele: atsisukęs į dešinę',
    '👨‍🦯‍➡' => 'vyras su neregio lazdele: atsisukęs į dešinę',
    '👩‍🦯‍➡' => 'moteris su neregio lazdele: atsisukęs į dešinę',
    '🧑‍🦼‍➡' => 'žmogus motorizuotame vežimėlyje: atsisukęs į dešinę',
    '👨‍🦼‍➡' => 'vyras motorizuotame vežimėlyje: atsisukęs į dešinę',
    '👩‍🦼‍➡' => 'moteris motorizuotame vežimėlyje: atsisukęs į dešinę',
    '🧑‍🦽‍➡' => 'žmogus rankomis valdomame vežimėlyje: atsisukęs į dešinę',
    '👨‍🦽‍➡' => 'vyras rankomis valdomame vežimėlyje: atsisukęs į dešinę',
    '👩‍🦽‍➡' => 'moteris rankomis valdomame vežimėlyje: atsisukęs į dešinę',
    '🏃‍♀‍➡' => 'bėganti moteris: atsisukęs į dešinę',
    '🏃‍♂‍➡' => 'bėgantis vyras: atsisukęs į dešinę',
    '👩‍❤‍👨' => 'pora su širdele: moteris vyras',
    '👨‍❤‍👨' => 'pora su širdele: vyras vyras',
    '👩‍❤‍👩' => 'pora su širdele: moteris moteris',
    '👨‍👩‍👦' => 'šeima: vyras moteris berniukas',
    '👨‍👩‍👧' => 'šeima: vyras moteris mergaitė',
    '👨‍👨‍👦' => 'šeima: vyras vyras berniukas',
    '👨‍👨‍👧' => 'šeima: vyras vyras mergaitė',
    '👩‍👩‍👦' => 'šeima: moteris moteris berniukas',
    '👩‍👩‍👧' => 'šeima: moteris moteris mergaitė',
    '👨‍👦‍👦' => 'šeima: vyras berniukas berniukas',
    '👨‍👧‍👦' => 'šeima: vyras mergaitė berniukas',
    '👨‍👧‍👧' => 'šeima: vyras mergaitė mergaitė',
    '👩‍👦‍👦' => 'šeima: moteris berniukas berniukas',
    '👩‍👧‍👦' => 'šeima: moteris mergaitė berniukas',
    '👩‍👧‍👧' => 'šeima: moteris mergaitė mergaitė',
    '🧑‍🤝‍🧑' => 'rankomis susikibę žmonės',
    '🧑‍🧑‍🧒' => 'šeima: suaugusysis, suaugusysis, vaikas',
    '🧑‍🧒‍🧒' => 'šeima: suaugusysis, vaikas, vaikas',
    '🧑🏻‍🦰' => 'suaugusysis: šviesios odos raudoni plaukai',
    '🧑🏼‍🦰' => 'suaugusysis: vidutinio gymio raudoni plaukai',
    '🧑🏽‍🦰' => 'suaugusysis: rusvos odos raudoni plaukai',
    '🧑🏾‍🦰' => 'suaugusysis: tamsios odos raudoni plaukai',
    '🧑🏿‍🦰' => 'suaugusysis: itin tamsios odos raudoni plaukai',
    '🧑🏻‍🦱' => 'suaugusysis: šviesios odos garbanoti plaukai',
    '🧑🏼‍🦱' => 'suaugusysis: vidutinio gymio garbanoti plaukai',
    '🧑🏽‍🦱' => 'suaugusysis: rusvos odos garbanoti plaukai',
    '🧑🏾‍🦱' => 'suaugusysis: tamsios odos garbanoti plaukai',
    '🧑🏿‍🦱' => 'suaugusysis: itin tamsios odos garbanoti plaukai',
    '🧑🏻‍🦳' => 'suaugusysis: šviesios odos žili plaukai',
    '🧑🏼‍🦳' => 'suaugusysis: vidutinio gymio žili plaukai',
    '🧑🏽‍🦳' => 'suaugusysis: rusvos odos žili plaukai',
    '🧑🏾‍🦳' => 'suaugusysis: tamsios odos žili plaukai',
    '🧑🏿‍🦳' => 'suaugusysis: itin tamsios odos žili plaukai',
    '🧑🏻‍🦲' => 'suaugusysis: šviesios odos plikas',
    '🧑🏼‍🦲' => 'suaugusysis: vidutinio gymio plikas',
    '🧑🏽‍🦲' => 'suaugusysis: rusvos odos plikas',
    '🧑🏾‍🦲' => 'suaugusysis: tamsios odos plikas',
    '🧑🏿‍🦲' => 'suaugusysis: itin tamsios odos plikas',
    '🧑🏻‍🩰' => 'baleto šokėjas: šviesios odos',
    '🧑🏼‍🩰' => 'baleto šokėjas: vidutinio gymio',
    '🧑🏽‍🩰' => 'baleto šokėjas: rusvos odos',
    '🧑🏾‍🩰' => 'baleto šokėjas: tamsios odos',
    '🧑🏿‍🩰' => 'baleto šokėjas: itin tamsios odos',
    '🧔🏻‍♂' => 'vyras: šviesios odos barzda',
    '🧔🏼‍♂' => 'vyras: vidutinio gymio barzda',
    '🧔🏽‍♂' => 'vyras: rusvos odos barzda',
    '🧔🏾‍♂' => 'vyras: tamsios odos barzda',
    '🧔🏿‍♂' => 'vyras: itin tamsios odos barzda',
    '👱🏻‍♂' => 'blondinas: šviesios odos',
    '👱🏼‍♂' => 'blondinas: vidutinio gymio',
    '👱🏽‍♂' => 'blondinas: rusvos odos',
    '👱🏾‍♂' => 'blondinas: tamsios odos',
    '👱🏿‍♂' => 'blondinas: itin tamsios odos',
    '👨🏻‍🦰' => 'vyras: šviesios odos raudoni plaukai',
    '👨🏼‍🦰' => 'vyras: vidutinio gymio raudoni plaukai',
    '👨🏽‍🦰' => 'vyras: rusvos odos raudoni plaukai',
    '👨🏾‍🦰' => 'vyras: tamsios odos raudoni plaukai',
    '👨🏿‍🦰' => 'vyras: itin tamsios odos raudoni plaukai',
    '👨🏻‍🦱' => 'vyras: šviesios odos garbanoti plaukai',
    '👨🏼‍🦱' => 'vyras: vidutinio gymio garbanoti plaukai',
    '👨🏽‍🦱' => 'vyras: rusvos odos garbanoti plaukai',
    '👨🏾‍🦱' => 'vyras: tamsios odos garbanoti plaukai',
    '👨🏿‍🦱' => 'vyras: itin tamsios odos garbanoti plaukai',
    '👨🏻‍🦳' => 'vyras: šviesios odos žili plaukai',
    '👨🏼‍🦳' => 'vyras: vidutinio gymio žili plaukai',
    '👨🏽‍🦳' => 'vyras: rusvos odos žili plaukai',
    '👨🏾‍🦳' => 'vyras: tamsios odos žili plaukai',
    '👨🏿‍🦳' => 'vyras: itin tamsios odos žili plaukai',
    '👨🏻‍🦲' => 'vyras: šviesios odos plikas',
    '👨🏼‍🦲' => 'vyras: vidutinio gymio plikas',
    '👨🏽‍🦲' => 'vyras: rusvos odos plikas',
    '👨🏾‍🦲' => 'vyras: tamsios odos plikas',
    '👨🏿‍🦲' => 'vyras: itin tamsios odos plikas',
    '🧔🏻‍♀' => 'moteris: šviesios odos barzda',
    '🧔🏼‍♀' => 'moteris: vidutinio gymio barzda',
    '🧔🏽‍♀' => 'moteris: rusvos odos barzda',
    '🧔🏾‍♀' => 'moteris: tamsios odos barzda',
    '🧔🏿‍♀' => 'moteris: itin tamsios odos barzda',
    '👱🏻‍♀' => 'blondinė: šviesios odos',
    '👱🏼‍♀' => 'blondinė: vidutinio gymio',
    '👱🏽‍♀' => 'blondinė: rusvos odos',
    '👱🏾‍♀' => 'blondinė: tamsios odos',
    '👱🏿‍♀' => 'blondinė: itin tamsios odos',
    '👩🏻‍🦰' => 'moteris: šviesios odos raudoni plaukai',
    '👩🏼‍🦰' => 'moteris: vidutinio gymio raudoni plaukai',
    '👩🏽‍🦰' => 'moteris: rusvos odos raudoni plaukai',
    '👩🏾‍🦰' => 'moteris: tamsios odos raudoni plaukai',
    '👩🏿‍🦰' => 'moteris: itin tamsios odos raudoni plaukai',
    '👩🏻‍🦱' => 'moteris: šviesios odos garbanoti plaukai',
    '👩🏼‍🦱' => 'moteris: vidutinio gymio garbanoti plaukai',
    '👩🏽‍🦱' => 'moteris: rusvos odos garbanoti plaukai',
    '👩🏾‍🦱' => 'moteris: tamsios odos garbanoti plaukai',
    '👩🏿‍🦱' => 'moteris: itin tamsios odos garbanoti plaukai',
    '👩🏻‍🦳' => 'moteris: šviesios odos žili plaukai',
    '👩🏼‍🦳' => 'moteris: vidutinio gymio žili plaukai',
    '👩🏽‍🦳' => 'moteris: rusvos odos žili plaukai',
    '👩🏾‍🦳' => 'moteris: tamsios odos žili plaukai',
    '👩🏿‍🦳' => 'moteris: itin tamsios odos žili plaukai',
    '👩🏻‍🦲' => 'moteris: šviesios odos plikas',
    '👩🏼‍🦲' => 'moteris: vidutinio gymio plikas',
    '👩🏽‍🦲' => 'moteris: rusvos odos plikas',
    '👩🏾‍🦲' => 'moteris: tamsios odos plikas',
    '👩🏿‍🦲' => 'moteris: itin tamsios odos plikas',
    '🙍🏻‍♂' => 'paniuręs vyras: šviesios odos',
    '🙍🏼‍♂' => 'paniuręs vyras: vidutinio gymio',
    '🙍🏽‍♂' => 'paniuręs vyras: rusvos odos',
    '🙍🏾‍♂' => 'paniuręs vyras: tamsios odos',
    '🙍🏿‍♂' => 'paniuręs vyras: itin tamsios odos',
    '🙍🏻‍♀' => 'paniurusi moteris: šviesios odos',
    '🙍🏼‍♀' => 'paniurusi moteris: vidutinio gymio',
    '🙍🏽‍♀' => 'paniurusi moteris: rusvos odos',
    '🙍🏾‍♀' => 'paniurusi moteris: tamsios odos',
    '🙍🏿‍♀' => 'paniurusi moteris: itin tamsios odos',
    '🙎🏻‍♂' => 'susiraukęs vyras: šviesios odos',
    '🙎🏼‍♂' => 'susiraukęs vyras: vidutinio gymio',
    '🙎🏽‍♂' => 'susiraukęs vyras: rusvos odos',
    '🙎🏾‍♂' => 'susiraukęs vyras: tamsios odos',
    '🙎🏿‍♂' => 'susiraukęs vyras: itin tamsios odos',
    '🙎🏻‍♀' => 'susiraukusi moteris: šviesios odos',
    '🙎🏼‍♀' => 'susiraukusi moteris: vidutinio gymio',
    '🙎🏽‍♀' => 'susiraukusi moteris: rusvos odos',
    '🙎🏾‍♀' => 'susiraukusi moteris: tamsios odos',
    '🙎🏿‍♀' => 'susiraukusi moteris: itin tamsios odos',
    '🙅🏻‍♂' => 'draudžiantis vyras: šviesios odos',
    '🙅🏼‍♂' => 'draudžiantis vyras: vidutinio gymio',
    '🙅🏽‍♂' => 'draudžiantis vyras: rusvos odos',
    '🙅🏾‍♂' => 'draudžiantis vyras: tamsios odos',
    '🙅🏿‍♂' => 'draudžiantis vyras: itin tamsios odos',
    '🙅🏻‍♀' => 'draudžianti moteris: šviesios odos',
    '🙅🏼‍♀' => 'draudžianti moteris: vidutinio gymio',
    '🙅🏽‍♀' => 'draudžianti moteris: rusvos odos',
    '🙅🏾‍♀' => 'draudžianti moteris: tamsios odos',
    '🙅🏿‍♀' => 'draudžianti moteris: itin tamsios odos',
    '🙆🏻‍♂' => 'leidžiantis vyras: šviesios odos',
    '🙆🏼‍♂' => 'leidžiantis vyras: vidutinio gymio',
    '🙆🏽‍♂' => 'leidžiantis vyras: rusvos odos',
    '🙆🏾‍♂' => 'leidžiantis vyras: tamsios odos',
    '🙆🏿‍♂' => 'leidžiantis vyras: itin tamsios odos',
    '🙆🏻‍♀' => 'leidžianti moteris: šviesios odos',
    '🙆🏼‍♀' => 'leidžianti moteris: vidutinio gymio',
    '🙆🏽‍♀' => 'leidžianti moteris: rusvos odos',
    '🙆🏾‍♀' => 'leidžianti moteris: tamsios odos',
    '🙆🏿‍♀' => 'leidžianti moteris: itin tamsios odos',
    '💁🏻‍♂' => 'lengvai ranką pakėlęs vyras: šviesios odos',
    '💁🏼‍♂' => 'lengvai ranką pakėlęs vyras: vidutinio gymio',
    '💁🏽‍♂' => 'lengvai ranką pakėlęs vyras: rusvos odos',
    '💁🏾‍♂' => 'lengvai ranką pakėlęs vyras: tamsios odos',
    '💁🏿‍♂' => 'lengvai ranką pakėlęs vyras: itin tamsios odos',
    '💁🏻‍♀' => 'ranką pakėlusi moteris: šviesios odos',
    '💁🏼‍♀' => 'ranką pakėlusi moteris: vidutinio gymio',
    '💁🏽‍♀' => 'ranką pakėlusi moteris: rusvos odos',
    '💁🏾‍♀' => 'ranką pakėlusi moteris: tamsios odos',
    '💁🏿‍♀' => 'ranką pakėlusi moteris: itin tamsios odos',
    '🙋🏻‍♂' => 'ranką pakėlęs vyras: šviesios odos',
    '🙋🏼‍♂' => 'ranką pakėlęs vyras: vidutinio gymio',
    '🙋🏽‍♂' => 'ranką pakėlęs vyras: rusvos odos',
    '🙋🏾‍♂' => 'ranką pakėlęs vyras: tamsios odos',
    '🙋🏿‍♂' => 'ranką pakėlęs vyras: itin tamsios odos',
    '🙋🏻‍♀' => 'ranką iškėlusi moteris: šviesios odos',
    '🙋🏼‍♀' => 'ranką iškėlusi moteris: vidutinio gymio',
    '🙋🏽‍♀' => 'ranką iškėlusi moteris: rusvos odos',
    '🙋🏾‍♀' => 'ranką iškėlusi moteris: tamsios odos',
    '🙋🏿‍♀' => 'ranką iškėlusi moteris: itin tamsios odos',
    '🧏🏻‍♂' => 'kurčias vyras: šviesios odos',
    '🧏🏼‍♂' => 'kurčias vyras: vidutinio gymio',
    '🧏🏽‍♂' => 'kurčias vyras: rusvos odos',
    '🧏🏾‍♂' => 'kurčias vyras: tamsios odos',
    '🧏🏿‍♂' => 'kurčias vyras: itin tamsios odos',
    '🧏🏻‍♀' => 'kurčia moteris: šviesios odos',
    '🧏🏼‍♀' => 'kurčia moteris: vidutinio gymio',
    '🧏🏽‍♀' => 'kurčia moteris: rusvos odos',
    '🧏🏾‍♀' => 'kurčia moteris: tamsios odos',
    '🧏🏿‍♀' => 'kurčia moteris: itin tamsios odos',
    '🙇🏻‍♂' => 'nusilenkiantis vyras: šviesios odos',
    '🙇🏼‍♂' => 'nusilenkiantis vyras: vidutinio gymio',
    '🙇🏽‍♂' => 'nusilenkiantis vyras: rusvos odos',
    '🙇🏾‍♂' => 'nusilenkiantis vyras: tamsios odos',
    '🙇🏿‍♂' => 'nusilenkiantis vyras: itin tamsios odos',
    '🙇🏻‍♀' => 'nusilenkianti moteris: šviesios odos',
    '🙇🏼‍♀' => 'nusilenkianti moteris: vidutinio gymio',
    '🙇🏽‍♀' => 'nusilenkianti moteris: rusvos odos',
    '🙇🏾‍♀' => 'nusilenkianti moteris: tamsios odos',
    '🙇🏿‍♀' => 'nusilenkianti moteris: itin tamsios odos',
    '🤦🏻‍♂' => 'susierzinęs vyras: šviesios odos',
    '🤦🏼‍♂' => 'susierzinęs vyras: vidutinio gymio',
    '🤦🏽‍♂' => 'susierzinęs vyras: rusvos odos',
    '🤦🏾‍♂' => 'susierzinęs vyras: tamsios odos',
    '🤦🏿‍♂' => 'susierzinęs vyras: itin tamsios odos',
    '🤦🏻‍♀' => 'susierzinusi moteris: šviesios odos',
    '🤦🏼‍♀' => 'susierzinusi moteris: vidutinio gymio',
    '🤦🏽‍♀' => 'susierzinusi moteris: rusvos odos',
    '🤦🏾‍♀' => 'susierzinusi moteris: tamsios odos',
    '🤦🏿‍♀' => 'susierzinusi moteris: itin tamsios odos',
    '🤷🏻‍♂' => 'abejojantis vyras: šviesios odos',
    '🤷🏼‍♂' => 'abejojantis vyras: vidutinio gymio',
    '🤷🏽‍♂' => 'abejojantis vyras: rusvos odos',
    '🤷🏾‍♂' => 'abejojantis vyras: tamsios odos',
    '🤷🏿‍♂' => 'abejojantis vyras: itin tamsios odos',
    '🤷🏻‍♀' => 'abejojanti moteris: šviesios odos',
    '🤷🏼‍♀' => 'abejojanti moteris: vidutinio gymio',
    '🤷🏽‍♀' => 'abejojanti moteris: rusvos odos',
    '🤷🏾‍♀' => 'abejojanti moteris: tamsios odos',
    '🤷🏿‍♀' => 'abejojanti moteris: itin tamsios odos',
    '🧑🏻‍⚕' => 'sveikatos darbuotojas: šviesios odos',
    '🧑🏼‍⚕' => 'sveikatos darbuotojas: vidutinio gymio',
    '🧑🏽‍⚕' => 'sveikatos darbuotojas: rusvos odos',
    '🧑🏾‍⚕' => 'sveikatos darbuotojas: tamsios odos',
    '🧑🏿‍⚕' => 'sveikatos darbuotojas: itin tamsios odos',
    '👨🏻‍⚕' => 'medikas: šviesios odos',
    '👨🏼‍⚕' => 'medikas: vidutinio gymio',
    '👨🏽‍⚕' => 'medikas: rusvos odos',
    '👨🏾‍⚕' => 'medikas: tamsios odos',
    '👨🏿‍⚕' => 'medikas: itin tamsios odos',
    '👩🏻‍⚕' => 'medikė: šviesios odos',
    '👩🏼‍⚕' => 'medikė: vidutinio gymio',
    '👩🏽‍⚕' => 'medikė: rusvos odos',
    '👩🏾‍⚕' => 'medikė: tamsios odos',
    '👩🏿‍⚕' => 'medikė: itin tamsios odos',
    '🧑🏻‍🎓' => 'paskutinio kurso studentas: šviesios odos',
    '🧑🏼‍🎓' => 'paskutinio kurso studentas: vidutinio gymio',
    '🧑🏽‍🎓' => 'paskutinio kurso studentas: rusvos odos',
    '🧑🏾‍🎓' => 'paskutinio kurso studentas: tamsios odos',
    '🧑🏿‍🎓' => 'paskutinio kurso studentas: itin tamsios odos',
    '👨🏻‍🎓' => 'studentas: šviesios odos',
    '👨🏼‍🎓' => 'studentas: vidutinio gymio',
    '👨🏽‍🎓' => 'studentas: rusvos odos',
    '👨🏾‍🎓' => 'studentas: tamsios odos',
    '👨🏿‍🎓' => 'studentas: itin tamsios odos',
    '👩🏻‍🎓' => 'studentė: šviesios odos',
    '👩🏼‍🎓' => 'studentė: vidutinio gymio',
    '👩🏽‍🎓' => 'studentė: rusvos odos',
    '👩🏾‍🎓' => 'studentė: tamsios odos',
    '👩🏿‍🎓' => 'studentė: itin tamsios odos',
    '🧑🏻‍🏫' => 'mokantis žmogus: šviesios odos',
    '🧑🏼‍🏫' => 'mokantis žmogus: vidutinio gymio',
    '🧑🏽‍🏫' => 'mokantis žmogus: rusvos odos',
    '🧑🏾‍🏫' => 'mokantis žmogus: tamsios odos',
    '🧑🏿‍🏫' => 'mokantis žmogus: itin tamsios odos',
    '👨🏻‍🏫' => 'mokytojas: šviesios odos',
    '👨🏼‍🏫' => 'mokytojas: vidutinio gymio',
    '👨🏽‍🏫' => 'mokytojas: rusvos odos',
    '👨🏾‍🏫' => 'mokytojas: tamsios odos',
    '👨🏿‍🏫' => 'mokytojas: itin tamsios odos',
    '👩🏻‍🏫' => 'mokytoja: šviesios odos',
    '👩🏼‍🏫' => 'mokytoja: vidutinio gymio',
    '👩🏽‍🏫' => 'mokytoja: rusvos odos',
    '👩🏾‍🏫' => 'mokytoja: tamsios odos',
    '👩🏿‍🏫' => 'mokytoja: itin tamsios odos',
    '🧑🏻‍⚖' => 'teisiantis žmogus: šviesios odos',
    '🧑🏼‍⚖' => 'teisiantis žmogus: vidutinio gymio',
    '🧑🏽‍⚖' => 'teisiantis žmogus: rusvos odos',
    '🧑🏾‍⚖' => 'teisiantis žmogus: tamsios odos',
    '🧑🏿‍⚖' => 'teisiantis žmogus: itin tamsios odos',
    '👨🏻‍⚖' => 'teisėjas: šviesios odos',
    '👨🏼‍⚖' => 'teisėjas: vidutinio gymio',
    '👨🏽‍⚖' => 'teisėjas: rusvos odos',
    '👨🏾‍⚖' => 'teisėjas: tamsios odos',
    '👨🏿‍⚖' => 'teisėjas: itin tamsios odos',
    '👩🏻‍⚖' => 'teisėja: šviesios odos',
    '👩🏼‍⚖' => 'teisėja: vidutinio gymio',
    '👩🏽‍⚖' => 'teisėja: rusvos odos',
    '👩🏾‍⚖' => 'teisėja: tamsios odos',
    '👩🏿‍⚖' => 'teisėja: itin tamsios odos',
    '🧑🏻‍🌾' => 'ūkininkaujantis žmogus: šviesios odos',
    '🧑🏼‍🌾' => 'ūkininkaujantis žmogus: vidutinio gymio',
    '🧑🏽‍🌾' => 'ūkininkaujantis žmogus: rusvos odos',
    '🧑🏾‍🌾' => 'ūkininkaujantis žmogus: tamsios odos',
    '🧑🏿‍🌾' => 'ūkininkaujantis žmogus: itin tamsios odos',
    '👨🏻‍🌾' => 'ūkininkas: šviesios odos',
    '👨🏼‍🌾' => 'ūkininkas: vidutinio gymio',
    '👨🏽‍🌾' => 'ūkininkas: rusvos odos',
    '👨🏾‍🌾' => 'ūkininkas: tamsios odos',
    '👨🏿‍🌾' => 'ūkininkas: itin tamsios odos',
    '👩🏻‍🌾' => 'ūkininkė: šviesios odos',
    '👩🏼‍🌾' => 'ūkininkė: vidutinio gymio',
    '👩🏽‍🌾' => 'ūkininkė: rusvos odos',
    '👩🏾‍🌾' => 'ūkininkė: tamsios odos',
    '👩🏿‍🌾' => 'ūkininkė: itin tamsios odos',
    '🧑🏻‍🍳' => 'gaminantis žmogus: šviesios odos',
    '🧑🏼‍🍳' => 'gaminantis žmogus: vidutinio gymio',
    '🧑🏽‍🍳' => 'gaminantis žmogus: rusvos odos',
    '🧑🏾‍🍳' => 'gaminantis žmogus: tamsios odos',
    '🧑🏿‍🍳' => 'gaminantis žmogus: itin tamsios odos',
    '👨🏻‍🍳' => 'virėjas: šviesios odos',
    '👨🏼‍🍳' => 'virėjas: vidutinio gymio',
    '👨🏽‍🍳' => 'virėjas: rusvos odos',
    '👨🏾‍🍳' => 'virėjas: tamsios odos',
    '👨🏿‍🍳' => 'virėjas: itin tamsios odos',
    '👩🏻‍🍳' => 'virėja: šviesios odos',
    '👩🏼‍🍳' => 'virėja: vidutinio gymio',
    '👩🏽‍🍳' => 'virėja: rusvos odos',
    '👩🏾‍🍳' => 'virėja: tamsios odos',
    '👩🏿‍🍳' => 'virėja: itin tamsios odos',
    '🧑🏻‍🔧' => 'remontuojantis žmogus: šviesios odos',
    '🧑🏼‍🔧' => 'remontuojantis žmogus: vidutinio gymio',
    '🧑🏽‍🔧' => 'remontuojantis žmogus: rusvos odos',
    '🧑🏾‍🔧' => 'remontuojantis žmogus: tamsios odos',
    '🧑🏿‍🔧' => 'remontuojantis žmogus: itin tamsios odos',
    '👨🏻‍🔧' => 'mechanikas: šviesios odos',
    '👨🏼‍🔧' => 'mechanikas: vidutinio gymio',
    '👨🏽‍🔧' => 'mechanikas: rusvos odos',
    '👨🏾‍🔧' => 'mechanikas: tamsios odos',
    '👨🏿‍🔧' => 'mechanikas: itin tamsios odos',
    '👩🏻‍🔧' => 'mechanikė: šviesios odos',
    '👩🏼‍🔧' => 'mechanikė: vidutinio gymio',
    '👩🏽‍🔧' => 'mechanikė: rusvos odos',
    '👩🏾‍🔧' => 'mechanikė: tamsios odos',
    '👩🏿‍🔧' => 'mechanikė: itin tamsios odos',
    '🧑🏻‍🏭' => 'gamyklos darbuotojas: šviesios odos',
    '🧑🏼‍🏭' => 'gamyklos darbuotojas: vidutinio gymio',
    '🧑🏽‍🏭' => 'gamyklos darbuotojas: rusvos odos',
    '🧑🏾‍🏭' => 'gamyklos darbuotojas: tamsios odos',
    '🧑🏿‍🏭' => 'gamyklos darbuotojas: itin tamsios odos',
    '👨🏻‍🏭' => 'fabriko darbininkas: šviesios odos',
    '👨🏼‍🏭' => 'fabriko darbininkas: vidutinio gymio',
    '👨🏽‍🏭' => 'fabriko darbininkas: rusvos odos',
    '👨🏾‍🏭' => 'fabriko darbininkas: tamsios odos',
    '👨🏿‍🏭' => 'fabriko darbininkas: itin tamsios odos',
    '👩🏻‍🏭' => 'fabriko darbininkė: šviesios odos',
    '👩🏼‍🏭' => 'fabriko darbininkė: vidutinio gymio',
    '👩🏽‍🏭' => 'fabriko darbininkė: rusvos odos',
    '👩🏾‍🏭' => 'fabriko darbininkė: tamsios odos',
    '👩🏿‍🏭' => 'fabriko darbininkė: itin tamsios odos',
    '🧑🏻‍💼' => 'dirbantysis biure: šviesios odos',
    '🧑🏼‍💼' => 'dirbantysis biure: vidutinio gymio',
    '🧑🏽‍💼' => 'dirbantysis biure: rusvos odos',
    '🧑🏾‍💼' => 'dirbantysis biure: tamsios odos',
    '🧑🏿‍💼' => 'dirbantysis biure: itin tamsios odos',
    '👨🏻‍💼' => 'biuro darbuotojas: šviesios odos',
    '👨🏼‍💼' => 'biuro darbuotojas: vidutinio gymio',
    '👨🏽‍💼' => 'biuro darbuotojas: rusvos odos',
    '👨🏾‍💼' => 'biuro darbuotojas: tamsios odos',
    '👨🏿‍💼' => 'biuro darbuotojas: itin tamsios odos',
    '👩🏻‍💼' => 'biuro darbuotoja: šviesios odos',
    '👩🏼‍💼' => 'biuro darbuotoja: vidutinio gymio',
    '👩🏽‍💼' => 'biuro darbuotoja: rusvos odos',
    '👩🏾‍💼' => 'biuro darbuotoja: tamsios odos',
    '👩🏿‍💼' => 'biuro darbuotoja: itin tamsios odos',
    '🧑🏻‍🔬' => 'mokslo darbuotojas: šviesios odos',
    '🧑🏼‍🔬' => 'mokslo darbuotojas: vidutinio gymio',
    '🧑🏽‍🔬' => 'mokslo darbuotojas: rusvos odos',
    '🧑🏾‍🔬' => 'mokslo darbuotojas: tamsios odos',
    '🧑🏿‍🔬' => 'mokslo darbuotojas: itin tamsios odos',
    '👨🏻‍🔬' => 'mokslininkas: šviesios odos',
    '👨🏼‍🔬' => 'mokslininkas: vidutinio gymio',
    '👨🏽‍🔬' => 'mokslininkas: rusvos odos',
    '👨🏾‍🔬' => 'mokslininkas: tamsios odos',
    '👨🏿‍🔬' => 'mokslininkas: itin tamsios odos',
    '👩🏻‍🔬' => 'mokslininkė: šviesios odos',
    '👩🏼‍🔬' => 'mokslininkė: vidutinio gymio',
    '👩🏽‍🔬' => 'mokslininkė: rusvos odos',
    '👩🏾‍🔬' => 'mokslininkė: tamsios odos',
    '👩🏿‍🔬' => 'mokslininkė: itin tamsios odos',
    '🧑🏻‍💻' => 'technikas: šviesios odos',
    '🧑🏼‍💻' => 'technikas: vidutinio gymio',
    '🧑🏽‍💻' => 'technikas: rusvos odos',
    '🧑🏾‍💻' => 'technikas: tamsios odos',
    '🧑🏿‍💻' => 'technikas: itin tamsios odos',
    '👨🏻‍💻' => 'technologas: šviesios odos',
    '👨🏼‍💻' => 'technologas: vidutinio gymio',
    '👨🏽‍💻' => 'technologas: rusvos odos',
    '👨🏾‍💻' => 'technologas: tamsios odos',
    '👨🏿‍💻' => 'technologas: itin tamsios odos',
    '👩🏻‍💻' => 'technologė: šviesios odos',
    '👩🏼‍💻' => 'technologė: vidutinio gymio',
    '👩🏽‍💻' => 'technologė: rusvos odos',
    '👩🏾‍💻' => 'technologė: tamsios odos',
    '👩🏿‍💻' => 'technologė: itin tamsios odos',
    '🧑🏻‍🎤' => 'dainuojantis žmogus: šviesios odos',
    '🧑🏼‍🎤' => 'dainuojantis žmogus: vidutinio gymio',
    '🧑🏽‍🎤' => 'dainuojantis žmogus: rusvos odos',
    '🧑🏾‍🎤' => 'dainuojantis žmogus: tamsios odos',
    '🧑🏿‍🎤' => 'dainuojantis žmogus: itin tamsios odos',
    '👨🏻‍🎤' => 'dainininkas: šviesios odos',
    '👨🏼‍🎤' => 'dainininkas: vidutinio gymio',
    '👨🏽‍🎤' => 'dainininkas: rusvos odos',
    '👨🏾‍🎤' => 'dainininkas: tamsios odos',
    '👨🏿‍🎤' => 'dainininkas: itin tamsios odos',
    '👩🏻‍🎤' => 'dainininkė: šviesios odos',
    '👩🏼‍🎤' => 'dainininkė: vidutinio gymio',
    '👩🏽‍🎤' => 'dainininkė: rusvos odos',
    '👩🏾‍🎤' => 'dainininkė: tamsios odos',
    '👩🏿‍🎤' => 'dainininkė: itin tamsios odos',
    '🧑🏻‍🎨' => 'tapytojas: šviesios odos',
    '🧑🏼‍🎨' => 'tapytojas: vidutinio gymio',
    '🧑🏽‍🎨' => 'tapytojas: rusvos odos',
    '🧑🏾‍🎨' => 'tapytojas: tamsios odos',
    '🧑🏿‍🎨' => 'tapytojas: itin tamsios odos',
    '👨🏻‍🎨' => 'dailininkas: šviesios odos',
    '👨🏼‍🎨' => 'dailininkas: vidutinio gymio',
    '👨🏽‍🎨' => 'dailininkas: rusvos odos',
    '👨🏾‍🎨' => 'dailininkas: tamsios odos',
    '👨🏿‍🎨' => 'dailininkas: itin tamsios odos',
    '👩🏻‍🎨' => 'dailininkė: šviesios odos',
    '👩🏼‍🎨' => 'dailininkė: vidutinio gymio',
    '👩🏽‍🎨' => 'dailininkė: rusvos odos',
    '👩🏾‍🎨' => 'dailininkė: tamsios odos',
    '👩🏿‍🎨' => 'dailininkė: itin tamsios odos',
    '🧑🏻‍✈' => 'pilotuojantis žmogus: šviesios odos',
    '🧑🏼‍✈' => 'pilotuojantis žmogus: vidutinio gymio',
    '🧑🏽‍✈' => 'pilotuojantis žmogus: rusvos odos',
    '🧑🏾‍✈' => 'pilotuojantis žmogus: tamsios odos',
    '🧑🏿‍✈' => 'pilotuojantis žmogus: itin tamsios odos',
    '👨🏻‍✈' => 'pilotas: šviesios odos',
    '👨🏼‍✈' => 'pilotas: vidutinio gymio',
    '👨🏽‍✈' => 'pilotas: rusvos odos',
    '👨🏾‍✈' => 'pilotas: tamsios odos',
    '👨🏿‍✈' => 'pilotas: itin tamsios odos',
    '👩🏻‍✈' => 'pilotė: šviesios odos',
    '👩🏼‍✈' => 'pilotė: vidutinio gymio',
    '👩🏽‍✈' => 'pilotė: rusvos odos',
    '👩🏾‍✈' => 'pilotė: tamsios odos',
    '👩🏿‍✈' => 'pilotė: itin tamsios odos',
    '🧑🏻‍🚀' => 'kosmonautas: šviesios odos',
    '🧑🏼‍🚀' => 'kosmonautas: vidutinio gymio',
    '🧑🏽‍🚀' => 'kosmonautas: rusvos odos',
    '🧑🏾‍🚀' => 'kosmonautas: tamsios odos',
    '🧑🏿‍🚀' => 'kosmonautas: itin tamsios odos',
    '👨🏻‍🚀' => 'astronautas: šviesios odos',
    '👨🏼‍🚀' => 'astronautas: vidutinio gymio',
    '👨🏽‍🚀' => 'astronautas: rusvos odos',
    '👨🏾‍🚀' => 'astronautas: tamsios odos',
    '👨🏿‍🚀' => 'astronautas: itin tamsios odos',
    '👩🏻‍🚀' => 'astronautė: šviesios odos',
    '👩🏼‍🚀' => 'astronautė: vidutinio gymio',
    '👩🏽‍🚀' => 'astronautė: rusvos odos',
    '👩🏾‍🚀' => 'astronautė: tamsios odos',
    '👩🏿‍🚀' => 'astronautė: itin tamsios odos',
    '🧑🏻‍🚒' => 'ugniagesys: šviesios odos',
    '🧑🏼‍🚒' => 'ugniagesys: vidutinio gymio',
    '🧑🏽‍🚒' => 'ugniagesys: rusvos odos',
    '🧑🏾‍🚒' => 'ugniagesys: tamsios odos',
    '🧑🏿‍🚒' => 'ugniagesys: itin tamsios odos',
    '👨🏻‍🚒' => 'gaisrininkas: šviesios odos',
    '👨🏼‍🚒' => 'gaisrininkas: vidutinio gymio',
    '👨🏽‍🚒' => 'gaisrininkas: rusvos odos',
    '👨🏾‍🚒' => 'gaisrininkas: tamsios odos',
    '👨🏿‍🚒' => 'gaisrininkas: itin tamsios odos',
    '👩🏻‍🚒' => 'gaisrininkė: šviesios odos',
    '👩🏼‍🚒' => 'gaisrininkė: vidutinio gymio',
    '👩🏽‍🚒' => 'gaisrininkė: rusvos odos',
    '👩🏾‍🚒' => 'gaisrininkė: tamsios odos',
    '👩🏿‍🚒' => 'gaisrininkė: itin tamsios odos',
    '👮🏻‍♂' => 'vyras policininkas: šviesios odos',
    '👮🏼‍♂' => 'vyras policininkas: vidutinio gymio',
    '👮🏽‍♂' => 'vyras policininkas: rusvos odos',
    '👮🏾‍♂' => 'vyras policininkas: tamsios odos',
    '👮🏿‍♂' => 'vyras policininkas: itin tamsios odos',
    '👮🏻‍♀' => 'moteris policininkė: šviesios odos',
    '👮🏼‍♀' => 'moteris policininkė: vidutinio gymio',
    '👮🏽‍♀' => 'moteris policininkė: rusvos odos',
    '👮🏾‍♀' => 'moteris policininkė: tamsios odos',
    '👮🏿‍♀' => 'moteris policininkė: itin tamsios odos',
    '🕵🏻‍♂' => 'seklys: šviesios odos',
    '🕵🏼‍♂' => 'seklys: vidutinio gymio',
    '🕵🏽‍♂' => 'seklys: rusvos odos',
    '🕵🏾‍♂' => 'seklys: tamsios odos',
    '🕵🏿‍♂' => 'seklys: itin tamsios odos',
    '🕵🏻‍♀' => 'seklė: šviesios odos',
    '🕵🏼‍♀' => 'seklė: vidutinio gymio',
    '🕵🏽‍♀' => 'seklė: rusvos odos',
    '🕵🏾‍♀' => 'seklė: tamsios odos',
    '🕵🏿‍♀' => 'seklė: itin tamsios odos',
    '💂🏻‍♂' => 'vyras sargybinis: šviesios odos',
    '💂🏼‍♂' => 'vyras sargybinis: vidutinio gymio',
    '💂🏽‍♂' => 'vyras sargybinis: rusvos odos',
    '💂🏾‍♂' => 'vyras sargybinis: tamsios odos',
    '💂🏿‍♂' => 'vyras sargybinis: itin tamsios odos',
    '💂🏻‍♀' => 'sargybinė: šviesios odos',
    '💂🏼‍♀' => 'sargybinė: vidutinio gymio',
    '💂🏽‍♀' => 'sargybinė: rusvos odos',
    '💂🏾‍♀' => 'sargybinė: tamsios odos',
    '💂🏿‍♀' => 'sargybinė: itin tamsios odos',
    '👷🏻‍♂' => 'vyras statybininkas: šviesios odos',
    '👷🏼‍♂' => 'vyras statybininkas: vidutinio gymio',
    '👷🏽‍♂' => 'vyras statybininkas: rusvos odos',
    '👷🏾‍♂' => 'vyras statybininkas: tamsios odos',
    '👷🏿‍♂' => 'vyras statybininkas: itin tamsios odos',
    '👷🏻‍♀' => 'statybininkė: šviesios odos',
    '👷🏼‍♀' => 'statybininkė: vidutinio gymio',
    '👷🏽‍♀' => 'statybininkė: rusvos odos',
    '👷🏾‍♀' => 'statybininkė: tamsios odos',
    '👷🏿‍♀' => 'statybininkė: itin tamsios odos',
    '👳🏻‍♂' => 'vyriškis su turbanu: šviesios odos',
    '👳🏼‍♂' => 'vyriškis su turbanu: vidutinio gymio',
    '👳🏽‍♂' => 'vyriškis su turbanu: rusvos odos',
    '👳🏾‍♂' => 'vyriškis su turbanu: tamsios odos',
    '👳🏿‍♂' => 'vyriškis su turbanu: itin tamsios odos',
    '👳🏻‍♀' => 'moteris su turbanu: šviesios odos',
    '👳🏼‍♀' => 'moteris su turbanu: vidutinio gymio',
    '👳🏽‍♀' => 'moteris su turbanu: rusvos odos',
    '👳🏾‍♀' => 'moteris su turbanu: tamsios odos',
    '👳🏿‍♀' => 'moteris su turbanu: itin tamsios odos',
    '🤵🏻‍♂' => 'vyras su smokingu: šviesios odos',
    '🤵🏼‍♂' => 'vyras su smokingu: vidutinio gymio',
    '🤵🏽‍♂' => 'vyras su smokingu: rusvos odos',
    '🤵🏾‍♂' => 'vyras su smokingu: tamsios odos',
    '🤵🏿‍♂' => 'vyras su smokingu: itin tamsios odos',
    '🤵🏻‍♀' => 'moteris su smokingu: šviesios odos',
    '🤵🏼‍♀' => 'moteris su smokingu: vidutinio gymio',
    '🤵🏽‍♀' => 'moteris su smokingu: rusvos odos',
    '🤵🏾‍♀' => 'moteris su smokingu: tamsios odos',
    '🤵🏿‍♀' => 'moteris su smokingu: itin tamsios odos',
    '👰🏻‍♂' => 'vyras su veliumu: šviesios odos',
    '👰🏼‍♂' => 'vyras su veliumu: vidutinio gymio',
    '👰🏽‍♂' => 'vyras su veliumu: rusvos odos',
    '👰🏾‍♂' => 'vyras su veliumu: tamsios odos',
    '👰🏿‍♂' => 'vyras su veliumu: itin tamsios odos',
    '👰🏻‍♀' => 'moteris su veliumu: šviesios odos',
    '👰🏼‍♀' => 'moteris su veliumu: vidutinio gymio',
    '👰🏽‍♀' => 'moteris su veliumu: rusvos odos',
    '👰🏾‍♀' => 'moteris su veliumu: tamsios odos',
    '👰🏿‍♀' => 'moteris su veliumu: itin tamsios odos',
    '👩🏻‍🍼' => 'kūdikį maitinanti moteris: šviesios odos',
    '👩🏼‍🍼' => 'kūdikį maitinanti moteris: vidutinio gymio',
    '👩🏽‍🍼' => 'kūdikį maitinanti moteris: rusvos odos',
    '👩🏾‍🍼' => 'kūdikį maitinanti moteris: tamsios odos',
    '👩🏿‍🍼' => 'kūdikį maitinanti moteris: itin tamsios odos',
    '👨🏻‍🍼' => 'kūdikį maitinantis vyras: šviesios odos',
    '👨🏼‍🍼' => 'kūdikį maitinantis vyras: vidutinio gymio',
    '👨🏽‍🍼' => 'kūdikį maitinantis vyras: rusvos odos',
    '👨🏾‍🍼' => 'kūdikį maitinantis vyras: tamsios odos',
    '👨🏿‍🍼' => 'kūdikį maitinantis vyras: itin tamsios odos',
    '🧑🏻‍🍼' => 'kūdikį maitinantis asmuo: šviesios odos',
    '🧑🏼‍🍼' => 'kūdikį maitinantis asmuo: vidutinio gymio',
    '🧑🏽‍🍼' => 'kūdikį maitinantis asmuo: rusvos odos',
    '🧑🏾‍🍼' => 'kūdikį maitinantis asmuo: tamsios odos',
    '🧑🏿‍🍼' => 'kūdikį maitinantis asmuo: itin tamsios odos',
    '🧑🏻‍🎄' => 'Kalėdų asmuo: šviesios odos',
    '🧑🏼‍🎄' => 'Kalėdų asmuo: vidutinio gymio',
    '🧑🏽‍🎄' => 'Kalėdų asmuo: rusvos odos',
    '🧑🏾‍🎄' => 'Kalėdų asmuo: tamsios odos',
    '🧑🏿‍🎄' => 'Kalėdų asmuo: itin tamsios odos',
    '🦸🏻‍♂' => 'vyras superherojus: šviesios odos',
    '🦸🏼‍♂' => 'vyras superherojus: vidutinio gymio',
    '🦸🏽‍♂' => 'vyras superherojus: rusvos odos',
    '🦸🏾‍♂' => 'vyras superherojus: tamsios odos',
    '🦸🏿‍♂' => 'vyras superherojus: itin tamsios odos',
    '🦸🏻‍♀' => 'moteris superherojė: šviesios odos',
    '🦸🏼‍♀' => 'moteris superherojė: vidutinio gymio',
    '🦸🏽‍♀' => 'moteris superherojė: rusvos odos',
    '🦸🏾‍♀' => 'moteris superherojė: tamsios odos',
    '🦸🏿‍♀' => 'moteris superherojė: itin tamsios odos',
    '🦹🏻‍♂' => 'vyras piktadarys: šviesios odos',
    '🦹🏼‍♂' => 'vyras piktadarys: vidutinio gymio',
    '🦹🏽‍♂' => 'vyras piktadarys: rusvos odos',
    '🦹🏾‍♂' => 'vyras piktadarys: tamsios odos',
    '🦹🏿‍♂' => 'vyras piktadarys: itin tamsios odos',
    '🦹🏻‍♀' => 'moteris piktadarė: šviesios odos',
    '🦹🏼‍♀' => 'moteris piktadarė: vidutinio gymio',
    '🦹🏽‍♀' => 'moteris piktadarė: rusvos odos',
    '🦹🏾‍♀' => 'moteris piktadarė: tamsios odos',
    '🦹🏿‍♀' => 'moteris piktadarė: itin tamsios odos',
    '🧙🏻‍♂' => 'vyras magas: šviesios odos',
    '🧙🏼‍♂' => 'vyras magas: vidutinio gymio',
    '🧙🏽‍♂' => 'vyras magas: rusvos odos',
    '🧙🏾‍♂' => 'vyras magas: tamsios odos',
    '🧙🏿‍♂' => 'vyras magas: itin tamsios odos',
    '🧙🏻‍♀' => 'magė: šviesios odos',
    '🧙🏼‍♀' => 'magė: vidutinio gymio',
    '🧙🏽‍♀' => 'magė: rusvos odos',
    '🧙🏾‍♀' => 'magė: tamsios odos',
    '🧙🏿‍♀' => 'magė: itin tamsios odos',
    '🧚🏻‍♂' => 'burtininkas: šviesios odos',
    '🧚🏼‍♂' => 'burtininkas: vidutinio gymio',
    '🧚🏽‍♂' => 'burtininkas: rusvos odos',
    '🧚🏾‍♂' => 'burtininkas: tamsios odos',
    '🧚🏿‍♂' => 'burtininkas: itin tamsios odos',
    '🧚🏻‍♀' => 'moteris fėja: šviesios odos',
    '🧚🏼‍♀' => 'moteris fėja: vidutinio gymio',
    '🧚🏽‍♀' => 'moteris fėja: rusvos odos',
    '🧚🏾‍♀' => 'moteris fėja: tamsios odos',
    '🧚🏿‍♀' => 'moteris fėja: itin tamsios odos',
    '🧛🏻‍♂' => 'vampyras vyras: šviesios odos',
    '🧛🏼‍♂' => 'vampyras vyras: vidutinio gymio',
    '🧛🏽‍♂' => 'vampyras vyras: rusvos odos',
    '🧛🏾‍♂' => 'vampyras vyras: tamsios odos',
    '🧛🏿‍♂' => 'vampyras vyras: itin tamsios odos',
    '🧛🏻‍♀' => 'vampyrė: šviesios odos',
    '🧛🏼‍♀' => 'vampyrė: vidutinio gymio',
    '🧛🏽‍♀' => 'vampyrė: rusvos odos',
    '🧛🏾‍♀' => 'vampyrė: tamsios odos',
    '🧛🏿‍♀' => 'vampyrė: itin tamsios odos',
    '🧜🏻‍♂' => 'vandenis/undinius: šviesios odos',
    '🧜🏼‍♂' => 'vandenis/undinius: vidutinio gymio',
    '🧜🏽‍♂' => 'vandenis/undinius: rusvos odos',
    '🧜🏾‍♂' => 'vandenis/undinius: tamsios odos',
    '🧜🏿‍♂' => 'vandenis/undinius: itin tamsios odos',
    '🧜🏻‍♀' => 'undinėlė: šviesios odos',
    '🧜🏼‍♀' => 'undinėlė: vidutinio gymio',
    '🧜🏽‍♀' => 'undinėlė: rusvos odos',
    '🧜🏾‍♀' => 'undinėlė: tamsios odos',
    '🧜🏿‍♀' => 'undinėlė: itin tamsios odos',
    '🧝🏻‍♂' => 'elfas vyras: šviesios odos',
    '🧝🏼‍♂' => 'elfas vyras: vidutinio gymio',
    '🧝🏽‍♂' => 'elfas vyras: rusvos odos',
    '🧝🏾‍♂' => 'elfas vyras: tamsios odos',
    '🧝🏿‍♂' => 'elfas vyras: itin tamsios odos',
    '🧝🏻‍♀' => 'elfė: šviesios odos',
    '🧝🏼‍♀' => 'elfė: vidutinio gymio',
    '🧝🏽‍♀' => 'elfė: rusvos odos',
    '🧝🏾‍♀' => 'elfė: tamsios odos',
    '🧝🏿‍♀' => 'elfė: itin tamsios odos',
    '💆🏻‍♂' => 'masažuojama vyro galva: šviesios odos',
    '💆🏼‍♂' => 'masažuojama vyro galva: vidutinio gymio',
    '💆🏽‍♂' => 'masažuojama vyro galva: rusvos odos',
    '💆🏾‍♂' => 'masažuojama vyro galva: tamsios odos',
    '💆🏿‍♂' => 'masažuojama vyro galva: itin tamsios odos',
    '💆🏻‍♀' => 'masažuojama moters galva: šviesios odos',
    '💆🏼‍♀' => 'masažuojama moters galva: vidutinio gymio',
    '💆🏽‍♀' => 'masažuojama moters galva: rusvos odos',
    '💆🏾‍♀' => 'masažuojama moters galva: tamsios odos',
    '💆🏿‍♀' => 'masažuojama moters galva: itin tamsios odos',
    '💇🏻‍♂' => 'apkerpamas vyras: šviesios odos',
    '💇🏼‍♂' => 'apkerpamas vyras: vidutinio gymio',
    '💇🏽‍♂' => 'apkerpamas vyras: rusvos odos',
    '💇🏾‍♂' => 'apkerpamas vyras: tamsios odos',
    '💇🏿‍♂' => 'apkerpamas vyras: itin tamsios odos',
    '💇🏻‍♀' => 'apkerpama moteris: šviesios odos',
    '💇🏼‍♀' => 'apkerpama moteris: vidutinio gymio',
    '💇🏽‍♀' => 'apkerpama moteris: rusvos odos',
    '💇🏾‍♀' => 'apkerpama moteris: tamsios odos',
    '💇🏿‍♀' => 'apkerpama moteris: itin tamsios odos',
    '🚶🏻‍♂' => 'einantis vyras: šviesios odos',
    '🚶🏼‍♂' => 'einantis vyras: vidutinio gymio',
    '🚶🏽‍♂' => 'einantis vyras: rusvos odos',
    '🚶🏾‍♂' => 'einantis vyras: tamsios odos',
    '🚶🏿‍♂' => 'einantis vyras: itin tamsios odos',
    '🚶🏻‍♀' => 'einanti moteris: šviesios odos',
    '🚶🏼‍♀' => 'einanti moteris: vidutinio gymio',
    '🚶🏽‍♀' => 'einanti moteris: rusvos odos',
    '🚶🏾‍♀' => 'einanti moteris: tamsios odos',
    '🚶🏿‍♀' => 'einanti moteris: itin tamsios odos',
    '🚶🏻‍➡' => 'pėstysis: šviesios odos atsisukęs į dešinę',
    '🚶🏼‍➡' => 'pėstysis: vidutinio gymio atsisukęs į dešinę',
    '🚶🏽‍➡' => 'pėstysis: rusvos odos atsisukęs į dešinę',
    '🚶🏾‍➡' => 'pėstysis: tamsios odos atsisukęs į dešinę',
    '🚶🏿‍➡' => 'pėstysis: itin tamsios odos atsisukęs į dešinę',
    '🧍🏻‍♂' => 'stovintis vyras: šviesios odos',
    '🧍🏼‍♂' => 'stovintis vyras: vidutinio gymio',
    '🧍🏽‍♂' => 'stovintis vyras: rusvos odos',
    '🧍🏾‍♂' => 'stovintis vyras: tamsios odos',
    '🧍🏿‍♂' => 'stovintis vyras: itin tamsios odos',
    '🧍🏻‍♀' => 'stovinti moteris: šviesios odos',
    '🧍🏼‍♀' => 'stovinti moteris: vidutinio gymio',
    '🧍🏽‍♀' => 'stovinti moteris: rusvos odos',
    '🧍🏾‍♀' => 'stovinti moteris: tamsios odos',
    '🧍🏿‍♀' => 'stovinti moteris: itin tamsios odos',
    '🧎🏻‍♂' => 'klūpantis vyras: šviesios odos',
    '🧎🏼‍♂' => 'klūpantis vyras: vidutinio gymio',
    '🧎🏽‍♂' => 'klūpantis vyras: rusvos odos',
    '🧎🏾‍♂' => 'klūpantis vyras: tamsios odos',
    '🧎🏿‍♂' => 'klūpantis vyras: itin tamsios odos',
    '🧎🏻‍♀' => 'klūpanti moteris: šviesios odos',
    '🧎🏼‍♀' => 'klūpanti moteris: vidutinio gymio',
    '🧎🏽‍♀' => 'klūpanti moteris: rusvos odos',
    '🧎🏾‍♀' => 'klūpanti moteris: tamsios odos',
    '🧎🏿‍♀' => 'klūpanti moteris: itin tamsios odos',
    '🧎🏻‍➡' => 'klūpantis žmogus: šviesios odos atsisukęs į dešinę',
    '🧎🏼‍➡' => 'klūpantis žmogus: vidutinio gymio atsisukęs į dešinę',
    '🧎🏽‍➡' => 'klūpantis žmogus: rusvos odos atsisukęs į dešinę',
    '🧎🏾‍➡' => 'klūpantis žmogus: tamsios odos atsisukęs į dešinę',
    '🧎🏿‍➡' => 'klūpantis žmogus: itin tamsios odos atsisukęs į dešinę',
    '🧑🏻‍🦯' => 'žmogus neregio lazdele: šviesios odos',
    '🧑🏼‍🦯' => 'žmogus neregio lazdele: vidutinio gymio',
    '🧑🏽‍🦯' => 'žmogus neregio lazdele: rusvos odos',
    '🧑🏾‍🦯' => 'žmogus neregio lazdele: tamsios odos',
    '🧑🏿‍🦯' => 'žmogus neregio lazdele: itin tamsios odos',
    '👨🏻‍🦯' => 'vyras su neregio lazdele: šviesios odos',
    '👨🏼‍🦯' => 'vyras su neregio lazdele: vidutinio gymio',
    '👨🏽‍🦯' => 'vyras su neregio lazdele: rusvos odos',
    '👨🏾‍🦯' => 'vyras su neregio lazdele: tamsios odos',
    '👨🏿‍🦯' => 'vyras su neregio lazdele: itin tamsios odos',
    '👩🏻‍🦯' => 'moteris su neregio lazdele: šviesios odos',
    '👩🏼‍🦯' => 'moteris su neregio lazdele: vidutinio gymio',
    '👩🏽‍🦯' => 'moteris su neregio lazdele: rusvos odos',
    '👩🏾‍🦯' => 'moteris su neregio lazdele: tamsios odos',
    '👩🏿‍🦯' => 'moteris su neregio lazdele: itin tamsios odos',
    '🧑🏻‍🦼' => 'žmogus motorizuotame vežimėlyje: šviesios odos',
    '🧑🏼‍🦼' => 'žmogus motorizuotame vežimėlyje: vidutinio gymio',
    '🧑🏽‍🦼' => 'žmogus motorizuotame vežimėlyje: rusvos odos',
    '🧑🏾‍🦼' => 'žmogus motorizuotame vežimėlyje: tamsios odos',
    '🧑🏿‍🦼' => 'žmogus motorizuotame vežimėlyje: itin tamsios odos',
    '👨🏻‍🦼' => 'vyras motorizuotame vežimėlyje: šviesios odos',
    '👨🏼‍🦼' => 'vyras motorizuotame vežimėlyje: vidutinio gymio',
    '👨🏽‍🦼' => 'vyras motorizuotame vežimėlyje: rusvos odos',
    '👨🏾‍🦼' => 'vyras motorizuotame vežimėlyje: tamsios odos',
    '👨🏿‍🦼' => 'vyras motorizuotame vežimėlyje: itin tamsios odos',
    '👩🏻‍🦼' => 'moteris motorizuotame vežimėlyje: šviesios odos',
    '👩🏼‍🦼' => 'moteris motorizuotame vežimėlyje: vidutinio gymio',
    '👩🏽‍🦼' => 'moteris motorizuotame vežimėlyje: rusvos odos',
    '👩🏾‍🦼' => 'moteris motorizuotame vežimėlyje: tamsios odos',
    '👩🏿‍🦼' => 'moteris motorizuotame vežimėlyje: itin tamsios odos',
    '🧑🏻‍🦽' => 'žmogus rankomis valdomame vežimėlyje: šviesios odos',
    '🧑🏼‍🦽' => 'žmogus rankomis valdomame vežimėlyje: vidutinio gymio',
    '🧑🏽‍🦽' => 'žmogus rankomis valdomame vežimėlyje: rusvos odos',
    '🧑🏾‍🦽' => 'žmogus rankomis valdomame vežimėlyje: tamsios odos',
    '🧑🏿‍🦽' => 'žmogus rankomis valdomame vežimėlyje: itin tamsios odos',
    '👨🏻‍🦽' => 'vyras rankomis valdomame vežimėlyje: šviesios odos',
    '👨🏼‍🦽' => 'vyras rankomis valdomame vežimėlyje: vidutinio gymio',
    '👨🏽‍🦽' => 'vyras rankomis valdomame vežimėlyje: rusvos odos',
    '👨🏾‍🦽' => 'vyras rankomis valdomame vežimėlyje: tamsios odos',
    '👨🏿‍🦽' => 'vyras rankomis valdomame vežimėlyje: itin tamsios odos',
    '👩🏻‍🦽' => 'moteris rankomis valdomame vežimėlyje: šviesios odos',
    '👩🏼‍🦽' => 'moteris rankomis valdomame vežimėlyje: vidutinio gymio',
    '👩🏽‍🦽' => 'moteris rankomis valdomame vežimėlyje: rusvos odos',
    '👩🏾‍🦽' => 'moteris rankomis valdomame vežimėlyje: tamsios odos',
    '👩🏿‍🦽' => 'moteris rankomis valdomame vežimėlyje: itin tamsios odos',
    '🏃🏻‍♂' => 'bėgantis vyras: šviesios odos',
    '🏃🏼‍♂' => 'bėgantis vyras: vidutinio gymio',
    '🏃🏽‍♂' => 'bėgantis vyras: rusvos odos',
    '🏃🏾‍♂' => 'bėgantis vyras: tamsios odos',
    '🏃🏿‍♂' => 'bėgantis vyras: itin tamsios odos',
    '🏃🏻‍♀' => 'bėganti moteris: šviesios odos',
    '🏃🏼‍♀' => 'bėganti moteris: vidutinio gymio',
    '🏃🏽‍♀' => 'bėganti moteris: rusvos odos',
    '🏃🏾‍♀' => 'bėganti moteris: tamsios odos',
    '🏃🏿‍♀' => 'bėganti moteris: itin tamsios odos',
    '🏃🏻‍➡' => 'bėgikas: šviesios odos atsisukęs į dešinę',
    '🏃🏼‍➡' => 'bėgikas: vidutinio gymio atsisukęs į dešinę',
    '🏃🏽‍➡' => 'bėgikas: rusvos odos atsisukęs į dešinę',
    '🏃🏾‍➡' => 'bėgikas: tamsios odos atsisukęs į dešinę',
    '🏃🏿‍➡' => 'bėgikas: itin tamsios odos atsisukęs į dešinę',
    '👯🏻‍♀' => 'vakarėlyje dalyvaujančios moterys: šviesios odos',
    '👯🏼‍♀' => 'vakarėlyje dalyvaujančios moterys: vidutinio gymio',
    '👯🏽‍♀' => 'vakarėlyje dalyvaujančios moterys: rusvos odos',
    '👯🏾‍♀' => 'vakarėlyje dalyvaujančios moterys: tamsios odos',
    '👯🏿‍♀' => 'vakarėlyje dalyvaujančios moterys: itin tamsios odos',
    '👯🏻‍♂' => 'vakarėlyje dalyvaujantys vyrai: šviesios odos',
    '👯🏼‍♂' => 'vakarėlyje dalyvaujantys vyrai: vidutinio gymio',
    '👯🏽‍♂' => 'vakarėlyje dalyvaujantys vyrai: rusvos odos',
    '👯🏾‍♂' => 'vakarėlyje dalyvaujantys vyrai: tamsios odos',
    '👯🏿‍♂' => 'vakarėlyje dalyvaujantys vyrai: itin tamsios odos',
    '🧖🏻‍♂' => 'vyras garų kambaryje: šviesios odos',
    '🧖🏼‍♂' => 'vyras garų kambaryje: vidutinio gymio',
    '🧖🏽‍♂' => 'vyras garų kambaryje: rusvos odos',
    '🧖🏾‍♂' => 'vyras garų kambaryje: tamsios odos',
    '🧖🏿‍♂' => 'vyras garų kambaryje: itin tamsios odos',
    '🧖🏻‍♀' => 'moteris garų kambaryje: šviesios odos',
    '🧖🏼‍♀' => 'moteris garų kambaryje: vidutinio gymio',
    '🧖🏽‍♀' => 'moteris garų kambaryje: rusvos odos',
    '🧖🏾‍♀' => 'moteris garų kambaryje: tamsios odos',
    '🧖🏿‍♀' => 'moteris garų kambaryje: itin tamsios odos',
    '🧗🏻‍♂' => 'kopiantis vyras: šviesios odos',
    '🧗🏼‍♂' => 'kopiantis vyras: vidutinio gymio',
    '🧗🏽‍♂' => 'kopiantis vyras: rusvos odos',
    '🧗🏾‍♂' => 'kopiantis vyras: tamsios odos',
    '🧗🏿‍♂' => 'kopiantis vyras: itin tamsios odos',
    '🧗🏻‍♀' => 'kopianti moteris: šviesios odos',
    '🧗🏼‍♀' => 'kopianti moteris: vidutinio gymio',
    '🧗🏽‍♀' => 'kopianti moteris: rusvos odos',
    '🧗🏾‍♀' => 'kopianti moteris: tamsios odos',
    '🧗🏿‍♀' => 'kopianti moteris: itin tamsios odos',
    '🏌🏻‍♂' => 'golfo žaidėjas vyras: šviesios odos',
    '🏌🏼‍♂' => 'golfo žaidėjas vyras: vidutinio gymio',
    '🏌🏽‍♂' => 'golfo žaidėjas vyras: rusvos odos',
    '🏌🏾‍♂' => 'golfo žaidėjas vyras: tamsios odos',
    '🏌🏿‍♂' => 'golfo žaidėjas vyras: itin tamsios odos',
    '🏌🏻‍♀' => 'golfo žaidėja: šviesios odos',
    '🏌🏼‍♀' => 'golfo žaidėja: vidutinio gymio',
    '🏌🏽‍♀' => 'golfo žaidėja: rusvos odos',
    '🏌🏾‍♀' => 'golfo žaidėja: tamsios odos',
    '🏌🏿‍♀' => 'golfo žaidėja: itin tamsios odos',
    '🏄🏻‍♂' => 'vyras banglentininkas: šviesios odos',
    '🏄🏼‍♂' => 'vyras banglentininkas: vidutinio gymio',
    '🏄🏽‍♂' => 'vyras banglentininkas: rusvos odos',
    '🏄🏾‍♂' => 'vyras banglentininkas: tamsios odos',
    '🏄🏿‍♂' => 'vyras banglentininkas: itin tamsios odos',
    '🏄🏻‍♀' => 'banglentininkė: šviesios odos',
    '🏄🏼‍♀' => 'banglentininkė: vidutinio gymio',
    '🏄🏽‍♀' => 'banglentininkė: rusvos odos',
    '🏄🏾‍♀' => 'banglentininkė: tamsios odos',
    '🏄🏿‍♀' => 'banglentininkė: itin tamsios odos',
    '🚣🏻‍♂' => 'irkluotojas: šviesios odos',
    '🚣🏼‍♂' => 'irkluotojas: vidutinio gymio',
    '🚣🏽‍♂' => 'irkluotojas: rusvos odos',
    '🚣🏾‍♂' => 'irkluotojas: tamsios odos',
    '🚣🏿‍♂' => 'irkluotojas: itin tamsios odos',
    '🚣🏻‍♀' => 'irkluotoja: šviesios odos',
    '🚣🏼‍♀' => 'irkluotoja: vidutinio gymio',
    '🚣🏽‍♀' => 'irkluotoja: rusvos odos',
    '🚣🏾‍♀' => 'irkluotoja: tamsios odos',
    '🚣🏿‍♀' => 'irkluotoja: itin tamsios odos',
    '🏊🏻‍♂' => 'vyras plaukikas: šviesios odos',
    '🏊🏼‍♂' => 'vyras plaukikas: vidutinio gymio',
    '🏊🏽‍♂' => 'vyras plaukikas: rusvos odos',
    '🏊🏾‍♂' => 'vyras plaukikas: tamsios odos',
    '🏊🏿‍♂' => 'vyras plaukikas: itin tamsios odos',
    '🏊🏻‍♀' => 'plaukikė: šviesios odos',
    '🏊🏼‍♀' => 'plaukikė: vidutinio gymio',
    '🏊🏽‍♀' => 'plaukikė: rusvos odos',
    '🏊🏾‍♀' => 'plaukikė: tamsios odos',
    '🏊🏿‍♀' => 'plaukikė: itin tamsios odos',
    '⛹🏻‍♂' => 'vyras su kamuoliu: šviesios odos',
    '⛹🏼‍♂' => 'vyras su kamuoliu: vidutinio gymio',
    '⛹🏽‍♂' => 'vyras su kamuoliu: rusvos odos',
    '⛹🏾‍♂' => 'vyras su kamuoliu: tamsios odos',
    '⛹🏿‍♂' => 'vyras su kamuoliu: itin tamsios odos',
    '⛹🏻‍♀' => 'moteris su kamuoliu: šviesios odos',
    '⛹🏼‍♀' => 'moteris su kamuoliu: vidutinio gymio',
    '⛹🏽‍♀' => 'moteris su kamuoliu: rusvos odos',
    '⛹🏾‍♀' => 'moteris su kamuoliu: tamsios odos',
    '⛹🏿‍♀' => 'moteris su kamuoliu: itin tamsios odos',
    '🏋🏻‍♂' => 'svorius keliantis vyras: šviesios odos',
    '🏋🏼‍♂' => 'svorius keliantis vyras: vidutinio gymio',
    '🏋🏽‍♂' => 'svorius keliantis vyras: rusvos odos',
    '🏋🏾‍♂' => 'svorius keliantis vyras: tamsios odos',
    '🏋🏿‍♂' => 'svorius keliantis vyras: itin tamsios odos',
    '🏋🏻‍♀' => 'svorius kelianti moteris: šviesios odos',
    '🏋🏼‍♀' => 'svorius kelianti moteris: vidutinio gymio',
    '🏋🏽‍♀' => 'svorius kelianti moteris: rusvos odos',
    '🏋🏾‍♀' => 'svorius kelianti moteris: tamsios odos',
    '🏋🏿‍♀' => 'svorius kelianti moteris: itin tamsios odos',
    '🚴🏻‍♂' => 'vyras dviratininkas: šviesios odos',
    '🚴🏼‍♂' => 'vyras dviratininkas: vidutinio gymio',
    '🚴🏽‍♂' => 'vyras dviratininkas: rusvos odos',
    '🚴🏾‍♂' => 'vyras dviratininkas: tamsios odos',
    '🚴🏿‍♂' => 'vyras dviratininkas: itin tamsios odos',
    '🚴🏻‍♀' => 'dviratininkė: šviesios odos',
    '🚴🏼‍♀' => 'dviratininkė: vidutinio gymio',
    '🚴🏽‍♀' => 'dviratininkė: rusvos odos',
    '🚴🏾‍♀' => 'dviratininkė: tamsios odos',
    '🚴🏿‍♀' => 'dviratininkė: itin tamsios odos',
    '🚵🏻‍♂' => 'kalnų dviratininkas vyras: šviesios odos',
    '🚵🏼‍♂' => 'kalnų dviratininkas vyras: vidutinio gymio',
    '🚵🏽‍♂' => 'kalnų dviratininkas vyras: rusvos odos',
    '🚵🏾‍♂' => 'kalnų dviratininkas vyras: tamsios odos',
    '🚵🏿‍♂' => 'kalnų dviratininkas vyras: itin tamsios odos',
    '🚵🏻‍♀' => 'kalnų dviratininkė moteris: šviesios odos',
    '🚵🏼‍♀' => 'kalnų dviratininkė moteris: vidutinio gymio',
    '🚵🏽‍♀' => 'kalnų dviratininkė moteris: rusvos odos',
    '🚵🏾‍♀' => 'kalnų dviratininkė moteris: tamsios odos',
    '🚵🏿‍♀' => 'kalnų dviratininkė moteris: itin tamsios odos',
    '🤸🏻‍♂' => 'vyras daro suktuką: šviesios odos',
    '🤸🏼‍♂' => 'vyras daro suktuką: vidutinio gymio',
    '🤸🏽‍♂' => 'vyras daro suktuką: rusvos odos',
    '🤸🏾‍♂' => 'vyras daro suktuką: tamsios odos',
    '🤸🏿‍♂' => 'vyras daro suktuką: itin tamsios odos',
    '🤸🏻‍♀' => 'moteris daro suktuką: šviesios odos',
    '🤸🏼‍♀' => 'moteris daro suktuką: vidutinio gymio',
    '🤸🏽‍♀' => 'moteris daro suktuką: rusvos odos',
    '🤸🏾‍♀' => 'moteris daro suktuką: tamsios odos',
    '🤸🏿‍♀' => 'moteris daro suktuką: itin tamsios odos',
    '🤼🏻‍♀' => 'moterų imtynės: šviesios odos',
    '🤼🏼‍♀' => 'moterų imtynės: vidutinio gymio',
    '🤼🏽‍♀' => 'moterų imtynės: rusvos odos',
    '🤼🏾‍♀' => 'moterų imtynės: tamsios odos',
    '🤼🏿‍♀' => 'moterų imtynės: itin tamsios odos',
    '🤼🏻‍♂' => 'vyrų imtynės: šviesios odos',
    '🤼🏼‍♂' => 'vyrų imtynės: vidutinio gymio',
    '🤼🏽‍♂' => 'vyrų imtynės: rusvos odos',
    '🤼🏾‍♂' => 'vyrų imtynės: tamsios odos',
    '🤼🏿‍♂' => 'vyrų imtynės: itin tamsios odos',
    '🤽🏻‍♂' => 'vandensvydžio žaidėjas: šviesios odos',
    '🤽🏼‍♂' => 'vandensvydžio žaidėjas: vidutinio gymio',
    '🤽🏽‍♂' => 'vandensvydžio žaidėjas: rusvos odos',
    '🤽🏾‍♂' => 'vandensvydžio žaidėjas: tamsios odos',
    '🤽🏿‍♂' => 'vandensvydžio žaidėjas: itin tamsios odos',
    '🤽🏻‍♀' => 'vandensvydžio žaidėja: šviesios odos',
    '🤽🏼‍♀' => 'vandensvydžio žaidėja: vidutinio gymio',
    '🤽🏽‍♀' => 'vandensvydžio žaidėja: rusvos odos',
    '🤽🏾‍♀' => 'vandensvydžio žaidėja: tamsios odos',
    '🤽🏿‍♀' => 'vandensvydžio žaidėja: itin tamsios odos',
    '🤾🏻‍♂' => 'rankininkas: šviesios odos',
    '🤾🏼‍♂' => 'rankininkas: vidutinio gymio',
    '🤾🏽‍♂' => 'rankininkas: rusvos odos',
    '🤾🏾‍♂' => 'rankininkas: tamsios odos',
    '🤾🏿‍♂' => 'rankininkas: itin tamsios odos',
    '🤾🏻‍♀' => 'rankininkė: šviesios odos',
    '🤾🏼‍♀' => 'rankininkė: vidutinio gymio',
    '🤾🏽‍♀' => 'rankininkė: rusvos odos',
    '🤾🏾‍♀' => 'rankininkė: tamsios odos',
    '🤾🏿‍♀' => 'rankininkė: itin tamsios odos',
    '🤹🏻‍♂' => 'žongliruotojas: šviesios odos',
    '🤹🏼‍♂' => 'žongliruotojas: vidutinio gymio',
    '🤹🏽‍♂' => 'žongliruotojas: rusvos odos',
    '🤹🏾‍♂' => 'žongliruotojas: tamsios odos',
    '🤹🏿‍♂' => 'žongliruotojas: itin tamsios odos',
    '🤹🏻‍♀' => 'žongliruotoja: šviesios odos',
    '🤹🏼‍♀' => 'žongliruotoja: vidutinio gymio',
    '🤹🏽‍♀' => 'žongliruotoja: rusvos odos',
    '🤹🏾‍♀' => 'žongliruotoja: tamsios odos',
    '🤹🏿‍♀' => 'žongliruotoja: itin tamsios odos',
    '🧘🏻‍♂' => 'vyras lotoso pozoje: šviesios odos',
    '🧘🏼‍♂' => 'vyras lotoso pozoje: vidutinio gymio',
    '🧘🏽‍♂' => 'vyras lotoso pozoje: rusvos odos',
    '🧘🏾‍♂' => 'vyras lotoso pozoje: tamsios odos',
    '🧘🏿‍♂' => 'vyras lotoso pozoje: itin tamsios odos',
    '🧘🏻‍♀' => 'moteris lotoso pozoje: šviesios odos',
    '🧘🏼‍♀' => 'moteris lotoso pozoje: vidutinio gymio',
    '🧘🏽‍♀' => 'moteris lotoso pozoje: rusvos odos',
    '🧘🏾‍♀' => 'moteris lotoso pozoje: tamsios odos',
    '🧘🏿‍♀' => 'moteris lotoso pozoje: itin tamsios odos',
    '🧑‍🦰' => 'suaugusysis: raudoni plaukai',
    '🧑‍🦱' => 'suaugusysis: garbanoti plaukai',
    '🧑‍🦳' => 'suaugusysis: žili plaukai',
    '🧑‍🦲' => 'suaugusysis: plikas',
    '👨‍🦰' => 'vyras: raudoni plaukai',
    '👨‍🦱' => 'vyras: garbanoti plaukai',
    '👨‍🦳' => 'vyras: žili plaukai',
    '👨‍🦲' => 'vyras: plikas',
    '👩‍🦰' => 'moteris: raudoni plaukai',
    '👩‍🦱' => 'moteris: garbanoti plaukai',
    '👩‍🦳' => 'moteris: žili plaukai',
    '👩‍🦲' => 'moteris: plikas',
    '🚶‍➡' => 'pėstysis: atsisukęs į dešinę',
    '🧎‍➡' => 'klūpantis žmogus: atsisukęs į dešinę',
    '🏃‍➡' => 'bėgikas: atsisukęs į dešinę',
    '👨‍👦' => 'šeima: vyras berniukas',
    '👨‍👧' => 'šeima: vyras mergaitė',
    '👩‍👦' => 'šeima: moteris berniukas',
    '👩‍👧' => 'šeima: moteris mergaitė',
    '😶‍🌫' => 'veidas debesyse',
    '😮‍💨' => 'veidas su garu',
    '🙂‍↕' => 'linksintis galva',
    '😵‍💫' => 'veidas su spiralinėmis akimis',
    '❤‍🔥' => 'deganti širdis',
    '❤‍🩹' => 'gydytina širdis',
    '👁‍🗨' => 'akis kalbėjimo burbule',
    '🧔‍♂' => 'vyras: barzda',
    '👱‍♂' => 'blondinas',
    '🧔‍♀' => 'moteris: barzda',
    '👱‍♀' => 'blondinė',
    '🙍‍♂' => 'paniuręs vyras',
    '🙍‍♀' => 'paniurusi moteris',
    '🙎‍♂' => 'susiraukęs vyras',
    '🙎‍♀' => 'susiraukusi moteris',
    '🙅‍♂' => 'draudžiantis vyras',
    '🙅‍♀' => 'draudžianti moteris',
    '🙆‍♂' => 'leidžiantis vyras',
    '🙆‍♀' => 'leidžianti moteris',
    '💁‍♂' => 'lengvai ranką pakėlęs vyras',
    '💁‍♀' => 'ranką pakėlusi moteris',
    '🙋‍♂' => 'ranką pakėlęs vyras',
    '🙋‍♀' => 'ranką iškėlusi moteris',
    '🧏‍♂' => 'kurčias vyras',
    '🧏‍♀' => 'kurčia moteris',
    '🙇‍♂' => 'nusilenkiantis vyras',
    '🙇‍♀' => 'nusilenkianti moteris',
    '🤦‍♂' => 'susierzinęs vyras',
    '🤦‍♀' => 'susierzinusi moteris',
    '🤷‍♂' => 'abejojantis vyras',
    '🤷‍♀' => 'abejojanti moteris',
    '🧑‍⚕' => 'sveikatos darbuotojas',
    '👨‍⚕' => 'medikas',
    '👩‍⚕' => 'medikė',
    '🧑‍🎓' => 'paskutinio kurso studentas',
    '👨‍🎓' => 'studentas',
    '👩‍🎓' => 'studentė',
    '🧑‍🏫' => 'mokantis žmogus',
    '👨‍🏫' => 'mokytojas',
    '👩‍🏫' => 'mokytoja',
    '🧑‍⚖' => 'teisiantis žmogus',
    '👨‍⚖' => 'teisėjas',
    '👩‍⚖' => 'teisėja',
    '🧑‍🌾' => 'ūkininkaujantis žmogus',
    '👨‍🌾' => 'ūkininkas',
    '👩‍🌾' => 'ūkininkė',
    '🧑‍🍳' => 'gaminantis žmogus',
    '👨‍🍳' => 'virėjas',
    '👩‍🍳' => 'virėja',
    '🧑‍🔧' => 'remontuojantis žmogus',
    '👨‍🔧' => 'mechanikas',
    '👩‍🔧' => 'mechanikė',
    '🧑‍🏭' => 'gamyklos darbuotojas',
    '👨‍🏭' => 'fabriko darbininkas',
    '👩‍🏭' => 'fabriko darbininkė',
    '🧑‍💼' => 'dirbantysis biure',
    '👨‍💼' => 'biuro darbuotojas',
    '👩‍💼' => 'biuro darbuotoja',
    '🧑‍🔬' => 'mokslo darbuotojas',
    '👨‍🔬' => 'mokslininkas',
    '👩‍🔬' => 'mokslininkė',
    '🧑‍💻' => 'technikas',
    '👨‍💻' => 'technologas',
    '👩‍💻' => 'technologė',
    '🧑‍🎤' => 'dainuojantis žmogus',
    '👨‍🎤' => 'dainininkas',
    '👩‍🎤' => 'dainininkė',
    '🧑‍🎨' => 'tapytojas',
    '👨‍🎨' => 'dailininkas',
    '👩‍🎨' => 'dailininkė',
    '🧑‍✈' => 'pilotuojantis žmogus',
    '👨‍✈' => 'pilotas',
    '👩‍✈' => 'pilotė',
    '🧑‍🚀' => 'kosmonautas',
    '👨‍🚀' => 'astronautas',
    '👩‍🚀' => 'astronautė',
    '🧑‍🚒' => 'ugniagesys',
    '👨‍🚒' => 'gaisrininkas',
    '👩‍🚒' => 'gaisrininkė',
    '👮‍♂' => 'vyras policininkas',
    '👮‍♀' => 'moteris policininkė',
    '🕵‍♂' => 'seklys',
    '🕵‍♀' => 'seklė',
    '💂‍♂' => 'vyras sargybinis',
    '💂‍♀' => 'sargybinė',
    '👷‍♂' => 'vyras statybininkas',
    '👷‍♀' => 'statybininkė',
    '👳‍♂' => 'vyriškis su turbanu',
    '👳‍♀' => 'moteris su turbanu',
    '🤵‍♂' => 'vyras su smokingu',
    '🤵‍♀' => 'moteris su smokingu',
    '👰‍♂' => 'vyras su veliumu',
    '👰‍♀' => 'moteris su veliumu',
    '👩‍🍼' => 'kūdikį maitinanti moteris',
    '👨‍🍼' => 'kūdikį maitinantis vyras',
    '🧑‍🍼' => 'kūdikį maitinantis asmuo',
    '🧑‍🎄' => 'Kalėdų asmuo',
    '🦸‍♂' => 'vyras superherojus',
    '🦸‍♀' => 'moteris superherojė',
    '🦹‍♂' => 'vyras piktadarys',
    '🦹‍♀' => 'moteris piktadarė',
    '🧙‍♂' => 'vyras magas',
    '🧙‍♀' => 'magė',
    '🧚‍♂' => 'burtininkas',
    '🧚‍♀' => 'moteris fėja',
    '🧛‍♂' => 'vampyras vyras',
    '🧛‍♀' => 'vampyrė',
    '🧜‍♂' => 'vandenis/undinius',
    '🧜‍♀' => 'undinėlė',
    '🧝‍♂' => 'elfas vyras',
    '🧝‍♀' => 'elfė',
    '🧞‍♂' => 'džinas',
    '🧞‍♀' => 'džinė',
    '🧟‍♂' => 'zombis vyras',
    '🧟‍♀' => 'zombė',
    '💆‍♂' => 'masažuojama vyro galva',
    '💆‍♀' => 'masažuojama moters galva',
    '💇‍♂' => 'apkerpamas vyras',
    '💇‍♀' => 'apkerpama moteris',
    '🚶‍♂' => 'einantis vyras',
    '🚶‍♀' => 'einanti moteris',
    '🧍‍♂' => 'stovintis vyras',
    '🧍‍♀' => 'stovinti moteris',
    '🧎‍♂' => 'klūpantis vyras',
    '🧎‍♀' => 'klūpanti moteris',
    '🧑‍🦯' => 'žmogus neregio lazdele',
    '👨‍🦯' => 'vyras su neregio lazdele',
    '👩‍🦯' => 'moteris su neregio lazdele',
    '🧑‍🦼' => 'žmogus motorizuotame vežimėlyje',
    '👨‍🦼' => 'vyras motorizuotame vežimėlyje',
    '👩‍🦼' => 'moteris motorizuotame vežimėlyje',
    '🧑‍🦽' => 'žmogus rankomis valdomame vežimėlyje',
    '👨‍🦽' => 'vyras rankomis valdomame vežimėlyje',
    '👩‍🦽' => 'moteris rankomis valdomame vežimėlyje',
    '🏃‍♂' => 'bėgantis vyras',
    '🏃‍♀' => 'bėganti moteris',
    '🧑‍🩰' => 'baleto šokėjas',
    '👯‍♂' => 'vakarėlyje dalyvaujantys vyrai',
    '👯‍♀' => 'vakarėlyje dalyvaujančios moterys',
    '🧖‍♂' => 'vyras garų kambaryje',
    '🧖‍♀' => 'moteris garų kambaryje',
    '🧗‍♂' => 'kopiantis vyras',
    '🧗‍♀' => 'kopianti moteris',
    '🏌‍♂' => 'golfo žaidėjas vyras',
    '🏌‍♀' => 'golfo žaidėja',
    '🏄‍♂' => 'vyras banglentininkas',
    '🏄‍♀' => 'banglentininkė',
    '🚣‍♂' => 'irkluotojas',
    '🚣‍♀' => 'irkluotoja',
    '🏊‍♂' => 'vyras plaukikas',
    '🏊‍♀' => 'plaukikė',
    '⛹‍♂' => 'vyras su kamuoliu',
    '⛹‍♀' => 'moteris su kamuoliu',
    '🏋‍♂' => 'svorius keliantis vyras',
    '🏋‍♀' => 'svorius kelianti moteris',
    '🚴‍♂' => 'vyras dviratininkas',
    '🚴‍♀' => 'dviratininkė',
    '🚵‍♂' => 'kalnų dviratininkas vyras',
    '🚵‍♀' => 'kalnų dviratininkė moteris',
    '🤸‍♂' => 'vyras daro suktuką',
    '🤸‍♀' => 'moteris daro suktuką',
    '🤼‍♂' => 'vyrų imtynės',
    '🤼‍♀' => 'moterų imtynės',
    '🤽‍♂' => 'vandensvydžio žaidėjas',
    '🤽‍♀' => 'vandensvydžio žaidėja',
    '🤾‍♂' => 'rankininkas',
    '🤾‍♀' => 'rankininkė',
    '🤹‍♂' => 'žongliruotojas',
    '🤹‍♀' => 'žongliruotoja',
    '🧘‍♂' => 'vyras lotoso pozoje',
    '🧘‍♀' => 'moteris lotoso pozoje',
    '🧑‍🧒' => 'šeima: suaugusysis, vaikas',
    '🐕‍🦺' => 'tarnaujantis šuo',
    '🐈‍⬛' => 'juoda katė',
    '🐻‍❄' => 'baltoji meška',
    '🐦‍⬛' => 'juodas paukštis',
    '🐦‍🔥' => 'feniksas',
    '🍋‍🟩' => 'žalioji citrina',
    '🍄‍🟫' => 'baravykas',
    '⛓‍💥' => 'nutraukta grandinė',
    '🏳‍🌈' => 'vaivorykštinė vėliava',
    '🏳‍⚧' => 'žydra, rožinė ir balta vėliava',
    '🏴‍☠' => 'piratų vėliava',
    '👋🏻' => 'mojuojanti ranka: šviesios odos',
    '👋🏼' => 'mojuojanti ranka: vidutinio gymio',
    '👋🏽' => 'mojuojanti ranka: rusvos odos',
    '👋🏾' => 'mojuojanti ranka: tamsios odos',
    '👋🏿' => 'mojuojanti ranka: itin tamsios odos',
    '🤚🏻' => 'pakelta viršutinė plaštakos pusė: šviesios odos',
    '🤚🏼' => 'pakelta viršutinė plaštakos pusė: vidutinio gymio',
    '🤚🏽' => 'pakelta viršutinė plaštakos pusė: rusvos odos',
    '🤚🏾' => 'pakelta viršutinė plaštakos pusė: tamsios odos',
    '🤚🏿' => 'pakelta viršutinė plaštakos pusė: itin tamsios odos',
    '🖐🏻' => 'iškelta ranka su išskėstais pirštais: šviesios odos',
    '🖐🏼' => 'iškelta ranka su išskėstais pirštais: vidutinio gymio',
    '🖐🏽' => 'iškelta ranka su išskėstais pirštais: rusvos odos',
    '🖐🏾' => 'iškelta ranka su išskėstais pirštais: tamsios odos',
    '🖐🏿' => 'iškelta ranka su išskėstais pirštais: itin tamsios odos',
    '✋🏻' => 'iškelta ranka: šviesios odos',
    '✋🏼' => 'iškelta ranka: vidutinio gymio',
    '✋🏽' => 'iškelta ranka: rusvos odos',
    '✋🏾' => 'iškelta ranka: tamsios odos',
    '✋🏿' => 'iškelta ranka: itin tamsios odos',
    '🖖🏻' => 'vulkanų rasės pasisveikinimo ženklas: šviesios odos',
    '🖖🏼' => 'vulkanų rasės pasisveikinimo ženklas: vidutinio gymio',
    '🖖🏽' => 'vulkanų rasės pasisveikinimo ženklas: rusvos odos',
    '🖖🏾' => 'vulkanų rasės pasisveikinimo ženklas: tamsios odos',
    '🖖🏿' => 'vulkanų rasės pasisveikinimo ženklas: itin tamsios odos',
    '🫱🏻' => 'į dešinę rodanti ranka: šviesios odos',
    '🫱🏼' => 'į dešinę rodanti ranka: vidutinio gymio',
    '🫱🏽' => 'į dešinę rodanti ranka: rusvos odos',
    '🫱🏾' => 'į dešinę rodanti ranka: tamsios odos',
    '🫱🏿' => 'į dešinę rodanti ranka: itin tamsios odos',
    '🫲🏻' => 'į kairę rodanti ranka: šviesios odos',
    '🫲🏼' => 'į kairę rodanti ranka: vidutinio gymio',
    '🫲🏽' => 'į kairę rodanti ranka: rusvos odos',
    '🫲🏾' => 'į kairę rodanti ranka: tamsios odos',
    '🫲🏿' => 'į kairę rodanti ranka: itin tamsios odos',
    '🫳🏻' => 'ranka delnu žemyn: šviesios odos',
    '🫳🏼' => 'ranka delnu žemyn: vidutinio gymio',
    '🫳🏽' => 'ranka delnu žemyn: rusvos odos',
    '🫳🏾' => 'ranka delnu žemyn: tamsios odos',
    '🫳🏿' => 'ranka delnu žemyn: itin tamsios odos',
    '🫴🏻' => 'ranka delnu į viršų: šviesios odos',
    '🫴🏼' => 'ranka delnu į viršų: vidutinio gymio',
    '🫴🏽' => 'ranka delnu į viršų: rusvos odos',
    '🫴🏾' => 'ranka delnu į viršų: tamsios odos',
    '🫴🏿' => 'ranka delnu į viršų: itin tamsios odos',
    '🫷🏻' => 'į kairę stumianti ranka: šviesios odos',
    '🫷🏼' => 'į kairę stumianti ranka: vidutinio gymio',
    '🫷🏽' => 'į kairę stumianti ranka: rusvos odos',
    '🫷🏾' => 'į kairę stumianti ranka: tamsios odos',
    '🫷🏿' => 'į kairę stumianti ranka: itin tamsios odos',
    '🫸🏻' => 'į dešinę stumianti ranka: šviesios odos',
    '🫸🏼' => 'į dešinę stumianti ranka: vidutinio gymio',
    '🫸🏽' => 'į dešinę stumianti ranka: rusvos odos',
    '🫸🏾' => 'į dešinę stumianti ranka: tamsios odos',
    '🫸🏿' => 'į dešinę stumianti ranka: itin tamsios odos',
    '👌🏻' => 'GERAI ženklas rankomis: šviesios odos',
    '👌🏼' => 'GERAI ženklas rankomis: vidutinio gymio',
    '👌🏽' => 'GERAI ženklas rankomis: rusvos odos',
    '👌🏾' => 'GERAI ženklas rankomis: tamsios odos',
    '👌🏿' => 'GERAI ženklas rankomis: itin tamsios odos',
    '🤌🏻' => 'suspausti pirštai: šviesios odos',
    '🤌🏼' => 'suspausti pirštai: vidutinio gymio',
    '🤌🏽' => 'suspausti pirštai: rusvos odos',
    '🤌🏾' => 'suspausti pirštai: tamsios odos',
    '🤌🏿' => 'suspausti pirštai: itin tamsios odos',
    '🤏🏻' => 'žnybianti ranka: šviesios odos',
    '🤏🏼' => 'žnybianti ranka: vidutinio gymio',
    '🤏🏽' => 'žnybianti ranka: rusvos odos',
    '🤏🏾' => 'žnybianti ranka: tamsios odos',
    '🤏🏿' => 'žnybianti ranka: itin tamsios odos',
    '✌🏻' => 'pergalės ženklą rodanti ranka: šviesios odos',
    '✌🏼' => 'pergalės ženklą rodanti ranka: vidutinio gymio',
    '✌🏽' => 'pergalės ženklą rodanti ranka: rusvos odos',
    '✌🏾' => 'pergalės ženklą rodanti ranka: tamsios odos',
    '✌🏿' => 'pergalės ženklą rodanti ranka: itin tamsios odos',
    '🤞🏻' => 'sukryžiuoti pirštai: šviesios odos',
    '🤞🏼' => 'sukryžiuoti pirštai: vidutinio gymio',
    '🤞🏽' => 'sukryžiuoti pirštai: rusvos odos',
    '🤞🏾' => 'sukryžiuoti pirštai: tamsios odos',
    '🤞🏿' => 'sukryžiuoti pirštai: itin tamsios odos',
    '🫰🏻' => 'ranka sukryžiuotu smiliumi ir nykščiu: šviesios odos',
    '🫰🏼' => 'ranka sukryžiuotu smiliumi ir nykščiu: vidutinio gymio',
    '🫰🏽' => 'ranka sukryžiuotu smiliumi ir nykščiu: rusvos odos',
    '🫰🏾' => 'ranka sukryžiuotu smiliumi ir nykščiu: tamsios odos',
    '🫰🏿' => 'ranka sukryžiuotu smiliumi ir nykščiu: itin tamsios odos',
    '🤟🏻' => '„myliu tave“ gestas: šviesios odos',
    '🤟🏼' => '„myliu tave“ gestas: vidutinio gymio',
    '🤟🏽' => '„myliu tave“ gestas: rusvos odos',
    '🤟🏾' => '„myliu tave“ gestas: tamsios odos',
    '🤟🏿' => '„myliu tave“ gestas: itin tamsios odos',
    '🤘🏻' => 'ragų ženklas: šviesios odos',
    '🤘🏼' => 'ragų ženklas: vidutinio gymio',
    '🤘🏽' => 'ragų ženklas: rusvos odos',
    '🤘🏾' => 'ragų ženklas: tamsios odos',
    '🤘🏿' => 'ragų ženklas: itin tamsios odos',
    '🤙🏻' => 'gestas paskambink man: šviesios odos',
    '🤙🏼' => 'gestas paskambink man: vidutinio gymio',
    '🤙🏽' => 'gestas paskambink man: rusvos odos',
    '🤙🏾' => 'gestas paskambink man: tamsios odos',
    '🤙🏿' => 'gestas paskambink man: itin tamsios odos',
    '👈🏻' => 'į kairę pirštu rodanti ranka: šviesios odos',
    '👈🏼' => 'į kairę pirštu rodanti ranka: vidutinio gymio',
    '👈🏽' => 'į kairę pirštu rodanti ranka: rusvos odos',
    '👈🏾' => 'į kairę pirštu rodanti ranka: tamsios odos',
    '👈🏿' => 'į kairę pirštu rodanti ranka: itin tamsios odos',
    '👉🏻' => 'į dešinę pirštu rodanti ranka: šviesios odos',
    '👉🏼' => 'į dešinę pirštu rodanti ranka: vidutinio gymio',
    '👉🏽' => 'į dešinę pirštu rodanti ranka: rusvos odos',
    '👉🏾' => 'į dešinę pirštu rodanti ranka: tamsios odos',
    '👉🏿' => 'į dešinę pirštu rodanti ranka: itin tamsios odos',
    '👆🏻' => 'delnu nusukta aukštyn pirštu rodanti ranka: šviesios odos',
    '👆🏼' => 'delnu nusukta aukštyn pirštu rodanti ranka: vidutinio gymio',
    '👆🏽' => 'delnu nusukta aukštyn pirštu rodanti ranka: rusvos odos',
    '👆🏾' => 'delnu nusukta aukštyn pirštu rodanti ranka: tamsios odos',
    '👆🏿' => 'delnu nusukta aukštyn pirštu rodanti ranka: itin tamsios odos',
    '🖕🏻' => 'vidurinis pirštas: šviesios odos',
    '🖕🏼' => 'vidurinis pirštas: vidutinio gymio',
    '🖕🏽' => 'vidurinis pirštas: rusvos odos',
    '🖕🏾' => 'vidurinis pirštas: tamsios odos',
    '🖕🏿' => 'vidurinis pirštas: itin tamsios odos',
    '👇🏻' => 'delnu nusukta žemyn pirštu rodanti ranka: šviesios odos',
    '👇🏼' => 'delnu nusukta žemyn pirštu rodanti ranka: vidutinio gymio',
    '👇🏽' => 'delnu nusukta žemyn pirštu rodanti ranka: rusvos odos',
    '👇🏾' => 'delnu nusukta žemyn pirštu rodanti ranka: tamsios odos',
    '👇🏿' => 'delnu nusukta žemyn pirštu rodanti ranka: itin tamsios odos',
    '☝🏻' => 'delnu atsukta aukštyn pirštu rodanti ranka: šviesios odos',
    '☝🏼' => 'delnu atsukta aukštyn pirštu rodanti ranka: vidutinio gymio',
    '☝🏽' => 'delnu atsukta aukštyn pirštu rodanti ranka: rusvos odos',
    '☝🏾' => 'delnu atsukta aukštyn pirštu rodanti ranka: tamsios odos',
    '☝🏿' => 'delnu atsukta aukštyn pirštu rodanti ranka: itin tamsios odos',
    '🫵🏻' => 'į žiūrovą rodantis smilius: šviesios odos',
    '🫵🏼' => 'į žiūrovą rodantis smilius: vidutinio gymio',
    '🫵🏽' => 'į žiūrovą rodantis smilius: rusvos odos',
    '🫵🏾' => 'į žiūrovą rodantis smilius: tamsios odos',
    '🫵🏿' => 'į žiūrovą rodantis smilius: itin tamsios odos',
    '👍🏻' => 'nykštys į viršų: šviesios odos',
    '👍🏼' => 'nykštys į viršų: vidutinio gymio',
    '👍🏽' => 'nykštys į viršų: rusvos odos',
    '👍🏾' => 'nykštys į viršų: tamsios odos',
    '👍🏿' => 'nykštys į viršų: itin tamsios odos',
    '👎🏻' => 'nykštys į apačią: šviesios odos',
    '👎🏼' => 'nykštys į apačią: vidutinio gymio',
    '👎🏽' => 'nykštys į apačią: rusvos odos',
    '👎🏾' => 'nykštys į apačią: tamsios odos',
    '👎🏿' => 'nykštys į apačią: itin tamsios odos',
    '✊🏻' => 'iškeltas kumštis: šviesios odos',
    '✊🏼' => 'iškeltas kumštis: vidutinio gymio',
    '✊🏽' => 'iškeltas kumštis: rusvos odos',
    '✊🏾' => 'iškeltas kumštis: tamsios odos',
    '✊🏿' => 'iškeltas kumštis: itin tamsios odos',
    '👊🏻' => 'artėjantis kumštis: šviesios odos',
    '👊🏼' => 'artėjantis kumštis: vidutinio gymio',
    '👊🏽' => 'artėjantis kumštis: rusvos odos',
    '👊🏾' => 'artėjantis kumštis: tamsios odos',
    '👊🏿' => 'artėjantis kumštis: itin tamsios odos',
    '🤛🏻' => 'į kairę nukreiptas kumštis: šviesios odos',
    '🤛🏼' => 'į kairę nukreiptas kumštis: vidutinio gymio',
    '🤛🏽' => 'į kairę nukreiptas kumštis: rusvos odos',
    '🤛🏾' => 'į kairę nukreiptas kumštis: tamsios odos',
    '🤛🏿' => 'į kairę nukreiptas kumštis: itin tamsios odos',
    '🤜🏻' => 'į dešinę nukreiptas kumštis: šviesios odos',
    '🤜🏼' => 'į dešinę nukreiptas kumštis: vidutinio gymio',
    '🤜🏽' => 'į dešinę nukreiptas kumštis: rusvos odos',
    '🤜🏾' => 'į dešinę nukreiptas kumštis: tamsios odos',
    '🤜🏿' => 'į dešinę nukreiptas kumštis: itin tamsios odos',
    '👏🏻' => 'plojančios rankos: šviesios odos',
    '👏🏼' => 'plojančios rankos: vidutinio gymio',
    '👏🏽' => 'plojančios rankos: rusvos odos',
    '👏🏾' => 'plojančios rankos: tamsios odos',
    '👏🏿' => 'plojančios rankos: itin tamsios odos',
    '🙌🏻' => 'žmogus, iškėlęs rankas: šviesios odos',
    '🙌🏼' => 'žmogus, iškėlęs rankas: vidutinio gymio',
    '🙌🏽' => 'žmogus, iškėlęs rankas: rusvos odos',
    '🙌🏾' => 'žmogus, iškėlęs rankas: tamsios odos',
    '🙌🏿' => 'žmogus, iškėlęs rankas: itin tamsios odos',
    '🫶🏻' => 'širdelė iš rankų: šviesios odos',
    '🫶🏼' => 'širdelė iš rankų: vidutinio gymio',
    '🫶🏽' => 'širdelė iš rankų: rusvos odos',
    '🫶🏾' => 'širdelė iš rankų: tamsios odos',
    '🫶🏿' => 'širdelė iš rankų: itin tamsios odos',
    '👐🏻' => 'atviros rankos: šviesios odos',
    '👐🏼' => 'atviros rankos: vidutinio gymio',
    '👐🏽' => 'atviros rankos: rusvos odos',
    '👐🏾' => 'atviros rankos: tamsios odos',
    '👐🏿' => 'atviros rankos: itin tamsios odos',
    '🤲🏻' => 'delnai suglausti: šviesios odos',
    '🤲🏼' => 'delnai suglausti: vidutinio gymio',
    '🤲🏽' => 'delnai suglausti: rusvos odos',
    '🤲🏾' => 'delnai suglausti: tamsios odos',
    '🤲🏿' => 'delnai suglausti: itin tamsios odos',
    '🤝🏻' => 'rankos paspaudimas: šviesios odos',
    '🤝🏼' => 'rankos paspaudimas: vidutinio gymio',
    '🤝🏽' => 'rankos paspaudimas: rusvos odos',
    '🤝🏾' => 'rankos paspaudimas: tamsios odos',
    '🤝🏿' => 'rankos paspaudimas: itin tamsios odos',
    '🙏🏻' => 'suglausti delnai: šviesios odos',
    '🙏🏼' => 'suglausti delnai: vidutinio gymio',
    '🙏🏽' => 'suglausti delnai: rusvos odos',
    '🙏🏾' => 'suglausti delnai: tamsios odos',
    '🙏🏿' => 'suglausti delnai: itin tamsios odos',
    '✍🏻' => 'rašanti ranka: šviesios odos',
    '✍🏼' => 'rašanti ranka: vidutinio gymio',
    '✍🏽' => 'rašanti ranka: rusvos odos',
    '✍🏾' => 'rašanti ranka: tamsios odos',
    '✍🏿' => 'rašanti ranka: itin tamsios odos',
    '💅🏻' => 'nagų lakas: šviesios odos',
    '💅🏼' => 'nagų lakas: vidutinio gymio',
    '💅🏽' => 'nagų lakas: rusvos odos',
    '💅🏾' => 'nagų lakas: tamsios odos',
    '💅🏿' => 'nagų lakas: itin tamsios odos',
    '🤳🏻' => 'asmenukė: šviesios odos',
    '🤳🏼' => 'asmenukė: vidutinio gymio',
    '🤳🏽' => 'asmenukė: rusvos odos',
    '🤳🏾' => 'asmenukė: tamsios odos',
    '🤳🏿' => 'asmenukė: itin tamsios odos',
    '💪🏻' => 'paryškinti bicepsai: šviesios odos',
    '💪🏼' => 'paryškinti bicepsai: vidutinio gymio',
    '💪🏽' => 'paryškinti bicepsai: rusvos odos',
    '💪🏾' => 'paryškinti bicepsai: tamsios odos',
    '💪🏿' => 'paryškinti bicepsai: itin tamsios odos',
    '🦵🏻' => 'koja: šviesios odos',
    '🦵🏼' => 'koja: vidutinio gymio',
    '🦵🏽' => 'koja: rusvos odos',
    '🦵🏾' => 'koja: tamsios odos',
    '🦵🏿' => 'koja: itin tamsios odos',
    '🦶🏻' => 'pėda: šviesios odos',
    '🦶🏼' => 'pėda: vidutinio gymio',
    '🦶🏽' => 'pėda: rusvos odos',
    '🦶🏾' => 'pėda: tamsios odos',
    '🦶🏿' => 'pėda: itin tamsios odos',
    '👂🏻' => 'ausis: šviesios odos',
    '👂🏼' => 'ausis: vidutinio gymio',
    '👂🏽' => 'ausis: rusvos odos',
    '👂🏾' => 'ausis: tamsios odos',
    '👂🏿' => 'ausis: itin tamsios odos',
    '🦻🏻' => 'ausis su klausos aparatu: šviesios odos',
    '🦻🏼' => 'ausis su klausos aparatu: vidutinio gymio',
    '🦻🏽' => 'ausis su klausos aparatu: rusvos odos',
    '🦻🏾' => 'ausis su klausos aparatu: tamsios odos',
    '🦻🏿' => 'ausis su klausos aparatu: itin tamsios odos',
    '👃🏻' => 'nosis: šviesios odos',
    '👃🏼' => 'nosis: vidutinio gymio',
    '👃🏽' => 'nosis: rusvos odos',
    '👃🏾' => 'nosis: tamsios odos',
    '👃🏿' => 'nosis: itin tamsios odos',
    '👶🏻' => 'kūdikis: šviesios odos',
    '👶🏼' => 'kūdikis: vidutinio gymio',
    '👶🏽' => 'kūdikis: rusvos odos',
    '👶🏾' => 'kūdikis: tamsios odos',
    '👶🏿' => 'kūdikis: itin tamsios odos',
    '🧒🏻' => 'vaikas: šviesios odos',
    '🧒🏼' => 'vaikas: vidutinio gymio',
    '🧒🏽' => 'vaikas: rusvos odos',
    '🧒🏾' => 'vaikas: tamsios odos',
    '🧒🏿' => 'vaikas: itin tamsios odos',
    '👦🏻' => 'berniukas: šviesios odos',
    '👦🏼' => 'berniukas: vidutinio gymio',
    '👦🏽' => 'berniukas: rusvos odos',
    '👦🏾' => 'berniukas: tamsios odos',
    '👦🏿' => 'berniukas: itin tamsios odos',
    '👧🏻' => 'mergaitė: šviesios odos',
    '👧🏼' => 'mergaitė: vidutinio gymio',
    '👧🏽' => 'mergaitė: rusvos odos',
    '👧🏾' => 'mergaitė: tamsios odos',
    '👧🏿' => 'mergaitė: itin tamsios odos',
    '🧑🏻' => 'suaugusysis: šviesios odos',
    '🧑🏼' => 'suaugusysis: vidutinio gymio',
    '🧑🏽' => 'suaugusysis: rusvos odos',
    '🧑🏾' => 'suaugusysis: tamsios odos',
    '🧑🏿' => 'suaugusysis: itin tamsios odos',
    '👱🏻' => 'šviesiaplaukis žmogus: šviesios odos',
    '👱🏼' => 'šviesiaplaukis žmogus: vidutinio gymio',
    '👱🏽' => 'šviesiaplaukis žmogus: rusvos odos',
    '👱🏾' => 'šviesiaplaukis žmogus: tamsios odos',
    '👱🏿' => 'šviesiaplaukis žmogus: itin tamsios odos',
    '👨🏻' => 'vyras: šviesios odos',
    '👨🏼' => 'vyras: vidutinio gymio',
    '👨🏽' => 'vyras: rusvos odos',
    '👨🏾' => 'vyras: tamsios odos',
    '👨🏿' => 'vyras: itin tamsios odos',
    '🧔🏻' => 'barzdotas žmogus: šviesios odos',
    '🧔🏼' => 'barzdotas žmogus: vidutinio gymio',
    '🧔🏽' => 'barzdotas žmogus: rusvos odos',
    '🧔🏾' => 'barzdotas žmogus: tamsios odos',
    '🧔🏿' => 'barzdotas žmogus: itin tamsios odos',
    '👩🏻' => 'moteris: šviesios odos',
    '👩🏼' => 'moteris: vidutinio gymio',
    '👩🏽' => 'moteris: rusvos odos',
    '👩🏾' => 'moteris: tamsios odos',
    '👩🏿' => 'moteris: itin tamsios odos',
    '🧓🏻' => 'kitas suaugusysis: šviesios odos',
    '🧓🏼' => 'kitas suaugusysis: vidutinio gymio',
    '🧓🏽' => 'kitas suaugusysis: rusvos odos',
    '🧓🏾' => 'kitas suaugusysis: tamsios odos',
    '🧓🏿' => 'kitas suaugusysis: itin tamsios odos',
    '👴🏻' => 'senas vyras: šviesios odos',
    '👴🏼' => 'senas vyras: vidutinio gymio',
    '👴🏽' => 'senas vyras: rusvos odos',
    '👴🏾' => 'senas vyras: tamsios odos',
    '👴🏿' => 'senas vyras: itin tamsios odos',
    '👵🏻' => 'sena moteris: šviesios odos',
    '👵🏼' => 'sena moteris: vidutinio gymio',
    '👵🏽' => 'sena moteris: rusvos odos',
    '👵🏾' => 'sena moteris: tamsios odos',
    '👵🏿' => 'sena moteris: itin tamsios odos',
    '🙍🏻' => 'paniuręs žmogus: šviesios odos',
    '🙍🏼' => 'paniuręs žmogus: vidutinio gymio',
    '🙍🏽' => 'paniuręs žmogus: rusvos odos',
    '🙍🏾' => 'paniuręs žmogus: tamsios odos',
    '🙍🏿' => 'paniuręs žmogus: itin tamsios odos',
    '🙎🏻' => 'susiraukęs žmogus: šviesios odos',
    '🙎🏼' => 'susiraukęs žmogus: vidutinio gymio',
    '🙎🏽' => 'susiraukęs žmogus: rusvos odos',
    '🙎🏾' => 'susiraukęs žmogus: tamsios odos',
    '🙎🏿' => 'susiraukęs žmogus: itin tamsios odos',
    '🙅🏻' => 'neigiamas gestas: šviesios odos',
    '🙅🏼' => 'neigiamas gestas: vidutinio gymio',
    '🙅🏽' => 'neigiamas gestas: rusvos odos',
    '🙅🏾' => 'neigiamas gestas: tamsios odos',
    '🙅🏿' => 'neigiamas gestas: itin tamsios odos',
    '🙆🏻' => 'teigiamas gestas: šviesios odos',
    '🙆🏼' => 'teigiamas gestas: vidutinio gymio',
    '🙆🏽' => 'teigiamas gestas: rusvos odos',
    '🙆🏾' => 'teigiamas gestas: tamsios odos',
    '🙆🏿' => 'teigiamas gestas: itin tamsios odos',
    '💁🏻' => 'informacijos skyriaus darbuotojas: šviesios odos',
    '💁🏼' => 'informacijos skyriaus darbuotojas: vidutinio gymio',
    '💁🏽' => 'informacijos skyriaus darbuotojas: rusvos odos',
    '💁🏾' => 'informacijos skyriaus darbuotojas: tamsios odos',
    '💁🏿' => 'informacijos skyriaus darbuotojas: itin tamsios odos',
    '🙋🏻' => 'žmogus, iškėlęs ranką: šviesios odos',
    '🙋🏼' => 'žmogus, iškėlęs ranką: vidutinio gymio',
    '🙋🏽' => 'žmogus, iškėlęs ranką: rusvos odos',
    '🙋🏾' => 'žmogus, iškėlęs ranką: tamsios odos',
    '🙋🏿' => 'žmogus, iškėlęs ranką: itin tamsios odos',
    '🧏🏻' => 'kurčias žmogus: šviesios odos',
    '🧏🏼' => 'kurčias žmogus: vidutinio gymio',
    '🧏🏽' => 'kurčias žmogus: rusvos odos',
    '🧏🏾' => 'kurčias žmogus: tamsios odos',
    '🧏🏿' => 'kurčias žmogus: itin tamsios odos',
    '🙇🏻' => 'nusilenkęs žmogus: šviesios odos',
    '🙇🏼' => 'nusilenkęs žmogus: vidutinio gymio',
    '🙇🏽' => 'nusilenkęs žmogus: rusvos odos',
    '🙇🏾' => 'nusilenkęs žmogus: tamsios odos',
    '🙇🏿' => 'nusilenkęs žmogus: itin tamsios odos',
    '🤦🏻' => 'o varge: šviesios odos',
    '🤦🏼' => 'o varge: vidutinio gymio',
    '🤦🏽' => 'o varge: rusvos odos',
    '🤦🏾' => 'o varge: tamsios odos',
    '🤦🏿' => 'o varge: itin tamsios odos',
    '🤷🏻' => 'gūžtelėjimas pečiais: šviesios odos',
    '🤷🏼' => 'gūžtelėjimas pečiais: vidutinio gymio',
    '🤷🏽' => 'gūžtelėjimas pečiais: rusvos odos',
    '🤷🏾' => 'gūžtelėjimas pečiais: tamsios odos',
    '🤷🏿' => 'gūžtelėjimas pečiais: itin tamsios odos',
    '👮🏻' => 'policininkas: šviesios odos',
    '👮🏼' => 'policininkas: vidutinio gymio',
    '👮🏽' => 'policininkas: rusvos odos',
    '👮🏾' => 'policininkas: tamsios odos',
    '👮🏿' => 'policininkas: itin tamsios odos',
    '🕵🏻' => 'detektyvas: šviesios odos',
    '🕵🏼' => 'detektyvas: vidutinio gymio',
    '🕵🏽' => 'detektyvas: rusvos odos',
    '🕵🏾' => 'detektyvas: tamsios odos',
    '🕵🏿' => 'detektyvas: itin tamsios odos',
    '💂🏻' => 'sargybinis: šviesios odos',
    '💂🏼' => 'sargybinis: vidutinio gymio',
    '💂🏽' => 'sargybinis: rusvos odos',
    '💂🏾' => 'sargybinis: tamsios odos',
    '💂🏿' => 'sargybinis: itin tamsios odos',
    '🥷🏻' => 'nindzė: šviesios odos',
    '🥷🏼' => 'nindzė: vidutinio gymio',
    '🥷🏽' => 'nindzė: rusvos odos',
    '🥷🏾' => 'nindzė: tamsios odos',
    '🥷🏿' => 'nindzė: itin tamsios odos',
    '👷🏻' => 'statybininkas: šviesios odos',
    '👷🏼' => 'statybininkas: vidutinio gymio',
    '👷🏽' => 'statybininkas: rusvos odos',
    '👷🏾' => 'statybininkas: tamsios odos',
    '👷🏿' => 'statybininkas: itin tamsios odos',
    '🫅🏻' => 'asmuo su karūna: šviesios odos',
    '🫅🏼' => 'asmuo su karūna: vidutinio gymio',
    '🫅🏽' => 'asmuo su karūna: rusvos odos',
    '🫅🏾' => 'asmuo su karūna: tamsios odos',
    '🫅🏿' => 'asmuo su karūna: itin tamsios odos',
    '🤴🏻' => 'princas: šviesios odos',
    '🤴🏼' => 'princas: vidutinio gymio',
    '🤴🏽' => 'princas: rusvos odos',
    '🤴🏾' => 'princas: tamsios odos',
    '🤴🏿' => 'princas: itin tamsios odos',
    '👸🏻' => 'princesė: šviesios odos',
    '👸🏼' => 'princesė: vidutinio gymio',
    '👸🏽' => 'princesė: rusvos odos',
    '👸🏾' => 'princesė: tamsios odos',
    '👸🏿' => 'princesė: itin tamsios odos',
    '👳🏻' => 'vyras su turbanu: šviesios odos',
    '👳🏼' => 'vyras su turbanu: vidutinio gymio',
    '👳🏽' => 'vyras su turbanu: rusvos odos',
    '👳🏾' => 'vyras su turbanu: tamsios odos',
    '👳🏿' => 'vyras su turbanu: itin tamsios odos',
    '👲🏻' => 'vyras su kinietiška kepurėle: šviesios odos',
    '👲🏼' => 'vyras su kinietiška kepurėle: vidutinio gymio',
    '👲🏽' => 'vyras su kinietiška kepurėle: rusvos odos',
    '👲🏾' => 'vyras su kinietiška kepurėle: tamsios odos',
    '👲🏿' => 'vyras su kinietiška kepurėle: itin tamsios odos',
    '🧕🏻' => 'moteris su skarele: šviesios odos',
    '🧕🏼' => 'moteris su skarele: vidutinio gymio',
    '🧕🏽' => 'moteris su skarele: rusvos odos',
    '🧕🏾' => 'moteris su skarele: tamsios odos',
    '🧕🏿' => 'moteris su skarele: itin tamsios odos',
    '🤵🏻' => 'asmuo su smokingu: šviesios odos',
    '🤵🏼' => 'asmuo su smokingu: vidutinio gymio',
    '🤵🏽' => 'asmuo su smokingu: rusvos odos',
    '🤵🏾' => 'asmuo su smokingu: tamsios odos',
    '🤵🏿' => 'asmuo su smokingu: itin tamsios odos',
    '👰🏻' => 'nuotaka su veliumu: šviesios odos',
    '👰🏼' => 'nuotaka su veliumu: vidutinio gymio',
    '👰🏽' => 'nuotaka su veliumu: rusvos odos',
    '👰🏾' => 'nuotaka su veliumu: tamsios odos',
    '👰🏿' => 'nuotaka su veliumu: itin tamsios odos',
    '🤰🏻' => 'nėščia moteris: šviesios odos',
    '🤰🏼' => 'nėščia moteris: vidutinio gymio',
    '🤰🏽' => 'nėščia moteris: rusvos odos',
    '🤰🏾' => 'nėščia moteris: tamsios odos',
    '🤰🏿' => 'nėščia moteris: itin tamsios odos',
    '🫃🏻' => 'nėščias vyras: šviesios odos',
    '🫃🏼' => 'nėščias vyras: vidutinio gymio',
    '🫃🏽' => 'nėščias vyras: rusvos odos',
    '🫃🏾' => 'nėščias vyras: tamsios odos',
    '🫃🏿' => 'nėščias vyras: itin tamsios odos',
    '🫄🏻' => 'nėščias asmuo: šviesios odos',
    '🫄🏼' => 'nėščias asmuo: vidutinio gymio',
    '🫄🏽' => 'nėščias asmuo: rusvos odos',
    '🫄🏾' => 'nėščias asmuo: tamsios odos',
    '🫄🏿' => 'nėščias asmuo: itin tamsios odos',
    '🤱🏻' => 'maitinimas krūtimi: šviesios odos',
    '🤱🏼' => 'maitinimas krūtimi: vidutinio gymio',
    '🤱🏽' => 'maitinimas krūtimi: rusvos odos',
    '🤱🏾' => 'maitinimas krūtimi: tamsios odos',
    '🤱🏿' => 'maitinimas krūtimi: itin tamsios odos',
    '👼🏻' => 'angeliukas: šviesios odos',
    '👼🏼' => 'angeliukas: vidutinio gymio',
    '👼🏽' => 'angeliukas: rusvos odos',
    '👼🏾' => 'angeliukas: tamsios odos',
    '👼🏿' => 'angeliukas: itin tamsios odos',
    '🎅🏻' => 'Kalėdų senelis: šviesios odos',
    '🎅🏼' => 'Kalėdų senelis: vidutinio gymio',
    '🎅🏽' => 'Kalėdų senelis: rusvos odos',
    '🎅🏾' => 'Kalėdų senelis: tamsios odos',
    '🎅🏿' => 'Kalėdų senelis: itin tamsios odos',
    '🤶🏻' => 'ponia Claus: šviesios odos',
    '🤶🏼' => 'ponia Claus: vidutinio gymio',
    '🤶🏽' => 'ponia Claus: rusvos odos',
    '🤶🏾' => 'ponia Claus: tamsios odos',
    '🤶🏿' => 'ponia Claus: itin tamsios odos',
    '🦸🏻' => 'superherojus: šviesios odos',
    '🦸🏼' => 'superherojus: vidutinio gymio',
    '🦸🏽' => 'superherojus: rusvos odos',
    '🦸🏾' => 'superherojus: tamsios odos',
    '🦸🏿' => 'superherojus: itin tamsios odos',
    '🦹🏻' => 'superpiktadarys: šviesios odos',
    '🦹🏼' => 'superpiktadarys: vidutinio gymio',
    '🦹🏽' => 'superpiktadarys: rusvos odos',
    '🦹🏾' => 'superpiktadarys: tamsios odos',
    '🦹🏿' => 'superpiktadarys: itin tamsios odos',
    '🧙🏻' => 'magas: šviesios odos',
    '🧙🏼' => 'magas: vidutinio gymio',
    '🧙🏽' => 'magas: rusvos odos',
    '🧙🏾' => 'magas: tamsios odos',
    '🧙🏿' => 'magas: itin tamsios odos',
    '🧚🏻' => 'fėja: šviesios odos',
    '🧚🏼' => 'fėja: vidutinio gymio',
    '🧚🏽' => 'fėja: rusvos odos',
    '🧚🏾' => 'fėja: tamsios odos',
    '🧚🏿' => 'fėja: itin tamsios odos',
    '🧛🏻' => 'vampyras: šviesios odos',
    '🧛🏼' => 'vampyras: vidutinio gymio',
    '🧛🏽' => 'vampyras: rusvos odos',
    '🧛🏾' => 'vampyras: tamsios odos',
    '🧛🏿' => 'vampyras: itin tamsios odos',
    '🧜🏻' => 'undinius: šviesios odos',
    '🧜🏼' => 'undinius: vidutinio gymio',
    '🧜🏽' => 'undinius: rusvos odos',
    '🧜🏾' => 'undinius: tamsios odos',
    '🧜🏿' => 'undinius: itin tamsios odos',
    '🧝🏻' => 'elfas: šviesios odos',
    '🧝🏼' => 'elfas: vidutinio gymio',
    '🧝🏽' => 'elfas: rusvos odos',
    '🧝🏾' => 'elfas: tamsios odos',
    '🧝🏿' => 'elfas: itin tamsios odos',
    '💆🏻' => 'veido masažas: šviesios odos',
    '💆🏼' => 'veido masažas: vidutinio gymio',
    '💆🏽' => 'veido masažas: rusvos odos',
    '💆🏾' => 'veido masažas: tamsios odos',
    '💆🏿' => 'veido masažas: itin tamsios odos',
    '💇🏻' => 'apkerpamas žmogus: šviesios odos',
    '💇🏼' => 'apkerpamas žmogus: vidutinio gymio',
    '💇🏽' => 'apkerpamas žmogus: rusvos odos',
    '💇🏾' => 'apkerpamas žmogus: tamsios odos',
    '💇🏿' => 'apkerpamas žmogus: itin tamsios odos',
    '🚶🏻' => 'pėstysis: šviesios odos',
    '🚶🏼' => 'pėstysis: vidutinio gymio',
    '🚶🏽' => 'pėstysis: rusvos odos',
    '🚶🏾' => 'pėstysis: tamsios odos',
    '🚶🏿' => 'pėstysis: itin tamsios odos',
    '🧍🏻' => 'stovintis žmogus: šviesios odos',
    '🧍🏼' => 'stovintis žmogus: vidutinio gymio',
    '🧍🏽' => 'stovintis žmogus: rusvos odos',
    '🧍🏾' => 'stovintis žmogus: tamsios odos',
    '🧍🏿' => 'stovintis žmogus: itin tamsios odos',
    '🧎🏻' => 'klūpantis žmogus: šviesios odos',
    '🧎🏼' => 'klūpantis žmogus: vidutinio gymio',
    '🧎🏽' => 'klūpantis žmogus: rusvos odos',
    '🧎🏾' => 'klūpantis žmogus: tamsios odos',
    '🧎🏿' => 'klūpantis žmogus: itin tamsios odos',
    '🏃🏻' => 'bėgikas: šviesios odos',
    '🏃🏼' => 'bėgikas: vidutinio gymio',
    '🏃🏽' => 'bėgikas: rusvos odos',
    '🏃🏾' => 'bėgikas: tamsios odos',
    '🏃🏿' => 'bėgikas: itin tamsios odos',
    '💃🏻' => 'šokanti moteris: šviesios odos',
    '💃🏼' => 'šokanti moteris: vidutinio gymio',
    '💃🏽' => 'šokanti moteris: rusvos odos',
    '💃🏾' => 'šokanti moteris: tamsios odos',
    '💃🏿' => 'šokanti moteris: itin tamsios odos',
    '🕺🏻' => 'šokantis vyras: šviesios odos',
    '🕺🏼' => 'šokantis vyras: vidutinio gymio',
    '🕺🏽' => 'šokantis vyras: rusvos odos',
    '🕺🏾' => 'šokantis vyras: tamsios odos',
    '🕺🏿' => 'šokantis vyras: itin tamsios odos',
    '🕴🏻' => 'į orą kylantis vyras su kostiumu: šviesios odos',
    '🕴🏼' => 'į orą kylantis vyras su kostiumu: vidutinio gymio',
    '🕴🏽' => 'į orą kylantis vyras su kostiumu: rusvos odos',
    '🕴🏾' => 'į orą kylantis vyras su kostiumu: tamsios odos',
    '🕴🏿' => 'į orą kylantis vyras su kostiumu: itin tamsios odos',
    '👯🏻' => 'besilinksminančios moterys: šviesios odos',
    '👯🏼' => 'besilinksminančios moterys: vidutinio gymio',
    '👯🏽' => 'besilinksminančios moterys: rusvos odos',
    '👯🏾' => 'besilinksminančios moterys: tamsios odos',
    '👯🏿' => 'besilinksminančios moterys: itin tamsios odos',
    '🧖🏻' => 'asmuo garų kambaryje: šviesios odos',
    '🧖🏼' => 'asmuo garų kambaryje: vidutinio gymio',
    '🧖🏽' => 'asmuo garų kambaryje: rusvos odos',
    '🧖🏾' => 'asmuo garų kambaryje: tamsios odos',
    '🧖🏿' => 'asmuo garų kambaryje: itin tamsios odos',
    '🧗🏻' => 'kopiantis žmogus: šviesios odos',
    '🧗🏼' => 'kopiantis žmogus: vidutinio gymio',
    '🧗🏽' => 'kopiantis žmogus: rusvos odos',
    '🧗🏾' => 'kopiantis žmogus: tamsios odos',
    '🧗🏿' => 'kopiantis žmogus: itin tamsios odos',
    '🏇🏻' => 'arklių lenktynės: šviesios odos',
    '🏇🏼' => 'arklių lenktynės: vidutinio gymio',
    '🏇🏽' => 'arklių lenktynės: rusvos odos',
    '🏇🏾' => 'arklių lenktynės: tamsios odos',
    '🏇🏿' => 'arklių lenktynės: itin tamsios odos',
    '🏂🏻' => 'snieglenčių sporto mėgėjas: šviesios odos',
    '🏂🏼' => 'snieglenčių sporto mėgėjas: vidutinio gymio',
    '🏂🏽' => 'snieglenčių sporto mėgėjas: rusvos odos',
    '🏂🏾' => 'snieglenčių sporto mėgėjas: tamsios odos',
    '🏂🏿' => 'snieglenčių sporto mėgėjas: itin tamsios odos',
    '🏌🏻' => 'golfo žaidėjas: šviesios odos',
    '🏌🏼' => 'golfo žaidėjas: vidutinio gymio',
    '🏌🏽' => 'golfo žaidėjas: rusvos odos',
    '🏌🏾' => 'golfo žaidėjas: tamsios odos',
    '🏌🏿' => 'golfo žaidėjas: itin tamsios odos',
    '🏄🏻' => 'banglentininkas: šviesios odos',
    '🏄🏼' => 'banglentininkas: vidutinio gymio',
    '🏄🏽' => 'banglentininkas: rusvos odos',
    '🏄🏾' => 'banglentininkas: tamsios odos',
    '🏄🏿' => 'banglentininkas: itin tamsios odos',
    '🚣🏻' => 'irkluojantis žmogus: šviesios odos',
    '🚣🏼' => 'irkluojantis žmogus: vidutinio gymio',
    '🚣🏽' => 'irkluojantis žmogus: rusvos odos',
    '🚣🏾' => 'irkluojantis žmogus: tamsios odos',
    '🚣🏿' => 'irkluojantis žmogus: itin tamsios odos',
    '🏊🏻' => 'plaukikas: šviesios odos',
    '🏊🏼' => 'plaukikas: vidutinio gymio',
    '🏊🏽' => 'plaukikas: rusvos odos',
    '🏊🏾' => 'plaukikas: tamsios odos',
    '🏊🏿' => 'plaukikas: itin tamsios odos',
    '⛹🏻' => 'žmogus su kamuoliu: šviesios odos',
    '⛹🏼' => 'žmogus su kamuoliu: vidutinio gymio',
    '⛹🏽' => 'žmogus su kamuoliu: rusvos odos',
    '⛹🏾' => 'žmogus su kamuoliu: tamsios odos',
    '⛹🏿' => 'žmogus su kamuoliu: itin tamsios odos',
    '🏋🏻' => 'svorių kilnotojas: šviesios odos',
    '🏋🏼' => 'svorių kilnotojas: vidutinio gymio',
    '🏋🏽' => 'svorių kilnotojas: rusvos odos',
    '🏋🏾' => 'svorių kilnotojas: tamsios odos',
    '🏋🏿' => 'svorių kilnotojas: itin tamsios odos',
    '🚴🏻' => 'dviratininkas: šviesios odos',
    '🚴🏼' => 'dviratininkas: vidutinio gymio',
    '🚴🏽' => 'dviratininkas: rusvos odos',
    '🚴🏾' => 'dviratininkas: tamsios odos',
    '🚴🏿' => 'dviratininkas: itin tamsios odos',
    '🚵🏻' => 'kalnų dviratininkas: šviesios odos',
    '🚵🏼' => 'kalnų dviratininkas: vidutinio gymio',
    '🚵🏽' => 'kalnų dviratininkas: rusvos odos',
    '🚵🏾' => 'kalnų dviratininkas: tamsios odos',
    '🚵🏿' => 'kalnų dviratininkas: itin tamsios odos',
    '🤸🏻' => 'persivertimas šonu: šviesios odos',
    '🤸🏼' => 'persivertimas šonu: vidutinio gymio',
    '🤸🏽' => 'persivertimas šonu: rusvos odos',
    '🤸🏾' => 'persivertimas šonu: tamsios odos',
    '🤸🏿' => 'persivertimas šonu: itin tamsios odos',
    '🤼🏻' => 'imtynininkai: šviesios odos',
    '🤼🏼' => 'imtynininkai: vidutinio gymio',
    '🤼🏽' => 'imtynininkai: rusvos odos',
    '🤼🏾' => 'imtynininkai: tamsios odos',
    '🤼🏿' => 'imtynininkai: itin tamsios odos',
    '🤽🏻' => 'vandensvydis: šviesios odos',
    '🤽🏼' => 'vandensvydis: vidutinio gymio',
    '🤽🏽' => 'vandensvydis: rusvos odos',
    '🤽🏾' => 'vandensvydis: tamsios odos',
    '🤽🏿' => 'vandensvydis: itin tamsios odos',
    '🤾🏻' => 'rankinis: šviesios odos',
    '🤾🏼' => 'rankinis: vidutinio gymio',
    '🤾🏽' => 'rankinis: rusvos odos',
    '🤾🏾' => 'rankinis: tamsios odos',
    '🤾🏿' => 'rankinis: itin tamsios odos',
    '🤹🏻' => 'žongliravimas: šviesios odos',
    '🤹🏼' => 'žongliravimas: vidutinio gymio',
    '🤹🏽' => 'žongliravimas: rusvos odos',
    '🤹🏾' => 'žongliravimas: tamsios odos',
    '🤹🏿' => 'žongliravimas: itin tamsios odos',
    '🧘🏻' => 'žmogus lotoso pozoje: šviesios odos',
    '🧘🏼' => 'žmogus lotoso pozoje: vidutinio gymio',
    '🧘🏽' => 'žmogus lotoso pozoje: rusvos odos',
    '🧘🏾' => 'žmogus lotoso pozoje: tamsios odos',
    '🧘🏿' => 'žmogus lotoso pozoje: itin tamsios odos',
    '🛀🏻' => 'žmogus prausiasi vonioje: šviesios odos',
    '🛀🏼' => 'žmogus prausiasi vonioje: vidutinio gymio',
    '🛀🏽' => 'žmogus prausiasi vonioje: rusvos odos',
    '🛀🏾' => 'žmogus prausiasi vonioje: tamsios odos',
    '🛀🏿' => 'žmogus prausiasi vonioje: itin tamsios odos',
    '🛌🏻' => 'žmogus lovoje: šviesios odos',
    '🛌🏼' => 'žmogus lovoje: vidutinio gymio',
    '🛌🏽' => 'žmogus lovoje: rusvos odos',
    '🛌🏾' => 'žmogus lovoje: tamsios odos',
    '🛌🏿' => 'žmogus lovoje: itin tamsios odos',
    '👭🏻' => 'dvi moterys, susikibusios už rankų: šviesios odos',
    '👭🏼' => 'dvi moterys, susikibusios už rankų: vidutinio gymio',
    '👭🏽' => 'dvi moterys, susikibusios už rankų: rusvos odos',
    '👭🏾' => 'dvi moterys, susikibusios už rankų: tamsios odos',
    '👭🏿' => 'dvi moterys, susikibusios už rankų: itin tamsios odos',
    '👫🏻' => 'vyras ir moteris, susikibę už rankų: šviesios odos',
    '👫🏼' => 'vyras ir moteris, susikibę už rankų: vidutinio gymio',
    '👫🏽' => 'vyras ir moteris, susikibę už rankų: rusvos odos',
    '👫🏾' => 'vyras ir moteris, susikibę už rankų: tamsios odos',
    '👫🏿' => 'vyras ir moteris, susikibę už rankų: itin tamsios odos',
    '👬🏻' => 'du vyrai, susikibę už rankų: šviesios odos',
    '👬🏼' => 'du vyrai, susikibę už rankų: vidutinio gymio',
    '👬🏽' => 'du vyrai, susikibę už rankų: rusvos odos',
    '👬🏾' => 'du vyrai, susikibę už rankų: tamsios odos',
    '👬🏿' => 'du vyrai, susikibę už rankų: itin tamsios odos',
    '💏🏻' => 'bučinys: šviesios odos',
    '💏🏼' => 'bučinys: vidutinio gymio',
    '💏🏽' => 'bučinys: rusvos odos',
    '💏🏾' => 'bučinys: tamsios odos',
    '💏🏿' => 'bučinys: itin tamsios odos',
    '💑🏻' => 'pora su širdele: šviesios odos',
    '💑🏼' => 'pora su širdele: vidutinio gymio',
    '💑🏽' => 'pora su širdele: rusvos odos',
    '💑🏾' => 'pora su širdele: tamsios odos',
    '💑🏿' => 'pora su širdele: itin tamsios odos',
    '🇦🇨' => 'vėliava: Dangun Žengimo sala',
    '🇦🇩' => 'vėliava: Andora',
    '🇦🇪' => 'vėliava: Jungtiniai Arabų Emyratai',
    '🇦🇫' => 'vėliava: Afganistanas',
    '🇦🇬' => 'vėliava: Antigva ir Barbuda',
    '🇦🇮' => 'vėliava: Angilija',
    '🇦🇱' => 'vėliava: Albanija',
    '🇦🇲' => 'vėliava: Armėnija',
    '🇦🇴' => 'vėliava: Angola',
    '🇦🇶' => 'vėliava: Antarktida',
    '🇦🇷' => 'vėliava: Argentina',
    '🇦🇸' => 'vėliava: Amerikos Samoa',
    '🇦🇹' => 'vėliava: Austrija',
    '🇦🇺' => 'vėliava: Australija',
    '🇦🇼' => 'vėliava: Aruba',
    '🇦🇽' => 'vėliava: Alandų Salos',
    '🇦🇿' => 'vėliava: Azerbaidžanas',
    '🇧🇦' => 'vėliava: Bosnija ir Hercegovina',
    '🇧🇧' => 'vėliava: Barbadosas',
    '🇧🇩' => 'vėliava: Bangladešas',
    '🇧🇪' => 'vėliava: Belgija',
    '🇧🇫' => 'vėliava: Burkina Fasas',
    '🇧🇬' => 'vėliava: Bulgarija',
    '🇧🇭' => 'vėliava: Bahreinas',
    '🇧🇮' => 'vėliava: Burundis',
    '🇧🇯' => 'vėliava: Beninas',
    '🇧🇱' => 'vėliava: Sen Bartelemi',
    '🇧🇲' => 'vėliava: Bermuda',
    '🇧🇳' => 'vėliava: Brunėjus',
    '🇧🇴' => 'vėliava: Bolivija',
    '🇧🇶' => 'vėliava: Karibų Nyderlandai',
    '🇧🇷' => 'vėliava: Brazilija',
    '🇧🇸' => 'vėliava: Bahamos',
    '🇧🇹' => 'vėliava: Butanas',
    '🇧🇻' => 'vėliava: Buvė Sala',
    '🇧🇼' => 'vėliava: Botsvana',
    '🇧🇾' => 'vėliava: Baltarusija',
    '🇧🇿' => 'vėliava: Belizas',
    '🇨🇦' => 'vėliava: Kanada',
    '🇨🇨' => 'vėliava: Kokosų (Kilingo) Salos',
    '🇨🇩' => 'vėliava: Kongas-Kinšasa',
    '🇨🇫' => 'vėliava: Centrinės Afrikos Respublika',
    '🇨🇬' => 'vėliava: Kongas-Brazavilis',
    '🇨🇭' => 'vėliava: Šveicarija',
    '🇨🇮' => 'vėliava: Dramblio Kaulo Krantas',
    '🇨🇰' => 'vėliava: Kuko Salos',
    '🇨🇱' => 'vėliava: Čilė',
    '🇨🇲' => 'vėliava: Kamerūnas',
    '🇨🇳' => 'vėliava: Kinija',
    '🇨🇴' => 'vėliava: Kolumbija',
    '🇨🇵' => 'vėliava: Klipertono sala',
    '🇨🇶' => 'vėliava: Sarkas',
    '🇨🇷' => 'vėliava: Kosta Rika',
    '🇨🇺' => 'vėliava: Kuba',
    '🇨🇻' => 'vėliava: Žaliasis Kyšulys',
    '🇨🇼' => 'vėliava: Kiurasao',
    '🇨🇽' => 'vėliava: Kalėdų Sala',
    '🇨🇾' => 'vėliava: Kipras',
    '🇨🇿' => 'vėliava: Čekija',
    '🇩🇪' => 'vėliava: Vokietija',
    '🇩🇬' => 'vėliava: Diego Garsija',
    '🇩🇯' => 'vėliava: Džibutis',
    '🇩🇰' => 'vėliava: Danija',
    '🇩🇲' => 'vėliava: Dominika',
    '🇩🇴' => 'vėliava: Dominikos Respublika',
    '🇩🇿' => 'vėliava: Alžyras',
    '🇪🇦' => 'vėliava: Seuta ir Melila',
    '🇪🇨' => 'vėliava: Ekvadoras',
    '🇪🇪' => 'vėliava: Estija',
    '🇪🇬' => 'vėliava: Egiptas',
    '🇪🇭' => 'vėliava: Vakarų Sachara',
    '🇪🇷' => 'vėliava: Eritrėja',
    '🇪🇸' => 'vėliava: Ispanija',
    '🇪🇹' => 'vėliava: Etiopija',
    '🇪🇺' => 'vėliava: Europos Sąjunga',
    '🇫🇮' => 'vėliava: Suomija',
    '🇫🇯' => 'vėliava: Fidžis',
    '🇫🇰' => 'vėliava: Folklando salos',
    '🇫🇲' => 'vėliava: Mikronezija',
    '🇫🇴' => 'vėliava: Farerų Salos',
    '🇫🇷' => 'vėliava: Prancūzija',
    '🇬🇦' => 'vėliava: Gabonas',
    '🇬🇧' => 'vėliava: Jungtinė Karalystė',
    '🇬🇩' => 'vėliava: Grenada',
    '🇬🇪' => 'vėliava: Gruzija',
    '🇬🇫' => 'vėliava: Prancūzijos Gviana',
    '🇬🇬' => 'vėliava: Gernsis',
    '🇬🇭' => 'vėliava: Gana',
    '🇬🇮' => 'vėliava: Gibraltaras',
    '🇬🇱' => 'vėliava: Grenlandija',
    '🇬🇲' => 'vėliava: Gambija',
    '🇬🇳' => 'vėliava: Gvinėja',
    '🇬🇵' => 'vėliava: Gvadelupa',
    '🇬🇶' => 'vėliava: Pusiaujo Gvinėja',
    '🇬🇷' => 'vėliava: Graikija',
    '🇬🇸' => 'vėliava: Pietų Džordžija ir Pietų Sandvičo salos',
    '🇬🇹' => 'vėliava: Gvatemala',
    '🇬🇺' => 'vėliava: Guamas',
    '🇬🇼' => 'vėliava: Bisau Gvinėja',
    '🇬🇾' => 'vėliava: Gajana',
    '🇭🇰' => 'vėliava: Ypatingasis Administracinis Kinijos Regionas Honkongas',
    '🇭🇲' => 'vėliava: Herdo ir Makdonaldo Salos',
    '🇭🇳' => 'vėliava: Hondūras',
    '🇭🇷' => 'vėliava: Kroatija',
    '🇭🇹' => 'vėliava: Haitis',
    '🇭🇺' => 'vėliava: Vengrija',
    '🇮🇨' => 'vėliava: Kanarų salos',
    '🇮🇩' => 'vėliava: Indonezija',
    '🇮🇪' => 'vėliava: Airija',
    '🇮🇱' => 'vėliava: Izraelis',
    '🇮🇲' => 'vėliava: Meno Sala',
    '🇮🇳' => 'vėliava: Indija',
    '🇮🇴' => 'vėliava: Indijos Vandenyno Britų Sritis',
    '🇮🇶' => 'vėliava: Irakas',
    '🇮🇷' => 'vėliava: Iranas',
    '🇮🇸' => 'vėliava: Islandija',
    '🇮🇹' => 'vėliava: Italija',
    '🇯🇪' => 'vėliava: Džersis',
    '🇯🇲' => 'vėliava: Jamaika',
    '🇯🇴' => 'vėliava: Jordanija',
    '🇯🇵' => 'vėliava: Japonija',
    '🇰🇪' => 'vėliava: Kenija',
    '🇰🇬' => 'vėliava: Kirgizija',
    '🇰🇭' => 'vėliava: Kambodža',
    '🇰🇮' => 'vėliava: Kiribatis',
    '🇰🇲' => 'vėliava: Komorai',
    '🇰🇳' => 'vėliava: Sent Kitsas ir Nevis',
    '🇰🇵' => 'vėliava: Šiaurės Korėja',
    '🇰🇷' => 'vėliava: Pietų Korėja',
    '🇰🇼' => 'vėliava: Kuveitas',
    '🇰🇾' => 'vėliava: Kaimanų Salos',
    '🇰🇿' => 'vėliava: Kazachstanas',
    '🇱🇦' => 'vėliava: Laosas',
    '🇱🇧' => 'vėliava: Libanas',
    '🇱🇨' => 'vėliava: Sent Lusija',
    '🇱🇮' => 'vėliava: Lichtenšteinas',
    '🇱🇰' => 'vėliava: Šri Lanka',
    '🇱🇷' => 'vėliava: Liberija',
    '🇱🇸' => 'vėliava: Lesotas',
    '🇱🇹' => 'vėliava: Lietuva',
    '🇱🇺' => 'vėliava: Liuksemburgas',
    '🇱🇻' => 'vėliava: Latvija',
    '🇱🇾' => 'vėliava: Libija',
    '🇲🇦' => 'vėliava: Marokas',
    '🇲🇨' => 'vėliava: Monakas',
    '🇲🇩' => 'vėliava: Moldova',
    '🇲🇪' => 'vėliava: Juodkalnija',
    '🇲🇫' => 'vėliava: Sen Martenas',
    '🇲🇬' => 'vėliava: Madagaskaras',
    '🇲🇭' => 'vėliava: Maršalo Salos',
    '🇲🇰' => 'vėliava: Šiaurės Makedonija',
    '🇲🇱' => 'vėliava: Malis',
    '🇲🇲' => 'vėliava: Mianmaras (Birma)',
    '🇲🇳' => 'vėliava: Mongolija',
    '🇲🇴' => 'vėliava: Ypatingasis Administracinis Kinijos Regionas Makao',
    '🇲🇵' => 'vėliava: Marianos Šiaurinės Salos',
    '🇲🇶' => 'vėliava: Martinika',
    '🇲🇷' => 'vėliava: Mauritanija',
    '🇲🇸' => 'vėliava: Montseratas',
    '🇲🇹' => 'vėliava: Malta',
    '🇲🇺' => 'vėliava: Mauricijus',
    '🇲🇻' => 'vėliava: Maldyvai',
    '🇲🇼' => 'vėliava: Malavis',
    '🇲🇽' => 'vėliava: Meksika',
    '🇲🇾' => 'vėliava: Malaizija',
    '🇲🇿' => 'vėliava: Mozambikas',
    '🇳🇦' => 'vėliava: Namibija',
    '🇳🇨' => 'vėliava: Naujoji Kaledonija',
    '🇳🇪' => 'vėliava: Nigeris',
    '🇳🇫' => 'vėliava: Norfolko sala',
    '🇳🇬' => 'vėliava: Nigerija',
    '🇳🇮' => 'vėliava: Nikaragva',
    '🇳🇱' => 'vėliava: Nyderlandai',
    '🇳🇴' => 'vėliava: Norvegija',
    '🇳🇵' => 'vėliava: Nepalas',
    '🇳🇷' => 'vėliava: Nauru',
    '🇳🇺' => 'vėliava: Niujė',
    '🇳🇿' => 'vėliava: Naujoji Zelandija',
    '🇴🇲' => 'vėliava: Omanas',
    '🇵🇦' => 'vėliava: Panama',
    '🇵🇪' => 'vėliava: Peru',
    '🇵🇫' => 'vėliava: Prancūzijos Polinezija',
    '🇵🇬' => 'vėliava: Papua Naujoji Gvinėja',
    '🇵🇭' => 'vėliava: Filipinai',
    '🇵🇰' => 'vėliava: Pakistanas',
    '🇵🇱' => 'vėliava: Lenkija',
    '🇵🇲' => 'vėliava: Sen Pjeras ir Mikelonas',
    '🇵🇳' => 'vėliava: Pitkerno salos',
    '🇵🇷' => 'vėliava: Puerto Rikas',
    '🇵🇸' => 'vėliava: Palestinos teritorija',
    '🇵🇹' => 'vėliava: Portugalija',
    '🇵🇼' => 'vėliava: Palau',
    '🇵🇾' => 'vėliava: Paragvajus',
    '🇶🇦' => 'vėliava: Kataras',
    '🇷🇪' => 'vėliava: Reunjonas',
    '🇷🇴' => 'vėliava: Rumunija',
    '🇷🇸' => 'vėliava: Serbija',
    '🇷🇺' => 'vėliava: Rusija',
    '🇷🇼' => 'vėliava: Ruanda',
    '🇸🇦' => 'vėliava: Saudo Arabija',
    '🇸🇧' => 'vėliava: Saliamono Salos',
    '🇸🇨' => 'vėliava: Seišeliai',
    '🇸🇩' => 'vėliava: Sudanas',
    '🇸🇪' => 'vėliava: Švedija',
    '🇸🇬' => 'vėliava: Singapūras',
    '🇸🇭' => 'vėliava: Šv. Elenos Sala',
    '🇸🇮' => 'vėliava: Slovėnija',
    '🇸🇯' => 'vėliava: Svalbardas ir Janas Majenas',
    '🇸🇰' => 'vėliava: Slovakija',
    '🇸🇱' => 'vėliava: Siera Leonė',
    '🇸🇲' => 'vėliava: San Marinas',
    '🇸🇳' => 'vėliava: Senegalas',
    '🇸🇴' => 'vėliava: Somalis',
    '🇸🇷' => 'vėliava: Surinamas',
    '🇸🇸' => 'vėliava: Pietų Sudanas',
    '🇸🇹' => 'vėliava: San Tomė ir Prinsipė',
    '🇸🇻' => 'vėliava: Salvadoras',
    '🇸🇽' => 'vėliava: Sint Martenas',
    '🇸🇾' => 'vėliava: Sirija',
    '🇸🇿' => 'vėliava: Svazilandas',
    '🇹🇦' => 'vėliava: Tristano da Kunjos',
    '🇹🇨' => 'vėliava: Terkso ir Kaikoso Salos',
    '🇹🇩' => 'vėliava: Čadas',
    '🇹🇫' => 'vėliava: Prancūzijos Pietų sritys',
    '🇹🇬' => 'vėliava: Togas',
    '🇹🇭' => 'vėliava: Tailandas',
    '🇹🇯' => 'vėliava: Tadžikija',
    '🇹🇰' => 'vėliava: Tokelau',
    '🇹🇱' => 'vėliava: Rytų Timoras',
    '🇹🇲' => 'vėliava: Turkmėnistanas',
    '🇹🇳' => 'vėliava: Tunisas',
    '🇹🇴' => 'vėliava: Tonga',
    '🇹🇷' => 'vėliava: Turkija',
    '🇹🇹' => 'vėliava: Trinidadas ir Tobagas',
    '🇹🇻' => 'vėliava: Tuvalu',
    '🇹🇼' => 'vėliava: Taivanas',
    '🇹🇿' => 'vėliava: Tanzanija',
    '🇺🇦' => 'vėliava: Ukraina',
    '🇺🇬' => 'vėliava: Uganda',
    '🇺🇲' => 'vėliava: Jungtinių Valstijų Mažosios Tolimosios Salos',
    '🇺🇳' => 'vėliava: Jungtinės Tautos',
    '🇺🇸' => 'vėliava: Jungtinės Valstijos',
    '🇺🇾' => 'vėliava: Urugvajus',
    '🇺🇿' => 'vėliava: Uzbekistanas',
    '🇻🇦' => 'vėliava: Vatikano Miesto Valstybė',
    '🇻🇨' => 'vėliava: Šventasis Vincentas ir Grenadinai',
    '🇻🇪' => 'vėliava: Venesuela',
    '🇻🇬' => 'vėliava: Didžiosios Britanijos Mergelių Salos',
    '🇻🇮' => 'vėliava: Jungtinių Valstijų Mergelių Salos',
    '🇻🇳' => 'vėliava: Vietnamas',
    '🇻🇺' => 'vėliava: Vanuatu',
    '🇼🇫' => 'vėliava: Volisas ir Futūna',
    '🇼🇸' => 'vėliava: Samoa',
    '🇽🇰' => 'vėliava: Kosovas',
    '🇾🇪' => 'vėliava: Jemenas',
    '🇾🇹' => 'vėliava: Majotas',
    '🇿🇦' => 'vėliava: Pietų Afrika',
    '🇿🇲' => 'vėliava: Zambija',
    '🇿🇼' => 'vėliava: Zimbabvė',
    '🔟' => 'mygtukas: 10',
    '🏻' => 'šviesios odos',
    '🏼' => 'vidutinio gymio',
    '🏽' => 'rusvos odos',
    '🏾' => 'tamsios odos',
    '🏿' => 'itin tamsios odos',
    '😀' => 'išsišiepęs veidas',
    '😃' => 'besišypsantis išsižiojęs veidas',
    '😄' => 'besišypsantis išsižiojęs veidas besišypsančiomis akimis',
    '😁' => 'išsišiepęs veidas su besišypsančiomis akimis',
    '😆' => 'besišypsantis išsižiojęs veidas su smarkiai užmerktomis akimis',
    '😅' => 'besišypsantis išsižiojęs veidas, išpiltas šalto prakaito',
    '🤣' => 'raitausi iš juoko',
    '😂' => 'veidas su džiaugsmo ašaromis',
    '🙂' => 'šiek tiek besišypsantis veidas',
    '🙃' => 'apverstas veidas',
    '🫠' => 'tirpstantis veidas',
    '😉' => 'mirksintis veidas',
    '😊' => 'besišypsantis veidas su besišypsančiomis akimis',
    '😇' => 'besišypsantis veidas su aureole',
    '🥰' => 'besišypsantis veidas su trimis širdelėmis',
    '😍' => 'besišypsantis veidas su širdelės formos akimis',
    '🤩' => 'žvaigždžių liga',
    '😘' => 'bučinį siunčiantis veidas',
    '😗' => 'bučiuojantis veidas',
    '☺' => 'besišypsantis veidas',
    '😚' => 'bučiuojantis su užmerktomis akimis',
    '😙' => 'bučiuojantis su besišypsančiomis akimis',
    '🥲' => 'besišypsantis veidas su ašara',
    '😋' => 'skaniu maistu besimėgaujantis veidas',
    '😛' => 'veidas su iškištu liežuviu',
    '😜' => 'veidas su iškištu liežuviu ir viena primerkta akimi',
    '🤪' => 'pamišęs veidas',
    '😝' => 'veidas su iškištu liežuviu ir stipriai užmerktomis akimis',
    '🤑' => 'veidas su pinigu vietoje liežuvio',
    '🤗' => 'apkabinantis veidas',
    '🤭' => 'veidas su ranka ant burnos',
    '🫢' => 'veidas atmerktomis akimis ir ranka uždengta burna',
    '🫣' => 'veidas su stebinčia akimi',
    '🤫' => 'tildantis veidas',
    '🤔' => 'mąstantis veidas',
    '🫡' => 'pagarbą atiduodantis veidas',
    '🤐' => 'veidas su užtrauktuku vietoje burnos',
    '🤨' => 'veidas su pakeltais antakiais',
    '😐' => 'neutralus veidas',
    '😑' => 'veidas be jokios išraiškos',
    '😶' => 'veidas be burnos',
    '🫥' => 'punktyrinis veidas',
    '😏' => 'iš pasitenkinimo besišypsantis veidas',
    '😒' => 'nelinksmas veidas',
    '🙄' => 'veidas, vartantis akis',
    '😬' => 'besivaipantis veidas',
    '🤥' => 'meluojantis veidas',
    '🫨' => 'besikratantis veidukas',
    '😌' => 'veidas su palengvėjimu',
    '😔' => 'susimąstęs veidas',
    '😪' => 'mieguistas veidas',
    '🤤' => 'besiseilėjantis veidas',
    '😴' => 'miegantis veidas',
    '🫩' => 'veidas su maišeliais po akimis',
    '😷' => 'veidas su medicinine kauke',
    '🤒' => 'veidas su termometru',
    '🤕' => 'veidas su galvos tvarsčiu',
    '🤢' => 'besiruošiantis vemti veidas',
    '🤮' => 'vemiantis veidas',
    '🤧' => 'čiaudantis veidas',
    '🥵' => 'įkaitęs veidas',
    '🥶' => 'sušalęs veidas',
    '🥴' => 'apkvaišęs veidas',
    '😵' => 'apsvaigęs veidas',
    '🤯' => 'sprogstanti galva',
    '🤠' => 'kaubojaus veidas su skrybėle',
    '🥳' => 'švenčiantis veidas',
    '🥸' => 'paslėptas veidas',
    '😎' => 'besišypsantis veidas su akiniais nuo saulės',
    '🤓' => 'moksliuko veidas',
    '🧐' => 'veidas su monokliu',
    '😕' => 'sutrikęs veidas',
    '🫤' => 'veidas įstriža burna',
    '😟' => 'susirūpinęs veidas',
    '🙁' => 'šiek tiek paniuręs veidas',
    '☹' => 'paniuręs veidas',
    '😮' => 'išsižiojęs veidas',
    '😯' => 'nuščiuvęs veidas',
    '😲' => 'apstulbęs veidas',
    '😳' => 'nuraudęs veidas',
    '🫪' => 'ištįsęs veidas',
    '🥺' => 'maldaujantis veidas',
    '🥹' => 'ašaras tramdantis veidas',
    '😦' => 'paniuręs išsižiojęs veidas',
    '😧' => 'kenčiantis veidas',
    '😨' => 'baimės pilnas veidas',
    '😰' => 'išsižiojęs veidas, išpiltas šalto prakaito',
    '😥' => 'nusivylęs veidas su palengvėjimu',
    '😢' => 'verkiantis veidas',
    '😭' => 'garsiai raudantis veidas',
    '😱' => 'iš baimės šaukiantis veidas',
    '😖' => 'suglumintas veidas',
    '😣' => 'atkaklus veidas',
    '😞' => 'nusivylęs veidas',
    '😓' => 'veidas, išpiltas šalto prakaito',
    '😩' => 'nuvargęs veidas',
    '😫' => 'pavargęs veidas',
    '🥱' => 'žiovaujantis veidas',
    '😤' => 'veidas su iš nosies einančiais garais',
    '😡' => 'susiraukęs veidas',
    '😠' => 'piktas veidas',
    '🤬' => 'veidas su simboliais ant burnos',
    '😈' => 'besišypsantis veidas su ragais',
    '👿' => 'velniūkštis',
    '💀' => 'kaukolė',
    '☠' => 'kaukolė ir sukryžiuoti kaulai',
    '💩' => 'išmatų krūvelė',
    '🤡' => 'klouno veidas',
    '👹' => 'pabaisa',
    '👺' => 'demonas',
    '👻' => 'vaiduoklis',
    '👽' => 'ateivis',
    '👾' => 'monstras ateivis',
    '🤖' => 'roboto veidas',
    '😺' => 'besišypsančios katės snukutis',
    '😸' => 'išsišiepusios katės snukutis su besišypsančiomis akimis',
    '😹' => 'katės snukutis su džiaugsmo ašaromis',
    '😻' => 'besišypsančios katės snukutis su širdelės formos akimis',
    '😼' => 'nuvargusios besišypsančios katės snukutis',
    '😽' => 'bučiuojančios katės snukutis',
    '🙀' => 'nustebusios katės snukutis',
    '😿' => 'verkiančios katės snukutis',
    '😾' => 'susiraukusios katės snukutis',
    '🙈' => 'užsidengusi akis beždžionė',
    '🙉' => 'užsidengusi ausis beždžionė',
    '🙊' => 'užsidengusi burną beždžionė',
    '💌' => 'meilės laiškas',
    '💘' => 'širdelė su strėle',
    '💝' => 'širdelė su kaspinu',
    '💖' => 'žėrinti širdelė',
    '💗' => 'auganti širdelė',
    '💓' => 'plakanti širdelė',
    '💞' => 'besisukančios širdelės',
    '💕' => 'dvi širdelės',
    '💟' => 'širdelės dekoracija',
    '❣' => 'storas širdelės formos šauktukas',
    '💔' => 'sudaužyta širdelė',
    '❤' => 'raudona širdelė',
    '🩷' => 'rožinė širdelė',
    '🧡' => 'oranžinė širdelė',
    '💛' => 'geltona širdelė',
    '💚' => 'žalia širdelė',
    '💙' => 'mėlyna širdelė',
    '🩵' => 'šviesiai mėlyna širdelė',
    '💜' => 'purpurinė širdelė',
    '🤎' => 'ruda širdelė',
    '🖤' => 'juoda širdis',
    '🩶' => 'pilka širdelė',
    '🤍' => 'balta širdelė',
    '💋' => 'bučinio žymė',
    '💯' => 'šimtas taškų',
    '💢' => 'pykčio simbolis',
    '🫯' => 'kovos debesis',
    '💥' => 'susidūrimas',
    '💫' => 'apsvaigęs',
    '💦' => 'prakaito lašeliai',
    '💨' => 'sukeltos dulkės',
    '🕳' => 'duobė',
    '💬' => 'kalbos debesėlis',
    '🗨' => 'kairysis kalbos debesėlis',
    '🗯' => 'dešinysis pykčio debesėlis',
    '💭' => 'minties debesėlis',
    '💤' => 'miego simbolis',
    '👋' => 'mojuojanti ranka',
    '🤚' => 'pakelta viršutinė plaštakos pusė',
    '🖐' => 'iškelta ranka su išskėstais pirštais',
    '✋' => 'iškelta ranka',
    '🖖' => 'vulkanų rasės pasisveikinimo ženklas',
    '🫱' => 'į dešinę rodanti ranka',
    '🫲' => 'į kairę rodanti ranka',
    '🫳' => 'ranka delnu žemyn',
    '🫴' => 'ranka delnu į viršų',
    '🫷' => 'į kairę stumianti ranka',
    '🫸' => 'į dešinę stumianti ranka',
    '👌' => 'GERAI ženklas rankomis',
    '🤌' => 'suspausti pirštai',
    '🤏' => 'žnybianti ranka',
    '✌' => 'pergalės ženklą rodanti ranka',
    '🤞' => 'sukryžiuoti pirštai',
    '🫰' => 'ranka sukryžiuotu smiliumi ir nykščiu',
    '🤟' => '„myliu tave“ gestas',
    '🤘' => 'ragų ženklas',
    '🤙' => 'gestas paskambink man',
    '👈' => 'į kairę pirštu rodanti ranka',
    '👉' => 'į dešinę pirštu rodanti ranka',
    '👆' => 'delnu nusukta aukštyn pirštu rodanti ranka',
    '🖕' => 'vidurinis pirštas',
    '👇' => 'delnu nusukta žemyn pirštu rodanti ranka',
    '☝' => 'delnu atsukta aukštyn pirštu rodanti ranka',
    '🫵' => 'į žiūrovą rodantis smilius',
    '👍' => 'nykštys į viršų',
    '👎' => 'nykštys į apačią',
    '✊' => 'iškeltas kumštis',
    '👊' => 'artėjantis kumštis',
    '🤛' => 'į kairę nukreiptas kumštis',
    '🤜' => 'į dešinę nukreiptas kumštis',
    '👏' => 'plojančios rankos',
    '🙌' => 'žmogus, iškėlęs rankas',
    '🫶' => 'širdelė iš rankų',
    '👐' => 'atviros rankos',
    '🤲' => 'delnai suglausti',
    '🤝' => 'rankos paspaudimas',
    '🙏' => 'suglausti delnai',
    '✍' => 'rašanti ranka',
    '💅' => 'nagų lakas',
    '🤳' => 'asmenukė',
    '💪' => 'paryškinti bicepsai',
    '🦾' => 'mechaninė ranka',
    '🦿' => 'mechaninė koja',
    '🦵' => 'koja',
    '🦶' => 'pėda',
    '👂' => 'ausis',
    '🦻' => 'ausis su klausos aparatu',
    '👃' => 'nosis',
    '🧠' => 'smegenys',
    '🫀' => 'širdis',
    '🫁' => 'plaučiai',
    '🦷' => 'dantis',
    '🦴' => 'kaulas',
    '👀' => 'akys',
    '👁' => 'akis',
    '👅' => 'liežuvis',
    '👄' => 'burna',
    '🫦' => 'prikąsta lūpa',
    '👶' => 'kūdikis',
    '🧒' => 'vaikas',
    '👦' => 'berniukas',
    '👧' => 'mergaitė',
    '🧑' => 'suaugusysis',
    '👱' => 'šviesiaplaukis žmogus',
    '👨' => 'vyras',
    '🧔' => 'barzdotas žmogus',
    '👩' => 'moteris',
    '🧓' => 'kitas suaugusysis',
    '👴' => 'senas vyras',
    '👵' => 'sena moteris',
    '🙍' => 'paniuręs žmogus',
    '🙎' => 'susiraukęs žmogus',
    '🙅' => 'neigiamas gestas',
    '🙆' => 'teigiamas gestas',
    '💁' => 'informacijos skyriaus darbuotojas',
    '🙋' => 'žmogus, iškėlęs ranką',
    '🧏' => 'kurčias žmogus',
    '🙇' => 'nusilenkęs žmogus',
    '🤦' => 'o varge',
    '🤷' => 'gūžtelėjimas pečiais',
    '👮' => 'policininkas',
    '🕵' => 'detektyvas',
    '💂' => 'sargybinis',
    '🥷' => 'nindzė',
    '👷' => 'statybininkas',
    '🫅' => 'asmuo su karūna',
    '🤴' => 'princas',
    '👸' => 'princesė',
    '👳' => 'vyras su turbanu',
    '👲' => 'vyras su kinietiška kepurėle',
    '🧕' => 'moteris su skarele',
    '🤵' => 'asmuo su smokingu',
    '👰' => 'nuotaka su veliumu',
    '🤰' => 'nėščia moteris',
    '🫃' => 'nėščias vyras',
    '🫄' => 'nėščias asmuo',
    '🤱' => 'maitinimas krūtimi',
    '👼' => 'angeliukas',
    '🎅' => 'Kalėdų senelis',
    '🤶' => 'ponia Claus',
    '🦸' => 'superherojus',
    '🦹' => 'superpiktadarys',
    '🧙' => 'magas',
    '🧚' => 'fėja',
    '🧛' => 'vampyras',
    '🧜' => 'undinius',
    '🧝' => 'elfas',
    '🧞' => 'dvasia',
    '🧟' => 'zombis',
    '🧌' => 'trolis',
    '🫈' => 'plaukuotas padaras',
    '💆' => 'veido masažas',
    '💇' => 'apkerpamas žmogus',
    '🚶' => 'pėstysis',
    '🧍' => 'stovintis žmogus',
    '🧎' => 'klūpantis žmogus',
    '🏃' => 'bėgikas',
    '💃' => 'šokanti moteris',
    '🕺' => 'šokantis vyras',
    '🕴' => 'į orą kylantis vyras su kostiumu',
    '👯' => 'besilinksminančios moterys',
    '🧖' => 'asmuo garų kambaryje',
    '🧗' => 'kopiantis žmogus',
    '🤺' => 'fechtuotojas',
    '🏇' => 'arklių lenktynės',
    '⛷' => 'slidininkas',
    '🏂' => 'snieglenčių sporto mėgėjas',
    '🏌' => 'golfo žaidėjas',
    '🏄' => 'banglentininkas',
    '🚣' => 'irkluojantis žmogus',
    '🏊' => 'plaukikas',
    '⛹' => 'žmogus su kamuoliu',
    '🏋' => 'svorių kilnotojas',
    '🚴' => 'dviratininkas',
    '🚵' => 'kalnų dviratininkas',
    '🤸' => 'persivertimas šonu',
    '🤼' => 'imtynininkai',
    '🤽' => 'vandensvydis',
    '🤾' => 'rankinis',
    '🤹' => 'žongliravimas',
    '🧘' => 'žmogus lotoso pozoje',
    '🛀' => 'žmogus prausiasi vonioje',
    '🛌' => 'žmogus lovoje',
    '👭' => 'dvi moterys, susikibusios už rankų',
    '👫' => 'vyras ir moteris, susikibę už rankų',
    '👬' => 'du vyrai, susikibę už rankų',
    '💏' => 'bučinys',
    '💑' => 'pora su širdele',
    '🗣' => 'kalbanti galva',
    '👤' => 'biusto siluetas',
    '👥' => 'biustų siluetai',
    '🫂' => 'apsikabinę žmonės',
    '👪' => 'šeima',
    '👣' => 'pėdsakai',
    '🫆' => 'piršto atspaudas',
    '🦰' => 'raudoni plaukai',
    '🦱' => 'garbanoti plaukai',
    '🦳' => 'žili plaukai',
    '🦲' => 'plikas',
    '🐵' => 'beždžionės snukutis',
    '🐒' => 'beždžionė',
    '🦍' => 'gorila',
    '🦧' => 'orangutangas',
    '🐶' => 'šuns snukutis',
    '🐕' => 'šuo',
    '🦮' => 'šuo vedlys',
    '🐩' => 'pudelis',
    '🐺' => 'vilko snukis',
    '🦊' => 'lapės snukis',
    '🦝' => 'meškėnas',
    '🐱' => 'katės snukutis',
    '🐈' => 'katė',
    '🦁' => 'liūto snukis',
    '🐯' => 'tigro snukis',
    '🐅' => 'tigras',
    '🐆' => 'leopardas',
    '🐴' => 'arklio snukis',
    '🫎' => 'briedis',
    '🫏' => 'asilas',
    '🐎' => 'arklys',
    '🦄' => 'vienaragio snukis',
    '🦓' => 'zebras',
    '🦌' => 'elnias',
    '🦬' => 'bizonas',
    '🐮' => 'karvės snukis',
    '🐂' => 'jautis',
    '🐃' => 'azijinis buivolas',
    '🐄' => 'karvė',
    '🐷' => 'kiaulės snukis',
    '🐖' => 'kiaulė',
    '🐗' => 'šernas',
    '🐽' => 'kiaulės nosis',
    '🐏' => 'avinas (gyvūnas)',
    '🐑' => 'avis',
    '🐐' => 'ožys',
    '🐪' => 'kupranugaris',
    '🐫' => 'dvikupris kupranugaris',
    '🦙' => 'lama',
    '🦒' => 'žirafa',
    '🐘' => 'dramblys',
    '🦣' => 'mamutas',
    '🦏' => 'raganosis',
    '🦛' => 'begemotas',
    '🐭' => 'pelės snukutis',
    '🐁' => 'pelė',
    '🐀' => 'žiurkė',
    '🐹' => 'žiurkėno snukutis',
    '🐰' => 'triušio snukutis',
    '🐇' => 'triušis',
    '🐿' => 'voverė',
    '🦫' => 'bebras',
    '🦔' => 'ežys',
    '🦇' => 'šikšnosparnis',
    '🐻' => 'meškos snukis',
    '🐨' => 'koala',
    '🐼' => 'pandos snukis',
    '🦥' => 'tinginys',
    '🦦' => 'ūdra',
    '🦨' => 'skunkas',
    '🦘' => 'kengūra',
    '🦡' => 'barsukas',
    '🐾' => 'pėdutės',
    '🦃' => 'kalakutas',
    '🐔' => 'višta',
    '🐓' => 'gaidys',
    '🐣' => 'išsiritęs viščiukas',
    '🐤' => 'viščiukas',
    '🐥' => 'atsisukęs snapu viščiukas',
    '🐦' => 'paukštis',
    '🐧' => 'pingvinas',
    '🕊' => 'balandis',
    '🦅' => 'erelis',
    '🦆' => 'antis',
    '🦢' => 'gulbė',
    '🦉' => 'pelėda',
    '🦤' => 'drontas',
    '🪶' => 'plunksna',
    '🦩' => 'flamingas',
    '🦚' => 'povas',
    '🦜' => 'papūga',
    '🪽' => 'sparnas',
    '🪿' => 'žąsis',
    '🐸' => 'varlės snukutis',
    '🐊' => 'krokodilas',
    '🐢' => 'vėžlys',
    '🦎' => 'driežas',
    '🐍' => 'gyvatė',
    '🐲' => 'drakono snukis',
    '🐉' => 'drakonas',
    '🦕' => 'sauropodas',
    '🦖' => 'Reksas',
    '🐳' => 'purškiantis banginis',
    '🐋' => 'banginis',
    '🐬' => 'delfinas',
    '🫍' => 'orka',
    '🦭' => 'ruonis',
    '🐟' => 'žuvis',
    '🐠' => 'tropinė žuvis',
    '🐡' => 'fugu',
    '🦈' => 'ryklys',
    '🐙' => 'aštuonkojis',
    '🐚' => 'susisukusi kriauklė',
    '🪸' => 'koralas',
    '🪼' => 'medūza',
    '🦀' => 'krabas',
    '🦞' => 'omaras',
    '🦐' => 'krevetė',
    '🦑' => 'kalmaras',
    '🦪' => 'austrė',
    '🐌' => 'sraigė',
    '🦋' => 'drugelis',
    '🐛' => 'vabalas',
    '🐜' => 'skruzdėlė',
    '🐝' => 'bitė',
    '🪲' => 'vabaliukas',
    '🐞' => 'boružė',
    '🦗' => 'svirplys',
    '🪳' => 'tarakonas',
    '🕷' => 'voras',
    '🕸' => 'voratinklis',
    '🦂' => 'skorpionas (gyvūnas)',
    '🦟' => 'uodas',
    '🪰' => 'musė',
    '🪱' => 'kirmėlė',
    '🦠' => 'mikrobas',
    '💐' => 'puokštė',
    '🌸' => 'vyšnios žiedas',
    '💮' => 'balta gėlė',
    '🪷' => 'lotusas',
    '🏵' => 'rozetė',
    '🌹' => 'rožė',
    '🥀' => 'gležna gėlė',
    '🌺' => 'kinrožė',
    '🌻' => 'saulėgrąža',
    '🌼' => 'gėlės žiedas',
    '🌷' => 'tulpė',
    '🪻' => 'hiacintas',
    '🌱' => 'daigas',
    '🪴' => 'pasodintas augalas',
    '🌲' => 'amžinai žaliuojantis medis',
    '🌳' => 'lapuotis',
    '🌴' => 'palmė',
    '🌵' => 'kaktusas',
    '🌾' => 'ryžių pėdas',
    '🌿' => 'žolelė',
    '☘' => 'trilapis dobilas',
    '🍀' => 'keturlapis dobilas',
    '🍁' => 'klevo lapas',
    '🍂' => 'nukritęs lapas',
    '🍃' => 'lapas vėjyje',
    '🪹' => 'tuščias lizdas',
    '🪺' => 'lizdas su kiaušiniais',
    '🍄' => 'grybas',
    '🪾' => 'medis be lapų',
    '🍇' => 'vynuogės',
    '🍈' => 'melionas',
    '🍉' => 'arbūzas',
    '🍊' => 'mandarinas',
    '🍋' => 'citrina',
    '🍌' => 'bananas',
    '🍍' => 'ananasas',
    '🥭' => 'mangas',
    '🍎' => 'raudonas obuolys',
    '🍏' => 'žalias obuolys',
    '🍐' => 'kriaušė',
    '🍑' => 'persikas',
    '🍒' => 'vyšnios',
    '🍓' => 'braškė',
    '🫐' => 'mėlynės',
    '🥝' => 'kivis',
    '🍅' => 'pomidoras',
    '🫒' => 'alyvuogė',
    '🥥' => 'kokosas',
    '🥑' => 'avokadas',
    '🍆' => 'baklažanas',
    '🥔' => 'bulvė',
    '🥕' => 'morka',
    '🌽' => 'kukurūzo burbuolė',
    '🌶' => 'aštrusis pipiras',
    '🫑' => 'paprika',
    '🥒' => 'agurkas',
    '🥬' => 'lapinė daržovė',
    '🥦' => 'brokolis',
    '🧄' => 'česnakas',
    '🧅' => 'svogūnas',
    '🥜' => 'žemės riešutas',
    '🫘' => 'pupelės',
    '🌰' => 'lazdyno riešutas',
    '🫚' => 'imbiero šaknis',
    '🫛' => 'žirnių ankštis',
    '🫜' => 'šakninė daržovė',
    '🍞' => 'duona',
    '🥐' => 'raguolis',
    '🥖' => 'ilgas batonas',
    '🫓' => 'paplotis',
    '🥨' => 'riestainis',
    '🥯' => 'apvalus riestainis',
    '🥞' => 'blynai',
    '🧇' => 'vaflis',
    '🧀' => 'sūrio gabaliukas',
    '🍖' => 'mėsa ant kaulo',
    '🍗' => 'paukščio šlaunelė',
    '🥩' => 'mėsos gabalėliai',
    '🥓' => 'kumpis',
    '🍔' => 'mėsainis',
    '🍟' => 'gruzdintos bulvytės',
    '🍕' => 'pica',
    '🌭' => 'dešrainis',
    '🥪' => 'sumuštinis',
    '🌮' => 'meksikietiškas paplotėlis',
    '🌯' => 'buritas',
    '🫔' => 'vyniotinis',
    '🥙' => 'įdarytas lavašas',
    '🧆' => 'falafelis',
    '🥚' => 'kiaušinis',
    '🍳' => 'valgio gaminimas',
    '🥘' => 'prikaistuvis su maistu',
    '🍲' => 'puodas su maistu',
    '🫕' => 'fondiu',
    '🥣' => 'dubuo su šaukštu',
    '🥗' => 'žalios salotos',
    '🍿' => 'spragėsiai',
    '🧈' => 'sviestas',
    '🧂' => 'druska',
    '🥫' => 'konservai',
    '🍱' => 'bento dėžutė',
    '🍘' => 'ryžių paplotėlis',
    '🍙' => 'ryžių rutuliukas',
    '🍚' => 'virti ryžiai',
    '🍛' => 'ryžiai su kariu',
    '🍜' => 'makaronų sriubos dubenėlis',
    '🍝' => 'spagečiai',
    '🍠' => 'kepta saldžioji bulvė',
    '🍢' => 'odenas',
    '🍣' => 'sušis',
    '🍤' => 'kepta krevetė',
    '🍥' => 'žuvies pyragėlis su išpieštu sūkurio simboliu',
    '🥮' => 'mėnulio pyragas',
    '🍡' => 'dango',
    '🥟' => 'kukulis',
    '🥠' => 'laimės sausainiukas',
    '🥡' => 'dėžutė išsinešti',
    '🍦' => 'minkšti ledai',
    '🍧' => 'susmulkintas ledas',
    '🍨' => 'ledai',
    '🍩' => 'spurga',
    '🍪' => 'sausainis',
    '🎂' => 'gimtadienio tortas',
    '🍰' => 'trapus pyragas',
    '🧁' => 'keksiukas',
    '🥧' => 'pyragas',
    '🍫' => 'šokolado batonėlis',
    '🍬' => 'saldainis',
    '🍭' => 'ledinukas ant pagaliuko',
    '🍮' => 'saldus kremas',
    '🍯' => 'medaus puodynė',
    '🍼' => 'kūdikio buteliukas',
    '🥛' => 'pieno stiklinė',
    '☕' => 'karštas gėrimas',
    '🫖' => 'arbatinukas',
    '🍵' => 'arbatos puodelis be rankenos',
    '🍶' => 'sakė',
    '🍾' => 'butelis su iššokusiu kamščiu',
    '🍷' => 'vyno taurė',
    '🍸' => 'kokteilio taurė',
    '🍹' => 'tropinis gėrimas',
    '🍺' => 'alaus bokalas',
    '🍻' => 'susidaužiantys alaus bokalai',
    '🥂' => 'sudaužtos taurės',
    '🥃' => 'stiklinė',
    '🫗' => 'pilamas skystis',
    '🥤' => 'puodelis su šiaudeliu',
    '🧋' => 'burbulinė arbata',
    '🧃' => 'gėrimo pakelis',
    '🧉' => 'matė',
    '🧊' => 'ledo kubelis',
    '🥢' => 'lazdelės',
    '🍽' => 'šakutė ir peilis su lėkšte',
    '🍴' => 'šakutė ir peilis',
    '🥄' => 'šaukštas',
    '🔪' => 'virtuvinis peilis',
    '🫙' => 'stiklainis',
    '🏺' => 'senovinė vaza',
    '🌍' => 'žemės rutulys su Europos ir Afrikos žemynais',
    '🌎' => 'žemės rutulys su Šiaurės ir Pietų Amerikos žemynais',
    '🌏' => 'žemės rutulys su Azijos ir Australijos žemynais',
    '🌐' => 'žemės rutulys su dienovidiniais',
    '🗺' => 'pasaulio žemėlapis',
    '🗾' => 'Japonijos žemėlapis',
    '🧭' => 'kompasas',
    '🏔' => 'kalnas su snieguota viršūne',
    '⛰' => 'kalnas',
    '🛘' => 'nuošliauža',
    '🌋' => 'ugnikalnis',
    '🗻' => 'Fudžio kalnas',
    '🏕' => 'stovyklavimas',
    '🏖' => 'paplūdimys ir skėtis',
    '🏜' => 'dykuma',
    '🏝' => 'atoki sala',
    '🏞' => 'nacionalinis parkas',
    '🏟' => 'stadionas',
    '🏛' => 'klasikinis pastatas',
    '🏗' => 'pastato konstrukcija',
    '🧱' => 'plyta',
    '🪨' => 'uoliena',
    '🪵' => 'mediena',
    '🛖' => 'namelis',
    '🏘' => 'namai',
    '🏚' => 'apleistas pastatas',
    '🏠' => 'namas',
    '🏡' => 'namas su sodu',
    '🏢' => 'biurų pastatas',
    '🏣' => 'japoniškas paštas',
    '🏤' => 'pašto pastatas',
    '🏥' => 'ligoninė',
    '🏦' => 'bankas',
    '🏨' => 'viešbutis',
    '🏩' => 'meilės viešbutis',
    '🏪' => 'visą parą dirbanti parduotuvė',
    '🏫' => 'mokykla',
    '🏬' => 'prekybos centras',
    '🏭' => 'gamykla',
    '🏯' => 'japoniška pilis',
    '🏰' => 'pilis',
    '💒' => 'vestuvės',
    '🗼' => 'Tokijo bokštas',
    '🗽' => 'laisvės statula',
    '⛪' => 'bažnyčia',
    '🕌' => 'mečetė',
    '🛕' => 'induistų šventykla',
    '🕍' => 'sinagoga',
    '⛩' => 'Šintoizmo šventykla',
    '🕋' => 'kaaba',
    '⛲' => 'fontanas',
    '⛺' => 'palapinė',
    '🌁' => 'rūkas',
    '🌃' => 'žvaigždėta naktis',
    '🏙' => 'miesto vaizdas',
    '🌄' => 'saulėtekis virš kalnų',
    '🌅' => 'saulėtekis',
    '🌆' => 'sutemos virš miesto',
    '🌇' => 'saulėlydis',
    '🌉' => 'tiltas naktį',
    '♨' => 'karštosios versmės',
    '🎠' => 'karuselės arkliukas',
    '🛝' => 'čiuožykla',
    '🎡' => 'apžvalgos ratas',
    '🎢' => 'linksmieji kalneliai',
    '💈' => 'kirpėjo suktukas',
    '🎪' => 'cirko palapinė',
    '🚂' => 'lokomotyvas',
    '🚃' => 'traukinio vagonas',
    '🚄' => 'greitasis traukinys',
    '🚅' => 'greitasis traukinys su smailu priekiu',
    '🚆' => 'traukinys',
    '🚇' => 'metro',
    '🚈' => 'miesto tramvajus',
    '🚉' => 'stotis',
    '🚊' => 'tramvajus',
    '🚝' => 'vienbėgis geležinkelis',
    '🚞' => 'kalnų traukinys',
    '🚋' => 'tramvajaus vagonas',
    '🚌' => 'autobusas',
    '🚍' => 'artėjantis autobusas',
    '🚎' => 'troleibusas',
    '🚐' => 'mikroautobusas',
    '🚑' => 'greitosios pagalbos automobilis',
    '🚒' => 'ugniagesių automobilis',
    '🚓' => 'policijos automobilis',
    '🚔' => 'artėjantis policijos automobilis',
    '🚕' => 'taksi',
    '🚖' => 'artėjantis taksi',
    '🚗' => 'automobilis',
    '🚘' => 'artėjantis automobilis',
    '🚙' => 'rekreacijos automobilis',
    '🛻' => 'pikapas',
    '🚚' => 'krovininis sunkvežimis',
    '🚛' => 'sunkvežimis su priekaba',
    '🚜' => 'traktorius',
    '🏎' => 'lenktyninis automobilis',
    '🏍' => 'motociklas',
    '🛵' => 'motoroleris',
    '🦽' => 'rankomis valdomas vežimėlis',
    '🦼' => 'motorizuotas vežimėlis',
    '🛺' => 'autorikša',
    '🚲' => 'dviratis',
    '🛴' => 'paspirtukas',
    '🛹' => 'riedlentė',
    '🛼' => 'riedučiai',
    '🚏' => 'autobusų stotelė',
    '🛣' => 'greitkelis',
    '🛤' => 'geležinkelio bėgiai',
    '🛢' => 'degalų statinė',
    '⛽' => 'degalų siurblys',
    '🛞' => 'ratas',
    '🚨' => 'policijos automobilio lempa',
    '🚥' => 'horizontalus šviesoforas',
    '🚦' => 'vertikalus šviesoforas',
    '🛑' => 'sustojimo ženklas',
    '🚧' => 'statybos',
    '⚓' => 'inkaras',
    '🛟' => 'gelbėjimo ratas',
    '⛵' => 'burlaivis',
    '🛶' => 'kanoja',
    '🚤' => 'motorinis kateris',
    '🛳' => 'keleivinis laivas',
    '⛴' => 'keltas',
    '🛥' => 'motorinė valtis',
    '🚢' => 'laivas',
    '✈' => 'lėktuvas',
    '🛩' => 'mažas lėktuvas',
    '🛫' => 'lėktuvo pakilimas',
    '🛬' => 'lėktuvo nusileidimas',
    '🪂' => 'parašiutas',
    '💺' => 'vieta',
    '🚁' => 'sraigstasparnis',
    '🚟' => 'kabanti geležinkelio linija',
    '🚠' => 'kalnų keltuvas',
    '🚡' => 'lynų keltuvas',
    '🛰' => 'palydovas',
    '🚀' => 'raketa',
    '🛸' => 'skraidanti lėkštė',
    '🛎' => 'skambutis',
    '🧳' => 'bagažas',
    '⌛' => 'smėlio laikrodis',
    '⏳' => 'smėlio laikrodis su krentančiu smėliu',
    '⌚' => 'laikrodis',
    '⏰' => 'žadintuvas',
    '⏱' => 'chronometras',
    '⏲' => 'laikmatis',
    '🕰' => 'virš židinio laikomas laikrodis',
    '🕛' => 'dvylika valandų',
    '🕧' => 'dvylika trisdešimt',
    '🕐' => 'pirma valanda',
    '🕜' => 'pusė dviejų',
    '🕑' => 'dvi valandos',
    '🕝' => 'pusė trijų',
    '🕒' => 'trys valandos',
    '🕞' => 'pusė keturių',
    '🕓' => 'keturios valandos',
    '🕟' => 'pusė penkių',
    '🕔' => 'penkios valandos',
    '🕠' => 'pusė šešių',
    '🕕' => 'šešios valandos',
    '🕡' => 'pusė septynių',
    '🕖' => 'septynios valandos',
    '🕢' => 'pusė aštuonių',
    '🕗' => 'aštuonios valandos',
    '🕣' => 'pusė devynių',
    '🕘' => 'devinta valanda',
    '🕤' => 'pusė dešimt',
    '🕙' => 'dešimt valandų',
    '🕥' => 'pusė vienuolikos',
    '🕚' => 'vienuolika valandų',
    '🕦' => 'pusė dvylikos',
    '🌑' => 'jaunas mėnulis',
    '🌒' => 'priešpilnis mėnulis',
    '🌓' => 'pirmas fazės ketvirtis',
    '🌔' => 'priešpilnis (pabaiga)',
    '🌕' => 'pilnatis',
    '🌖' => 'delčia',
    '🌗' => 'paskutinis fazės ketvirtis',
    '🌘' => 'delčia (pabaiga)',
    '🌙' => 'pusmėnulis',
    '🌚' => 'jaunas mėnulis su veidu',
    '🌛' => 'priešpilnio mėnulis su veidu',
    '🌜' => 'delčios mėnulis su veidu',
    '🌡' => 'termometras',
    '☀' => 'saulė',
    '🌝' => 'pilnatis su veidu',
    '🌞' => 'saulė su veidu',
    '🪐' => 'planeta su žiedu',
    '⭐' => 'balta vidutinė žvaigždė',
    '🌟' => 'žėrinti žvaigždė',
    '🌠' => 'krintanti žvaigždė',
    '🌌' => 'paukščių takas',
    '☁' => 'debesis',
    '⛅' => 'saulė už debesų',
    '⛈' => 'debesis su žaibu ir lietumi',
    '🌤' => 'saulė už nedidelio debesies',
    '🌥' => 'saulė už didelio debesies',
    '🌦' => 'saulė už debesies, iš kurio lyja',
    '🌧' => 'debesis, iš kurio lyja',
    '🌨' => 'debesis, iš kurio sninga',
    '🌩' => 'debesis su žaibu',
    '🌪' => 'tornadas',
    '🌫' => 'ūkana',
    '🌬' => 'vėjo veidas',
    '🌀' => 'ciklonas',
    '🌈' => 'vaivorykštė',
    '🌂' => 'suskleistas skėtis',
    '☂' => 'skėtis',
    '☔' => 'skėtis su lietaus lašais',
    '⛱' => 'skėtis ant žemės',
    '⚡' => 'aukštoji įtampa',
    '❄' => 'snaigė',
    '☃' => 'sniego senis',
    '⛄' => 'sniego senis be sniego',
    '☄' => 'kometa',
    '🔥' => 'ugnis',
    '💧' => 'lašas',
    '🌊' => 'vandens banga',
    '🎃' => 'žibintas iš moliūgo',
    '🎄' => 'Kalėdų eglutė',
    '🎆' => 'fejerverkai',
    '🎇' => 'šaltoji ugnelė',
    '🧨' => 'fejerverkas',
    '✨' => 'kibirkštėlės',
    '🎈' => 'balionas',
    '🎉' => 'konfeti šaudyklė',
    '🎊' => 'konfeti kamuolys',
    '🎋' => 'tanabata medis',
    '🎍' => 'dekoracija iš pušies',
    '🎎' => 'japoniškos lėlės',
    '🎏' => 'karpio vėtrungė',
    '🎐' => 'vėjo varpeliai',
    '🎑' => 'mėnesienos ceremonija',
    '🧧' => 'raudonas vokas',
    '🎀' => 'kaspinas',
    '🎁' => 'supakuota dovana',
    '🎗' => 'atminimo kaspinas',
    '🎟' => 'įėjimo bilietai',
    '🎫' => 'bilietas',
    '🎖' => 'kariuomenės medalis',
    '🏆' => 'trofėjus',
    '🏅' => 'sporto medalis',
    '🥇' => '1-osios vietos medalis',
    '🥈' => '2-osios vietos medalis',
    '🥉' => '3-osios vietos medalis',
    '⚽' => 'futbolo kamuolys',
    '⚾' => 'beisbolo kamuoliukas',
    '🥎' => 'softbolas',
    '🏀' => 'krepšinio kamuolys',
    '🏐' => 'tinklinio kamuolys',
    '🏈' => 'amerikietiškojo futbolo kamuolys',
    '🏉' => 'regbio kamuolys',
    '🎾' => 'teniso kamuoliukas',
    '🥏' => 'skraidantis diskas',
    '🎳' => 'boulingas',
    '🏏' => 'kriketas',
    '🏑' => 'žolės riedulys',
    '🏒' => 'ledo ritulio lazda ir ritulys',
    '🥍' => 'lakrosas',
    '🏓' => 'stalo tenisas',
    '🏸' => 'badmintonas',
    '🥊' => 'bokso pirštinė',
    '🥋' => 'kovos sporto šakos uniforma',
    '🥅' => 'vartai',
    '⛳' => 'vėliava skylutėje',
    '⛸' => 'pačiūžos',
    '🎣' => 'meškerė',
    '🤿' => 'nardymo kaukė',
    '🎽' => 'bėgimo marškinėliai',
    '🎿' => 'slidės',
    '🛷' => 'rogės',
    '🥌' => 'akmenslydis',
    '🎯' => 'smūgis tiesiai į taikinį',
    '🪀' => 'jo-jo',
    '🪁' => 'aitvaras',
    '🔫' => 'vandens šautuvas',
    '🎱' => 'biliardo kamuoliukas',
    '🔮' => 'krištolinis rutulys',
    '🪄' => 'stebuklinga lazdelė',
    '🎮' => 'vaizdo žaidimas',
    '🕹' => 'valdymo svirtis',
    '🎰' => 'žaidimų automatas',
    '🎲' => 'kauliukas',
    '🧩' => 'dėlionė',
    '🧸' => 'meškiukas',
    '🪅' => 'pinjata',
    '🪩' => 'veidrodinis rutulys',
    '🪆' => 'matrioškos',
    '♠' => 'pikai',
    '♥' => 'širdys',
    '♦' => 'būgnai',
    '♣' => 'kryžiai',
    '♟' => 'šachmatų pėstininkas',
    '🃏' => 'juokdarys',
    '🀄' => 'madžongo raudonas drakonas',
    '🎴' => 'kortos su gėlėmis',
    '🎭' => 'scenos menas',
    '🖼' => 'rėmas su paveikslu',
    '🎨' => 'dailininko paletė',
    '🧵' => 'siūlas',
    '🪡' => 'siuvimo adata',
    '🧶' => 'siūlų kamuolys',
    '🪢' => 'mazgas',
    '👓' => 'akiniai',
    '🕶' => 'akiniai nuo saulės',
    '🥽' => 'apsauginiai akiniai',
    '🥼' => 'laboratorinis chalatas',
    '🦺' => 'gelbėjimosi liemenė',
    '👔' => 'kaklaraištis',
    '👕' => 'marškinėliai',
    '👖' => 'džinsai',
    '🧣' => 'skara',
    '🧤' => 'pirštinės',
    '🧥' => 'paltas',
    '🧦' => 'kojinės',
    '👗' => 'suknelė',
    '👘' => 'kimono',
    '🥻' => 'saris',
    '🩱' => 'vientisas maudymosi kostiumėlis',
    '🩲' => 'trumpikės',
    '🩳' => 'šortai',
    '👙' => 'bikinis',
    '👚' => 'moteriški drabužiai',
    '🪭' => 'sulankstoma vėduoklė',
    '👛' => 'piniginė',
    '👜' => 'rankinė',
    '👝' => 'maišelis',
    '🛍' => 'pirkinių krepšeliai',
    '🎒' => 'mokyklinė kuprinė',
    '🩴' => 'sandalai su dirželiu',
    '👞' => 'vyriškas batas',
    '👟' => 'bėgimo batelis',
    '🥾' => 'žygio batai',
    '🥿' => 'lygiapadis batelis',
    '👠' => 'aukštakulnis batelis',
    '👡' => 'moteriška basutė',
    '🩰' => 'baleto bateliai',
    '👢' => 'moteriškas batas',
    '🪮' => 'plaukų šukutės',
    '👑' => 'karūna',
    '👒' => 'moteriška skrybėlė',
    '🎩' => 'cilindras',
    '🎓' => 'mokyklos baigimo kepurėlė',
    '🧢' => 'reklaminė kepurė',
    '🪖' => 'kareiviškas šalmas',
    '⛑' => 'šalmas su baltu kryžiumi',
    '📿' => 'rožinis',
    '💄' => 'lūpų dažai',
    '💍' => 'žiedas',
    '💎' => 'brangakmenis',
    '🔇' => 'garsiakalbis išjungtas',
    '🔈' => 'tylus garsiakalbis',
    '🔉' => 'vidutinio garso garsiakalbis',
    '🔊' => 'didelis garsiakalbio garsumas',
    '📢' => 'garsiakalbio simbolis',
    '📣' => 'garsintuvas',
    '📯' => 'pašto ragas',
    '🔔' => 'varpelis',
    '🔕' => 'perbrauktas varpelis',
    '🎼' => 'partitūra',
    '🎵' => 'muzikos nata',
    '🎶' => 'muzikos natos',
    '🎙' => 'studijos mikrofonas',
    '🎚' => 'lygio slankiklis',
    '🎛' => 'valdymo rankenos',
    '🎤' => 'mikrofonas',
    '🎧' => 'ausinės',
    '📻' => 'radijas',
    '🎷' => 'saksofonas',
    '🎺' => 'trimitas',
    '🪊' => 'trombonas',
    '🪗' => 'akordeonas',
    '🎸' => 'gitara',
    '🎹' => 'muzikos klaviatūra',
    '🎻' => 'smuikas',
    '🪕' => 'bandža',
    '🥁' => 'būgnas',
    '🪘' => 'ilgas būgnas',
    '🪇' => 'marakasai',
    '🪈' => 'fleita',
    '🪉' => 'arfa',
    '📱' => 'mobilusis telefonas',
    '📲' => 'mobilusis telefonas su rodykle',
    '☎' => 'telefonas',
    '📞' => 'telefono ragelis',
    '📟' => 'gaviklis',
    '📠' => 'fakso aparatas',
    '🔋' => 'baterija',
    '🪫' => 'išeikvota baterija',
    '🔌' => 'elektros kištukas',
    '💻' => 'skreitinis kompiuteris',
    '🖥' => 'stalinis kompiuteris',
    '🖨' => 'spausdintuvas',
    '⌨' => 'klaviatūra',
    '🖱' => 'kompiuterio pelė',
    '🖲' => 'rutulinis manipuliatorius',
    '💽' => 'kompiuterio diskas',
    '💾' => 'diskelis',
    '💿' => 'optinis diskas',
    '📀' => 'skaitmeninis vaizdo diskas',
    '🧮' => 'skaitytuvai',
    '🎥' => 'filmavimo kamera',
    '🎞' => 'filmo kadrai',
    '📽' => 'filmų projektorius',
    '🎬' => 'pliauškė',
    '📺' => 'televizorius',
    '📷' => 'fotoaparatas',
    '📸' => 'fotoaparatas su blykste',
    '📹' => 'vaizdo kamera',
    '📼' => 'vaizdo įrašų kasetė',
    '🔍' => 'didinimo stiklas į kairę',
    '🔎' => 'didinimo stiklas į dešinę',
    '🕯' => 'žvakė',
    '💡' => 'lemputė',
    '🔦' => 'žibintuvėlis',
    '🏮' => 'raudonas popierinis žibintas',
    '🪔' => 'žibalinė lempa',
    '📔' => 'užrašų knygelė su dekoratyviniu viršeliu',
    '📕' => 'užversta knyga',
    '📖' => 'atversta knyga',
    '📗' => 'žalia knyga',
    '📘' => 'mėlyna knyga',
    '📙' => 'oranžinė knyga',
    '📚' => 'knygos',
    '📓' => 'užrašinė',
    '📒' => 'sąskaitų knyga',
    '📃' => 'užsirietęs puslapis',
    '📜' => 'susuktas lapas',
    '📄' => 'puslapis viršutine puse',
    '📰' => 'laikraštis',
    '🗞' => 'susuktas laikraštis',
    '📑' => 'žymių skirtukai',
    '🔖' => 'žymė',
    '🏷' => 'etiketė',
    '🪙' => 'moneta',
    '💰' => 'pinigų maišas',
    '🪎' => 'lobių skrynia',
    '💴' => 'jenos banknotas',
    '💵' => 'dolerio banknotas',
    '💶' => 'euro banknotas',
    '💷' => 'svaro sterlingų banknotas',
    '💸' => 'pinigai su sparnais',
    '💳' => 'kredito kortelė',
    '🧾' => 'čekis',
    '💹' => 'didėjimo diagrama su jenos simboliu',
    '✉' => 'vokas',
    '📧' => 'el. laiškas',
    '📨' => 'gaunamas vokas',
    '📩' => 'vokas su rodykle',
    '📤' => 'siunčiamų laiškų dėklas',
    '📥' => 'gaunamų laiškų dėklas',
    '📦' => 'paketas',
    '📫' => 'uždaryta pašto dėžutė su pakelta vėliava',
    '📪' => 'uždaryta pašto dėžutė su nuleista vėliava',
    '📬' => 'atidaryta pašto dėžutė su pakelta vėliava',
    '📭' => 'atidaryta pašto dėžutė su nuleista vėliava',
    '📮' => 'pašto dėžutė',
    '🗳' => 'balsavimo dėžutė su balsavimo biuleteniu',
    '✏' => 'pieštukas',
    '✒' => 'juoda plunksna',
    '🖋' => 'automatinis plunksnakotis',
    '🖊' => 'rašiklis',
    '🖌' => 'teptukas',
    '🖍' => 'kreidelė',
    '📝' => 'atmintinė',
    '💼' => 'portfelis',
    '📁' => 'failų aplankas',
    '📂' => 'atidarytas failų aplankas',
    '🗂' => 'kortelių laikiklio skirtukai',
    '📅' => 'kalendorius',
    '📆' => 'nuplėšiamas kalendorius',
    '🗒' => 'užrašinė su spirale',
    '🗓' => 'kalendorius su spirale',
    '📇' => 'kortelių dėklas',
    '📈' => 'didėjimo tendencijos diagrama',
    '📉' => 'mažėjimo tendencijos diagrama',
    '📊' => 'juostinė diagrama',
    '📋' => 'segtuvas',
    '📌' => 'smeigtukas',
    '📍' => 'apvalus smeigtukas',
    '📎' => 'sąvaržėlė',
    '🖇' => 'sukabintos sąvaržėlės',
    '📏' => 'tiesi liniuotė',
    '📐' => 'trikampė liniuotė',
    '✂' => 'žirklės',
    '🗃' => 'kortelių saugojimo dėžė',
    '🗄' => 'bylų spintelė su stalčiais',
    '🗑' => 'šiukšliadėžė',
    '🔒' => 'spyna',
    '🔓' => 'atrakinta spyna',
    '🔏' => 'spyna ir rašiklis',
    '🔐' => 'užrakinta spyna su raktu',
    '🔑' => 'raktas',
    '🗝' => 'senas raktas',
    '🔨' => 'plaktukas',
    '🪓' => 'kirvis',
    '⛏' => 'kirstuvas',
    '⚒' => 'plaktuvas ir kirstuvas',
    '🛠' => 'plaktukas ir veržliaraktis',
    '🗡' => 'durklas',
    '⚔' => 'sukryžiuoti kardai',
    '💣' => 'bomba',
    '🪃' => 'bumerangas',
    '🏹' => 'lankas ir strėlė',
    '🛡' => 'skydas',
    '🪚' => 'pjūklas',
    '🔧' => 'veržliaraktis',
    '🪛' => 'atsuktuvas',
    '🔩' => 'veržlė ir varžtas',
    '⚙' => 'krumpliaratis',
    '🗜' => 'suspaudimas',
    '⚖' => 'svarstyklės su lėkštėmis',
    '🦯' => 'neregio lazda',
    '🔗' => 'jungtis',
    '⛓' => 'grandinės',
    '🪝' => 'kablys',
    '🧰' => 'įrankių rinkinys',
    '🧲' => 'magnetas',
    '🪜' => 'kopėčios',
    '🪏' => 'kastuvas',
    '⚗' => 'distiliavimo indas',
    '🧪' => 'mėgintuvėlis',
    '🧫' => 'petri lėkštelė',
    '🧬' => 'DNR',
    '🔬' => 'mikroskopas',
    '🔭' => 'teleskopas',
    '📡' => 'palydovinė antena',
    '💉' => 'švirkštas',
    '🩸' => 'kraujo lašas',
    '💊' => 'piliulė',
    '🩹' => 'pleistras',
    '🩼' => 'ramentas',
    '🩺' => 'stetoskopas',
    '🩻' => 'rentgenas',
    '🚪' => 'durys',
    '🛗' => 'elevatorius',
    '🪞' => 'veidrodis',
    '🪟' => 'langas',
    '🛏' => 'lova',
    '🛋' => 'sofa ir lempa',
    '🪑' => 'kėdė',
    '🚽' => 'tualetas',
    '🪠' => 'santechninė pompa',
    '🚿' => 'dušas',
    '🛁' => 'vonia',
    '🪤' => 'pelėkautai',
    '🪒' => 'skustuvas',
    '🧴' => 'losjono buteliukas',
    '🧷' => 'žiogelis',
    '🧹' => 'šluota',
    '🧺' => 'pintinė',
    '🧻' => 'popieriaus ritinys',
    '🪣' => 'kibiras',
    '🧼' => 'muilas',
    '🫧' => 'burbulai',
    '🪥' => 'dantų šepetėlis',
    '🧽' => 'kempinė',
    '🧯' => 'gesintuvas',
    '🛒' => 'pirkinių vežimėlis',
    '🚬' => 'rūkymas',
    '⚰' => 'karstas',
    '🪦' => 'paminklas',
    '⚱' => 'laidojimo urna',
    '🧿' => 'amuletas akis',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'plakatas',
    '🪪' => 'tapatybės kortelė',
    '🏧' => 'bankomato ženklas',
    '🚮' => 'šiukšlių metimo į šiukšliadėžes ženklas',
    '🚰' => 'geriamasis vanduo',
    '♿' => 'neįgaliojo vežimėlio simbolis',
    '🚹' => 'vyrų tualetas',
    '🚺' => 'moterų tualetas',
    '🚻' => 'tualeto kambarys',
    '🚼' => 'kūdikio simbolis',
    '🚾' => 'tualeto patalpa',
    '🛂' => 'pasų kontrolė',
    '🛃' => 'muitinė',
    '🛄' => 'bagažo skyrius',
    '🛅' => 'paliktas bagažas',
    '⚠' => 'įspėjimas',
    '🚸' => 'vaikų perėja',
    '⛔' => 'įėjimo nėra',
    '🚫' => 'draudžiama',
    '🚳' => 'dviračiai draudžiami',
    '🚭' => 'rūkyti draudžiama',
    '🚯' => 'šiukšlinti draudžiama',
    '🚱' => 'draudžiama gerti vandenį',
    '🚷' => 'pėstiesiems eiti draudžiama',
    '📵' => 'jokių mobiliųjų telefonų',
    '🔞' => 'tik pilnamečiams',
    '☢' => 'radioaktyvu',
    '☣' => 'biorizika',
    '⬆' => 'rodyklė į viršų',
    '↗' => 'rodyklė į viršų ir į dešinę',
    '➡' => 'rodyklė į dešinę',
    '↘' => 'rodyklė į apačią ir į dešinę',
    '⬇' => 'rodyklė į apačią',
    '↙' => 'rodyklė į apačią ir į kairę',
    '⬅' => 'rodyklė į kairę',
    '↖' => 'rodyklė į viršų ir į kairę',
    '↕' => 'rodyklė į viršų ir į apačią',
    '↔' => 'rodyklė į kairę ir į dešinę',
    '↩' => 'rodyklė į dešinę, užlenkta į kairę',
    '↪' => 'rodyklė į kairę, užlenkta į dešinę',
    '⤴' => 'rodyklė į dešinę, užlenkta į viršų',
    '⤵' => 'rodyklė į dešinę, užlenkta į apačią',
    '🔃' => 'vertikalios laikrodžio rodyklės kryptimis nukreiptos rodyklės',
    '🔄' => 'prieš laikrodžio rodyklę nukreiptų rodyklių mygtukas',
    '🔙' => 'rodyklė su užrašu „Back“',
    '🔚' => 'rodyklė su užrašu „End“',
    '🔛' => 'rodyklė su užrašu „On!“',
    '🔜' => 'rodyklė su užrašu „Soon“',
    '🔝' => 'rodyklė su užrašu „Top“',
    '🛐' => 'garbinimo vieta',
    '⚛' => 'atomo simbolis',
    '🕉' => 'Om',
    '✡' => 'Dovydo žvaigždė',
    '☸' => 'Dharmos ratas',
    '☯' => 'In ir Jang',
    '✝' => 'Romos katalikų kryžius',
    '☦' => 'ortodoksų kryžius',
    '☪' => 'žvaigždė ir pusmėnulis',
    '☮' => 'taikos simbolis',
    '🕎' => 'menora',
    '🔯' => 'šešiakampė žvaigždė su tašku',
    '🪯' => 'khanda',
    '♈' => 'avinas',
    '♉' => 'tauras',
    '♊' => 'dvyniai',
    '♋' => 'vėžys',
    '♌' => 'liūtas',
    '♍' => 'mergelė',
    '♎' => 'svarstyklės',
    '♏' => 'skorpionas',
    '♐' => 'šaulys',
    '♑' => 'ožiaragis',
    '♒' => 'vandenio ženklas',
    '♓' => 'žuvys',
    '⛎' => 'gyvatnešis',
    '🔀' => 'maišyti takelius',
    '🔁' => 'kartoti',
    '🔂' => 'kartoti vieną',
    '▶' => 'paleisti',
    '⏩' => 'sukti pirmyn',
    '⏭' => 'kitas takelis',
    '⏯' => 'paleisti arba pristabdyti',
    '◀' => 'atvirkštinė tvarka',
    '⏪' => 'atsukti atgal',
    '⏮' => 'paskutinis takelis',
    '🔼' => 'į viršų',
    '⏫' => 'greitai į viršų',
    '🔽' => 'į apačią',
    '⏬' => 'greitai į apačią',
    '⏸' => 'pristabdyti',
    '⏹' => 'sustabdymo mygtukas',
    '⏺' => 'įrašymo mygtukas',
    '⏏' => 'išmetimo mygtukas',
    '🎦' => 'kinas',
    '🔅' => 'užtemdymo mygtukas',
    '🔆' => 'ryškumo mygtukas',
    '📶' => 'antenos juostos',
    '🛜' => 'belaidis ryšys',
    '📳' => 'vibravimo režimas',
    '📴' => 'išjungti mobilųjį telefoną',
    '♀' => 'moteriškos lyties ženklas',
    '♂' => 'vyriškos lyties ženklas',
    '⚧' => 'translyčių simbolis',
    '✖' => 'paryškintas daugybos ženklas',
    '➕' => 'paryškintas pliusas',
    '➖' => 'paryškintas minusas',
    '➗' => 'paryškintas dalybos ženklas',
    '🟰' => 'paryškintas lygybės ženklas',
    '♾' => 'begalybė',
    '‼' => 'du šauktukai',
    '⁉' => 'šauktukas ir klaustukas',
    '❓' => 'raudonas klaustukas',
    '❔' => 'baltas klaustukas',
    '❕' => 'baltas šauktukas',
    '❗' => 'raudonas šauktukas',
    '〰' => 'vingiuotas brūkšnys',
    '💱' => 'valiutos keitimas',
    '💲' => 'paryškintas dolerio ženklas',
    '⚕' => 'medicinos simbolis',
    '♻' => 'perdirbimo simbolis',
    '⚜' => 'lelijos simbolis',
    '🔱' => 'trišakė emblema',
    '📛' => 'vardo ženklelis',
    '🔰' => 'japoniškas pradedančiojo simbolis',
    '⭕' => 'ryškus didelis ratas',
    '✅' => 'balta paryškinta varnelė',
    '☑' => 'balsavimo laukelis su varnele',
    '✔' => 'paryškinta varnelė',
    '❌' => 'kryžiukas',
    '❎' => 'kryžiuko mygtukas',
    '➰' => 'kilpelė',
    '➿' => 'dviguba kilpelė',
    '〽' => 'dalių apkeitimo ženklas',
    '✳' => 'aštuoniakampė žvaigždutė',
    '✴' => 'aštuoniakampė žvaigždė',
    '❇' => 'kibirkštėlė',
    '™' => 'prekės ženklas',
    '🫟' => 'tiškalas',
    '🔠' => 'įvestis didžiosios lotyniškos raidės',
    '🔡' => 'įvestis mažosios lotyniškos raidės',
    '🔢' => 'įvesties skaičiai',
    '🔣' => 'įvesties simboliai',
    '🔤' => 'įvestis lotyniškos raidės',
    '🅰' => 'mygtukas „A“ (raudona)',
    '🆎' => 'mygtukas „AB“ (raudona)',
    '🅱' => 'mygtukas „B“ (raudona)',
    '🆑' => 'simbolis „CL“',
    '🆒' => 'simbolis „COOL“',
    '🆓' => 'simbolis „FREE“',
    'ℹ' => 'informacija',
    '🆔' => 'simbolis „ID“',
    'Ⓜ' => 'raidė „M“',
    '🆕' => 'simbolis „NEW“',
    '🆖' => 'simbolis „NG“',
    '🅾' => 'simbolis „O“ (raudona)',
    '🆗' => 'simbolis „OK“',
    '🅿' => 'simbolis „P“',
    '🆘' => 'simbolis „SOS“',
    '🆙' => 'mygtukas „Up!“',
    '🆚' => 'simbolis „VS“',
    '🈁' => 'čia reiškiantis hieroglifas',
    '🈂' => 'paslaugos mokestį reiškiantis hieroglifas',
    '🈷' => 'mėnesio sumą reiškiantis hieroglifas',
    '🈶' => 'ne nemokamą reiškiantis hieroglifas',
    '🈯' => 'rezervavimą reiškiantis hieroglifas',
    '🉐' => 'susitarimą reiškiantis hieroglifas',
    '🈹' => 'nuolaidą reiškiantis hieroglifas',
    '🈚' => 'nemokamumą reiškiantis hieroglifas',
    '🈲' => 'draudimą reiškiantis hieroglifas',
    '🉑' => 'sutikimą reiškiantis hieroglifas',
    '🈸' => 'taikymą reiškiantis hieroglifas',
    '🈴' => 'bendrumą reiškiantis hieroglifas',
    '🈳' => 'tuštumą reiškiantis hieroglifas',
    '㊗' => 'pasveikinimą reiškiantis hieroglifas',
    '㊙' => 'paslaptį reiškiantis hieroglifas',
    '🈺' => 'veikimą reiškiantis hieroglifas',
    '🈵' => 'pilnatvę reiškiantis hieroglifas',
    '🔴' => 'raudonas apskritimas',
    '🟠' => 'oranžinis apskritimas',
    '🟡' => 'geltonas apskritimas',
    '🟢' => 'žalias apskritimas',
    '🔵' => 'mėlynas apskritimas',
    '🟣' => 'violetinis apskritimas',
    '🟤' => 'rudas apskritimas',
    '⚫' => 'juodas apskritimas',
    '⚪' => 'baltas apskritimas',
    '🟥' => 'raudonas kvadratas',
    '🟧' => 'oranžinis kvadratas',
    '🟨' => 'geltonas kvadratas',
    '🟩' => 'žalias kvadratas',
    '🟦' => 'mėlynas kvadratas',
    '🟪' => 'violetinis kvadratas',
    '🟫' => 'rudas kvadratas',
    '⬛' => 'juodas didelis kvadratas',
    '⬜' => 'baltas didelis kvadratas',
    '◼' => 'juodas vidutinis kvadratas',
    '◻' => 'baltas vidutinis kvadratas',
    '◾' => 'juodas vidutiniškai mažas kvadratas',
    '◽' => 'baltas vidutiniškai mažas kvadratas',
    '▪' => 'juodas mažas kvadratas',
    '▫' => 'baltas mažas kvadratas',
    '🔶' => 'didelis oranžinis deimantas',
    '🔷' => 'didelis mėlynas deimantas',
    '🔸' => 'mažas oranžinis deimantas',
    '🔹' => 'mažas mėlynas deimantas',
    '🔺' => 'raudonas į viršų nukreiptas trikampis',
    '🔻' => 'raudonas į apačią nukreiptas trikampis',
    '💠' => 'deimantas su tašku',
    '🔘' => 'akutė',
    '🔳' => 'baltas kvadratinis mygtukas',
    '🔲' => 'juodas kvadratinis mygtukas',
    '🏁' => 'vėliava langeliais',
    '🚩' => 'trikampė vėliava',
    '🎌' => 'sukryžiuotos vėliavos',
    '🏴' => 'juoda vėliava',
    '🏳' => 'balta vėliava',
];
