<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'cium: dewasa, dewasa, ton kulit cerah dan ton kulit sederhana cerah',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'cium: dewasa, dewasa, ton kulit cerah dan ton kulit sederhana',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'cium: dewasa, dewasa, ton kulit cerah dan ton kulit sederhana gelap',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'cium: dewasa, dewasa, ton kulit cerah dan ton kulit gelap',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'cium: dewasa, dewasa, ton kulit sederhana cerah dan ton kulit cerah',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'cium: dewasa, dewasa, ton kulit sederhana cerah dan ton kulit sederhana',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'cium: dewasa, dewasa, ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'cium: dewasa, dewasa, ton kulit sederhana cerah dan ton kulit gelap',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'cium: dewasa, dewasa, ton kulit sederhana dan ton kulit cerah',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'cium: dewasa, dewasa, ton kulit sederhana dan ton kulit sederhana cerah',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'cium: dewasa, dewasa, ton kulit sederhana dan ton kulit sederhana gelap',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'cium: dewasa, dewasa, ton kulit sederhana dan ton kulit gelap',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'cium: dewasa, dewasa, ton kulit sederhana gelap dan ton kulit cerah',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'cium: dewasa, dewasa, ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'cium: dewasa, dewasa, ton kulit sederhana gelap dan ton kulit sederhana',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'cium: dewasa, dewasa, ton kulit sederhana gelap dan ton kulit gelap',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'cium: dewasa, dewasa, ton kulit gelap dan ton kulit cerah',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'cium: dewasa, dewasa, ton kulit gelap dan ton kulit sederhana cerah',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'cium: dewasa, dewasa, ton kulit gelap dan ton kulit sederhana',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'cium: dewasa, dewasa, ton kulit gelap dan ton kulit sederhana gelap',
    '👨🏻‍❤‍💋‍👨🏻' => 'cium: lelaki, lelaki dan ton kulit cerah',
    '👨🏻‍❤‍💋‍👨🏼' => 'cium: lelaki, lelaki, ton kulit cerah dan ton kulit sederhana cerah',
    '👨🏻‍❤‍💋‍👨🏽' => 'cium: lelaki, lelaki, ton kulit cerah dan ton kulit sederhana',
    '👨🏻‍❤‍💋‍👨🏾' => 'cium: lelaki, lelaki, ton kulit cerah dan ton kulit sederhana gelap',
    '👨🏻‍❤‍💋‍👨🏿' => 'cium: lelaki, lelaki, ton kulit cerah dan ton kulit gelap',
    '👨🏼‍❤‍💋‍👨🏻' => 'cium: lelaki, lelaki, ton kulit sederhana cerah dan ton kulit cerah',
    '👨🏼‍❤‍💋‍👨🏼' => 'cium: lelaki, lelaki dan ton kulit sederhana cerah',
    '👨🏼‍❤‍💋‍👨🏽' => 'cium: lelaki, lelaki, ton kulit sederhana cerah dan ton kulit sederhana',
    '👨🏼‍❤‍💋‍👨🏾' => 'cium: lelaki, lelaki, ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👨🏼‍❤‍💋‍👨🏿' => 'cium: lelaki, lelaki, ton kulit sederhana cerah dan ton kulit gelap',
    '👨🏽‍❤‍💋‍👨🏻' => 'cium: lelaki, lelaki, ton kulit sederhana dan ton kulit cerah',
    '👨🏽‍❤‍💋‍👨🏼' => 'cium: lelaki, lelaki, ton kulit sederhana dan ton kulit sederhana cerah',
    '👨🏽‍❤‍💋‍👨🏽' => 'cium: lelaki, lelaki dan ton kulit sederhana',
    '👨🏽‍❤‍💋‍👨🏾' => 'cium: lelaki, lelaki, ton kulit sederhana dan ton kulit sederhana gelap',
    '👨🏽‍❤‍💋‍👨🏿' => 'cium: lelaki, lelaki, ton kulit sederhana dan ton kulit gelap',
    '👨🏾‍❤‍💋‍👨🏻' => 'cium: lelaki, lelaki, ton kulit sederhana gelap dan ton kulit cerah',
    '👨🏾‍❤‍💋‍👨🏼' => 'cium: lelaki, lelaki, ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👨🏾‍❤‍💋‍👨🏽' => 'cium: lelaki, lelaki, ton kulit sederhana gelap dan ton kulit sederhana',
    '👨🏾‍❤‍💋‍👨🏾' => 'cium: lelaki, lelaki dan ton kulit sederhana gelap',
    '👨🏾‍❤‍💋‍👨🏿' => 'cium: lelaki, lelaki, ton kulit sederhana gelap dan ton kulit gelap',
    '👨🏿‍❤‍💋‍👨🏻' => 'cium: lelaki, lelaki, ton kulit gelap dan ton kulit cerah',
    '👨🏿‍❤‍💋‍👨🏼' => 'cium: lelaki, lelaki, ton kulit gelap dan ton kulit sederhana cerah',
    '👨🏿‍❤‍💋‍👨🏽' => 'cium: lelaki, lelaki, ton kulit gelap dan ton kulit sederhana',
    '👨🏿‍❤‍💋‍👨🏾' => 'cium: lelaki, lelaki, ton kulit gelap dan ton kulit sederhana gelap',
    '👨🏿‍❤‍💋‍👨🏿' => 'cium: lelaki, lelaki dan ton kulit gelap',
    '👩🏻‍❤‍💋‍👨🏻' => 'cium: perempuan, lelaki dan ton kulit cerah',
    '👩🏻‍❤‍💋‍👨🏼' => 'cium: perempuan, lelaki, ton kulit cerah dan ton kulit sederhana cerah',
    '👩🏻‍❤‍💋‍👨🏽' => 'cium: perempuan, lelaki, ton kulit cerah dan ton kulit sederhana',
    '👩🏻‍❤‍💋‍👨🏾' => 'cium: perempuan, lelaki, ton kulit cerah dan ton kulit sederhana gelap',
    '👩🏻‍❤‍💋‍👨🏿' => 'cium: perempuan, lelaki, ton kulit cerah dan ton kulit gelap',
    '👩🏼‍❤‍💋‍👨🏻' => 'cium: perempuan, lelaki, ton kulit sederhana cerah dan ton kulit cerah',
    '👩🏼‍❤‍💋‍👨🏼' => 'cium: perempuan, lelaki dan ton kulit sederhana cerah',
    '👩🏼‍❤‍💋‍👨🏽' => 'cium: perempuan, lelaki, ton kulit sederhana cerah dan ton kulit sederhana',
    '👩🏼‍❤‍💋‍👨🏾' => 'cium: perempuan, lelaki, ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👩🏼‍❤‍💋‍👨🏿' => 'cium: perempuan, lelaki, ton kulit sederhana cerah dan ton kulit gelap',
    '👩🏽‍❤‍💋‍👨🏻' => 'cium: perempuan, lelaki, ton kulit sederhana dan ton kulit cerah',
    '👩🏽‍❤‍💋‍👨🏼' => 'cium: perempuan, lelaki, ton kulit sederhana dan ton kulit sederhana cerah',
    '👩🏽‍❤‍💋‍👨🏽' => 'cium: perempuan, lelaki dan ton kulit sederhana',
    '👩🏽‍❤‍💋‍👨🏾' => 'cium: perempuan, lelaki, ton kulit sederhana dan ton kulit sederhana gelap',
    '👩🏽‍❤‍💋‍👨🏿' => 'cium: perempuan, lelaki, ton kulit sederhana dan ton kulit gelap',
    '👩🏾‍❤‍💋‍👨🏻' => 'cium: perempuan, lelaki, ton kulit sederhana gelap dan ton kulit cerah',
    '👩🏾‍❤‍💋‍👨🏼' => 'cium: perempuan, lelaki, ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👩🏾‍❤‍💋‍👨🏽' => 'cium: perempuan, lelaki, ton kulit sederhana gelap dan ton kulit sederhana',
    '👩🏾‍❤‍💋‍👨🏾' => 'cium: perempuan, lelaki dan ton kulit sederhana gelap',
    '👩🏾‍❤‍💋‍👨🏿' => 'cium: perempuan, lelaki, ton kulit sederhana gelap dan ton kulit gelap',
    '👩🏿‍❤‍💋‍👨🏻' => 'cium: perempuan, lelaki, ton kulit gelap dan ton kulit cerah',
    '👩🏿‍❤‍💋‍👨🏼' => 'cium: perempuan, lelaki, ton kulit gelap dan ton kulit sederhana cerah',
    '👩🏿‍❤‍💋‍👨🏽' => 'cium: perempuan, lelaki, ton kulit gelap dan ton kulit sederhana',
    '👩🏿‍❤‍💋‍👨🏾' => 'cium: perempuan, lelaki, ton kulit gelap dan ton kulit sederhana gelap',
    '👩🏿‍❤‍💋‍👨🏿' => 'cium: perempuan, lelaki dan ton kulit gelap',
    '👩🏻‍❤‍💋‍👩🏻' => 'cium: perempuan, perempuan dan ton kulit cerah',
    '👩🏻‍❤‍💋‍👩🏼' => 'cium: perempuan, perempuan, ton kulit cerah dan ton kulit sederhana cerah',
    '👩🏻‍❤‍💋‍👩🏽' => 'cium: perempuan, perempuan, ton kulit cerah dan ton kulit sederhana',
    '👩🏻‍❤‍💋‍👩🏾' => 'cium: perempuan, perempuan, ton kulit cerah dan ton kulit sederhana gelap',
    '👩🏻‍❤‍💋‍👩🏿' => 'cium: perempuan, perempuan, ton kulit cerah dan ton kulit gelap',
    '👩🏼‍❤‍💋‍👩🏻' => 'cium: perempuan, perempuan, ton kulit sederhana cerah dan ton kulit cerah',
    '👩🏼‍❤‍💋‍👩🏼' => 'cium: perempuan, perempuan dan ton kulit sederhana cerah',
    '👩🏼‍❤‍💋‍👩🏽' => 'cium: perempuan, perempuan, ton kulit sederhana cerah dan ton kulit sederhana',
    '👩🏼‍❤‍💋‍👩🏾' => 'cium: perempuan, perempuan, ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👩🏼‍❤‍💋‍👩🏿' => 'cium: perempuan, perempuan, ton kulit sederhana cerah dan ton kulit gelap',
    '👩🏽‍❤‍💋‍👩🏻' => 'cium: perempuan, perempuan, ton kulit sederhana dan ton kulit cerah',
    '👩🏽‍❤‍💋‍👩🏼' => 'cium: perempuan, perempuan, ton kulit sederhana dan ton kulit sederhana cerah',
    '👩🏽‍❤‍💋‍👩🏽' => 'cium: perempuan, perempuan dan ton kulit sederhana',
    '👩🏽‍❤‍💋‍👩🏾' => 'cium: perempuan, perempuan, ton kulit sederhana dan ton kulit sederhana gelap',
    '👩🏽‍❤‍💋‍👩🏿' => 'cium: perempuan, perempuan, ton kulit sederhana dan ton kulit gelap',
    '👩🏾‍❤‍💋‍👩🏻' => 'cium: perempuan, perempuan, ton kulit sederhana gelap dan ton kulit cerah',
    '👩🏾‍❤‍💋‍👩🏼' => 'cium: perempuan, perempuan, ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👩🏾‍❤‍💋‍👩🏽' => 'cium: perempuan, perempuan, ton kulit sederhana gelap dan ton kulit sederhana',
    '👩🏾‍❤‍💋‍👩🏾' => 'cium: perempuan, perempuan dan ton kulit sederhana gelap',
    '👩🏾‍❤‍💋‍👩🏿' => 'cium: perempuan, perempuan, ton kulit sederhana gelap dan ton kulit gelap',
    '👩🏿‍❤‍💋‍👩🏻' => 'cium: perempuan, perempuan, ton kulit gelap dan ton kulit cerah',
    '👩🏿‍❤‍💋‍👩🏼' => 'cium: perempuan, perempuan, ton kulit gelap dan ton kulit sederhana cerah',
    '👩🏿‍❤‍💋‍👩🏽' => 'cium: perempuan, perempuan, ton kulit gelap dan ton kulit sederhana',
    '👩🏿‍❤‍💋‍👩🏾' => 'cium: perempuan, perempuan, ton kulit gelap dan ton kulit sederhana gelap',
    '👩🏿‍❤‍💋‍👩🏿' => 'cium: perempuan, perempuan dan ton kulit gelap',
    '🧑🏻‍🫯‍🧑🏼' => 'bergusti: ton kulit cerah dan ton kulit sederhana cerah',
    '🧑🏻‍🫯‍🧑🏽' => 'bergusti: ton kulit cerah dan ton kulit sederhana',
    '🧑🏻‍🫯‍🧑🏾' => 'bergusti: ton kulit cerah dan ton kulit sederhana gelap',
    '🧑🏻‍🫯‍🧑🏿' => 'bergusti: ton kulit cerah dan ton kulit gelap',
    '🧑🏼‍🫯‍🧑🏻' => 'bergusti: ton kulit sederhana cerah dan ton kulit cerah',
    '🧑🏼‍🫯‍🧑🏽' => 'bergusti: ton kulit sederhana cerah dan ton kulit sederhana',
    '🧑🏼‍🫯‍🧑🏾' => 'bergusti: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '🧑🏼‍🫯‍🧑🏿' => 'bergusti: ton kulit sederhana cerah dan ton kulit gelap',
    '🧑🏽‍🫯‍🧑🏻' => 'bergusti: ton kulit sederhana dan ton kulit cerah',
    '🧑🏽‍🫯‍🧑🏼' => 'bergusti: ton kulit sederhana dan ton kulit sederhana cerah',
    '🧑🏽‍🫯‍🧑🏾' => 'bergusti: ton kulit sederhana dan ton kulit sederhana gelap',
    '🧑🏽‍🫯‍🧑🏿' => 'bergusti: ton kulit sederhana dan ton kulit gelap',
    '🧑🏾‍🫯‍🧑🏻' => 'bergusti: ton kulit sederhana gelap dan ton kulit cerah',
    '🧑🏾‍🫯‍🧑🏼' => 'bergusti: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '🧑🏾‍🫯‍🧑🏽' => 'bergusti: ton kulit sederhana gelap dan ton kulit sederhana',
    '🧑🏾‍🫯‍🧑🏿' => 'bergusti: ton kulit sederhana gelap dan ton kulit gelap',
    '🧑🏿‍🫯‍🧑🏻' => 'bergusti: ton kulit gelap dan ton kulit cerah',
    '🧑🏿‍🫯‍🧑🏼' => 'bergusti: ton kulit gelap dan ton kulit sederhana cerah',
    '🧑🏿‍🫯‍🧑🏽' => 'bergusti: ton kulit gelap dan ton kulit sederhana',
    '🧑🏿‍🫯‍🧑🏾' => 'bergusti: ton kulit gelap dan ton kulit sederhana gelap',
    '🧑🏻‍❤‍🧑🏼' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit cerah dan ton kulit sederhana cerah',
    '🧑🏻‍❤‍🧑🏽' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit cerah dan ton kulit sederhana',
    '🧑🏻‍❤‍🧑🏾' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit cerah dan ton kulit sederhana gelap',
    '🧑🏻‍❤‍🧑🏿' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit cerah dan ton kulit gelap',
    '🧑🏼‍❤‍🧑🏻' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana cerah dan ton kulit cerah',
    '🧑🏼‍❤‍🧑🏽' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana cerah dan ton kulit sederhana',
    '🧑🏼‍❤‍🧑🏾' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '🧑🏼‍❤‍🧑🏿' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana cerah dan ton kulit gelap',
    '🧑🏽‍❤‍🧑🏻' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana dan ton kulit cerah',
    '🧑🏽‍❤‍🧑🏼' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana dan ton kulit sederhana cerah',
    '🧑🏽‍❤‍🧑🏾' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana dan ton kulit sederhana gelap',
    '🧑🏽‍❤‍🧑🏿' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana dan ton kulit gelap',
    '🧑🏾‍❤‍🧑🏻' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana gelap dan ton kulit cerah',
    '🧑🏾‍❤‍🧑🏼' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '🧑🏾‍❤‍🧑🏽' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana gelap dan ton kulit sederhana',
    '🧑🏾‍❤‍🧑🏿' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit sederhana gelap dan ton kulit gelap',
    '🧑🏿‍❤‍🧑🏻' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit gelap dan ton kulit cerah',
    '🧑🏿‍❤‍🧑🏼' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit gelap dan ton kulit sederhana cerah',
    '🧑🏿‍❤‍🧑🏽' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit gelap dan ton kulit sederhana',
    '🧑🏿‍❤‍🧑🏾' => 'pasangan dengan simbol hati: dewasa, dewasa, ton kulit gelap dan ton kulit sederhana gelap',
    '🧑🏻‍🐰‍🧑🏼' => 'orang dengan telinga arnab: ton kulit cerah dan ton kulit sederhana cerah',
    '🧑🏻‍🐰‍🧑🏽' => 'orang dengan telinga arnab: ton kulit cerah dan ton kulit sederhana',
    '🧑🏻‍🐰‍🧑🏾' => 'orang dengan telinga arnab: ton kulit cerah dan ton kulit sederhana gelap',
    '🧑🏻‍🐰‍🧑🏿' => 'orang dengan telinga arnab: ton kulit cerah dan ton kulit gelap',
    '🧑🏼‍🐰‍🧑🏻' => 'orang dengan telinga arnab: ton kulit sederhana cerah dan ton kulit cerah',
    '🧑🏼‍🐰‍🧑🏽' => 'orang dengan telinga arnab: ton kulit sederhana cerah dan ton kulit sederhana',
    '🧑🏼‍🐰‍🧑🏾' => 'orang dengan telinga arnab: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '🧑🏼‍🐰‍🧑🏿' => 'orang dengan telinga arnab: ton kulit sederhana cerah dan ton kulit gelap',
    '🧑🏽‍🐰‍🧑🏻' => 'orang dengan telinga arnab: ton kulit sederhana dan ton kulit cerah',
    '🧑🏽‍🐰‍🧑🏼' => 'orang dengan telinga arnab: ton kulit sederhana dan ton kulit sederhana cerah',
    '🧑🏽‍🐰‍🧑🏾' => 'orang dengan telinga arnab: ton kulit sederhana dan ton kulit sederhana gelap',
    '🧑🏽‍🐰‍🧑🏿' => 'orang dengan telinga arnab: ton kulit sederhana dan ton kulit gelap',
    '🧑🏾‍🐰‍🧑🏻' => 'orang dengan telinga arnab: ton kulit sederhana gelap dan ton kulit cerah',
    '🧑🏾‍🐰‍🧑🏼' => 'orang dengan telinga arnab: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '🧑🏾‍🐰‍🧑🏽' => 'orang dengan telinga arnab: ton kulit sederhana gelap dan ton kulit sederhana',
    '🧑🏾‍🐰‍🧑🏿' => 'orang dengan telinga arnab: ton kulit sederhana gelap dan ton kulit gelap',
    '🧑🏿‍🐰‍🧑🏻' => 'orang dengan telinga arnab: ton kulit gelap dan ton kulit cerah',
    '🧑🏿‍🐰‍🧑🏼' => 'orang dengan telinga arnab: ton kulit gelap dan ton kulit sederhana cerah',
    '🧑🏿‍🐰‍🧑🏽' => 'orang dengan telinga arnab: ton kulit gelap dan ton kulit sederhana',
    '🧑🏿‍🐰‍🧑🏾' => 'orang dengan telinga arnab: ton kulit gelap dan ton kulit sederhana gelap',
    '👨🏻‍🫯‍👨🏼' => 'lelaki bergusti: ton kulit cerah dan ton kulit sederhana cerah',
    '👨🏻‍🫯‍👨🏽' => 'lelaki bergusti: ton kulit cerah dan ton kulit sederhana',
    '👨🏻‍🫯‍👨🏾' => 'lelaki bergusti: ton kulit cerah dan ton kulit sederhana gelap',
    '👨🏻‍🫯‍👨🏿' => 'lelaki bergusti: ton kulit cerah dan ton kulit gelap',
    '👨🏼‍🫯‍👨🏻' => 'lelaki bergusti: ton kulit sederhana cerah dan ton kulit cerah',
    '👨🏼‍🫯‍👨🏽' => 'lelaki bergusti: ton kulit sederhana cerah dan ton kulit sederhana',
    '👨🏼‍🫯‍👨🏾' => 'lelaki bergusti: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👨🏼‍🫯‍👨🏿' => 'lelaki bergusti: ton kulit sederhana cerah dan ton kulit gelap',
    '👨🏽‍🫯‍👨🏻' => 'lelaki bergusti: ton kulit sederhana dan ton kulit cerah',
    '👨🏽‍🫯‍👨🏼' => 'lelaki bergusti: ton kulit sederhana dan ton kulit sederhana cerah',
    '👨🏽‍🫯‍👨🏾' => 'lelaki bergusti: ton kulit sederhana dan ton kulit sederhana gelap',
    '👨🏽‍🫯‍👨🏿' => 'lelaki bergusti: ton kulit sederhana dan ton kulit gelap',
    '👨🏾‍🫯‍👨🏻' => 'lelaki bergusti: ton kulit sederhana gelap dan ton kulit cerah',
    '👨🏾‍🫯‍👨🏼' => 'lelaki bergusti: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👨🏾‍🫯‍👨🏽' => 'lelaki bergusti: ton kulit sederhana gelap dan ton kulit sederhana',
    '👨🏾‍🫯‍👨🏿' => 'lelaki bergusti: ton kulit sederhana gelap dan ton kulit gelap',
    '👨🏿‍🫯‍👨🏻' => 'lelaki bergusti: ton kulit gelap dan ton kulit cerah',
    '👨🏿‍🫯‍👨🏼' => 'lelaki bergusti: ton kulit gelap dan ton kulit sederhana cerah',
    '👨🏿‍🫯‍👨🏽' => 'lelaki bergusti: ton kulit gelap dan ton kulit sederhana',
    '👨🏿‍🫯‍👨🏾' => 'lelaki bergusti: ton kulit gelap dan ton kulit sederhana gelap',
    '👨🏻‍❤‍👨🏻' => 'pasangan dengan simbol hati: lelaki, lelaki dan ton kulit cerah',
    '👨🏻‍❤‍👨🏼' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit cerah dan ton kulit sederhana cerah',
    '👨🏻‍❤‍👨🏽' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit cerah dan ton kulit sederhana',
    '👨🏻‍❤‍👨🏾' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit cerah dan ton kulit sederhana gelap',
    '👨🏻‍❤‍👨🏿' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit cerah dan ton kulit gelap',
    '👨🏼‍❤‍👨🏻' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana cerah dan ton kulit cerah',
    '👨🏼‍❤‍👨🏼' => 'pasangan dengan simbol hati: lelaki, lelaki dan ton kulit sederhana cerah',
    '👨🏼‍❤‍👨🏽' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana cerah dan ton kulit sederhana',
    '👨🏼‍❤‍👨🏾' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👨🏼‍❤‍👨🏿' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana cerah dan ton kulit gelap',
    '👨🏽‍❤‍👨🏻' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana dan ton kulit cerah',
    '👨🏽‍❤‍👨🏼' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana dan ton kulit sederhana cerah',
    '👨🏽‍❤‍👨🏽' => 'pasangan dengan simbol hati: lelaki, lelaki dan ton kulit sederhana',
    '👨🏽‍❤‍👨🏾' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana dan ton kulit sederhana gelap',
    '👨🏽‍❤‍👨🏿' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana dan ton kulit gelap',
    '👨🏾‍❤‍👨🏻' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana gelap dan ton kulit cerah',
    '👨🏾‍❤‍👨🏼' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👨🏾‍❤‍👨🏽' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana gelap dan ton kulit sederhana',
    '👨🏾‍❤‍👨🏾' => 'pasangan dengan simbol hati: lelaki, lelaki dan ton kulit sederhana gelap',
    '👨🏾‍❤‍👨🏿' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit sederhana gelap dan ton kulit gelap',
    '👨🏿‍❤‍👨🏻' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit gelap dan ton kulit cerah',
    '👨🏿‍❤‍👨🏼' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit gelap dan ton kulit sederhana cerah',
    '👨🏿‍❤‍👨🏽' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit gelap dan ton kulit sederhana',
    '👨🏿‍❤‍👨🏾' => 'pasangan dengan simbol hati: lelaki, lelaki, ton kulit gelap dan ton kulit sederhana gelap',
    '👨🏿‍❤‍👨🏿' => 'pasangan dengan simbol hati: lelaki, lelaki dan ton kulit gelap',
    '👨🏻‍🐰‍👨🏼' => 'lelaki berpesta: ton kulit cerah dan ton kulit sederhana cerah',
    '👨🏻‍🐰‍👨🏽' => 'lelaki berpesta: ton kulit cerah dan ton kulit sederhana',
    '👨🏻‍🐰‍👨🏾' => 'lelaki berpesta: ton kulit cerah dan ton kulit sederhana gelap',
    '👨🏻‍🐰‍👨🏿' => 'lelaki berpesta: ton kulit cerah dan ton kulit gelap',
    '👨🏼‍🐰‍👨🏻' => 'lelaki berpesta: ton kulit sederhana cerah dan ton kulit cerah',
    '👨🏼‍🐰‍👨🏽' => 'lelaki berpesta: ton kulit sederhana cerah dan ton kulit sederhana',
    '👨🏼‍🐰‍👨🏾' => 'lelaki berpesta: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👨🏼‍🐰‍👨🏿' => 'lelaki berpesta: ton kulit sederhana cerah dan ton kulit gelap',
    '👨🏽‍🐰‍👨🏻' => 'lelaki berpesta: ton kulit sederhana dan ton kulit cerah',
    '👨🏽‍🐰‍👨🏼' => 'lelaki berpesta: ton kulit sederhana dan ton kulit sederhana cerah',
    '👨🏽‍🐰‍👨🏾' => 'lelaki berpesta: ton kulit sederhana dan ton kulit sederhana gelap',
    '👨🏽‍🐰‍👨🏿' => 'lelaki berpesta: ton kulit sederhana dan ton kulit gelap',
    '👨🏾‍🐰‍👨🏻' => 'lelaki berpesta: ton kulit sederhana gelap dan ton kulit cerah',
    '👨🏾‍🐰‍👨🏼' => 'lelaki berpesta: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👨🏾‍🐰‍👨🏽' => 'lelaki berpesta: ton kulit sederhana gelap dan ton kulit sederhana',
    '👨🏾‍🐰‍👨🏿' => 'lelaki berpesta: ton kulit sederhana gelap dan ton kulit gelap',
    '👨🏿‍🐰‍👨🏻' => 'lelaki berpesta: ton kulit gelap dan ton kulit cerah',
    '👨🏿‍🐰‍👨🏼' => 'lelaki berpesta: ton kulit gelap dan ton kulit sederhana cerah',
    '👨🏿‍🐰‍👨🏽' => 'lelaki berpesta: ton kulit gelap dan ton kulit sederhana',
    '👨🏿‍🐰‍👨🏾' => 'lelaki berpesta: ton kulit gelap dan ton kulit sederhana gelap',
    '👩🏻‍🫯‍👩🏼' => 'wanita bergusti: ton kulit cerah dan ton kulit sederhana cerah',
    '👩🏻‍🫯‍👩🏽' => 'wanita bergusti: ton kulit cerah dan ton kulit sederhana',
    '👩🏻‍🫯‍👩🏾' => 'wanita bergusti: ton kulit cerah dan ton kulit sederhana gelap',
    '👩🏻‍🫯‍👩🏿' => 'wanita bergusti: ton kulit cerah dan ton kulit gelap',
    '👩🏼‍🫯‍👩🏻' => 'wanita bergusti: ton kulit sederhana cerah dan ton kulit cerah',
    '👩🏼‍🫯‍👩🏽' => 'wanita bergusti: ton kulit sederhana cerah dan ton kulit sederhana',
    '👩🏼‍🫯‍👩🏾' => 'wanita bergusti: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👩🏼‍🫯‍👩🏿' => 'wanita bergusti: ton kulit sederhana cerah dan ton kulit gelap',
    '👩🏽‍🫯‍👩🏻' => 'wanita bergusti: ton kulit sederhana dan ton kulit cerah',
    '👩🏽‍🫯‍👩🏼' => 'wanita bergusti: ton kulit sederhana dan ton kulit sederhana cerah',
    '👩🏽‍🫯‍👩🏾' => 'wanita bergusti: ton kulit sederhana dan ton kulit sederhana gelap',
    '👩🏽‍🫯‍👩🏿' => 'wanita bergusti: ton kulit sederhana dan ton kulit gelap',
    '👩🏾‍🫯‍👩🏻' => 'wanita bergusti: ton kulit sederhana gelap dan ton kulit cerah',
    '👩🏾‍🫯‍👩🏼' => 'wanita bergusti: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👩🏾‍🫯‍👩🏽' => 'wanita bergusti: ton kulit sederhana gelap dan ton kulit sederhana',
    '👩🏾‍🫯‍👩🏿' => 'wanita bergusti: ton kulit sederhana gelap dan ton kulit gelap',
    '👩🏿‍🫯‍👩🏻' => 'wanita bergusti: ton kulit gelap dan ton kulit cerah',
    '👩🏿‍🫯‍👩🏼' => 'wanita bergusti: ton kulit gelap dan ton kulit sederhana cerah',
    '👩🏿‍🫯‍👩🏽' => 'wanita bergusti: ton kulit gelap dan ton kulit sederhana',
    '👩🏿‍🫯‍👩🏾' => 'wanita bergusti: ton kulit gelap dan ton kulit sederhana gelap',
    '👩🏻‍❤‍👨🏻' => 'pasangan dengan simbol hati: perempuan, lelaki dan ton kulit cerah',
    '👩🏻‍❤‍👨🏼' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit cerah dan ton kulit sederhana cerah',
    '👩🏻‍❤‍👨🏽' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit cerah dan ton kulit sederhana',
    '👩🏻‍❤‍👨🏾' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit cerah dan ton kulit sederhana gelap',
    '👩🏻‍❤‍👨🏿' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit cerah dan ton kulit gelap',
    '👩🏼‍❤‍👨🏻' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana cerah dan ton kulit cerah',
    '👩🏼‍❤‍👨🏼' => 'pasangan dengan simbol hati: perempuan, lelaki dan ton kulit sederhana cerah',
    '👩🏼‍❤‍👨🏽' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana cerah dan ton kulit sederhana',
    '👩🏼‍❤‍👨🏾' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👩🏼‍❤‍👨🏿' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana cerah dan ton kulit gelap',
    '👩🏽‍❤‍👨🏻' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana dan ton kulit cerah',
    '👩🏽‍❤‍👨🏼' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana dan ton kulit sederhana cerah',
    '👩🏽‍❤‍👨🏽' => 'pasangan dengan simbol hati: perempuan, lelaki dan ton kulit sederhana',
    '👩🏽‍❤‍👨🏾' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana dan ton kulit sederhana gelap',
    '👩🏽‍❤‍👨🏿' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana dan ton kulit gelap',
    '👩🏾‍❤‍👨🏻' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana gelap dan ton kulit cerah',
    '👩🏾‍❤‍👨🏼' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👩🏾‍❤‍👨🏽' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana gelap dan ton kulit sederhana',
    '👩🏾‍❤‍👨🏾' => 'pasangan dengan simbol hati: perempuan, lelaki dan ton kulit sederhana gelap',
    '👩🏾‍❤‍👨🏿' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit sederhana gelap dan ton kulit gelap',
    '👩🏿‍❤‍👨🏻' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit gelap dan ton kulit cerah',
    '👩🏿‍❤‍👨🏼' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit gelap dan ton kulit sederhana cerah',
    '👩🏿‍❤‍👨🏽' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit gelap dan ton kulit sederhana',
    '👩🏿‍❤‍👨🏾' => 'pasangan dengan simbol hati: perempuan, lelaki, ton kulit gelap dan ton kulit sederhana gelap',
    '👩🏿‍❤‍👨🏿' => 'pasangan dengan simbol hati: perempuan, lelaki dan ton kulit gelap',
    '👩🏻‍❤‍👩🏻' => 'pasangan dengan simbol hati: perempuan, perempuan dan ton kulit cerah',
    '👩🏻‍❤‍👩🏼' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit cerah dan ton kulit sederhana cerah',
    '👩🏻‍❤‍👩🏽' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit cerah dan ton kulit sederhana',
    '👩🏻‍❤‍👩🏾' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit cerah dan ton kulit sederhana gelap',
    '👩🏻‍❤‍👩🏿' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit cerah dan ton kulit gelap',
    '👩🏼‍❤‍👩🏻' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana cerah dan ton kulit cerah',
    '👩🏼‍❤‍👩🏼' => 'pasangan dengan simbol hati: perempuan, perempuan dan ton kulit sederhana cerah',
    '👩🏼‍❤‍👩🏽' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana cerah dan ton kulit sederhana',
    '👩🏼‍❤‍👩🏾' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👩🏼‍❤‍👩🏿' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana cerah dan ton kulit gelap',
    '👩🏽‍❤‍👩🏻' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana dan ton kulit cerah',
    '👩🏽‍❤‍👩🏼' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana dan ton kulit sederhana cerah',
    '👩🏽‍❤‍👩🏽' => 'pasangan dengan simbol hati: perempuan, perempuan dan ton kulit sederhana',
    '👩🏽‍❤‍👩🏾' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana dan ton kulit sederhana gelap',
    '👩🏽‍❤‍👩🏿' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana dan ton kulit gelap',
    '👩🏾‍❤‍👩🏻' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana gelap dan ton kulit cerah',
    '👩🏾‍❤‍👩🏼' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👩🏾‍❤‍👩🏽' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana gelap dan ton kulit sederhana',
    '👩🏾‍❤‍👩🏾' => 'pasangan dengan simbol hati: perempuan, perempuan dan ton kulit sederhana gelap',
    '👩🏾‍❤‍👩🏿' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit sederhana gelap dan ton kulit gelap',
    '👩🏿‍❤‍👩🏻' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit gelap dan ton kulit cerah',
    '👩🏿‍❤‍👩🏼' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit gelap dan ton kulit sederhana cerah',
    '👩🏿‍❤‍👩🏽' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit gelap dan ton kulit sederhana',
    '👩🏿‍❤‍👩🏾' => 'pasangan dengan simbol hati: perempuan, perempuan, ton kulit gelap dan ton kulit sederhana gelap',
    '👩🏿‍❤‍👩🏿' => 'pasangan dengan simbol hati: perempuan, perempuan dan ton kulit gelap',
    '👩🏻‍🐰‍👩🏼' => 'perempuan berpesta: ton kulit cerah dan ton kulit sederhana cerah',
    '👩🏻‍🐰‍👩🏽' => 'perempuan berpesta: ton kulit cerah dan ton kulit sederhana',
    '👩🏻‍🐰‍👩🏾' => 'perempuan berpesta: ton kulit cerah dan ton kulit sederhana gelap',
    '👩🏻‍🐰‍👩🏿' => 'perempuan berpesta: ton kulit cerah dan ton kulit gelap',
    '👩🏼‍🐰‍👩🏻' => 'perempuan berpesta: ton kulit sederhana cerah dan ton kulit cerah',
    '👩🏼‍🐰‍👩🏽' => 'perempuan berpesta: ton kulit sederhana cerah dan ton kulit sederhana',
    '👩🏼‍🐰‍👩🏾' => 'perempuan berpesta: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👩🏼‍🐰‍👩🏿' => 'perempuan berpesta: ton kulit sederhana cerah dan ton kulit gelap',
    '👩🏽‍🐰‍👩🏻' => 'perempuan berpesta: ton kulit sederhana dan ton kulit cerah',
    '👩🏽‍🐰‍👩🏼' => 'perempuan berpesta: ton kulit sederhana dan ton kulit sederhana cerah',
    '👩🏽‍🐰‍👩🏾' => 'perempuan berpesta: ton kulit sederhana dan ton kulit sederhana gelap',
    '👩🏽‍🐰‍👩🏿' => 'perempuan berpesta: ton kulit sederhana dan ton kulit gelap',
    '👩🏾‍🐰‍👩🏻' => 'perempuan berpesta: ton kulit sederhana gelap dan ton kulit cerah',
    '👩🏾‍🐰‍👩🏼' => 'perempuan berpesta: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👩🏾‍🐰‍👩🏽' => 'perempuan berpesta: ton kulit sederhana gelap dan ton kulit sederhana',
    '👩🏾‍🐰‍👩🏿' => 'perempuan berpesta: ton kulit sederhana gelap dan ton kulit gelap',
    '👩🏿‍🐰‍👩🏻' => 'perempuan berpesta: ton kulit gelap dan ton kulit cerah',
    '👩🏿‍🐰‍👩🏼' => 'perempuan berpesta: ton kulit gelap dan ton kulit sederhana cerah',
    '👩🏿‍🐰‍👩🏽' => 'perempuan berpesta: ton kulit gelap dan ton kulit sederhana',
    '👩🏿‍🐰‍👩🏾' => 'perempuan berpesta: ton kulit gelap dan ton kulit sederhana gelap',
    '🧑🏻‍🤝‍🧑🏻' => 'orang berpegangan tangan: ton kulit cerah',
    '🧑🏻‍🤝‍🧑🏼' => 'orang berpegangan tangan: ton kulit cerah dan ton kulit sederhana cerah',
    '🧑🏻‍🤝‍🧑🏽' => 'orang berpegangan tangan: ton kulit cerah dan ton kulit sederhana',
    '🧑🏻‍🤝‍🧑🏾' => 'orang berpegangan tangan: ton kulit cerah dan ton kulit sederhana gelap',
    '🧑🏻‍🤝‍🧑🏿' => 'orang berpegangan tangan: ton kulit cerah dan ton kulit gelap',
    '🧑🏼‍🤝‍🧑🏻' => 'orang berpegangan tangan: ton kulit sederhana cerah dan ton kulit cerah',
    '🧑🏼‍🤝‍🧑🏼' => 'orang berpegangan tangan: ton kulit sederhana cerah',
    '🧑🏼‍🤝‍🧑🏽' => 'orang berpegangan tangan: ton kulit sederhana cerah dan ton kulit sederhana',
    '🧑🏼‍🤝‍🧑🏾' => 'orang berpegangan tangan: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '🧑🏼‍🤝‍🧑🏿' => 'orang berpegangan tangan: ton kulit sederhana cerah dan ton kulit gelap',
    '🧑🏽‍🤝‍🧑🏻' => 'orang berpegangan tangan: ton kulit sederhana dan ton kulit cerah',
    '🧑🏽‍🤝‍🧑🏼' => 'orang berpegangan tangan: ton kulit sederhana dan ton kulit sederhana cerah',
    '🧑🏽‍🤝‍🧑🏽' => 'orang berpegangan tangan: ton kulit sederhana',
    '🧑🏽‍🤝‍🧑🏾' => 'orang berpegangan tangan: ton kulit sederhana dan ton kulit sederhana gelap',
    '🧑🏽‍🤝‍🧑🏿' => 'orang berpegangan tangan: ton kulit sederhana dan ton kulit gelap',
    '🧑🏾‍🤝‍🧑🏻' => 'orang berpegangan tangan: ton kulit sederhana gelap dan ton kulit cerah',
    '🧑🏾‍🤝‍🧑🏼' => 'orang berpegangan tangan: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '🧑🏾‍🤝‍🧑🏽' => 'orang berpegangan tangan: ton kulit sederhana gelap dan ton kulit sederhana',
    '🧑🏾‍🤝‍🧑🏾' => 'orang berpegangan tangan: ton kulit sederhana gelap',
    '🧑🏾‍🤝‍🧑🏿' => 'orang berpegangan tangan: ton kulit sederhana gelap dan ton kulit gelap',
    '🧑🏿‍🤝‍🧑🏻' => 'orang berpegangan tangan: ton kulit gelap dan ton kulit cerah',
    '🧑🏿‍🤝‍🧑🏼' => 'orang berpegangan tangan: ton kulit gelap dan ton kulit sederhana cerah',
    '🧑🏿‍🤝‍🧑🏽' => 'orang berpegangan tangan: ton kulit gelap dan ton kulit sederhana',
    '🧑🏿‍🤝‍🧑🏾' => 'orang berpegangan tangan: ton kulit gelap dan ton kulit sederhana gelap',
    '🧑🏿‍🤝‍🧑🏿' => 'orang berpegangan tangan: ton kulit gelap',
    '👩🏻‍🤝‍👩🏼' => 'dua wanita berpegangan tangan: ton kulit cerah dan ton kulit sederhana cerah',
    '👩🏻‍🤝‍👩🏽' => 'dua wanita berpegangan tangan: ton kulit cerah dan ton kulit sederhana',
    '👩🏻‍🤝‍👩🏾' => 'dua wanita berpegangan tangan: ton kulit cerah dan ton kulit sederhana gelap',
    '👩🏻‍🤝‍👩🏿' => 'dua wanita berpegangan tangan: ton kulit cerah dan ton kulit gelap',
    '👩🏼‍🤝‍👩🏻' => 'dua wanita berpegangan tangan: ton kulit sederhana cerah dan ton kulit cerah',
    '👩🏼‍🤝‍👩🏽' => 'dua wanita berpegangan tangan: ton kulit sederhana cerah dan ton kulit sederhana',
    '👩🏼‍🤝‍👩🏾' => 'dua wanita berpegangan tangan: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👩🏼‍🤝‍👩🏿' => 'dua wanita berpegangan tangan: ton kulit sederhana cerah dan ton kulit gelap',
    '👩🏽‍🤝‍👩🏻' => 'dua wanita berpegangan tangan: ton kulit sederhana dan ton kulit cerah',
    '👩🏽‍🤝‍👩🏼' => 'dua wanita berpegangan tangan: ton kulit sederhana dan ton kulit sederhana cerah',
    '👩🏽‍🤝‍👩🏾' => 'dua wanita berpegangan tangan: ton kulit sederhana dan ton kulit sederhana gelap',
    '👩🏽‍🤝‍👩🏿' => 'dua wanita berpegangan tangan: ton kulit sederhana dan ton kulit gelap',
    '👩🏾‍🤝‍👩🏻' => 'dua wanita berpegangan tangan: ton kulit sederhana gelap dan ton kulit cerah',
    '👩🏾‍🤝‍👩🏼' => 'dua wanita berpegangan tangan: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👩🏾‍🤝‍👩🏽' => 'dua wanita berpegangan tangan: ton kulit sederhana gelap dan ton kulit sederhana',
    '👩🏾‍🤝‍👩🏿' => 'dua wanita berpegangan tangan: ton kulit sederhana gelap dan ton kulit gelap',
    '👩🏿‍🤝‍👩🏻' => 'dua wanita berpegangan tangan: ton kulit gelap dan ton kulit cerah',
    '👩🏿‍🤝‍👩🏼' => 'dua wanita berpegangan tangan: ton kulit gelap dan ton kulit sederhana cerah',
    '👩🏿‍🤝‍👩🏽' => 'dua wanita berpegangan tangan: ton kulit gelap dan ton kulit sederhana',
    '👩🏿‍🤝‍👩🏾' => 'dua wanita berpegangan tangan: ton kulit gelap dan ton kulit sederhana gelap',
    '👩🏻‍🤝‍👨🏼' => 'lelaki dan wanita berpegangan tangan: ton kulit cerah dan ton kulit sederhana cerah',
    '👩🏻‍🤝‍👨🏽' => 'lelaki dan wanita berpegangan tangan: ton kulit cerah dan ton kulit sederhana',
    '👩🏻‍🤝‍👨🏾' => 'lelaki dan wanita berpegangan tangan: ton kulit cerah dan ton kulit sederhana gelap',
    '👩🏻‍🤝‍👨🏿' => 'lelaki dan wanita berpegangan tangan: ton kulit cerah dan ton kulit gelap',
    '👩🏼‍🤝‍👨🏻' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana cerah dan ton kulit cerah',
    '👩🏼‍🤝‍👨🏽' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana cerah dan ton kulit sederhana',
    '👩🏼‍🤝‍👨🏾' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👩🏼‍🤝‍👨🏿' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana cerah dan ton kulit gelap',
    '👩🏽‍🤝‍👨🏻' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana dan ton kulit cerah',
    '👩🏽‍🤝‍👨🏼' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana dan ton kulit sederhana cerah',
    '👩🏽‍🤝‍👨🏾' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana dan ton kulit sederhana gelap',
    '👩🏽‍🤝‍👨🏿' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana dan ton kulit gelap',
    '👩🏾‍🤝‍👨🏻' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana gelap dan ton kulit cerah',
    '👩🏾‍🤝‍👨🏼' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👩🏾‍🤝‍👨🏽' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana gelap dan ton kulit sederhana',
    '👩🏾‍🤝‍👨🏿' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana gelap dan ton kulit gelap',
    '👩🏿‍🤝‍👨🏻' => 'lelaki dan wanita berpegangan tangan: ton kulit gelap dan ton kulit cerah',
    '👩🏿‍🤝‍👨🏼' => 'lelaki dan wanita berpegangan tangan: ton kulit gelap dan ton kulit sederhana cerah',
    '👩🏿‍🤝‍👨🏽' => 'lelaki dan wanita berpegangan tangan: ton kulit gelap dan ton kulit sederhana',
    '👩🏿‍🤝‍👨🏾' => 'lelaki dan wanita berpegangan tangan: ton kulit gelap dan ton kulit sederhana gelap',
    '👨🏻‍🤝‍👨🏼' => 'dua lelaki berpegangan tangan: ton kulit cerah dan ton kulit sederhana cerah',
    '👨🏻‍🤝‍👨🏽' => 'dua lelaki berpegangan tangan: ton kulit cerah dan ton kulit sederhana',
    '👨🏻‍🤝‍👨🏾' => 'dua lelaki berpegangan tangan: ton kulit cerah dan ton kulit sederhana gelap',
    '👨🏻‍🤝‍👨🏿' => 'dua lelaki berpegangan tangan: ton kulit cerah dan ton kulit gelap',
    '👨🏼‍🤝‍👨🏻' => 'dua lelaki berpegangan tangan: ton kulit sederhana cerah dan ton kulit cerah',
    '👨🏼‍🤝‍👨🏽' => 'dua lelaki berpegangan tangan: ton kulit sederhana cerah dan ton kulit sederhana',
    '👨🏼‍🤝‍👨🏾' => 'dua lelaki berpegangan tangan: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '👨🏼‍🤝‍👨🏿' => 'dua lelaki berpegangan tangan: ton kulit sederhana cerah dan ton kulit gelap',
    '👨🏽‍🤝‍👨🏻' => 'dua lelaki berpegangan tangan: ton kulit sederhana dan ton kulit cerah',
    '👨🏽‍🤝‍👨🏼' => 'dua lelaki berpegangan tangan: ton kulit sederhana dan ton kulit sederhana cerah',
    '👨🏽‍🤝‍👨🏾' => 'dua lelaki berpegangan tangan: ton kulit sederhana dan ton kulit sederhana gelap',
    '👨🏽‍🤝‍👨🏿' => 'dua lelaki berpegangan tangan: ton kulit sederhana dan ton kulit gelap',
    '👨🏾‍🤝‍👨🏻' => 'dua lelaki berpegangan tangan: ton kulit sederhana gelap dan ton kulit cerah',
    '👨🏾‍🤝‍👨🏼' => 'dua lelaki berpegangan tangan: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '👨🏾‍🤝‍👨🏽' => 'dua lelaki berpegangan tangan: ton kulit sederhana gelap dan ton kulit sederhana',
    '👨🏾‍🤝‍👨🏿' => 'dua lelaki berpegangan tangan: ton kulit sederhana gelap dan ton kulit gelap',
    '👨🏿‍🤝‍👨🏻' => 'dua lelaki berpegangan tangan: ton kulit gelap dan ton kulit cerah',
    '👨🏿‍🤝‍👨🏼' => 'dua lelaki berpegangan tangan: ton kulit gelap dan ton kulit sederhana cerah',
    '👨🏿‍🤝‍👨🏽' => 'dua lelaki berpegangan tangan: ton kulit gelap dan ton kulit sederhana',
    '👨🏿‍🤝‍👨🏾' => 'dua lelaki berpegangan tangan: ton kulit gelap dan ton kulit sederhana gelap',
    '👩‍❤‍💋‍👨' => 'cium: perempuan dan lelaki',
    '👨‍❤‍💋‍👨' => 'cium: lelaki dan lelaki',
    '👩‍❤‍💋‍👩' => 'cium: perempuan dan perempuan',
    '👨‍👩‍👧‍👦' => 'keluarga: lelaki, perempuan, budak perempuan dan kanak-kanak lelaki',
    '👨‍👩‍👦‍👦' => 'keluarga: lelaki, perempuan, kanak-kanak lelaki dan kanak-kanak lelaki',
    '👨‍👩‍👧‍👧' => 'keluarga: lelaki, perempuan, budak perempuan dan budak perempuan',
    '👨‍👨‍👧‍👦' => 'keluarga: lelaki, lelaki, budak perempuan dan kanak-kanak lelaki',
    '👨‍👨‍👦‍👦' => 'keluarga: lelaki, lelaki, kanak-kanak lelaki dan kanak-kanak lelaki',
    '👨‍👨‍👧‍👧' => 'keluarga: lelaki, lelaki, budak perempuan dan budak perempuan',
    '👩‍👩‍👧‍👦' => 'keluarga: perempuan, perempuan, budak perempuan dan kanak-kanak lelaki',
    '👩‍👩‍👦‍👦' => 'keluarga: perempuan, perempuan, kanak-kanak lelaki dan kanak-kanak lelaki',
    '👩‍👩‍👧‍👧' => 'keluarga: perempuan, perempuan, budak perempuan dan budak perempuan',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'bendera: England',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'bendera: Scotland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'bendera: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'keluarga: dewasa, dewasa, kanak-kanak, kanak-kanak',
    '🚶🏻‍♀‍➡' => 'perempuan berjalan: ton kulit cerah dan menghadap kanan',
    '🚶🏼‍♀‍➡' => 'perempuan berjalan: ton kulit sederhana cerah dan menghadap kanan',
    '🚶🏽‍♀‍➡' => 'perempuan berjalan: ton kulit sederhana dan menghadap kanan',
    '🚶🏾‍♀‍➡' => 'perempuan berjalan: ton kulit sederhana gelap dan menghadap kanan',
    '🚶🏿‍♀‍➡' => 'perempuan berjalan: ton kulit gelap dan menghadap kanan',
    '🚶🏻‍♂‍➡' => 'lelaki berjalan: ton kulit cerah dan menghadap kanan',
    '🚶🏼‍♂‍➡' => 'lelaki berjalan: ton kulit sederhana cerah dan menghadap kanan',
    '🚶🏽‍♂‍➡' => 'lelaki berjalan: ton kulit sederhana dan menghadap kanan',
    '🚶🏾‍♂‍➡' => 'lelaki berjalan: ton kulit sederhana gelap dan menghadap kanan',
    '🚶🏿‍♂‍➡' => 'lelaki berjalan: ton kulit gelap dan menghadap kanan',
    '🧎🏻‍♀‍➡' => 'perempuan bersimpuh: ton kulit cerah dan menghadap kanan',
    '🧎🏼‍♀‍➡' => 'perempuan bersimpuh: ton kulit sederhana cerah dan menghadap kanan',
    '🧎🏽‍♀‍➡' => 'perempuan bersimpuh: ton kulit sederhana dan menghadap kanan',
    '🧎🏾‍♀‍➡' => 'perempuan bersimpuh: ton kulit sederhana gelap dan menghadap kanan',
    '🧎🏿‍♀‍➡' => 'perempuan bersimpuh: ton kulit gelap dan menghadap kanan',
    '🧎🏻‍♂‍➡' => 'lelaki bersimpuh: ton kulit cerah dan menghadap kanan',
    '🧎🏼‍♂‍➡' => 'lelaki bersimpuh: ton kulit sederhana cerah dan menghadap kanan',
    '🧎🏽‍♂‍➡' => 'lelaki bersimpuh: ton kulit sederhana dan menghadap kanan',
    '🧎🏾‍♂‍➡' => 'lelaki bersimpuh: ton kulit sederhana gelap dan menghadap kanan',
    '🧎🏿‍♂‍➡' => 'lelaki bersimpuh: ton kulit gelap dan menghadap kanan',
    '🧑🏻‍🦯‍➡' => 'orang dengan tongkat putih: ton kulit cerah dan menghadap kanan',
    '🧑🏼‍🦯‍➡' => 'orang dengan tongkat putih: ton kulit sederhana cerah dan menghadap kanan',
    '🧑🏽‍🦯‍➡' => 'orang dengan tongkat putih: ton kulit sederhana dan menghadap kanan',
    '🧑🏾‍🦯‍➡' => 'orang dengan tongkat putih: ton kulit sederhana gelap dan menghadap kanan',
    '🧑🏿‍🦯‍➡' => 'orang dengan tongkat putih: ton kulit gelap dan menghadap kanan',
    '👨🏻‍🦯‍➡' => 'lelaki dengan tongkat putih: ton kulit cerah dan menghadap kanan',
    '👨🏼‍🦯‍➡' => 'lelaki dengan tongkat putih: ton kulit sederhana cerah dan menghadap kanan',
    '👨🏽‍🦯‍➡' => 'lelaki dengan tongkat putih: ton kulit sederhana dan menghadap kanan',
    '👨🏾‍🦯‍➡' => 'lelaki dengan tongkat putih: ton kulit sederhana gelap dan menghadap kanan',
    '👨🏿‍🦯‍➡' => 'lelaki dengan tongkat putih: ton kulit gelap dan menghadap kanan',
    '👩🏻‍🦯‍➡' => 'perempuan dengan tongkat putih: ton kulit cerah dan menghadap kanan',
    '👩🏼‍🦯‍➡' => 'perempuan dengan tongkat putih: ton kulit sederhana cerah dan menghadap kanan',
    '👩🏽‍🦯‍➡' => 'perempuan dengan tongkat putih: ton kulit sederhana dan menghadap kanan',
    '👩🏾‍🦯‍➡' => 'perempuan dengan tongkat putih: ton kulit sederhana gelap dan menghadap kanan',
    '👩🏿‍🦯‍➡' => 'perempuan dengan tongkat putih: ton kulit gelap dan menghadap kanan',
    '🧑🏻‍🦼‍➡' => 'orang dalam kerusi roda bermotor: ton kulit cerah dan menghadap kanan',
    '🧑🏼‍🦼‍➡' => 'orang dalam kerusi roda bermotor: ton kulit sederhana cerah dan menghadap kanan',
    '🧑🏽‍🦼‍➡' => 'orang dalam kerusi roda bermotor: ton kulit sederhana dan menghadap kanan',
    '🧑🏾‍🦼‍➡' => 'orang dalam kerusi roda bermotor: ton kulit sederhana gelap dan menghadap kanan',
    '🧑🏿‍🦼‍➡' => 'orang dalam kerusi roda bermotor: ton kulit gelap dan menghadap kanan',
    '👨🏻‍🦼‍➡' => 'lelaki dalam kerusi roda bermotor: ton kulit cerah dan menghadap kanan',
    '👨🏼‍🦼‍➡' => 'lelaki dalam kerusi roda bermotor: ton kulit sederhana cerah dan menghadap kanan',
    '👨🏽‍🦼‍➡' => 'lelaki dalam kerusi roda bermotor: ton kulit sederhana dan menghadap kanan',
    '👨🏾‍🦼‍➡' => 'lelaki dalam kerusi roda bermotor: ton kulit sederhana gelap dan menghadap kanan',
    '👨🏿‍🦼‍➡' => 'lelaki dalam kerusi roda bermotor: ton kulit gelap dan menghadap kanan',
    '👩🏻‍🦼‍➡' => 'perempuan dalam kerusi roda bermotor: ton kulit cerah dan menghadap kanan',
    '👩🏼‍🦼‍➡' => 'perempuan dalam kerusi roda bermotor: ton kulit sederhana cerah dan menghadap kanan',
    '👩🏽‍🦼‍➡' => 'perempuan dalam kerusi roda bermotor: ton kulit sederhana dan menghadap kanan',
    '👩🏾‍🦼‍➡' => 'perempuan dalam kerusi roda bermotor: ton kulit sederhana gelap dan menghadap kanan',
    '👩🏿‍🦼‍➡' => 'perempuan dalam kerusi roda bermotor: ton kulit gelap dan menghadap kanan',
    '🧑🏻‍🦽‍➡' => 'orang dalam kerusi roda manual: ton kulit cerah dan menghadap kanan',
    '🧑🏼‍🦽‍➡' => 'orang dalam kerusi roda manual: ton kulit sederhana cerah dan menghadap kanan',
    '🧑🏽‍🦽‍➡' => 'orang dalam kerusi roda manual: ton kulit sederhana dan menghadap kanan',
    '🧑🏾‍🦽‍➡' => 'orang dalam kerusi roda manual: ton kulit sederhana gelap dan menghadap kanan',
    '🧑🏿‍🦽‍➡' => 'orang dalam kerusi roda manual: ton kulit gelap dan menghadap kanan',
    '👨🏻‍🦽‍➡' => 'lelaki dalam kerusi roda manual: ton kulit cerah dan menghadap kanan',
    '👨🏼‍🦽‍➡' => 'lelaki dalam kerusi roda manual: ton kulit sederhana cerah dan menghadap kanan',
    '👨🏽‍🦽‍➡' => 'lelaki dalam kerusi roda manual: ton kulit sederhana dan menghadap kanan',
    '👨🏾‍🦽‍➡' => 'lelaki dalam kerusi roda manual: ton kulit sederhana gelap dan menghadap kanan',
    '👨🏿‍🦽‍➡' => 'lelaki dalam kerusi roda manual: ton kulit gelap dan menghadap kanan',
    '👩🏻‍🦽‍➡' => 'perempuan dalam kereta roda manual: ton kulit cerah dan menghadap kanan',
    '👩🏼‍🦽‍➡' => 'perempuan dalam kereta roda manual: ton kulit sederhana cerah dan menghadap kanan',
    '👩🏽‍🦽‍➡' => 'perempuan dalam kereta roda manual: ton kulit sederhana dan menghadap kanan',
    '👩🏾‍🦽‍➡' => 'perempuan dalam kereta roda manual: ton kulit sederhana gelap dan menghadap kanan',
    '👩🏿‍🦽‍➡' => 'perempuan dalam kereta roda manual: ton kulit gelap dan menghadap kanan',
    '🏃🏻‍♀‍➡' => 'perempuan berlari: ton kulit cerah dan menghadap kanan',
    '🏃🏼‍♀‍➡' => 'perempuan berlari: ton kulit sederhana cerah dan menghadap kanan',
    '🏃🏽‍♀‍➡' => 'perempuan berlari: ton kulit sederhana dan menghadap kanan',
    '🏃🏾‍♀‍➡' => 'perempuan berlari: ton kulit sederhana gelap dan menghadap kanan',
    '🏃🏿‍♀‍➡' => 'perempuan berlari: ton kulit gelap dan menghadap kanan',
    '🏃🏻‍♂‍➡' => 'lelaki berlari: ton kulit cerah dan menghadap kanan',
    '🏃🏼‍♂‍➡' => 'lelaki berlari: ton kulit sederhana cerah dan menghadap kanan',
    '🏃🏽‍♂‍➡' => 'lelaki berlari: ton kulit sederhana dan menghadap kanan',
    '🏃🏾‍♂‍➡' => 'lelaki berlari: ton kulit sederhana gelap dan menghadap kanan',
    '🏃🏿‍♂‍➡' => 'lelaki berlari: ton kulit gelap dan menghadap kanan',
    '🫱🏻‍🫲🏼' => 'berjabat tangan: ton kulit cerah dan ton kulit sederhana cerah',
    '🫱🏻‍🫲🏽' => 'berjabat tangan: ton kulit cerah dan ton kulit sederhana',
    '🫱🏻‍🫲🏾' => 'berjabat tangan: ton kulit cerah dan ton kulit sederhana gelap',
    '🫱🏻‍🫲🏿' => 'berjabat tangan: ton kulit cerah dan ton kulit gelap',
    '🫱🏼‍🫲🏻' => 'berjabat tangan: ton kulit sederhana cerah dan ton kulit cerah',
    '🫱🏼‍🫲🏽' => 'berjabat tangan: ton kulit sederhana cerah dan ton kulit sederhana',
    '🫱🏼‍🫲🏾' => 'berjabat tangan: ton kulit sederhana cerah dan ton kulit sederhana gelap',
    '🫱🏼‍🫲🏿' => 'berjabat tangan: ton kulit sederhana cerah dan ton kulit gelap',
    '🫱🏽‍🫲🏻' => 'berjabat tangan: ton kulit sederhana dan ton kulit cerah',
    '🫱🏽‍🫲🏼' => 'berjabat tangan: ton kulit sederhana dan ton kulit sederhana cerah',
    '🫱🏽‍🫲🏾' => 'berjabat tangan: ton kulit sederhana dan ton kulit sederhana gelap',
    '🫱🏽‍🫲🏿' => 'berjabat tangan: ton kulit sederhana dan ton kulit gelap',
    '🫱🏾‍🫲🏻' => 'berjabat tangan: ton kulit sederhana gelap dan ton kulit cerah',
    '🫱🏾‍🫲🏼' => 'berjabat tangan: ton kulit sederhana gelap dan ton kulit sederhana cerah',
    '🫱🏾‍🫲🏽' => 'berjabat tangan: ton kulit sederhana gelap dan ton kulit sederhana',
    '🫱🏾‍🫲🏿' => 'berjabat tangan: ton kulit sederhana gelap dan ton kulit gelap',
    '🫱🏿‍🫲🏻' => 'berjabat tangan: ton kulit gelap dan ton kulit cerah',
    '🫱🏿‍🫲🏼' => 'berjabat tangan: ton kulit gelap dan ton kulit sederhana cerah',
    '🫱🏿‍🫲🏽' => 'berjabat tangan: ton kulit gelap dan ton kulit sederhana',
    '🫱🏿‍🫲🏾' => 'berjabat tangan: ton kulit gelap dan ton kulit sederhana gelap',
    '🚶‍♀‍➡' => 'perempuan berjalan: menghadap kanan',
    '🚶‍♂‍➡' => 'lelaki berjalan: menghadap kanan',
    '🧎‍♀‍➡' => 'perempuan bersimpuh: menghadap kanan',
    '🧎‍♂‍➡' => 'lelaki bersimpuh: menghadap kanan',
    '🧑‍🦯‍➡' => 'orang dengan tongkat putih: menghadap kanan',
    '👨‍🦯‍➡' => 'lelaki dengan tongkat putih: menghadap kanan',
    '👩‍🦯‍➡' => 'perempuan dengan tongkat putih: menghadap kanan',
    '🧑‍🦼‍➡' => 'orang dalam kerusi roda bermotor: menghadap kanan',
    '👨‍🦼‍➡' => 'lelaki dalam kerusi roda bermotor: menghadap kanan',
    '👩‍🦼‍➡' => 'perempuan dalam kerusi roda bermotor: menghadap kanan',
    '🧑‍🦽‍➡' => 'orang dalam kerusi roda manual: menghadap kanan',
    '👨‍🦽‍➡' => 'lelaki dalam kerusi roda manual: menghadap kanan',
    '👩‍🦽‍➡' => 'perempuan dalam kereta roda manual: menghadap kanan',
    '🏃‍♀‍➡' => 'perempuan berlari: menghadap kanan',
    '🏃‍♂‍➡' => 'lelaki berlari: menghadap kanan',
    '👩‍❤‍👨' => 'pasangan dengan simbol hati: perempuan dan lelaki',
    '👨‍❤‍👨' => 'pasangan dengan simbol hati: lelaki dan lelaki',
    '👩‍❤‍👩' => 'pasangan dengan simbol hati: perempuan dan perempuan',
    '👨‍👩‍👦' => 'keluarga: lelaki, perempuan dan kanak-kanak lelaki',
    '👨‍👩‍👧' => 'keluarga: lelaki, perempuan dan budak perempuan',
    '👨‍👨‍👦' => 'keluarga: lelaki, lelaki dan kanak-kanak lelaki',
    '👨‍👨‍👧' => 'keluarga: lelaki, lelaki dan budak perempuan',
    '👩‍👩‍👦' => 'keluarga: perempuan, perempuan dan kanak-kanak lelaki',
    '👩‍👩‍👧' => 'keluarga: perempuan, perempuan dan budak perempuan',
    '👨‍👦‍👦' => 'keluarga: lelaki, kanak-kanak lelaki dan kanak-kanak lelaki',
    '👨‍👧‍👦' => 'keluarga: lelaki, budak perempuan dan kanak-kanak lelaki',
    '👨‍👧‍👧' => 'keluarga: lelaki, budak perempuan dan budak perempuan',
    '👩‍👦‍👦' => 'keluarga: perempuan, kanak-kanak lelaki dan kanak-kanak lelaki',
    '👩‍👧‍👦' => 'keluarga: perempuan, budak perempuan dan kanak-kanak lelaki',
    '👩‍👧‍👧' => 'keluarga: perempuan, budak perempuan dan budak perempuan',
    '🧑‍🤝‍🧑' => 'orang berpegangan tangan',
    '🧑‍🧑‍🧒' => 'keluarga: dewasa, dewasa, kanak-kanak',
    '🧑‍🧒‍🧒' => 'keluarga: dewasa, kanak-kanak, kanak-kanak',
    '🧑🏻‍🦰' => 'dewasa: ton kulit cerah dan rambut merah',
    '🧑🏼‍🦰' => 'dewasa: ton kulit sederhana cerah dan rambut merah',
    '🧑🏽‍🦰' => 'dewasa: ton kulit sederhana dan rambut merah',
    '🧑🏾‍🦰' => 'dewasa: ton kulit sederhana gelap dan rambut merah',
    '🧑🏿‍🦰' => 'dewasa: ton kulit gelap dan rambut merah',
    '🧑🏻‍🦱' => 'dewasa: ton kulit cerah dan rambut kerinting',
    '🧑🏼‍🦱' => 'dewasa: ton kulit sederhana cerah dan rambut kerinting',
    '🧑🏽‍🦱' => 'dewasa: ton kulit sederhana dan rambut kerinting',
    '🧑🏾‍🦱' => 'dewasa: ton kulit sederhana gelap dan rambut kerinting',
    '🧑🏿‍🦱' => 'dewasa: ton kulit gelap dan rambut kerinting',
    '🧑🏻‍🦳' => 'dewasa: ton kulit cerah dan rambut putih',
    '🧑🏼‍🦳' => 'dewasa: ton kulit sederhana cerah dan rambut putih',
    '🧑🏽‍🦳' => 'dewasa: ton kulit sederhana dan rambut putih',
    '🧑🏾‍🦳' => 'dewasa: ton kulit sederhana gelap dan rambut putih',
    '🧑🏿‍🦳' => 'dewasa: ton kulit gelap dan rambut putih',
    '🧑🏻‍🦲' => 'dewasa: ton kulit cerah dan botak',
    '🧑🏼‍🦲' => 'dewasa: ton kulit sederhana cerah dan botak',
    '🧑🏽‍🦲' => 'dewasa: ton kulit sederhana dan botak',
    '🧑🏾‍🦲' => 'dewasa: ton kulit sederhana gelap dan botak',
    '🧑🏿‍🦲' => 'dewasa: ton kulit gelap dan botak',
    '🧑🏻‍🩰' => 'penari balet: ton kulit cerah',
    '🧑🏼‍🩰' => 'penari balet: ton kulit sederhana cerah',
    '🧑🏽‍🩰' => 'penari balet: ton kulit sederhana',
    '🧑🏾‍🩰' => 'penari balet: ton kulit sederhana gelap',
    '🧑🏿‍🩰' => 'penari balet: ton kulit gelap',
    '🧔🏻‍♂' => 'lelaki: ton kulit cerah dan janggut',
    '🧔🏼‍♂' => 'lelaki: ton kulit sederhana cerah dan janggut',
    '🧔🏽‍♂' => 'lelaki: ton kulit sederhana dan janggut',
    '🧔🏾‍♂' => 'lelaki: ton kulit sederhana gelap dan janggut',
    '🧔🏿‍♂' => 'lelaki: ton kulit gelap dan janggut',
    '👱🏻‍♂' => 'lelaki: ton kulit cerah dan rambut perang',
    '👱🏼‍♂' => 'lelaki: ton kulit sederhana cerah dan rambut perang',
    '👱🏽‍♂' => 'lelaki: ton kulit sederhana dan rambut perang',
    '👱🏾‍♂' => 'lelaki: ton kulit sederhana gelap dan rambut perang',
    '👱🏿‍♂' => 'lelaki: ton kulit gelap dan rambut perang',
    '👨🏻‍🦰' => 'lelaki: ton kulit cerah dan rambut merah',
    '👨🏼‍🦰' => 'lelaki: ton kulit sederhana cerah dan rambut merah',
    '👨🏽‍🦰' => 'lelaki: ton kulit sederhana dan rambut merah',
    '👨🏾‍🦰' => 'lelaki: ton kulit sederhana gelap dan rambut merah',
    '👨🏿‍🦰' => 'lelaki: ton kulit gelap dan rambut merah',
    '👨🏻‍🦱' => 'lelaki: ton kulit cerah dan rambut kerinting',
    '👨🏼‍🦱' => 'lelaki: ton kulit sederhana cerah dan rambut kerinting',
    '👨🏽‍🦱' => 'lelaki: ton kulit sederhana dan rambut kerinting',
    '👨🏾‍🦱' => 'lelaki: ton kulit sederhana gelap dan rambut kerinting',
    '👨🏿‍🦱' => 'lelaki: ton kulit gelap dan rambut kerinting',
    '👨🏻‍🦳' => 'lelaki: ton kulit cerah dan rambut putih',
    '👨🏼‍🦳' => 'lelaki: ton kulit sederhana cerah dan rambut putih',
    '👨🏽‍🦳' => 'lelaki: ton kulit sederhana dan rambut putih',
    '👨🏾‍🦳' => 'lelaki: ton kulit sederhana gelap dan rambut putih',
    '👨🏿‍🦳' => 'lelaki: ton kulit gelap dan rambut putih',
    '👨🏻‍🦲' => 'lelaki: ton kulit cerah dan botak',
    '👨🏼‍🦲' => 'lelaki: ton kulit sederhana cerah dan botak',
    '👨🏽‍🦲' => 'lelaki: ton kulit sederhana dan botak',
    '👨🏾‍🦲' => 'lelaki: ton kulit sederhana gelap dan botak',
    '👨🏿‍🦲' => 'lelaki: ton kulit gelap dan botak',
    '🧔🏻‍♀' => 'wanita: ton kulit cerah dan janggut',
    '🧔🏼‍♀' => 'wanita: ton kulit sederhana cerah dan janggut',
    '🧔🏽‍♀' => 'wanita: ton kulit sederhana dan janggut',
    '🧔🏾‍♀' => 'wanita: ton kulit sederhana gelap dan janggut',
    '🧔🏿‍♀' => 'wanita: ton kulit gelap dan janggut',
    '👱🏻‍♀' => 'perempuan: ton kulit cerah dan rambut perang',
    '👱🏼‍♀' => 'perempuan: ton kulit sederhana cerah dan rambut perang',
    '👱🏽‍♀' => 'perempuan: ton kulit sederhana dan rambut perang',
    '👱🏾‍♀' => 'perempuan: ton kulit sederhana gelap dan rambut perang',
    '👱🏿‍♀' => 'perempuan: ton kulit gelap dan rambut perang',
    '👩🏻‍🦰' => 'perempuan: ton kulit cerah dan rambut merah',
    '👩🏼‍🦰' => 'perempuan: ton kulit sederhana cerah dan rambut merah',
    '👩🏽‍🦰' => 'perempuan: ton kulit sederhana dan rambut merah',
    '👩🏾‍🦰' => 'perempuan: ton kulit sederhana gelap dan rambut merah',
    '👩🏿‍🦰' => 'perempuan: ton kulit gelap dan rambut merah',
    '👩🏻‍🦱' => 'perempuan: ton kulit cerah dan rambut kerinting',
    '👩🏼‍🦱' => 'perempuan: ton kulit sederhana cerah dan rambut kerinting',
    '👩🏽‍🦱' => 'perempuan: ton kulit sederhana dan rambut kerinting',
    '👩🏾‍🦱' => 'perempuan: ton kulit sederhana gelap dan rambut kerinting',
    '👩🏿‍🦱' => 'perempuan: ton kulit gelap dan rambut kerinting',
    '👩🏻‍🦳' => 'perempuan: ton kulit cerah dan rambut putih',
    '👩🏼‍🦳' => 'perempuan: ton kulit sederhana cerah dan rambut putih',
    '👩🏽‍🦳' => 'perempuan: ton kulit sederhana dan rambut putih',
    '👩🏾‍🦳' => 'perempuan: ton kulit sederhana gelap dan rambut putih',
    '👩🏿‍🦳' => 'perempuan: ton kulit gelap dan rambut putih',
    '👩🏻‍🦲' => 'perempuan: ton kulit cerah dan botak',
    '👩🏼‍🦲' => 'perempuan: ton kulit sederhana cerah dan botak',
    '👩🏽‍🦲' => 'perempuan: ton kulit sederhana dan botak',
    '👩🏾‍🦲' => 'perempuan: ton kulit sederhana gelap dan botak',
    '👩🏿‍🦲' => 'perempuan: ton kulit gelap dan botak',
    '🙍🏻‍♂' => 'lelaki berkerut dahi: ton kulit cerah',
    '🙍🏼‍♂' => 'lelaki berkerut dahi: ton kulit sederhana cerah',
    '🙍🏽‍♂' => 'lelaki berkerut dahi: ton kulit sederhana',
    '🙍🏾‍♂' => 'lelaki berkerut dahi: ton kulit sederhana gelap',
    '🙍🏿‍♂' => 'lelaki berkerut dahi: ton kulit gelap',
    '🙍🏻‍♀' => 'perempuan berkerut dahi: ton kulit cerah',
    '🙍🏼‍♀' => 'perempuan berkerut dahi: ton kulit sederhana cerah',
    '🙍🏽‍♀' => 'perempuan berkerut dahi: ton kulit sederhana',
    '🙍🏾‍♀' => 'perempuan berkerut dahi: ton kulit sederhana gelap',
    '🙍🏿‍♀' => 'perempuan berkerut dahi: ton kulit gelap',
    '🙎🏻‍♂' => 'lelaki mencebik: ton kulit cerah',
    '🙎🏼‍♂' => 'lelaki mencebik: ton kulit sederhana cerah',
    '🙎🏽‍♂' => 'lelaki mencebik: ton kulit sederhana',
    '🙎🏾‍♂' => 'lelaki mencebik: ton kulit sederhana gelap',
    '🙎🏿‍♂' => 'lelaki mencebik: ton kulit gelap',
    '🙎🏻‍♀' => 'perempuan mencebik: ton kulit cerah',
    '🙎🏼‍♀' => 'perempuan mencebik: ton kulit sederhana cerah',
    '🙎🏽‍♀' => 'perempuan mencebik: ton kulit sederhana',
    '🙎🏾‍♀' => 'perempuan mencebik: ton kulit sederhana gelap',
    '🙎🏿‍♀' => 'perempuan mencebik: ton kulit gelap',
    '🙅🏻‍♂' => 'lelaki memberi isyarat tidak ok: ton kulit cerah',
    '🙅🏼‍♂' => 'lelaki memberi isyarat tidak ok: ton kulit sederhana cerah',
    '🙅🏽‍♂' => 'lelaki memberi isyarat tidak ok: ton kulit sederhana',
    '🙅🏾‍♂' => 'lelaki memberi isyarat tidak ok: ton kulit sederhana gelap',
    '🙅🏿‍♂' => 'lelaki memberi isyarat tidak ok: ton kulit gelap',
    '🙅🏻‍♀' => 'perempuan memberi isyarat tidak ok: ton kulit cerah',
    '🙅🏼‍♀' => 'perempuan memberi isyarat tidak ok: ton kulit sederhana cerah',
    '🙅🏽‍♀' => 'perempuan memberi isyarat tidak ok: ton kulit sederhana',
    '🙅🏾‍♀' => 'perempuan memberi isyarat tidak ok: ton kulit sederhana gelap',
    '🙅🏿‍♀' => 'perempuan memberi isyarat tidak ok: ton kulit gelap',
    '🙆🏻‍♂' => 'lelaki memberi isyarat ok: ton kulit cerah',
    '🙆🏼‍♂' => 'lelaki memberi isyarat ok: ton kulit sederhana cerah',
    '🙆🏽‍♂' => 'lelaki memberi isyarat ok: ton kulit sederhana',
    '🙆🏾‍♂' => 'lelaki memberi isyarat ok: ton kulit sederhana gelap',
    '🙆🏿‍♂' => 'lelaki memberi isyarat ok: ton kulit gelap',
    '🙆🏻‍♀' => 'perempuan memberi isyarat ok: ton kulit cerah',
    '🙆🏼‍♀' => 'perempuan memberi isyarat ok: ton kulit sederhana cerah',
    '🙆🏽‍♀' => 'perempuan memberi isyarat ok: ton kulit sederhana',
    '🙆🏾‍♀' => 'perempuan memberi isyarat ok: ton kulit sederhana gelap',
    '🙆🏿‍♀' => 'perempuan memberi isyarat ok: ton kulit gelap',
    '💁🏻‍♂' => 'lelaki menadah tangan: ton kulit cerah',
    '💁🏼‍♂' => 'lelaki menadah tangan: ton kulit sederhana cerah',
    '💁🏽‍♂' => 'lelaki menadah tangan: ton kulit sederhana',
    '💁🏾‍♂' => 'lelaki menadah tangan: ton kulit sederhana gelap',
    '💁🏿‍♂' => 'lelaki menadah tangan: ton kulit gelap',
    '💁🏻‍♀' => 'perempuan menadah tangan: ton kulit cerah',
    '💁🏼‍♀' => 'perempuan menadah tangan: ton kulit sederhana cerah',
    '💁🏽‍♀' => 'perempuan menadah tangan: ton kulit sederhana',
    '💁🏾‍♀' => 'perempuan menadah tangan: ton kulit sederhana gelap',
    '💁🏿‍♀' => 'perempuan menadah tangan: ton kulit gelap',
    '🙋🏻‍♂' => 'lelaki mengangkat tangan: ton kulit cerah',
    '🙋🏼‍♂' => 'lelaki mengangkat tangan: ton kulit sederhana cerah',
    '🙋🏽‍♂' => 'lelaki mengangkat tangan: ton kulit sederhana',
    '🙋🏾‍♂' => 'lelaki mengangkat tangan: ton kulit sederhana gelap',
    '🙋🏿‍♂' => 'lelaki mengangkat tangan: ton kulit gelap',
    '🙋🏻‍♀' => 'perempuan mengangkat tangan: ton kulit cerah',
    '🙋🏼‍♀' => 'perempuan mengangkat tangan: ton kulit sederhana cerah',
    '🙋🏽‍♀' => 'perempuan mengangkat tangan: ton kulit sederhana',
    '🙋🏾‍♀' => 'perempuan mengangkat tangan: ton kulit sederhana gelap',
    '🙋🏿‍♀' => 'perempuan mengangkat tangan: ton kulit gelap',
    '🧏🏻‍♂' => 'lelaki pekak: ton kulit cerah',
    '🧏🏼‍♂' => 'lelaki pekak: ton kulit sederhana cerah',
    '🧏🏽‍♂' => 'lelaki pekak: ton kulit sederhana',
    '🧏🏾‍♂' => 'lelaki pekak: ton kulit sederhana gelap',
    '🧏🏿‍♂' => 'lelaki pekak: ton kulit gelap',
    '🧏🏻‍♀' => 'perempuan pekak: ton kulit cerah',
    '🧏🏼‍♀' => 'perempuan pekak: ton kulit sederhana cerah',
    '🧏🏽‍♀' => 'perempuan pekak: ton kulit sederhana',
    '🧏🏾‍♀' => 'perempuan pekak: ton kulit sederhana gelap',
    '🧏🏿‍♀' => 'perempuan pekak: ton kulit gelap',
    '🙇🏻‍♂' => 'lelaki menunduk: ton kulit cerah',
    '🙇🏼‍♂' => 'lelaki menunduk: ton kulit sederhana cerah',
    '🙇🏽‍♂' => 'lelaki menunduk: ton kulit sederhana',
    '🙇🏾‍♂' => 'lelaki menunduk: ton kulit sederhana gelap',
    '🙇🏿‍♂' => 'lelaki menunduk: ton kulit gelap',
    '🙇🏻‍♀' => 'perempuan menunduk: ton kulit cerah',
    '🙇🏼‍♀' => 'perempuan menunduk: ton kulit sederhana cerah',
    '🙇🏽‍♀' => 'perempuan menunduk: ton kulit sederhana',
    '🙇🏾‍♀' => 'perempuan menunduk: ton kulit sederhana gelap',
    '🙇🏿‍♀' => 'perempuan menunduk: ton kulit gelap',
    '🤦🏻‍♂' => 'lelaki menepuk muka: ton kulit cerah',
    '🤦🏼‍♂' => 'lelaki menepuk muka: ton kulit sederhana cerah',
    '🤦🏽‍♂' => 'lelaki menepuk muka: ton kulit sederhana',
    '🤦🏾‍♂' => 'lelaki menepuk muka: ton kulit sederhana gelap',
    '🤦🏿‍♂' => 'lelaki menepuk muka: ton kulit gelap',
    '🤦🏻‍♀' => 'perempuan menepuk muka: ton kulit cerah',
    '🤦🏼‍♀' => 'perempuan menepuk muka: ton kulit sederhana cerah',
    '🤦🏽‍♀' => 'perempuan menepuk muka: ton kulit sederhana',
    '🤦🏾‍♀' => 'perempuan menepuk muka: ton kulit sederhana gelap',
    '🤦🏿‍♀' => 'perempuan menepuk muka: ton kulit gelap',
    '🤷🏻‍♂' => 'lelaki mengangkat bahu: ton kulit cerah',
    '🤷🏼‍♂' => 'lelaki mengangkat bahu: ton kulit sederhana cerah',
    '🤷🏽‍♂' => 'lelaki mengangkat bahu: ton kulit sederhana',
    '🤷🏾‍♂' => 'lelaki mengangkat bahu: ton kulit sederhana gelap',
    '🤷🏿‍♂' => 'lelaki mengangkat bahu: ton kulit gelap',
    '🤷🏻‍♀' => 'perempuan mengangkat bahu: ton kulit cerah',
    '🤷🏼‍♀' => 'perempuan mengangkat bahu: ton kulit sederhana cerah',
    '🤷🏽‍♀' => 'perempuan mengangkat bahu: ton kulit sederhana',
    '🤷🏾‍♀' => 'perempuan mengangkat bahu: ton kulit sederhana gelap',
    '🤷🏿‍♀' => 'perempuan mengangkat bahu: ton kulit gelap',
    '🧑🏻‍⚕' => 'pekerja kesihatan: ton kulit cerah',
    '🧑🏼‍⚕' => 'pekerja kesihatan: ton kulit sederhana cerah',
    '🧑🏽‍⚕' => 'pekerja kesihatan: ton kulit sederhana',
    '🧑🏾‍⚕' => 'pekerja kesihatan: ton kulit sederhana gelap',
    '🧑🏿‍⚕' => 'pekerja kesihatan: ton kulit gelap',
    '👨🏻‍⚕' => 'pekerja kesihatan lelaki: ton kulit cerah',
    '👨🏼‍⚕' => 'pekerja kesihatan lelaki: ton kulit sederhana cerah',
    '👨🏽‍⚕' => 'pekerja kesihatan lelaki: ton kulit sederhana',
    '👨🏾‍⚕' => 'pekerja kesihatan lelaki: ton kulit sederhana gelap',
    '👨🏿‍⚕' => 'pekerja kesihatan lelaki: ton kulit gelap',
    '👩🏻‍⚕' => 'pekerja kesihatan wanita: ton kulit cerah',
    '👩🏼‍⚕' => 'pekerja kesihatan wanita: ton kulit sederhana cerah',
    '👩🏽‍⚕' => 'pekerja kesihatan wanita: ton kulit sederhana',
    '👩🏾‍⚕' => 'pekerja kesihatan wanita: ton kulit sederhana gelap',
    '👩🏿‍⚕' => 'pekerja kesihatan wanita: ton kulit gelap',
    '🧑🏻‍🎓' => 'pelajar: ton kulit cerah',
    '🧑🏼‍🎓' => 'pelajar: ton kulit sederhana cerah',
    '🧑🏽‍🎓' => 'pelajar: ton kulit sederhana',
    '🧑🏾‍🎓' => 'pelajar: ton kulit sederhana gelap',
    '🧑🏿‍🎓' => 'pelajar: ton kulit gelap',
    '👨🏻‍🎓' => 'pelajar lelaki: ton kulit cerah',
    '👨🏼‍🎓' => 'pelajar lelaki: ton kulit sederhana cerah',
    '👨🏽‍🎓' => 'pelajar lelaki: ton kulit sederhana',
    '👨🏾‍🎓' => 'pelajar lelaki: ton kulit sederhana gelap',
    '👨🏿‍🎓' => 'pelajar lelaki: ton kulit gelap',
    '👩🏻‍🎓' => 'pelajar wanita: ton kulit cerah',
    '👩🏼‍🎓' => 'pelajar wanita: ton kulit sederhana cerah',
    '👩🏽‍🎓' => 'pelajar wanita: ton kulit sederhana',
    '👩🏾‍🎓' => 'pelajar wanita: ton kulit sederhana gelap',
    '👩🏿‍🎓' => 'pelajar wanita: ton kulit gelap',
    '🧑🏻‍🏫' => 'guru: ton kulit cerah',
    '🧑🏼‍🏫' => 'guru: ton kulit sederhana cerah',
    '🧑🏽‍🏫' => 'guru: ton kulit sederhana',
    '🧑🏾‍🏫' => 'guru: ton kulit sederhana gelap',
    '🧑🏿‍🏫' => 'guru: ton kulit gelap',
    '👨🏻‍🏫' => 'guru lelaki: ton kulit cerah',
    '👨🏼‍🏫' => 'guru lelaki: ton kulit sederhana cerah',
    '👨🏽‍🏫' => 'guru lelaki: ton kulit sederhana',
    '👨🏾‍🏫' => 'guru lelaki: ton kulit sederhana gelap',
    '👨🏿‍🏫' => 'guru lelaki: ton kulit gelap',
    '👩🏻‍🏫' => 'guru wanita: ton kulit cerah',
    '👩🏼‍🏫' => 'guru wanita: ton kulit sederhana cerah',
    '👩🏽‍🏫' => 'guru wanita: ton kulit sederhana',
    '👩🏾‍🏫' => 'guru wanita: ton kulit sederhana gelap',
    '👩🏿‍🏫' => 'guru wanita: ton kulit gelap',
    '🧑🏻‍⚖' => 'hakim: ton kulit cerah',
    '🧑🏼‍⚖' => 'hakim: ton kulit sederhana cerah',
    '🧑🏽‍⚖' => 'hakim: ton kulit sederhana',
    '🧑🏾‍⚖' => 'hakim: ton kulit sederhana gelap',
    '🧑🏿‍⚖' => 'hakim: ton kulit gelap',
    '👨🏻‍⚖' => 'hakim lelaki: ton kulit cerah',
    '👨🏼‍⚖' => 'hakim lelaki: ton kulit sederhana cerah',
    '👨🏽‍⚖' => 'hakim lelaki: ton kulit sederhana',
    '👨🏾‍⚖' => 'hakim lelaki: ton kulit sederhana gelap',
    '👨🏿‍⚖' => 'hakim lelaki: ton kulit gelap',
    '👩🏻‍⚖' => 'hakim wanita: ton kulit cerah',
    '👩🏼‍⚖' => 'hakim wanita: ton kulit sederhana cerah',
    '👩🏽‍⚖' => 'hakim wanita: ton kulit sederhana',
    '👩🏾‍⚖' => 'hakim wanita: ton kulit sederhana gelap',
    '👩🏿‍⚖' => 'hakim wanita: ton kulit gelap',
    '🧑🏻‍🌾' => 'petani: ton kulit cerah',
    '🧑🏼‍🌾' => 'petani: ton kulit sederhana cerah',
    '🧑🏽‍🌾' => 'petani: ton kulit sederhana',
    '🧑🏾‍🌾' => 'petani: ton kulit sederhana gelap',
    '🧑🏿‍🌾' => 'petani: ton kulit gelap',
    '👨🏻‍🌾' => 'petani lelaki: ton kulit cerah',
    '👨🏼‍🌾' => 'petani lelaki: ton kulit sederhana cerah',
    '👨🏽‍🌾' => 'petani lelaki: ton kulit sederhana',
    '👨🏾‍🌾' => 'petani lelaki: ton kulit sederhana gelap',
    '👨🏿‍🌾' => 'petani lelaki: ton kulit gelap',
    '👩🏻‍🌾' => 'petani wanita: ton kulit cerah',
    '👩🏼‍🌾' => 'petani wanita: ton kulit sederhana cerah',
    '👩🏽‍🌾' => 'petani wanita: ton kulit sederhana',
    '👩🏾‍🌾' => 'petani wanita: ton kulit sederhana gelap',
    '👩🏿‍🌾' => 'petani wanita: ton kulit gelap',
    '🧑🏻‍🍳' => 'tukang masak: ton kulit cerah',
    '🧑🏼‍🍳' => 'tukang masak: ton kulit sederhana cerah',
    '🧑🏽‍🍳' => 'tukang masak: ton kulit sederhana',
    '🧑🏾‍🍳' => 'tukang masak: ton kulit sederhana gelap',
    '🧑🏿‍🍳' => 'tukang masak: ton kulit gelap',
    '👨🏻‍🍳' => 'tukang masak lelaki: ton kulit cerah',
    '👨🏼‍🍳' => 'tukang masak lelaki: ton kulit sederhana cerah',
    '👨🏽‍🍳' => 'tukang masak lelaki: ton kulit sederhana',
    '👨🏾‍🍳' => 'tukang masak lelaki: ton kulit sederhana gelap',
    '👨🏿‍🍳' => 'tukang masak lelaki: ton kulit gelap',
    '👩🏻‍🍳' => 'tukang masak wanita: ton kulit cerah',
    '👩🏼‍🍳' => 'tukang masak wanita: ton kulit sederhana cerah',
    '👩🏽‍🍳' => 'tukang masak wanita: ton kulit sederhana',
    '👩🏾‍🍳' => 'tukang masak wanita: ton kulit sederhana gelap',
    '👩🏿‍🍳' => 'tukang masak wanita: ton kulit gelap',
    '🧑🏻‍🔧' => 'mekanik: ton kulit cerah',
    '🧑🏼‍🔧' => 'mekanik: ton kulit sederhana cerah',
    '🧑🏽‍🔧' => 'mekanik: ton kulit sederhana',
    '🧑🏾‍🔧' => 'mekanik: ton kulit sederhana gelap',
    '🧑🏿‍🔧' => 'mekanik: ton kulit gelap',
    '👨🏻‍🔧' => 'mekanik lelaki: ton kulit cerah',
    '👨🏼‍🔧' => 'mekanik lelaki: ton kulit sederhana cerah',
    '👨🏽‍🔧' => 'mekanik lelaki: ton kulit sederhana',
    '👨🏾‍🔧' => 'mekanik lelaki: ton kulit sederhana gelap',
    '👨🏿‍🔧' => 'mekanik lelaki: ton kulit gelap',
    '👩🏻‍🔧' => 'mekanik wanita: ton kulit cerah',
    '👩🏼‍🔧' => 'mekanik wanita: ton kulit sederhana cerah',
    '👩🏽‍🔧' => 'mekanik wanita: ton kulit sederhana',
    '👩🏾‍🔧' => 'mekanik wanita: ton kulit sederhana gelap',
    '👩🏿‍🔧' => 'mekanik wanita: ton kulit gelap',
    '🧑🏻‍🏭' => 'pekerja kilang: ton kulit cerah',
    '🧑🏼‍🏭' => 'pekerja kilang: ton kulit sederhana cerah',
    '🧑🏽‍🏭' => 'pekerja kilang: ton kulit sederhana',
    '🧑🏾‍🏭' => 'pekerja kilang: ton kulit sederhana gelap',
    '🧑🏿‍🏭' => 'pekerja kilang: ton kulit gelap',
    '👨🏻‍🏭' => 'pekerja kilang lelaki: ton kulit cerah',
    '👨🏼‍🏭' => 'pekerja kilang lelaki: ton kulit sederhana cerah',
    '👨🏽‍🏭' => 'pekerja kilang lelaki: ton kulit sederhana',
    '👨🏾‍🏭' => 'pekerja kilang lelaki: ton kulit sederhana gelap',
    '👨🏿‍🏭' => 'pekerja kilang lelaki: ton kulit gelap',
    '👩🏻‍🏭' => 'pekerja kilang wanita: ton kulit cerah',
    '👩🏼‍🏭' => 'pekerja kilang wanita: ton kulit sederhana cerah',
    '👩🏽‍🏭' => 'pekerja kilang wanita: ton kulit sederhana',
    '👩🏾‍🏭' => 'pekerja kilang wanita: ton kulit sederhana gelap',
    '👩🏿‍🏭' => 'pekerja kilang wanita: ton kulit gelap',
    '🧑🏻‍💼' => 'pekerja pejabat: ton kulit cerah',
    '🧑🏼‍💼' => 'pekerja pejabat: ton kulit sederhana cerah',
    '🧑🏽‍💼' => 'pekerja pejabat: ton kulit sederhana',
    '🧑🏾‍💼' => 'pekerja pejabat: ton kulit sederhana gelap',
    '🧑🏿‍💼' => 'pekerja pejabat: ton kulit gelap',
    '👨🏻‍💼' => 'pekerja pejabat lelaki: ton kulit cerah',
    '👨🏼‍💼' => 'pekerja pejabat lelaki: ton kulit sederhana cerah',
    '👨🏽‍💼' => 'pekerja pejabat lelaki: ton kulit sederhana',
    '👨🏾‍💼' => 'pekerja pejabat lelaki: ton kulit sederhana gelap',
    '👨🏿‍💼' => 'pekerja pejabat lelaki: ton kulit gelap',
    '👩🏻‍💼' => 'pekerja pejabat wanita: ton kulit cerah',
    '👩🏼‍💼' => 'pekerja pejabat wanita: ton kulit sederhana cerah',
    '👩🏽‍💼' => 'pekerja pejabat wanita: ton kulit sederhana',
    '👩🏾‍💼' => 'pekerja pejabat wanita: ton kulit sederhana gelap',
    '👩🏿‍💼' => 'pekerja pejabat wanita: ton kulit gelap',
    '🧑🏻‍🔬' => 'saintis: ton kulit cerah',
    '🧑🏼‍🔬' => 'saintis: ton kulit sederhana cerah',
    '🧑🏽‍🔬' => 'saintis: ton kulit sederhana',
    '🧑🏾‍🔬' => 'saintis: ton kulit sederhana gelap',
    '🧑🏿‍🔬' => 'saintis: ton kulit gelap',
    '👨🏻‍🔬' => 'saintis lelaki: ton kulit cerah',
    '👨🏼‍🔬' => 'saintis lelaki: ton kulit sederhana cerah',
    '👨🏽‍🔬' => 'saintis lelaki: ton kulit sederhana',
    '👨🏾‍🔬' => 'saintis lelaki: ton kulit sederhana gelap',
    '👨🏿‍🔬' => 'saintis lelaki: ton kulit gelap',
    '👩🏻‍🔬' => 'saintis wanita: ton kulit cerah',
    '👩🏼‍🔬' => 'saintis wanita: ton kulit sederhana cerah',
    '👩🏽‍🔬' => 'saintis wanita: ton kulit sederhana',
    '👩🏾‍🔬' => 'saintis wanita: ton kulit sederhana gelap',
    '👩🏿‍🔬' => 'saintis wanita: ton kulit gelap',
    '🧑🏻‍💻' => 'ahli teknologi: ton kulit cerah',
    '🧑🏼‍💻' => 'ahli teknologi: ton kulit sederhana cerah',
    '🧑🏽‍💻' => 'ahli teknologi: ton kulit sederhana',
    '🧑🏾‍💻' => 'ahli teknologi: ton kulit sederhana gelap',
    '🧑🏿‍💻' => 'ahli teknologi: ton kulit gelap',
    '👨🏻‍💻' => 'ahli teknologi lelaki: ton kulit cerah',
    '👨🏼‍💻' => 'ahli teknologi lelaki: ton kulit sederhana cerah',
    '👨🏽‍💻' => 'ahli teknologi lelaki: ton kulit sederhana',
    '👨🏾‍💻' => 'ahli teknologi lelaki: ton kulit sederhana gelap',
    '👨🏿‍💻' => 'ahli teknologi lelaki: ton kulit gelap',
    '👩🏻‍💻' => 'ahli teknologi wanita: ton kulit cerah',
    '👩🏼‍💻' => 'ahli teknologi wanita: ton kulit sederhana cerah',
    '👩🏽‍💻' => 'ahli teknologi wanita: ton kulit sederhana',
    '👩🏾‍💻' => 'ahli teknologi wanita: ton kulit sederhana gelap',
    '👩🏿‍💻' => 'ahli teknologi wanita: ton kulit gelap',
    '🧑🏻‍🎤' => 'penyanyi: ton kulit cerah',
    '🧑🏼‍🎤' => 'penyanyi: ton kulit sederhana cerah',
    '🧑🏽‍🎤' => 'penyanyi: ton kulit sederhana',
    '🧑🏾‍🎤' => 'penyanyi: ton kulit sederhana gelap',
    '🧑🏿‍🎤' => 'penyanyi: ton kulit gelap',
    '👨🏻‍🎤' => 'penyanyi lelaki: ton kulit cerah',
    '👨🏼‍🎤' => 'penyanyi lelaki: ton kulit sederhana cerah',
    '👨🏽‍🎤' => 'penyanyi lelaki: ton kulit sederhana',
    '👨🏾‍🎤' => 'penyanyi lelaki: ton kulit sederhana gelap',
    '👨🏿‍🎤' => 'penyanyi lelaki: ton kulit gelap',
    '👩🏻‍🎤' => 'penyanyi wanita: ton kulit cerah',
    '👩🏼‍🎤' => 'penyanyi wanita: ton kulit sederhana cerah',
    '👩🏽‍🎤' => 'penyanyi wanita: ton kulit sederhana',
    '👩🏾‍🎤' => 'penyanyi wanita: ton kulit sederhana gelap',
    '👩🏿‍🎤' => 'penyanyi wanita: ton kulit gelap',
    '🧑🏻‍🎨' => 'artis: ton kulit cerah',
    '🧑🏼‍🎨' => 'artis: ton kulit sederhana cerah',
    '🧑🏽‍🎨' => 'artis: ton kulit sederhana',
    '🧑🏾‍🎨' => 'artis: ton kulit sederhana gelap',
    '🧑🏿‍🎨' => 'artis: ton kulit gelap',
    '👨🏻‍🎨' => 'pelukis lelaki: ton kulit cerah',
    '👨🏼‍🎨' => 'pelukis lelaki: ton kulit sederhana cerah',
    '👨🏽‍🎨' => 'pelukis lelaki: ton kulit sederhana',
    '👨🏾‍🎨' => 'pelukis lelaki: ton kulit sederhana gelap',
    '👨🏿‍🎨' => 'pelukis lelaki: ton kulit gelap',
    '👩🏻‍🎨' => 'pelukis wanita: ton kulit cerah',
    '👩🏼‍🎨' => 'pelukis wanita: ton kulit sederhana cerah',
    '👩🏽‍🎨' => 'pelukis wanita: ton kulit sederhana',
    '👩🏾‍🎨' => 'pelukis wanita: ton kulit sederhana gelap',
    '👩🏿‍🎨' => 'pelukis wanita: ton kulit gelap',
    '🧑🏻‍✈' => 'juruterbang: ton kulit cerah',
    '🧑🏼‍✈' => 'juruterbang: ton kulit sederhana cerah',
    '🧑🏽‍✈' => 'juruterbang: ton kulit sederhana',
    '🧑🏾‍✈' => 'juruterbang: ton kulit sederhana gelap',
    '🧑🏿‍✈' => 'juruterbang: ton kulit gelap',
    '👨🏻‍✈' => 'juruterbang lelaki: ton kulit cerah',
    '👨🏼‍✈' => 'juruterbang lelaki: ton kulit sederhana cerah',
    '👨🏽‍✈' => 'juruterbang lelaki: ton kulit sederhana',
    '👨🏾‍✈' => 'juruterbang lelaki: ton kulit sederhana gelap',
    '👨🏿‍✈' => 'juruterbang lelaki: ton kulit gelap',
    '👩🏻‍✈' => 'juruterbang wanita: ton kulit cerah',
    '👩🏼‍✈' => 'juruterbang wanita: ton kulit sederhana cerah',
    '👩🏽‍✈' => 'juruterbang wanita: ton kulit sederhana',
    '👩🏾‍✈' => 'juruterbang wanita: ton kulit sederhana gelap',
    '👩🏿‍✈' => 'juruterbang wanita: ton kulit gelap',
    '🧑🏻‍🚀' => 'angkasawan: ton kulit cerah',
    '🧑🏼‍🚀' => 'angkasawan: ton kulit sederhana cerah',
    '🧑🏽‍🚀' => 'angkasawan: ton kulit sederhana',
    '🧑🏾‍🚀' => 'angkasawan: ton kulit sederhana gelap',
    '🧑🏿‍🚀' => 'angkasawan: ton kulit gelap',
    '👨🏻‍🚀' => 'angkasawan lelaki: ton kulit cerah',
    '👨🏼‍🚀' => 'angkasawan lelaki: ton kulit sederhana cerah',
    '👨🏽‍🚀' => 'angkasawan lelaki: ton kulit sederhana',
    '👨🏾‍🚀' => 'angkasawan lelaki: ton kulit sederhana gelap',
    '👨🏿‍🚀' => 'angkasawan lelaki: ton kulit gelap',
    '👩🏻‍🚀' => 'angkasawati: ton kulit cerah',
    '👩🏼‍🚀' => 'angkasawati: ton kulit sederhana cerah',
    '👩🏽‍🚀' => 'angkasawati: ton kulit sederhana',
    '👩🏾‍🚀' => 'angkasawati: ton kulit sederhana gelap',
    '👩🏿‍🚀' => 'angkasawati: ton kulit gelap',
    '🧑🏻‍🚒' => 'ahli bomba: ton kulit cerah',
    '🧑🏼‍🚒' => 'ahli bomba: ton kulit sederhana cerah',
    '🧑🏽‍🚒' => 'ahli bomba: ton kulit sederhana',
    '🧑🏾‍🚒' => 'ahli bomba: ton kulit sederhana gelap',
    '🧑🏿‍🚒' => 'ahli bomba: ton kulit gelap',
    '👨🏻‍🚒' => 'ahli bomba lelaki: ton kulit cerah',
    '👨🏼‍🚒' => 'ahli bomba lelaki: ton kulit sederhana cerah',
    '👨🏽‍🚒' => 'ahli bomba lelaki: ton kulit sederhana',
    '👨🏾‍🚒' => 'ahli bomba lelaki: ton kulit sederhana gelap',
    '👨🏿‍🚒' => 'ahli bomba lelaki: ton kulit gelap',
    '👩🏻‍🚒' => 'ahli bomba wanita: ton kulit cerah',
    '👩🏼‍🚒' => 'ahli bomba wanita: ton kulit sederhana cerah',
    '👩🏽‍🚒' => 'ahli bomba wanita: ton kulit sederhana',
    '👩🏾‍🚒' => 'ahli bomba wanita: ton kulit sederhana gelap',
    '👩🏿‍🚒' => 'ahli bomba wanita: ton kulit gelap',
    '👮🏻‍♂' => 'pegawai polis lelaki: ton kulit cerah',
    '👮🏼‍♂' => 'pegawai polis lelaki: ton kulit sederhana cerah',
    '👮🏽‍♂' => 'pegawai polis lelaki: ton kulit sederhana',
    '👮🏾‍♂' => 'pegawai polis lelaki: ton kulit sederhana gelap',
    '👮🏿‍♂' => 'pegawai polis lelaki: ton kulit gelap',
    '👮🏻‍♀' => 'pegawai polis wanita: ton kulit cerah',
    '👮🏼‍♀' => 'pegawai polis wanita: ton kulit sederhana cerah',
    '👮🏽‍♀' => 'pegawai polis wanita: ton kulit sederhana',
    '👮🏾‍♀' => 'pegawai polis wanita: ton kulit sederhana gelap',
    '👮🏿‍♀' => 'pegawai polis wanita: ton kulit gelap',
    '🕵🏻‍♂' => 'mata-mata gelap lelaki: ton kulit cerah',
    '🕵🏼‍♂' => 'mata-mata gelap lelaki: ton kulit sederhana cerah',
    '🕵🏽‍♂' => 'mata-mata gelap lelaki: ton kulit sederhana',
    '🕵🏾‍♂' => 'mata-mata gelap lelaki: ton kulit sederhana gelap',
    '🕵🏿‍♂' => 'mata-mata gelap lelaki: ton kulit gelap',
    '🕵🏻‍♀' => 'mata-mata gelap wanita: ton kulit cerah',
    '🕵🏼‍♀' => 'mata-mata gelap wanita: ton kulit sederhana cerah',
    '🕵🏽‍♀' => 'mata-mata gelap wanita: ton kulit sederhana',
    '🕵🏾‍♀' => 'mata-mata gelap wanita: ton kulit sederhana gelap',
    '🕵🏿‍♀' => 'mata-mata gelap wanita: ton kulit gelap',
    '💂🏻‍♂' => 'pengawal lelaki: ton kulit cerah',
    '💂🏼‍♂' => 'pengawal lelaki: ton kulit sederhana cerah',
    '💂🏽‍♂' => 'pengawal lelaki: ton kulit sederhana',
    '💂🏾‍♂' => 'pengawal lelaki: ton kulit sederhana gelap',
    '💂🏿‍♂' => 'pengawal lelaki: ton kulit gelap',
    '💂🏻‍♀' => 'pengawal wanita: ton kulit cerah',
    '💂🏼‍♀' => 'pengawal wanita: ton kulit sederhana cerah',
    '💂🏽‍♀' => 'pengawal wanita: ton kulit sederhana',
    '💂🏾‍♀' => 'pengawal wanita: ton kulit sederhana gelap',
    '💂🏿‍♀' => 'pengawal wanita: ton kulit gelap',
    '👷🏻‍♂' => 'pekerja pembinaan lelaki: ton kulit cerah',
    '👷🏼‍♂' => 'pekerja pembinaan lelaki: ton kulit sederhana cerah',
    '👷🏽‍♂' => 'pekerja pembinaan lelaki: ton kulit sederhana',
    '👷🏾‍♂' => 'pekerja pembinaan lelaki: ton kulit sederhana gelap',
    '👷🏿‍♂' => 'pekerja pembinaan lelaki: ton kulit gelap',
    '👷🏻‍♀' => 'pekerja pembinaan wanita: ton kulit cerah',
    '👷🏼‍♀' => 'pekerja pembinaan wanita: ton kulit sederhana cerah',
    '👷🏽‍♀' => 'pekerja pembinaan wanita: ton kulit sederhana',
    '👷🏾‍♀' => 'pekerja pembinaan wanita: ton kulit sederhana gelap',
    '👷🏿‍♀' => 'pekerja pembinaan wanita: ton kulit gelap',
    '👳🏻‍♂' => 'lelaki berserban: ton kulit cerah',
    '👳🏼‍♂' => 'lelaki berserban: ton kulit sederhana cerah',
    '👳🏽‍♂' => 'lelaki berserban: ton kulit sederhana',
    '👳🏾‍♂' => 'lelaki berserban: ton kulit sederhana gelap',
    '👳🏿‍♂' => 'lelaki berserban: ton kulit gelap',
    '👳🏻‍♀' => 'wanita berserban: ton kulit cerah',
    '👳🏼‍♀' => 'wanita berserban: ton kulit sederhana cerah',
    '👳🏽‍♀' => 'wanita berserban: ton kulit sederhana',
    '👳🏾‍♀' => 'wanita berserban: ton kulit sederhana gelap',
    '👳🏿‍♀' => 'wanita berserban: ton kulit gelap',
    '🤵🏻‍♂' => 'lelaki berpakaian tuksedo: ton kulit cerah',
    '🤵🏼‍♂' => 'lelaki berpakaian tuksedo: ton kulit sederhana cerah',
    '🤵🏽‍♂' => 'lelaki berpakaian tuksedo: ton kulit sederhana',
    '🤵🏾‍♂' => 'lelaki berpakaian tuksedo: ton kulit sederhana gelap',
    '🤵🏿‍♂' => 'lelaki berpakaian tuksedo: ton kulit gelap',
    '🤵🏻‍♀' => 'wanita berpakaian tuksedo: ton kulit cerah',
    '🤵🏼‍♀' => 'wanita berpakaian tuksedo: ton kulit sederhana cerah',
    '🤵🏽‍♀' => 'wanita berpakaian tuksedo: ton kulit sederhana',
    '🤵🏾‍♀' => 'wanita berpakaian tuksedo: ton kulit sederhana gelap',
    '🤵🏿‍♀' => 'wanita berpakaian tuksedo: ton kulit gelap',
    '👰🏻‍♂' => 'lelaki memakai vel: ton kulit cerah',
    '👰🏼‍♂' => 'lelaki memakai vel: ton kulit sederhana cerah',
    '👰🏽‍♂' => 'lelaki memakai vel: ton kulit sederhana',
    '👰🏾‍♂' => 'lelaki memakai vel: ton kulit sederhana gelap',
    '👰🏿‍♂' => 'lelaki memakai vel: ton kulit gelap',
    '👰🏻‍♀' => 'wanita memakai vel: ton kulit cerah',
    '👰🏼‍♀' => 'wanita memakai vel: ton kulit sederhana cerah',
    '👰🏽‍♀' => 'wanita memakai vel: ton kulit sederhana',
    '👰🏾‍♀' => 'wanita memakai vel: ton kulit sederhana gelap',
    '👰🏿‍♀' => 'wanita memakai vel: ton kulit gelap',
    '👩🏻‍🍼' => 'wanita menyusui bayi: ton kulit cerah',
    '👩🏼‍🍼' => 'wanita menyusui bayi: ton kulit sederhana cerah',
    '👩🏽‍🍼' => 'wanita menyusui bayi: ton kulit sederhana',
    '👩🏾‍🍼' => 'wanita menyusui bayi: ton kulit sederhana gelap',
    '👩🏿‍🍼' => 'wanita menyusui bayi: ton kulit gelap',
    '👨🏻‍🍼' => 'lelaki menyusui bayi: ton kulit cerah',
    '👨🏼‍🍼' => 'lelaki menyusui bayi: ton kulit sederhana cerah',
    '👨🏽‍🍼' => 'lelaki menyusui bayi: ton kulit sederhana',
    '👨🏾‍🍼' => 'lelaki menyusui bayi: ton kulit sederhana gelap',
    '👨🏿‍🍼' => 'lelaki menyusui bayi: ton kulit gelap',
    '🧑🏻‍🍼' => 'orang menyusui bayi: ton kulit cerah',
    '🧑🏼‍🍼' => 'orang menyusui bayi: ton kulit sederhana cerah',
    '🧑🏽‍🍼' => 'orang menyusui bayi: ton kulit sederhana',
    '🧑🏾‍🍼' => 'orang menyusui bayi: ton kulit sederhana gelap',
    '🧑🏿‍🍼' => 'orang menyusui bayi: ton kulit gelap',
    '🧑🏻‍🎄' => 'orang claus: ton kulit cerah',
    '🧑🏼‍🎄' => 'orang claus: ton kulit sederhana cerah',
    '🧑🏽‍🎄' => 'orang claus: ton kulit sederhana',
    '🧑🏾‍🎄' => 'orang claus: ton kulit sederhana gelap',
    '🧑🏿‍🎄' => 'orang claus: ton kulit gelap',
    '🦸🏻‍♂' => 'adi wira lelaki: ton kulit cerah',
    '🦸🏼‍♂' => 'adi wira lelaki: ton kulit sederhana cerah',
    '🦸🏽‍♂' => 'adi wira lelaki: ton kulit sederhana',
    '🦸🏾‍♂' => 'adi wira lelaki: ton kulit sederhana gelap',
    '🦸🏿‍♂' => 'adi wira lelaki: ton kulit gelap',
    '🦸🏻‍♀' => 'adi wira wanita: ton kulit cerah',
    '🦸🏼‍♀' => 'adi wira wanita: ton kulit sederhana cerah',
    '🦸🏽‍♀' => 'adi wira wanita: ton kulit sederhana',
    '🦸🏾‍♀' => 'adi wira wanita: ton kulit sederhana gelap',
    '🦸🏿‍♀' => 'adi wira wanita: ton kulit gelap',
    '🦹🏻‍♂' => 'ketua penjahat lelaki: ton kulit cerah',
    '🦹🏼‍♂' => 'ketua penjahat lelaki: ton kulit sederhana cerah',
    '🦹🏽‍♂' => 'ketua penjahat lelaki: ton kulit sederhana',
    '🦹🏾‍♂' => 'ketua penjahat lelaki: ton kulit sederhana gelap',
    '🦹🏿‍♂' => 'ketua penjahat lelaki: ton kulit gelap',
    '🦹🏻‍♀' => 'ketua penjahat wanita: ton kulit cerah',
    '🦹🏼‍♀' => 'ketua penjahat wanita: ton kulit sederhana cerah',
    '🦹🏽‍♀' => 'ketua penjahat wanita: ton kulit sederhana',
    '🦹🏾‍♀' => 'ketua penjahat wanita: ton kulit sederhana gelap',
    '🦹🏿‍♀' => 'ketua penjahat wanita: ton kulit gelap',
    '🧙🏻‍♂' => 'ahli sihir lelaki: ton kulit cerah',
    '🧙🏼‍♂' => 'ahli sihir lelaki: ton kulit sederhana cerah',
    '🧙🏽‍♂' => 'ahli sihir lelaki: ton kulit sederhana',
    '🧙🏾‍♂' => 'ahli sihir lelaki: ton kulit sederhana gelap',
    '🧙🏿‍♂' => 'ahli sihir lelaki: ton kulit gelap',
    '🧙🏻‍♀' => 'ahli sihir wanita: ton kulit cerah',
    '🧙🏼‍♀' => 'ahli sihir wanita: ton kulit sederhana cerah',
    '🧙🏽‍♀' => 'ahli sihir wanita: ton kulit sederhana',
    '🧙🏾‍♀' => 'ahli sihir wanita: ton kulit sederhana gelap',
    '🧙🏿‍♀' => 'ahli sihir wanita: ton kulit gelap',
    '🧚🏻‍♂' => 'pari-pari lelaki: ton kulit cerah',
    '🧚🏼‍♂' => 'pari-pari lelaki: ton kulit sederhana cerah',
    '🧚🏽‍♂' => 'pari-pari lelaki: ton kulit sederhana',
    '🧚🏾‍♂' => 'pari-pari lelaki: ton kulit sederhana gelap',
    '🧚🏿‍♂' => 'pari-pari lelaki: ton kulit gelap',
    '🧚🏻‍♀' => 'pari-pari wanita: ton kulit cerah',
    '🧚🏼‍♀' => 'pari-pari wanita: ton kulit sederhana cerah',
    '🧚🏽‍♀' => 'pari-pari wanita: ton kulit sederhana',
    '🧚🏾‍♀' => 'pari-pari wanita: ton kulit sederhana gelap',
    '🧚🏿‍♀' => 'pari-pari wanita: ton kulit gelap',
    '🧛🏻‍♂' => 'puntianak lelaki: ton kulit cerah',
    '🧛🏼‍♂' => 'puntianak lelaki: ton kulit sederhana cerah',
    '🧛🏽‍♂' => 'puntianak lelaki: ton kulit sederhana',
    '🧛🏾‍♂' => 'puntianak lelaki: ton kulit sederhana gelap',
    '🧛🏿‍♂' => 'puntianak lelaki: ton kulit gelap',
    '🧛🏻‍♀' => 'puntianak wanita: ton kulit cerah',
    '🧛🏼‍♀' => 'puntianak wanita: ton kulit sederhana cerah',
    '🧛🏽‍♀' => 'puntianak wanita: ton kulit sederhana',
    '🧛🏾‍♀' => 'puntianak wanita: ton kulit sederhana gelap',
    '🧛🏿‍♀' => 'puntianak wanita: ton kulit gelap',
    '🧜🏻‍♂' => 'duyung jantan: ton kulit cerah',
    '🧜🏼‍♂' => 'duyung jantan: ton kulit sederhana cerah',
    '🧜🏽‍♂' => 'duyung jantan: ton kulit sederhana',
    '🧜🏾‍♂' => 'duyung jantan: ton kulit sederhana gelap',
    '🧜🏿‍♂' => 'duyung jantan: ton kulit gelap',
    '🧜🏻‍♀' => 'ikan duyung: ton kulit cerah',
    '🧜🏼‍♀' => 'ikan duyung: ton kulit sederhana cerah',
    '🧜🏽‍♀' => 'ikan duyung: ton kulit sederhana',
    '🧜🏾‍♀' => 'ikan duyung: ton kulit sederhana gelap',
    '🧜🏿‍♀' => 'ikan duyung: ton kulit gelap',
    '🧝🏻‍♂' => 'orang halus lelaki: ton kulit cerah',
    '🧝🏼‍♂' => 'orang halus lelaki: ton kulit sederhana cerah',
    '🧝🏽‍♂' => 'orang halus lelaki: ton kulit sederhana',
    '🧝🏾‍♂' => 'orang halus lelaki: ton kulit sederhana gelap',
    '🧝🏿‍♂' => 'orang halus lelaki: ton kulit gelap',
    '🧝🏻‍♀' => 'orang halus wanita: ton kulit cerah',
    '🧝🏼‍♀' => 'orang halus wanita: ton kulit sederhana cerah',
    '🧝🏽‍♀' => 'orang halus wanita: ton kulit sederhana',
    '🧝🏾‍♀' => 'orang halus wanita: ton kulit sederhana gelap',
    '🧝🏿‍♀' => 'orang halus wanita: ton kulit gelap',
    '💆🏻‍♂' => 'lelaki diurut muka: ton kulit cerah',
    '💆🏼‍♂' => 'lelaki diurut muka: ton kulit sederhana cerah',
    '💆🏽‍♂' => 'lelaki diurut muka: ton kulit sederhana',
    '💆🏾‍♂' => 'lelaki diurut muka: ton kulit sederhana gelap',
    '💆🏿‍♂' => 'lelaki diurut muka: ton kulit gelap',
    '💆🏻‍♀' => 'perempuan diurut muka: ton kulit cerah',
    '💆🏼‍♀' => 'perempuan diurut muka: ton kulit sederhana cerah',
    '💆🏽‍♀' => 'perempuan diurut muka: ton kulit sederhana',
    '💆🏾‍♀' => 'perempuan diurut muka: ton kulit sederhana gelap',
    '💆🏿‍♀' => 'perempuan diurut muka: ton kulit gelap',
    '💇🏻‍♂' => 'lelaki digunting rambut: ton kulit cerah',
    '💇🏼‍♂' => 'lelaki digunting rambut: ton kulit sederhana cerah',
    '💇🏽‍♂' => 'lelaki digunting rambut: ton kulit sederhana',
    '💇🏾‍♂' => 'lelaki digunting rambut: ton kulit sederhana gelap',
    '💇🏿‍♂' => 'lelaki digunting rambut: ton kulit gelap',
    '💇🏻‍♀' => 'perempuan digunting rambut: ton kulit cerah',
    '💇🏼‍♀' => 'perempuan digunting rambut: ton kulit sederhana cerah',
    '💇🏽‍♀' => 'perempuan digunting rambut: ton kulit sederhana',
    '💇🏾‍♀' => 'perempuan digunting rambut: ton kulit sederhana gelap',
    '💇🏿‍♀' => 'perempuan digunting rambut: ton kulit gelap',
    '🚶🏻‍♂' => 'lelaki berjalan: ton kulit cerah',
    '🚶🏼‍♂' => 'lelaki berjalan: ton kulit sederhana cerah',
    '🚶🏽‍♂' => 'lelaki berjalan: ton kulit sederhana',
    '🚶🏾‍♂' => 'lelaki berjalan: ton kulit sederhana gelap',
    '🚶🏿‍♂' => 'lelaki berjalan: ton kulit gelap',
    '🚶🏻‍♀' => 'perempuan berjalan: ton kulit cerah',
    '🚶🏼‍♀' => 'perempuan berjalan: ton kulit sederhana cerah',
    '🚶🏽‍♀' => 'perempuan berjalan: ton kulit sederhana',
    '🚶🏾‍♀' => 'perempuan berjalan: ton kulit sederhana gelap',
    '🚶🏿‍♀' => 'perempuan berjalan: ton kulit gelap',
    '🚶🏻‍➡' => 'pejalan kaki: ton kulit cerah dan menghadap kanan',
    '🚶🏼‍➡' => 'pejalan kaki: ton kulit sederhana cerah dan menghadap kanan',
    '🚶🏽‍➡' => 'pejalan kaki: ton kulit sederhana dan menghadap kanan',
    '🚶🏾‍➡' => 'pejalan kaki: ton kulit sederhana gelap dan menghadap kanan',
    '🚶🏿‍➡' => 'pejalan kaki: ton kulit gelap dan menghadap kanan',
    '🧍🏻‍♂' => 'lelaki berdiri: ton kulit cerah',
    '🧍🏼‍♂' => 'lelaki berdiri: ton kulit sederhana cerah',
    '🧍🏽‍♂' => 'lelaki berdiri: ton kulit sederhana',
    '🧍🏾‍♂' => 'lelaki berdiri: ton kulit sederhana gelap',
    '🧍🏿‍♂' => 'lelaki berdiri: ton kulit gelap',
    '🧍🏻‍♀' => 'perempuan berdiri: ton kulit cerah',
    '🧍🏼‍♀' => 'perempuan berdiri: ton kulit sederhana cerah',
    '🧍🏽‍♀' => 'perempuan berdiri: ton kulit sederhana',
    '🧍🏾‍♀' => 'perempuan berdiri: ton kulit sederhana gelap',
    '🧍🏿‍♀' => 'perempuan berdiri: ton kulit gelap',
    '🧎🏻‍♂' => 'lelaki bersimpuh: ton kulit cerah',
    '🧎🏼‍♂' => 'lelaki bersimpuh: ton kulit sederhana cerah',
    '🧎🏽‍♂' => 'lelaki bersimpuh: ton kulit sederhana',
    '🧎🏾‍♂' => 'lelaki bersimpuh: ton kulit sederhana gelap',
    '🧎🏿‍♂' => 'lelaki bersimpuh: ton kulit gelap',
    '🧎🏻‍♀' => 'perempuan bersimpuh: ton kulit cerah',
    '🧎🏼‍♀' => 'perempuan bersimpuh: ton kulit sederhana cerah',
    '🧎🏽‍♀' => 'perempuan bersimpuh: ton kulit sederhana',
    '🧎🏾‍♀' => 'perempuan bersimpuh: ton kulit sederhana gelap',
    '🧎🏿‍♀' => 'perempuan bersimpuh: ton kulit gelap',
    '🧎🏻‍➡' => 'orang bersimpuh: ton kulit cerah dan menghadap kanan',
    '🧎🏼‍➡' => 'orang bersimpuh: ton kulit sederhana cerah dan menghadap kanan',
    '🧎🏽‍➡' => 'orang bersimpuh: ton kulit sederhana dan menghadap kanan',
    '🧎🏾‍➡' => 'orang bersimpuh: ton kulit sederhana gelap dan menghadap kanan',
    '🧎🏿‍➡' => 'orang bersimpuh: ton kulit gelap dan menghadap kanan',
    '🧑🏻‍🦯' => 'orang dengan tongkat putih: ton kulit cerah',
    '🧑🏼‍🦯' => 'orang dengan tongkat putih: ton kulit sederhana cerah',
    '🧑🏽‍🦯' => 'orang dengan tongkat putih: ton kulit sederhana',
    '🧑🏾‍🦯' => 'orang dengan tongkat putih: ton kulit sederhana gelap',
    '🧑🏿‍🦯' => 'orang dengan tongkat putih: ton kulit gelap',
    '👨🏻‍🦯' => 'lelaki dengan tongkat putih: ton kulit cerah',
    '👨🏼‍🦯' => 'lelaki dengan tongkat putih: ton kulit sederhana cerah',
    '👨🏽‍🦯' => 'lelaki dengan tongkat putih: ton kulit sederhana',
    '👨🏾‍🦯' => 'lelaki dengan tongkat putih: ton kulit sederhana gelap',
    '👨🏿‍🦯' => 'lelaki dengan tongkat putih: ton kulit gelap',
    '👩🏻‍🦯' => 'perempuan dengan tongkat putih: ton kulit cerah',
    '👩🏼‍🦯' => 'perempuan dengan tongkat putih: ton kulit sederhana cerah',
    '👩🏽‍🦯' => 'perempuan dengan tongkat putih: ton kulit sederhana',
    '👩🏾‍🦯' => 'perempuan dengan tongkat putih: ton kulit sederhana gelap',
    '👩🏿‍🦯' => 'perempuan dengan tongkat putih: ton kulit gelap',
    '🧑🏻‍🦼' => 'orang dalam kerusi roda bermotor: ton kulit cerah',
    '🧑🏼‍🦼' => 'orang dalam kerusi roda bermotor: ton kulit sederhana cerah',
    '🧑🏽‍🦼' => 'orang dalam kerusi roda bermotor: ton kulit sederhana',
    '🧑🏾‍🦼' => 'orang dalam kerusi roda bermotor: ton kulit sederhana gelap',
    '🧑🏿‍🦼' => 'orang dalam kerusi roda bermotor: ton kulit gelap',
    '👨🏻‍🦼' => 'lelaki dalam kerusi roda bermotor: ton kulit cerah',
    '👨🏼‍🦼' => 'lelaki dalam kerusi roda bermotor: ton kulit sederhana cerah',
    '👨🏽‍🦼' => 'lelaki dalam kerusi roda bermotor: ton kulit sederhana',
    '👨🏾‍🦼' => 'lelaki dalam kerusi roda bermotor: ton kulit sederhana gelap',
    '👨🏿‍🦼' => 'lelaki dalam kerusi roda bermotor: ton kulit gelap',
    '👩🏻‍🦼' => 'perempuan dalam kerusi roda bermotor: ton kulit cerah',
    '👩🏼‍🦼' => 'perempuan dalam kerusi roda bermotor: ton kulit sederhana cerah',
    '👩🏽‍🦼' => 'perempuan dalam kerusi roda bermotor: ton kulit sederhana',
    '👩🏾‍🦼' => 'perempuan dalam kerusi roda bermotor: ton kulit sederhana gelap',
    '👩🏿‍🦼' => 'perempuan dalam kerusi roda bermotor: ton kulit gelap',
    '🧑🏻‍🦽' => 'orang dalam kerusi roda manual: ton kulit cerah',
    '🧑🏼‍🦽' => 'orang dalam kerusi roda manual: ton kulit sederhana cerah',
    '🧑🏽‍🦽' => 'orang dalam kerusi roda manual: ton kulit sederhana',
    '🧑🏾‍🦽' => 'orang dalam kerusi roda manual: ton kulit sederhana gelap',
    '🧑🏿‍🦽' => 'orang dalam kerusi roda manual: ton kulit gelap',
    '👨🏻‍🦽' => 'lelaki dalam kerusi roda manual: ton kulit cerah',
    '👨🏼‍🦽' => 'lelaki dalam kerusi roda manual: ton kulit sederhana cerah',
    '👨🏽‍🦽' => 'lelaki dalam kerusi roda manual: ton kulit sederhana',
    '👨🏾‍🦽' => 'lelaki dalam kerusi roda manual: ton kulit sederhana gelap',
    '👨🏿‍🦽' => 'lelaki dalam kerusi roda manual: ton kulit gelap',
    '👩🏻‍🦽' => 'perempuan dalam kereta roda manual: ton kulit cerah',
    '👩🏼‍🦽' => 'perempuan dalam kereta roda manual: ton kulit sederhana cerah',
    '👩🏽‍🦽' => 'perempuan dalam kereta roda manual: ton kulit sederhana',
    '👩🏾‍🦽' => 'perempuan dalam kereta roda manual: ton kulit sederhana gelap',
    '👩🏿‍🦽' => 'perempuan dalam kereta roda manual: ton kulit gelap',
    '🏃🏻‍♂' => 'lelaki berlari: ton kulit cerah',
    '🏃🏼‍♂' => 'lelaki berlari: ton kulit sederhana cerah',
    '🏃🏽‍♂' => 'lelaki berlari: ton kulit sederhana',
    '🏃🏾‍♂' => 'lelaki berlari: ton kulit sederhana gelap',
    '🏃🏿‍♂' => 'lelaki berlari: ton kulit gelap',
    '🏃🏻‍♀' => 'perempuan berlari: ton kulit cerah',
    '🏃🏼‍♀' => 'perempuan berlari: ton kulit sederhana cerah',
    '🏃🏽‍♀' => 'perempuan berlari: ton kulit sederhana',
    '🏃🏾‍♀' => 'perempuan berlari: ton kulit sederhana gelap',
    '🏃🏿‍♀' => 'perempuan berlari: ton kulit gelap',
    '🏃🏻‍➡' => 'pelari: ton kulit cerah dan menghadap kanan',
    '🏃🏼‍➡' => 'pelari: ton kulit sederhana cerah dan menghadap kanan',
    '🏃🏽‍➡' => 'pelari: ton kulit sederhana dan menghadap kanan',
    '🏃🏾‍➡' => 'pelari: ton kulit sederhana gelap dan menghadap kanan',
    '🏃🏿‍➡' => 'pelari: ton kulit gelap dan menghadap kanan',
    '👯🏻‍♀' => 'perempuan berpesta: ton kulit cerah',
    '👯🏼‍♀' => 'perempuan berpesta: ton kulit sederhana cerah',
    '👯🏽‍♀' => 'perempuan berpesta: ton kulit sederhana',
    '👯🏾‍♀' => 'perempuan berpesta: ton kulit sederhana gelap',
    '👯🏿‍♀' => 'perempuan berpesta: ton kulit gelap',
    '👯🏻‍♂' => 'lelaki berpesta: ton kulit cerah',
    '👯🏼‍♂' => 'lelaki berpesta: ton kulit sederhana cerah',
    '👯🏽‍♂' => 'lelaki berpesta: ton kulit sederhana',
    '👯🏾‍♂' => 'lelaki berpesta: ton kulit sederhana gelap',
    '👯🏿‍♂' => 'lelaki berpesta: ton kulit gelap',
    '🧖🏻‍♂' => 'lelaki dalam bilik berwap: ton kulit cerah',
    '🧖🏼‍♂' => 'lelaki dalam bilik berwap: ton kulit sederhana cerah',
    '🧖🏽‍♂' => 'lelaki dalam bilik berwap: ton kulit sederhana',
    '🧖🏾‍♂' => 'lelaki dalam bilik berwap: ton kulit sederhana gelap',
    '🧖🏿‍♂' => 'lelaki dalam bilik berwap: ton kulit gelap',
    '🧖🏻‍♀' => 'wanita dalam bilik berwap: ton kulit cerah',
    '🧖🏼‍♀' => 'wanita dalam bilik berwap: ton kulit sederhana cerah',
    '🧖🏽‍♀' => 'wanita dalam bilik berwap: ton kulit sederhana',
    '🧖🏾‍♀' => 'wanita dalam bilik berwap: ton kulit sederhana gelap',
    '🧖🏿‍♀' => 'wanita dalam bilik berwap: ton kulit gelap',
    '🧗🏻‍♂' => 'lelaki mendaki: ton kulit cerah',
    '🧗🏼‍♂' => 'lelaki mendaki: ton kulit sederhana cerah',
    '🧗🏽‍♂' => 'lelaki mendaki: ton kulit sederhana',
    '🧗🏾‍♂' => 'lelaki mendaki: ton kulit sederhana gelap',
    '🧗🏿‍♂' => 'lelaki mendaki: ton kulit gelap',
    '🧗🏻‍♀' => 'wanita mendaki: ton kulit cerah',
    '🧗🏼‍♀' => 'wanita mendaki: ton kulit sederhana cerah',
    '🧗🏽‍♀' => 'wanita mendaki: ton kulit sederhana',
    '🧗🏾‍♀' => 'wanita mendaki: ton kulit sederhana gelap',
    '🧗🏿‍♀' => 'wanita mendaki: ton kulit gelap',
    '🏌🏻‍♂' => 'lelaki bermain golf: ton kulit cerah',
    '🏌🏼‍♂' => 'lelaki bermain golf: ton kulit sederhana cerah',
    '🏌🏽‍♂' => 'lelaki bermain golf: ton kulit sederhana',
    '🏌🏾‍♂' => 'lelaki bermain golf: ton kulit sederhana gelap',
    '🏌🏿‍♂' => 'lelaki bermain golf: ton kulit gelap',
    '🏌🏻‍♀' => 'wanita bermain golf: ton kulit cerah',
    '🏌🏼‍♀' => 'wanita bermain golf: ton kulit sederhana cerah',
    '🏌🏽‍♀' => 'wanita bermain golf: ton kulit sederhana',
    '🏌🏾‍♀' => 'wanita bermain golf: ton kulit sederhana gelap',
    '🏌🏿‍♀' => 'wanita bermain golf: ton kulit gelap',
    '🏄🏻‍♂' => 'lelaki meluncur air: ton kulit cerah',
    '🏄🏼‍♂' => 'lelaki meluncur air: ton kulit sederhana cerah',
    '🏄🏽‍♂' => 'lelaki meluncur air: ton kulit sederhana',
    '🏄🏾‍♂' => 'lelaki meluncur air: ton kulit sederhana gelap',
    '🏄🏿‍♂' => 'lelaki meluncur air: ton kulit gelap',
    '🏄🏻‍♀' => 'wanita meluncur air: ton kulit cerah',
    '🏄🏼‍♀' => 'wanita meluncur air: ton kulit sederhana cerah',
    '🏄🏽‍♀' => 'wanita meluncur air: ton kulit sederhana',
    '🏄🏾‍♀' => 'wanita meluncur air: ton kulit sederhana gelap',
    '🏄🏿‍♀' => 'wanita meluncur air: ton kulit gelap',
    '🚣🏻‍♂' => 'lelaki mendayung sampan: ton kulit cerah',
    '🚣🏼‍♂' => 'lelaki mendayung sampan: ton kulit sederhana cerah',
    '🚣🏽‍♂' => 'lelaki mendayung sampan: ton kulit sederhana',
    '🚣🏾‍♂' => 'lelaki mendayung sampan: ton kulit sederhana gelap',
    '🚣🏿‍♂' => 'lelaki mendayung sampan: ton kulit gelap',
    '🚣🏻‍♀' => 'wanita mendayung sampan: ton kulit cerah',
    '🚣🏼‍♀' => 'wanita mendayung sampan: ton kulit sederhana cerah',
    '🚣🏽‍♀' => 'wanita mendayung sampan: ton kulit sederhana',
    '🚣🏾‍♀' => 'wanita mendayung sampan: ton kulit sederhana gelap',
    '🚣🏿‍♀' => 'wanita mendayung sampan: ton kulit gelap',
    '🏊🏻‍♂' => 'lelaki berenang: ton kulit cerah',
    '🏊🏼‍♂' => 'lelaki berenang: ton kulit sederhana cerah',
    '🏊🏽‍♂' => 'lelaki berenang: ton kulit sederhana',
    '🏊🏾‍♂' => 'lelaki berenang: ton kulit sederhana gelap',
    '🏊🏿‍♂' => 'lelaki berenang: ton kulit gelap',
    '🏊🏻‍♀' => 'wanita berenang: ton kulit cerah',
    '🏊🏼‍♀' => 'wanita berenang: ton kulit sederhana cerah',
    '🏊🏽‍♀' => 'wanita berenang: ton kulit sederhana',
    '🏊🏾‍♀' => 'wanita berenang: ton kulit sederhana gelap',
    '🏊🏿‍♀' => 'wanita berenang: ton kulit gelap',
    '⛹🏻‍♂' => 'lelaki melantun bola: ton kulit cerah',
    '⛹🏼‍♂' => 'lelaki melantun bola: ton kulit sederhana cerah',
    '⛹🏽‍♂' => 'lelaki melantun bola: ton kulit sederhana',
    '⛹🏾‍♂' => 'lelaki melantun bola: ton kulit sederhana gelap',
    '⛹🏿‍♂' => 'lelaki melantun bola: ton kulit gelap',
    '⛹🏻‍♀' => 'wanita melantun bola: ton kulit cerah',
    '⛹🏼‍♀' => 'wanita melantun bola: ton kulit sederhana cerah',
    '⛹🏽‍♀' => 'wanita melantun bola: ton kulit sederhana',
    '⛹🏾‍♀' => 'wanita melantun bola: ton kulit sederhana gelap',
    '⛹🏿‍♀' => 'wanita melantun bola: ton kulit gelap',
    '🏋🏻‍♂' => 'lelaki mengangkat berat: ton kulit cerah',
    '🏋🏼‍♂' => 'lelaki mengangkat berat: ton kulit sederhana cerah',
    '🏋🏽‍♂' => 'lelaki mengangkat berat: ton kulit sederhana',
    '🏋🏾‍♂' => 'lelaki mengangkat berat: ton kulit sederhana gelap',
    '🏋🏿‍♂' => 'lelaki mengangkat berat: ton kulit gelap',
    '🏋🏻‍♀' => 'wanita mengangkat berat: ton kulit cerah',
    '🏋🏼‍♀' => 'wanita mengangkat berat: ton kulit sederhana cerah',
    '🏋🏽‍♀' => 'wanita mengangkat berat: ton kulit sederhana',
    '🏋🏾‍♀' => 'wanita mengangkat berat: ton kulit sederhana gelap',
    '🏋🏿‍♀' => 'wanita mengangkat berat: ton kulit gelap',
    '🚴🏻‍♂' => 'lelaki berbasikal: ton kulit cerah',
    '🚴🏼‍♂' => 'lelaki berbasikal: ton kulit sederhana cerah',
    '🚴🏽‍♂' => 'lelaki berbasikal: ton kulit sederhana',
    '🚴🏾‍♂' => 'lelaki berbasikal: ton kulit sederhana gelap',
    '🚴🏿‍♂' => 'lelaki berbasikal: ton kulit gelap',
    '🚴🏻‍♀' => 'wanita berbasikal: ton kulit cerah',
    '🚴🏼‍♀' => 'wanita berbasikal: ton kulit sederhana cerah',
    '🚴🏽‍♀' => 'wanita berbasikal: ton kulit sederhana',
    '🚴🏾‍♀' => 'wanita berbasikal: ton kulit sederhana gelap',
    '🚴🏿‍♀' => 'wanita berbasikal: ton kulit gelap',
    '🚵🏻‍♂' => 'lelaki berbasikal gunung: ton kulit cerah',
    '🚵🏼‍♂' => 'lelaki berbasikal gunung: ton kulit sederhana cerah',
    '🚵🏽‍♂' => 'lelaki berbasikal gunung: ton kulit sederhana',
    '🚵🏾‍♂' => 'lelaki berbasikal gunung: ton kulit sederhana gelap',
    '🚵🏿‍♂' => 'lelaki berbasikal gunung: ton kulit gelap',
    '🚵🏻‍♀' => 'wanita berbasikal gunung: ton kulit cerah',
    '🚵🏼‍♀' => 'wanita berbasikal gunung: ton kulit sederhana cerah',
    '🚵🏽‍♀' => 'wanita berbasikal gunung: ton kulit sederhana',
    '🚵🏾‍♀' => 'wanita berbasikal gunung: ton kulit sederhana gelap',
    '🚵🏿‍♀' => 'wanita berbasikal gunung: ton kulit gelap',
    '🤸🏻‍♂' => 'lelaki membuat putar roda: ton kulit cerah',
    '🤸🏼‍♂' => 'lelaki membuat putar roda: ton kulit sederhana cerah',
    '🤸🏽‍♂' => 'lelaki membuat putar roda: ton kulit sederhana',
    '🤸🏾‍♂' => 'lelaki membuat putar roda: ton kulit sederhana gelap',
    '🤸🏿‍♂' => 'lelaki membuat putar roda: ton kulit gelap',
    '🤸🏻‍♀' => 'wanita membuat putar roda: ton kulit cerah',
    '🤸🏼‍♀' => 'wanita membuat putar roda: ton kulit sederhana cerah',
    '🤸🏽‍♀' => 'wanita membuat putar roda: ton kulit sederhana',
    '🤸🏾‍♀' => 'wanita membuat putar roda: ton kulit sederhana gelap',
    '🤸🏿‍♀' => 'wanita membuat putar roda: ton kulit gelap',
    '🤼🏻‍♀' => 'wanita bergusti: ton kulit cerah',
    '🤼🏼‍♀' => 'wanita bergusti: ton kulit sederhana cerah',
    '🤼🏽‍♀' => 'wanita bergusti: ton kulit sederhana',
    '🤼🏾‍♀' => 'wanita bergusti: ton kulit sederhana gelap',
    '🤼🏿‍♀' => 'wanita bergusti: ton kulit gelap',
    '🤼🏻‍♂' => 'lelaki bergusti: ton kulit cerah',
    '🤼🏼‍♂' => 'lelaki bergusti: ton kulit sederhana cerah',
    '🤼🏽‍♂' => 'lelaki bergusti: ton kulit sederhana',
    '🤼🏾‍♂' => 'lelaki bergusti: ton kulit sederhana gelap',
    '🤼🏿‍♂' => 'lelaki bergusti: ton kulit gelap',
    '🤽🏻‍♂' => 'lelaki bermain polo air: ton kulit cerah',
    '🤽🏼‍♂' => 'lelaki bermain polo air: ton kulit sederhana cerah',
    '🤽🏽‍♂' => 'lelaki bermain polo air: ton kulit sederhana',
    '🤽🏾‍♂' => 'lelaki bermain polo air: ton kulit sederhana gelap',
    '🤽🏿‍♂' => 'lelaki bermain polo air: ton kulit gelap',
    '🤽🏻‍♀' => 'wanita bermain polo air: ton kulit cerah',
    '🤽🏼‍♀' => 'wanita bermain polo air: ton kulit sederhana cerah',
    '🤽🏽‍♀' => 'wanita bermain polo air: ton kulit sederhana',
    '🤽🏾‍♀' => 'wanita bermain polo air: ton kulit sederhana gelap',
    '🤽🏿‍♀' => 'wanita bermain polo air: ton kulit gelap',
    '🤾🏻‍♂' => 'lelaki bermain bola baling: ton kulit cerah',
    '🤾🏼‍♂' => 'lelaki bermain bola baling: ton kulit sederhana cerah',
    '🤾🏽‍♂' => 'lelaki bermain bola baling: ton kulit sederhana',
    '🤾🏾‍♂' => 'lelaki bermain bola baling: ton kulit sederhana gelap',
    '🤾🏿‍♂' => 'lelaki bermain bola baling: ton kulit gelap',
    '🤾🏻‍♀' => 'wanita bermain bola baling: ton kulit cerah',
    '🤾🏼‍♀' => 'wanita bermain bola baling: ton kulit sederhana cerah',
    '🤾🏽‍♀' => 'wanita bermain bola baling: ton kulit sederhana',
    '🤾🏾‍♀' => 'wanita bermain bola baling: ton kulit sederhana gelap',
    '🤾🏿‍♀' => 'wanita bermain bola baling: ton kulit gelap',
    '🤹🏻‍♂' => 'lelaki menjugel: ton kulit cerah',
    '🤹🏼‍♂' => 'lelaki menjugel: ton kulit sederhana cerah',
    '🤹🏽‍♂' => 'lelaki menjugel: ton kulit sederhana',
    '🤹🏾‍♂' => 'lelaki menjugel: ton kulit sederhana gelap',
    '🤹🏿‍♂' => 'lelaki menjugel: ton kulit gelap',
    '🤹🏻‍♀' => 'wanita menjugel: ton kulit cerah',
    '🤹🏼‍♀' => 'wanita menjugel: ton kulit sederhana cerah',
    '🤹🏽‍♀' => 'wanita menjugel: ton kulit sederhana',
    '🤹🏾‍♀' => 'wanita menjugel: ton kulit sederhana gelap',
    '🤹🏿‍♀' => 'wanita menjugel: ton kulit gelap',
    '🧘🏻‍♂' => 'lelaki duduk teratai: ton kulit cerah',
    '🧘🏼‍♂' => 'lelaki duduk teratai: ton kulit sederhana cerah',
    '🧘🏽‍♂' => 'lelaki duduk teratai: ton kulit sederhana',
    '🧘🏾‍♂' => 'lelaki duduk teratai: ton kulit sederhana gelap',
    '🧘🏿‍♂' => 'lelaki duduk teratai: ton kulit gelap',
    '🧘🏻‍♀' => 'wanita duduk teratai: ton kulit cerah',
    '🧘🏼‍♀' => 'wanita duduk teratai: ton kulit sederhana cerah',
    '🧘🏽‍♀' => 'wanita duduk teratai: ton kulit sederhana',
    '🧘🏾‍♀' => 'wanita duduk teratai: ton kulit sederhana gelap',
    '🧘🏿‍♀' => 'wanita duduk teratai: ton kulit gelap',
    '🧑‍🦰' => 'dewasa: rambut merah',
    '🧑‍🦱' => 'dewasa: rambut kerinting',
    '🧑‍🦳' => 'dewasa: rambut putih',
    '🧑‍🦲' => 'dewasa: botak',
    '👨‍🦰' => 'lelaki: rambut merah',
    '👨‍🦱' => 'lelaki: rambut kerinting',
    '👨‍🦳' => 'lelaki: rambut putih',
    '👨‍🦲' => 'lelaki: botak',
    '👩‍🦰' => 'perempuan: rambut merah',
    '👩‍🦱' => 'perempuan: rambut kerinting',
    '👩‍🦳' => 'perempuan: rambut putih',
    '👩‍🦲' => 'perempuan: botak',
    '🚶‍➡' => 'pejalan kaki: menghadap kanan',
    '🧎‍➡' => 'orang bersimpuh: menghadap kanan',
    '🏃‍➡' => 'pelari: menghadap kanan',
    '👨‍👦' => 'keluarga: lelaki dan kanak-kanak lelaki',
    '👨‍👧' => 'keluarga: lelaki dan budak perempuan',
    '👩‍👦' => 'keluarga: perempuan dan kanak-kanak lelaki',
    '👩‍👧' => 'keluarga: perempuan dan budak perempuan',
    '😶‍🌫' => 'muka dikepung awan',
    '😮‍💨' => 'muka menghembuskan nafas',
    '🙂‍↕' => 'mengangguk kepala',
    '😵‍💫' => 'muka dengan mata berpusar',
    '❤‍🔥' => 'hati membara',
    '❤‍🩹' => 'hati sembuh',
    '👁‍🗨' => 'mata dalam gelembung pertuturan',
    '🧔‍♂' => 'lelaki: janggut',
    '👱‍♂' => 'lelaki: rambut perang',
    '🧔‍♀' => 'wanita: janggut',
    '👱‍♀' => 'perempuan: rambut perang',
    '🙍‍♂' => 'lelaki berkerut dahi',
    '🙍‍♀' => 'perempuan berkerut dahi',
    '🙎‍♂' => 'lelaki mencebik',
    '🙎‍♀' => 'perempuan mencebik',
    '🙅‍♂' => 'lelaki memberi isyarat tidak ok',
    '🙅‍♀' => 'perempuan memberi isyarat tidak ok',
    '🙆‍♂' => 'lelaki memberi isyarat ok',
    '🙆‍♀' => 'perempuan memberi isyarat ok',
    '💁‍♂' => 'lelaki menadah tangan',
    '💁‍♀' => 'perempuan menadah tangan',
    '🙋‍♂' => 'lelaki mengangkat tangan',
    '🙋‍♀' => 'perempuan mengangkat tangan',
    '🧏‍♂' => 'lelaki pekak',
    '🧏‍♀' => 'perempuan pekak',
    '🙇‍♂' => 'lelaki menunduk',
    '🙇‍♀' => 'perempuan menunduk',
    '🤦‍♂' => 'lelaki menepuk muka',
    '🤦‍♀' => 'perempuan menepuk muka',
    '🤷‍♂' => 'lelaki mengangkat bahu',
    '🤷‍♀' => 'perempuan mengangkat bahu',
    '🧑‍⚕' => 'pekerja kesihatan',
    '👨‍⚕' => 'pekerja kesihatan lelaki',
    '👩‍⚕' => 'pekerja kesihatan wanita',
    '🧑‍🎓' => 'pelajar',
    '👨‍🎓' => 'pelajar lelaki',
    '👩‍🎓' => 'pelajar wanita',
    '🧑‍🏫' => 'guru',
    '👨‍🏫' => 'guru lelaki',
    '👩‍🏫' => 'guru wanita',
    '🧑‍⚖' => 'hakim',
    '👨‍⚖' => 'hakim lelaki',
    '👩‍⚖' => 'hakim wanita',
    '🧑‍🌾' => 'petani',
    '👨‍🌾' => 'petani lelaki',
    '👩‍🌾' => 'petani wanita',
    '🧑‍🍳' => 'tukang masak',
    '👨‍🍳' => 'tukang masak lelaki',
    '👩‍🍳' => 'tukang masak wanita',
    '🧑‍🔧' => 'mekanik',
    '👨‍🔧' => 'mekanik lelaki',
    '👩‍🔧' => 'mekanik wanita',
    '🧑‍🏭' => 'pekerja kilang',
    '👨‍🏭' => 'pekerja kilang lelaki',
    '👩‍🏭' => 'pekerja kilang wanita',
    '🧑‍💼' => 'pekerja pejabat',
    '👨‍💼' => 'pekerja pejabat lelaki',
    '👩‍💼' => 'pekerja pejabat wanita',
    '🧑‍🔬' => 'saintis',
    '👨‍🔬' => 'saintis lelaki',
    '👩‍🔬' => 'saintis wanita',
    '🧑‍💻' => 'ahli teknologi',
    '👨‍💻' => 'ahli teknologi lelaki',
    '👩‍💻' => 'ahli teknologi wanita',
    '🧑‍🎤' => 'penyanyi',
    '👨‍🎤' => 'penyanyi lelaki',
    '👩‍🎤' => 'penyanyi wanita',
    '🧑‍🎨' => 'artis',
    '👨‍🎨' => 'pelukis lelaki',
    '👩‍🎨' => 'pelukis wanita',
    '🧑‍✈' => 'juruterbang',
    '👨‍✈' => 'juruterbang lelaki',
    '👩‍✈' => 'juruterbang wanita',
    '🧑‍🚀' => 'angkasawan',
    '👨‍🚀' => 'angkasawan lelaki',
    '👩‍🚀' => 'angkasawati',
    '🧑‍🚒' => 'ahli bomba',
    '👨‍🚒' => 'ahli bomba lelaki',
    '👩‍🚒' => 'ahli bomba wanita',
    '👮‍♂' => 'pegawai polis lelaki',
    '👮‍♀' => 'pegawai polis wanita',
    '🕵‍♂' => 'mata-mata gelap lelaki',
    '🕵‍♀' => 'mata-mata gelap wanita',
    '💂‍♂' => 'pengawal lelaki',
    '💂‍♀' => 'pengawal wanita',
    '👷‍♂' => 'pekerja pembinaan lelaki',
    '👷‍♀' => 'pekerja pembinaan wanita',
    '👳‍♂' => 'lelaki berserban',
    '👳‍♀' => 'wanita berserban',
    '🤵‍♂' => 'lelaki berpakaian tuksedo',
    '🤵‍♀' => 'wanita berpakaian tuksedo',
    '👰‍♂' => 'lelaki memakai vel',
    '👰‍♀' => 'wanita memakai vel',
    '👩‍🍼' => 'wanita menyusui bayi',
    '👨‍🍼' => 'lelaki menyusui bayi',
    '🧑‍🍼' => 'orang menyusui bayi',
    '🧑‍🎄' => 'orang claus',
    '🦸‍♂' => 'adi wira lelaki',
    '🦸‍♀' => 'adi wira wanita',
    '🦹‍♂' => 'ketua penjahat lelaki',
    '🦹‍♀' => 'ketua penjahat wanita',
    '🧙‍♂' => 'ahli sihir lelaki',
    '🧙‍♀' => 'ahli sihir wanita',
    '🧚‍♂' => 'pari-pari lelaki',
    '🧚‍♀' => 'pari-pari wanita',
    '🧛‍♂' => 'puntianak lelaki',
    '🧛‍♀' => 'puntianak wanita',
    '🧜‍♂' => 'duyung jantan',
    '🧜‍♀' => 'ikan duyung',
    '🧝‍♂' => 'orang halus lelaki',
    '🧝‍♀' => 'orang halus wanita',
    '🧞‍♂' => 'jin jantan',
    '🧞‍♀' => 'jin betina',
    '🧟‍♂' => 'zombi lelaki',
    '🧟‍♀' => 'zombi wanita',
    '💆‍♂' => 'lelaki diurut muka',
    '💆‍♀' => 'perempuan diurut muka',
    '💇‍♂' => 'lelaki digunting rambut',
    '💇‍♀' => 'perempuan digunting rambut',
    '🚶‍♂' => 'lelaki berjalan',
    '🚶‍♀' => 'perempuan berjalan',
    '🧍‍♂' => 'lelaki berdiri',
    '🧍‍♀' => 'perempuan berdiri',
    '🧎‍♂' => 'lelaki bersimpuh',
    '🧎‍♀' => 'perempuan bersimpuh',
    '🧑‍🦯' => 'orang dengan tongkat putih',
    '👨‍🦯' => 'lelaki dengan tongkat putih',
    '👩‍🦯' => 'perempuan dengan tongkat putih',
    '🧑‍🦼' => 'orang dalam kerusi roda bermotor',
    '👨‍🦼' => 'lelaki dalam kerusi roda bermotor',
    '👩‍🦼' => 'perempuan dalam kerusi roda bermotor',
    '🧑‍🦽' => 'orang dalam kerusi roda manual',
    '👨‍🦽' => 'lelaki dalam kerusi roda manual',
    '👩‍🦽' => 'perempuan dalam kereta roda manual',
    '🏃‍♂' => 'lelaki berlari',
    '🏃‍♀' => 'perempuan berlari',
    '🧑‍🩰' => 'penari balet',
    '👯‍♂' => 'lelaki berpesta',
    '👯‍♀' => 'perempuan berpesta',
    '🧖‍♂' => 'lelaki dalam bilik berwap',
    '🧖‍♀' => 'wanita dalam bilik berwap',
    '🧗‍♂' => 'lelaki mendaki',
    '🧗‍♀' => 'wanita mendaki',
    '🏌‍♂' => 'lelaki bermain golf',
    '🏌‍♀' => 'wanita bermain golf',
    '🏄‍♂' => 'lelaki meluncur air',
    '🏄‍♀' => 'wanita meluncur air',
    '🚣‍♂' => 'lelaki mendayung sampan',
    '🚣‍♀' => 'wanita mendayung sampan',
    '🏊‍♂' => 'lelaki berenang',
    '🏊‍♀' => 'wanita berenang',
    '⛹‍♂' => 'lelaki melantun bola',
    '⛹‍♀' => 'wanita melantun bola',
    '🏋‍♂' => 'lelaki mengangkat berat',
    '🏋‍♀' => 'wanita mengangkat berat',
    '🚴‍♂' => 'lelaki berbasikal',
    '🚴‍♀' => 'wanita berbasikal',
    '🚵‍♂' => 'lelaki berbasikal gunung',
    '🚵‍♀' => 'wanita berbasikal gunung',
    '🤸‍♂' => 'lelaki membuat putar roda',
    '🤸‍♀' => 'wanita membuat putar roda',
    '🤼‍♂' => 'lelaki bergusti',
    '🤼‍♀' => 'wanita bergusti',
    '🤽‍♂' => 'lelaki bermain polo air',
    '🤽‍♀' => 'wanita bermain polo air',
    '🤾‍♂' => 'lelaki bermain bola baling',
    '🤾‍♀' => 'wanita bermain bola baling',
    '🤹‍♂' => 'lelaki menjugel',
    '🤹‍♀' => 'wanita menjugel',
    '🧘‍♂' => 'lelaki duduk teratai',
    '🧘‍♀' => 'wanita duduk teratai',
    '🧑‍🧒' => 'keluarga: dewasa, kanak-kanak',
    '🐕‍🦺' => 'anjing khidmat',
    '🐈‍⬛' => 'kucing hitam',
    '🐻‍❄' => 'beruang kutub',
    '🐦‍⬛' => 'burung hitam',
    '🐦‍🔥' => 'burung phoenix',
    '🍋‍🟩' => 'limau nipis',
    '🍄‍🟫' => 'cendawan perang',
    '⛓‍💥' => 'rantai terputus',
    '🏳‍🌈' => 'bendera pelangi',
    '🏳‍⚧' => 'bendera biru,merah jambu, dan putih',
    '🏴‍☠' => 'bendera lanun',
    '👋🏻' => 'lambai tangan: ton kulit cerah',
    '👋🏼' => 'lambai tangan: ton kulit sederhana cerah',
    '👋🏽' => 'lambai tangan: ton kulit sederhana',
    '👋🏾' => 'lambai tangan: ton kulit sederhana gelap',
    '👋🏿' => 'lambai tangan: ton kulit gelap',
    '🤚🏻' => 'angkat belakang tapak tangan: ton kulit cerah',
    '🤚🏼' => 'angkat belakang tapak tangan: ton kulit sederhana cerah',
    '🤚🏽' => 'angkat belakang tapak tangan: ton kulit sederhana',
    '🤚🏾' => 'angkat belakang tapak tangan: ton kulit sederhana gelap',
    '🤚🏿' => 'angkat belakang tapak tangan: ton kulit gelap',
    '🖐🏻' => 'tangan dengan jari terkepak: ton kulit cerah',
    '🖐🏼' => 'tangan dengan jari terkepak: ton kulit sederhana cerah',
    '🖐🏽' => 'tangan dengan jari terkepak: ton kulit sederhana',
    '🖐🏾' => 'tangan dengan jari terkepak: ton kulit sederhana gelap',
    '🖐🏿' => 'tangan dengan jari terkepak: ton kulit gelap',
    '✋🏻' => 'angkat tangan: ton kulit cerah',
    '✋🏼' => 'angkat tangan: ton kulit sederhana cerah',
    '✋🏽' => 'angkat tangan: ton kulit sederhana',
    '✋🏾' => 'angkat tangan: ton kulit sederhana gelap',
    '✋🏿' => 'angkat tangan: ton kulit gelap',
    '🖖🏻' => 'tabik vulcan: ton kulit cerah',
    '🖖🏼' => 'tabik vulcan: ton kulit sederhana cerah',
    '🖖🏽' => 'tabik vulcan: ton kulit sederhana',
    '🖖🏾' => 'tabik vulcan: ton kulit sederhana gelap',
    '🖖🏿' => 'tabik vulcan: ton kulit gelap',
    '🫱🏻' => 'tangan kanan: ton kulit cerah',
    '🫱🏼' => 'tangan kanan: ton kulit sederhana cerah',
    '🫱🏽' => 'tangan kanan: ton kulit sederhana',
    '🫱🏾' => 'tangan kanan: ton kulit sederhana gelap',
    '🫱🏿' => 'tangan kanan: ton kulit gelap',
    '🫲🏻' => 'tangan kiri: ton kulit cerah',
    '🫲🏼' => 'tangan kiri: ton kulit sederhana cerah',
    '🫲🏽' => 'tangan kiri: ton kulit sederhana',
    '🫲🏾' => 'tangan kiri: ton kulit sederhana gelap',
    '🫲🏿' => 'tangan kiri: ton kulit gelap',
    '🫳🏻' => 'tapak tangan ke bawah: ton kulit cerah',
    '🫳🏼' => 'tapak tangan ke bawah: ton kulit sederhana cerah',
    '🫳🏽' => 'tapak tangan ke bawah: ton kulit sederhana',
    '🫳🏾' => 'tapak tangan ke bawah: ton kulit sederhana gelap',
    '🫳🏿' => 'tapak tangan ke bawah: ton kulit gelap',
    '🫴🏻' => 'tapak tangan ke atas: ton kulit cerah',
    '🫴🏼' => 'tapak tangan ke atas: ton kulit sederhana cerah',
    '🫴🏽' => 'tapak tangan ke atas: ton kulit sederhana',
    '🫴🏾' => 'tapak tangan ke atas: ton kulit sederhana gelap',
    '🫴🏿' => 'tapak tangan ke atas: ton kulit gelap',
    '🫷🏻' => 'tangan menolak ke arah kiri: ton kulit cerah',
    '🫷🏼' => 'tangan menolak ke arah kiri: ton kulit sederhana cerah',
    '🫷🏽' => 'tangan menolak ke arah kiri: ton kulit sederhana',
    '🫷🏾' => 'tangan menolak ke arah kiri: ton kulit sederhana gelap',
    '🫷🏿' => 'tangan menolak ke arah kiri: ton kulit gelap',
    '🫸🏻' => 'tangan menolak ke arah kanan: ton kulit cerah',
    '🫸🏼' => 'tangan menolak ke arah kanan: ton kulit sederhana cerah',
    '🫸🏽' => 'tangan menolak ke arah kanan: ton kulit sederhana',
    '🫸🏾' => 'tangan menolak ke arah kanan: ton kulit sederhana gelap',
    '🫸🏿' => 'tangan menolak ke arah kanan: ton kulit gelap',
    '👌🏻' => 'simbol OK: ton kulit cerah',
    '👌🏼' => 'simbol OK: ton kulit sederhana cerah',
    '👌🏽' => 'simbol OK: ton kulit sederhana',
    '👌🏾' => 'simbol OK: ton kulit sederhana gelap',
    '👌🏿' => 'simbol OK: ton kulit gelap',
    '🤌🏻' => 'jari mencubit: ton kulit cerah',
    '🤌🏼' => 'jari mencubit: ton kulit sederhana cerah',
    '🤌🏽' => 'jari mencubit: ton kulit sederhana',
    '🤌🏾' => 'jari mencubit: ton kulit sederhana gelap',
    '🤌🏿' => 'jari mencubit: ton kulit gelap',
    '🤏🏻' => 'tangan mencubit: ton kulit cerah',
    '🤏🏼' => 'tangan mencubit: ton kulit sederhana cerah',
    '🤏🏽' => 'tangan mencubit: ton kulit sederhana',
    '🤏🏾' => 'tangan mencubit: ton kulit sederhana gelap',
    '🤏🏿' => 'tangan mencubit: ton kulit gelap',
    '✌🏻' => 'simbol kemenangan: ton kulit cerah',
    '✌🏼' => 'simbol kemenangan: ton kulit sederhana cerah',
    '✌🏽' => 'simbol kemenangan: ton kulit sederhana',
    '✌🏾' => 'simbol kemenangan: ton kulit sederhana gelap',
    '✌🏿' => 'simbol kemenangan: ton kulit gelap',
    '🤞🏻' => 'silang jari: ton kulit cerah',
    '🤞🏼' => 'silang jari: ton kulit sederhana cerah',
    '🤞🏽' => 'silang jari: ton kulit sederhana',
    '🤞🏾' => 'silang jari: ton kulit sederhana gelap',
    '🤞🏿' => 'silang jari: ton kulit gelap',
    '🫰🏻' => 'tangan dengan jari telunjuk dan ibu jari bersilang: ton kulit cerah',
    '🫰🏼' => 'tangan dengan jari telunjuk dan ibu jari bersilang: ton kulit sederhana cerah',
    '🫰🏽' => 'tangan dengan jari telunjuk dan ibu jari bersilang: ton kulit sederhana',
    '🫰🏾' => 'tangan dengan jari telunjuk dan ibu jari bersilang: ton kulit sederhana gelap',
    '🫰🏿' => 'tangan dengan jari telunjuk dan ibu jari bersilang: ton kulit gelap',
    '🤟🏻' => 'gerak isyarat cinta kamu: ton kulit cerah',
    '🤟🏼' => 'gerak isyarat cinta kamu: ton kulit sederhana cerah',
    '🤟🏽' => 'gerak isyarat cinta kamu: ton kulit sederhana',
    '🤟🏾' => 'gerak isyarat cinta kamu: ton kulit sederhana gelap',
    '🤟🏿' => 'gerak isyarat cinta kamu: ton kulit gelap',
    '🤘🏻' => 'simbol tanduk: ton kulit cerah',
    '🤘🏼' => 'simbol tanduk: ton kulit sederhana cerah',
    '🤘🏽' => 'simbol tanduk: ton kulit sederhana',
    '🤘🏾' => 'simbol tanduk: ton kulit sederhana gelap',
    '🤘🏿' => 'simbol tanduk: ton kulit gelap',
    '🤙🏻' => 'telefon saya: ton kulit cerah',
    '🤙🏼' => 'telefon saya: ton kulit sederhana cerah',
    '🤙🏽' => 'telefon saya: ton kulit sederhana',
    '🤙🏾' => 'telefon saya: ton kulit sederhana gelap',
    '🤙🏿' => 'telefon saya: ton kulit gelap',
    '👈🏻' => 'jari telunjuk tunjuk kiri: ton kulit cerah',
    '👈🏼' => 'jari telunjuk tunjuk kiri: ton kulit sederhana cerah',
    '👈🏽' => 'jari telunjuk tunjuk kiri: ton kulit sederhana',
    '👈🏾' => 'jari telunjuk tunjuk kiri: ton kulit sederhana gelap',
    '👈🏿' => 'jari telunjuk tunjuk kiri: ton kulit gelap',
    '👉🏻' => 'jari telunjuk tunjuk kanan: ton kulit cerah',
    '👉🏼' => 'jari telunjuk tunjuk kanan: ton kulit sederhana cerah',
    '👉🏽' => 'jari telunjuk tunjuk kanan: ton kulit sederhana',
    '👉🏾' => 'jari telunjuk tunjuk kanan: ton kulit sederhana gelap',
    '👉🏿' => 'jari telunjuk tunjuk kanan: ton kulit gelap',
    '👆🏻' => 'jari telunjuk tunjuk hala ke atas: ton kulit cerah',
    '👆🏼' => 'jari telunjuk tunjuk hala ke atas: ton kulit sederhana cerah',
    '👆🏽' => 'jari telunjuk tunjuk hala ke atas: ton kulit sederhana',
    '👆🏾' => 'jari telunjuk tunjuk hala ke atas: ton kulit sederhana gelap',
    '👆🏿' => 'jari telunjuk tunjuk hala ke atas: ton kulit gelap',
    '🖕🏻' => 'jari hantu: ton kulit cerah',
    '🖕🏼' => 'jari hantu: ton kulit sederhana cerah',
    '🖕🏽' => 'jari hantu: ton kulit sederhana',
    '🖕🏾' => 'jari hantu: ton kulit sederhana gelap',
    '🖕🏿' => 'jari hantu: ton kulit gelap',
    '👇🏻' => 'jari telunjuk belakang tangan tuding ke bawah: ton kulit cerah',
    '👇🏼' => 'jari telunjuk belakang tangan tuding ke bawah: ton kulit sederhana cerah',
    '👇🏽' => 'jari telunjuk belakang tangan tuding ke bawah: ton kulit sederhana',
    '👇🏾' => 'jari telunjuk belakang tangan tuding ke bawah: ton kulit sederhana gelap',
    '👇🏿' => 'jari telunjuk belakang tangan tuding ke bawah: ton kulit gelap',
    '☝🏻' => 'jari telunjuk menunjuk ke atas: ton kulit cerah',
    '☝🏼' => 'jari telunjuk menunjuk ke atas: ton kulit sederhana cerah',
    '☝🏽' => 'jari telunjuk menunjuk ke atas: ton kulit sederhana',
    '☝🏾' => 'jari telunjuk menunjuk ke atas: ton kulit sederhana gelap',
    '☝🏿' => 'jari telunjuk menunjuk ke atas: ton kulit gelap',
    '🫵🏻' => 'jari telunjuk menunjuk ke arah pemandang: ton kulit cerah',
    '🫵🏼' => 'jari telunjuk menunjuk ke arah pemandang: ton kulit sederhana cerah',
    '🫵🏽' => 'jari telunjuk menunjuk ke arah pemandang: ton kulit sederhana',
    '🫵🏾' => 'jari telunjuk menunjuk ke arah pemandang: ton kulit sederhana gelap',
    '🫵🏿' => 'jari telunjuk menunjuk ke arah pemandang: ton kulit gelap',
    '👍🏻' => 'simbol bagus: ton kulit cerah',
    '👍🏼' => 'simbol bagus: ton kulit sederhana cerah',
    '👍🏽' => 'simbol bagus: ton kulit sederhana',
    '👍🏾' => 'simbol bagus: ton kulit sederhana gelap',
    '👍🏿' => 'simbol bagus: ton kulit gelap',
    '👎🏻' => 'simbol tidak bagus: ton kulit cerah',
    '👎🏼' => 'simbol tidak bagus: ton kulit sederhana cerah',
    '👎🏽' => 'simbol tidak bagus: ton kulit sederhana',
    '👎🏾' => 'simbol tidak bagus: ton kulit sederhana gelap',
    '👎🏿' => 'simbol tidak bagus: ton kulit gelap',
    '✊🏻' => 'angkat penumbuk: ton kulit cerah',
    '✊🏼' => 'angkat penumbuk: ton kulit sederhana cerah',
    '✊🏽' => 'angkat penumbuk: ton kulit sederhana',
    '✊🏾' => 'angkat penumbuk: ton kulit sederhana gelap',
    '✊🏿' => 'angkat penumbuk: ton kulit gelap',
    '👊🏻' => 'penumbuk dari depan: ton kulit cerah',
    '👊🏼' => 'penumbuk dari depan: ton kulit sederhana cerah',
    '👊🏽' => 'penumbuk dari depan: ton kulit sederhana',
    '👊🏾' => 'penumbuk dari depan: ton kulit sederhana gelap',
    '👊🏿' => 'penumbuk dari depan: ton kulit gelap',
    '🤛🏻' => 'penumbuk ke kiri: ton kulit cerah',
    '🤛🏼' => 'penumbuk ke kiri: ton kulit sederhana cerah',
    '🤛🏽' => 'penumbuk ke kiri: ton kulit sederhana',
    '🤛🏾' => 'penumbuk ke kiri: ton kulit sederhana gelap',
    '🤛🏿' => 'penumbuk ke kiri: ton kulit gelap',
    '🤜🏻' => 'penumbuk ke kanan: ton kulit cerah',
    '🤜🏼' => 'penumbuk ke kanan: ton kulit sederhana cerah',
    '🤜🏽' => 'penumbuk ke kanan: ton kulit sederhana',
    '🤜🏾' => 'penumbuk ke kanan: ton kulit sederhana gelap',
    '🤜🏿' => 'penumbuk ke kanan: ton kulit gelap',
    '👏🏻' => 'bertepuk tangan: ton kulit cerah',
    '👏🏼' => 'bertepuk tangan: ton kulit sederhana cerah',
    '👏🏽' => 'bertepuk tangan: ton kulit sederhana',
    '👏🏾' => 'bertepuk tangan: ton kulit sederhana gelap',
    '👏🏿' => 'bertepuk tangan: ton kulit gelap',
    '🙌🏻' => 'orang mengangkat tangan: ton kulit cerah',
    '🙌🏼' => 'orang mengangkat tangan: ton kulit sederhana cerah',
    '🙌🏽' => 'orang mengangkat tangan: ton kulit sederhana',
    '🙌🏾' => 'orang mengangkat tangan: ton kulit sederhana gelap',
    '🙌🏿' => 'orang mengangkat tangan: ton kulit gelap',
    '🫶🏻' => 'tangan berbentuk hati: ton kulit cerah',
    '🫶🏼' => 'tangan berbentuk hati: ton kulit sederhana cerah',
    '🫶🏽' => 'tangan berbentuk hati: ton kulit sederhana',
    '🫶🏾' => 'tangan berbentuk hati: ton kulit sederhana gelap',
    '🫶🏿' => 'tangan berbentuk hati: ton kulit gelap',
    '👐🏻' => 'tangan terbuka: ton kulit cerah',
    '👐🏼' => 'tangan terbuka: ton kulit sederhana cerah',
    '👐🏽' => 'tangan terbuka: ton kulit sederhana',
    '👐🏾' => 'tangan terbuka: ton kulit sederhana gelap',
    '👐🏿' => 'tangan terbuka: ton kulit gelap',
    '🤲🏻' => 'tapak tangan rapat: ton kulit cerah',
    '🤲🏼' => 'tapak tangan rapat: ton kulit sederhana cerah',
    '🤲🏽' => 'tapak tangan rapat: ton kulit sederhana',
    '🤲🏾' => 'tapak tangan rapat: ton kulit sederhana gelap',
    '🤲🏿' => 'tapak tangan rapat: ton kulit gelap',
    '🤝🏻' => 'berjabat tangan: ton kulit cerah',
    '🤝🏼' => 'berjabat tangan: ton kulit sederhana cerah',
    '🤝🏽' => 'berjabat tangan: ton kulit sederhana',
    '🤝🏾' => 'berjabat tangan: ton kulit sederhana gelap',
    '🤝🏿' => 'berjabat tangan: ton kulit gelap',
    '🙏🏻' => 'menyusun jari: ton kulit cerah',
    '🙏🏼' => 'menyusun jari: ton kulit sederhana cerah',
    '🙏🏽' => 'menyusun jari: ton kulit sederhana',
    '🙏🏾' => 'menyusun jari: ton kulit sederhana gelap',
    '🙏🏿' => 'menyusun jari: ton kulit gelap',
    '✍🏻' => 'tangan menulis: ton kulit cerah',
    '✍🏼' => 'tangan menulis: ton kulit sederhana cerah',
    '✍🏽' => 'tangan menulis: ton kulit sederhana',
    '✍🏾' => 'tangan menulis: ton kulit sederhana gelap',
    '✍🏿' => 'tangan menulis: ton kulit gelap',
    '💅🏻' => 'pengilat kuku: ton kulit cerah',
    '💅🏼' => 'pengilat kuku: ton kulit sederhana cerah',
    '💅🏽' => 'pengilat kuku: ton kulit sederhana',
    '💅🏾' => 'pengilat kuku: ton kulit sederhana gelap',
    '💅🏿' => 'pengilat kuku: ton kulit gelap',
    '🤳🏻' => 'swafoto: ton kulit cerah',
    '🤳🏼' => 'swafoto: ton kulit sederhana cerah',
    '🤳🏽' => 'swafoto: ton kulit sederhana',
    '🤳🏾' => 'swafoto: ton kulit sederhana gelap',
    '🤳🏿' => 'swafoto: ton kulit gelap',
    '💪🏻' => 'biseps dilenturtegang: ton kulit cerah',
    '💪🏼' => 'biseps dilenturtegang: ton kulit sederhana cerah',
    '💪🏽' => 'biseps dilenturtegang: ton kulit sederhana',
    '💪🏾' => 'biseps dilenturtegang: ton kulit sederhana gelap',
    '💪🏿' => 'biseps dilenturtegang: ton kulit gelap',
    '🦵🏻' => 'kaki: ton kulit cerah',
    '🦵🏼' => 'kaki: ton kulit sederhana cerah',
    '🦵🏽' => 'kaki: ton kulit sederhana',
    '🦵🏾' => 'kaki: ton kulit sederhana gelap',
    '🦵🏿' => 'kaki: ton kulit gelap',
    '🦶🏻' => 'hujung kaki: ton kulit cerah',
    '🦶🏼' => 'hujung kaki: ton kulit sederhana cerah',
    '🦶🏽' => 'hujung kaki: ton kulit sederhana',
    '🦶🏾' => 'hujung kaki: ton kulit sederhana gelap',
    '🦶🏿' => 'hujung kaki: ton kulit gelap',
    '👂🏻' => 'telinga: ton kulit cerah',
    '👂🏼' => 'telinga: ton kulit sederhana cerah',
    '👂🏽' => 'telinga: ton kulit sederhana',
    '👂🏾' => 'telinga: ton kulit sederhana gelap',
    '👂🏿' => 'telinga: ton kulit gelap',
    '🦻🏻' => 'telinga dengan alat bantu dengar: ton kulit cerah',
    '🦻🏼' => 'telinga dengan alat bantu dengar: ton kulit sederhana cerah',
    '🦻🏽' => 'telinga dengan alat bantu dengar: ton kulit sederhana',
    '🦻🏾' => 'telinga dengan alat bantu dengar: ton kulit sederhana gelap',
    '🦻🏿' => 'telinga dengan alat bantu dengar: ton kulit gelap',
    '👃🏻' => 'hidung: ton kulit cerah',
    '👃🏼' => 'hidung: ton kulit sederhana cerah',
    '👃🏽' => 'hidung: ton kulit sederhana',
    '👃🏾' => 'hidung: ton kulit sederhana gelap',
    '👃🏿' => 'hidung: ton kulit gelap',
    '👶🏻' => 'bayi: ton kulit cerah',
    '👶🏼' => 'bayi: ton kulit sederhana cerah',
    '👶🏽' => 'bayi: ton kulit sederhana',
    '👶🏾' => 'bayi: ton kulit sederhana gelap',
    '👶🏿' => 'bayi: ton kulit gelap',
    '🧒🏻' => 'kanak-kanak: ton kulit cerah',
    '🧒🏼' => 'kanak-kanak: ton kulit sederhana cerah',
    '🧒🏽' => 'kanak-kanak: ton kulit sederhana',
    '🧒🏾' => 'kanak-kanak: ton kulit sederhana gelap',
    '🧒🏿' => 'kanak-kanak: ton kulit gelap',
    '👦🏻' => 'kanak-kanak lelaki: ton kulit cerah',
    '👦🏼' => 'kanak-kanak lelaki: ton kulit sederhana cerah',
    '👦🏽' => 'kanak-kanak lelaki: ton kulit sederhana',
    '👦🏾' => 'kanak-kanak lelaki: ton kulit sederhana gelap',
    '👦🏿' => 'kanak-kanak lelaki: ton kulit gelap',
    '👧🏻' => 'budak perempuan: ton kulit cerah',
    '👧🏼' => 'budak perempuan: ton kulit sederhana cerah',
    '👧🏽' => 'budak perempuan: ton kulit sederhana',
    '👧🏾' => 'budak perempuan: ton kulit sederhana gelap',
    '👧🏿' => 'budak perempuan: ton kulit gelap',
    '🧑🏻' => 'dewasa: ton kulit cerah',
    '🧑🏼' => 'dewasa: ton kulit sederhana cerah',
    '🧑🏽' => 'dewasa: ton kulit sederhana',
    '🧑🏾' => 'dewasa: ton kulit sederhana gelap',
    '🧑🏿' => 'dewasa: ton kulit gelap',
    '👱🏻' => 'orang: ton kulit cerah dan rambut perang',
    '👱🏼' => 'orang: ton kulit sederhana cerah dan rambut perang',
    '👱🏽' => 'orang: ton kulit sederhana dan rambut perang',
    '👱🏾' => 'orang: ton kulit sederhana gelap dan rambut perang',
    '👱🏿' => 'orang: ton kulit gelap dan rambut perang',
    '👨🏻' => 'lelaki: ton kulit cerah',
    '👨🏼' => 'lelaki: ton kulit sederhana cerah',
    '👨🏽' => 'lelaki: ton kulit sederhana',
    '👨🏾' => 'lelaki: ton kulit sederhana gelap',
    '👨🏿' => 'lelaki: ton kulit gelap',
    '🧔🏻' => 'orang: ton kulit cerah dan janggut',
    '🧔🏼' => 'orang: ton kulit sederhana cerah dan janggut',
    '🧔🏽' => 'orang: ton kulit sederhana dan janggut',
    '🧔🏾' => 'orang: ton kulit sederhana gelap dan janggut',
    '🧔🏿' => 'orang: ton kulit gelap dan janggut',
    '👩🏻' => 'perempuan: ton kulit cerah',
    '👩🏼' => 'perempuan: ton kulit sederhana cerah',
    '👩🏽' => 'perempuan: ton kulit sederhana',
    '👩🏾' => 'perempuan: ton kulit sederhana gelap',
    '👩🏿' => 'perempuan: ton kulit gelap',
    '🧓🏻' => 'dewasa lebih tua: ton kulit cerah',
    '🧓🏼' => 'dewasa lebih tua: ton kulit sederhana cerah',
    '🧓🏽' => 'dewasa lebih tua: ton kulit sederhana',
    '🧓🏾' => 'dewasa lebih tua: ton kulit sederhana gelap',
    '🧓🏿' => 'dewasa lebih tua: ton kulit gelap',
    '👴🏻' => 'lelaki tua: ton kulit cerah',
    '👴🏼' => 'lelaki tua: ton kulit sederhana cerah',
    '👴🏽' => 'lelaki tua: ton kulit sederhana',
    '👴🏾' => 'lelaki tua: ton kulit sederhana gelap',
    '👴🏿' => 'lelaki tua: ton kulit gelap',
    '👵🏻' => 'wanita tua: ton kulit cerah',
    '👵🏼' => 'wanita tua: ton kulit sederhana cerah',
    '👵🏽' => 'wanita tua: ton kulit sederhana',
    '👵🏾' => 'wanita tua: ton kulit sederhana gelap',
    '👵🏿' => 'wanita tua: ton kulit gelap',
    '🙍🏻' => 'orang berkerut dahi: ton kulit cerah',
    '🙍🏼' => 'orang berkerut dahi: ton kulit sederhana cerah',
    '🙍🏽' => 'orang berkerut dahi: ton kulit sederhana',
    '🙍🏾' => 'orang berkerut dahi: ton kulit sederhana gelap',
    '🙍🏿' => 'orang berkerut dahi: ton kulit gelap',
    '🙎🏻' => 'orang mencebik: ton kulit cerah',
    '🙎🏼' => 'orang mencebik: ton kulit sederhana cerah',
    '🙎🏽' => 'orang mencebik: ton kulit sederhana',
    '🙎🏾' => 'orang mencebik: ton kulit sederhana gelap',
    '🙎🏿' => 'orang mencebik: ton kulit gelap',
    '🙅🏻' => 'gerak isyarat tidak: ton kulit cerah',
    '🙅🏼' => 'gerak isyarat tidak: ton kulit sederhana cerah',
    '🙅🏽' => 'gerak isyarat tidak: ton kulit sederhana',
    '🙅🏾' => 'gerak isyarat tidak: ton kulit sederhana gelap',
    '🙅🏿' => 'gerak isyarat tidak: ton kulit gelap',
    '🙆🏻' => 'gerak isyarat okey: ton kulit cerah',
    '🙆🏼' => 'gerak isyarat okey: ton kulit sederhana cerah',
    '🙆🏽' => 'gerak isyarat okey: ton kulit sederhana',
    '🙆🏾' => 'gerak isyarat okey: ton kulit sederhana gelap',
    '🙆🏿' => 'gerak isyarat okey: ton kulit gelap',
    '💁🏻' => 'pegawai kaunter pertanyaan: ton kulit cerah',
    '💁🏼' => 'pegawai kaunter pertanyaan: ton kulit sederhana cerah',
    '💁🏽' => 'pegawai kaunter pertanyaan: ton kulit sederhana',
    '💁🏾' => 'pegawai kaunter pertanyaan: ton kulit sederhana gelap',
    '💁🏿' => 'pegawai kaunter pertanyaan: ton kulit gelap',
    '🙋🏻' => 'orang gembira mengangkat tangan: ton kulit cerah',
    '🙋🏼' => 'orang gembira mengangkat tangan: ton kulit sederhana cerah',
    '🙋🏽' => 'orang gembira mengangkat tangan: ton kulit sederhana',
    '🙋🏾' => 'orang gembira mengangkat tangan: ton kulit sederhana gelap',
    '🙋🏿' => 'orang gembira mengangkat tangan: ton kulit gelap',
    '🧏🏻' => 'orang pekak: ton kulit cerah',
    '🧏🏼' => 'orang pekak: ton kulit sederhana cerah',
    '🧏🏽' => 'orang pekak: ton kulit sederhana',
    '🧏🏾' => 'orang pekak: ton kulit sederhana gelap',
    '🧏🏿' => 'orang pekak: ton kulit gelap',
    '🙇🏻' => 'orang menunduk: ton kulit cerah',
    '🙇🏼' => 'orang menunduk: ton kulit sederhana cerah',
    '🙇🏽' => 'orang menunduk: ton kulit sederhana',
    '🙇🏾' => 'orang menunduk: ton kulit sederhana gelap',
    '🙇🏿' => 'orang menunduk: ton kulit gelap',
    '🤦🏻' => 'tepuk dahi: ton kulit cerah',
    '🤦🏼' => 'tepuk dahi: ton kulit sederhana cerah',
    '🤦🏽' => 'tepuk dahi: ton kulit sederhana',
    '🤦🏾' => 'tepuk dahi: ton kulit sederhana gelap',
    '🤦🏿' => 'tepuk dahi: ton kulit gelap',
    '🤷🏻' => 'angkat bahu: ton kulit cerah',
    '🤷🏼' => 'angkat bahu: ton kulit sederhana cerah',
    '🤷🏽' => 'angkat bahu: ton kulit sederhana',
    '🤷🏾' => 'angkat bahu: ton kulit sederhana gelap',
    '🤷🏿' => 'angkat bahu: ton kulit gelap',
    '👮🏻' => 'pegawai polis: ton kulit cerah',
    '👮🏼' => 'pegawai polis: ton kulit sederhana cerah',
    '👮🏽' => 'pegawai polis: ton kulit sederhana',
    '👮🏾' => 'pegawai polis: ton kulit sederhana gelap',
    '👮🏿' => 'pegawai polis: ton kulit gelap',
    '🕵🏻' => 'detektif: ton kulit cerah',
    '🕵🏼' => 'detektif: ton kulit sederhana cerah',
    '🕵🏽' => 'detektif: ton kulit sederhana',
    '🕵🏾' => 'detektif: ton kulit sederhana gelap',
    '🕵🏿' => 'detektif: ton kulit gelap',
    '💂🏻' => 'pengawal: ton kulit cerah',
    '💂🏼' => 'pengawal: ton kulit sederhana cerah',
    '💂🏽' => 'pengawal: ton kulit sederhana',
    '💂🏾' => 'pengawal: ton kulit sederhana gelap',
    '💂🏿' => 'pengawal: ton kulit gelap',
    '🥷🏻' => 'ninja: ton kulit cerah',
    '🥷🏼' => 'ninja: ton kulit sederhana cerah',
    '🥷🏽' => 'ninja: ton kulit sederhana',
    '🥷🏾' => 'ninja: ton kulit sederhana gelap',
    '🥷🏿' => 'ninja: ton kulit gelap',
    '👷🏻' => 'pekerja pembinaan: ton kulit cerah',
    '👷🏼' => 'pekerja pembinaan: ton kulit sederhana cerah',
    '👷🏽' => 'pekerja pembinaan: ton kulit sederhana',
    '👷🏾' => 'pekerja pembinaan: ton kulit sederhana gelap',
    '👷🏿' => 'pekerja pembinaan: ton kulit gelap',
    '🫅🏻' => 'orang memakai mahkota: ton kulit cerah',
    '🫅🏼' => 'orang memakai mahkota: ton kulit sederhana cerah',
    '🫅🏽' => 'orang memakai mahkota: ton kulit sederhana',
    '🫅🏾' => 'orang memakai mahkota: ton kulit sederhana gelap',
    '🫅🏿' => 'orang memakai mahkota: ton kulit gelap',
    '🤴🏻' => 'putera: ton kulit cerah',
    '🤴🏼' => 'putera: ton kulit sederhana cerah',
    '🤴🏽' => 'putera: ton kulit sederhana',
    '🤴🏾' => 'putera: ton kulit sederhana gelap',
    '🤴🏿' => 'putera: ton kulit gelap',
    '👸🏻' => 'puteri: ton kulit cerah',
    '👸🏼' => 'puteri: ton kulit sederhana cerah',
    '👸🏽' => 'puteri: ton kulit sederhana',
    '👸🏾' => 'puteri: ton kulit sederhana gelap',
    '👸🏿' => 'puteri: ton kulit gelap',
    '👳🏻' => 'orang berserban: ton kulit cerah',
    '👳🏼' => 'orang berserban: ton kulit sederhana cerah',
    '👳🏽' => 'orang berserban: ton kulit sederhana',
    '👳🏾' => 'orang berserban: ton kulit sederhana gelap',
    '👳🏿' => 'orang berserban: ton kulit gelap',
    '👲🏻' => 'lelaki bertopi cina: ton kulit cerah',
    '👲🏼' => 'lelaki bertopi cina: ton kulit sederhana cerah',
    '👲🏽' => 'lelaki bertopi cina: ton kulit sederhana',
    '👲🏾' => 'lelaki bertopi cina: ton kulit sederhana gelap',
    '👲🏿' => 'lelaki bertopi cina: ton kulit gelap',
    '🧕🏻' => 'wanita bertudung: ton kulit cerah',
    '🧕🏼' => 'wanita bertudung: ton kulit sederhana cerah',
    '🧕🏽' => 'wanita bertudung: ton kulit sederhana',
    '🧕🏾' => 'wanita bertudung: ton kulit sederhana gelap',
    '🧕🏿' => 'wanita bertudung: ton kulit gelap',
    '🤵🏻' => 'orang bertuksedo: ton kulit cerah',
    '🤵🏼' => 'orang bertuksedo: ton kulit sederhana cerah',
    '🤵🏽' => 'orang bertuksedo: ton kulit sederhana',
    '🤵🏾' => 'orang bertuksedo: ton kulit sederhana gelap',
    '🤵🏿' => 'orang bertuksedo: ton kulit gelap',
    '👰🏻' => 'orang memakai vel: ton kulit cerah',
    '👰🏼' => 'orang memakai vel: ton kulit sederhana cerah',
    '👰🏽' => 'orang memakai vel: ton kulit sederhana',
    '👰🏾' => 'orang memakai vel: ton kulit sederhana gelap',
    '👰🏿' => 'orang memakai vel: ton kulit gelap',
    '🤰🏻' => 'wanita hamil: ton kulit cerah',
    '🤰🏼' => 'wanita hamil: ton kulit sederhana cerah',
    '🤰🏽' => 'wanita hamil: ton kulit sederhana',
    '🤰🏾' => 'wanita hamil: ton kulit sederhana gelap',
    '🤰🏿' => 'wanita hamil: ton kulit gelap',
    '🫃🏻' => 'lelaki bunting: ton kulit cerah',
    '🫃🏼' => 'lelaki bunting: ton kulit sederhana cerah',
    '🫃🏽' => 'lelaki bunting: ton kulit sederhana',
    '🫃🏾' => 'lelaki bunting: ton kulit sederhana gelap',
    '🫃🏿' => 'lelaki bunting: ton kulit gelap',
    '🫄🏻' => 'orang hamil: ton kulit cerah',
    '🫄🏼' => 'orang hamil: ton kulit sederhana cerah',
    '🫄🏽' => 'orang hamil: ton kulit sederhana',
    '🫄🏾' => 'orang hamil: ton kulit sederhana gelap',
    '🫄🏿' => 'orang hamil: ton kulit gelap',
    '🤱🏻' => 'menyusu badan: ton kulit cerah',
    '🤱🏼' => 'menyusu badan: ton kulit sederhana cerah',
    '🤱🏽' => 'menyusu badan: ton kulit sederhana',
    '🤱🏾' => 'menyusu badan: ton kulit sederhana gelap',
    '🤱🏿' => 'menyusu badan: ton kulit gelap',
    '👼🏻' => 'pari-pari bayi: ton kulit cerah',
    '👼🏼' => 'pari-pari bayi: ton kulit sederhana cerah',
    '👼🏽' => 'pari-pari bayi: ton kulit sederhana',
    '👼🏾' => 'pari-pari bayi: ton kulit sederhana gelap',
    '👼🏿' => 'pari-pari bayi: ton kulit gelap',
    '🎅🏻' => 'santa klaus: ton kulit cerah',
    '🎅🏼' => 'santa klaus: ton kulit sederhana cerah',
    '🎅🏽' => 'santa klaus: ton kulit sederhana',
    '🎅🏾' => 'santa klaus: ton kulit sederhana gelap',
    '🎅🏿' => 'santa klaus: ton kulit gelap',
    '🤶🏻' => 'Pn. Claus: ton kulit cerah',
    '🤶🏼' => 'Pn. Claus: ton kulit sederhana cerah',
    '🤶🏽' => 'Pn. Claus: ton kulit sederhana',
    '🤶🏾' => 'Pn. Claus: ton kulit sederhana gelap',
    '🤶🏿' => 'Pn. Claus: ton kulit gelap',
    '🦸🏻' => 'adiwira: ton kulit cerah',
    '🦸🏼' => 'adiwira: ton kulit sederhana cerah',
    '🦸🏽' => 'adiwira: ton kulit sederhana',
    '🦸🏾' => 'adiwira: ton kulit sederhana gelap',
    '🦸🏿' => 'adiwira: ton kulit gelap',
    '🦹🏻' => 'ketua penjahat: ton kulit cerah',
    '🦹🏼' => 'ketua penjahat: ton kulit sederhana cerah',
    '🦹🏽' => 'ketua penjahat: ton kulit sederhana',
    '🦹🏾' => 'ketua penjahat: ton kulit sederhana gelap',
    '🦹🏿' => 'ketua penjahat: ton kulit gelap',
    '🧙🏻' => 'ahli silap mata: ton kulit cerah',
    '🧙🏼' => 'ahli silap mata: ton kulit sederhana cerah',
    '🧙🏽' => 'ahli silap mata: ton kulit sederhana',
    '🧙🏾' => 'ahli silap mata: ton kulit sederhana gelap',
    '🧙🏿' => 'ahli silap mata: ton kulit gelap',
    '🧚🏻' => 'pari-pari: ton kulit cerah',
    '🧚🏼' => 'pari-pari: ton kulit sederhana cerah',
    '🧚🏽' => 'pari-pari: ton kulit sederhana',
    '🧚🏾' => 'pari-pari: ton kulit sederhana gelap',
    '🧚🏿' => 'pari-pari: ton kulit gelap',
    '🧛🏻' => 'puntianak: ton kulit cerah',
    '🧛🏼' => 'puntianak: ton kulit sederhana cerah',
    '🧛🏽' => 'puntianak: ton kulit sederhana',
    '🧛🏾' => 'puntianak: ton kulit sederhana gelap',
    '🧛🏿' => 'puntianak: ton kulit gelap',
    '🧜🏻' => 'manusia duyung: ton kulit cerah',
    '🧜🏼' => 'manusia duyung: ton kulit sederhana cerah',
    '🧜🏽' => 'manusia duyung: ton kulit sederhana',
    '🧜🏾' => 'manusia duyung: ton kulit sederhana gelap',
    '🧜🏿' => 'manusia duyung: ton kulit gelap',
    '🧝🏻' => 'orang halus: ton kulit cerah',
    '🧝🏼' => 'orang halus: ton kulit sederhana cerah',
    '🧝🏽' => 'orang halus: ton kulit sederhana',
    '🧝🏾' => 'orang halus: ton kulit sederhana gelap',
    '🧝🏿' => 'orang halus: ton kulit gelap',
    '💆🏻' => 'urut muka: ton kulit cerah',
    '💆🏼' => 'urut muka: ton kulit sederhana cerah',
    '💆🏽' => 'urut muka: ton kulit sederhana',
    '💆🏾' => 'urut muka: ton kulit sederhana gelap',
    '💆🏿' => 'urut muka: ton kulit gelap',
    '💇🏻' => 'gunting rambut: ton kulit cerah',
    '💇🏼' => 'gunting rambut: ton kulit sederhana cerah',
    '💇🏽' => 'gunting rambut: ton kulit sederhana',
    '💇🏾' => 'gunting rambut: ton kulit sederhana gelap',
    '💇🏿' => 'gunting rambut: ton kulit gelap',
    '🚶🏻' => 'pejalan kaki: ton kulit cerah',
    '🚶🏼' => 'pejalan kaki: ton kulit sederhana cerah',
    '🚶🏽' => 'pejalan kaki: ton kulit sederhana',
    '🚶🏾' => 'pejalan kaki: ton kulit sederhana gelap',
    '🚶🏿' => 'pejalan kaki: ton kulit gelap',
    '🧍🏻' => 'orang berdiri: ton kulit cerah',
    '🧍🏼' => 'orang berdiri: ton kulit sederhana cerah',
    '🧍🏽' => 'orang berdiri: ton kulit sederhana',
    '🧍🏾' => 'orang berdiri: ton kulit sederhana gelap',
    '🧍🏿' => 'orang berdiri: ton kulit gelap',
    '🧎🏻' => 'orang bersimpuh: ton kulit cerah',
    '🧎🏼' => 'orang bersimpuh: ton kulit sederhana cerah',
    '🧎🏽' => 'orang bersimpuh: ton kulit sederhana',
    '🧎🏾' => 'orang bersimpuh: ton kulit sederhana gelap',
    '🧎🏿' => 'orang bersimpuh: ton kulit gelap',
    '🏃🏻' => 'pelari: ton kulit cerah',
    '🏃🏼' => 'pelari: ton kulit sederhana cerah',
    '🏃🏽' => 'pelari: ton kulit sederhana',
    '🏃🏾' => 'pelari: ton kulit sederhana gelap',
    '🏃🏿' => 'pelari: ton kulit gelap',
    '💃🏻' => 'perempuan menari: ton kulit cerah',
    '💃🏼' => 'perempuan menari: ton kulit sederhana cerah',
    '💃🏽' => 'perempuan menari: ton kulit sederhana',
    '💃🏾' => 'perempuan menari: ton kulit sederhana gelap',
    '💃🏿' => 'perempuan menari: ton kulit gelap',
    '🕺🏻' => 'lelaki menari: ton kulit cerah',
    '🕺🏼' => 'lelaki menari: ton kulit sederhana cerah',
    '🕺🏽' => 'lelaki menari: ton kulit sederhana',
    '🕺🏾' => 'lelaki menari: ton kulit sederhana gelap',
    '🕺🏿' => 'lelaki menari: ton kulit gelap',
    '🕴🏻' => 'lelaki memakai sut urusan terapung-apung: ton kulit cerah',
    '🕴🏼' => 'lelaki memakai sut urusan terapung-apung: ton kulit sederhana cerah',
    '🕴🏽' => 'lelaki memakai sut urusan terapung-apung: ton kulit sederhana',
    '🕴🏾' => 'lelaki memakai sut urusan terapung-apung: ton kulit sederhana gelap',
    '🕴🏿' => 'lelaki memakai sut urusan terapung-apung: ton kulit gelap',
    '👯🏻' => 'orang dengan telinga arnab: ton kulit cerah',
    '👯🏼' => 'orang dengan telinga arnab: ton kulit sederhana cerah',
    '👯🏽' => 'orang dengan telinga arnab: ton kulit sederhana',
    '👯🏾' => 'orang dengan telinga arnab: ton kulit sederhana gelap',
    '👯🏿' => 'orang dengan telinga arnab: ton kulit gelap',
    '🧖🏻' => 'orang dalam bilik berwap: ton kulit cerah',
    '🧖🏼' => 'orang dalam bilik berwap: ton kulit sederhana cerah',
    '🧖🏽' => 'orang dalam bilik berwap: ton kulit sederhana',
    '🧖🏾' => 'orang dalam bilik berwap: ton kulit sederhana gelap',
    '🧖🏿' => 'orang dalam bilik berwap: ton kulit gelap',
    '🧗🏻' => 'orang mendaki: ton kulit cerah',
    '🧗🏼' => 'orang mendaki: ton kulit sederhana cerah',
    '🧗🏽' => 'orang mendaki: ton kulit sederhana',
    '🧗🏾' => 'orang mendaki: ton kulit sederhana gelap',
    '🧗🏿' => 'orang mendaki: ton kulit gelap',
    '🏇🏻' => 'lumba kuda: ton kulit cerah',
    '🏇🏼' => 'lumba kuda: ton kulit sederhana cerah',
    '🏇🏽' => 'lumba kuda: ton kulit sederhana',
    '🏇🏾' => 'lumba kuda: ton kulit sederhana gelap',
    '🏇🏿' => 'lumba kuda: ton kulit gelap',
    '🏂🏻' => 'peluncur papan salji: ton kulit cerah',
    '🏂🏼' => 'peluncur papan salji: ton kulit sederhana cerah',
    '🏂🏽' => 'peluncur papan salji: ton kulit sederhana',
    '🏂🏾' => 'peluncur papan salji: ton kulit sederhana gelap',
    '🏂🏿' => 'peluncur papan salji: ton kulit gelap',
    '🏌🏻' => 'pemain golf: ton kulit cerah',
    '🏌🏼' => 'pemain golf: ton kulit sederhana cerah',
    '🏌🏽' => 'pemain golf: ton kulit sederhana',
    '🏌🏾' => 'pemain golf: ton kulit sederhana gelap',
    '🏌🏿' => 'pemain golf: ton kulit gelap',
    '🏄🏻' => 'peluncur air: ton kulit cerah',
    '🏄🏼' => 'peluncur air: ton kulit sederhana cerah',
    '🏄🏽' => 'peluncur air: ton kulit sederhana',
    '🏄🏾' => 'peluncur air: ton kulit sederhana gelap',
    '🏄🏿' => 'peluncur air: ton kulit gelap',
    '🚣🏻' => 'orang mendayung sampan: ton kulit cerah',
    '🚣🏼' => 'orang mendayung sampan: ton kulit sederhana cerah',
    '🚣🏽' => 'orang mendayung sampan: ton kulit sederhana',
    '🚣🏾' => 'orang mendayung sampan: ton kulit sederhana gelap',
    '🚣🏿' => 'orang mendayung sampan: ton kulit gelap',
    '🏊🏻' => 'perenang: ton kulit cerah',
    '🏊🏼' => 'perenang: ton kulit sederhana cerah',
    '🏊🏽' => 'perenang: ton kulit sederhana',
    '🏊🏾' => 'perenang: ton kulit sederhana gelap',
    '🏊🏿' => 'perenang: ton kulit gelap',
    '⛹🏻' => 'orang melantun bola: ton kulit cerah',
    '⛹🏼' => 'orang melantun bola: ton kulit sederhana cerah',
    '⛹🏽' => 'orang melantun bola: ton kulit sederhana',
    '⛹🏾' => 'orang melantun bola: ton kulit sederhana gelap',
    '⛹🏿' => 'orang melantun bola: ton kulit gelap',
    '🏋🏻' => 'ahli angkat berat: ton kulit cerah',
    '🏋🏼' => 'ahli angkat berat: ton kulit sederhana cerah',
    '🏋🏽' => 'ahli angkat berat: ton kulit sederhana',
    '🏋🏾' => 'ahli angkat berat: ton kulit sederhana gelap',
    '🏋🏿' => 'ahli angkat berat: ton kulit gelap',
    '🚴🏻' => 'menunggang basikal: ton kulit cerah',
    '🚴🏼' => 'menunggang basikal: ton kulit sederhana cerah',
    '🚴🏽' => 'menunggang basikal: ton kulit sederhana',
    '🚴🏾' => 'menunggang basikal: ton kulit sederhana gelap',
    '🚴🏿' => 'menunggang basikal: ton kulit gelap',
    '🚵🏻' => 'penunggang basikal bukit: ton kulit cerah',
    '🚵🏼' => 'penunggang basikal bukit: ton kulit sederhana cerah',
    '🚵🏽' => 'penunggang basikal bukit: ton kulit sederhana',
    '🚵🏾' => 'penunggang basikal bukit: ton kulit sederhana gelap',
    '🚵🏿' => 'penunggang basikal bukit: ton kulit gelap',
    '🤸🏻' => 'putar roda: ton kulit cerah',
    '🤸🏼' => 'putar roda: ton kulit sederhana cerah',
    '🤸🏽' => 'putar roda: ton kulit sederhana',
    '🤸🏾' => 'putar roda: ton kulit sederhana gelap',
    '🤸🏿' => 'putar roda: ton kulit gelap',
    '🤼🏻' => 'bergusti: ton kulit cerah',
    '🤼🏼' => 'bergusti: ton kulit sederhana cerah',
    '🤼🏽' => 'bergusti: ton kulit sederhana',
    '🤼🏾' => 'bergusti: ton kulit sederhana gelap',
    '🤼🏿' => 'bergusti: ton kulit gelap',
    '🤽🏻' => 'polo air: ton kulit cerah',
    '🤽🏼' => 'polo air: ton kulit sederhana cerah',
    '🤽🏽' => 'polo air: ton kulit sederhana',
    '🤽🏾' => 'polo air: ton kulit sederhana gelap',
    '🤽🏿' => 'polo air: ton kulit gelap',
    '🤾🏻' => 'main bola baling: ton kulit cerah',
    '🤾🏼' => 'main bola baling: ton kulit sederhana cerah',
    '🤾🏽' => 'main bola baling: ton kulit sederhana',
    '🤾🏾' => 'main bola baling: ton kulit sederhana gelap',
    '🤾🏿' => 'main bola baling: ton kulit gelap',
    '🤹🏻' => 'menjugel: ton kulit cerah',
    '🤹🏼' => 'menjugel: ton kulit sederhana cerah',
    '🤹🏽' => 'menjugel: ton kulit sederhana',
    '🤹🏾' => 'menjugel: ton kulit sederhana gelap',
    '🤹🏿' => 'menjugel: ton kulit gelap',
    '🧘🏻' => 'orang dalam kedudukan teratai: ton kulit cerah',
    '🧘🏼' => 'orang dalam kedudukan teratai: ton kulit sederhana cerah',
    '🧘🏽' => 'orang dalam kedudukan teratai: ton kulit sederhana',
    '🧘🏾' => 'orang dalam kedudukan teratai: ton kulit sederhana gelap',
    '🧘🏿' => 'orang dalam kedudukan teratai: ton kulit gelap',
    '🛀🏻' => 'orang sedang mandi: ton kulit cerah',
    '🛀🏼' => 'orang sedang mandi: ton kulit sederhana cerah',
    '🛀🏽' => 'orang sedang mandi: ton kulit sederhana',
    '🛀🏾' => 'orang sedang mandi: ton kulit sederhana gelap',
    '🛀🏿' => 'orang sedang mandi: ton kulit gelap',
    '🛌🏻' => 'orang tidur atas katil: ton kulit cerah',
    '🛌🏼' => 'orang tidur atas katil: ton kulit sederhana cerah',
    '🛌🏽' => 'orang tidur atas katil: ton kulit sederhana',
    '🛌🏾' => 'orang tidur atas katil: ton kulit sederhana gelap',
    '🛌🏿' => 'orang tidur atas katil: ton kulit gelap',
    '👭🏻' => 'dua wanita berpegangan tangan: ton kulit cerah',
    '👭🏼' => 'dua wanita berpegangan tangan: ton kulit sederhana cerah',
    '👭🏽' => 'dua wanita berpegangan tangan: ton kulit sederhana',
    '👭🏾' => 'dua wanita berpegangan tangan: ton kulit sederhana gelap',
    '👭🏿' => 'dua wanita berpegangan tangan: ton kulit gelap',
    '👫🏻' => 'lelaki dan wanita berpegangan tangan: ton kulit cerah',
    '👫🏼' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana cerah',
    '👫🏽' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana',
    '👫🏾' => 'lelaki dan wanita berpegangan tangan: ton kulit sederhana gelap',
    '👫🏿' => 'lelaki dan wanita berpegangan tangan: ton kulit gelap',
    '👬🏻' => 'dua lelaki berpegangan tangan: ton kulit cerah',
    '👬🏼' => 'dua lelaki berpegangan tangan: ton kulit sederhana cerah',
    '👬🏽' => 'dua lelaki berpegangan tangan: ton kulit sederhana',
    '👬🏾' => 'dua lelaki berpegangan tangan: ton kulit sederhana gelap',
    '👬🏿' => 'dua lelaki berpegangan tangan: ton kulit gelap',
    '💏🏻' => 'cium: ton kulit cerah',
    '💏🏼' => 'cium: ton kulit sederhana cerah',
    '💏🏽' => 'cium: ton kulit sederhana',
    '💏🏾' => 'cium: ton kulit sederhana gelap',
    '💏🏿' => 'cium: ton kulit gelap',
    '💑🏻' => 'pasangan dengan simbol hati: ton kulit cerah',
    '💑🏼' => 'pasangan dengan simbol hati: ton kulit sederhana cerah',
    '💑🏽' => 'pasangan dengan simbol hati: ton kulit sederhana',
    '💑🏾' => 'pasangan dengan simbol hati: ton kulit sederhana gelap',
    '💑🏿' => 'pasangan dengan simbol hati: ton kulit gelap',
    '🇦🇨' => 'bendera: Pulau Ascension',
    '🇦🇩' => 'bendera: Andorra',
    '🇦🇪' => 'bendera: Emiriah Arab Bersatu',
    '🇦🇫' => 'bendera: Afghanistan',
    '🇦🇬' => 'bendera: Antigua dan Barbuda',
    '🇦🇮' => 'bendera: Anguilla',
    '🇦🇱' => 'bendera: Albania',
    '🇦🇲' => 'bendera: Armenia',
    '🇦🇴' => 'bendera: Angola',
    '🇦🇶' => 'bendera: Antartika',
    '🇦🇷' => 'bendera: Argentina',
    '🇦🇸' => 'bendera: Samoa Amerika',
    '🇦🇹' => 'bendera: Austria',
    '🇦🇺' => 'bendera: Australia',
    '🇦🇼' => 'bendera: Aruba',
    '🇦🇽' => 'bendera: Kepulauan Aland',
    '🇦🇿' => 'bendera: Azerbaijan',
    '🇧🇦' => 'bendera: Bosnia dan Herzegovina',
    '🇧🇧' => 'bendera: Barbados',
    '🇧🇩' => 'bendera: Bangladesh',
    '🇧🇪' => 'bendera: Belgium',
    '🇧🇫' => 'bendera: Burkina Faso',
    '🇧🇬' => 'bendera: Bulgaria',
    '🇧🇭' => 'bendera: Bahrain',
    '🇧🇮' => 'bendera: Burundi',
    '🇧🇯' => 'bendera: Benin',
    '🇧🇱' => 'bendera: St. Barthelemy',
    '🇧🇲' => 'bendera: Bermuda',
    '🇧🇳' => 'bendera: Brunei',
    '🇧🇴' => 'bendera: Bolivia',
    '🇧🇶' => 'bendera: Belanda Caribbean',
    '🇧🇷' => 'bendera: Brazil',
    '🇧🇸' => 'bendera: Bahamas',
    '🇧🇹' => 'bendera: Bhutan',
    '🇧🇻' => 'bendera: Pulau Bouvet',
    '🇧🇼' => 'bendera: Botswana',
    '🇧🇾' => 'bendera: Belarus',
    '🇧🇿' => 'bendera: Belize',
    '🇨🇦' => 'bendera: Kanada',
    '🇨🇨' => 'bendera: Kepulauan Cocos (Keeling)',
    '🇨🇩' => 'bendera: Congo - Kinshasa',
    '🇨🇫' => 'bendera: Republik Afrika Tengah',
    '🇨🇬' => 'bendera: Congo - Brazzaville',
    '🇨🇭' => 'bendera: Switzerland',
    '🇨🇮' => 'bendera: Cote d’Ivoire',
    '🇨🇰' => 'bendera: Kepulauan Cook',
    '🇨🇱' => 'bendera: Chile',
    '🇨🇲' => 'bendera: Cameroon',
    '🇨🇳' => 'bendera: China',
    '🇨🇴' => 'bendera: Colombia',
    '🇨🇵' => 'bendera: Pulau Clipperton',
    '🇨🇶' => 'bendera: Sark',
    '🇨🇷' => 'bendera: Costa Rica',
    '🇨🇺' => 'bendera: Cuba',
    '🇨🇻' => 'bendera: Cape Verde',
    '🇨🇼' => 'bendera: Curacao',
    '🇨🇽' => 'bendera: Pulau Krismas',
    '🇨🇾' => 'bendera: Cyprus',
    '🇨🇿' => 'bendera: Czechia',
    '🇩🇪' => 'bendera: Jerman',
    '🇩🇬' => 'bendera: Diego Garcia',
    '🇩🇯' => 'bendera: Djibouti',
    '🇩🇰' => 'bendera: Denmark',
    '🇩🇲' => 'bendera: Dominica',
    '🇩🇴' => 'bendera: Republik Dominica',
    '🇩🇿' => 'bendera: Algeria',
    '🇪🇦' => 'bendera: Ceuta dan Melilla',
    '🇪🇨' => 'bendera: Ecuador',
    '🇪🇪' => 'bendera: Estonia',
    '🇪🇬' => 'bendera: Mesir',
    '🇪🇭' => 'bendera: Sahara Barat',
    '🇪🇷' => 'bendera: Eritrea',
    '🇪🇸' => 'bendera: Sepanyol',
    '🇪🇹' => 'bendera: Ethiopia',
    '🇪🇺' => 'bendera: Kesatuan Eropah',
    '🇫🇮' => 'bendera: Finland',
    '🇫🇯' => 'bendera: Fiji',
    '🇫🇰' => 'bendera: Kepulauan Falkland',
    '🇫🇲' => 'bendera: Micronesia',
    '🇫🇴' => 'bendera: Kepulauan Faroe',
    '🇫🇷' => 'bendera: Perancis',
    '🇬🇦' => 'bendera: Gabon',
    '🇬🇧' => 'bendera: United Kingdom',
    '🇬🇩' => 'bendera: Grenada',
    '🇬🇪' => 'bendera: Georgia',
    '🇬🇫' => 'bendera: Guiana Perancis',
    '🇬🇬' => 'bendera: Guernsey',
    '🇬🇭' => 'bendera: Ghana',
    '🇬🇮' => 'bendera: Gibraltar',
    '🇬🇱' => 'bendera: Greenland',
    '🇬🇲' => 'bendera: Gambia',
    '🇬🇳' => 'bendera: Guinea',
    '🇬🇵' => 'bendera: Guadeloupe',
    '🇬🇶' => 'bendera: Guinea Khatulistiwa',
    '🇬🇷' => 'bendera: Greece',
    '🇬🇸' => 'bendera: Kepulauan Georgia Selatan & Sandwich Selatan',
    '🇬🇹' => 'bendera: Guatemala',
    '🇬🇺' => 'bendera: Guam',
    '🇬🇼' => 'bendera: Guinea Bissau',
    '🇬🇾' => 'bendera: Guyana',
    '🇭🇰' => 'bendera: Hong Kong SAR China',
    '🇭🇲' => 'bendera: Kepulauan Heard & McDonald',
    '🇭🇳' => 'bendera: Honduras',
    '🇭🇷' => 'bendera: Croatia',
    '🇭🇹' => 'bendera: Haiti',
    '🇭🇺' => 'bendera: Hungary',
    '🇮🇨' => 'bendera: Kepulauan Canary',
    '🇮🇩' => 'bendera: Indonesia',
    '🇮🇪' => 'bendera: Ireland',
    '🇮🇱' => 'bendera: Israel',
    '🇮🇲' => 'bendera: Isle of Man',
    '🇮🇳' => 'bendera: India',
    '🇮🇴' => 'bendera: Wilayah Lautan Hindi British',
    '🇮🇶' => 'bendera: Iraq',
    '🇮🇷' => 'bendera: Iran',
    '🇮🇸' => 'bendera: Iceland',
    '🇮🇹' => 'bendera: Itali',
    '🇯🇪' => 'bendera: Jersey',
    '🇯🇲' => 'bendera: Jamaica',
    '🇯🇴' => 'bendera: Jordan',
    '🇯🇵' => 'bendera: Jepun',
    '🇰🇪' => 'bendera: Kenya',
    '🇰🇬' => 'bendera: Kyrgyzstan',
    '🇰🇭' => 'bendera: Kemboja',
    '🇰🇮' => 'bendera: Kiribati',
    '🇰🇲' => 'bendera: Comoros',
    '🇰🇳' => 'bendera: Saint Kitts dan Nevis',
    '🇰🇵' => 'bendera: Korea Utara',
    '🇰🇷' => 'bendera: Korea Selatan',
    '🇰🇼' => 'bendera: Kuwait',
    '🇰🇾' => 'bendera: Kepulauan Cayman',
    '🇰🇿' => 'bendera: Kazakhstan',
    '🇱🇦' => 'bendera: Laos',
    '🇱🇧' => 'bendera: Lubnan',
    '🇱🇨' => 'bendera: Saint Lucia',
    '🇱🇮' => 'bendera: Liechtenstein',
    '🇱🇰' => 'bendera: Sri Lanka',
    '🇱🇷' => 'bendera: Liberia',
    '🇱🇸' => 'bendera: Lesotho',
    '🇱🇹' => 'bendera: Lithuania',
    '🇱🇺' => 'bendera: Luxembourg',
    '🇱🇻' => 'bendera: Latvia',
    '🇱🇾' => 'bendera: Libya',
    '🇲🇦' => 'bendera: Maghribi',
    '🇲🇨' => 'bendera: Monaco',
    '🇲🇩' => 'bendera: Moldova',
    '🇲🇪' => 'bendera: Montenegro',
    '🇲🇫' => 'bendera: Saint Martin',
    '🇲🇬' => 'bendera: Madagaskar',
    '🇲🇭' => 'bendera: Kepulauan Marshall',
    '🇲🇰' => 'bendera: Macedonia Utara',
    '🇲🇱' => 'bendera: Mali',
    '🇲🇲' => 'bendera: Myanmar (Burma)',
    '🇲🇳' => 'bendera: Mongolia',
    '🇲🇴' => 'bendera: Macau SAR China',
    '🇲🇵' => 'bendera: Kepulauan Mariana Utara',
    '🇲🇶' => 'bendera: Martinique',
    '🇲🇷' => 'bendera: Mauritania',
    '🇲🇸' => 'bendera: Montserrat',
    '🇲🇹' => 'bendera: Malta',
    '🇲🇺' => 'bendera: Mauritius',
    '🇲🇻' => 'bendera: Maldives',
    '🇲🇼' => 'bendera: Malawi',
    '🇲🇽' => 'bendera: Mexico',
    '🇲🇾' => 'bendera: Malaysia',
    '🇲🇿' => 'bendera: Mozambique',
    '🇳🇦' => 'bendera: Namibia',
    '🇳🇨' => 'bendera: New Caledonia',
    '🇳🇪' => 'bendera: Niger',
    '🇳🇫' => 'bendera: Pulau Norfolk',
    '🇳🇬' => 'bendera: Nigeria',
    '🇳🇮' => 'bendera: Nicaragua',
    '🇳🇱' => 'bendera: Belanda',
    '🇳🇴' => 'bendera: Norway',
    '🇳🇵' => 'bendera: Nepal',
    '🇳🇷' => 'bendera: Nauru',
    '🇳🇺' => 'bendera: Niue',
    '🇳🇿' => 'bendera: New Zealand',
    '🇴🇲' => 'bendera: Oman',
    '🇵🇦' => 'bendera: Panama',
    '🇵🇪' => 'bendera: Peru',
    '🇵🇫' => 'bendera: Polinesia Perancis',
    '🇵🇬' => 'bendera: Papua New Guinea',
    '🇵🇭' => 'bendera: Filipina',
    '🇵🇰' => 'bendera: Pakistan',
    '🇵🇱' => 'bendera: Poland',
    '🇵🇲' => 'bendera: Saint Pierre dan Miquelon',
    '🇵🇳' => 'bendera: Kepulauan Pitcairn',
    '🇵🇷' => 'bendera: Puerto Rico',
    '🇵🇸' => 'bendera: Wilayah Palestin',
    '🇵🇹' => 'bendera: Portugal',
    '🇵🇼' => 'bendera: Palau',
    '🇵🇾' => 'bendera: Paraguay',
    '🇶🇦' => 'bendera: Qatar',
    '🇷🇪' => 'bendera: Reunion',
    '🇷🇴' => 'bendera: Romania',
    '🇷🇸' => 'bendera: Serbia',
    '🇷🇺' => 'bendera: Rusia',
    '🇷🇼' => 'bendera: Rwanda',
    '🇸🇦' => 'bendera: Arab Saudi',
    '🇸🇧' => 'bendera: Kepulauan Solomon',
    '🇸🇨' => 'bendera: Seychelles',
    '🇸🇩' => 'bendera: Sudan',
    '🇸🇪' => 'bendera: Sweden',
    '🇸🇬' => 'bendera: Singapura',
    '🇸🇭' => 'bendera: Saint Helena',
    '🇸🇮' => 'bendera: Slovenia',
    '🇸🇯' => 'bendera: Svalbard dan Jan Mayen',
    '🇸🇰' => 'bendera: Slovakia',
    '🇸🇱' => 'bendera: Sierra Leone',
    '🇸🇲' => 'bendera: San Marino',
    '🇸🇳' => 'bendera: Senegal',
    '🇸🇴' => 'bendera: Somalia',
    '🇸🇷' => 'bendera: Surinam',
    '🇸🇸' => 'bendera: Sudan Selatan',
    '🇸🇹' => 'bendera: Sao Tome dan Principe',
    '🇸🇻' => 'bendera: El Salvador',
    '🇸🇽' => 'bendera: Sint Maarten',
    '🇸🇾' => 'bendera: Syria',
    '🇸🇿' => 'bendera: Eswatini',
    '🇹🇦' => 'bendera: Tristan da Cunha',
    '🇹🇨' => 'bendera: Kepulauan Turks dan Caicos',
    '🇹🇩' => 'bendera: Chad',
    '🇹🇫' => 'bendera: Wilayah Selatan Perancis',
    '🇹🇬' => 'bendera: Togo',
    '🇹🇭' => 'bendera: Thailand',
    '🇹🇯' => 'bendera: Tajikistan',
    '🇹🇰' => 'bendera: Tokelau',
    '🇹🇱' => 'bendera: Timor-Leste',
    '🇹🇲' => 'bendera: Turkmenistan',
    '🇹🇳' => 'bendera: Tunisia',
    '🇹🇴' => 'bendera: Tonga',
    '🇹🇷' => 'bendera: Turkiye',
    '🇹🇹' => 'bendera: Trinidad dan Tobago',
    '🇹🇻' => 'bendera: Tuvalu',
    '🇹🇼' => 'bendera: Taiwan',
    '🇹🇿' => 'bendera: Tanzania',
    '🇺🇦' => 'bendera: Ukraine',
    '🇺🇬' => 'bendera: Uganda',
    '🇺🇲' => 'bendera: Kepulauan Terpencil A.S.',
    '🇺🇳' => 'bendera: Bangsa-bangsa Bersatu',
    '🇺🇸' => 'bendera: Amerika Syarikat',
    '🇺🇾' => 'bendera: Uruguay',
    '🇺🇿' => 'bendera: Uzbekistan',
    '🇻🇦' => 'bendera: Kota Vatican',
    '🇻🇨' => 'bendera: Saint Vincent dan Grenadines',
    '🇻🇪' => 'bendera: Venezuela',
    '🇻🇬' => 'bendera: Kepulauan Virgin British',
    '🇻🇮' => 'bendera: Kepulauan Virgin A.S.',
    '🇻🇳' => 'bendera: Vietnam',
    '🇻🇺' => 'bendera: Vanuatu',
    '🇼🇫' => 'bendera: Wallis dan Futuna',
    '🇼🇸' => 'bendera: Samoa',
    '🇽🇰' => 'bendera: Kosovo',
    '🇾🇪' => 'bendera: Yaman',
    '🇾🇹' => 'bendera: Mayotte',
    '🇿🇦' => 'bendera: Afrika Selatan',
    '🇿🇲' => 'bendera: Zambia',
    '🇿🇼' => 'bendera: Zimbabwe',
    '🔟' => 'butang kekunci: 10',
    '🏻' => 'ton kulit cerah',
    '🏼' => 'ton kulit sederhana cerah',
    '🏽' => 'ton kulit sederhana',
    '🏾' => 'ton kulit sederhana gelap',
    '🏿' => 'ton kulit gelap',
    '😀' => 'muka tersengih',
    '😃' => 'muka tersengih dengan mata besar',
    '😄' => 'muka tersengih dan mata tersenyum',
    '😁' => 'muka berseri-seri dengan mata tersenyum',
    '😆' => 'muka tersengih mata tertutup rapat',
    '😅' => 'muka tersengih dan berpeluh',
    '🤣' => 'ketawa tergolek-golek',
    '😂' => 'muka dengan air mata kegembiraan',
    '🙂' => 'muka tersenyum sedikit',
    '🙃' => 'muka terbalik',
    '🫠' => 'muka mencair',
    '😉' => 'muka kenyit mata',
    '😊' => 'muka tersenyum dengan mata tersenyum',
    '😇' => 'muka tersenyum dengan halo',
    '🥰' => 'muka tersenyum dengan hati',
    '😍' => 'muka tersenyum dengan mata berbentuk hati',
    '🤩' => 'terpesona',
    '😘' => 'muka melayangkan ciuman',
    '😗' => 'muka memberi ciuman',
    '☺' => 'muka tersenyum',
    '😚' => 'muka memberi ciuman dengan mata tertutup',
    '😙' => 'muka memberi ciuman dengan mata tersenyum',
    '🥲' => 'muka tersenyum dengan airmata',
    '😋' => 'muka menikmati makanan lazat',
    '😛' => 'muka menjelir lidah',
    '😜' => 'muka menjelir lidah dan mengenyit mata',
    '🤪' => 'muka gila-gila',
    '😝' => 'muka menjelir lidah dan mata tertutup rapat',
    '🤑' => 'muka dengan wang dalam mulut',
    '🤗' => 'muka memberi pelukan',
    '🤭' => 'muka dengan tangan atas mulut',
    '🫢' => 'muka dengan mata terbuka dan tangan atas mulut',
    '🫣' => 'muka dengan mata mengintai',
    '🤫' => 'muka suruh senyap',
    '🤔' => 'muka sedang berfikir',
    '🫡' => 'muka sedang menabik',
    '🤐' => 'muka mulut berzip',
    '🤨' => 'muka dengan kening terangkat',
    '😐' => 'muka neutral',
    '😑' => 'muka selamba',
    '😶' => 'muka tanpa mulut',
    '🫥' => 'muka garis putus-putus',
    '😏' => 'muka tersenyum sinis',
    '😒' => 'muka tidak puas hati',
    '🙄' => 'muka dengan mata juling ke atas',
    '😬' => 'muka menyeringai',
    '🤥' => 'muka bohong',
    '🫨' => 'muka bergoyang',
    '😌' => 'muka lega',
    '😔' => 'muka bertafakur',
    '😪' => 'muka mengantuk',
    '🤤' => 'muka meliur',
    '😴' => 'muka tidur',
    '🫩' => 'muka dengan lingkaran gelap bawah mata',
    '😷' => 'muka memakai topeng perubatan',
    '🤒' => 'muka dengan termometer',
    '🤕' => 'muka dengan kepala berbalut',
    '🤢' => 'muka mual',
    '🤮' => 'muka muntah',
    '🤧' => 'muka bersin',
    '🥵' => 'muka sebak',
    '🥶' => 'muka dingin',
    '🥴' => 'muka kepeningan',
    '😵' => 'muka pening',
    '🤯' => 'kepala meletup',
    '🤠' => 'muka koboi',
    '🥳' => 'muka berparti',
    '🥸' => 'muka samaran',
    '😎' => 'muka tersenyum berkaca mata hitam',
    '🤓' => 'muka nerda',
    '🧐' => 'muka dengan cermin mata satu kanta',
    '😕' => 'muka keliru',
    '🫤' => 'muka dengan mulut serong',
    '😟' => 'muka risau',
    '🙁' => 'muka berkerut sedikit',
    '☹' => 'muka berkerut',
    '😮' => 'muka bermulut ternganga',
    '😯' => 'muka terkejut',
    '😲' => 'muka terperanjat',
    '😳' => 'muka malu',
    '🫪' => 'muka herot',
    '🥺' => 'muka merayu',
    '🥹' => 'muka menahan air mata',
    '😦' => 'muka berkerut dengan mulut ternganga',
    '😧' => 'muka merana',
    '😨' => 'muka ketakutan',
    '😰' => 'muka gementar dan berpeluh sejuk',
    '😥' => 'muka kecewa namun lega',
    '😢' => 'muka menangis',
    '😭' => 'muka meraung',
    '😱' => 'muka menjerit ketakutan',
    '😖' => 'muka bingung',
    '😣' => 'muka tekun',
    '😞' => 'muka kecewa',
    '😓' => 'muka berpeluh sejuk',
    '😩' => 'muka tak bermaya',
    '😫' => 'muka letih',
    '🥱' => 'muka menguap',
    '😤' => 'muka bangga kemenangan',
    '😡' => 'muka mencebik',
    '😠' => 'muka marah',
    '🤬' => 'muka dengan simbol pada mulut',
    '😈' => 'muka senyum bertanduk',
    '👿' => 'muka marah bertanduk',
    '💀' => 'tengkorak',
    '☠' => 'tengkorak dan tulang bersilang',
    '💩' => 'selonggok najis',
    '🤡' => 'muka badut',
    '👹' => 'gergasi',
    '👺' => 'goblin',
    '👻' => 'hantu',
    '👽' => 'makhluk asing',
    '👾' => 'raksasa angkasa lepas',
    '🤖' => 'robot',
    '😺' => 'kucing tersengih',
    '😸' => 'kucing tersengih dengan mata tersenyum',
    '😹' => 'kucing dengan air mata kegembiraan',
    '😻' => 'kucing tersenyum dengan mata berbentuk hati',
    '😼' => 'muka kucing tersenyum sinis',
    '😽' => 'kucing melemparkan ciuman',
    '🙀' => 'muka kucing keletihan',
    '😿' => 'muka kucing menangis',
    '😾' => 'muka kucing mulut muncung',
    '🙈' => 'monyet tutup mata',
    '🙉' => 'monyet tutup telinga',
    '🙊' => 'monyet tutup mulut',
    '💌' => 'surat cinta',
    '💘' => 'hati ditembusi anak panah',
    '💝' => 'hati dengan reben',
    '💖' => 'hati berkilauan',
    '💗' => 'hati membesar',
    '💓' => 'jantung berdegup',
    '💞' => 'hati berputar',
    '💕' => 'dua hati',
    '💟' => 'hiasan hati',
    '❣' => 'tanda seru hati',
    '💔' => 'patah hati',
    '❤' => 'hati merah',
    '🩷' => 'hati merah jambu',
    '🧡' => 'hati jingga',
    '💛' => 'hati kuning',
    '💚' => 'hati hijau',
    '💙' => 'hati biru',
    '🩵' => 'hati biru muda',
    '💜' => 'hati ungu',
    '🤎' => 'hati perang',
    '🖤' => 'hati hitam',
    '🩶' => 'hati kelabu',
    '🤍' => 'hati putih',
    '💋' => 'tanda ciuman',
    '💯' => 'seratus mata',
    '💢' => 'simbol marah',
    '🫯' => 'awan pergelutan',
    '💥' => 'pelanggaran',
    '💫' => 'pening',
    '💦' => 'titis peluh',
    '💨' => 'meluru',
    '🕳' => 'lubang',
    '💬' => 'gelembung pertuturan',
    '🗨' => 'gelembung pertuturan kiri',
    '🗯' => 'gelembung marah kanan',
    '💭' => 'gelembung fikir',
    '💤' => 'zzz',
    '👋' => 'lambai tangan',
    '🤚' => 'angkat belakang tapak tangan',
    '🖐' => 'tangan dengan jari terkepak',
    '✋' => 'angkat tangan',
    '🖖' => 'tabik vulcan',
    '🫱' => 'tangan kanan',
    '🫲' => 'tangan kiri',
    '🫳' => 'tapak tangan ke bawah',
    '🫴' => 'tapak tangan ke atas',
    '🫷' => 'tangan menolak ke arah kiri',
    '🫸' => 'tangan menolak ke arah kanan',
    '👌' => 'simbol OK',
    '🤌' => 'jari mencubit',
    '🤏' => 'tangan mencubit',
    '✌' => 'simbol kemenangan',
    '🤞' => 'silang jari',
    '🫰' => 'tangan dengan jari telunjuk dan ibu jari bersilang',
    '🤟' => 'gerak isyarat cinta kamu',
    '🤘' => 'simbol tanduk',
    '🤙' => 'telefon saya',
    '👈' => 'jari telunjuk tunjuk kiri',
    '👉' => 'jari telunjuk tunjuk kanan',
    '👆' => 'jari telunjuk tunjuk hala ke atas',
    '🖕' => 'jari hantu',
    '👇' => 'jari telunjuk belakang tangan tuding ke bawah',
    '☝' => 'jari telunjuk menunjuk ke atas',
    '🫵' => 'jari telunjuk menunjuk ke arah pemandang',
    '👍' => 'simbol bagus',
    '👎' => 'simbol tidak bagus',
    '✊' => 'angkat penumbuk',
    '👊' => 'penumbuk dari depan',
    '🤛' => 'penumbuk ke kiri',
    '🤜' => 'penumbuk ke kanan',
    '👏' => 'bertepuk tangan',
    '🙌' => 'orang mengangkat tangan',
    '🫶' => 'tangan berbentuk hati',
    '👐' => 'tangan terbuka',
    '🤲' => 'tapak tangan rapat',
    '🤝' => 'berjabat tangan',
    '🙏' => 'menyusun jari',
    '✍' => 'tangan menulis',
    '💅' => 'pengilat kuku',
    '🤳' => 'swafoto',
    '💪' => 'biseps dilenturtegang',
    '🦾' => 'lengan mekanikal',
    '🦿' => 'kaki mekanikal',
    '🦵' => 'kaki',
    '🦶' => 'hujung kaki',
    '👂' => 'telinga',
    '🦻' => 'telinga dengan alat bantu dengar',
    '👃' => 'hidung',
    '🧠' => 'otak',
    '🫀' => 'organ jantung',
    '🫁' => 'paru-paru',
    '🦷' => 'gigi',
    '🦴' => 'tulang',
    '👀' => 'sepasang mata',
    '👁' => 'mata',
    '👅' => 'lidah',
    '👄' => 'mulut',
    '🫦' => 'menggigit bibir',
    '👶' => 'bayi',
    '🧒' => 'kanak-kanak',
    '👦' => 'kanak-kanak lelaki',
    '👧' => 'budak perempuan',
    '🧑' => 'dewasa',
    '👱' => 'orang: rambut perang',
    '👨' => 'lelaki',
    '🧔' => 'orang: janggut',
    '👩' => 'perempuan',
    '🧓' => 'dewasa lebih tua',
    '👴' => 'lelaki tua',
    '👵' => 'wanita tua',
    '🙍' => 'orang berkerut dahi',
    '🙎' => 'orang mencebik',
    '🙅' => 'gerak isyarat tidak',
    '🙆' => 'gerak isyarat okey',
    '💁' => 'pegawai kaunter pertanyaan',
    '🙋' => 'orang gembira mengangkat tangan',
    '🧏' => 'orang pekak',
    '🙇' => 'orang menunduk',
    '🤦' => 'tepuk dahi',
    '🤷' => 'angkat bahu',
    '👮' => 'pegawai polis',
    '🕵' => 'detektif',
    '💂' => 'pengawal',
    '🥷' => 'ninja',
    '👷' => 'pekerja pembinaan',
    '🫅' => 'orang memakai mahkota',
    '🤴' => 'putera',
    '👸' => 'puteri',
    '👳' => 'orang berserban',
    '👲' => 'lelaki bertopi cina',
    '🧕' => 'wanita bertudung',
    '🤵' => 'orang bertuksedo',
    '👰' => 'orang memakai vel',
    '🤰' => 'wanita hamil',
    '🫃' => 'lelaki bunting',
    '🫄' => 'orang hamil',
    '🤱' => 'menyusu badan',
    '👼' => 'pari-pari bayi',
    '🎅' => 'santa klaus',
    '🤶' => 'Pn. Claus',
    '🦸' => 'adiwira',
    '🦹' => 'ketua penjahat',
    '🧙' => 'ahli silap mata',
    '🧚' => 'pari-pari',
    '🧛' => 'puntianak',
    '🧜' => 'manusia duyung',
    '🧝' => 'orang halus',
    '🧞' => 'jin',
    '🧟' => 'zombi',
    '🧌' => 'raksasa',
    '🫈' => 'makhluk berbulu',
    '💆' => 'urut muka',
    '💇' => 'gunting rambut',
    '🚶' => 'pejalan kaki',
    '🧍' => 'orang berdiri',
    '🧎' => 'orang bersimpuh',
    '🏃' => 'pelari',
    '💃' => 'perempuan menari',
    '🕺' => 'lelaki menari',
    '🕴' => 'lelaki memakai sut urusan terapung-apung',
    '👯' => 'orang dengan telinga arnab',
    '🧖' => 'orang dalam bilik berwap',
    '🧗' => 'orang mendaki',
    '🤺' => 'pemain pedang',
    '🏇' => 'lumba kuda',
    '⛷' => 'pemain ski',
    '🏂' => 'peluncur papan salji',
    '🏌' => 'pemain golf',
    '🏄' => 'peluncur air',
    '🚣' => 'orang mendayung sampan',
    '🏊' => 'perenang',
    '⛹' => 'orang melantun bola',
    '🏋' => 'ahli angkat berat',
    '🚴' => 'menunggang basikal',
    '🚵' => 'penunggang basikal bukit',
    '🤸' => 'putar roda',
    '🤼' => 'bergusti',
    '🤽' => 'polo air',
    '🤾' => 'main bola baling',
    '🤹' => 'menjugel',
    '🧘' => 'orang dalam kedudukan teratai',
    '🛀' => 'orang sedang mandi',
    '🛌' => 'orang tidur atas katil',
    '👭' => 'dua wanita berpegangan tangan',
    '👫' => 'lelaki dan wanita berpegangan tangan',
    '👬' => 'dua lelaki berpegangan tangan',
    '💏' => 'cium',
    '💑' => 'pasangan dengan simbol hati',
    '🗣' => 'kepala bercakap',
    '👤' => 'bayang dada',
    '👥' => 'bayang beberapa dada',
    '🫂' => 'orang berpelukan',
    '👪' => 'keluarga',
    '👣' => 'jejak kaki',
    '🫆' => 'cap jari',
    '🦰' => 'rambut merah',
    '🦱' => 'rambut kerinting',
    '🦳' => 'rambut putih',
    '🦲' => 'botak',
    '🐵' => 'muka monyet',
    '🐒' => 'monyet',
    '🦍' => 'gorila',
    '🦧' => 'orang utan',
    '🐶' => 'muka anjing',
    '🐕' => 'anjing',
    '🦮' => 'anjing pandu',
    '🐩' => 'anjing poodle',
    '🐺' => 'serigala',
    '🦊' => 'rubah',
    '🦝' => 'rakun',
    '🐱' => 'muka kucing',
    '🐈' => 'kucing',
    '🦁' => 'singa',
    '🐯' => 'muka harimau',
    '🐅' => 'harimau',
    '🐆' => 'harimau bintang',
    '🐴' => 'muka kuda',
    '🫎' => 'moose',
    '🫏' => 'keldai',
    '🐎' => 'kuda',
    '🦄' => 'unikorn',
    '🦓' => 'zebra',
    '🦌' => 'rusa',
    '🦬' => 'bison',
    '🐮' => 'muka lembu',
    '🐂' => 'lembu jantan',
    '🐃' => 'kerbau',
    '🐄' => 'lembu',
    '🐷' => 'muka khinzir',
    '🐖' => 'khinzir',
    '🐗' => 'babi hutan',
    '🐽' => 'hidung khinzir',
    '🐏' => 'biri-biri jantan',
    '🐑' => 'biri-biri betina',
    '🐐' => 'kambing',
    '🐪' => 'unta',
    '🐫' => 'unta bonggol dua',
    '🦙' => 'llama',
    '🦒' => 'zirafah',
    '🐘' => 'gajah',
    '🦣' => 'mamot',
    '🦏' => 'badak sumbu',
    '🦛' => 'badak air',
    '🐭' => 'muka tikus',
    '🐁' => 'Mencit',
    '🐀' => 'tikus',
    '🐹' => 'hamster',
    '🐰' => 'muka arnab',
    '🐇' => 'arnab',
    '🐿' => 'tupai tanah',
    '🦫' => 'beaver',
    '🦔' => 'landak kecil',
    '🦇' => 'kelawar',
    '🐻' => 'beruang',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'sloth',
    '🦦' => 'memerang',
    '🦨' => 'skunk',
    '🦘' => 'kanggaru',
    '🦡' => 'bejar',
    '🐾' => 'tapak kaki haiwan',
    '🦃' => 'ayam belanda',
    '🐔' => 'ayam',
    '🐓' => 'ayam jantan',
    '🐣' => 'anak ayam menetas',
    '🐤' => 'anak ayam',
    '🐥' => 'anak ayam menghadap depan',
    '🐦' => 'burung',
    '🐧' => 'penguin',
    '🕊' => 'burung merpati',
    '🦅' => 'helang',
    '🦆' => 'itik',
    '🦢' => 'swan',
    '🦉' => 'burung hantu',
    '🦤' => 'dodo',
    '🪶' => 'bulu pelepah',
    '🦩' => 'flamingo',
    '🦚' => 'merak',
    '🦜' => 'kakak tua',
    '🪽' => 'sayap',
    '🪿' => 'angsa',
    '🐸' => 'katak',
    '🐊' => 'buaya',
    '🐢' => 'penyu',
    '🦎' => 'cicak',
    '🐍' => 'ular',
    '🐲' => 'muka naga',
    '🐉' => 'naga',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'ikan paus memancutkan air',
    '🐋' => 'ikan paus',
    '🐬' => 'ikan lumba-lumba',
    '🫍' => 'orca',
    '🦭' => 'anjing laut',
    '🐟' => 'ikan',
    '🐠' => 'ikan tropika',
    '🐡' => 'ikan buntal',
    '🦈' => 'jerung',
    '🐙' => 'sotong kurita',
    '🐚' => 'kulit kerang berpilin',
    '🪸' => 'karang',
    '🪼' => 'ubur-ubur',
    '🦀' => 'ketam',
    '🦞' => 'udang karang',
    '🦐' => 'udang',
    '🦑' => 'sotong',
    '🦪' => 'tiram',
    '🐌' => 'siput',
    '🦋' => 'rama-rama',
    '🐛' => 'ulat',
    '🐜' => 'semut',
    '🐝' => 'lebah madu',
    '🪲' => 'kumbang',
    '🐞' => 'kumbang kura-kura',
    '🦗' => 'cengkerik',
    '🪳' => 'lipas',
    '🕷' => 'labah-labah',
    '🕸' => 'sarang labah-labah',
    '🦂' => 'kala jengking',
    '🦟' => 'nyamuk',
    '🪰' => 'lalat',
    '🪱' => 'cacing',
    '🦠' => 'mikrob',
    '💐' => 'sejambak bunga',
    '🌸' => 'bunga sakura',
    '💮' => 'bunga putih',
    '🪷' => 'teratai',
    '🏵' => 'roset',
    '🌹' => 'bunga mawar',
    '🥀' => 'bunga layu',
    '🌺' => 'bunga raya',
    '🌻' => 'bunga matahari',
    '🌼' => 'bunga mekar',
    '🌷' => 'bunga tulip',
    '🪻' => 'keladi bunting',
    '🌱' => 'anak benih',
    '🪴' => 'pokok dalam pasu',
    '🌲' => 'malar hijau',
    '🌳' => 'pokok daun luruh',
    '🌴' => 'pokok palma',
    '🌵' => 'kaktus',
    '🌾' => 'seberkas padi',
    '🌿' => 'herba',
    '☘' => 'syamrok',
    '🍀' => 'daun bunga cengkih',
    '🍁' => 'daun mapel',
    '🍂' => 'daun luruh',
    '🍃' => 'daun melayang ditiup angin',
    '🪹' => 'sarang kosong',
    '🪺' => 'sarang dengan telur',
    '🍄' => 'cendawan',
    '🪾' => 'pokok tidak berdaun',
    '🍇' => 'anggur',
    '🍈' => 'tembikai susu',
    '🍉' => 'tembikai',
    '🍊' => 'limau tangerin',
    '🍋' => 'lemon',
    '🍌' => 'pisang',
    '🍍' => 'nanas',
    '🥭' => 'mangga',
    '🍎' => 'epal merah',
    '🍏' => 'epal hijau',
    '🍐' => 'buah pear',
    '🍑' => 'buah pic',
    '🍒' => 'buah ceri',
    '🍓' => 'buah strawberi',
    '🫐' => 'beri biru',
    '🥝' => 'buah kiwi',
    '🍅' => 'tomato',
    '🫒' => 'buah zaitun',
    '🥥' => 'kelapa',
    '🥑' => 'avokado',
    '🍆' => 'terung',
    '🥔' => 'ubi kentang',
    '🥕' => 'lobak merah',
    '🌽' => 'tongkol jagung',
    '🌶' => 'cili api',
    '🫑' => 'cili kembung',
    '🥒' => 'timun',
    '🥬' => 'sayuran hijau',
    '🥦' => 'brokoli',
    '🧄' => 'bawang putih',
    '🧅' => 'bawang',
    '🥜' => 'kacang tanah',
    '🫘' => 'kacang',
    '🌰' => 'buah berangan',
    '🫚' => 'akar halia',
    '🫛' => 'lenggai',
    '🫜' => 'sayur akar',
    '🍞' => 'roti',
    '🥐' => 'kroisan',
    '🥖' => 'roti baguette',
    '🫓' => 'roti leper',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'penkek',
    '🧇' => 'wafel',
    '🧀' => 'sepotong keju',
    '🍖' => 'daging salut tulang',
    '🍗' => 'paha ayam',
    '🥩' => 'sepotong daging',
    '🥓' => 'bakon',
    '🍔' => 'hamburger',
    '🍟' => 'kentang goreng',
    '🍕' => 'piza',
    '🌭' => 'hot dog',
    '🥪' => 'sandwic',
    '🌮' => 'tako',
    '🌯' => 'burito',
    '🫔' => 'tamale',
    '🥙' => 'roti kebab',
    '🧆' => 'falafel',
    '🥚' => 'telur',
    '🍳' => 'memasak',
    '🥘' => 'makanan dalam belanga',
    '🍲' => 'seperiuk makanan',
    '🫕' => 'fondue',
    '🥣' => 'mangkuk dan sudu',
    '🥗' => 'salad hijau',
    '🍿' => 'bertih jagung',
    '🧈' => 'mentega',
    '🧂' => 'garam',
    '🥫' => 'makanan tin',
    '🍱' => 'kotak bento',
    '🍘' => 'keropok beras',
    '🍙' => 'bebola nasi',
    '🍚' => 'nasi masak',
    '🍛' => 'nasi kari',
    '🍜' => 'mangkuk kukus',
    '🍝' => 'spageti',
    '🍠' => 'ubi keledek bakar',
    '🍢' => 'oden',
    '🍣' => 'susyi',
    '🍤' => 'udang goreng',
    '🍥' => 'kek ikan dengan corak pusar',
    '🥮' => 'kuih bulan',
    '🍡' => 'dango',
    '🥟' => 'ladu',
    '🥠' => 'biskut nasib',
    '🥡' => 'kotak bungkus',
    '🍦' => 'ais krim lembut',
    '🍧' => 'air batu campur',
    '🍨' => 'ais krim',
    '🍩' => 'donat',
    '🍪' => 'biskut',
    '🎂' => 'kek hari jadi',
    '🍰' => 'sepotong kek',
    '🧁' => 'kek cawan',
    '🥧' => 'pai',
    '🍫' => 'sekeping coklat',
    '🍬' => 'gula-gula',
    '🍭' => 'lolipop',
    '🍮' => 'kastard',
    '🍯' => 'periuk madu',
    '🍼' => 'botol susu',
    '🥛' => 'segelas susu',
    '☕' => 'minuman panas',
    '🫖' => 'teko teh',
    '🍵' => 'cawan teh tanpa tangkai',
    '🍶' => 'sake',
    '🍾' => 'botol dengan penutup gabus terbuka',
    '🍷' => 'gelas wain',
    '🍸' => 'gelas koktel',
    '🍹' => 'minuman tropika',
    '🍺' => 'kole bir',
    '🍻' => 'kole bir berdenting',
    '🥂' => 'melaga gelas',
    '🥃' => 'gelas pendek',
    '🫗' => 'menuang cecair',
    '🥤' => 'cawan dan straw',
    '🧋' => 'teh buih',
    '🧃' => 'minuman air kotak',
    '🧉' => 'mate',
    '🧊' => 'kiub ais',
    '🥢' => 'penyepit',
    '🍽' => 'garpu dan pisau dengan pinggan',
    '🍴' => 'garpu dan pisau',
    '🥄' => 'sudu',
    '🔪' => 'pisau dapur',
    '🫙' => 'balang',
    '🏺' => 'amfora',
    '🌍' => 'peta glob Eropah-Afrika',
    '🌎' => 'peta glob Amerika',
    '🌏' => 'peta glob Asia-Australia',
    '🌐' => 'glob dengan garisan meridian',
    '🗺' => 'peta dunia',
    '🗾' => 'peta Jepun',
    '🧭' => 'kompas',
    '🏔' => 'gunung dengan puncak bersalji',
    '⛰' => 'gunung',
    '🛘' => 'tanah runtuh',
    '🌋' => 'gunung berapi',
    '🗻' => 'gunung fuji',
    '🏕' => 'berkhemah',
    '🏖' => 'pantai dengan payung',
    '🏜' => 'padang pasir',
    '🏝' => 'pulau padang pasir',
    '🏞' => 'taman negara',
    '🏟' => 'stadium',
    '🏛' => 'bangunan klasik',
    '🏗' => 'pembinaan bangunan',
    '🧱' => 'bata',
    '🪨' => 'batuan',
    '🪵' => 'kayu',
    '🛖' => 'pondok',
    '🏘' => 'bangunan perumahan',
    '🏚' => 'rumah terbiar',
    '🏠' => 'rumah',
    '🏡' => 'rumah dengan taman',
    '🏢' => 'bangunan pejabat',
    '🏣' => 'Pejabat pos Jepun',
    '🏤' => 'pejabat pos',
    '🏥' => 'hospital',
    '🏦' => 'bank',
    '🏨' => 'hotel',
    '🏩' => 'hotel cinta',
    '🏪' => 'kedai serbaneka',
    '🏫' => 'sekolah',
    '🏬' => 'gedung serbaneka',
    '🏭' => 'kilang',
    '🏯' => 'istana Jepun',
    '🏰' => 'istana',
    '💒' => 'perkahwinan',
    '🗼' => 'menara Tokyo',
    '🗽' => 'Patung Liberty',
    '⛪' => 'gereja',
    '🕌' => 'masjid',
    '🛕' => 'kuil hindu',
    '🕍' => 'saumaah',
    '⛩' => 'kuil shinto',
    '🕋' => 'kaabah',
    '⛲' => 'air pancut',
    '⛺' => 'khemah',
    '🌁' => 'berkabus',
    '🌃' => 'malam berbintang',
    '🏙' => 'panorama kota',
    '🌄' => 'matahari terbit di banjaran pergunungan',
    '🌅' => 'matahari terbit',
    '🌆' => 'panorama kota waktu senja',
    '🌇' => 'matahari terbenam',
    '🌉' => 'jambatan pada waktu malam',
    '♨' => 'mata air panas',
    '🎠' => 'kuda karusel',
    '🛝' => 'papan gelongsor taman permainan',
    '🎡' => 'roda ferris',
    '🎢' => 'roller coaster',
    '💈' => 'jalur kedai gunting rambut',
    '🎪' => 'khemah sarkas',
    '🚂' => 'lokomotif',
    '🚃' => 'gerabak kereta api',
    '🚄' => 'kereta api laju',
    '🚅' => 'kereta api laju dengan muncung peluru',
    '🚆' => 'kereta api',
    '🚇' => 'kereta api bawah tanah',
    '🚈' => 'rel ringan',
    '🚉' => 'stesen',
    '🚊' => 'trem',
    '🚝' => 'monorel',
    '🚞' => 'kereta api gunung',
    '🚋' => 'gerabak trem',
    '🚌' => 'bas',
    '🚍' => 'bas dari arah depan',
    '🚎' => 'bas troli',
    '🚐' => 'bas mini',
    '🚑' => 'ambulans',
    '🚒' => 'kereta bomba',
    '🚓' => 'kereta polis',
    '🚔' => 'kereta polis dari arah depan',
    '🚕' => 'teksi',
    '🚖' => 'teksi dari arah depan',
    '🚗' => 'kereta',
    '🚘' => 'kereta dari arah depan',
    '🚙' => 'kenderaan rekreasi',
    '🛻' => 'trak pikap',
    '🚚' => 'trak penghantaran',
    '🚛' => 'lori bersendi',
    '🚜' => 'traktor',
    '🏎' => 'kereta lumba',
    '🏍' => 'motosikal',
    '🛵' => 'skuter bermotor',
    '🦽' => 'kerusi roda manual',
    '🦼' => 'kerosi roda bermotor',
    '🛺' => 'lanca auto',
    '🚲' => 'basikal',
    '🛴' => 'skuter tolak',
    '🛹' => 'papan luncur',
    '🛼' => 'kasut roda',
    '🚏' => 'perhentian bas',
    '🛣' => 'jalan raya',
    '🛤' => 'jalan kereta api',
    '🛢' => 'tong minyak',
    '⛽' => 'pam minyak',
    '🛞' => 'roda',
    '🚨' => 'lampu kereta polis',
    '🚥' => 'lampu isyarat melintang',
    '🚦' => 'lampu isyarat menegak',
    '🛑' => 'tanda berhenti',
    '🚧' => 'pembinaan',
    '⚓' => 'sauh',
    '🛟' => 'boya',
    '⛵' => 'perahu layar',
    '🛶' => 'kanu',
    '🚤' => 'bot laju',
    '🛳' => 'kapal penumpang',
    '⛴' => 'feri',
    '🛥' => 'motobot',
    '🚢' => 'kapal',
    '✈' => 'kapal terbang',
    '🛩' => 'kapal terbang kecil',
    '🛫' => 'kapal terbang berlepas',
    '🛬' => 'kapal terbang mendarat',
    '🪂' => 'paracut',
    '💺' => 'tempat duduk',
    '🚁' => 'helikopter',
    '🚟' => 'kereta api landasan tergantung',
    '🚠' => 'jalan kabel gunung',
    '🚡' => 'jalan trem udara',
    '🛰' => 'satelit',
    '🚀' => 'roket',
    '🛸' => 'piring terbang',
    '🛎' => 'loceng porter',
    '🧳' => 'bagasi',
    '⌛' => 'jam pasir',
    '⏳' => 'jam pasir dengan pasir mengalir',
    '⌚' => 'jam tangan',
    '⏰' => 'jam loceng',
    '⏱' => 'jam randik',
    '⏲' => 'jam pemasa',
    '🕰' => 'jam para pendiang',
    '🕛' => 'pukul dua belas',
    '🕧' => 'dua belas setengah',
    '🕐' => 'pukul satu',
    '🕜' => 'satu setengah',
    '🕑' => 'pukul dua',
    '🕝' => 'dua setengah',
    '🕒' => 'pukul 3',
    '🕞' => 'tiga setengah',
    '🕓' => 'pukul empat',
    '🕟' => 'empat setengah',
    '🕔' => 'pukul lima',
    '🕠' => 'lima setengah',
    '🕕' => 'pukul enam',
    '🕡' => 'enam setengah',
    '🕖' => 'pukul tujuh',
    '🕢' => 'tujuh setengah',
    '🕗' => 'pukul lapan',
    '🕣' => 'lapan setengah',
    '🕘' => 'pukul sembilan',
    '🕤' => 'sembilan setengah',
    '🕙' => 'pukul sepuluh',
    '🕥' => 'sepuluh setengah',
    '🕚' => 'pukul sebelas',
    '🕦' => 'sebelas setengah',
    '🌑' => 'bulan baharu',
    '🌒' => 'bulan sabit membesar',
    '🌓' => 'bulan suku pertama',
    '🌔' => 'bulan hampir purnama mengambang',
    '🌕' => 'bulan purnama',
    '🌖' => 'bulan hampir purnama memalap',
    '🌗' => 'bulan suku terakhir',
    '🌘' => 'bulan sabit memalap',
    '🌙' => 'bulan sabit',
    '🌚' => 'muka bulan baharu',
    '🌛' => 'muka bulan suku pertama',
    '🌜' => 'muka bulan suku terakhir',
    '🌡' => 'termometer',
    '☀' => 'matahari',
    '🌝' => 'muka bulan purnama',
    '🌞' => 'matahari dengan muka',
    '🪐' => 'planet bergelang',
    '⭐' => 'bintang sederhana putih',
    '🌟' => 'bintang bersinar',
    '🌠' => 'tahi bintang',
    '🌌' => 'bima sakti',
    '☁' => 'awan',
    '⛅' => 'matahari di sebalik awan',
    '⛈' => 'awan dengan kilat dan hujan',
    '🌤' => 'matahari di sebalik awan kecil',
    '🌥' => 'matahari di sebalik awan besar',
    '🌦' => 'matahari di sebalik awan hujan',
    '🌧' => 'awan dengan hujan',
    '🌨' => 'awan dengan salji',
    '🌩' => 'awan dengan kilat',
    '🌪' => 'puting beliung',
    '🌫' => 'kabus',
    '🌬' => 'muka angin',
    '🌀' => 'taufan',
    '🌈' => 'pelangi',
    '🌂' => 'payung tertutup',
    '☂' => 'payung',
    '☔' => 'payung dengan titisan hujan',
    '⛱' => 'payung di atas tanah',
    '⚡' => 'voltan tinggi',
    '❄' => 'emping salji',
    '☃' => 'orang-orang salji',
    '⛄' => 'orang-orang salji tanpa salji',
    '☄' => 'komet',
    '🔥' => 'api',
    '💧' => 'titisan air',
    '🌊' => 'ombak laut',
    '🎃' => 'tanglung labu',
    '🎄' => 'pokok krismas',
    '🎆' => 'bunga api',
    '🎇' => 'mercun',
    '🧨' => 'petasan',
    '✨' => 'berkilauan',
    '🎈' => 'belon',
    '🎉' => 'pencetus bunyi parti',
    '🎊' => 'bebola konfeti',
    '🎋' => 'pokok tanabata',
    '🎍' => 'hiasan pain',
    '🎎' => 'anak patung Jepun',
    '🎏' => 'panji-panji kap',
    '🎐' => 'peranggu loceng angin',
    '🎑' => 'upacara bulan',
    '🧧' => 'angpau',
    '🎀' => 'reben',
    '🎁' => 'bungkusan hadiah',
    '🎗' => 'reben peringatan',
    '🎟' => 'tiket masuk',
    '🎫' => 'tiket',
    '🎖' => 'pingat tentera',
    '🏆' => 'piala',
    '🏅' => 'pingat sukan',
    '🥇' => 'pingat tempat pertama',
    '🥈' => 'pingat tempat kedua',
    '🥉' => 'pingat tempat ketiga',
    '⚽' => 'bola sepak',
    '⚾' => 'besbol',
    '🥎' => 'bola lisut',
    '🏀' => 'bola keranjang',
    '🏐' => 'bola tampar',
    '🏈' => 'bola sepak amerika',
    '🏉' => 'bola sepak ragbi',
    '🎾' => 'tenis',
    '🥏' => 'cakera terbang',
    '🎳' => 'boling',
    '🏏' => 'kriket',
    '🏑' => 'hoki padang',
    '🏒' => 'hoki ais',
    '🥍' => 'lacrosse',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'sarung tangan tinju',
    '🥋' => 'pakaian seni bela diri',
    '🥅' => 'jaring gol',
    '⛳' => 'bendera dalam lubang',
    '⛸' => 'sepatu luncur ais',
    '🎣' => 'joran mengail',
    '🤿' => 'topeng menyelam',
    '🎽' => 'baju larian',
    '🎿' => 'ski',
    '🛷' => 'geluncur',
    '🥌' => 'batu curling',
    '🎯' => 'balingan tepat',
    '🪀' => 'yo-yo',
    '🪁' => 'layang-layang',
    '🔫' => 'pistol air',
    '🎱' => 'biliard',
    '🔮' => 'bola kristal',
    '🪄' => 'tongkat sakti',
    '🎮' => 'permainan video',
    '🕹' => 'kayu bedik',
    '🎰' => 'mesin judi',
    '🎲' => 'dadu permainan',
    '🧩' => 'kepingan suai gambar',
    '🧸' => 'beruang teddy',
    '🪅' => 'pinata',
    '🪩' => 'bola cermin',
    '🪆' => 'anak potong sekelompok',
    '♠' => 'daun sped',
    '♥' => 'daun lekuk',
    '♦' => 'daun daiman',
    '♣' => 'daun kelawar',
    '♟' => 'bidak catur',
    '🃏' => 'joker',
    '🀄' => 'naga merah mahjung',
    '🎴' => 'terup bunga',
    '🎭' => 'seni persembahan',
    '🖼' => 'bingkai dengan gambar',
    '🎨' => 'palet artis',
    '🧵' => 'benang',
    '🪡' => 'jarum menjahit',
    '🧶' => 'yarn',
    '🪢' => 'simpul',
    '👓' => 'cermin mata',
    '🕶' => 'kaca mata hitam',
    '🥽' => 'gogal',
    '🥼' => 'kot makmal',
    '🦺' => 'rompi keselamatan',
    '👔' => 'tali leher',
    '👕' => 'kemeja-t',
    '👖' => 'seluar jean',
    '🧣' => 'skaf',
    '🧤' => 'sarung tangan',
    '🧥' => 'kot',
    '🧦' => 'stoking',
    '👗' => 'gaun',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'sut renang terus',
    '🩲' => 'seluar dalam',
    '🩳' => 'seluar pendek',
    '👙' => 'bikini',
    '👚' => 'pakaian wanita',
    '🪭' => 'kipas tangan boleh lipat',
    '👛' => 'dompet',
    '👜' => 'beg tangan',
    '👝' => 'pau',
    '🛍' => 'beg beli-belah',
    '🎒' => 'beg galas sekolah',
    '🩴' => 'sandal tali kulit',
    '👞' => 'kasut lelaki',
    '👟' => 'kasut lari',
    '🥾' => 'but kembara',
    '🥿' => 'kasut rata',
    '👠' => 'kasut tumit tinggi',
    '👡' => 'sandal wanita',
    '🩰' => 'kasut balet',
    '👢' => 'but wanita',
    '🪮' => 'pin rambut',
    '👑' => 'mahkota',
    '👒' => 'topi wanita',
    '🎩' => 'topi tinggi',
    '🎓' => 'topi konvokesyen',
    '🧢' => 'kep berbil',
    '🪖' => 'helmet tentera',
    '⛑' => 'topi keselamatan dengan palang putih',
    '📿' => 'tasbih',
    '💄' => 'gincu',
    '💍' => 'cincin',
    '💎' => 'batu permata',
    '🔇' => 'pembesar suara dimatikan',
    '🔈' => 'kelantangan rendah pembesar suara',
    '🔉' => 'kelantangan sederhana pembesar suara',
    '🔊' => 'kelantangan tinggi pembesar suara',
    '📢' => 'corong pembesar suara',
    '📣' => 'megafon',
    '📯' => 'hon pos',
    '🔔' => 'loceng',
    '🔕' => 'loceng berpalang',
    '🎼' => 'skor muzik',
    '🎵' => 'nota muzik',
    '🎶' => 'nota-nota muzik',
    '🎙' => 'mikrofon studio',
    '🎚' => 'pelungsur aras',
    '🎛' => 'tombol kawalan',
    '🎤' => 'mikrofon',
    '🎧' => 'fon kepala',
    '📻' => 'radio',
    '🎷' => 'saksofon',
    '🎺' => 'trompet',
    '🪊' => 'trombon',
    '🪗' => 'akordion',
    '🎸' => 'gitar',
    '🎹' => 'keyboard muzik',
    '🎻' => 'biola',
    '🪕' => 'banjo',
    '🥁' => 'dram',
    '🪘' => 'karatung',
    '🪇' => 'marakas',
    '🪈' => 'seruling',
    '🪉' => 'hap',
    '📱' => 'telefon bimbit',
    '📲' => 'telefon bimbit dengan anak panah',
    '☎' => 'telefon',
    '📞' => 'gagang telefon',
    '📟' => 'alat kelui',
    '📠' => 'mesin faksimili',
    '🔋' => 'bateri',
    '🪫' => 'bateri lemah',
    '🔌' => 'palam elektrik',
    '💻' => 'komputer riba',
    '🖥' => 'komputer meja',
    '🖨' => 'pencetak',
    '⌨' => 'papan kekunci',
    '🖱' => 'tetikus komputer',
    '🖲' => 'bebola jejak',
    '💽' => 'cakera komputer',
    '💾' => 'cakera liut',
    '💿' => 'cakera optik',
    '📀' => 'dvd',
    '🧮' => 'sempua',
    '🎥' => 'kamera filem',
    '🎞' => 'bingkai filem',
    '📽' => 'projektor filem',
    '🎬' => 'papan pengetap',
    '📺' => 'televisyen',
    '📷' => 'kamera',
    '📸' => 'kamera dengan denyar',
    '📹' => 'kamera video',
    '📼' => 'pita video',
    '🔍' => 'kanta pembesar condong ke kiri',
    '🔎' => 'kanta pembesar condong ke kanan',
    '🕯' => 'lilin',
    '💡' => 'mentol lampu',
    '🔦' => 'lampu suluh',
    '🏮' => 'tanglung kertas merah',
    '🪔' => 'lampu diya',
    '📔' => 'buku nota dengan kulit berhias',
    '📕' => 'buku tertutup',
    '📖' => 'buka terbuka',
    '📗' => 'buku hijau',
    '📘' => 'buku biru',
    '📙' => 'buku oren',
    '📚' => 'buku',
    '📓' => 'buku nota',
    '📒' => 'lejar',
    '📃' => 'halaman ikal',
    '📜' => 'skrol',
    '📄' => 'halaman menghadap atas',
    '📰' => 'akhbar',
    '🗞' => 'akhbar bergulung',
    '📑' => 'tab penanda halaman',
    '🔖' => 'penanda buku',
    '🏷' => 'label',
    '🪙' => 'syiling',
    '💰' => 'karung duit',
    '🪎' => 'peti harta karun',
    '💴' => 'wang kertas yen',
    '💵' => 'wang kertas dolar',
    '💶' => 'wang kertas euro',
    '💷' => 'wang kertas paun',
    '💸' => 'wang kertas bersayap',
    '💳' => 'kad kredit',
    '🧾' => 'resit',
    '💹' => 'carta yen meningkat',
    '✉' => 'sampul surat',
    '📧' => 'e-mel',
    '📨' => 'sampul surat masuk',
    '📩' => 'sampul surat dengan anak panah',
    '📤' => 'dulang keluar',
    '📥' => 'dulang masuk',
    '📦' => 'pakej',
    '📫' => 'peti surat tertutup dengan bendera dinaikkan',
    '📪' => 'peti surat tertutup dengan bendera diturunkan',
    '📬' => 'peti surat terbuka dengan bendera dinaikkan',
    '📭' => 'peti surat terbuka dengan bendera diturunkan',
    '📮' => 'peti pos',
    '🗳' => 'peti undi dengan undian',
    '✏' => 'pensel',
    '✒' => 'mata pen hitam',
    '🖋' => 'pena',
    '🖊' => 'pen',
    '🖌' => 'berus cat',
    '🖍' => 'krayon',
    '📝' => 'memo',
    '💼' => 'beg bimbit',
    '📁' => 'folder fail',
    '📂' => 'folder buka fail',
    '🗂' => 'pembahagi indeks kad',
    '📅' => 'kalendar',
    '📆' => 'kalendar koyak',
    '🗒' => 'pad nota pilin',
    '🗓' => 'kalendar pilin',
    '📇' => 'indeks kad',
    '📈' => 'carta menaik',
    '📉' => 'carta menurun',
    '📊' => 'carta bar',
    '📋' => 'papan klip',
    '📌' => 'paku tekan',
    '📍' => 'paku tekan bulat',
    '📎' => 'klip kertas',
    '🖇' => 'klip kertas berpaut',
    '📏' => 'pembaris lurus',
    '📐' => 'pembaris segi tiga',
    '✂' => 'gunting',
    '🗃' => 'kotak fail kad',
    '🗄' => 'kabinet fail',
    '🗑' => 'tong sampah',
    '🔒' => 'bermangga',
    '🔓' => 'mangga terbuka',
    '🔏' => 'mangga dengan pen',
    '🔐' => 'mangga terkunci dengan anak kunci',
    '🔑' => 'kunci',
    '🗝' => 'kunci lama',
    '🔨' => 'tukul',
    '🪓' => 'kapak',
    '⛏' => 'beliung',
    '⚒' => 'tukul dan beliung',
    '🛠' => 'tukul dan perengkuh',
    '🗡' => 'pisau belati',
    '⚔' => 'pedang bersilang',
    '💣' => 'bom',
    '🪃' => 'bumerang',
    '🏹' => 'panah dan busur',
    '🛡' => 'perisai',
    '🪚' => 'gergaji kayu',
    '🔧' => 'perengkuh',
    '🪛' => 'pemutar skru',
    '🔩' => 'nat dan bolt',
    '⚙' => 'gear',
    '🗜' => 'ragum',
    '⚖' => 'neraca timbang',
    '🦯' => 'tongkat penduga',
    '🔗' => 'pautan',
    '⛓' => 'rantai',
    '🪝' => 'cangkuk',
    '🧰' => 'kotak alat',
    '🧲' => 'magnet',
    '🪜' => 'tangga',
    '🪏' => 'penyodok',
    '⚗' => 'alembic',
    '🧪' => 'tabung uji',
    '🧫' => 'piring petri',
    '🧬' => 'dna',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'antena satelit',
    '💉' => 'picagari',
    '🩸' => 'titisan darah',
    '💊' => 'pil',
    '🩹' => 'pembalut adhesif',
    '🩼' => 'topang',
    '🩺' => 'stetoskop',
    '🩻' => 'sinar-x',
    '🚪' => 'pintu',
    '🛗' => 'elevator',
    '🪞' => 'cermin',
    '🪟' => 'tingkap',
    '🛏' => 'katil',
    '🛋' => 'sofa dan lampu',
    '🪑' => 'kerusi',
    '🚽' => 'mangkuk tandas',
    '🪠' => 'pelocok',
    '🚿' => 'pancuran',
    '🛁' => 'tab mandi',
    '🪤' => 'perangkap tikus',
    '🪒' => 'pisau cukur',
    '🧴' => 'botol losyen',
    '🧷' => 'pin dawai',
    '🧹' => 'penyapu',
    '🧺' => 'bakul',
    '🧻' => 'gulungan kertas',
    '🪣' => 'timba',
    '🧼' => 'sabun',
    '🫧' => 'buih',
    '🪥' => 'berus gigi',
    '🧽' => 'span',
    '🧯' => 'alat pemadam api',
    '🛒' => 'troli beli-belah',
    '🚬' => 'rokok',
    '⚰' => 'keranda',
    '🪦' => 'nisan',
    '⚱' => 'takar abu mayat',
    '🧿' => 'azimat nazar',
    '🪬' => 'hamsa',
    '🗿' => 'moyai',
    '🪧' => 'plakad',
    '🪪' => 'kad pengenalan',
    '🏧' => 'tanda ATM',
    '🚮' => 'tanda buang ke dalam tong sampah',
    '🚰' => 'air minum',
    '♿' => 'kerusi roda',
    '🚹' => 'tandas lelaki',
    '🚺' => 'tandas wanita',
    '🚻' => 'bilik air',
    '🚼' => 'simbol bayi',
    '🚾' => 'tandas pam',
    '🛂' => 'kawalan pasport',
    '🛃' => 'kastam',
    '🛄' => 'tuntutan bagasi',
    '🛅' => 'bagasi tertinggal',
    '⚠' => 'amaran',
    '🚸' => 'kanak-kanak melintas',
    '⛔' => 'dilarang masuk',
    '🚫' => 'dilarang',
    '🚳' => 'basikal dilarang',
    '🚭' => 'dilarang merokok',
    '🚯' => 'dilarang membuang sampah',
    '🚱' => 'air tak boleh minum',
    '🚷' => 'pejalan kaki dilarang',
    '📵' => 'dilarang guna telefon bimbit',
    '🔞' => 'bawah lapan belas tidak dibenarkan',
    '☢' => 'radioaktif',
    '☣' => 'biobahaya',
    '⬆' => 'anak panah ke atas',
    '↗' => 'anak panah penjuru atas kanan',
    '➡' => 'anak panah ke kanan',
    '↘' => 'anak panah penjuru bawah kanan',
    '⬇' => 'anak panah ke bawah',
    '↙' => 'anak panah ke penjuru kiri bawah',
    '⬅' => 'anak panah ke kiri',
    '↖' => 'anak panah ke penjuru kiri atas',
    '↕' => 'anak panah ke atas ke bawah',
    '↔' => 'anak panah ke kiri ke kanan',
    '↩' => 'anak panah ke kanan melengkung ke kiri',
    '↪' => 'anak panah ke kiri melengkung ke kanan',
    '⤴' => 'anak panah ke kanan melengkung ke atas',
    '⤵' => 'anak panah ke kanan melengkung ke bawah',
    '🔃' => 'anak panah menegak ikut jam',
    '🔄' => 'butang anak panah lawan jam',
    '🔙' => 'anak panah ‘BACK’',
    '🔚' => 'anak panah ‘END’',
    '🔛' => 'anak panah ON!',
    '🔜' => 'anak panah ‘SOON’',
    '🔝' => 'anak panah ‘TOP’',
    '🛐' => 'tempat ibadat',
    '⚛' => 'simbol atom',
    '🕉' => 'om',
    '✡' => 'bintang daud',
    '☸' => 'roda dharma',
    '☯' => 'yin yang',
    '✝' => 'salib latin',
    '☦' => 'salib ortodoks',
    '☪' => 'bintang dan bulan sabit',
    '☮' => 'simbol keamanan',
    '🕎' => 'menorah',
    '🔯' => 'bintang berpenjuru enam berbintik',
    '🪯' => 'khanda',
    '♈' => 'Aries',
    '♉' => 'Taurus',
    '♊' => 'Gemini',
    '♋' => 'Cancer',
    '♌' => 'Leo',
    '♍' => 'Virgo',
    '♎' => 'Libra',
    '♏' => 'Scorpio',
    '♐' => 'Sagittarius',
    '♑' => 'Capricorn',
    '♒' => 'Aquarius',
    '♓' => 'Pisces',
    '⛎' => 'Ophiuchus',
    '🔀' => 'butang rombak trek',
    '🔁' => 'butang ulang',
    '🔂' => 'butang ulang sekali',
    '▶' => 'butang main',
    '⏩' => 'butang mara laju',
    '⏭' => 'butang trek berikutnya',
    '⏯' => 'butang main atau jeda',
    '◀' => 'butang undur',
    '⏪' => 'butang undur laju',
    '⏮' => 'butang runut terakhir',
    '🔼' => 'butang ke atas',
    '⏫' => 'butang laju ke atas',
    '🔽' => 'butang ke bawah',
    '⏬' => 'butang laju ke bawah',
    '⏸' => 'butang jeda',
    '⏹' => 'butang henti',
    '⏺' => 'butang rakam',
    '⏏' => 'butang keluarkan',
    '🎦' => 'panggung',
    '🔅' => 'butang malap',
    '🔆' => 'butang cerah',
    '📶' => 'palang antena',
    '🛜' => 'wayarles',
    '📳' => 'mod getaran',
    '📴' => 'telefon mudah alih dimatikan',
    '♀' => 'simbol perempuan',
    '♂' => 'simbol lelaki',
    '⚧' => 'simbol transgender',
    '✖' => 'darab',
    '➕' => 'tambah',
    '➖' => 'tolak',
    '➗' => 'bahagi',
    '🟰' => 'tanda sama dengan tebal',
    '♾' => 'infiniti',
    '‼' => 'tanda seru berganda',
    '⁉' => 'tanda soal seru',
    '❓' => 'tanda soal',
    '❔' => 'tanda soal putih',
    '❕' => 'tanda seru putih',
    '❗' => 'tanda seru merah',
    '〰' => 'sengkang berombak-ombak',
    '💱' => 'pertukaran mata wang',
    '💲' => 'tanda dolar tebal',
    '⚕' => 'simbol perubatan',
    '♻' => 'simbol kitar semula',
    '⚜' => 'fleur-de-lis',
    '🔱' => 'lambang trisula',
    '📛' => 'lencana nama',
    '🔰' => 'simbol Jepun untuk pemula',
    '⭕' => 'lohong bulatan besar',
    '✅' => 'butang tanda rait',
    '☑' => 'peti undi dengan tanda semak',
    '✔' => 'tanda rait',
    '❌' => 'tanda pangkah',
    '❎' => 'butang tanda pangkah',
    '➰' => 'gelung ikal',
    '➿' => 'gelung ikal berganda',
    '〽' => 'tanda penyelingan bahagian',
    '✳' => 'asterisk berjejari lapan',
    '✴' => 'bintang berpenjuru lapan',
    '❇' => 'kilauan',
    '™' => 'tanda dagangan',
    '🫟' => 'percik',
    '🔠' => 'huruf besar latin input',
    '🔡' => 'huruf kecil latin input',
    '🔢' => 'nombor input',
    '🔣' => 'simbol input',
    '🔤' => 'huruf latin input',
    '🅰' => 'butang A (jenis darah)',
    '🆎' => 'butang AB (jenis darah)',
    '🅱' => 'butang B (jenis darah)',
    '🆑' => 'butang CL',
    '🆒' => 'butang COOL',
    '🆓' => 'butang FREE',
    'ℹ' => 'sumber maklumat',
    '🆔' => 'butang ID',
    'Ⓜ' => 'huruf M dibulatkan',
    '🆕' => 'butang NEW',
    '🆖' => 'butang NG',
    '🅾' => 'butang O (jenis darah)',
    '🆗' => 'butang OK',
    '🅿' => 'butang P',
    '🆘' => 'butang SOS',
    '🆙' => 'butang UP!',
    '🆚' => 'butang VS',
    '🈁' => 'butang ‘di sini’ Jepun',
    '🈂' => 'butang ‘caj perkhidmatan’ Jepun',
    '🈷' => 'butang “amaun bulanan” Jepun',
    '🈶' => 'butang “bukan percuma” Jepun',
    '🈯' => 'butang “ditempah” Jepun',
    '🉐' => 'butang “murah” Jepun',
    '🈹' => 'butang “diskaun” Jepun',
    '🈚' => 'butang “percuma” Jepun',
    '🈲' => 'butang “dilarang” Jepun',
    '🉑' => 'butang “boleh diterima” Jepun',
    '🈸' => 'butang “aplikasi” Jepun',
    '🈴' => 'butang “gred lulus” Jepun',
    '🈳' => 'butang “kerja kosong” Jepun',
    '㊗' => 'butang “tahniah” Jepun',
    '㊙' => 'butang “rahsia” Jepun',
    '🈺' => 'butang “dibuka untuk perniagaan” Jepun',
    '🈵' => 'butang “tiada kekosongan” Jepun',
    '🔴' => 'bulatan merah',
    '🟠' => 'bulatan jingga',
    '🟡' => 'bulatan kuning',
    '🟢' => 'bulatan hijau',
    '🔵' => 'bulatan biru',
    '🟣' => 'bulatan ungu',
    '🟤' => 'bulatan perang',
    '⚫' => 'bulatan hitam',
    '⚪' => 'bulatan putih',
    '🟥' => 'persegi merah',
    '🟧' => 'persegi jingga',
    '🟨' => 'persegi kuning',
    '🟩' => 'persegi hijau',
    '🟦' => 'persegi biru',
    '🟪' => 'persegi ungu',
    '🟫' => 'persegi perang',
    '⬛' => 'persegi besar hitam',
    '⬜' => 'persegi besar putih',
    '◼' => 'persegi sederhana hitam',
    '◻' => 'persegi sederhana putih',
    '◾' => 'persegi sederhana kecil hitam',
    '◽' => 'persegi sederhana kecil putih',
    '▪' => 'persegi kecil hitam',
    '▫' => 'persegi kecil putih',
    '🔶' => 'berlian jingga besar',
    '🔷' => 'berlian biru besar',
    '🔸' => 'berlian jingga kecil',
    '🔹' => 'berlian biru kecil',
    '🔺' => 'segi tiga merah menunjuk ke atas',
    '🔻' => 'segi tiga merah menunjuk ke bawah',
    '💠' => 'berlian berbintik',
    '🔘' => 'butang radio',
    '🔳' => 'butang persegi putih',
    '🔲' => 'butang persegi hitam',
    '🏁' => 'bendera pelepas',
    '🚩' => 'bendera tiga segi',
    '🎌' => 'bendera bersilang',
    '🏴' => 'bendera hitam',
    '🏳' => 'bendera putih',
];
