<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'dhungoo: nama, nama, toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'dhungoo: nama, nama, toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'dhungoo: nama, nama, toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'dhungoo: nama, nama, toonii gogaa ifaa, toonii gogaa gurraachaa',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'dhungoo: nama, nama, toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'dhungoo: nama, nama, toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'dhungoo: nama, nama, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'dhungoo: nama, nama, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'dhungoo: nama, nama, toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'dhungoo: nama, nama, toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'dhungoo: nama, nama, toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'dhungoo: nama, nama, toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'dhungoo: nama, nama, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'dhungoo: nama, nama, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'dhungoo: nama, nama, toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'dhungoo: nama, nama, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'dhungoo: nama, nama, toonii gogaa gurraachaa, toonii gogaa ifaa',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'dhungoo: nama, nama, toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'dhungoo: nama, nama, toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'dhungoo: nama, nama, toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏻‍❤‍💋‍👨🏻' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa',
    '👨🏻‍❤‍💋‍👨🏼' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏻‍❤‍💋‍👨🏽' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👨🏻‍❤‍💋‍👨🏾' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏻‍❤‍💋‍👨🏿' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👨🏼‍❤‍💋‍👨🏻' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👨🏼‍❤‍💋‍👨🏼' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa',
    '👨🏼‍❤‍💋‍👨🏽' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏼‍❤‍💋‍👨🏾' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏼‍❤‍💋‍👨🏿' => 'dhungoo: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏽‍❤‍💋‍👨🏻' => 'dhungoo: dhiira, dhiira, toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👨🏽‍❤‍💋‍👨🏼' => 'dhungoo: dhiira, dhiira, toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍❤‍💋‍👨🏽' => 'dhungoo: dhiira, dhiira, toonii godaa gidduugaleessa',
    '👨🏽‍❤‍💋‍👨🏾' => 'dhungoo: dhiira, dhiira, toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏽‍❤‍💋‍👨🏿' => 'dhungoo: dhiira, dhiira, toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏾‍❤‍💋‍👨🏻' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👨🏾‍❤‍💋‍👨🏼' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏾‍❤‍💋‍👨🏽' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏾‍❤‍💋‍👨🏾' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏾‍❤‍💋‍👨🏿' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏿‍❤‍💋‍👨🏻' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👨🏿‍❤‍💋‍👨🏼' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏿‍❤‍💋‍👨🏽' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👨🏿‍❤‍💋‍👨🏾' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍❤‍💋‍👨🏿' => 'dhungoo: dhiira, dhiira, toonii gogaa gurraachaa',
    '👩🏻‍❤‍💋‍👨🏻' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa',
    '👩🏻‍❤‍💋‍👨🏼' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏻‍❤‍💋‍👨🏽' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👩🏻‍❤‍💋‍👨🏾' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍❤‍💋‍👨🏿' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👩🏼‍❤‍💋‍👨🏻' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👩🏼‍❤‍💋‍👨🏼' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa',
    '👩🏼‍❤‍💋‍👨🏽' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏼‍❤‍💋‍👨🏾' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏼‍❤‍💋‍👨🏿' => 'dhungoo: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏽‍❤‍💋‍👨🏻' => 'dhungoo: dubartii, dhiira, toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👩🏽‍❤‍💋‍👨🏼' => 'dhungoo: dubartii, dhiira, toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍❤‍💋‍👨🏽' => 'dhungoo: dubartii, dhiira, toonii godaa gidduugaleessa',
    '👩🏽‍❤‍💋‍👨🏾' => 'dhungoo: dubartii, dhiira, toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏽‍❤‍💋‍👨🏿' => 'dhungoo: dubartii, dhiira, toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏾‍❤‍💋‍👨🏻' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👩🏾‍❤‍💋‍👨🏼' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏾‍❤‍💋‍👨🏽' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏾‍❤‍💋‍👨🏾' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏾‍❤‍💋‍👨🏿' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏿‍❤‍💋‍👨🏻' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👩🏿‍❤‍💋‍👨🏼' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏿‍❤‍💋‍👨🏽' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👩🏿‍❤‍💋‍👨🏾' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍❤‍💋‍👨🏿' => 'dhungoo: dubartii, dhiira, toonii gogaa gurraachaa',
    '👩🏻‍❤‍💋‍👩🏻' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa',
    '👩🏻‍❤‍💋‍👩🏼' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏻‍❤‍💋‍👩🏽' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👩🏻‍❤‍💋‍👩🏾' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍❤‍💋‍👩🏿' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👩🏼‍❤‍💋‍👩🏻' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👩🏼‍❤‍💋‍👩🏼' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa',
    '👩🏼‍❤‍💋‍👩🏽' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏼‍❤‍💋‍👩🏾' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏼‍❤‍💋‍👩🏿' => 'dhungoo: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏽‍❤‍💋‍👩🏻' => 'dhungoo: dubartii, dubartii, toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👩🏽‍❤‍💋‍👩🏼' => 'dhungoo: dubartii, dubartii, toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍❤‍💋‍👩🏽' => 'dhungoo: dubartii, dubartii, toonii godaa gidduugaleessa',
    '👩🏽‍❤‍💋‍👩🏾' => 'dhungoo: dubartii, dubartii, toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏽‍❤‍💋‍👩🏿' => 'dhungoo: dubartii, dubartii, toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏾‍❤‍💋‍👩🏻' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👩🏾‍❤‍💋‍👩🏼' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏾‍❤‍💋‍👩🏽' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏾‍❤‍💋‍👩🏾' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏾‍❤‍💋‍👩🏿' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏿‍❤‍💋‍👩🏻' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👩🏿‍❤‍💋‍👩🏼' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏿‍❤‍💋‍👩🏽' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👩🏿‍❤‍💋‍👩🏾' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍❤‍💋‍👩🏿' => 'dhungoo: dubartii, dubartii, toonii gogaa gurraachaa',
    '🧑🏻‍🫯‍🧑🏼' => 'namoota wal tuman: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏻‍🫯‍🧑🏽' => 'namoota wal tuman: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '🧑🏻‍🫯‍🧑🏾' => 'namoota wal tuman: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏻‍🫯‍🧑🏿' => 'namoota wal tuman: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '🧑🏼‍🫯‍🧑🏻' => 'namoota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏼‍🫯‍🧑🏽' => 'namoota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏼‍🫯‍🧑🏾' => 'namoota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏼‍🫯‍🧑🏿' => 'namoota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏽‍🫯‍🧑🏻' => 'namoota wal tuman: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '🧑🏽‍🫯‍🧑🏼' => 'namoota wal tuman: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🫯‍🧑🏾' => 'namoota wal tuman: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏽‍🫯‍🧑🏿' => 'namoota wal tuman: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏾‍🫯‍🧑🏻' => 'namoota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏾‍🫯‍🧑🏼' => 'namoota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏾‍🫯‍🧑🏽' => 'namoota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏾‍🫯‍🧑🏿' => 'namoota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏿‍🫯‍🧑🏻' => 'namoota wal tuman: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '🧑🏿‍🫯‍🧑🏼' => 'namoota wal tuman: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏿‍🫯‍🧑🏽' => 'namoota wal tuman: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '🧑🏿‍🫯‍🧑🏾' => 'namoota wal tuman: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏻‍❤‍🧑🏼' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏻‍❤‍🧑🏽' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '🧑🏻‍❤‍🧑🏾' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏻‍❤‍🧑🏿' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa ifaa, toonii gogaa gurraachaa',
    '🧑🏼‍❤‍🧑🏻' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏼‍❤‍🧑🏽' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏼‍❤‍🧑🏾' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏼‍❤‍🧑🏿' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏽‍❤‍🧑🏻' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '🧑🏽‍❤‍🧑🏼' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍❤‍🧑🏾' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏽‍❤‍🧑🏿' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏾‍❤‍🧑🏻' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏾‍❤‍🧑🏼' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏾‍❤‍🧑🏽' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏾‍❤‍🧑🏿' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏿‍❤‍🧑🏻' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa gurraachaa, toonii gogaa ifaa',
    '🧑🏿‍❤‍🧑🏼' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏿‍❤‍🧑🏽' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '🧑🏿‍❤‍🧑🏾' => 'hiriyyoota gaa’ilaa onnee waliin: nama, nama, toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏻‍🐰‍🧑🏼' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏻‍🐰‍🧑🏽' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '🧑🏻‍🐰‍🧑🏾' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏻‍🐰‍🧑🏿' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '🧑🏼‍🐰‍🧑🏻' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏼‍🐰‍🧑🏽' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏼‍🐰‍🧑🏾' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏼‍🐰‍🧑🏿' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏽‍🐰‍🧑🏻' => 'namoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '🧑🏽‍🐰‍🧑🏼' => 'namoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🐰‍🧑🏾' => 'namoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏽‍🐰‍🧑🏿' => 'namoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏾‍🐰‍🧑🏻' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏾‍🐰‍🧑🏼' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏾‍🐰‍🧑🏽' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏾‍🐰‍🧑🏿' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏿‍🐰‍🧑🏻' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '🧑🏿‍🐰‍🧑🏼' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏿‍🐰‍🧑🏽' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '🧑🏿‍🐰‍🧑🏾' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏻‍🫯‍👨🏼' => 'dhiirota wal tuman: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏻‍🫯‍👨🏽' => 'dhiirota wal tuman: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👨🏻‍🫯‍👨🏾' => 'dhiirota wal tuman: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏻‍🫯‍👨🏿' => 'dhiirota wal tuman: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👨🏼‍🫯‍👨🏻' => 'dhiirota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👨🏼‍🫯‍👨🏽' => 'dhiirota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏼‍🫯‍👨🏾' => 'dhiirota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏼‍🫯‍👨🏿' => 'dhiirota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏽‍🫯‍👨🏻' => 'dhiirota wal tuman: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👨🏽‍🫯‍👨🏼' => 'dhiirota wal tuman: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🫯‍👨🏾' => 'dhiirota wal tuman: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏽‍🫯‍👨🏿' => 'dhiirota wal tuman: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏾‍🫯‍👨🏻' => 'dhiirota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👨🏾‍🫯‍👨🏼' => 'dhiirota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏾‍🫯‍👨🏽' => 'dhiirota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏾‍🫯‍👨🏿' => 'dhiirota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏿‍🫯‍👨🏻' => 'dhiirota wal tuman: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👨🏿‍🫯‍👨🏼' => 'dhiirota wal tuman: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏿‍🫯‍👨🏽' => 'dhiirota wal tuman: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👨🏿‍🫯‍👨🏾' => 'dhiirota wal tuman: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏻‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa',
    '👨🏻‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏻‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👨🏻‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏻‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👨🏼‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👨🏼‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa',
    '👨🏼‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏼‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏼‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏽‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👨🏽‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii godaa gidduugaleessa',
    '👨🏽‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏽‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏾‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👨🏾‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏾‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏾‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏾‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏿‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👨🏿‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏿‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👨🏿‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira, toonii gogaa gurraachaa',
    '👨🏻‍🐰‍👨🏼' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏻‍🐰‍👨🏽' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👨🏻‍🐰‍👨🏾' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏻‍🐰‍👨🏿' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👨🏼‍🐰‍👨🏻' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👨🏼‍🐰‍👨🏽' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏼‍🐰‍👨🏾' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏼‍🐰‍👨🏿' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏽‍🐰‍👨🏻' => 'dhiirota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👨🏽‍🐰‍👨🏼' => 'dhiirota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🐰‍👨🏾' => 'dhiirota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏽‍🐰‍👨🏿' => 'dhiirota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏾‍🐰‍👨🏻' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👨🏾‍🐰‍👨🏼' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏾‍🐰‍👨🏽' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏾‍🐰‍👨🏿' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏿‍🐰‍👨🏻' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👨🏿‍🐰‍👨🏼' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏿‍🐰‍👨🏽' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👨🏿‍🐰‍👨🏾' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍🫯‍👩🏼' => 'dubartoota wal tuman: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏻‍🫯‍👩🏽' => 'dubartoota wal tuman: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👩🏻‍🫯‍👩🏾' => 'dubartoota wal tuman: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍🫯‍👩🏿' => 'dubartoota wal tuman: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👩🏼‍🫯‍👩🏻' => 'dubartoota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👩🏼‍🫯‍👩🏽' => 'dubartoota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏼‍🫯‍👩🏾' => 'dubartoota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏼‍🫯‍👩🏿' => 'dubartoota wal tuman: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏽‍🫯‍👩🏻' => 'dubartoota wal tuman: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👩🏽‍🫯‍👩🏼' => 'dubartoota wal tuman: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🫯‍👩🏾' => 'dubartoota wal tuman: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏽‍🫯‍👩🏿' => 'dubartoota wal tuman: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏾‍🫯‍👩🏻' => 'dubartoota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👩🏾‍🫯‍👩🏼' => 'dubartoota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏾‍🫯‍👩🏽' => 'dubartoota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏾‍🫯‍👩🏿' => 'dubartoota wal tuman: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏿‍🫯‍👩🏻' => 'dubartoota wal tuman: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👩🏿‍🫯‍👩🏼' => 'dubartoota wal tuman: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏿‍🫯‍👩🏽' => 'dubartoota wal tuman: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👩🏿‍🫯‍👩🏾' => 'dubartoota wal tuman: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa',
    '👩🏻‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏻‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👩🏻‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👩🏼‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👩🏼‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa',
    '👩🏼‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏼‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏼‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏽‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👩🏽‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii godaa gidduugaleessa',
    '👩🏽‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏽‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏾‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👩🏾‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏾‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏾‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏾‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏿‍❤‍👨🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👩🏿‍❤‍👨🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏿‍❤‍👨🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👩🏿‍❤‍👨🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍❤‍👨🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira, toonii gogaa gurraachaa',
    '👩🏻‍❤‍👩🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa',
    '👩🏻‍❤‍👩🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏻‍❤‍👩🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👩🏻‍❤‍👩🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍❤‍👩🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👩🏼‍❤‍👩🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👩🏼‍❤‍👩🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa',
    '👩🏼‍❤‍👩🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏼‍❤‍👩🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏼‍❤‍👩🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏽‍❤‍👩🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👩🏽‍❤‍👩🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍❤‍👩🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii godaa gidduugaleessa',
    '👩🏽‍❤‍👩🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏽‍❤‍👩🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏾‍❤‍👩🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👩🏾‍❤‍👩🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏾‍❤‍👩🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏾‍❤‍👩🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏾‍❤‍👩🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏿‍❤‍👩🏻' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👩🏿‍❤‍👩🏼' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏿‍❤‍👩🏽' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👩🏿‍❤‍👩🏾' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍❤‍👩🏿' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii, toonii gogaa gurraachaa',
    '👩🏻‍🐰‍👩🏼' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏻‍🐰‍👩🏽' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👩🏻‍🐰‍👩🏾' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍🐰‍👩🏿' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👩🏼‍🐰‍👩🏻' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👩🏼‍🐰‍👩🏽' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏼‍🐰‍👩🏾' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏼‍🐰‍👩🏿' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏽‍🐰‍👩🏻' => 'dubartoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👩🏽‍🐰‍👩🏼' => 'dubartoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🐰‍👩🏾' => 'dubartoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏽‍🐰‍👩🏿' => 'dubartoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏾‍🐰‍👩🏻' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👩🏾‍🐰‍👩🏼' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏾‍🐰‍👩🏽' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏾‍🐰‍👩🏿' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏿‍🐰‍👩🏻' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👩🏿‍🐰‍👩🏼' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏿‍🐰‍👩🏽' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👩🏿‍🐰‍👩🏾' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏻‍🤝‍🧑🏻' => 'namoota harka wal qabatan: toonii gogaa ifaa',
    '🧑🏻‍🤝‍🧑🏼' => 'namoota harka wal qabatan: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏻‍🤝‍🧑🏽' => 'namoota harka wal qabatan: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '🧑🏻‍🤝‍🧑🏾' => 'namoota harka wal qabatan: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏻‍🤝‍🧑🏿' => 'namoota harka wal qabatan: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '🧑🏼‍🤝‍🧑🏻' => 'namoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏼‍🤝‍🧑🏼' => 'namoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏼‍🤝‍🧑🏽' => 'namoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏼‍🤝‍🧑🏾' => 'namoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏼‍🤝‍🧑🏿' => 'namoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏽‍🤝‍🧑🏻' => 'namoota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '🧑🏽‍🤝‍🧑🏼' => 'namoota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🤝‍🧑🏽' => 'namoota harka wal qabatan: toonii godaa gidduugaleessa',
    '🧑🏽‍🤝‍🧑🏾' => 'namoota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏽‍🤝‍🧑🏿' => 'namoota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏾‍🤝‍🧑🏻' => 'namoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '🧑🏾‍🤝‍🧑🏼' => 'namoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏾‍🤝‍🧑🏽' => 'namoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '🧑🏾‍🤝‍🧑🏾' => 'namoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏾‍🤝‍🧑🏿' => 'namoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '🧑🏿‍🤝‍🧑🏻' => 'namoota harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '🧑🏿‍🤝‍🧑🏼' => 'namoota harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '🧑🏿‍🤝‍🧑🏽' => 'namoota harka wal qabatan: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '🧑🏿‍🤝‍🧑🏾' => 'namoota harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🤝‍🧑🏿' => 'namoota harka wal qabatan: toonii gogaa gurraachaa',
    '👩🏻‍🤝‍👩🏼' => 'dubartoota harka wal qabatan: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏻‍🤝‍👩🏽' => 'dubartoota harka wal qabatan: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👩🏻‍🤝‍👩🏾' => 'dubartoota harka wal qabatan: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍🤝‍👩🏿' => 'dubartoota harka wal qabatan: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👩🏼‍🤝‍👩🏻' => 'dubartoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👩🏼‍🤝‍👩🏽' => 'dubartoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏼‍🤝‍👩🏾' => 'dubartoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏼‍🤝‍👩🏿' => 'dubartoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏽‍🤝‍👩🏻' => 'dubartoota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👩🏽‍🤝‍👩🏼' => 'dubartoota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🤝‍👩🏾' => 'dubartoota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏽‍🤝‍👩🏿' => 'dubartoota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏾‍🤝‍👩🏻' => 'dubartoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👩🏾‍🤝‍👩🏼' => 'dubartoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏾‍🤝‍👩🏽' => 'dubartoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏾‍🤝‍👩🏿' => 'dubartoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏿‍🤝‍👩🏻' => 'dubartoota harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👩🏿‍🤝‍👩🏼' => 'dubartoota harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏿‍🤝‍👩🏽' => 'dubartoota harka wal qabatan: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👩🏿‍🤝‍👩🏾' => 'dubartoota harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍🤝‍👨🏼' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏻‍🤝‍👨🏽' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👩🏻‍🤝‍👨🏾' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏻‍🤝‍👨🏿' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👩🏼‍🤝‍👨🏻' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👩🏼‍🤝‍👨🏽' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏼‍🤝‍👨🏾' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏼‍🤝‍👨🏿' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏽‍🤝‍👨🏻' => 'dubartii fi dhiira harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👩🏽‍🤝‍👨🏼' => 'dubartii fi dhiira harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🤝‍👨🏾' => 'dubartii fi dhiira harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👩🏽‍🤝‍👨🏿' => 'dubartii fi dhiira harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏾‍🤝‍👨🏻' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👩🏾‍🤝‍👨🏼' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏾‍🤝‍👨🏽' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👩🏾‍🤝‍👨🏿' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👩🏿‍🤝‍👨🏻' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👩🏿‍🤝‍👨🏼' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👩🏿‍🤝‍👨🏽' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👩🏿‍🤝‍👨🏾' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏻‍🤝‍👨🏼' => 'dhiirota harka wal qabatan: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏻‍🤝‍👨🏽' => 'dhiirota harka wal qabatan: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '👨🏻‍🤝‍👨🏾' => 'dhiirota harka wal qabatan: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏻‍🤝‍👨🏿' => 'dhiirota harka wal qabatan: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '👨🏼‍🤝‍👨🏻' => 'dhiirota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '👨🏼‍🤝‍👨🏽' => 'dhiirota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏼‍🤝‍👨🏾' => 'dhiirota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏼‍🤝‍👨🏿' => 'dhiirota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏽‍🤝‍👨🏻' => 'dhiirota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '👨🏽‍🤝‍👨🏼' => 'dhiirota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🤝‍👨🏾' => 'dhiirota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '👨🏽‍🤝‍👨🏿' => 'dhiirota harka wal qabatan: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏾‍🤝‍👨🏻' => 'dhiirota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '👨🏾‍🤝‍👨🏼' => 'dhiirota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏾‍🤝‍👨🏽' => 'dhiirota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '👨🏾‍🤝‍👨🏿' => 'dhiirota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '👨🏿‍🤝‍👨🏻' => 'dhiirota harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '👨🏿‍🤝‍👨🏼' => 'dhiirota harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '👨🏿‍🤝‍👨🏽' => 'dhiirota harka wal qabatan: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '👨🏿‍🤝‍👨🏾' => 'dhiirota harka wal qabatan: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩‍❤‍💋‍👨' => 'dhungoo: dubartii, dhiira',
    '👨‍❤‍💋‍👨' => 'dhungoo: dhiira, dhiira',
    '👩‍❤‍💋‍👩' => 'dhungoo: dubartii, dubartii',
    '👨‍👩‍👧‍👦' => 'maatii: dhiira, dubartii, dubara, gurbaa',
    '👨‍👩‍👦‍👦' => 'maatii: dhiira, dubartii, gurbaa, gurbaa',
    '👨‍👩‍👧‍👧' => 'maatii: dhiira, dubartii, dubara, dubara',
    '👨‍👨‍👧‍👦' => 'maatii: dhiira, dhiira, dubara, gurbaa',
    '👨‍👨‍👦‍👦' => 'maatii: dhiira, dhiira, gurbaa, gurbaa',
    '👨‍👨‍👧‍👧' => 'maatii: dhiira, dhiira, dubara, dubara',
    '👩‍👩‍👧‍👦' => 'maatii: dubartii, dubartii, dubara, gurbaa',
    '👩‍👩‍👦‍👦' => 'maatii: dubartii, dubartii, gurbaa, gurbaa',
    '👩‍👩‍👧‍👧' => 'maatii: dubartii, dubartii, dubara, dubara',
    '🫱🏻‍🫲🏼' => 'harka fuudhuu: toonii gogaa ifaa, toonii gogaa ifaa-gidduugaleessa',
    '🫱🏻‍🫲🏽' => 'harka fuudhuu: toonii gogaa ifaa, toonii godaa gidduugaleessa',
    '🫱🏻‍🫲🏾' => 'harka fuudhuu: toonii gogaa ifaa, toonii gogaa gurraacha-gidduugaleessa',
    '🫱🏻‍🫲🏿' => 'harka fuudhuu: toonii gogaa ifaa, toonii gogaa gurraachaa',
    '🫱🏼‍🫲🏻' => 'harka fuudhuu: toonii gogaa ifaa-gidduugaleessa, toonii gogaa ifaa',
    '🫱🏼‍🫲🏽' => 'harka fuudhuu: toonii gogaa ifaa-gidduugaleessa, toonii godaa gidduugaleessa',
    '🫱🏼‍🫲🏾' => 'harka fuudhuu: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🫱🏼‍🫲🏿' => 'harka fuudhuu: toonii gogaa ifaa-gidduugaleessa, toonii gogaa gurraachaa',
    '🫱🏽‍🫲🏻' => 'harka fuudhuu: toonii godaa gidduugaleessa, toonii gogaa ifaa',
    '🫱🏽‍🫲🏼' => 'harka fuudhuu: toonii godaa gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🫱🏽‍🫲🏾' => 'harka fuudhuu: toonii godaa gidduugaleessa, toonii gogaa gurraacha-gidduugaleessa',
    '🫱🏽‍🫲🏿' => 'harka fuudhuu: toonii godaa gidduugaleessa, toonii gogaa gurraachaa',
    '🫱🏾‍🫲🏻' => 'harka fuudhuu: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa',
    '🫱🏾‍🫲🏼' => 'harka fuudhuu: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa ifaa-gidduugaleessa',
    '🫱🏾‍🫲🏽' => 'harka fuudhuu: toonii gogaa gurraacha-gidduugaleessa, toonii godaa gidduugaleessa',
    '🫱🏾‍🫲🏿' => 'harka fuudhuu: toonii gogaa gurraacha-gidduugaleessa, toonii gogaa gurraachaa',
    '🫱🏿‍🫲🏻' => 'harka fuudhuu: toonii gogaa gurraachaa, toonii gogaa ifaa',
    '🫱🏿‍🫲🏼' => 'harka fuudhuu: toonii gogaa gurraachaa, toonii gogaa ifaa-gidduugaleessa',
    '🫱🏿‍🫲🏽' => 'harka fuudhuu: toonii gogaa gurraachaa, toonii godaa gidduugaleessa',
    '🫱🏿‍🫲🏾' => 'harka fuudhuu: toonii gogaa gurraachaa, toonii gogaa gurraacha-gidduugaleessa',
    '👩‍❤‍👨' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dhiira',
    '👨‍❤‍👨' => 'hiriyyoota gaa’ilaa onnee waliin: dhiira, dhiira',
    '👩‍❤‍👩' => 'hiriyyoota gaa’ilaa onnee waliin: dubartii, dubartii',
    '👨‍👩‍👦' => 'maatii: dhiira, dubartii, gurbaa',
    '👨‍👩‍👧' => 'maatii: dhiira, dubartii, dubara',
    '👨‍👨‍👦' => 'maatii: dhiira, dhiira, gurbaa',
    '👨‍👨‍👧' => 'maatii: dhiira, dhiira, dubara',
    '👩‍👩‍👦' => 'maatii: dubartii, dubartii, gurbaa',
    '👩‍👩‍👧' => 'maatii: dubartii, dubartii, dubara',
    '👨‍👦‍👦' => 'maatii: dhiira, gurbaa, gurbaa',
    '👨‍👧‍👦' => 'maatii: dhiira, dubara, gurbaa',
    '👨‍👧‍👧' => 'maatii: dhiira, dubara, dubara',
    '👩‍👦‍👦' => 'maatii: dubartii, gurbaa, gurbaa',
    '👩‍👧‍👦' => 'maatii: dubartii, dubara, gurbaa',
    '👩‍👧‍👧' => 'maatii: dubartii, dubara, dubara',
    '🧑‍🤝‍🧑' => 'namoota harka wal qabatan',
    '🧑🏻‍🦰' => 'nama: toonii gogaa ifaa, rifeensa diimaa',
    '🧑🏼‍🦰' => 'nama: toonii gogaa ifaa-gidduugaleessa, rifeensa diimaa',
    '🧑🏽‍🦰' => 'nama: toonii godaa gidduugaleessa, rifeensa diimaa',
    '🧑🏾‍🦰' => 'nama: toonii gogaa gurraacha-gidduugaleessa, rifeensa diimaa',
    '🧑🏿‍🦰' => 'nama: toonii gogaa gurraachaa, rifeensa diimaa',
    '🧑🏻‍🦱' => 'nama: toonii gogaa ifaa, rifeensa luuccaa',
    '🧑🏼‍🦱' => 'nama: toonii gogaa ifaa-gidduugaleessa, rifeensa luuccaa',
    '🧑🏽‍🦱' => 'nama: toonii godaa gidduugaleessa, rifeensa luuccaa',
    '🧑🏾‍🦱' => 'nama: toonii gogaa gurraacha-gidduugaleessa, rifeensa luuccaa',
    '🧑🏿‍🦱' => 'nama: toonii gogaa gurraachaa, rifeensa luuccaa',
    '🧑🏻‍🦳' => 'nama: toonii gogaa ifaa, rifeensa adii',
    '🧑🏼‍🦳' => 'nama: toonii gogaa ifaa-gidduugaleessa, rifeensa adii',
    '🧑🏽‍🦳' => 'nama: toonii godaa gidduugaleessa, rifeensa adii',
    '🧑🏾‍🦳' => 'nama: toonii gogaa gurraacha-gidduugaleessa, rifeensa adii',
    '🧑🏿‍🦳' => 'nama: toonii gogaa gurraachaa, rifeensa adii',
    '🧑🏻‍🦲' => 'nama: toonii gogaa ifaa, moluu',
    '🧑🏼‍🦲' => 'nama: toonii gogaa ifaa-gidduugaleessa, moluu',
    '🧑🏽‍🦲' => 'nama: toonii godaa gidduugaleessa, moluu',
    '🧑🏾‍🦲' => 'nama: toonii gogaa gurraacha-gidduugaleessa, moluu',
    '🧑🏿‍🦲' => 'nama: toonii gogaa gurraachaa, moluu',
    '🧑🏻‍🩰' => 'shubbisaa baaleetii: toonii gogaa ifaa',
    '🧑🏼‍🩰' => 'shubbisaa baaleetii: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🩰' => 'shubbisaa baaleetii: toonii godaa gidduugaleessa',
    '🧑🏾‍🩰' => 'shubbisaa baaleetii: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🩰' => 'shubbisaa baaleetii: toonii gogaa gurraachaa',
    '🧔🏻‍♂' => 'dhiira: toonii gogaa ifaa, areeda qabu',
    '🧔🏼‍♂' => 'dhiira: toonii gogaa ifaa-gidduugaleessa, areeda qabu',
    '🧔🏽‍♂' => 'dhiira: toonii godaa gidduugaleessa, areeda qabu',
    '🧔🏾‍♂' => 'dhiira: toonii gogaa gurraacha-gidduugaleessa, areeda qabu',
    '🧔🏿‍♂' => 'dhiira: toonii gogaa gurraachaa, areeda qabu',
    '👱🏻‍♂' => 'dhiira: toonii gogaa ifaa, rifeensa keelloo',
    '👱🏼‍♂' => 'dhiira: toonii gogaa ifaa-gidduugaleessa, rifeensa keelloo',
    '👱🏽‍♂' => 'dhiira: toonii godaa gidduugaleessa, rifeensa keelloo',
    '👱🏾‍♂' => 'dhiira: toonii gogaa gurraacha-gidduugaleessa, rifeensa keelloo',
    '👱🏿‍♂' => 'dhiira: toonii gogaa gurraachaa, rifeensa keelloo',
    '👨🏻‍🦰' => 'dhiira: toonii gogaa ifaa, rifeensa diimaa',
    '👨🏼‍🦰' => 'dhiira: toonii gogaa ifaa-gidduugaleessa, rifeensa diimaa',
    '👨🏽‍🦰' => 'dhiira: toonii godaa gidduugaleessa, rifeensa diimaa',
    '👨🏾‍🦰' => 'dhiira: toonii gogaa gurraacha-gidduugaleessa, rifeensa diimaa',
    '👨🏿‍🦰' => 'dhiira: toonii gogaa gurraachaa, rifeensa diimaa',
    '👨🏻‍🦱' => 'dhiira: toonii gogaa ifaa, rifeensa luuccaa',
    '👨🏼‍🦱' => 'dhiira: toonii gogaa ifaa-gidduugaleessa, rifeensa luuccaa',
    '👨🏽‍🦱' => 'dhiira: toonii godaa gidduugaleessa, rifeensa luuccaa',
    '👨🏾‍🦱' => 'dhiira: toonii gogaa gurraacha-gidduugaleessa, rifeensa luuccaa',
    '👨🏿‍🦱' => 'dhiira: toonii gogaa gurraachaa, rifeensa luuccaa',
    '👨🏻‍🦳' => 'dhiira: toonii gogaa ifaa, rifeensa adii',
    '👨🏼‍🦳' => 'dhiira: toonii gogaa ifaa-gidduugaleessa, rifeensa adii',
    '👨🏽‍🦳' => 'dhiira: toonii godaa gidduugaleessa, rifeensa adii',
    '👨🏾‍🦳' => 'dhiira: toonii gogaa gurraacha-gidduugaleessa, rifeensa adii',
    '👨🏿‍🦳' => 'dhiira: toonii gogaa gurraachaa, rifeensa adii',
    '👨🏻‍🦲' => 'dhiira: toonii gogaa ifaa, moluu',
    '👨🏼‍🦲' => 'dhiira: toonii gogaa ifaa-gidduugaleessa, moluu',
    '👨🏽‍🦲' => 'dhiira: toonii godaa gidduugaleessa, moluu',
    '👨🏾‍🦲' => 'dhiira: toonii gogaa gurraacha-gidduugaleessa, moluu',
    '👨🏿‍🦲' => 'dhiira: toonii gogaa gurraachaa, moluu',
    '🧔🏻‍♀' => 'dubartii: toonii gogaa ifaa, areeda qabdu',
    '🧔🏼‍♀' => 'dubartii: toonii gogaa ifaa-gidduugaleessa, areeda qabdu',
    '🧔🏽‍♀' => 'dubartii: toonii godaa gidduugaleessa, areeda qabdu',
    '🧔🏾‍♀' => 'dubartii: toonii gogaa gurraacha-gidduugaleessa, areeda qabdu',
    '🧔🏿‍♀' => 'dubartii: toonii gogaa gurraachaa, areeda qabdu',
    '👱🏻‍♀' => 'dubartii: toonii gogaa ifaa, rifeensa keelloo',
    '👱🏼‍♀' => 'dubartii: toonii gogaa ifaa-gidduugaleessa, rifeensa keelloo',
    '👱🏽‍♀' => 'dubartii: toonii godaa gidduugaleessa, rifeensa keelloo',
    '👱🏾‍♀' => 'dubartii: toonii gogaa gurraacha-gidduugaleessa, rifeensa keelloo',
    '👱🏿‍♀' => 'dubartii: toonii gogaa gurraachaa, rifeensa keelloo',
    '👩🏻‍🦰' => 'dubartii: toonii gogaa ifaa, rifeensa diimaa',
    '👩🏼‍🦰' => 'dubartii: toonii gogaa ifaa-gidduugaleessa, rifeensa diimaa',
    '👩🏽‍🦰' => 'dubartii: toonii godaa gidduugaleessa, rifeensa diimaa',
    '👩🏾‍🦰' => 'dubartii: toonii gogaa gurraacha-gidduugaleessa, rifeensa diimaa',
    '👩🏿‍🦰' => 'dubartii: toonii gogaa gurraachaa, rifeensa diimaa',
    '👩🏻‍🦱' => 'dubartii: toonii gogaa ifaa, rifeensa luuccaa',
    '👩🏼‍🦱' => 'dubartii: toonii gogaa ifaa-gidduugaleessa, rifeensa luuccaa',
    '👩🏽‍🦱' => 'dubartii: toonii godaa gidduugaleessa, rifeensa luuccaa',
    '👩🏾‍🦱' => 'dubartii: toonii gogaa gurraacha-gidduugaleessa, rifeensa luuccaa',
    '👩🏿‍🦱' => 'dubartii: toonii gogaa gurraachaa, rifeensa luuccaa',
    '👩🏻‍🦳' => 'dubartii: toonii gogaa ifaa, rifeensa adii',
    '👩🏼‍🦳' => 'dubartii: toonii gogaa ifaa-gidduugaleessa, rifeensa adii',
    '👩🏽‍🦳' => 'dubartii: toonii godaa gidduugaleessa, rifeensa adii',
    '👩🏾‍🦳' => 'dubartii: toonii gogaa gurraacha-gidduugaleessa, rifeensa adii',
    '👩🏿‍🦳' => 'dubartii: toonii gogaa gurraachaa, rifeensa adii',
    '👩🏻‍🦲' => 'dubartii: toonii gogaa ifaa, moluu',
    '👩🏼‍🦲' => 'dubartii: toonii gogaa ifaa-gidduugaleessa, moluu',
    '👩🏽‍🦲' => 'dubartii: toonii godaa gidduugaleessa, moluu',
    '👩🏾‍🦲' => 'dubartii: toonii gogaa gurraacha-gidduugaleessa, moluu',
    '👩🏿‍🦲' => 'dubartii: toonii gogaa gurraachaa, moluu',
    '🙍🏻‍♂' => 'dhiira mufate: toonii gogaa ifaa',
    '🙍🏼‍♂' => 'dhiira mufate: toonii gogaa ifaa-gidduugaleessa',
    '🙍🏽‍♂' => 'dhiira mufate: toonii godaa gidduugaleessa',
    '🙍🏾‍♂' => 'dhiira mufate: toonii gogaa gurraacha-gidduugaleessa',
    '🙍🏿‍♂' => 'dhiira mufate: toonii gogaa gurraachaa',
    '🙍🏻‍♀' => 'dubartii mufatte: toonii gogaa ifaa',
    '🙍🏼‍♀' => 'dubartii mufatte: toonii gogaa ifaa-gidduugaleessa',
    '🙍🏽‍♀' => 'dubartii mufatte: toonii godaa gidduugaleessa',
    '🙍🏾‍♀' => 'dubartii mufatte: toonii gogaa gurraacha-gidduugaleessa',
    '🙍🏿‍♀' => 'dubartii mufatte: toonii gogaa gurraachaa',
    '🙎🏻‍♂' => 'dhiira huuruu dhiibu: toonii gogaa ifaa',
    '🙎🏼‍♂' => 'dhiira huuruu dhiibu: toonii gogaa ifaa-gidduugaleessa',
    '🙎🏽‍♂' => 'dhiira huuruu dhiibu: toonii godaa gidduugaleessa',
    '🙎🏾‍♂' => 'dhiira huuruu dhiibu: toonii gogaa gurraacha-gidduugaleessa',
    '🙎🏿‍♂' => 'dhiira huuruu dhiibu: toonii gogaa gurraachaa',
    '🙎🏻‍♀' => 'dubartii huuruu dhiibdu: toonii gogaa ifaa',
    '🙎🏼‍♀' => 'dubartii huuruu dhiibdu: toonii gogaa ifaa-gidduugaleessa',
    '🙎🏽‍♀' => 'dubartii huuruu dhiibdu: toonii godaa gidduugaleessa',
    '🙎🏾‍♀' => 'dubartii huuruu dhiibdu: toonii gogaa gurraacha-gidduugaleessa',
    '🙎🏿‍♀' => 'dubartii huuruu dhiibdu: toonii gogaa gurraachaa',
    '🙅🏻‍♂' => 'dhiira LAKKI jedhu: toonii gogaa ifaa',
    '🙅🏼‍♂' => 'dhiira LAKKI jedhu: toonii gogaa ifaa-gidduugaleessa',
    '🙅🏽‍♂' => 'dhiira LAKKI jedhu: toonii godaa gidduugaleessa',
    '🙅🏾‍♂' => 'dhiira LAKKI jedhu: toonii gogaa gurraacha-gidduugaleessa',
    '🙅🏿‍♂' => 'dhiira LAKKI jedhu: toonii gogaa gurraachaa',
    '🙅🏻‍♀' => 'dubartii LAKKI jettu: toonii gogaa ifaa',
    '🙅🏼‍♀' => 'dubartii LAKKI jettu: toonii gogaa ifaa-gidduugaleessa',
    '🙅🏽‍♀' => 'dubartii LAKKI jettu: toonii godaa gidduugaleessa',
    '🙅🏾‍♀' => 'dubartii LAKKI jettu: toonii gogaa gurraacha-gidduugaleessa',
    '🙅🏿‍♀' => 'dubartii LAKKI jettu: toonii gogaa gurraachaa',
    '🙆🏻‍♂' => 'dhiira TOLE jedhu: toonii gogaa ifaa',
    '🙆🏼‍♂' => 'dhiira TOLE jedhu: toonii gogaa ifaa-gidduugaleessa',
    '🙆🏽‍♂' => 'dhiira TOLE jedhu: toonii godaa gidduugaleessa',
    '🙆🏾‍♂' => 'dhiira TOLE jedhu: toonii gogaa gurraacha-gidduugaleessa',
    '🙆🏿‍♂' => 'dhiira TOLE jedhu: toonii gogaa gurraachaa',
    '🙆🏻‍♀' => 'dubartii TOLE jettu: toonii gogaa ifaa',
    '🙆🏼‍♀' => 'dubartii TOLE jettu: toonii gogaa ifaa-gidduugaleessa',
    '🙆🏽‍♀' => 'dubartii TOLE jettu: toonii godaa gidduugaleessa',
    '🙆🏾‍♀' => 'dubartii TOLE jettu: toonii gogaa gurraacha-gidduugaleessa',
    '🙆🏿‍♀' => 'dubartii TOLE jettu: toonii gogaa gurraachaa',
    '💁🏻‍♂' => 'dhiira harka diriirsu: toonii gogaa ifaa',
    '💁🏼‍♂' => 'dhiira harka diriirsu: toonii gogaa ifaa-gidduugaleessa',
    '💁🏽‍♂' => 'dhiira harka diriirsu: toonii godaa gidduugaleessa',
    '💁🏾‍♂' => 'dhiira harka diriirsu: toonii gogaa gurraacha-gidduugaleessa',
    '💁🏿‍♂' => 'dhiira harka diriirsu: toonii gogaa gurraachaa',
    '💁🏻‍♀' => 'dubartii harka diriirsitu: toonii gogaa ifaa',
    '💁🏼‍♀' => 'dubartii harka diriirsitu: toonii gogaa ifaa-gidduugaleessa',
    '💁🏽‍♀' => 'dubartii harka diriirsitu: toonii godaa gidduugaleessa',
    '💁🏾‍♀' => 'dubartii harka diriirsitu: toonii gogaa gurraacha-gidduugaleessa',
    '💁🏿‍♀' => 'dubartii harka diriirsitu: toonii gogaa gurraachaa',
    '🙋🏻‍♂' => 'dhiira harka baasu: toonii gogaa ifaa',
    '🙋🏼‍♂' => 'dhiira harka baasu: toonii gogaa ifaa-gidduugaleessa',
    '🙋🏽‍♂' => 'dhiira harka baasu: toonii godaa gidduugaleessa',
    '🙋🏾‍♂' => 'dhiira harka baasu: toonii gogaa gurraacha-gidduugaleessa',
    '🙋🏿‍♂' => 'dhiira harka baasu: toonii gogaa gurraachaa',
    '🙋🏻‍♀' => 'dubartii harka baastu: toonii gogaa ifaa',
    '🙋🏼‍♀' => 'dubartii harka baastu: toonii gogaa ifaa-gidduugaleessa',
    '🙋🏽‍♀' => 'dubartii harka baastu: toonii godaa gidduugaleessa',
    '🙋🏾‍♀' => 'dubartii harka baastu: toonii gogaa gurraacha-gidduugaleessa',
    '🙋🏿‍♀' => 'dubartii harka baastu: toonii gogaa gurraachaa',
    '🧏🏻‍♂' => 'dhiira duudaa: toonii gogaa ifaa',
    '🧏🏼‍♂' => 'dhiira duudaa: toonii gogaa ifaa-gidduugaleessa',
    '🧏🏽‍♂' => 'dhiira duudaa: toonii godaa gidduugaleessa',
    '🧏🏾‍♂' => 'dhiira duudaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧏🏿‍♂' => 'dhiira duudaa: toonii gogaa gurraachaa',
    '🧏🏻‍♀' => 'dubartii duudaa: toonii gogaa ifaa',
    '🧏🏼‍♀' => 'dubartii duudaa: toonii gogaa ifaa-gidduugaleessa',
    '🧏🏽‍♀' => 'dubartii duudaa: toonii godaa gidduugaleessa',
    '🧏🏾‍♀' => 'dubartii duudaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧏🏿‍♀' => 'dubartii duudaa: toonii gogaa gurraachaa',
    '🙇🏻‍♂' => 'dhiira sagadu: toonii gogaa ifaa',
    '🙇🏼‍♂' => 'dhiira sagadu: toonii gogaa ifaa-gidduugaleessa',
    '🙇🏽‍♂' => 'dhiira sagadu: toonii godaa gidduugaleessa',
    '🙇🏾‍♂' => 'dhiira sagadu: toonii gogaa gurraacha-gidduugaleessa',
    '🙇🏿‍♂' => 'dhiira sagadu: toonii gogaa gurraachaa',
    '🙇🏻‍♀' => 'dubartii sagaddu: toonii gogaa ifaa',
    '🙇🏼‍♀' => 'dubartii sagaddu: toonii gogaa ifaa-gidduugaleessa',
    '🙇🏽‍♀' => 'dubartii sagaddu: toonii godaa gidduugaleessa',
    '🙇🏾‍♀' => 'dubartii sagaddu: toonii gogaa gurraacha-gidduugaleessa',
    '🙇🏿‍♀' => 'dubartii sagaddu: toonii gogaa gurraachaa',
    '🤦🏻‍♂' => 'dhiira barruun fuula qabate: toonii gogaa ifaa',
    '🤦🏼‍♂' => 'dhiira barruun fuula qabate: toonii gogaa ifaa-gidduugaleessa',
    '🤦🏽‍♂' => 'dhiira barruun fuula qabate: toonii godaa gidduugaleessa',
    '🤦🏾‍♂' => 'dhiira barruun fuula qabate: toonii gogaa gurraacha-gidduugaleessa',
    '🤦🏿‍♂' => 'dhiira barruun fuula qabate: toonii gogaa gurraachaa',
    '🤦🏻‍♀' => 'dubartii barruun fuula qabatte: toonii gogaa ifaa',
    '🤦🏼‍♀' => 'dubartii barruun fuula qabatte: toonii gogaa ifaa-gidduugaleessa',
    '🤦🏽‍♀' => 'dubartii barruun fuula qabatte: toonii godaa gidduugaleessa',
    '🤦🏾‍♀' => 'dubartii barruun fuula qabatte: toonii gogaa gurraacha-gidduugaleessa',
    '🤦🏿‍♀' => 'dubartii barruun fuula qabatte: toonii gogaa gurraachaa',
    '🤷🏻‍♂' => 'dhiira mataa raasu: toonii gogaa ifaa',
    '🤷🏼‍♂' => 'dhiira mataa raasu: toonii gogaa ifaa-gidduugaleessa',
    '🤷🏽‍♂' => 'dhiira mataa raasu: toonii godaa gidduugaleessa',
    '🤷🏾‍♂' => 'dhiira mataa raasu: toonii gogaa gurraacha-gidduugaleessa',
    '🤷🏿‍♂' => 'dhiira mataa raasu: toonii gogaa gurraachaa',
    '🤷🏻‍♀' => 'dubartii mataa raastu: toonii gogaa ifaa',
    '🤷🏼‍♀' => 'dubartii mataa raastu: toonii gogaa ifaa-gidduugaleessa',
    '🤷🏽‍♀' => 'dubartii mataa raastu: toonii godaa gidduugaleessa',
    '🤷🏾‍♀' => 'dubartii mataa raastu: toonii gogaa gurraacha-gidduugaleessa',
    '🤷🏿‍♀' => 'dubartii mataa raastu: toonii gogaa gurraachaa',
    '🧑🏻‍⚕' => 'hojjetaa fayyaa: toonii gogaa ifaa',
    '🧑🏼‍⚕' => 'hojjetaa fayyaa: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍⚕' => 'hojjetaa fayyaa: toonii godaa gidduugaleessa',
    '🧑🏾‍⚕' => 'hojjetaa fayyaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍⚕' => 'hojjetaa fayyaa: toonii gogaa gurraachaa',
    '👨🏻‍⚕' => 'dhiira hojjetaa fayyaa: toonii gogaa ifaa',
    '👨🏼‍⚕' => 'dhiira hojjetaa fayyaa: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍⚕' => 'dhiira hojjetaa fayyaa: toonii godaa gidduugaleessa',
    '👨🏾‍⚕' => 'dhiira hojjetaa fayyaa: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍⚕' => 'dhiira hojjetaa fayyaa: toonii gogaa gurraachaa',
    '👩🏻‍⚕' => 'dubartii hojjettuu fayyaa: toonii gogaa ifaa',
    '👩🏼‍⚕' => 'dubartii hojjettuu fayyaa: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍⚕' => 'dubartii hojjettuu fayyaa: toonii godaa gidduugaleessa',
    '👩🏾‍⚕' => 'dubartii hojjettuu fayyaa: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍⚕' => 'dubartii hojjettuu fayyaa: toonii gogaa gurraachaa',
    '🧑🏻‍🎓' => 'barataa: toonii gogaa ifaa',
    '🧑🏼‍🎓' => 'barataa: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🎓' => 'barataa: toonii godaa gidduugaleessa',
    '🧑🏾‍🎓' => 'barataa: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🎓' => 'barataa: toonii gogaa gurraachaa',
    '👨🏻‍🎓' => 'dhiira barataa: toonii gogaa ifaa',
    '👨🏼‍🎓' => 'dhiira barataa: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🎓' => 'dhiira barataa: toonii godaa gidduugaleessa',
    '👨🏾‍🎓' => 'dhiira barataa: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🎓' => 'dhiira barataa: toonii gogaa gurraachaa',
    '👩🏻‍🎓' => 'dubartii barattuu: toonii gogaa ifaa',
    '👩🏼‍🎓' => 'dubartii barattuu: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🎓' => 'dubartii barattuu: toonii godaa gidduugaleessa',
    '👩🏾‍🎓' => 'dubartii barattuu: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🎓' => 'dubartii barattuu: toonii gogaa gurraachaa',
    '🧑🏻‍🏫' => 'barsiisaa: toonii gogaa ifaa',
    '🧑🏼‍🏫' => 'barsiisaa: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🏫' => 'barsiisaa: toonii godaa gidduugaleessa',
    '🧑🏾‍🏫' => 'barsiisaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🏫' => 'barsiisaa: toonii gogaa gurraachaa',
    '👨🏻‍🏫' => 'dhiira barsiisaa: toonii gogaa ifaa',
    '👨🏼‍🏫' => 'dhiira barsiisaa: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🏫' => 'dhiira barsiisaa: toonii godaa gidduugaleessa',
    '👨🏾‍🏫' => 'dhiira barsiisaa: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🏫' => 'dhiira barsiisaa: toonii gogaa gurraachaa',
    '👩🏻‍🏫' => 'dubartii barsiistuu: toonii gogaa ifaa',
    '👩🏼‍🏫' => 'dubartii barsiistuu: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🏫' => 'dubartii barsiistuu: toonii godaa gidduugaleessa',
    '👩🏾‍🏫' => 'dubartii barsiistuu: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🏫' => 'dubartii barsiistuu: toonii gogaa gurraachaa',
    '🧑🏻‍⚖' => 'abbaa murtii: toonii gogaa ifaa',
    '🧑🏼‍⚖' => 'abbaa murtii: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍⚖' => 'abbaa murtii: toonii godaa gidduugaleessa',
    '🧑🏾‍⚖' => 'abbaa murtii: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍⚖' => 'abbaa murtii: toonii gogaa gurraachaa',
    '👨🏻‍⚖' => 'dhiira abbaa murtii: toonii gogaa ifaa',
    '👨🏼‍⚖' => 'dhiira abbaa murtii: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍⚖' => 'dhiira abbaa murtii: toonii godaa gidduugaleessa',
    '👨🏾‍⚖' => 'dhiira abbaa murtii: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍⚖' => 'dhiira abbaa murtii: toonii gogaa gurraachaa',
    '👩🏻‍⚖' => 'dubartii haadha murtii: toonii gogaa ifaa',
    '👩🏼‍⚖' => 'dubartii haadha murtii: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍⚖' => 'dubartii haadha murtii: toonii godaa gidduugaleessa',
    '👩🏾‍⚖' => 'dubartii haadha murtii: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍⚖' => 'dubartii haadha murtii: toonii gogaa gurraachaa',
    '🧑🏻‍🌾' => 'qotee bulaa: toonii gogaa ifaa',
    '🧑🏼‍🌾' => 'qotee bulaa: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🌾' => 'qotee bulaa: toonii godaa gidduugaleessa',
    '🧑🏾‍🌾' => 'qotee bulaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🌾' => 'qotee bulaa: toonii gogaa gurraachaa',
    '👨🏻‍🌾' => 'dhiira qotee bulaa: toonii gogaa ifaa',
    '👨🏼‍🌾' => 'dhiira qotee bulaa: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🌾' => 'dhiira qotee bulaa: toonii godaa gidduugaleessa',
    '👨🏾‍🌾' => 'dhiira qotee bulaa: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🌾' => 'dhiira qotee bulaa: toonii gogaa gurraachaa',
    '👩🏻‍🌾' => 'dubartii qottee bultuu: toonii gogaa ifaa',
    '👩🏼‍🌾' => 'dubartii qottee bultuu: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🌾' => 'dubartii qottee bultuu: toonii godaa gidduugaleessa',
    '👩🏾‍🌾' => 'dubartii qottee bultuu: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🌾' => 'dubartii qottee bultuu: toonii gogaa gurraachaa',
    '🧑🏻‍🍳' => 'nama nyaata bilcheessu: toonii gogaa ifaa',
    '🧑🏼‍🍳' => 'nama nyaata bilcheessu: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🍳' => 'nama nyaata bilcheessu: toonii godaa gidduugaleessa',
    '🧑🏾‍🍳' => 'nama nyaata bilcheessu: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🍳' => 'nama nyaata bilcheessu: toonii gogaa gurraachaa',
    '👨🏻‍🍳' => 'dhiira nyaata bilcheessu: toonii gogaa ifaa',
    '👨🏼‍🍳' => 'dhiira nyaata bilcheessu: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🍳' => 'dhiira nyaata bilcheessu: toonii godaa gidduugaleessa',
    '👨🏾‍🍳' => 'dhiira nyaata bilcheessu: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🍳' => 'dhiira nyaata bilcheessu: toonii gogaa gurraachaa',
    '👩🏻‍🍳' => 'dubartii nyaata hojjettu: toonii gogaa ifaa',
    '👩🏼‍🍳' => 'dubartii nyaata hojjettu: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🍳' => 'dubartii nyaata hojjettu: toonii godaa gidduugaleessa',
    '👩🏾‍🍳' => 'dubartii nyaata hojjettu: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🍳' => 'dubartii nyaata hojjettu: toonii gogaa gurraachaa',
    '🧑🏻‍🔧' => 'mekaanikii: toonii gogaa ifaa',
    '🧑🏼‍🔧' => 'mekaanikii: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🔧' => 'mekaanikii: toonii godaa gidduugaleessa',
    '🧑🏾‍🔧' => 'mekaanikii: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🔧' => 'mekaanikii: toonii gogaa gurraachaa',
    '👨🏻‍🔧' => 'dhiira makaanikii: toonii gogaa ifaa',
    '👨🏼‍🔧' => 'dhiira makaanikii: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🔧' => 'dhiira makaanikii: toonii godaa gidduugaleessa',
    '👨🏾‍🔧' => 'dhiira makaanikii: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🔧' => 'dhiira makaanikii: toonii gogaa gurraachaa',
    '👩🏻‍🔧' => 'dubartii makaanikii: toonii gogaa ifaa',
    '👩🏼‍🔧' => 'dubartii makaanikii: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🔧' => 'dubartii makaanikii: toonii godaa gidduugaleessa',
    '👩🏾‍🔧' => 'dubartii makaanikii: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🔧' => 'dubartii makaanikii: toonii gogaa gurraachaa',
    '🧑🏻‍🏭' => 'hojjetaa waarshaa: toonii gogaa ifaa',
    '🧑🏼‍🏭' => 'hojjetaa waarshaa: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🏭' => 'hojjetaa waarshaa: toonii godaa gidduugaleessa',
    '🧑🏾‍🏭' => 'hojjetaa waarshaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🏭' => 'hojjetaa waarshaa: toonii gogaa gurraachaa',
    '👨🏻‍🏭' => 'dhiira hojjetaa waarshaa: toonii gogaa ifaa',
    '👨🏼‍🏭' => 'dhiira hojjetaa waarshaa: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🏭' => 'dhiira hojjetaa waarshaa: toonii godaa gidduugaleessa',
    '👨🏾‍🏭' => 'dhiira hojjetaa waarshaa: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🏭' => 'dhiira hojjetaa waarshaa: toonii gogaa gurraachaa',
    '👩🏻‍🏭' => 'dubartii hojjettuu waarshaa: toonii gogaa ifaa',
    '👩🏼‍🏭' => 'dubartii hojjettuu waarshaa: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🏭' => 'dubartii hojjettuu waarshaa: toonii godaa gidduugaleessa',
    '👩🏾‍🏭' => 'dubartii hojjettuu waarshaa: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🏭' => 'dubartii hojjettuu waarshaa: toonii gogaa gurraachaa',
    '🧑🏻‍💼' => 'hoojjetaa waajjiraa: toonii gogaa ifaa',
    '🧑🏼‍💼' => 'hoojjetaa waajjiraa: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍💼' => 'hoojjetaa waajjiraa: toonii godaa gidduugaleessa',
    '🧑🏾‍💼' => 'hoojjetaa waajjiraa: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍💼' => 'hoojjetaa waajjiraa: toonii gogaa gurraachaa',
    '👨🏻‍💼' => 'dhiira hojjetaa waajjiraa: toonii gogaa ifaa',
    '👨🏼‍💼' => 'dhiira hojjetaa waajjiraa: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍💼' => 'dhiira hojjetaa waajjiraa: toonii godaa gidduugaleessa',
    '👨🏾‍💼' => 'dhiira hojjetaa waajjiraa: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍💼' => 'dhiira hojjetaa waajjiraa: toonii gogaa gurraachaa',
    '👩🏻‍💼' => 'dubartii hojjettuu waajjiraa: toonii gogaa ifaa',
    '👩🏼‍💼' => 'dubartii hojjettuu waajjiraa: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍💼' => 'dubartii hojjettuu waajjiraa: toonii godaa gidduugaleessa',
    '👩🏾‍💼' => 'dubartii hojjettuu waajjiraa: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍💼' => 'dubartii hojjettuu waajjiraa: toonii gogaa gurraachaa',
    '🧑🏻‍🔬' => 'saayintistii: toonii gogaa ifaa',
    '🧑🏼‍🔬' => 'saayintistii: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🔬' => 'saayintistii: toonii godaa gidduugaleessa',
    '🧑🏾‍🔬' => 'saayintistii: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🔬' => 'saayintistii: toonii gogaa gurraachaa',
    '👨🏻‍🔬' => 'dhiira saayintistii: toonii gogaa ifaa',
    '👨🏼‍🔬' => 'dhiira saayintistii: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🔬' => 'dhiira saayintistii: toonii godaa gidduugaleessa',
    '👨🏾‍🔬' => 'dhiira saayintistii: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🔬' => 'dhiira saayintistii: toonii gogaa gurraachaa',
    '👩🏻‍🔬' => 'dubartii saayintistii: toonii gogaa ifaa',
    '👩🏼‍🔬' => 'dubartii saayintistii: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🔬' => 'dubartii saayintistii: toonii godaa gidduugaleessa',
    '👩🏾‍🔬' => 'dubartii saayintistii: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🔬' => 'dubartii saayintistii: toonii gogaa gurraachaa',
    '🧑🏻‍💻' => 'ogeessa tekinoloojii: toonii gogaa ifaa',
    '🧑🏼‍💻' => 'ogeessa tekinoloojii: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍💻' => 'ogeessa tekinoloojii: toonii godaa gidduugaleessa',
    '🧑🏾‍💻' => 'ogeessa tekinoloojii: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍💻' => 'ogeessa tekinoloojii: toonii gogaa gurraachaa',
    '👨🏻‍💻' => 'dhiira ogeessa tekinoloojii: toonii gogaa ifaa',
    '👨🏼‍💻' => 'dhiira ogeessa tekinoloojii: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍💻' => 'dhiira ogeessa tekinoloojii: toonii godaa gidduugaleessa',
    '👨🏾‍💻' => 'dhiira ogeessa tekinoloojii: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍💻' => 'dhiira ogeessa tekinoloojii: toonii gogaa gurraachaa',
    '👩🏻‍💻' => 'dubartii ogeettii tekinoloojii: toonii gogaa ifaa',
    '👩🏼‍💻' => 'dubartii ogeettii tekinoloojii: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍💻' => 'dubartii ogeettii tekinoloojii: toonii godaa gidduugaleessa',
    '👩🏾‍💻' => 'dubartii ogeettii tekinoloojii: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍💻' => 'dubartii ogeettii tekinoloojii: toonii gogaa gurraachaa',
    '🧑🏻‍🎤' => 'sirbituu: toonii gogaa ifaa',
    '🧑🏼‍🎤' => 'sirbituu: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🎤' => 'sirbituu: toonii godaa gidduugaleessa',
    '🧑🏾‍🎤' => 'sirbituu: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🎤' => 'sirbituu: toonii gogaa gurraachaa',
    '👨🏻‍🎤' => 'dhiira sirbu: toonii gogaa ifaa',
    '👨🏼‍🎤' => 'dhiira sirbu: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🎤' => 'dhiira sirbu: toonii godaa gidduugaleessa',
    '👨🏾‍🎤' => 'dhiira sirbu: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🎤' => 'dhiira sirbu: toonii gogaa gurraachaa',
    '👩🏻‍🎤' => 'dubartii sirbituu: toonii gogaa ifaa',
    '👩🏼‍🎤' => 'dubartii sirbituu: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🎤' => 'dubartii sirbituu: toonii godaa gidduugaleessa',
    '👩🏾‍🎤' => 'dubartii sirbituu: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🎤' => 'dubartii sirbituu: toonii gogaa gurraachaa',
    '🧑🏻‍🎨' => 'artistii: toonii gogaa ifaa',
    '🧑🏼‍🎨' => 'artistii: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🎨' => 'artistii: toonii godaa gidduugaleessa',
    '🧑🏾‍🎨' => 'artistii: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🎨' => 'artistii: toonii gogaa gurraachaa',
    '👨🏻‍🎨' => 'dhiira artistii: toonii gogaa ifaa',
    '👨🏼‍🎨' => 'dhiira artistii: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🎨' => 'dhiira artistii: toonii godaa gidduugaleessa',
    '👨🏾‍🎨' => 'dhiira artistii: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🎨' => 'dhiira artistii: toonii gogaa gurraachaa',
    '👩🏻‍🎨' => 'dubartii artistii: toonii gogaa ifaa',
    '👩🏼‍🎨' => 'dubartii artistii: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🎨' => 'dubartii artistii: toonii godaa gidduugaleessa',
    '👩🏾‍🎨' => 'dubartii artistii: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🎨' => 'dubartii artistii: toonii gogaa gurraachaa',
    '🧑🏻‍✈' => 'paayileetii: toonii gogaa ifaa',
    '🧑🏼‍✈' => 'paayileetii: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍✈' => 'paayileetii: toonii godaa gidduugaleessa',
    '🧑🏾‍✈' => 'paayileetii: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍✈' => 'paayileetii: toonii gogaa gurraachaa',
    '👨🏻‍✈' => 'dhiira paayileetii: toonii gogaa ifaa',
    '👨🏼‍✈' => 'dhiira paayileetii: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍✈' => 'dhiira paayileetii: toonii godaa gidduugaleessa',
    '👨🏾‍✈' => 'dhiira paayileetii: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍✈' => 'dhiira paayileetii: toonii gogaa gurraachaa',
    '👩🏻‍✈' => 'dubartii paayileetii: toonii gogaa ifaa',
    '👩🏼‍✈' => 'dubartii paayileetii: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍✈' => 'dubartii paayileetii: toonii godaa gidduugaleessa',
    '👩🏾‍✈' => 'dubartii paayileetii: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍✈' => 'dubartii paayileetii: toonii gogaa gurraachaa',
    '🧑🏻‍🚀' => 'ogeessa astiroonoomii: toonii gogaa ifaa',
    '🧑🏼‍🚀' => 'ogeessa astiroonoomii: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🚀' => 'ogeessa astiroonoomii: toonii godaa gidduugaleessa',
    '🧑🏾‍🚀' => 'ogeessa astiroonoomii: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🚀' => 'ogeessa astiroonoomii: toonii gogaa gurraachaa',
    '👨🏻‍🚀' => 'dhiira ogeessa astiroonoomii: toonii gogaa ifaa',
    '👨🏼‍🚀' => 'dhiira ogeessa astiroonoomii: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🚀' => 'dhiira ogeessa astiroonoomii: toonii godaa gidduugaleessa',
    '👨🏾‍🚀' => 'dhiira ogeessa astiroonoomii: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🚀' => 'dhiira ogeessa astiroonoomii: toonii gogaa gurraachaa',
    '👩🏻‍🚀' => 'dubarii ogeettii astiroonoomi: toonii gogaa ifaa',
    '👩🏼‍🚀' => 'dubarii ogeettii astiroonoomi: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🚀' => 'dubarii ogeettii astiroonoomi: toonii godaa gidduugaleessa',
    '👩🏾‍🚀' => 'dubarii ogeettii astiroonoomi: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🚀' => 'dubarii ogeettii astiroonoomi: toonii gogaa gurraachaa',
    '🧑🏻‍🚒' => 'nama ibidda dhaamsu: toonii gogaa ifaa',
    '🧑🏼‍🚒' => 'nama ibidda dhaamsu: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🚒' => 'nama ibidda dhaamsu: toonii godaa gidduugaleessa',
    '🧑🏾‍🚒' => 'nama ibidda dhaamsu: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🚒' => 'nama ibidda dhaamsu: toonii gogaa gurraachaa',
    '👨🏻‍🚒' => 'dhiira hojjetaa balaa ibiddaa: toonii gogaa ifaa',
    '👨🏼‍🚒' => 'dhiira hojjetaa balaa ibiddaa: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🚒' => 'dhiira hojjetaa balaa ibiddaa: toonii godaa gidduugaleessa',
    '👨🏾‍🚒' => 'dhiira hojjetaa balaa ibiddaa: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🚒' => 'dhiira hojjetaa balaa ibiddaa: toonii gogaa gurraachaa',
    '👩🏻‍🚒' => 'dubartii hojjettuu balaa ibiddaa: toonii gogaa ifaa',
    '👩🏼‍🚒' => 'dubartii hojjettuu balaa ibiddaa: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🚒' => 'dubartii hojjettuu balaa ibiddaa: toonii godaa gidduugaleessa',
    '👩🏾‍🚒' => 'dubartii hojjettuu balaa ibiddaa: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🚒' => 'dubartii hojjettuu balaa ibiddaa: toonii gogaa gurraachaa',
    '👮🏻‍♂' => 'dhiira qondaala poolisii: toonii gogaa ifaa',
    '👮🏼‍♂' => 'dhiira qondaala poolisii: toonii gogaa ifaa-gidduugaleessa',
    '👮🏽‍♂' => 'dhiira qondaala poolisii: toonii godaa gidduugaleessa',
    '👮🏾‍♂' => 'dhiira qondaala poolisii: toonii gogaa gurraacha-gidduugaleessa',
    '👮🏿‍♂' => 'dhiira qondaala poolisii: toonii gogaa gurraachaa',
    '👮🏻‍♀' => 'dubartii qondaala poolisii: toonii gogaa ifaa',
    '👮🏼‍♀' => 'dubartii qondaala poolisii: toonii gogaa ifaa-gidduugaleessa',
    '👮🏽‍♀' => 'dubartii qondaala poolisii: toonii godaa gidduugaleessa',
    '👮🏾‍♀' => 'dubartii qondaala poolisii: toonii gogaa gurraacha-gidduugaleessa',
    '👮🏿‍♀' => 'dubartii qondaala poolisii: toonii gogaa gurraachaa',
    '🕵🏻‍♂' => 'dhiira qorataa: toonii gogaa ifaa',
    '🕵🏼‍♂' => 'dhiira qorataa: toonii gogaa ifaa-gidduugaleessa',
    '🕵🏽‍♂' => 'dhiira qorataa: toonii godaa gidduugaleessa',
    '🕵🏾‍♂' => 'dhiira qorataa: toonii gogaa gurraacha-gidduugaleessa',
    '🕵🏿‍♂' => 'dhiira qorataa: toonii gogaa gurraachaa',
    '🕵🏻‍♀' => 'dubartii qorattuu: toonii gogaa ifaa',
    '🕵🏼‍♀' => 'dubartii qorattuu: toonii gogaa ifaa-gidduugaleessa',
    '🕵🏽‍♀' => 'dubartii qorattuu: toonii godaa gidduugaleessa',
    '🕵🏾‍♀' => 'dubartii qorattuu: toonii gogaa gurraacha-gidduugaleessa',
    '🕵🏿‍♀' => 'dubartii qorattuu: toonii gogaa gurraachaa',
    '💂🏻‍♂' => 'dhiira eegaa: toonii gogaa ifaa',
    '💂🏼‍♂' => 'dhiira eegaa: toonii gogaa ifaa-gidduugaleessa',
    '💂🏽‍♂' => 'dhiira eegaa: toonii godaa gidduugaleessa',
    '💂🏾‍♂' => 'dhiira eegaa: toonii gogaa gurraacha-gidduugaleessa',
    '💂🏿‍♂' => 'dhiira eegaa: toonii gogaa gurraachaa',
    '💂🏻‍♀' => 'dubartii eegduu: toonii gogaa ifaa',
    '💂🏼‍♀' => 'dubartii eegduu: toonii gogaa ifaa-gidduugaleessa',
    '💂🏽‍♀' => 'dubartii eegduu: toonii godaa gidduugaleessa',
    '💂🏾‍♀' => 'dubartii eegduu: toonii gogaa gurraacha-gidduugaleessa',
    '💂🏿‍♀' => 'dubartii eegduu: toonii gogaa gurraachaa',
    '👷🏻‍♂' => 'dhiira hojjetaa ijaarsaa: toonii gogaa ifaa',
    '👷🏼‍♂' => 'dhiira hojjetaa ijaarsaa: toonii gogaa ifaa-gidduugaleessa',
    '👷🏽‍♂' => 'dhiira hojjetaa ijaarsaa: toonii godaa gidduugaleessa',
    '👷🏾‍♂' => 'dhiira hojjetaa ijaarsaa: toonii gogaa gurraacha-gidduugaleessa',
    '👷🏿‍♂' => 'dhiira hojjetaa ijaarsaa: toonii gogaa gurraachaa',
    '👷🏻‍♀' => 'dubartii hojjettuu ijaarsaa: toonii gogaa ifaa',
    '👷🏼‍♀' => 'dubartii hojjettuu ijaarsaa: toonii gogaa ifaa-gidduugaleessa',
    '👷🏽‍♀' => 'dubartii hojjettuu ijaarsaa: toonii godaa gidduugaleessa',
    '👷🏾‍♀' => 'dubartii hojjettuu ijaarsaa: toonii gogaa gurraacha-gidduugaleessa',
    '👷🏿‍♀' => 'dubartii hojjettuu ijaarsaa: toonii gogaa gurraachaa',
    '👳🏻‍♂' => 'dhiira turbaanii uffatu: toonii gogaa ifaa',
    '👳🏼‍♂' => 'dhiira turbaanii uffatu: toonii gogaa ifaa-gidduugaleessa',
    '👳🏽‍♂' => 'dhiira turbaanii uffatu: toonii godaa gidduugaleessa',
    '👳🏾‍♂' => 'dhiira turbaanii uffatu: toonii gogaa gurraacha-gidduugaleessa',
    '👳🏿‍♂' => 'dhiira turbaanii uffatu: toonii gogaa gurraachaa',
    '👳🏻‍♀' => 'dubartii turbaanii uffattu: toonii gogaa ifaa',
    '👳🏼‍♀' => 'dubartii turbaanii uffattu: toonii gogaa ifaa-gidduugaleessa',
    '👳🏽‍♀' => 'dubartii turbaanii uffattu: toonii godaa gidduugaleessa',
    '👳🏾‍♀' => 'dubartii turbaanii uffattu: toonii gogaa gurraacha-gidduugaleessa',
    '👳🏿‍♀' => 'dubartii turbaanii uffattu: toonii gogaa gurraachaa',
    '🤵🏻‍♂' => 'dhiira bijaamaa uffate: toonii gogaa ifaa',
    '🤵🏼‍♂' => 'dhiira bijaamaa uffate: toonii gogaa ifaa-gidduugaleessa',
    '🤵🏽‍♂' => 'dhiira bijaamaa uffate: toonii godaa gidduugaleessa',
    '🤵🏾‍♂' => 'dhiira bijaamaa uffate: toonii gogaa gurraacha-gidduugaleessa',
    '🤵🏿‍♂' => 'dhiira bijaamaa uffate: toonii gogaa gurraachaa',
    '🤵🏻‍♀' => 'dubartii bijaamaa uffatte: toonii gogaa ifaa',
    '🤵🏼‍♀' => 'dubartii bijaamaa uffatte: toonii gogaa ifaa-gidduugaleessa',
    '🤵🏽‍♀' => 'dubartii bijaamaa uffatte: toonii godaa gidduugaleessa',
    '🤵🏾‍♀' => 'dubartii bijaamaa uffatte: toonii gogaa gurraacha-gidduugaleessa',
    '🤵🏿‍♀' => 'dubartii bijaamaa uffatte: toonii gogaa gurraachaa',
    '👰🏻‍♂' => 'dhiira golgaa waliin: toonii gogaa ifaa',
    '👰🏼‍♂' => 'dhiira golgaa waliin: toonii gogaa ifaa-gidduugaleessa',
    '👰🏽‍♂' => 'dhiira golgaa waliin: toonii godaa gidduugaleessa',
    '👰🏾‍♂' => 'dhiira golgaa waliin: toonii gogaa gurraacha-gidduugaleessa',
    '👰🏿‍♂' => 'dhiira golgaa waliin: toonii gogaa gurraachaa',
    '👰🏻‍♀' => 'dubartii golgaa waliin: toonii gogaa ifaa',
    '👰🏼‍♀' => 'dubartii golgaa waliin: toonii gogaa ifaa-gidduugaleessa',
    '👰🏽‍♀' => 'dubartii golgaa waliin: toonii godaa gidduugaleessa',
    '👰🏾‍♀' => 'dubartii golgaa waliin: toonii gogaa gurraacha-gidduugaleessa',
    '👰🏿‍♀' => 'dubartii golgaa waliin: toonii gogaa gurraachaa',
    '👩🏻‍🍼' => 'dubartii daa’ima nyaachistu: toonii gogaa ifaa',
    '👩🏼‍🍼' => 'dubartii daa’ima nyaachistu: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🍼' => 'dubartii daa’ima nyaachistu: toonii godaa gidduugaleessa',
    '👩🏾‍🍼' => 'dubartii daa’ima nyaachistu: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🍼' => 'dubartii daa’ima nyaachistu: toonii gogaa gurraachaa',
    '👨🏻‍🍼' => 'dhiira daa’ima nyaachisu: toonii gogaa ifaa',
    '👨🏼‍🍼' => 'dhiira daa’ima nyaachisu: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🍼' => 'dhiira daa’ima nyaachisu: toonii godaa gidduugaleessa',
    '👨🏾‍🍼' => 'dhiira daa’ima nyaachisu: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🍼' => 'dhiira daa’ima nyaachisu: toonii gogaa gurraachaa',
    '🧑🏻‍🍼' => 'nama daa’ima nyaachisu: toonii gogaa ifaa',
    '🧑🏼‍🍼' => 'nama daa’ima nyaachisu: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🍼' => 'nama daa’ima nyaachisu: toonii godaa gidduugaleessa',
    '🧑🏾‍🍼' => 'nama daa’ima nyaachisu: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🍼' => 'nama daa’ima nyaachisu: toonii gogaa gurraachaa',
    '🧑🏻‍🎄' => 'Kilaawosii qillee: toonii gogaa ifaa',
    '🧑🏼‍🎄' => 'Kilaawosii qillee: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🎄' => 'Kilaawosii qillee: toonii godaa gidduugaleessa',
    '🧑🏾‍🎄' => 'Kilaawosii qillee: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🎄' => 'Kilaawosii qillee: toonii gogaa gurraachaa',
    '🦸🏻‍♂' => 'dhiira goota: toonii gogaa ifaa',
    '🦸🏼‍♂' => 'dhiira goota: toonii gogaa ifaa-gidduugaleessa',
    '🦸🏽‍♂' => 'dhiira goota: toonii godaa gidduugaleessa',
    '🦸🏾‍♂' => 'dhiira goota: toonii gogaa gurraacha-gidduugaleessa',
    '🦸🏿‍♂' => 'dhiira goota: toonii gogaa gurraachaa',
    '🦸🏻‍♀' => 'dubartii goota: toonii gogaa ifaa',
    '🦸🏼‍♀' => 'dubartii goota: toonii gogaa ifaa-gidduugaleessa',
    '🦸🏽‍♀' => 'dubartii goota: toonii godaa gidduugaleessa',
    '🦸🏾‍♀' => 'dubartii goota: toonii gogaa gurraacha-gidduugaleessa',
    '🦸🏿‍♀' => 'dubartii goota: toonii gogaa gurraachaa',
    '🦹🏻‍♂' => 'dhiira jallataa: toonii gogaa ifaa',
    '🦹🏼‍♂' => 'dhiira jallataa: toonii gogaa ifaa-gidduugaleessa',
    '🦹🏽‍♂' => 'dhiira jallataa: toonii godaa gidduugaleessa',
    '🦹🏾‍♂' => 'dhiira jallataa: toonii gogaa gurraacha-gidduugaleessa',
    '🦹🏿‍♂' => 'dhiira jallataa: toonii gogaa gurraachaa',
    '🦹🏻‍♀' => 'dubartii jallattuu: toonii gogaa ifaa',
    '🦹🏼‍♀' => 'dubartii jallattuu: toonii gogaa ifaa-gidduugaleessa',
    '🦹🏽‍♀' => 'dubartii jallattuu: toonii godaa gidduugaleessa',
    '🦹🏾‍♀' => 'dubartii jallattuu: toonii gogaa gurraacha-gidduugaleessa',
    '🦹🏿‍♀' => 'dubartii jallattuu: toonii gogaa gurraachaa',
    '🧙🏻‍♂' => 'dhiira falfalaa: toonii gogaa ifaa',
    '🧙🏼‍♂' => 'dhiira falfalaa: toonii gogaa ifaa-gidduugaleessa',
    '🧙🏽‍♂' => 'dhiira falfalaa: toonii godaa gidduugaleessa',
    '🧙🏾‍♂' => 'dhiira falfalaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧙🏿‍♂' => 'dhiira falfalaa: toonii gogaa gurraachaa',
    '🧙🏻‍♀' => 'dubartii fafaltuu: toonii gogaa ifaa',
    '🧙🏼‍♀' => 'dubartii fafaltuu: toonii gogaa ifaa-gidduugaleessa',
    '🧙🏽‍♀' => 'dubartii fafaltuu: toonii godaa gidduugaleessa',
    '🧙🏾‍♀' => 'dubartii fafaltuu: toonii gogaa gurraacha-gidduugaleessa',
    '🧙🏿‍♀' => 'dubartii fafaltuu: toonii gogaa gurraachaa',
    '🧚🏻‍♂' => 'dhiira feerii: toonii gogaa ifaa',
    '🧚🏼‍♂' => 'dhiira feerii: toonii gogaa ifaa-gidduugaleessa',
    '🧚🏽‍♂' => 'dhiira feerii: toonii godaa gidduugaleessa',
    '🧚🏾‍♂' => 'dhiira feerii: toonii gogaa gurraacha-gidduugaleessa',
    '🧚🏿‍♂' => 'dhiira feerii: toonii gogaa gurraachaa',
    '🧚🏻‍♀' => 'dubartii feerii: toonii gogaa ifaa',
    '🧚🏼‍♀' => 'dubartii feerii: toonii gogaa ifaa-gidduugaleessa',
    '🧚🏽‍♀' => 'dubartii feerii: toonii godaa gidduugaleessa',
    '🧚🏾‍♀' => 'dubartii feerii: toonii gogaa gurraacha-gidduugaleessa',
    '🧚🏿‍♀' => 'dubartii feerii: toonii gogaa gurraachaa',
    '🧛🏻‍♂' => 'dhiira vaampaayerii: toonii gogaa ifaa',
    '🧛🏼‍♂' => 'dhiira vaampaayerii: toonii gogaa ifaa-gidduugaleessa',
    '🧛🏽‍♂' => 'dhiira vaampaayerii: toonii godaa gidduugaleessa',
    '🧛🏾‍♂' => 'dhiira vaampaayerii: toonii gogaa gurraacha-gidduugaleessa',
    '🧛🏿‍♂' => 'dhiira vaampaayerii: toonii gogaa gurraachaa',
    '🧛🏻‍♀' => 'dubartii vaampaayerii: toonii gogaa ifaa',
    '🧛🏼‍♀' => 'dubartii vaampaayerii: toonii gogaa ifaa-gidduugaleessa',
    '🧛🏽‍♀' => 'dubartii vaampaayerii: toonii godaa gidduugaleessa',
    '🧛🏾‍♀' => 'dubartii vaampaayerii: toonii gogaa gurraacha-gidduugaleessa',
    '🧛🏿‍♀' => 'dubartii vaampaayerii: toonii gogaa gurraachaa',
    '🧜🏻‍♂' => 'dhiira lo’u: toonii gogaa ifaa',
    '🧜🏼‍♂' => 'dhiira lo’u: toonii gogaa ifaa-gidduugaleessa',
    '🧜🏽‍♂' => 'dhiira lo’u: toonii godaa gidduugaleessa',
    '🧜🏾‍♂' => 'dhiira lo’u: toonii gogaa gurraacha-gidduugaleessa',
    '🧜🏿‍♂' => 'dhiira lo’u: toonii gogaa gurraachaa',
    '🧜🏻‍♀' => 'dubartii lootu: toonii gogaa ifaa',
    '🧜🏼‍♀' => 'dubartii lootu: toonii gogaa ifaa-gidduugaleessa',
    '🧜🏽‍♀' => 'dubartii lootu: toonii godaa gidduugaleessa',
    '🧜🏾‍♀' => 'dubartii lootu: toonii gogaa gurraacha-gidduugaleessa',
    '🧜🏿‍♀' => 'dubartii lootu: toonii gogaa gurraachaa',
    '💆🏻‍♂' => 'dhiira sukkuumamaa jiru: toonii gogaa ifaa',
    '💆🏼‍♂' => 'dhiira sukkuumamaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '💆🏽‍♂' => 'dhiira sukkuumamaa jiru: toonii godaa gidduugaleessa',
    '💆🏾‍♂' => 'dhiira sukkuumamaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '💆🏿‍♂' => 'dhiira sukkuumamaa jiru: toonii gogaa gurraachaa',
    '💆🏻‍♀' => 'dubartii sukkuumamaa jirtu: toonii gogaa ifaa',
    '💆🏼‍♀' => 'dubartii sukkuumamaa jirtu: toonii gogaa ifaa-gidduugaleessa',
    '💆🏽‍♀' => 'dubartii sukkuumamaa jirtu: toonii godaa gidduugaleessa',
    '💆🏾‍♀' => 'dubartii sukkuumamaa jirtu: toonii gogaa gurraacha-gidduugaleessa',
    '💆🏿‍♀' => 'dubartii sukkuumamaa jirtu: toonii gogaa gurraachaa',
    '💇🏻‍♂' => 'dhiira rifeensa sirreeffachaa jiru: toonii gogaa ifaa',
    '💇🏼‍♂' => 'dhiira rifeensa sirreeffachaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '💇🏽‍♂' => 'dhiira rifeensa sirreeffachaa jiru: toonii godaa gidduugaleessa',
    '💇🏾‍♂' => 'dhiira rifeensa sirreeffachaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '💇🏿‍♂' => 'dhiira rifeensa sirreeffachaa jiru: toonii gogaa gurraachaa',
    '💇🏻‍♀' => 'dubartii rifeensa sirreeffachaa jirtu: toonii gogaa ifaa',
    '💇🏼‍♀' => 'dubartii rifeensa sirreeffachaa jirtu: toonii gogaa ifaa-gidduugaleessa',
    '💇🏽‍♀' => 'dubartii rifeensa sirreeffachaa jirtu: toonii godaa gidduugaleessa',
    '💇🏾‍♀' => 'dubartii rifeensa sirreeffachaa jirtu: toonii gogaa gurraacha-gidduugaleessa',
    '💇🏿‍♀' => 'dubartii rifeensa sirreeffachaa jirtu: toonii gogaa gurraachaa',
    '🚶🏻‍♂' => 'dhiira deemaa jiru: toonii gogaa ifaa',
    '🚶🏼‍♂' => 'dhiira deemaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🚶🏽‍♂' => 'dhiira deemaa jiru: toonii godaa gidduugaleessa',
    '🚶🏾‍♂' => 'dhiira deemaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🚶🏿‍♂' => 'dhiira deemaa jiru: toonii gogaa gurraachaa',
    '🚶🏻‍♀' => 'dubartii deemaa jirtu: toonii gogaa ifaa',
    '🚶🏼‍♀' => 'dubartii deemaa jirtu: toonii gogaa ifaa-gidduugaleessa',
    '🚶🏽‍♀' => 'dubartii deemaa jirtu: toonii godaa gidduugaleessa',
    '🚶🏾‍♀' => 'dubartii deemaa jirtu: toonii gogaa gurraacha-gidduugaleessa',
    '🚶🏿‍♀' => 'dubartii deemaa jirtu: toonii gogaa gurraachaa',
    '🧍🏻‍♂' => 'dhiira dhaabbatu: toonii gogaa ifaa',
    '🧍🏼‍♂' => 'dhiira dhaabbatu: toonii gogaa ifaa-gidduugaleessa',
    '🧍🏽‍♂' => 'dhiira dhaabbatu: toonii godaa gidduugaleessa',
    '🧍🏾‍♂' => 'dhiira dhaabbatu: toonii gogaa gurraacha-gidduugaleessa',
    '🧍🏿‍♂' => 'dhiira dhaabbatu: toonii gogaa gurraachaa',
    '🧍🏻‍♀' => 'dubartii dhaabbattu: toonii gogaa ifaa',
    '🧍🏼‍♀' => 'dubartii dhaabbattu: toonii gogaa ifaa-gidduugaleessa',
    '🧍🏽‍♀' => 'dubartii dhaabbattu: toonii godaa gidduugaleessa',
    '🧍🏾‍♀' => 'dubartii dhaabbattu: toonii gogaa gurraacha-gidduugaleessa',
    '🧍🏿‍♀' => 'dubartii dhaabbattu: toonii gogaa gurraachaa',
    '🧎🏻‍♂' => 'dhiira jilbeeffate: toonii gogaa ifaa',
    '🧎🏼‍♂' => 'dhiira jilbeeffate: toonii gogaa ifaa-gidduugaleessa',
    '🧎🏽‍♂' => 'dhiira jilbeeffate: toonii godaa gidduugaleessa',
    '🧎🏾‍♂' => 'dhiira jilbeeffate: toonii gogaa gurraacha-gidduugaleessa',
    '🧎🏿‍♂' => 'dhiira jilbeeffate: toonii gogaa gurraachaa',
    '🧎🏻‍♀' => 'dubartii jilbeeffatte: toonii gogaa ifaa',
    '🧎🏼‍♀' => 'dubartii jilbeeffatte: toonii gogaa ifaa-gidduugaleessa',
    '🧎🏽‍♀' => 'dubartii jilbeeffatte: toonii godaa gidduugaleessa',
    '🧎🏾‍♀' => 'dubartii jilbeeffatte: toonii gogaa gurraacha-gidduugaleessa',
    '🧎🏿‍♀' => 'dubartii jilbeeffatte: toonii gogaa gurraachaa',
    '🧑🏻‍🦯' => 'nama shimala adii waliin: toonii gogaa ifaa',
    '🧑🏼‍🦯' => 'nama shimala adii waliin: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🦯' => 'nama shimala adii waliin: toonii godaa gidduugaleessa',
    '🧑🏾‍🦯' => 'nama shimala adii waliin: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🦯' => 'nama shimala adii waliin: toonii gogaa gurraachaa',
    '👨🏻‍🦯' => 'dhiira hokkoo adii waliin: toonii gogaa ifaa',
    '👨🏼‍🦯' => 'dhiira hokkoo adii waliin: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🦯' => 'dhiira hokkoo adii waliin: toonii godaa gidduugaleessa',
    '👨🏾‍🦯' => 'dhiira hokkoo adii waliin: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🦯' => 'dhiira hokkoo adii waliin: toonii gogaa gurraachaa',
    '👩🏻‍🦯' => 'dubartii hokkoo adii waliin: toonii gogaa ifaa',
    '👩🏼‍🦯' => 'dubartii hokkoo adii waliin: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🦯' => 'dubartii hokkoo adii waliin: toonii godaa gidduugaleessa',
    '👩🏾‍🦯' => 'dubartii hokkoo adii waliin: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🦯' => 'dubartii hokkoo adii waliin: toonii gogaa gurraachaa',
    '🧑🏻‍🦼' => 'nama wiilcherii motoraa irra: toonii gogaa ifaa',
    '🧑🏼‍🦼' => 'nama wiilcherii motoraa irra: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🦼' => 'nama wiilcherii motoraa irra: toonii godaa gidduugaleessa',
    '🧑🏾‍🦼' => 'nama wiilcherii motoraa irra: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🦼' => 'nama wiilcherii motoraa irra: toonii gogaa gurraachaa',
    '👨🏻‍🦼' => 'dhiira wiilcherii motoraa irra: toonii gogaa ifaa',
    '👨🏼‍🦼' => 'dhiira wiilcherii motoraa irra: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🦼' => 'dhiira wiilcherii motoraa irra: toonii godaa gidduugaleessa',
    '👨🏾‍🦼' => 'dhiira wiilcherii motoraa irra: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🦼' => 'dhiira wiilcherii motoraa irra: toonii gogaa gurraachaa',
    '👩🏻‍🦼' => 'dubartii wiilcherii motoraa irra: toonii gogaa ifaa',
    '👩🏼‍🦼' => 'dubartii wiilcherii motoraa irra: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🦼' => 'dubartii wiilcherii motoraa irra: toonii godaa gidduugaleessa',
    '👩🏾‍🦼' => 'dubartii wiilcherii motoraa irra: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🦼' => 'dubartii wiilcherii motoraa irra: toonii gogaa gurraachaa',
    '🧑🏻‍🦽' => 'nama wiilcherii harkaa irra: toonii gogaa ifaa',
    '🧑🏼‍🦽' => 'nama wiilcherii harkaa irra: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽‍🦽' => 'nama wiilcherii harkaa irra: toonii godaa gidduugaleessa',
    '🧑🏾‍🦽' => 'nama wiilcherii harkaa irra: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿‍🦽' => 'nama wiilcherii harkaa irra: toonii gogaa gurraachaa',
    '👨🏻‍🦽' => 'dhiira wiilcharii harkaa irra: toonii gogaa ifaa',
    '👨🏼‍🦽' => 'dhiira wiilcharii harkaa irra: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽‍🦽' => 'dhiira wiilcharii harkaa irra: toonii godaa gidduugaleessa',
    '👨🏾‍🦽' => 'dhiira wiilcharii harkaa irra: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿‍🦽' => 'dhiira wiilcharii harkaa irra: toonii gogaa gurraachaa',
    '👩🏻‍🦽' => 'dubartii wiilcherii harkaa irra: toonii gogaa ifaa',
    '👩🏼‍🦽' => 'dubartii wiilcherii harkaa irra: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽‍🦽' => 'dubartii wiilcherii harkaa irra: toonii godaa gidduugaleessa',
    '👩🏾‍🦽' => 'dubartii wiilcherii harkaa irra: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿‍🦽' => 'dubartii wiilcherii harkaa irra: toonii gogaa gurraachaa',
    '🏃🏻‍♂' => 'dhiira fiigu: toonii gogaa ifaa',
    '🏃🏼‍♂' => 'dhiira fiigu: toonii gogaa ifaa-gidduugaleessa',
    '🏃🏽‍♂' => 'dhiira fiigu: toonii godaa gidduugaleessa',
    '🏃🏾‍♂' => 'dhiira fiigu: toonii gogaa gurraacha-gidduugaleessa',
    '🏃🏿‍♂' => 'dhiira fiigu: toonii gogaa gurraachaa',
    '🏃🏻‍♀' => 'dubartii fiigdu: toonii gogaa ifaa',
    '🏃🏼‍♀' => 'dubartii fiigdu: toonii gogaa ifaa-gidduugaleessa',
    '🏃🏽‍♀' => 'dubartii fiigdu: toonii godaa gidduugaleessa',
    '🏃🏾‍♀' => 'dubartii fiigdu: toonii gogaa gurraacha-gidduugaleessa',
    '🏃🏿‍♀' => 'dubartii fiigdu: toonii gogaa gurraachaa',
    '👯🏻‍♀' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa',
    '👯🏼‍♀' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa',
    '👯🏽‍♀' => 'dubartoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa',
    '👯🏾‍♀' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa',
    '👯🏿‍♀' => 'dubartoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa',
    '👯🏻‍♂' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa',
    '👯🏼‍♂' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa',
    '👯🏽‍♂' => 'dhiirota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa',
    '👯🏾‍♂' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa',
    '👯🏿‍♂' => 'dhiirota gurra baanii ofirraa qaban: toonii gogaa gurraachaa',
    '🧖🏻‍♂' => 'dhiira kutaa hurkaa keessaa: toonii gogaa ifaa',
    '🧖🏼‍♂' => 'dhiira kutaa hurkaa keessaa: toonii gogaa ifaa-gidduugaleessa',
    '🧖🏽‍♂' => 'dhiira kutaa hurkaa keessaa: toonii godaa gidduugaleessa',
    '🧖🏾‍♂' => 'dhiira kutaa hurkaa keessaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧖🏿‍♂' => 'dhiira kutaa hurkaa keessaa: toonii gogaa gurraachaa',
    '🧖🏻‍♀' => 'dubartii kutaa hurkaa keessaa: toonii gogaa ifaa',
    '🧖🏼‍♀' => 'dubartii kutaa hurkaa keessaa: toonii gogaa ifaa-gidduugaleessa',
    '🧖🏽‍♀' => 'dubartii kutaa hurkaa keessaa: toonii godaa gidduugaleessa',
    '🧖🏾‍♀' => 'dubartii kutaa hurkaa keessaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧖🏿‍♀' => 'dubartii kutaa hurkaa keessaa: toonii gogaa gurraachaa',
    '🧗🏻‍♂' => 'dhiira yaabbachaa jiru: toonii gogaa ifaa',
    '🧗🏼‍♂' => 'dhiira yaabbachaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🧗🏽‍♂' => 'dhiira yaabbachaa jiru: toonii godaa gidduugaleessa',
    '🧗🏾‍♂' => 'dhiira yaabbachaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🧗🏿‍♂' => 'dhiira yaabbachaa jiru: toonii gogaa gurraachaa',
    '🧗🏻‍♀' => 'dubartii yaabbachaa jirtu: toonii gogaa ifaa',
    '🧗🏼‍♀' => 'dubartii yaabbachaa jirtu: toonii gogaa ifaa-gidduugaleessa',
    '🧗🏽‍♀' => 'dubartii yaabbachaa jirtu: toonii godaa gidduugaleessa',
    '🧗🏾‍♀' => 'dubartii yaabbachaa jirtu: toonii gogaa gurraacha-gidduugaleessa',
    '🧗🏿‍♀' => 'dubartii yaabbachaa jirtu: toonii gogaa gurraachaa',
    '🏌🏻‍♂' => 'dhiira golfii taphatu: toonii gogaa ifaa',
    '🏌🏼‍♂' => 'dhiira golfii taphatu: toonii gogaa ifaa-gidduugaleessa',
    '🏌🏽‍♂' => 'dhiira golfii taphatu: toonii godaa gidduugaleessa',
    '🏌🏾‍♂' => 'dhiira golfii taphatu: toonii gogaa gurraacha-gidduugaleessa',
    '🏌🏿‍♂' => 'dhiira golfii taphatu: toonii gogaa gurraachaa',
    '🏌🏻‍♀' => 'dubartii golfii taphattu: toonii gogaa ifaa',
    '🏌🏼‍♀' => 'dubartii golfii taphattu: toonii gogaa ifaa-gidduugaleessa',
    '🏌🏽‍♀' => 'dubartii golfii taphattu: toonii godaa gidduugaleessa',
    '🏌🏾‍♀' => 'dubartii golfii taphattu: toonii gogaa gurraacha-gidduugaleessa',
    '🏌🏿‍♀' => 'dubartii golfii taphattu: toonii gogaa gurraachaa',
    '🏄🏻‍♂' => 'dhiira bololi’u: toonii gogaa ifaa',
    '🏄🏼‍♂' => 'dhiira bololi’u: toonii gogaa ifaa-gidduugaleessa',
    '🏄🏽‍♂' => 'dhiira bololi’u: toonii godaa gidduugaleessa',
    '🏄🏾‍♂' => 'dhiira bololi’u: toonii gogaa gurraacha-gidduugaleessa',
    '🏄🏿‍♂' => 'dhiira bololi’u: toonii gogaa gurraachaa',
    '🏄🏻‍♀' => 'dubartii bololiitu: toonii gogaa ifaa',
    '🏄🏼‍♀' => 'dubartii bololiitu: toonii gogaa ifaa-gidduugaleessa',
    '🏄🏽‍♀' => 'dubartii bololiitu: toonii godaa gidduugaleessa',
    '🏄🏾‍♀' => 'dubartii bololiitu: toonii gogaa gurraacha-gidduugaleessa',
    '🏄🏿‍♀' => 'dubartii bololiitu: toonii gogaa gurraachaa',
    '🚣🏻‍♂' => 'dhiira bidiruu oofu: toonii gogaa ifaa',
    '🚣🏼‍♂' => 'dhiira bidiruu oofu: toonii gogaa ifaa-gidduugaleessa',
    '🚣🏽‍♂' => 'dhiira bidiruu oofu: toonii godaa gidduugaleessa',
    '🚣🏾‍♂' => 'dhiira bidiruu oofu: toonii gogaa gurraacha-gidduugaleessa',
    '🚣🏿‍♂' => 'dhiira bidiruu oofu: toonii gogaa gurraachaa',
    '🚣🏻‍♀' => 'dubartii bidiruu oofu: toonii gogaa ifaa',
    '🚣🏼‍♀' => 'dubartii bidiruu oofu: toonii gogaa ifaa-gidduugaleessa',
    '🚣🏽‍♀' => 'dubartii bidiruu oofu: toonii godaa gidduugaleessa',
    '🚣🏾‍♀' => 'dubartii bidiruu oofu: toonii gogaa gurraacha-gidduugaleessa',
    '🚣🏿‍♀' => 'dubartii bidiruu oofu: toonii gogaa gurraachaa',
    '🏊🏻‍♂' => 'dhiira daakaa jiru: toonii gogaa ifaa',
    '🏊🏼‍♂' => 'dhiira daakaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🏊🏽‍♂' => 'dhiira daakaa jiru: toonii godaa gidduugaleessa',
    '🏊🏾‍♂' => 'dhiira daakaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🏊🏿‍♂' => 'dhiira daakaa jiru: toonii gogaa gurraachaa',
    '🏊🏻‍♀' => 'dubartii daakaa jirtu: toonii gogaa ifaa',
    '🏊🏼‍♀' => 'dubartii daakaa jirtu: toonii gogaa ifaa-gidduugaleessa',
    '🏊🏽‍♀' => 'dubartii daakaa jirtu: toonii godaa gidduugaleessa',
    '🏊🏾‍♀' => 'dubartii daakaa jirtu: toonii gogaa gurraacha-gidduugaleessa',
    '🏊🏿‍♀' => 'dubartii daakaa jirtu: toonii gogaa gurraachaa',
    '⛹🏻‍♂' => 'dhiira kubbaa utaalchisu: toonii gogaa ifaa',
    '⛹🏼‍♂' => 'dhiira kubbaa utaalchisu: toonii gogaa ifaa-gidduugaleessa',
    '⛹🏽‍♂' => 'dhiira kubbaa utaalchisu: toonii godaa gidduugaleessa',
    '⛹🏾‍♂' => 'dhiira kubbaa utaalchisu: toonii gogaa gurraacha-gidduugaleessa',
    '⛹🏿‍♂' => 'dhiira kubbaa utaalchisu: toonii gogaa gurraachaa',
    '⛹🏻‍♀' => 'dubartii kubbaa utaalchistu: toonii gogaa ifaa',
    '⛹🏼‍♀' => 'dubartii kubbaa utaalchistu: toonii gogaa ifaa-gidduugaleessa',
    '⛹🏽‍♀' => 'dubartii kubbaa utaalchistu: toonii godaa gidduugaleessa',
    '⛹🏾‍♀' => 'dubartii kubbaa utaalchistu: toonii gogaa gurraacha-gidduugaleessa',
    '⛹🏿‍♀' => 'dubartii kubbaa utaalchistu: toonii gogaa gurraachaa',
    '🏋🏻‍♂' => 'dhiira ulfaatina kaasu: toonii gogaa ifaa',
    '🏋🏼‍♂' => 'dhiira ulfaatina kaasu: toonii gogaa ifaa-gidduugaleessa',
    '🏋🏽‍♂' => 'dhiira ulfaatina kaasu: toonii godaa gidduugaleessa',
    '🏋🏾‍♂' => 'dhiira ulfaatina kaasu: toonii gogaa gurraacha-gidduugaleessa',
    '🏋🏿‍♂' => 'dhiira ulfaatina kaasu: toonii gogaa gurraachaa',
    '🏋🏻‍♀' => 'dubartii ulfaatina kaastu: toonii gogaa ifaa',
    '🏋🏼‍♀' => 'dubartii ulfaatina kaastu: toonii gogaa ifaa-gidduugaleessa',
    '🏋🏽‍♀' => 'dubartii ulfaatina kaastu: toonii godaa gidduugaleessa',
    '🏋🏾‍♀' => 'dubartii ulfaatina kaastu: toonii gogaa gurraacha-gidduugaleessa',
    '🏋🏿‍♀' => 'dubartii ulfaatina kaastu: toonii gogaa gurraachaa',
    '🚴🏻‍♂' => 'dhiira biskileetii oofu: toonii gogaa ifaa',
    '🚴🏼‍♂' => 'dhiira biskileetii oofu: toonii gogaa ifaa-gidduugaleessa',
    '🚴🏽‍♂' => 'dhiira biskileetii oofu: toonii godaa gidduugaleessa',
    '🚴🏾‍♂' => 'dhiira biskileetii oofu: toonii gogaa gurraacha-gidduugaleessa',
    '🚴🏿‍♂' => 'dhiira biskileetii oofu: toonii gogaa gurraachaa',
    '🚴🏻‍♀' => 'dubartii biskileetii ooftu: toonii gogaa ifaa',
    '🚴🏼‍♀' => 'dubartii biskileetii ooftu: toonii gogaa ifaa-gidduugaleessa',
    '🚴🏽‍♀' => 'dubartii biskileetii ooftu: toonii godaa gidduugaleessa',
    '🚴🏾‍♀' => 'dubartii biskileetii ooftu: toonii gogaa gurraacha-gidduugaleessa',
    '🚴🏿‍♀' => 'dubartii biskileetii ooftu: toonii gogaa gurraachaa',
    '🚵🏻‍♂' => 'dhiira biskileetiin tulluu bahu: toonii gogaa ifaa',
    '🚵🏼‍♂' => 'dhiira biskileetiin tulluu bahu: toonii gogaa ifaa-gidduugaleessa',
    '🚵🏽‍♂' => 'dhiira biskileetiin tulluu bahu: toonii godaa gidduugaleessa',
    '🚵🏾‍♂' => 'dhiira biskileetiin tulluu bahu: toonii gogaa gurraacha-gidduugaleessa',
    '🚵🏿‍♂' => 'dhiira biskileetiin tulluu bahu: toonii gogaa gurraachaa',
    '🚵🏻‍♀' => 'dubartii biskileetiin tulluu baatu: toonii gogaa ifaa',
    '🚵🏼‍♀' => 'dubartii biskileetiin tulluu baatu: toonii gogaa ifaa-gidduugaleessa',
    '🚵🏽‍♀' => 'dubartii biskileetiin tulluu baatu: toonii godaa gidduugaleessa',
    '🚵🏾‍♀' => 'dubartii biskileetiin tulluu baatu: toonii gogaa gurraacha-gidduugaleessa',
    '🚵🏿‍♀' => 'dubartii biskileetiin tulluu baatu: toonii gogaa gurraachaa',
    '🤸🏻‍♂' => 'dhiira harkaan garagalu: toonii gogaa ifaa',
    '🤸🏼‍♂' => 'dhiira harkaan garagalu: toonii gogaa ifaa-gidduugaleessa',
    '🤸🏽‍♂' => 'dhiira harkaan garagalu: toonii godaa gidduugaleessa',
    '🤸🏾‍♂' => 'dhiira harkaan garagalu: toonii gogaa gurraacha-gidduugaleessa',
    '🤸🏿‍♂' => 'dhiira harkaan garagalu: toonii gogaa gurraachaa',
    '🤸🏻‍♀' => 'dubartii harkaan garagaltu: toonii gogaa ifaa',
    '🤸🏼‍♀' => 'dubartii harkaan garagaltu: toonii gogaa ifaa-gidduugaleessa',
    '🤸🏽‍♀' => 'dubartii harkaan garagaltu: toonii godaa gidduugaleessa',
    '🤸🏾‍♀' => 'dubartii harkaan garagaltu: toonii gogaa gurraacha-gidduugaleessa',
    '🤸🏿‍♀' => 'dubartii harkaan garagaltu: toonii gogaa gurraachaa',
    '🤼🏻‍♀' => 'dubartoota wal tuman: toonii gogaa ifaa',
    '🤼🏼‍♀' => 'dubartoota wal tuman: toonii gogaa ifaa-gidduugaleessa',
    '🤼🏽‍♀' => 'dubartoota wal tuman: toonii godaa gidduugaleessa',
    '🤼🏾‍♀' => 'dubartoota wal tuman: toonii gogaa gurraacha-gidduugaleessa',
    '🤼🏿‍♀' => 'dubartoota wal tuman: toonii gogaa gurraachaa',
    '🤼🏻‍♂' => 'dhiirota wal tuman: toonii gogaa ifaa',
    '🤼🏼‍♂' => 'dhiirota wal tuman: toonii gogaa ifaa-gidduugaleessa',
    '🤼🏽‍♂' => 'dhiirota wal tuman: toonii godaa gidduugaleessa',
    '🤼🏾‍♂' => 'dhiirota wal tuman: toonii gogaa gurraacha-gidduugaleessa',
    '🤼🏿‍♂' => 'dhiirota wal tuman: toonii gogaa gurraachaa',
    '🤽🏻‍♂' => 'dhiira pooloo bishaanii taphachaa jiru: toonii gogaa ifaa',
    '🤽🏼‍♂' => 'dhiira pooloo bishaanii taphachaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🤽🏽‍♂' => 'dhiira pooloo bishaanii taphachaa jiru: toonii godaa gidduugaleessa',
    '🤽🏾‍♂' => 'dhiira pooloo bishaanii taphachaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🤽🏿‍♂' => 'dhiira pooloo bishaanii taphachaa jiru: toonii gogaa gurraachaa',
    '🤽🏻‍♀' => 'dubartii pooloo bishaanii taphachaa jirtu: toonii gogaa ifaa',
    '🤽🏼‍♀' => 'dubartii pooloo bishaanii taphachaa jirtu: toonii gogaa ifaa-gidduugaleessa',
    '🤽🏽‍♀' => 'dubartii pooloo bishaanii taphachaa jirtu: toonii godaa gidduugaleessa',
    '🤽🏾‍♀' => 'dubartii pooloo bishaanii taphachaa jirtu: toonii gogaa gurraacha-gidduugaleessa',
    '🤽🏿‍♀' => 'dubartii pooloo bishaanii taphachaa jirtu: toonii gogaa gurraachaa',
    '🤾🏻‍♂' => 'dhiira kubbaa harkaa taphachaa jiru: toonii gogaa ifaa',
    '🤾🏼‍♂' => 'dhiira kubbaa harkaa taphachaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🤾🏽‍♂' => 'dhiira kubbaa harkaa taphachaa jiru: toonii godaa gidduugaleessa',
    '🤾🏾‍♂' => 'dhiira kubbaa harkaa taphachaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🤾🏿‍♂' => 'dhiira kubbaa harkaa taphachaa jiru: toonii gogaa gurraachaa',
    '🤾🏻‍♀' => 'dubartii kubbaa harkaa taphachaa jirtu: toonii gogaa ifaa',
    '🤾🏼‍♀' => 'dubartii kubbaa harkaa taphachaa jirtu: toonii gogaa ifaa-gidduugaleessa',
    '🤾🏽‍♀' => 'dubartii kubbaa harkaa taphachaa jirtu: toonii godaa gidduugaleessa',
    '🤾🏾‍♀' => 'dubartii kubbaa harkaa taphachaa jirtu: toonii gogaa gurraacha-gidduugaleessa',
    '🤾🏿‍♀' => 'dubartii kubbaa harkaa taphachaa jirtu: toonii gogaa gurraachaa',
    '🤹🏻‍♂' => 'dhiira waa ol daddarbatee qabatu: toonii gogaa ifaa',
    '🤹🏼‍♂' => 'dhiira waa ol daddarbatee qabatu: toonii gogaa ifaa-gidduugaleessa',
    '🤹🏽‍♂' => 'dhiira waa ol daddarbatee qabatu: toonii godaa gidduugaleessa',
    '🤹🏾‍♂' => 'dhiira waa ol daddarbatee qabatu: toonii gogaa gurraacha-gidduugaleessa',
    '🤹🏿‍♂' => 'dhiira waa ol daddarbatee qabatu: toonii gogaa gurraachaa',
    '🤹🏻‍♀' => 'dubartii waa ol daddarbattee qabattu: toonii gogaa ifaa',
    '🤹🏼‍♀' => 'dubartii waa ol daddarbattee qabattu: toonii gogaa ifaa-gidduugaleessa',
    '🤹🏽‍♀' => 'dubartii waa ol daddarbattee qabattu: toonii godaa gidduugaleessa',
    '🤹🏾‍♀' => 'dubartii waa ol daddarbattee qabattu: toonii gogaa gurraacha-gidduugaleessa',
    '🤹🏿‍♀' => 'dubartii waa ol daddarbattee qabattu: toonii gogaa gurraachaa',
    '🧘🏻‍♂' => 'dhiira lootasii irra jiru: toonii gogaa ifaa',
    '🧘🏼‍♂' => 'dhiira lootasii irra jiru: toonii gogaa ifaa-gidduugaleessa',
    '🧘🏽‍♂' => 'dhiira lootasii irra jiru: toonii godaa gidduugaleessa',
    '🧘🏾‍♂' => 'dhiira lootasii irra jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🧘🏿‍♂' => 'dhiira lootasii irra jiru: toonii gogaa gurraachaa',
    '🧘🏻‍♀' => 'dubartii lootasii irra jirtu: toonii gogaa ifaa',
    '🧘🏼‍♀' => 'dubartii lootasii irra jirtu: toonii gogaa ifaa-gidduugaleessa',
    '🧘🏽‍♀' => 'dubartii lootasii irra jirtu: toonii godaa gidduugaleessa',
    '🧘🏾‍♀' => 'dubartii lootasii irra jirtu: toonii gogaa gurraacha-gidduugaleessa',
    '🧘🏿‍♀' => 'dubartii lootasii irra jirtu: toonii gogaa gurraachaa',
    '🧑‍🦰' => 'nama: rifeensa diimaa',
    '🧑‍🦱' => 'nama: rifeensa luuccaa',
    '🧑‍🦳' => 'nama: rifeensa adii',
    '🧑‍🦲' => 'nama: moluu',
    '👨‍🦰' => 'dhiira: rifeensa diimaa',
    '👨‍🦱' => 'dhiira: rifeensa luuccaa',
    '👨‍🦳' => 'dhiira: rifeensa adii',
    '👨‍🦲' => 'dhiira: moluu',
    '👩‍🦰' => 'dubartii: rifeensa diimaa',
    '👩‍🦱' => 'dubartii: rifeensa luuccaa',
    '👩‍🦳' => 'dubartii: rifeensa adii',
    '👩‍🦲' => 'dubartii: moluu',
    '👨‍👦' => 'maatii: dhiira, gurbaa',
    '👨‍👧' => 'maatii: dhiira, dubara',
    '👩‍👦' => 'maatii: dubartii, gurbaa',
    '👩‍👧' => 'maatii: dubartii, dubara',
    '😮‍💨' => 'fuula hafuura baafatu',
    '🙂‍↕' => 'mataa oliif gadi raasuu',
    '😵‍💫' => 'fuula ija maraa waliin',
    '❤‍🔥' => 'onnee ibidda irra jiru',
    '❤‍🩹' => 'onnee suphuu',
    '👁‍🗨' => 'ija afuuffee dubbii keessaa',
    '🧔‍♂' => 'dhiira: areeda qabu',
    '👱‍♂' => 'dhiira: rifeensa keelloo',
    '🧔‍♀' => 'dubartii: areeda qabdu',
    '👱‍♀' => 'dubartii: rifeensa keelloo',
    '🙍‍♂' => 'dhiira mufate',
    '🙍‍♀' => 'dubartii mufatte',
    '🙎‍♂' => 'dhiira huuruu dhiibu',
    '🙎‍♀' => 'dubartii huuruu dhiibdu',
    '🙅‍♂' => 'dhiira LAKKI jedhu',
    '🙅‍♀' => 'dubartii LAKKI jettu',
    '🙆‍♂' => 'dhiira TOLE jedhu',
    '🙆‍♀' => 'dubartii TOLE jettu',
    '💁‍♂' => 'dhiira harka diriirsu',
    '💁‍♀' => 'dubartii harka diriirsitu',
    '🙋‍♂' => 'dhiira harka baasu',
    '🙋‍♀' => 'dubartii harka baastu',
    '🧏‍♂' => 'dhiira duudaa',
    '🧏‍♀' => 'dubartii duudaa',
    '🙇‍♂' => 'dhiira sagadu',
    '🙇‍♀' => 'dubartii sagaddu',
    '🤦‍♂' => 'dhiira barruun fuula qabate',
    '🤦‍♀' => 'dubartii barruun fuula qabatte',
    '🤷‍♂' => 'dhiira mataa raasu',
    '🤷‍♀' => 'dubartii mataa raastu',
    '🧑‍⚕' => 'hojjetaa fayyaa',
    '👨‍⚕' => 'dhiira hojjetaa fayyaa',
    '👩‍⚕' => 'dubartii hojjettuu fayyaa',
    '🧑‍🎓' => 'barataa',
    '👨‍🎓' => 'dhiira barataa',
    '👩‍🎓' => 'dubartii barattuu',
    '🧑‍🏫' => 'barsiisaa',
    '👨‍🏫' => 'dhiira barsiisaa',
    '👩‍🏫' => 'dubartii barsiistuu',
    '🧑‍⚖' => 'abbaa murtii',
    '👨‍⚖' => 'dhiira abbaa murtii',
    '👩‍⚖' => 'dubartii haadha murtii',
    '🧑‍🌾' => 'qotee bulaa',
    '👨‍🌾' => 'dhiira qotee bulaa',
    '👩‍🌾' => 'dubartii qottee bultuu',
    '🧑‍🍳' => 'nama nyaata bilcheessu',
    '👨‍🍳' => 'dhiira nyaata bilcheessu',
    '👩‍🍳' => 'dubartii nyaata hojjettu',
    '🧑‍🔧' => 'mekaanikii',
    '👨‍🔧' => 'dhiira makaanikii',
    '👩‍🔧' => 'dubartii makaanikii',
    '🧑‍🏭' => 'hojjetaa waarshaa',
    '👨‍🏭' => 'dhiira hojjetaa waarshaa',
    '👩‍🏭' => 'dubartii hojjettuu waarshaa',
    '🧑‍💼' => 'hoojjetaa waajjiraa',
    '👨‍💼' => 'dhiira hojjetaa waajjiraa',
    '👩‍💼' => 'dubartii hojjettuu waajjiraa',
    '🧑‍🔬' => 'saayintistii',
    '👨‍🔬' => 'dhiira saayintistii',
    '👩‍🔬' => 'dubartii saayintistii',
    '🧑‍💻' => 'ogeessa tekinoloojii',
    '👨‍💻' => 'dhiira ogeessa tekinoloojii',
    '👩‍💻' => 'dubartii ogeettii tekinoloojii',
    '🧑‍🎤' => 'sirbituu',
    '👨‍🎤' => 'dhiira sirbu',
    '👩‍🎤' => 'dubartii sirbituu',
    '🧑‍🎨' => 'artistii',
    '👨‍🎨' => 'dhiira artistii',
    '👩‍🎨' => 'dubartii artistii',
    '🧑‍✈' => 'paayileetii',
    '👨‍✈' => 'dhiira paayileetii',
    '👩‍✈' => 'dubartii paayileetii',
    '🧑‍🚀' => 'ogeessa astiroonoomii',
    '👨‍🚀' => 'dhiira ogeessa astiroonoomii',
    '👩‍🚀' => 'dubarii ogeettii astiroonoomi',
    '🧑‍🚒' => 'nama ibidda dhaamsu',
    '👨‍🚒' => 'dhiira hojjetaa balaa ibiddaa',
    '👩‍🚒' => 'dubartii hojjettuu balaa ibiddaa',
    '👮‍♂' => 'dhiira qondaala poolisii',
    '👮‍♀' => 'dubartii qondaala poolisii',
    '🕵‍♂' => 'dhiira qorataa',
    '🕵‍♀' => 'dubartii qorattuu',
    '💂‍♂' => 'dhiira eegaa',
    '💂‍♀' => 'dubartii eegduu',
    '👷‍♂' => 'dhiira hojjetaa ijaarsaa',
    '👷‍♀' => 'dubartii hojjettuu ijaarsaa',
    '👳‍♂' => 'dhiira turbaanii uffatu',
    '👳‍♀' => 'dubartii turbaanii uffattu',
    '🤵‍♂' => 'dhiira bijaamaa uffate',
    '🤵‍♀' => 'dubartii bijaamaa uffatte',
    '👰‍♂' => 'dhiira golgaa waliin',
    '👰‍♀' => 'dubartii golgaa waliin',
    '👩‍🍼' => 'dubartii daa’ima nyaachistu',
    '👨‍🍼' => 'dhiira daa’ima nyaachisu',
    '🧑‍🍼' => 'nama daa’ima nyaachisu',
    '🧑‍🎄' => 'Kilaawosii qillee',
    '🦸‍♂' => 'dhiira goota',
    '🦸‍♀' => 'dubartii goota',
    '🦹‍♂' => 'dhiira jallataa',
    '🦹‍♀' => 'dubartii jallattuu',
    '🧙‍♂' => 'dhiira falfalaa',
    '🧙‍♀' => 'dubartii fafaltuu',
    '🧚‍♂' => 'dhiira feerii',
    '🧚‍♀' => 'dubartii feerii',
    '🧛‍♂' => 'dhiira vaampaayerii',
    '🧛‍♀' => 'dubartii vaampaayerii',
    '🧜‍♂' => 'dhiira lo’u',
    '🧜‍♀' => 'dubartii lootu',
    '💆‍♂' => 'dhiira sukkuumamaa jiru',
    '💆‍♀' => 'dubartii sukkuumamaa jirtu',
    '💇‍♂' => 'dhiira rifeensa sirreeffachaa jiru',
    '💇‍♀' => 'dubartii rifeensa sirreeffachaa jirtu',
    '🚶‍♂' => 'dhiira deemaa jiru',
    '🚶‍♀' => 'dubartii deemaa jirtu',
    '🧍‍♂' => 'dhiira dhaabbatu',
    '🧍‍♀' => 'dubartii dhaabbattu',
    '🧎‍♂' => 'dhiira jilbeeffate',
    '🧎‍♀' => 'dubartii jilbeeffatte',
    '🧑‍🦯' => 'nama shimala adii waliin',
    '👨‍🦯' => 'dhiira hokkoo adii waliin',
    '👩‍🦯' => 'dubartii hokkoo adii waliin',
    '🧑‍🦼' => 'nama wiilcherii motoraa irra',
    '👨‍🦼' => 'dhiira wiilcherii motoraa irra',
    '👩‍🦼' => 'dubartii wiilcherii motoraa irra',
    '🧑‍🦽' => 'nama wiilcherii harkaa irra',
    '👨‍🦽' => 'dhiira wiilcharii harkaa irra',
    '👩‍🦽' => 'dubartii wiilcherii harkaa irra',
    '🏃‍♂' => 'dhiira fiigu',
    '🏃‍♀' => 'dubartii fiigdu',
    '🧑‍🩰' => 'shubbisaa baaleetii',
    '👯‍♂' => 'dhiirota gurra baanii ofirraa qaban',
    '👯‍♀' => 'dubartoota gurra baanii ofirraa qaban',
    '🧖‍♂' => 'dhiira kutaa hurkaa keessaa',
    '🧖‍♀' => 'dubartii kutaa hurkaa keessaa',
    '🧗‍♂' => 'dhiira yaabbachaa jiru',
    '🧗‍♀' => 'dubartii yaabbachaa jirtu',
    '🏌‍♂' => 'dhiira golfii taphatu',
    '🏌‍♀' => 'dubartii golfii taphattu',
    '🏄‍♂' => 'dhiira bololi’u',
    '🏄‍♀' => 'dubartii bololiitu',
    '🚣‍♂' => 'dhiira bidiruu oofu',
    '🚣‍♀' => 'dubartii bidiruu oofu',
    '🏊‍♂' => 'dhiira daakaa jiru',
    '🏊‍♀' => 'dubartii daakaa jirtu',
    '⛹‍♂' => 'dhiira kubbaa utaalchisu',
    '⛹‍♀' => 'dubartii kubbaa utaalchistu',
    '🏋‍♂' => 'dhiira ulfaatina kaasu',
    '🏋‍♀' => 'dubartii ulfaatina kaastu',
    '🚴‍♂' => 'dhiira biskileetii oofu',
    '🚴‍♀' => 'dubartii biskileetii ooftu',
    '🚵‍♂' => 'dhiira biskileetiin tulluu bahu',
    '🚵‍♀' => 'dubartii biskileetiin tulluu baatu',
    '🤸‍♂' => 'dhiira harkaan garagalu',
    '🤸‍♀' => 'dubartii harkaan garagaltu',
    '🤼‍♂' => 'dhiirota wal tuman',
    '🤼‍♀' => 'dubartoota wal tuman',
    '🤽‍♂' => 'dhiira pooloo bishaanii taphachaa jiru',
    '🤽‍♀' => 'dubartii pooloo bishaanii taphachaa jirtu',
    '🤾‍♂' => 'dhiira kubbaa harkaa taphachaa jiru',
    '🤾‍♀' => 'dubartii kubbaa harkaa taphachaa jirtu',
    '🤹‍♂' => 'dhiira waa ol daddarbatee qabatu',
    '🤹‍♀' => 'dubartii waa ol daddarbattee qabattu',
    '🧘‍♂' => 'dhiira lootasii irra jiru',
    '🧘‍♀' => 'dubartii lootasii irra jirtu',
    '🐕‍🦺' => 'saree tajaajilaa',
    '🐈‍⬛' => 'adurree gurraattii',
    '🐻‍❄' => 'poolaar biir',
    '🐦‍⬛' => 'simbirroo gurraattii',
    '🐦‍🔥' => 'foyeeniksii',
    '🍋‍🟩' => 'liimee',
    '🍄‍🟫' => 'waakkoo magaala',
    '⛓‍💥' => 'cancala cabe',
    '🏳‍🌈' => 'alaabaa sabbata waaqayyoo',
    '🏳‍⚧' => 'alaabaa saala jijjiirrachuu',
    '🏴‍☠' => 'alaabaa saamtotaa',
    '👋🏻' => 'harka raasuu: toonii gogaa ifaa',
    '👋🏼' => 'harka raasuu: toonii gogaa ifaa-gidduugaleessa',
    '👋🏽' => 'harka raasuu: toonii godaa gidduugaleessa',
    '👋🏾' => 'harka raasuu: toonii gogaa gurraacha-gidduugaleessa',
    '👋🏿' => 'harka raasuu: toonii gogaa gurraachaa',
    '🤚🏻' => 'duuba harkaa ol baasuu: toonii gogaa ifaa',
    '🤚🏼' => 'duuba harkaa ol baasuu: toonii gogaa ifaa-gidduugaleessa',
    '🤚🏽' => 'duuba harkaa ol baasuu: toonii godaa gidduugaleessa',
    '🤚🏾' => 'duuba harkaa ol baasuu: toonii gogaa gurraacha-gidduugaleessa',
    '🤚🏿' => 'duuba harkaa ol baasuu: toonii gogaa gurraachaa',
    '🖐🏻' => 'harka quba bal’isuun: toonii gogaa ifaa',
    '🖐🏼' => 'harka quba bal’isuun: toonii gogaa ifaa-gidduugaleessa',
    '🖐🏽' => 'harka quba bal’isuun: toonii godaa gidduugaleessa',
    '🖐🏾' => 'harka quba bal’isuun: toonii gogaa gurraacha-gidduugaleessa',
    '🖐🏿' => 'harka quba bal’isuun: toonii gogaa gurraachaa',
    '✋🏻' => 'harka ol ba’e: toonii gogaa ifaa',
    '✋🏼' => 'harka ol ba’e: toonii gogaa ifaa-gidduugaleessa',
    '✋🏽' => 'harka ol ba’e: toonii godaa gidduugaleessa',
    '✋🏾' => 'harka ol ba’e: toonii gogaa gurraacha-gidduugaleessa',
    '✋🏿' => 'harka ol ba’e: toonii gogaa gurraachaa',
    '🖖🏻' => 'vuulkaan saluutee: toonii gogaa ifaa',
    '🖖🏼' => 'vuulkaan saluutee: toonii gogaa ifaa-gidduugaleessa',
    '🖖🏽' => 'vuulkaan saluutee: toonii godaa gidduugaleessa',
    '🖖🏾' => 'vuulkaan saluutee: toonii gogaa gurraacha-gidduugaleessa',
    '🖖🏿' => 'vuulkaan saluutee: toonii gogaa gurraachaa',
    '🫱🏻' => 'harka gara mirgaatti: toonii gogaa ifaa',
    '🫱🏼' => 'harka gara mirgaatti: toonii gogaa ifaa-gidduugaleessa',
    '🫱🏽' => 'harka gara mirgaatti: toonii godaa gidduugaleessa',
    '🫱🏾' => 'harka gara mirgaatti: toonii gogaa gurraacha-gidduugaleessa',
    '🫱🏿' => 'harka gara mirgaatti: toonii gogaa gurraachaa',
    '🫲🏻' => 'harka gara bitaatti: toonii gogaa ifaa',
    '🫲🏼' => 'harka gara bitaatti: toonii gogaa ifaa-gidduugaleessa',
    '🫲🏽' => 'harka gara bitaatti: toonii godaa gidduugaleessa',
    '🫲🏾' => 'harka gara bitaatti: toonii gogaa gurraacha-gidduugaleessa',
    '🫲🏿' => 'harka gara bitaatti: toonii gogaa gurraachaa',
    '🫳🏻' => 'harka barruu gadi garagale: toonii gogaa ifaa',
    '🫳🏼' => 'harka barruu gadi garagale: toonii gogaa ifaa-gidduugaleessa',
    '🫳🏽' => 'harka barruu gadi garagale: toonii godaa gidduugaleessa',
    '🫳🏾' => 'harka barruu gadi garagale: toonii gogaa gurraacha-gidduugaleessa',
    '🫳🏿' => 'harka barruu gadi garagale: toonii gogaa gurraachaa',
    '🫴🏻' => 'harka barruu ol garagale: toonii gogaa ifaa',
    '🫴🏼' => 'harka barruu ol garagale: toonii gogaa ifaa-gidduugaleessa',
    '🫴🏽' => 'harka barruu ol garagale: toonii godaa gidduugaleessa',
    '🫴🏾' => 'harka barruu ol garagale: toonii gogaa gurraacha-gidduugaleessa',
    '🫴🏿' => 'harka barruu ol garagale: toonii gogaa gurraachaa',
    '🫷🏻' => 'harka gara bitaatti dhiibu: toonii gogaa ifaa',
    '🫷🏼' => 'harka gara bitaatti dhiibu: toonii gogaa ifaa-gidduugaleessa',
    '🫷🏽' => 'harka gara bitaatti dhiibu: toonii godaa gidduugaleessa',
    '🫷🏾' => 'harka gara bitaatti dhiibu: toonii gogaa gurraacha-gidduugaleessa',
    '🫷🏿' => 'harka gara bitaatti dhiibu: toonii gogaa gurraachaa',
    '🫸🏻' => 'harka gara mirgaatti dhiibu: toonii gogaa ifaa',
    '🫸🏼' => 'harka gara mirgaatti dhiibu: toonii gogaa ifaa-gidduugaleessa',
    '🫸🏽' => 'harka gara mirgaatti dhiibu: toonii godaa gidduugaleessa',
    '🫸🏾' => 'harka gara mirgaatti dhiibu: toonii gogaa gurraacha-gidduugaleessa',
    '🫸🏿' => 'harka gara mirgaatti dhiibu: toonii gogaa gurraachaa',
    '👌🏻' => 'harka tolee: toonii gogaa ifaa',
    '👌🏼' => 'harka tolee: toonii gogaa ifaa-gidduugaleessa',
    '👌🏽' => 'harka tolee: toonii godaa gidduugaleessa',
    '👌🏾' => 'harka tolee: toonii gogaa gurraacha-gidduugaleessa',
    '👌🏿' => 'harka tolee: toonii gogaa gurraachaa',
    '🤌🏻' => 'quboota walitti qabaman: toonii gogaa ifaa',
    '🤌🏼' => 'quboota walitti qabaman: toonii gogaa ifaa-gidduugaleessa',
    '🤌🏽' => 'quboota walitti qabaman: toonii godaa gidduugaleessa',
    '🤌🏾' => 'quboota walitti qabaman: toonii gogaa gurraacha-gidduugaleessa',
    '🤌🏿' => 'quboota walitti qabaman: toonii gogaa gurraachaa',
    '🤏🏻' => 'harka qubni isaa walitti qabame: toonii gogaa ifaa',
    '🤏🏼' => 'harka qubni isaa walitti qabame: toonii gogaa ifaa-gidduugaleessa',
    '🤏🏽' => 'harka qubni isaa walitti qabame: toonii godaa gidduugaleessa',
    '🤏🏾' => 'harka qubni isaa walitti qabame: toonii gogaa gurraacha-gidduugaleessa',
    '🤏🏿' => 'harka qubni isaa walitti qabame: toonii gogaa gurraachaa',
    '✌🏻' => 'harka moo’ichaa: toonii gogaa ifaa',
    '✌🏼' => 'harka moo’ichaa: toonii gogaa ifaa-gidduugaleessa',
    '✌🏽' => 'harka moo’ichaa: toonii godaa gidduugaleessa',
    '✌🏾' => 'harka moo’ichaa: toonii gogaa gurraacha-gidduugaleessa',
    '✌🏿' => 'harka moo’ichaa: toonii gogaa gurraachaa',
    '🤞🏻' => 'quba wal qaxxaamure: toonii gogaa ifaa',
    '🤞🏼' => 'quba wal qaxxaamure: toonii gogaa ifaa-gidduugaleessa',
    '🤞🏽' => 'quba wal qaxxaamure: toonii godaa gidduugaleessa',
    '🤞🏾' => 'quba wal qaxxaamure: toonii gogaa gurraacha-gidduugaleessa',
    '🤞🏿' => 'quba wal qaxxaamure: toonii gogaa gurraachaa',
    '🫰🏻' => 'harka qubni akeektuu fi abgudduun wal qaxxamure: toonii gogaa ifaa',
    '🫰🏼' => 'harka qubni akeektuu fi abgudduun wal qaxxamure: toonii gogaa ifaa-gidduugaleessa',
    '🫰🏽' => 'harka qubni akeektuu fi abgudduun wal qaxxamure: toonii godaa gidduugaleessa',
    '🫰🏾' => 'harka qubni akeektuu fi abgudduun wal qaxxamure: toonii gogaa gurraacha-gidduugaleessa',
    '🫰🏿' => 'harka qubni akeektuu fi abgudduun wal qaxxamure: toonii gogaa gurraachaa',
    '🤟🏻' => 'mallattoo sin jaaladhaa: toonii gogaa ifaa',
    '🤟🏼' => 'mallattoo sin jaaladhaa: toonii gogaa ifaa-gidduugaleessa',
    '🤟🏽' => 'mallattoo sin jaaladhaa: toonii godaa gidduugaleessa',
    '🤟🏾' => 'mallattoo sin jaaladhaa: toonii gogaa gurraacha-gidduugaleessa',
    '🤟🏿' => 'mallattoo sin jaaladhaa: toonii gogaa gurraachaa',
    '🤘🏻' => 'mallattoo gaafaa: toonii gogaa ifaa',
    '🤘🏼' => 'mallattoo gaafaa: toonii gogaa ifaa-gidduugaleessa',
    '🤘🏽' => 'mallattoo gaafaa: toonii godaa gidduugaleessa',
    '🤘🏾' => 'mallattoo gaafaa: toonii gogaa gurraacha-gidduugaleessa',
    '🤘🏿' => 'mallattoo gaafaa: toonii gogaa gurraachaa',
    '🤙🏻' => 'harka naaf bilbilii: toonii gogaa ifaa',
    '🤙🏼' => 'harka naaf bilbilii: toonii gogaa ifaa-gidduugaleessa',
    '🤙🏽' => 'harka naaf bilbilii: toonii godaa gidduugaleessa',
    '🤙🏾' => 'harka naaf bilbilii: toonii gogaa gurraacha-gidduugaleessa',
    '🤙🏿' => 'harka naaf bilbilii: toonii gogaa gurraachaa',
    '👈🏻' => 'dugda harkaa bitatti akeeku: toonii gogaa ifaa',
    '👈🏼' => 'dugda harkaa bitatti akeeku: toonii gogaa ifaa-gidduugaleessa',
    '👈🏽' => 'dugda harkaa bitatti akeeku: toonii godaa gidduugaleessa',
    '👈🏾' => 'dugda harkaa bitatti akeeku: toonii gogaa gurraacha-gidduugaleessa',
    '👈🏿' => 'dugda harkaa bitatti akeeku: toonii gogaa gurraachaa',
    '👉🏻' => 'dugda harkaa mirgatti akeeku: toonii gogaa ifaa',
    '👉🏼' => 'dugda harkaa mirgatti akeeku: toonii gogaa ifaa-gidduugaleessa',
    '👉🏽' => 'dugda harkaa mirgatti akeeku: toonii godaa gidduugaleessa',
    '👉🏾' => 'dugda harkaa mirgatti akeeku: toonii gogaa gurraacha-gidduugaleessa',
    '👉🏿' => 'dugda harkaa mirgatti akeeku: toonii gogaa gurraachaa',
    '👆🏻' => 'dugda harkaa asii ol akeeku: toonii gogaa ifaa',
    '👆🏼' => 'dugda harkaa asii ol akeeku: toonii gogaa ifaa-gidduugaleessa',
    '👆🏽' => 'dugda harkaa asii ol akeeku: toonii godaa gidduugaleessa',
    '👆🏾' => 'dugda harkaa asii ol akeeku: toonii gogaa gurraacha-gidduugaleessa',
    '👆🏿' => 'dugda harkaa asii ol akeeku: toonii gogaa gurraachaa',
    '🖕🏻' => 'guba gidduu: toonii gogaa ifaa',
    '🖕🏼' => 'guba gidduu: toonii gogaa ifaa-gidduugaleessa',
    '🖕🏽' => 'guba gidduu: toonii godaa gidduugaleessa',
    '🖕🏾' => 'guba gidduu: toonii gogaa gurraacha-gidduugaleessa',
    '🖕🏿' => 'guba gidduu: toonii gogaa gurraachaa',
    '👇🏻' => 'dugda harkaa asii gadi akeeku: toonii gogaa ifaa',
    '👇🏼' => 'dugda harkaa asii gadi akeeku: toonii gogaa ifaa-gidduugaleessa',
    '👇🏽' => 'dugda harkaa asii gadi akeeku: toonii godaa gidduugaleessa',
    '👇🏾' => 'dugda harkaa asii gadi akeeku: toonii gogaa gurraacha-gidduugaleessa',
    '👇🏿' => 'dugda harkaa asii gadi akeeku: toonii gogaa gurraachaa',
    '☝🏻' => 'akeektuu ol akeeku: toonii gogaa ifaa',
    '☝🏼' => 'akeektuu ol akeeku: toonii gogaa ifaa-gidduugaleessa',
    '☝🏽' => 'akeektuu ol akeeku: toonii godaa gidduugaleessa',
    '☝🏾' => 'akeektuu ol akeeku: toonii gogaa gurraacha-gidduugaleessa',
    '☝🏿' => 'akeektuu ol akeeku: toonii gogaa gurraachaa',
    '🫵🏻' => 'quba akeektuu gara isa ilaaluutti qiyyaafate: toonii gogaa ifaa',
    '🫵🏼' => 'quba akeektuu gara isa ilaaluutti qiyyaafate: toonii gogaa ifaa-gidduugaleessa',
    '🫵🏽' => 'quba akeektuu gara isa ilaaluutti qiyyaafate: toonii godaa gidduugaleessa',
    '🫵🏾' => 'quba akeektuu gara isa ilaaluutti qiyyaafate: toonii gogaa gurraacha-gidduugaleessa',
    '🫵🏿' => 'quba akeektuu gara isa ilaaluutti qiyyaafate: toonii gogaa gurraachaa',
    '👍🏻' => 'angudduu ol qabuu: toonii gogaa ifaa',
    '👍🏼' => 'angudduu ol qabuu: toonii gogaa ifaa-gidduugaleessa',
    '👍🏽' => 'angudduu ol qabuu: toonii godaa gidduugaleessa',
    '👍🏾' => 'angudduu ol qabuu: toonii gogaa gurraacha-gidduugaleessa',
    '👍🏿' => 'angudduu ol qabuu: toonii gogaa gurraachaa',
    '👎🏻' => 'abgudduu gadi qabuu: toonii gogaa ifaa',
    '👎🏼' => 'abgudduu gadi qabuu: toonii gogaa ifaa-gidduugaleessa',
    '👎🏽' => 'abgudduu gadi qabuu: toonii godaa gidduugaleessa',
    '👎🏾' => 'abgudduu gadi qabuu: toonii gogaa gurraacha-gidduugaleessa',
    '👎🏿' => 'abgudduu gadi qabuu: toonii gogaa gurraachaa',
    '✊🏻' => 'haboottee ol ba’e: toonii gogaa ifaa',
    '✊🏼' => 'haboottee ol ba’e: toonii gogaa ifaa-gidduugaleessa',
    '✊🏽' => 'haboottee ol ba’e: toonii godaa gidduugaleessa',
    '✊🏾' => 'haboottee ol ba’e: toonii gogaa gurraacha-gidduugaleessa',
    '✊🏿' => 'haboottee ol ba’e: toonii gogaa gurraachaa',
    '👊🏻' => 'haboottee dhufaa jiru: toonii gogaa ifaa',
    '👊🏼' => 'haboottee dhufaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '👊🏽' => 'haboottee dhufaa jiru: toonii godaa gidduugaleessa',
    '👊🏾' => 'haboottee dhufaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '👊🏿' => 'haboottee dhufaa jiru: toonii gogaa gurraachaa',
    '🤛🏻' => 'haboottee gara bitaatti garagale: toonii gogaa ifaa',
    '🤛🏼' => 'haboottee gara bitaatti garagale: toonii gogaa ifaa-gidduugaleessa',
    '🤛🏽' => 'haboottee gara bitaatti garagale: toonii godaa gidduugaleessa',
    '🤛🏾' => 'haboottee gara bitaatti garagale: toonii gogaa gurraacha-gidduugaleessa',
    '🤛🏿' => 'haboottee gara bitaatti garagale: toonii gogaa gurraachaa',
    '🤜🏻' => 'haboottee gara mirgaatti garagale: toonii gogaa ifaa',
    '🤜🏼' => 'haboottee gara mirgaatti garagale: toonii gogaa ifaa-gidduugaleessa',
    '🤜🏽' => 'haboottee gara mirgaatti garagale: toonii godaa gidduugaleessa',
    '🤜🏾' => 'haboottee gara mirgaatti garagale: toonii gogaa gurraacha-gidduugaleessa',
    '🤜🏿' => 'haboottee gara mirgaatti garagale: toonii gogaa gurraachaa',
    '👏🏻' => 'harka rukutuu: toonii gogaa ifaa',
    '👏🏼' => 'harka rukutuu: toonii gogaa ifaa-gidduugaleessa',
    '👏🏽' => 'harka rukutuu: toonii godaa gidduugaleessa',
    '👏🏾' => 'harka rukutuu: toonii gogaa gurraacha-gidduugaleessa',
    '👏🏿' => 'harka rukutuu: toonii gogaa gurraachaa',
    '🙌🏻' => 'harkawwan baasuu: toonii gogaa ifaa',
    '🙌🏼' => 'harkawwan baasuu: toonii gogaa ifaa-gidduugaleessa',
    '🙌🏽' => 'harkawwan baasuu: toonii godaa gidduugaleessa',
    '🙌🏾' => 'harkawwan baasuu: toonii gogaa gurraacha-gidduugaleessa',
    '🙌🏿' => 'harkawwan baasuu: toonii gogaa gurraachaa',
    '🫶🏻' => 'harkoota onnee: toonii gogaa ifaa',
    '🫶🏼' => 'harkoota onnee: toonii gogaa ifaa-gidduugaleessa',
    '🫶🏽' => 'harkoota onnee: toonii godaa gidduugaleessa',
    '🫶🏾' => 'harkoota onnee: toonii gogaa gurraacha-gidduugaleessa',
    '🫶🏿' => 'harkoota onnee: toonii gogaa gurraachaa',
    '👐🏻' => 'harkoota banaa: toonii gogaa ifaa',
    '👐🏼' => 'harkoota banaa: toonii gogaa ifaa-gidduugaleessa',
    '👐🏽' => 'harkoota banaa: toonii godaa gidduugaleessa',
    '👐🏾' => 'harkoota banaa: toonii gogaa gurraacha-gidduugaleessa',
    '👐🏿' => 'harkoota banaa: toonii gogaa gurraachaa',
    '🤲🏻' => 'barruu wal faana ol ka’e: toonii gogaa ifaa',
    '🤲🏼' => 'barruu wal faana ol ka’e: toonii gogaa ifaa-gidduugaleessa',
    '🤲🏽' => 'barruu wal faana ol ka’e: toonii godaa gidduugaleessa',
    '🤲🏾' => 'barruu wal faana ol ka’e: toonii gogaa gurraacha-gidduugaleessa',
    '🤲🏿' => 'barruu wal faana ol ka’e: toonii gogaa gurraachaa',
    '🤝🏻' => 'harka fuudhuu: toonii gogaa ifaa',
    '🤝🏼' => 'harka fuudhuu: toonii gogaa ifaa-gidduugaleessa',
    '🤝🏽' => 'harka fuudhuu: toonii godaa gidduugaleessa',
    '🤝🏾' => 'harka fuudhuu: toonii gogaa gurraacha-gidduugaleessa',
    '🤝🏿' => 'harka fuudhuu: toonii gogaa gurraachaa',
    '🙏🏻' => 'harkoota walitti dhufuun ol qabaman: toonii gogaa ifaa',
    '🙏🏼' => 'harkoota walitti dhufuun ol qabaman: toonii gogaa ifaa-gidduugaleessa',
    '🙏🏽' => 'harkoota walitti dhufuun ol qabaman: toonii godaa gidduugaleessa',
    '🙏🏾' => 'harkoota walitti dhufuun ol qabaman: toonii gogaa gurraacha-gidduugaleessa',
    '🙏🏿' => 'harkoota walitti dhufuun ol qabaman: toonii gogaa gurraachaa',
    '✍🏻' => 'harka barreessu: toonii gogaa ifaa',
    '✍🏼' => 'harka barreessu: toonii gogaa ifaa-gidduugaleessa',
    '✍🏽' => 'harka barreessu: toonii godaa gidduugaleessa',
    '✍🏾' => 'harka barreessu: toonii gogaa gurraacha-gidduugaleessa',
    '✍🏿' => 'harka barreessu: toonii gogaa gurraachaa',
    '💅🏻' => 'halluu qeensaa: toonii gogaa ifaa',
    '💅🏼' => 'halluu qeensaa: toonii gogaa ifaa-gidduugaleessa',
    '💅🏽' => 'halluu qeensaa: toonii godaa gidduugaleessa',
    '💅🏾' => 'halluu qeensaa: toonii gogaa gurraacha-gidduugaleessa',
    '💅🏿' => 'halluu qeensaa: toonii gogaa gurraachaa',
    '🤳🏻' => 'selfii: toonii gogaa ifaa',
    '🤳🏼' => 'selfii: toonii gogaa ifaa-gidduugaleessa',
    '🤳🏽' => 'selfii: toonii godaa gidduugaleessa',
    '🤳🏾' => 'selfii: toonii gogaa gurraacha-gidduugaleessa',
    '🤳🏿' => 'selfii: toonii gogaa gurraachaa',
    '💪🏻' => 'irree dacha’e: toonii gogaa ifaa',
    '💪🏼' => 'irree dacha’e: toonii gogaa ifaa-gidduugaleessa',
    '💪🏽' => 'irree dacha’e: toonii godaa gidduugaleessa',
    '💪🏾' => 'irree dacha’e: toonii gogaa gurraacha-gidduugaleessa',
    '💪🏿' => 'irree dacha’e: toonii gogaa gurraachaa',
    '🦵🏻' => 'miila: toonii gogaa ifaa',
    '🦵🏼' => 'miila: toonii gogaa ifaa-gidduugaleessa',
    '🦵🏽' => 'miila: toonii godaa gidduugaleessa',
    '🦵🏾' => 'miila: toonii gogaa gurraacha-gidduugaleessa',
    '🦵🏿' => 'miila: toonii gogaa gurraachaa',
    '🦶🏻' => 'faana: toonii gogaa ifaa',
    '🦶🏼' => 'faana: toonii gogaa ifaa-gidduugaleessa',
    '🦶🏽' => 'faana: toonii godaa gidduugaleessa',
    '🦶🏾' => 'faana: toonii gogaa gurraacha-gidduugaleessa',
    '🦶🏿' => 'faana: toonii gogaa gurraachaa',
    '👂🏻' => 'gurra: toonii gogaa ifaa',
    '👂🏼' => 'gurra: toonii gogaa ifaa-gidduugaleessa',
    '👂🏽' => 'gurra: toonii godaa gidduugaleessa',
    '👂🏾' => 'gurra: toonii gogaa gurraacha-gidduugaleessa',
    '👂🏿' => 'gurra: toonii gogaa gurraachaa',
    '🦻🏻' => 'gurra gargaartuu dhageettii waliin: toonii gogaa ifaa',
    '🦻🏼' => 'gurra gargaartuu dhageettii waliin: toonii gogaa ifaa-gidduugaleessa',
    '🦻🏽' => 'gurra gargaartuu dhageettii waliin: toonii godaa gidduugaleessa',
    '🦻🏾' => 'gurra gargaartuu dhageettii waliin: toonii gogaa gurraacha-gidduugaleessa',
    '🦻🏿' => 'gurra gargaartuu dhageettii waliin: toonii gogaa gurraachaa',
    '👃🏻' => 'funyaan: toonii gogaa ifaa',
    '👃🏼' => 'funyaan: toonii gogaa ifaa-gidduugaleessa',
    '👃🏽' => 'funyaan: toonii godaa gidduugaleessa',
    '👃🏾' => 'funyaan: toonii gogaa gurraacha-gidduugaleessa',
    '👃🏿' => 'funyaan: toonii gogaa gurraachaa',
    '👶🏻' => 'daa’ima: toonii gogaa ifaa',
    '👶🏼' => 'daa’ima: toonii gogaa ifaa-gidduugaleessa',
    '👶🏽' => 'daa’ima: toonii godaa gidduugaleessa',
    '👶🏾' => 'daa’ima: toonii gogaa gurraacha-gidduugaleessa',
    '👶🏿' => 'daa’ima: toonii gogaa gurraachaa',
    '👦🏻' => 'gurbaa: toonii gogaa ifaa',
    '👦🏼' => 'gurbaa: toonii gogaa ifaa-gidduugaleessa',
    '👦🏽' => 'gurbaa: toonii godaa gidduugaleessa',
    '👦🏾' => 'gurbaa: toonii gogaa gurraacha-gidduugaleessa',
    '👦🏿' => 'gurbaa: toonii gogaa gurraachaa',
    '👧🏻' => 'dubara: toonii gogaa ifaa',
    '👧🏼' => 'dubara: toonii gogaa ifaa-gidduugaleessa',
    '👧🏽' => 'dubara: toonii godaa gidduugaleessa',
    '👧🏾' => 'dubara: toonii gogaa gurraacha-gidduugaleessa',
    '👧🏿' => 'dubara: toonii gogaa gurraachaa',
    '🧑🏻' => 'nama: toonii gogaa ifaa',
    '🧑🏼' => 'nama: toonii gogaa ifaa-gidduugaleessa',
    '🧑🏽' => 'nama: toonii godaa gidduugaleessa',
    '🧑🏾' => 'nama: toonii gogaa gurraacha-gidduugaleessa',
    '🧑🏿' => 'nama: toonii gogaa gurraachaa',
    '👱🏻' => 'nama: toonii gogaa ifaa, rifeensa keelloo',
    '👱🏼' => 'nama: toonii gogaa ifaa-gidduugaleessa, rifeensa keelloo',
    '👱🏽' => 'nama: toonii godaa gidduugaleessa, rifeensa keelloo',
    '👱🏾' => 'nama: toonii gogaa gurraacha-gidduugaleessa, rifeensa keelloo',
    '👱🏿' => 'nama: toonii gogaa gurraachaa, rifeensa keelloo',
    '👨🏻' => 'dhiira: toonii gogaa ifaa',
    '👨🏼' => 'dhiira: toonii gogaa ifaa-gidduugaleessa',
    '👨🏽' => 'dhiira: toonii godaa gidduugaleessa',
    '👨🏾' => 'dhiira: toonii gogaa gurraacha-gidduugaleessa',
    '👨🏿' => 'dhiira: toonii gogaa gurraachaa',
    '🧔🏻' => 'person: toonii gogaa ifaa, areeda qabu',
    '🧔🏼' => 'person: toonii gogaa ifaa-gidduugaleessa, areeda qabu',
    '🧔🏽' => 'person: toonii godaa gidduugaleessa, areeda qabu',
    '🧔🏾' => 'person: toonii gogaa gurraacha-gidduugaleessa, areeda qabu',
    '🧔🏿' => 'person: toonii gogaa gurraachaa, areeda qabu',
    '👩🏻' => 'dubartii: toonii gogaa ifaa',
    '👩🏼' => 'dubartii: toonii gogaa ifaa-gidduugaleessa',
    '👩🏽' => 'dubartii: toonii godaa gidduugaleessa',
    '👩🏾' => 'dubartii: toonii gogaa gurraacha-gidduugaleessa',
    '👩🏿' => 'dubartii: toonii gogaa gurraachaa',
    '🧓🏻' => 'nama jaarsa: toonii gogaa ifaa',
    '🧓🏼' => 'nama jaarsa: toonii gogaa ifaa-gidduugaleessa',
    '🧓🏽' => 'nama jaarsa: toonii godaa gidduugaleessa',
    '🧓🏾' => 'nama jaarsa: toonii gogaa gurraacha-gidduugaleessa',
    '🧓🏿' => 'nama jaarsa: toonii gogaa gurraachaa',
    '👴🏻' => 'jaarsa: toonii gogaa ifaa',
    '👴🏼' => 'jaarsa: toonii gogaa ifaa-gidduugaleessa',
    '👴🏽' => 'jaarsa: toonii godaa gidduugaleessa',
    '👴🏾' => 'jaarsa: toonii gogaa gurraacha-gidduugaleessa',
    '👴🏿' => 'jaarsa: toonii gogaa gurraachaa',
    '👵🏻' => 'jaartii: toonii gogaa ifaa',
    '👵🏼' => 'jaartii: toonii gogaa ifaa-gidduugaleessa',
    '👵🏽' => 'jaartii: toonii godaa gidduugaleessa',
    '👵🏾' => 'jaartii: toonii gogaa gurraacha-gidduugaleessa',
    '👵🏿' => 'jaartii: toonii gogaa gurraachaa',
    '🙍🏻' => 'nama mufate: toonii gogaa ifaa',
    '🙍🏼' => 'nama mufate: toonii gogaa ifaa-gidduugaleessa',
    '🙍🏽' => 'nama mufate: toonii godaa gidduugaleessa',
    '🙍🏾' => 'nama mufate: toonii gogaa gurraacha-gidduugaleessa',
    '🙍🏿' => 'nama mufate: toonii gogaa gurraachaa',
    '🙎🏻' => 'nama huuruu dhiibuu: toonii gogaa ifaa',
    '🙎🏼' => 'nama huuruu dhiibuu: toonii gogaa ifaa-gidduugaleessa',
    '🙎🏽' => 'nama huuruu dhiibuu: toonii godaa gidduugaleessa',
    '🙎🏾' => 'nama huuruu dhiibuu: toonii gogaa gurraacha-gidduugaleessa',
    '🙎🏿' => 'nama huuruu dhiibuu: toonii gogaa gurraachaa',
    '🙅🏻' => 'nama LAKKI jedhu: toonii gogaa ifaa',
    '🙅🏼' => 'nama LAKKI jedhu: toonii gogaa ifaa-gidduugaleessa',
    '🙅🏽' => 'nama LAKKI jedhu: toonii godaa gidduugaleessa',
    '🙅🏾' => 'nama LAKKI jedhu: toonii gogaa gurraacha-gidduugaleessa',
    '🙅🏿' => 'nama LAKKI jedhu: toonii gogaa gurraachaa',
    '🙆🏻' => 'nama TOLE jedhu: toonii gogaa ifaa',
    '🙆🏼' => 'nama TOLE jedhu: toonii gogaa ifaa-gidduugaleessa',
    '🙆🏽' => 'nama TOLE jedhu: toonii godaa gidduugaleessa',
    '🙆🏾' => 'nama TOLE jedhu: toonii gogaa gurraacha-gidduugaleessa',
    '🙆🏿' => 'nama TOLE jedhu: toonii gogaa gurraachaa',
    '💁🏻' => 'nama harka diriirsu: toonii gogaa ifaa',
    '💁🏼' => 'nama harka diriirsu: toonii gogaa ifaa-gidduugaleessa',
    '💁🏽' => 'nama harka diriirsu: toonii godaa gidduugaleessa',
    '💁🏾' => 'nama harka diriirsu: toonii gogaa gurraacha-gidduugaleessa',
    '💁🏿' => 'nama harka diriirsu: toonii gogaa gurraachaa',
    '🙋🏻' => 'nama harka baasu: toonii gogaa ifaa',
    '🙋🏼' => 'nama harka baasu: toonii gogaa ifaa-gidduugaleessa',
    '🙋🏽' => 'nama harka baasu: toonii godaa gidduugaleessa',
    '🙋🏾' => 'nama harka baasu: toonii gogaa gurraacha-gidduugaleessa',
    '🙋🏿' => 'nama harka baasu: toonii gogaa gurraachaa',
    '🧏🏻' => 'nama duudaa: toonii gogaa ifaa',
    '🧏🏼' => 'nama duudaa: toonii gogaa ifaa-gidduugaleessa',
    '🧏🏽' => 'nama duudaa: toonii godaa gidduugaleessa',
    '🧏🏾' => 'nama duudaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧏🏿' => 'nama duudaa: toonii gogaa gurraachaa',
    '🙇🏻' => 'nama sagadu: toonii gogaa ifaa',
    '🙇🏼' => 'nama sagadu: toonii gogaa ifaa-gidduugaleessa',
    '🙇🏽' => 'nama sagadu: toonii godaa gidduugaleessa',
    '🙇🏾' => 'nama sagadu: toonii gogaa gurraacha-gidduugaleessa',
    '🙇🏿' => 'nama sagadu: toonii gogaa gurraachaa',
    '🤦🏻' => 'nama barruun fuula qabate: toonii gogaa ifaa',
    '🤦🏼' => 'nama barruun fuula qabate: toonii gogaa ifaa-gidduugaleessa',
    '🤦🏽' => 'nama barruun fuula qabate: toonii godaa gidduugaleessa',
    '🤦🏾' => 'nama barruun fuula qabate: toonii gogaa gurraacha-gidduugaleessa',
    '🤦🏿' => 'nama barruun fuula qabate: toonii gogaa gurraachaa',
    '🤷🏻' => 'nama mataa raasu: toonii gogaa ifaa',
    '🤷🏼' => 'nama mataa raasu: toonii gogaa ifaa-gidduugaleessa',
    '🤷🏽' => 'nama mataa raasu: toonii godaa gidduugaleessa',
    '🤷🏾' => 'nama mataa raasu: toonii gogaa gurraacha-gidduugaleessa',
    '🤷🏿' => 'nama mataa raasu: toonii gogaa gurraachaa',
    '👮🏻' => 'qondaala poolisii: toonii gogaa ifaa',
    '👮🏼' => 'qondaala poolisii: toonii gogaa ifaa-gidduugaleessa',
    '👮🏽' => 'qondaala poolisii: toonii godaa gidduugaleessa',
    '👮🏾' => 'qondaala poolisii: toonii gogaa gurraacha-gidduugaleessa',
    '👮🏿' => 'qondaala poolisii: toonii gogaa gurraachaa',
    '🕵🏻' => 'qorataa: toonii gogaa ifaa',
    '🕵🏼' => 'qorataa: toonii gogaa ifaa-gidduugaleessa',
    '🕵🏽' => 'qorataa: toonii godaa gidduugaleessa',
    '🕵🏾' => 'qorataa: toonii gogaa gurraacha-gidduugaleessa',
    '🕵🏿' => 'qorataa: toonii gogaa gurraachaa',
    '💂🏻' => 'eegaa: toonii gogaa ifaa',
    '💂🏼' => 'eegaa: toonii gogaa ifaa-gidduugaleessa',
    '💂🏽' => 'eegaa: toonii godaa gidduugaleessa',
    '💂🏾' => 'eegaa: toonii gogaa gurraacha-gidduugaleessa',
    '💂🏿' => 'eegaa: toonii gogaa gurraachaa',
    '🥷🏻' => 'niinjaa: toonii gogaa ifaa',
    '🥷🏼' => 'niinjaa: toonii gogaa ifaa-gidduugaleessa',
    '🥷🏽' => 'niinjaa: toonii godaa gidduugaleessa',
    '🥷🏾' => 'niinjaa: toonii gogaa gurraacha-gidduugaleessa',
    '🥷🏿' => 'niinjaa: toonii gogaa gurraachaa',
    '👷🏻' => 'hojjetaa ijaarsaa: toonii gogaa ifaa',
    '👷🏼' => 'hojjetaa ijaarsaa: toonii gogaa ifaa-gidduugaleessa',
    '👷🏽' => 'hojjetaa ijaarsaa: toonii godaa gidduugaleessa',
    '👷🏾' => 'hojjetaa ijaarsaa: toonii gogaa gurraacha-gidduugaleessa',
    '👷🏿' => 'hojjetaa ijaarsaa: toonii gogaa gurraachaa',
    '🫅🏻' => 'nama gonfoo waliin: toonii gogaa ifaa',
    '🫅🏼' => 'nama gonfoo waliin: toonii gogaa ifaa-gidduugaleessa',
    '🫅🏽' => 'nama gonfoo waliin: toonii godaa gidduugaleessa',
    '🫅🏾' => 'nama gonfoo waliin: toonii gogaa gurraacha-gidduugaleessa',
    '🫅🏿' => 'nama gonfoo waliin: toonii gogaa gurraachaa',
    '🤴🏻' => 'ilma mootii: toonii gogaa ifaa',
    '🤴🏼' => 'ilma mootii: toonii gogaa ifaa-gidduugaleessa',
    '🤴🏽' => 'ilma mootii: toonii godaa gidduugaleessa',
    '🤴🏾' => 'ilma mootii: toonii gogaa gurraacha-gidduugaleessa',
    '🤴🏿' => 'ilma mootii: toonii gogaa gurraachaa',
    '👸🏻' => 'intala mootii: toonii gogaa ifaa',
    '👸🏼' => 'intala mootii: toonii gogaa ifaa-gidduugaleessa',
    '👸🏽' => 'intala mootii: toonii godaa gidduugaleessa',
    '👸🏾' => 'intala mootii: toonii gogaa gurraacha-gidduugaleessa',
    '👸🏿' => 'intala mootii: toonii gogaa gurraachaa',
    '👳🏻' => 'nama turbaanii uffatu: toonii gogaa ifaa',
    '👳🏼' => 'nama turbaanii uffatu: toonii gogaa ifaa-gidduugaleessa',
    '👳🏽' => 'nama turbaanii uffatu: toonii godaa gidduugaleessa',
    '👳🏾' => 'nama turbaanii uffatu: toonii gogaa gurraacha-gidduugaleessa',
    '👳🏿' => 'nama turbaanii uffatu: toonii gogaa gurraachaa',
    '👲🏻' => 'nama kofiyyaa godhate: toonii gogaa ifaa',
    '👲🏼' => 'nama kofiyyaa godhate: toonii gogaa ifaa-gidduugaleessa',
    '👲🏽' => 'nama kofiyyaa godhate: toonii godaa gidduugaleessa',
    '👲🏾' => 'nama kofiyyaa godhate: toonii gogaa gurraacha-gidduugaleessa',
    '👲🏿' => 'nama kofiyyaa godhate: toonii gogaa gurraachaa',
    '🧕🏻' => 'dubartii mataatti maratte: toonii gogaa ifaa',
    '🧕🏼' => 'dubartii mataatti maratte: toonii gogaa ifaa-gidduugaleessa',
    '🧕🏽' => 'dubartii mataatti maratte: toonii godaa gidduugaleessa',
    '🧕🏾' => 'dubartii mataatti maratte: toonii gogaa gurraacha-gidduugaleessa',
    '🧕🏿' => 'dubartii mataatti maratte: toonii gogaa gurraachaa',
    '🤵🏻' => 'nama bijaamaa uffate: toonii gogaa ifaa',
    '🤵🏼' => 'nama bijaamaa uffate: toonii gogaa ifaa-gidduugaleessa',
    '🤵🏽' => 'nama bijaamaa uffate: toonii godaa gidduugaleessa',
    '🤵🏾' => 'nama bijaamaa uffate: toonii gogaa gurraacha-gidduugaleessa',
    '🤵🏿' => 'nama bijaamaa uffate: toonii gogaa gurraachaa',
    '👰🏻' => 'nama golgaa waliin: toonii gogaa ifaa',
    '👰🏼' => 'nama golgaa waliin: toonii gogaa ifaa-gidduugaleessa',
    '👰🏽' => 'nama golgaa waliin: toonii godaa gidduugaleessa',
    '👰🏾' => 'nama golgaa waliin: toonii gogaa gurraacha-gidduugaleessa',
    '👰🏿' => 'nama golgaa waliin: toonii gogaa gurraachaa',
    '🤰🏻' => 'dubartii ulfa: toonii gogaa ifaa',
    '🤰🏼' => 'dubartii ulfa: toonii gogaa ifaa-gidduugaleessa',
    '🤰🏽' => 'dubartii ulfa: toonii godaa gidduugaleessa',
    '🤰🏾' => 'dubartii ulfa: toonii gogaa gurraacha-gidduugaleessa',
    '🤰🏿' => 'dubartii ulfa: toonii gogaa gurraachaa',
    '🫃🏻' => 'dhiira ulfa: toonii gogaa ifaa',
    '🫃🏼' => 'dhiira ulfa: toonii gogaa ifaa-gidduugaleessa',
    '🫃🏽' => 'dhiira ulfa: toonii godaa gidduugaleessa',
    '🫃🏾' => 'dhiira ulfa: toonii gogaa gurraacha-gidduugaleessa',
    '🫃🏿' => 'dhiira ulfa: toonii gogaa gurraachaa',
    '🫄🏻' => 'nama ulfa: toonii gogaa ifaa',
    '🫄🏼' => 'nama ulfa: toonii gogaa ifaa-gidduugaleessa',
    '🫄🏽' => 'nama ulfa: toonii godaa gidduugaleessa',
    '🫄🏾' => 'nama ulfa: toonii gogaa gurraacha-gidduugaleessa',
    '🫄🏿' => 'nama ulfa: toonii gogaa gurraachaa',
    '🤱🏻' => 'harma hoosisuu: toonii gogaa ifaa',
    '🤱🏼' => 'harma hoosisuu: toonii gogaa ifaa-gidduugaleessa',
    '🤱🏽' => 'harma hoosisuu: toonii godaa gidduugaleessa',
    '🤱🏾' => 'harma hoosisuu: toonii gogaa gurraacha-gidduugaleessa',
    '🤱🏿' => 'harma hoosisuu: toonii gogaa gurraachaa',
    '👼🏻' => 'daa’ima ergamaa: toonii gogaa ifaa',
    '👼🏼' => 'daa’ima ergamaa: toonii gogaa ifaa-gidduugaleessa',
    '👼🏽' => 'daa’ima ergamaa: toonii godaa gidduugaleessa',
    '👼🏾' => 'daa’ima ergamaa: toonii gogaa gurraacha-gidduugaleessa',
    '👼🏿' => 'daa’ima ergamaa: toonii gogaa gurraachaa',
    '🎅🏻' => 'Saantaa kilaawos: toonii gogaa ifaa',
    '🎅🏼' => 'Saantaa kilaawos: toonii gogaa ifaa-gidduugaleessa',
    '🎅🏽' => 'Saantaa kilaawos: toonii godaa gidduugaleessa',
    '🎅🏾' => 'Saantaa kilaawos: toonii gogaa gurraacha-gidduugaleessa',
    '🎅🏿' => 'Saantaa kilaawos: toonii gogaa gurraachaa',
    '🤶🏻' => 'Obbo Kilaawos: toonii gogaa ifaa',
    '🤶🏼' => 'Obbo Kilaawos: toonii gogaa ifaa-gidduugaleessa',
    '🤶🏽' => 'Obbo Kilaawos: toonii godaa gidduugaleessa',
    '🤶🏾' => 'Obbo Kilaawos: toonii gogaa gurraacha-gidduugaleessa',
    '🤶🏿' => 'Obbo Kilaawos: toonii gogaa gurraachaa',
    '🦸🏻' => 'goota: toonii gogaa ifaa',
    '🦸🏼' => 'goota: toonii gogaa ifaa-gidduugaleessa',
    '🦸🏽' => 'goota: toonii godaa gidduugaleessa',
    '🦸🏾' => 'goota: toonii gogaa gurraacha-gidduugaleessa',
    '🦸🏿' => 'goota: toonii gogaa gurraachaa',
    '🦹🏻' => 'jallataa: toonii gogaa ifaa',
    '🦹🏼' => 'jallataa: toonii gogaa ifaa-gidduugaleessa',
    '🦹🏽' => 'jallataa: toonii godaa gidduugaleessa',
    '🦹🏾' => 'jallataa: toonii gogaa gurraacha-gidduugaleessa',
    '🦹🏿' => 'jallataa: toonii gogaa gurraachaa',
    '🧙🏻' => 'falfalaa: toonii gogaa ifaa',
    '🧙🏼' => 'falfalaa: toonii gogaa ifaa-gidduugaleessa',
    '🧙🏽' => 'falfalaa: toonii godaa gidduugaleessa',
    '🧙🏾' => 'falfalaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧙🏿' => 'falfalaa: toonii gogaa gurraachaa',
    '🧚🏻' => 'feerii: toonii gogaa ifaa',
    '🧚🏼' => 'feerii: toonii gogaa ifaa-gidduugaleessa',
    '🧚🏽' => 'feerii: toonii godaa gidduugaleessa',
    '🧚🏾' => 'feerii: toonii gogaa gurraacha-gidduugaleessa',
    '🧚🏿' => 'feerii: toonii gogaa gurraachaa',
    '🧛🏻' => 'vaampaayerii: toonii gogaa ifaa',
    '🧛🏼' => 'vaampaayerii: toonii gogaa ifaa-gidduugaleessa',
    '🧛🏽' => 'vaampaayerii: toonii godaa gidduugaleessa',
    '🧛🏾' => 'vaampaayerii: toonii gogaa gurraacha-gidduugaleessa',
    '🧛🏿' => 'vaampaayerii: toonii gogaa gurraachaa',
    '🧜🏻' => 'nama lo’u: toonii gogaa ifaa',
    '🧜🏼' => 'nama lo’u: toonii gogaa ifaa-gidduugaleessa',
    '🧜🏽' => 'nama lo’u: toonii godaa gidduugaleessa',
    '🧜🏾' => 'nama lo’u: toonii gogaa gurraacha-gidduugaleessa',
    '🧜🏿' => 'nama lo’u: toonii gogaa gurraachaa',
    '🧝🏻' => 'eeliif: toonii gogaa ifaa',
    '🧝🏼' => 'eeliif: toonii gogaa ifaa-gidduugaleessa',
    '🧝🏽' => 'eeliif: toonii godaa gidduugaleessa',
    '🧝🏾' => 'eeliif: toonii gogaa gurraacha-gidduugaleessa',
    '🧝🏿' => 'eeliif: toonii gogaa gurraachaa',
    '💆🏻' => 'nama sukkuumamaa jiru: toonii gogaa ifaa',
    '💆🏼' => 'nama sukkuumamaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '💆🏽' => 'nama sukkuumamaa jiru: toonii godaa gidduugaleessa',
    '💆🏾' => 'nama sukkuumamaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '💆🏿' => 'nama sukkuumamaa jiru: toonii gogaa gurraachaa',
    '💇🏻' => 'nama rifeensa sirreeffachaa jiru: toonii gogaa ifaa',
    '💇🏼' => 'nama rifeensa sirreeffachaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '💇🏽' => 'nama rifeensa sirreeffachaa jiru: toonii godaa gidduugaleessa',
    '💇🏾' => 'nama rifeensa sirreeffachaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '💇🏿' => 'nama rifeensa sirreeffachaa jiru: toonii gogaa gurraachaa',
    '🚶🏻' => 'nama deemaa jiru: toonii gogaa ifaa',
    '🚶🏼' => 'nama deemaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🚶🏽' => 'nama deemaa jiru: toonii godaa gidduugaleessa',
    '🚶🏾' => 'nama deemaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🚶🏿' => 'nama deemaa jiru: toonii gogaa gurraachaa',
    '🧍🏻' => 'nama dhaabbatu: toonii gogaa ifaa',
    '🧍🏼' => 'nama dhaabbatu: toonii gogaa ifaa-gidduugaleessa',
    '🧍🏽' => 'nama dhaabbatu: toonii godaa gidduugaleessa',
    '🧍🏾' => 'nama dhaabbatu: toonii gogaa gurraacha-gidduugaleessa',
    '🧍🏿' => 'nama dhaabbatu: toonii gogaa gurraachaa',
    '🧎🏻' => 'nama jilbeeffate: toonii gogaa ifaa',
    '🧎🏼' => 'nama jilbeeffate: toonii gogaa ifaa-gidduugaleessa',
    '🧎🏽' => 'nama jilbeeffate: toonii godaa gidduugaleessa',
    '🧎🏾' => 'nama jilbeeffate: toonii gogaa gurraacha-gidduugaleessa',
    '🧎🏿' => 'nama jilbeeffate: toonii gogaa gurraachaa',
    '🏃🏻' => 'nama fiigu: toonii gogaa ifaa',
    '🏃🏼' => 'nama fiigu: toonii gogaa ifaa-gidduugaleessa',
    '🏃🏽' => 'nama fiigu: toonii godaa gidduugaleessa',
    '🏃🏾' => 'nama fiigu: toonii gogaa gurraacha-gidduugaleessa',
    '🏃🏿' => 'nama fiigu: toonii gogaa gurraachaa',
    '💃🏻' => 'dubartii shubbistu: toonii gogaa ifaa',
    '💃🏼' => 'dubartii shubbistu: toonii gogaa ifaa-gidduugaleessa',
    '💃🏽' => 'dubartii shubbistu: toonii godaa gidduugaleessa',
    '💃🏾' => 'dubartii shubbistu: toonii gogaa gurraacha-gidduugaleessa',
    '💃🏿' => 'dubartii shubbistu: toonii gogaa gurraachaa',
    '🕺🏻' => 'dhiira shubbisu: toonii gogaa ifaa',
    '🕺🏼' => 'dhiira shubbisu: toonii gogaa ifaa-gidduugaleessa',
    '🕺🏽' => 'dhiira shubbisu: toonii godaa gidduugaleessa',
    '🕺🏾' => 'dhiira shubbisu: toonii gogaa gurraacha-gidduugaleessa',
    '🕺🏿' => 'dhiira shubbisu: toonii gogaa gurraachaa',
    '🕴🏻' => 'nama suufii uffatee bololi’u: toonii gogaa ifaa',
    '🕴🏼' => 'nama suufii uffatee bololi’u: toonii gogaa ifaa-gidduugaleessa',
    '🕴🏽' => 'nama suufii uffatee bololi’u: toonii godaa gidduugaleessa',
    '🕴🏾' => 'nama suufii uffatee bololi’u: toonii gogaa gurraacha-gidduugaleessa',
    '🕴🏿' => 'nama suufii uffatee bololi’u: toonii gogaa gurraachaa',
    '👯🏻' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa',
    '👯🏼' => 'namoota gurra baanii ofirraa qaban: toonii gogaa ifaa-gidduugaleessa',
    '👯🏽' => 'namoota gurra baanii ofirraa qaban: toonii godaa gidduugaleessa',
    '👯🏾' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraacha-gidduugaleessa',
    '👯🏿' => 'namoota gurra baanii ofirraa qaban: toonii gogaa gurraachaa',
    '🧖🏻' => 'nama kutaa hurkaa keessaa: toonii gogaa ifaa',
    '🧖🏼' => 'nama kutaa hurkaa keessaa: toonii gogaa ifaa-gidduugaleessa',
    '🧖🏽' => 'nama kutaa hurkaa keessaa: toonii godaa gidduugaleessa',
    '🧖🏾' => 'nama kutaa hurkaa keessaa: toonii gogaa gurraacha-gidduugaleessa',
    '🧖🏿' => 'nama kutaa hurkaa keessaa: toonii gogaa gurraachaa',
    '🧗🏻' => 'nama yaabbachaa jiru: toonii gogaa ifaa',
    '🧗🏼' => 'nama yaabbachaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🧗🏽' => 'nama yaabbachaa jiru: toonii godaa gidduugaleessa',
    '🧗🏾' => 'nama yaabbachaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🧗🏿' => 'nama yaabbachaa jiru: toonii gogaa gurraachaa',
    '🏇🏻' => 'gugsii fardaa: toonii gogaa ifaa',
    '🏇🏼' => 'gugsii fardaa: toonii gogaa ifaa-gidduugaleessa',
    '🏇🏽' => 'gugsii fardaa: toonii godaa gidduugaleessa',
    '🏇🏾' => 'gugsii fardaa: toonii gogaa gurraacha-gidduugaleessa',
    '🏇🏿' => 'gugsii fardaa: toonii gogaa gurraachaa',
    '🏂🏻' => 'daangaa cabbii: toonii gogaa ifaa',
    '🏂🏼' => 'daangaa cabbii: toonii gogaa ifaa-gidduugaleessa',
    '🏂🏽' => 'daangaa cabbii: toonii godaa gidduugaleessa',
    '🏂🏾' => 'daangaa cabbii: toonii gogaa gurraacha-gidduugaleessa',
    '🏂🏿' => 'daangaa cabbii: toonii gogaa gurraachaa',
    '🏌🏻' => 'nama golfii taphatu: toonii gogaa ifaa',
    '🏌🏼' => 'nama golfii taphatu: toonii gogaa ifaa-gidduugaleessa',
    '🏌🏽' => 'nama golfii taphatu: toonii godaa gidduugaleessa',
    '🏌🏾' => 'nama golfii taphatu: toonii gogaa gurraacha-gidduugaleessa',
    '🏌🏿' => 'nama golfii taphatu: toonii gogaa gurraachaa',
    '🏄🏻' => 'nama bololi’u: toonii gogaa ifaa',
    '🏄🏼' => 'nama bololi’u: toonii gogaa ifaa-gidduugaleessa',
    '🏄🏽' => 'nama bololi’u: toonii godaa gidduugaleessa',
    '🏄🏾' => 'nama bololi’u: toonii gogaa gurraacha-gidduugaleessa',
    '🏄🏿' => 'nama bololi’u: toonii gogaa gurraachaa',
    '🚣🏻' => 'nama bidiruu oofu: toonii gogaa ifaa',
    '🚣🏼' => 'nama bidiruu oofu: toonii gogaa ifaa-gidduugaleessa',
    '🚣🏽' => 'nama bidiruu oofu: toonii godaa gidduugaleessa',
    '🚣🏾' => 'nama bidiruu oofu: toonii gogaa gurraacha-gidduugaleessa',
    '🚣🏿' => 'nama bidiruu oofu: toonii gogaa gurraachaa',
    '🏊🏻' => 'nama daakaa jiru: toonii gogaa ifaa',
    '🏊🏼' => 'nama daakaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🏊🏽' => 'nama daakaa jiru: toonii godaa gidduugaleessa',
    '🏊🏾' => 'nama daakaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🏊🏿' => 'nama daakaa jiru: toonii gogaa gurraachaa',
    '⛹🏻' => 'nama kubbaa utaalchisu: toonii gogaa ifaa',
    '⛹🏼' => 'nama kubbaa utaalchisu: toonii gogaa ifaa-gidduugaleessa',
    '⛹🏽' => 'nama kubbaa utaalchisu: toonii godaa gidduugaleessa',
    '⛹🏾' => 'nama kubbaa utaalchisu: toonii gogaa gurraacha-gidduugaleessa',
    '⛹🏿' => 'nama kubbaa utaalchisu: toonii gogaa gurraachaa',
    '🏋🏻' => 'nama ulfaatina kaasu: toonii gogaa ifaa',
    '🏋🏼' => 'nama ulfaatina kaasu: toonii gogaa ifaa-gidduugaleessa',
    '🏋🏽' => 'nama ulfaatina kaasu: toonii godaa gidduugaleessa',
    '🏋🏾' => 'nama ulfaatina kaasu: toonii gogaa gurraacha-gidduugaleessa',
    '🏋🏿' => 'nama ulfaatina kaasu: toonii gogaa gurraachaa',
    '🚴🏻' => 'nama biskileetii oofu: toonii gogaa ifaa',
    '🚴🏼' => 'nama biskileetii oofu: toonii gogaa ifaa-gidduugaleessa',
    '🚴🏽' => 'nama biskileetii oofu: toonii godaa gidduugaleessa',
    '🚴🏾' => 'nama biskileetii oofu: toonii gogaa gurraacha-gidduugaleessa',
    '🚴🏿' => 'nama biskileetii oofu: toonii gogaa gurraachaa',
    '🚵🏻' => 'nama biskileetiin tulluu bahu: toonii gogaa ifaa',
    '🚵🏼' => 'nama biskileetiin tulluu bahu: toonii gogaa ifaa-gidduugaleessa',
    '🚵🏽' => 'nama biskileetiin tulluu bahu: toonii godaa gidduugaleessa',
    '🚵🏾' => 'nama biskileetiin tulluu bahu: toonii gogaa gurraacha-gidduugaleessa',
    '🚵🏿' => 'nama biskileetiin tulluu bahu: toonii gogaa gurraachaa',
    '🤸🏻' => 'nama harkaan garagalu: toonii gogaa ifaa',
    '🤸🏼' => 'nama harkaan garagalu: toonii gogaa ifaa-gidduugaleessa',
    '🤸🏽' => 'nama harkaan garagalu: toonii godaa gidduugaleessa',
    '🤸🏾' => 'nama harkaan garagalu: toonii gogaa gurraacha-gidduugaleessa',
    '🤸🏿' => 'nama harkaan garagalu: toonii gogaa gurraachaa',
    '🤼🏻' => 'namoota wal tuman: toonii gogaa ifaa',
    '🤼🏼' => 'namoota wal tuman: toonii gogaa ifaa-gidduugaleessa',
    '🤼🏽' => 'namoota wal tuman: toonii godaa gidduugaleessa',
    '🤼🏾' => 'namoota wal tuman: toonii gogaa gurraacha-gidduugaleessa',
    '🤼🏿' => 'namoota wal tuman: toonii gogaa gurraachaa',
    '🤽🏻' => 'nama pooloo bishaanii taphachaa jiru: toonii gogaa ifaa',
    '🤽🏼' => 'nama pooloo bishaanii taphachaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🤽🏽' => 'nama pooloo bishaanii taphachaa jiru: toonii godaa gidduugaleessa',
    '🤽🏾' => 'nama pooloo bishaanii taphachaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🤽🏿' => 'nama pooloo bishaanii taphachaa jiru: toonii gogaa gurraachaa',
    '🤾🏻' => 'nama kubbaa harkaa taphachaa jiru: toonii gogaa ifaa',
    '🤾🏼' => 'nama kubbaa harkaa taphachaa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🤾🏽' => 'nama kubbaa harkaa taphachaa jiru: toonii godaa gidduugaleessa',
    '🤾🏾' => 'nama kubbaa harkaa taphachaa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🤾🏿' => 'nama kubbaa harkaa taphachaa jiru: toonii gogaa gurraachaa',
    '🤹🏻' => 'nama waa ol daddarbatee qabatu: toonii gogaa ifaa',
    '🤹🏼' => 'nama waa ol daddarbatee qabatu: toonii gogaa ifaa-gidduugaleessa',
    '🤹🏽' => 'nama waa ol daddarbatee qabatu: toonii godaa gidduugaleessa',
    '🤹🏾' => 'nama waa ol daddarbatee qabatu: toonii gogaa gurraacha-gidduugaleessa',
    '🤹🏿' => 'nama waa ol daddarbatee qabatu: toonii gogaa gurraachaa',
    '🧘🏻' => 'nama lootasii irra jiru: toonii gogaa ifaa',
    '🧘🏼' => 'nama lootasii irra jiru: toonii gogaa ifaa-gidduugaleessa',
    '🧘🏽' => 'nama lootasii irra jiru: toonii godaa gidduugaleessa',
    '🧘🏾' => 'nama lootasii irra jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🧘🏿' => 'nama lootasii irra jiru: toonii gogaa gurraachaa',
    '🛀🏻' => 'nama qaama dhiqatu: toonii gogaa ifaa',
    '🛀🏼' => 'nama qaama dhiqatu: toonii gogaa ifaa-gidduugaleessa',
    '🛀🏽' => 'nama qaama dhiqatu: toonii godaa gidduugaleessa',
    '🛀🏾' => 'nama qaama dhiqatu: toonii gogaa gurraacha-gidduugaleessa',
    '🛀🏿' => 'nama qaama dhiqatu: toonii gogaa gurraachaa',
    '🛌🏻' => 'nama siree keessa jiru: toonii gogaa ifaa',
    '🛌🏼' => 'nama siree keessa jiru: toonii gogaa ifaa-gidduugaleessa',
    '🛌🏽' => 'nama siree keessa jiru: toonii godaa gidduugaleessa',
    '🛌🏾' => 'nama siree keessa jiru: toonii gogaa gurraacha-gidduugaleessa',
    '🛌🏿' => 'nama siree keessa jiru: toonii gogaa gurraachaa',
    '👭🏻' => 'dubartoota harka wal qabatan: toonii gogaa ifaa',
    '👭🏼' => 'dubartoota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa',
    '👭🏽' => 'dubartoota harka wal qabatan: toonii godaa gidduugaleessa',
    '👭🏾' => 'dubartoota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa',
    '👭🏿' => 'dubartoota harka wal qabatan: toonii gogaa gurraachaa',
    '👫🏻' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa',
    '👫🏼' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa ifaa-gidduugaleessa',
    '👫🏽' => 'dubartii fi dhiira harka wal qabatan: toonii godaa gidduugaleessa',
    '👫🏾' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa',
    '👫🏿' => 'dubartii fi dhiira harka wal qabatan: toonii gogaa gurraachaa',
    '👬🏻' => 'dhiirota harka wal qabatan: toonii gogaa ifaa',
    '👬🏼' => 'dhiirota harka wal qabatan: toonii gogaa ifaa-gidduugaleessa',
    '👬🏽' => 'dhiirota harka wal qabatan: toonii godaa gidduugaleessa',
    '👬🏾' => 'dhiirota harka wal qabatan: toonii gogaa gurraacha-gidduugaleessa',
    '👬🏿' => 'dhiirota harka wal qabatan: toonii gogaa gurraachaa',
    '💏🏻' => 'dhungoo: toonii gogaa ifaa',
    '💏🏼' => 'dhungoo: toonii gogaa ifaa-gidduugaleessa',
    '💏🏽' => 'dhungoo: toonii godaa gidduugaleessa',
    '💏🏾' => 'dhungoo: toonii gogaa gurraacha-gidduugaleessa',
    '💏🏿' => 'dhungoo: toonii gogaa gurraachaa',
    '💑🏻' => 'hiriyyoota gaa’ilaa onnee waliin: toonii gogaa ifaa',
    '💑🏼' => 'hiriyyoota gaa’ilaa onnee waliin: toonii gogaa ifaa-gidduugaleessa',
    '💑🏽' => 'hiriyyoota gaa’ilaa onnee waliin: toonii godaa gidduugaleessa',
    '💑🏾' => 'hiriyyoota gaa’ilaa onnee waliin: toonii gogaa gurraacha-gidduugaleessa',
    '💑🏿' => 'hiriyyoota gaa’ilaa onnee waliin: toonii gogaa gurraachaa',
    '🏻' => 'toonii gogaa ifaa',
    '🏼' => 'toonii gogaa ifaa-gidduugaleessa',
    '🏽' => 'toonii godaa gidduugaleessa',
    '🏾' => 'toonii gogaa gurraacha-gidduugaleessa',
    '🏿' => 'toonii gogaa gurraachaa',
    '😀' => 'fuula kolfu',
    '😃' => 'fuula kolfu ija guddaa waliin',
    '😄' => 'fuula kolfu ija seequ waliin',
    '😁' => 'fuula ifaa ijoota kolfaa waliin',
    '😆' => 'fuula kottonfataa kolfu',
    '😅' => 'fuula kolfu dafqa waliin',
    '🤣' => 'kolfanii lafa gangalachuu',
    '😂' => 'fuula imimmaan gammachuu waliin',
    '🙂' => 'fuula xiqqoo seequ',
    '🙃' => 'fuula gadi garagale',
    '🫠' => 'fuula baqu',
    '😉' => 'fuula ija libsatu',
    '😊' => 'fuula seequ ija seequ waliin',
    '😇' => 'fuula kolfu haloo waliin',
    '🥰' => 'fuula seequ onneewwan waliin',
    '😍' => 'fuula seequ ija onnee waliin',
    '🤩' => 'urjiidhaan rukutamuu',
    '😘' => 'dhungoo fuula raasu',
    '😗' => 'fuula dhungatu',
    '☺' => 'fuula seequ',
    '😚' => 'fuula dhungoo ija cufame waliin',
    '😙' => 'fuula dhungoo ija seequ waliin',
    '🥲' => 'fuula seequ imimmaan waliin',
    '😋' => 'fuula nyaata dharra’e',
    '😛' => 'fuula arraba waliin',
    '😜' => 'fuula libsatu arraba waliin',
    '🤪' => 'fuula qoosaa',
    '😝' => 'fuula kottonfatu arraba waliin',
    '🤑' => 'fuula afaan maallaqaa',
    '🤗' => 'harka bal’isuun fuula seequ',
    '🤭' => 'fuula afaan harka irraa qabu',
    '🫢' => 'fuula ijoota banaa fi harki afaan irra jiru',
    '🫣' => 'fula ija calaqqisu qabu',
    '🤫' => 'fuula suntuuraa',
    '🤔' => 'fuula yaaduu',
    '🫡' => 'fuula nagaa dhiyeessuu',
    '🤐' => 'fuula afaan ziip ta’ee',
    '🤨' => 'fuula nyaarri ol ka’e',
    '😐' => 'fuula walabaa',
    '😑' => 'fuula miira hin qabde',
    '😶' => 'fuula afaan malee',
    '🫥' => 'fuula tuqaa fi sararaa',
    '😏' => 'fuula huuruu dhiibu',
    '😒' => 'fuula hin ajaa’ibsiifamne',
    '🙄' => 'fuula ija naanna’u waliin',
    '😬' => 'fuula saalfii',
    '🤥' => 'fuula sobaa',
    '🫨' => 'fuula hollatu',
    '😌' => 'fuula boqote',
    '😔' => 'fuula yaaddoo',
    '😪' => 'fuula hirribaa',
    '🤤' => 'fuula cophu',
    '😴' => 'fuula rafaa jiru',
    '🫩' => 'fuula ija jalaa ibirkuu qabu',
    '😷' => 'fuula maaskii fayyaa waliin',
    '🤒' => 'fuula termoomeetirii waliin',
    '🤕' => 'fuula mataa buruqee',
    '🤢' => 'fuula raata’aa',
    '🤮' => 'fuula oldeebisaa jiru',
    '🤧' => 'fuula haxxiffachuu',
    '🥵' => 'fuula ho’aa',
    '🥶' => 'fuula qorraa',
    '😵' => 'fuula ija wal qaxxaamurfame waliin',
    '🤯' => 'mataa dho’aa jiru',
    '🤠' => 'fuula baarneexaa tiksee',
    '🥳' => 'fuula paartii kabajaa jiru',
    '🥸' => 'fuula fakkeessaa',
    '😎' => 'fuula seequ kishaafa aduu waliin',
    '🤓' => 'fuula gowwaa',
    '🧐' => 'fuula moonookilii waliin',
    '😕' => 'fuula burjaaja’e',
    '🫤' => 'fuula afaan jallisee jiru',
    '😟' => 'fuula yaadda’e',
    '🙁' => 'fuula xiqqoo gudunfame',
    '☹' => 'fuula gudunfamaa',
    '😮' => 'fuula afaan banaa waliin',
    '😯' => 'fuula rifaatuu',
    '😲' => 'fuula raajeffame',
    '😳' => 'fuula diimate',
    '🫪' => 'fuula jallate',
    '🥺' => 'fuula marartoo',
    '🥹' => 'fuula imimmaan kuuse',
    '😦' => 'fuula gudunfame afaan banaa waliin',
    '😧' => 'fuula dhiphate',
    '😨' => 'fuula sodaa',
    '😰' => 'fuula dhiphate dafqa waliin',
    '😥' => 'fuula gadde garuu aara galfate',
    '😢' => 'fuula boo’u',
    '😭' => 'fuula sagalee dhageessisee boo’u',
    '😱' => 'fuula sodaatiin suntuure',
    '😖' => 'fuula bitaa itti gale',
    '😣' => 'fuula obsaa',
    '😞' => 'fuula mufate',
    '😓' => 'fuula gadi jedhe dafqa waliin',
    '😩' => 'fuula dadhabbii',
    '😫' => 'fuula dadhabe',
    '🥱' => 'fuula hamuummatu',
    '😤' => 'fuula hurki funyaanii bahu',
    '😡' => 'fuula garmalee aare',
    '😠' => 'fuula aarii',
    '🤬' => 'fuula malattoo afaan irraa qabu',
    '😈' => 'fuula seequ gaafa waliin',
    '👿' => 'fuula aarii gaafa waliin',
    '💀' => 'lafee mataa',
    '☠' => 'lafee mataa fi lafee wal qaxxaamure',
    '💩' => 'gatii dhabeessa',
    '🤡' => 'fuula nama qoosuu',
    '👹' => 'oogiree',
    '👺' => 'gobliin',
    '👻' => 'ekeraa',
    '👽' => 'eeliyaan',
    '👾' => 'bulguu eeliyaan',
    '🤖' => 'roobootii',
    '😺' => 'adurree kolfitu',
    '😸' => 'adurree kolfitu ija seequ waliin',
    '😹' => 'adurree imimmaan gammachuu waliin',
    '😻' => 'adurree seeqxu ija onnee waliin',
    '😼' => 'adurree seeqa aarii waliin',
    '😽' => 'adurree dhungattu',
    '🙀' => 'adurree dadhabde',
    '😿' => 'adurree boossu',
    '😾' => 'adurree aarte',
    '🙈' => 'qamalee waan hamaa hin argu jettu',
    '🙉' => 'qamalee waan hamaa hin dhagahu jettu',
    '🙊' => 'qamalee waan hamaa hin dubbadhu jettu',
    '💌' => 'xalayyaa jaalalaa',
    '💘' => 'onnee xiyya waliin',
    '💝' => 'onnee riibanii waliin',
    '💖' => 'onnee calaqqisu',
    '💗' => 'onnee ifu',
    '💓' => 'onnee dhahattu',
    '💞' => 'onnee naanna’u',
    '💕' => 'onnee lama',
    '💟' => 'faaya onnee',
    '❣' => 'raajeffannoo onnee',
    '💔' => 'onnee cabe',
    '❤' => 'onnee diimaa',
    '🩷' => 'onnee daanguleessa',
    '🧡' => 'onnee burtukaana',
    '💛' => 'onnee keelloo',
    '💚' => 'onnee magariisa',
    '💙' => 'onnee cuquliisa',
    '🩵' => 'onnee cuquliisa ifu',
    '💜' => 'onnee bildiimaa',
    '🤎' => 'onnee magaala',
    '🖤' => 'onnee gurraacha',
    '🩶' => 'onnee daalacha',
    '🤍' => 'onnee adii',
    '💋' => 'mallattoo dhungoo',
    '💯' => 'qabxiiwwan dhibba',
    '💢' => 'mallattoo aarii',
    '🫯' => 'duumessa lolaa',
    '💥' => 'walitti bu’insa',
    '💫' => 'dunquqqaa’aa',
    '💦' => 'copha jiidhaa',
    '💨' => 'dhiibaa deemuu',
    '🕳' => 'qaawwa',
    '💬' => 'afuuffee dubbii',
    '🗨' => 'afuuffee dubbii bitaa',
    '🗯' => 'afuuffee dubbii mirgaa',
    '💭' => 'afuuffee yaadaa',
    '💤' => 'ZZZ',
    '👋' => 'harka raasuu',
    '🤚' => 'duuba harkaa ol baasuu',
    '🖐' => 'harka quba bal’isuun',
    '✋' => 'harka ol ba’e',
    '🖖' => 'vuulkaan saluutee',
    '🫱' => 'harka gara mirgaatti',
    '🫲' => 'harka gara bitaatti',
    '🫳' => 'harka barruu gadi garagale',
    '🫴' => 'harka barruu ol garagale',
    '🫷' => 'harka gara bitaatti dhiibu',
    '🫸' => 'harka gara mirgaatti dhiibu',
    '👌' => 'harka tolee',
    '🤌' => 'quboota walitti qabaman',
    '🤏' => 'harka qubni isaa walitti qabame',
    '✌' => 'harka moo’ichaa',
    '🤞' => 'quba wal qaxxaamure',
    '🫰' => 'harka qubni akeektuu fi abgudduun wal qaxxamure',
    '🤟' => 'mallattoo sin jaaladhaa',
    '🤘' => 'mallattoo gaafaa',
    '🤙' => 'harka naaf bilbilii',
    '👈' => 'dugda harkaa bitatti akeeku',
    '👉' => 'dugda harkaa mirgatti akeeku',
    '👆' => 'dugda harkaa asii ol akeeku',
    '🖕' => 'guba gidduu',
    '👇' => 'dugda harkaa asii gadi akeeku',
    '☝' => 'akeektuu ol akeeku',
    '🫵' => 'quba akeektuu gara isa ilaaluutti qiyyaafate',
    '👍' => 'angudduu ol qabuu',
    '👎' => 'abgudduu gadi qabuu',
    '✊' => 'haboottee ol ba’e',
    '👊' => 'haboottee dhufaa jiru',
    '🤛' => 'haboottee gara bitaatti garagale',
    '🤜' => 'haboottee gara mirgaatti garagale',
    '👏' => 'harka rukutuu',
    '🙌' => 'harkawwan baasuu',
    '🫶' => 'harkoota onnee',
    '👐' => 'harkoota banaa',
    '🤲' => 'barruu wal faana ol ka’e',
    '🤝' => 'harka fuudhuu',
    '🙏' => 'harkoota walitti dhufuun ol qabaman',
    '✍' => 'harka barreessu',
    '💅' => 'halluu qeensaa',
    '🤳' => 'selfii',
    '💪' => 'irree dacha’e',
    '🦾' => 'irree mekaanikaalii',
    '🦿' => 'miila mekaanikaalii',
    '🦵' => 'miila',
    '🦶' => 'faana',
    '👂' => 'gurra',
    '🦻' => 'gurra gargaartuu dhageettii waliin',
    '👃' => 'funyaan',
    '🧠' => 'sammuu',
    '🫀' => 'onnee anaatoomii',
    '🫁' => 'somba',
    '🦷' => 'ilkaan',
    '🦴' => 'lafee',
    '👀' => 'ijoota',
    '👁' => 'ija',
    '👅' => 'arraba',
    '👄' => 'afaan',
    '🫦' => 'hidhii ciniinuu',
    '👶' => 'daa’ima',
    '👦' => 'gurbaa',
    '👧' => 'dubara',
    '🧑' => 'nama',
    '👱' => 'nama: rifeensa keelloo',
    '👨' => 'dhiira',
    '🧔' => 'person: areeda qabu',
    '👩' => 'dubartii',
    '🧓' => 'nama jaarsa',
    '👴' => 'jaarsa',
    '👵' => 'jaartii',
    '🙍' => 'nama mufate',
    '🙎' => 'nama huuruu dhiibuu',
    '🙅' => 'nama LAKKI jedhu',
    '🙆' => 'nama TOLE jedhu',
    '💁' => 'nama harka diriirsu',
    '🙋' => 'nama harka baasu',
    '🧏' => 'nama duudaa',
    '🙇' => 'nama sagadu',
    '🤦' => 'nama barruun fuula qabate',
    '🤷' => 'nama mataa raasu',
    '👮' => 'qondaala poolisii',
    '🕵' => 'qorataa',
    '💂' => 'eegaa',
    '🥷' => 'niinjaa',
    '👷' => 'hojjetaa ijaarsaa',
    '🫅' => 'nama gonfoo waliin',
    '🤴' => 'ilma mootii',
    '👸' => 'intala mootii',
    '👳' => 'nama turbaanii uffatu',
    '👲' => 'nama kofiyyaa godhate',
    '🧕' => 'dubartii mataatti maratte',
    '🤵' => 'nama bijaamaa uffate',
    '👰' => 'nama golgaa waliin',
    '🤰' => 'dubartii ulfa',
    '🫃' => 'dhiira ulfa',
    '🫄' => 'nama ulfa',
    '🤱' => 'harma hoosisuu',
    '👼' => 'daa’ima ergamaa',
    '🎅' => 'Saantaa kilaawos',
    '🤶' => 'Obbo Kilaawos',
    '🦸' => 'goota',
    '🦹' => 'jallataa',
    '🧙' => 'falfalaa',
    '🧚' => 'feerii',
    '🧛' => 'vaampaayerii',
    '🧜' => 'nama lo’u',
    '🧝' => 'eeliif',
    '🧞' => 'jinnii',
    '🧟' => 'zoombii',
    '🧌' => 'bulguu',
    '🫈' => 'uumama rifeensaa',
    '💆' => 'nama sukkuumamaa jiru',
    '💇' => 'nama rifeensa sirreeffachaa jiru',
    '🚶' => 'nama deemaa jiru',
    '🧍' => 'nama dhaabbatu',
    '🧎' => 'nama jilbeeffate',
    '🏃' => 'nama fiigu',
    '💃' => 'dubartii shubbistu',
    '🕺' => 'dhiira shubbisu',
    '🕴' => 'nama suufii uffatee bololi’u',
    '👯' => 'namoota gurra baanii ofirraa qaban',
    '🧖' => 'nama kutaa hurkaa keessaa',
    '🧗' => 'nama yaabbachaa jiru',
    '🤺' => 'nama faccisu',
    '🏇' => 'gugsii fardaa',
    '⛷' => 'sigiga cabbii',
    '🏂' => 'daangaa cabbii',
    '🏌' => 'nama golfii taphatu',
    '🏄' => 'nama bololi’u',
    '🚣' => 'nama bidiruu oofu',
    '🏊' => 'nama daakaa jiru',
    '⛹' => 'nama kubbaa utaalchisu',
    '🏋' => 'nama ulfaatina kaasu',
    '🚴' => 'nama biskileetii oofu',
    '🚵' => 'nama biskileetiin tulluu bahu',
    '🤸' => 'nama harkaan garagalu',
    '🤼' => 'namoota wal tuman',
    '🤽' => 'nama pooloo bishaanii taphachaa jiru',
    '🤾' => 'nama kubbaa harkaa taphachaa jiru',
    '🤹' => 'nama waa ol daddarbatee qabatu',
    '🧘' => 'nama lootasii irra jiru',
    '🛀' => 'nama qaama dhiqatu',
    '🛌' => 'nama siree keessa jiru',
    '👭' => 'dubartoota harka wal qabatan',
    '👫' => 'dubartii fi dhiira harka wal qabatan',
    '👬' => 'dhiirota harka wal qabatan',
    '💏' => 'dhungoo',
    '💑' => 'hiriyyoota gaa’ilaa onnee waliin',
    '🗣' => 'mataa dubbatu',
    '👤' => 'bobboca lapheen olii',
    '👥' => 'bobbocawwan lapheen olii',
    '🫂' => 'namoota wal hammatan',
    '👪' => 'maatii',
    '👣' => 'faana miilaa',
    '🫆' => 'ashaaraa qubaa',
    '🦰' => 'rifeensa diimaa',
    '🦱' => 'rifeensa luuccaa',
    '🦳' => 'rifeensa adii',
    '🦲' => 'moluu',
    '🐵' => 'fuula qamalee',
    '🐒' => 'qamalee',
    '🦍' => 'goorillaa',
    '🦧' => 'orangutaan',
    '🐶' => 'fuula saree',
    '🐕' => 'saree',
    '🦮' => 'saree karaa agarsiistu',
    '🐩' => 'puudilii',
    '🐺' => 'jeedala',
    '🦊' => 'sardiida',
    '🦝' => 'xirinyii',
    '🐱' => 'fuula hadurree',
    '🐈' => 'adurree',
    '🦁' => 'leenca',
    '🐯' => 'fuula qeerransaa',
    '🐅' => 'qeerransa',
    '🐴' => 'fuula fardaa',
    '🫎' => 'muusii',
    '🫏' => 'harree',
    '🐎' => 'farda',
    '🦄' => 'yooniikoornii',
    '🦓' => 'harree diidoo',
    '🦌' => 'bosonuu',
    '🦬' => 'biisoon',
    '🐮' => 'fuula sa’aa',
    '🐂' => 'sangaa',
    '🐃' => 'gafarsa bishaanii',
    '🐄' => 'sa’aa',
    '🐷' => 'fuula booyyee',
    '🐖' => 'booyyee',
    '🐽' => 'funyaan booyyee',
    '🐏' => 'korbeessa hoolaa',
    '🐑' => 'hoolaa ilmoo',
    '🐐' => 're’ee',
    '🐪' => 'gaala',
    '🐫' => 'gaala dugda lamaa',
    '🦙' => 'ilaamaa',
    '🦒' => 'sattawwaa',
    '🐘' => 'arba',
    '🦣' => 'maamoozii',
    '🦏' => 'karkarroo',
    '🦛' => 'roobii',
    '🐭' => 'fuula hantuutaa',
    '🐀' => 'hantuuta',
    '🐹' => 'hamisterii',
    '🐰' => 'fuula illeettii',
    '🐇' => 'illeettii',
    '🐿' => 'chiipmaankii',
    '🦫' => 'focii',
    '🦔' => 'xaddee',
    '🦇' => 'simbira halkanii',
    '🐻' => 'biir',
    '🐨' => 'kowaalaa',
    '🐼' => 'paandaa',
    '🦥' => 'isloozii',
    '🦦' => 'ooterii',
    '🦨' => 'luugduu',
    '🦘' => 'kaangaaroo',
    '🦡' => 'iyyaa',
    '🐾' => 'maxxansa faanaa',
    '🦃' => 'turkeeyii',
    '🐔' => 'lukkuu',
    '🐓' => 'kormaa lukkuu',
    '🐣' => 'cuucii yaa’u',
    '🐤' => 'cuucii xiqqoo',
    '🐥' => 'fuuldura cuucii xiqqoo',
    '🐦' => 'simbirroo',
    '🐧' => 'peenguwiin',
    '🕊' => 'gugee nagaa',
    '🦅' => 'culuullee',
    '🦆' => 'daakiyee',
    '🦢' => 'iswaanii',
    '🦉' => 'hurunguu',
    '🦤' => 'doodoo',
    '🪶' => 'baallee',
    '🦩' => 'andoolessa',
    '🦚' => 'piikook',
    '🦜' => 'paaroot',
    '🪽' => 'kaattuu',
    '🪿' => 'dor’ee',
    '🐸' => 'raacha',
    '🐊' => 'naacha',
    '🦎' => 'lootuu',
    '🐍' => 'bofa',
    '🐲' => 'fuula diraagoon',
    '🐉' => 'diraagoon',
    '🦕' => 'saaroopoodii',
    '🦖' => 'Tireeksii',
    '🐳' => 'weelii tufu',
    '🐋' => 'weelii',
    '🐬' => 'doolfiinii',
    '🫍' => 'qurxummuu ajjeesu',
    '🦭' => 'siilii',
    '🐟' => 'qurxummii',
    '🐠' => 'qurxummii tirooppikaalii',
    '🐡' => 'qurxummii afuuftuu',
    '🦈' => 'shaarkii',
    '🐙' => 'oktoopas',
    '🐚' => 'elellaa',
    '🪸' => 'koraalii',
    '🪼' => 'jeeliifiish',
    '🦀' => 'loccuu',
    '🦞' => 'loobisterii',
    '🦐' => 'raammoo bishaan keessaa',
    '🦑' => 'iskuyiidii',
    '🦪' => 'ooyisterii',
    '🐌' => 'cilalluu',
    '🦋' => 'billaacha',
    '🐛' => 'geergoo',
    '🐜' => 'goondaa',
    '🐝' => 'kanniisa dammaa',
    '🪲' => 'ilbiisa boombii',
    '🐞' => 'boombii dhaltuu',
    '🦗' => 'kirikeetii',
    '🪳' => 'bararoo',
    '🕷' => 'sarariitii',
    '🕸' => 'dirra sarariitii',
    '🦂' => 'iskoorpiyoon',
    '🦟' => 'titiisa',
    '🪰' => 'barrisuu',
    '🪱' => 'raammoo',
    '🦠' => 'maayikiroobii',
    '💐' => 'habaaboo kaasuu',
    '🌸' => 'cheerii biloosam',
    '💮' => 'habaaboo adii',
    '🪷' => 'lootes',
    '🏵' => 'rozeetii',
    '🌹' => 'habaaboo',
    '🥀' => 'habaaboo coolige',
    '🌺' => 'hibiskas',
    '🌻' => 'suufii',
    '🌼' => 'biloosam',
    '🌷' => 'tuuliippii',
    '🪻' => 'hayaasiintii',
    '🌱' => 'biqiltuu',
    '🪴' => 'biqiltuu neeshaa keessaa',
    '🌲' => 'muka magariisa',
    '🌳' => 'muka desidasii',
    '🌴' => 'muka meexxii',
    '🌵' => 'adaamii',
    '🌾' => 'habaaboo ruuzii',
    '🌿' => 'baala mukaa',
    '☘' => 'siddisa',
    '🍀' => 'baala afur',
    '🍁' => 'baala maapilii',
    '🍂' => 'baala kufe',
    '🍃' => 'baala bubbee keessa balali’u',
    '🪹' => 'koonyaa duwwaa',
    '🪺' => 'koonyaa killee waliin',
    '🍄' => 'waakkoo',
    '🪾' => 'muka baala hin qabne',
    '🍇' => 'wayinii',
    '🍈' => 'meloonii',
    '🍉' => 'habaabii',
    '🍊' => 'mandariinii',
    '🍋' => 'loomii',
    '🍌' => 'muuzii',
    '🍍' => 'anaanaasii',
    '🥭' => 'maangoo',
    '🍎' => 'appilii diimaa',
    '🍏' => 'appilii magariisa',
    '🍐' => 'piirii',
    '🍑' => 'kookii',
    '🍒' => 'cheerii',
    '🍓' => 'goraa',
    '🫐' => 'goraa cuquliisa',
    '🥝' => 'firii kiwwii',
    '🍅' => 'timaatima',
    '🫒' => 'ejersa',
    '🥥' => 'kokonaatii',
    '🥑' => 'avukaadoo',
    '🍆' => 'eegpilaantii',
    '🥔' => 'dinnicha',
    '🥕' => 'kaarotii',
    '🌽' => 'gurra boqqolloo',
    '🌶' => 'qaaraa gubu',
    '🫑' => 'abbaa suyyaa',
    '🥒' => 'kukumberii',
    '🥬' => 'baala magariisa',
    '🥦' => 'birookoolii',
    '🧄' => 'qullubbii adii',
    '🧅' => 'qullubbii diimaa',
    '🥜' => 'ocholoonii',
    '🫘' => 'baaqelaa',
    '🌰' => 'cheestinaatii',
    '🫚' => 'hidda jinjibilaa',
    '🫛' => 'poodii ataraa',
    '🫜' => 'kuduraa hundee',
    '🍞' => 'daabboo',
    '🥐' => 'kiroosantii',
    '🥖' => 'daabboo abbaa ulee',
    '🫓' => 'daabboo difoo',
    '🥨' => 'pireetizeelii',
    '🥞' => 'paankeekii',
    '🧇' => 'waafeel',
    '🧀' => 'muraa baaduu',
    '🍖' => 'foon lafee irraa',
    '🍗' => 'miila lukkuu',
    '🥩' => 'muraa foonii',
    '🥓' => 'baakoonii',
    '🍔' => 'hambargarii',
    '🍟' => 'waaddii dinnichaa',
    '🍕' => 'piizaa',
    '🌭' => 'saree ho’aa',
    '🥪' => 'daanduchii',
    '🌮' => 'taakoo',
    '🌯' => 'buriitoo',
    '🫔' => 'taamaalee',
    '🥙' => 'daabboo diriiraa guutuu',
    '🧆' => 'felaafeelii',
    '🥚' => 'killee',
    '🍳' => 'nyaata bilcheessuu',
    '🥘' => 'distii nyaataa gadi fagoo',
    '🍲' => 'xuwwee nyaataa',
    '🫕' => 'foondii',
    '🥣' => 'shaanii golboo fal’aana waliin',
    '🥗' => 'saalaadii magariisa',
    '🍿' => 'fandishaa',
    '🧈' => 'dhadhaa',
    '🧂' => 'ashaboo',
    '🥫' => 'nyaata xaasaa keessaa',
    '🍱' => 'sanduuqa beentoo',
    '🍘' => 'cabaa ruuzii',
    '🍙' => 'kubbaa ruuzii',
    '🍚' => 'ruuzii affeelame',
    '🍛' => 'ruuzii kaarii',
    '🍜' => 'kuuraa hurkaa',
    '🍝' => 'ispaageetii',
    '🍠' => 'dinnicha mi’aawaa affeelame',
    '🍢' => 'odeen',
    '🍣' => 'suushii',
    '🍤' => 'shiriimpii waadame',
    '🍥' => 'keekii qurxummii maraa waliin',
    '🥮' => 'keekii addeessaa',
    '🍡' => 'dangoo',
    '🥟' => 'mulmulii',
    '🥠' => 'saambusaa',
    '🥡' => 'sanduuqa',
    '🍦' => 'ayis kireemii laafaa',
    '🍧' => 'cabbii haadame',
    '🍨' => 'ayis kireemii',
    '🍩' => 'doonaatii',
    '🍪' => 'kuukiisii',
    '🎂' => 'keekii guyyaa dhalootaa',
    '🍰' => 'keekii gabaabaa',
    '🧁' => 'kaapkeekii',
    '🥧' => 'ambaashaa',
    '🍫' => 'dalgee chokoleetii',
    '🍬' => 'karameellaa',
    '🍭' => 'looliipooppii',
    '🍮' => 'kaastardii',
    '🍯' => 'xuwwee dammaa',
    '🍼' => 'qaruuraa daa’imaa',
    '🥛' => 'aannan waancaa tokko',
    '☕' => 'dhugaatii ho’aa',
    '🫖' => 'makarajii',
    '🍵' => 'kubbaayyaa shayii qabannoo hin qabne',
    '🍶' => 'saakee',
    '🍾' => 'qaruuraa gadaaddiin irraa futta’u',
    '🍷' => 'wancaa wayinii',
    '🍸' => 'waancaa kookteelii',
    '🍹' => 'dhugaatii tirooppikaalii',
    '🍺' => 'maagii biiraa',
    '🍻' => 'maagii biiraa walitti buusuu',
    '🥂' => 'kubbaayyaawwan fuullee walitti bu’an',
    '🥃' => 'kubbaayyaa fuullee qabannoo hin qabne',
    '🫗' => 'dhangala’aa buusuu',
    '🥤' => 'kubbaayyaa xuuxxuu waliin',
    '🧋' => 'kobba shayii',
    '🧃' => 'sanduuqa dhugaatii',
    '🧉' => 'maatee',
    '🧊' => 'cabbii',
    '🥢' => 'choopistiikii',
    '🍽' => 'fal’aanaa fi haalbee sahaanii waliin',
    '🍴' => 'fal’aana fi haalbee',
    '🥄' => 'fal’aana',
    '🔪' => 'haalbee mana nyaataa',
    '🫙' => 'jaarii',
    '🏺' => 'amfooraa',
    '🌍' => 'giloobii Awurooppaa-Afrikaa agarsiisu',
    '🌎' => 'giloobii Ameerikaa agarsiisu',
    '🌏' => 'giloobii Eeshiyaa-Awustiraaliyaa agarsiisu',
    '🌐' => 'giloobii meridiyaanii waliin',
    '🗺' => 'kaartaa addunyaa',
    '🗾' => 'kaartaa Jaappaan',
    '🧭' => 'kompaasii',
    '🏔' => 'tulluu cabbiin uwwifame',
    '⛰' => 'tulluu',
    '🛘' => 'Sigiga lafaa',
    '🌋' => 'voolkaanoo',
    '🗻' => 'tulluu fujii',
    '🏕' => 'kaampii tolfachuu',
    '🏖' => 'qarqara galaanaa dibaabee waliin',
    '🏜' => 'gammoojjii',
    '🏝' => 'odola gammoojjii',
    '🏞' => 'paarkii biyyaalessaa',
    '🏟' => 'istaadiyeemii',
    '🏛' => 'gamoo kalaasikaalaa',
    '🏗' => 'ijaarsa ijaaruu',
    '🧱' => 'xuubii',
    '🪨' => 'kattaa',
    '🪵' => 'muka',
    '🛖' => 'mana citaa',
    '🏘' => 'manneen',
    '🏚' => 'mana gatame',
    '🏠' => 'mana',
    '🏡' => 'mana iddoo biqiltuu qabu',
    '🏢' => 'gamoo waajjiraa',
    '🏣' => 'mana poostaa Jaappaan',
    '🏤' => 'mana poostaa',
    '🏥' => 'hospitaala',
    '🏦' => 'baankii',
    '🏨' => 'hoteela',
    '🏩' => 'hoteela jaalalaa',
    '🏪' => 'mana daldalaa mijataa',
    '🏫' => 'mana barumsaa',
    '🏬' => 'mana daldalaa muummee',
    '🏭' => 'waarshaa',
    '🏯' => 'masaraa Jaappaan',
    '🏰' => 'masaraa',
    '💒' => 'cidha',
    '🗼' => 'taaworii Tookiyoo',
    '🗽' => 'Siidaa Bilisummaa',
    '⛪' => 'mana kiristaanaa',
    '🕌' => 'masjiida',
    '🛕' => 'mana kadhannaa hinduu',
    '🕍' => 'mana sagadaa',
    '⛩' => 'Shintoo shiriinee',
    '🕋' => 'kaabaa',
    '⛲' => 'madda',
    '⛺' => 'dunkaana',
    '🌁' => 'hurrii',
    '🌃' => 'halkan urjii waliin',
    '🏙' => 'teessuma magaalaa',
    '🌄' => 'aduu tulluu irratti baatu',
    '🌅' => 'aduu baatu',
    '🌆' => 'teessuma magaalaa gara galgalaa',
    '🌇' => 'aduu lixxu',
    '🌉' => 'riqicha halkaniin',
    '♨' => 'burqaa ho’aa',
    '🎠' => 'farda karoosil',
    '🛝' => 'mucucaata bakka taphaa',
    '🎡' => 'goommaa faaris',
    '🎢' => 'rooler koostii',
    '💈' => 'utubaa mana rifeensaa',
    '🎪' => 'dukkaana siirkas',
    '🚂' => 'lokomootiivii',
    '🚃' => 'konkolaataa baaburaa',
    '🚄' => 'baabura saffisa olaanaa',
    '🚅' => 'baabura xiyyitii',
    '🚆' => 'baabura',
    '🚇' => 'meetiroo',
    '🚈' => 'baabura salphaa',
    '🚉' => 'buufata',
    '🚊' => 'tiraamii',
    '🚝' => 'moonooriyaal',
    '🚞' => 'baabura tulluu',
    '🚋' => 'konkolaataa tiraamii',
    '🚌' => 'atoobisii',
    '🚍' => 'atoobisii dhufaa jiru',
    '🚎' => 'tirooliibaas',
    '🚐' => 'minibaasii',
    '🚑' => 'ambulaansii',
    '🚒' => 'konkolaataa ibidda dhaamsu',
    '🚓' => 'konkolaataa poolisii',
    '🚔' => 'konkolaataa poolisii dhufaa jiru',
    '🚕' => 'taaksii',
    '🚖' => 'taaksii dhufaa jiru',
    '🚗' => 'awutoomoobilii',
    '🚘' => 'awutoomoobilii dhufaa jiru',
    '🚙' => 'konkolaataa tajaajila ispoortii',
    '🛻' => 'konkolaataa piikaappii',
    '🚚' => 'konkolaataa meeshaa dhaqqabsiisu',
    '🚛' => 'konkolaataa fe’umsaa',
    '🚜' => 'tiraaktera',
    '🏎' => 'konkolaataa dorgommii',
    '🏍' => 'motorsaayikilii',
    '🛵' => 'iskuuterii motoraa',
    '🦽' => 'wiilcherii harkaa',
    '🦼' => 'wiilcherii motoraa',
    '🛺' => 'awutoo riikshaawu',
    '🚲' => 'biskileetii',
    '🛴' => 'iskuuterii irra ejjetamu',
    '🛹' => 'iskeet boordii',
    '🛼' => 'iskaatii naanna’u',
    '🚏' => 'dhaabbii atoobisii',
    '🛣' => 'daandii motoraa',
    '🛤' => 'hadiida baaburaa',
    '🛢' => 'baarmeelii boba’aa',
    '⛽' => 'paampii boba’aa',
    '🛞' => 'wiilii',
    '🚨' => 'ifa konkolaataa poolisii',
    '🚥' => 'ibsaa tiraafikaa dalgaa',
    '🚦' => 'ibsaa tiraafikaa olee',
    '🛑' => 'mallaattoo dhaabadhuu',
    '🚧' => 'ijaarsa',
    '⚓' => 'sibiila dooniin ittiin dhaabbatu',
    '🛟' => 'afuuffee geengoo bishaan irraa',
    '⛵' => 'bidiruu',
    '🛶' => 'yabala',
    '🚤' => 'bidiruu saffisaa',
    '🛳' => 'doonii imaltootaa',
    '⛴' => 'doonii',
    '🛥' => 'bidiruu motoraa',
    '✈' => 'xiyyaara',
    '🛩' => 'xiyyaara xiqqoo',
    '🛫' => 'ka’umsa xiyyaaraa',
    '🛬' => 'bu’uu xiyyaaraa',
    '🪂' => 'paaraashuutii',
    '💺' => 'taa’umsa',
    '🚁' => 'helekooptera',
    '🚟' => 'baabura rarraafamu',
    '🚠' => 'daandii wadaroo tulluu',
    '🚡' => 'daandii tiraamii qilleensaa',
    '🛰' => 'saatelaayitii',
    '🚀' => 'rookkeettii',
    '🛸' => 'saawuserii balali’u',
    '🛎' => 'belbela hojiif dammaqsitu',
    '🧳' => 'borsaa imalaa',
    '⌛' => 'sa’aatiifuullee xumurame',
    '⏳' => 'sa’aatiifuulee hin xumuramne',
    '⌚' => 'sa’aatii',
    '⏰' => 'sa’aatii dammaqsituu',
    '⏱' => 'sa’aatii dhaabbii',
    '⏲' => 'sa’aatii lakkooftuu',
    '🕰' => 'sa’aatii manteelpiis',
    '🕛' => 'sa’aatii kudha lama',
    '🕧' => 'kudha lamaaf walakkaa',
    '🕐' => 'sa’aatii tokko',
    '🕜' => 'tokkoof walakkaa',
    '🕑' => 'sa’aatii lama',
    '🕝' => 'lamaaf walakkaa',
    '🕒' => 'sa’aatii sadii',
    '🕞' => 'sadiif walakkaa',
    '🕓' => 'sa’aatii afur',
    '🕟' => 'afuriif walakkaa',
    '🕔' => 'sa’aatii shan',
    '🕠' => 'shaniif walakkaa',
    '🕕' => 'sa’aatii jaha',
    '🕡' => 'ja’aaf walakkaa',
    '🕖' => 'sa’aatii toorba',
    '🕢' => 'toorbaaf walakkaa',
    '🕗' => 'sa’aatii saddet',
    '🕣' => 'saddetiif walakkaa',
    '🕘' => 'sa’aatii sagal',
    '🕤' => 'sagaliif walakkaa',
    '🕙' => 'sa’aatii kudhan',
    '🕥' => 'kudhaniif walakkaa',
    '🕚' => 'sa’aatii kudha tokko',
    '🕦' => 'kudha tokkoof walakkaa',
    '🌑' => 'addeessa haaraa',
    '🌒' => 'addeessa dabalaa deemu',
    '🌓' => 'addeessa kurmaana jalqabaa',
    '🌔' => 'addeessa guutuu ga’e',
    '🌕' => 'addeessa guutuu',
    '🌖' => 'addeessa hir’ataa deemu',
    '🌗' => 'addeessa kurmaana dhumaa',
    '🌘' => 'addeessa baduu ga’e',
    '🌙' => 'addeessa walakkaa',
    '🌚' => 'fuula addeessa haaraa',
    '🌛' => 'fuula addeessaa kurmaana jalqabaa',
    '🌜' => 'fuula addeessa kurmaana dhumaa',
    '🌡' => 'termoomeetirii',
    '☀' => 'aduu',
    '🌝' => 'fuula addeessa guutuu',
    '🌞' => 'aduu fuula waliin',
    '🪐' => 'pilaaneetii naanna’u',
    '⭐' => 'urjii',
    '🌟' => 'urjii ifu',
    '🌠' => 'urjii furguggifamu',
    '🌌' => 'miilki weyii',
    '☁' => 'duumessa',
    '⛅' => 'aduu duumessa duubaa',
    '⛈' => 'duumessa bakakkaa fi rooba waliin',
    '🌤' => 'aduu duumessa xiqqoo duubaa',
    '🌥' => 'aduu duumessa guddaa duubaa',
    '🌦' => 'aduu duumessa rooba duubaa',
    '🌧' => 'duumessa rooba waliin',
    '🌨' => 'duumessa cabbii waliin',
    '🌩' => 'duumessa bakakkaa waliin',
    '🌪' => 'obomboleettii',
    '🌬' => 'fuula bubbee',
    '🌀' => 'saayikiloonii',
    '🌈' => 'sabbata waaqaa',
    '🌂' => 'dibaabee cufamaa',
    '☂' => 'dibaabee',
    '☔' => 'dibaabee rooba roobu waliin',
    '⛱' => 'dibaabee lafa jiru',
    '⚡' => 'voolteejii olaanaa',
    '❄' => 'harcaatii cabbii',
    '☃' => 'nama cabbii',
    '⛄' => 'nama cabbii cabbii malee',
    '☄' => 'koomeetii',
    '🔥' => 'ibidda',
    '💧' => 'copha',
    '🌊' => 'dambalii bishaanii',
    '🎃' => 'jaak=olaanternii',
    '🎄' => 'muka ayyaana qillee',
    '🎆' => 'hojii ibiddaa',
    '🎇' => 'qaanqee',
    '🧨' => 'dhukaatuu ibiddaa',
    '✨' => 'calaqqeewwan',
    '🎈' => 'afuuffee',
    '🎉' => 'paartii poopper',
    '🎊' => 'kubbaa konfeetii',
    '🎋' => 'muka tanabaataa',
    '🎍' => 'faaya paayinii',
    '🎎' => 'ashaangulliitii Jaappaan',
    '🎏' => 'tamsaasa caarpii',
    '🎐' => 'naannoftuu bubbee',
    '🎑' => 'kabaja addeessa ilaaluu',
    '🧧' => 'poostaa diimaa',
    '🎀' => 'riibanii',
    '🎁' => 'kennaa golgame',
    '🎗' => 'riibanii yaadachiisaa',
    '🎟' => 'tikkeetii seensaa',
    '🎫' => 'tikkeetii',
    '🎖' => 'meedaaliyaa waraanaa',
    '🏆' => 'geeba',
    '🏅' => 'meedaaliyaa ispoortii',
    '🥇' => 'meedaaliyaa 1ffaa',
    '🥈' => 'meedaaliyaa 2ffaa',
    '🥉' => 'meedaaliyaa 3ffaa',
    '⚽' => 'kubbaa miillaa',
    '⚾' => 'beezboolii',
    '🥎' => 'kubbaa laafaa',
    '🏀' => 'kubbaa saaphanaa',
    '🏐' => 'kubbaa kachoo',
    '🏈' => 'kubbaa miillaa ameerikaa',
    '🏉' => 'kubbaa miillaa ragbii',
    '🎾' => 'teenisii',
    '🥏' => 'beeddee balali’aa jiru',
    '🎳' => 'boowuliingii',
    '🏏' => 'tapha kirikeetii',
    '🏑' => 'hookii dirree',
    '🏒' => 'hookii cabbii',
    '🥍' => 'laakiroosii',
    '🏓' => 'piing poongii',
    '🏸' => 'baadmintan',
    '🥊' => 'gowaantii buunyaa',
    '🥋' => 'uffata danbii maarshaal artii',
    '🥅' => 'kiyyoo galchii',
    '⛳' => 'alaabaa boolla keessaa',
    '⛸' => 'iskeetii cabbii',
    '🎣' => 'dhaaba qurxummii kiyyeessuu',
    '🤿' => 'haguuggii culluxxoo bishaanii',
    '🎽' => 'qomee fiigichaa',
    '🎿' => 'iskiis',
    '🛷' => 'shartattee',
    '🥌' => 'dhagaa gungurii',
    '🎯' => 'buliseyee',
    '🪀' => 'yoo-yoo',
    '🪁' => 'kaayitii',
    '🔫' => 'shugguxii bishaanii',
    '🎱' => 'kubbaa puulii 8',
    '🔮' => 'kubbaa kiristaalaa',
    '🪄' => 'ulee falfalaa',
    '🎮' => 'tapha suurasagalee',
    '🕹' => 'jooyistiikii',
    '🎰' => 'maashinii qaawwaa',
    '🎲' => 'daayii taphaa',
    '🧩' => 'qeenxee pazilii',
    '🧸' => 'teedii biir',
    '🪅' => 'pinaataa',
    '🪩' => 'kubbaa of ilaallee',
    '🪆' => 'doolii toora gale',
    '♠' => 'mallattoo ispeed',
    '♥' => 'mallattoo onnee',
    '♦' => 'mallattoo daayimendii',
    '♣' => 'mallattoo kilabii',
    '♟' => 'paawunii cheezii',
    '🃏' => 'jookerii',
    '🀄' => 'diraagoonii diimaa mahijoong',
    '🎴' => 'kaardii taphaa habaaboo',
    '🎭' => 'artiiwwan adeemsisuu',
    '🖼' => 'fireemii suuraa',
    '🎨' => 'gabatee artistii',
    '🧵' => 'kirrii',
    '🪡' => 'lilmoo hodhaa',
    '🧶' => 'maraa kirrii',
    '🪢' => 'hiddaa',
    '👓' => 'kishaafa',
    '🕶' => 'kishaafa aduu',
    '🥽' => 'kishaafa guddaa',
    '🥼' => 'uffata laabii',
    '🦺' => 'uffata nageenyaa',
    '👔' => 'karabaataa',
    '👕' => 'qomee',
    '👖' => 'jiinsii',
    '🧣' => 'fooxaa mormaa',
    '🧤' => 'golgaa harkaa',
    '🧥' => 'kaabbortaa',
    '🧦' => 'kaalsiiwwan',
    '👗' => 'wandaboo',
    '👘' => 'kimoonoo',
    '🥻' => 'saarii',
    '🩱' => 'uffata bishaan daakaa',
    '🩲' => 'uffata keessaa',
    '🩳' => 'qumxaa',
    '👙' => 'bikinii',
    '👚' => 'uffata dubartootaa',
    '🪭' => 'hurguftuu harkaa dacha’u',
    '👛' => 'borsaa',
    '👜' => 'borsa harkaa',
    '👝' => 'borsaa maallaqaa',
    '🛍' => 'borsaa ittiin gabaa bahan',
    '🎒' => 'borsaa dugdaa',
    '🩴' => 'siliipparii',
    '👞' => 'kophee dhiiraa',
    '👟' => 'kophee fiigichaa',
    '🥾' => 'boottii karaa deemsaa',
    '🥿' => 'kophee diriiraa',
    '👠' => 'kophee ol dheeraa',
    '👡' => 'kophee dubartootaa',
    '🩰' => 'kophee baaleetii',
    '👢' => 'boottii dubartootaa',
    '🪮' => 'filaa',
    '👑' => 'gonfoo',
    '👒' => 'qoobii dubartii',
    '🎩' => 'qoobii gubbaa',
    '🎓' => 'qoobii eebbaa',
    '🧢' => 'keeppii golboo',
    '🪖' => 'kofiyyaa waraanaa',
    '⛑' => 'heelmeetii hojjetoota baraarsaa',
    '📿' => 'lakkooftuu kadhannaa',
    '💄' => 'lippistikii',
    '💍' => 'qubeelaa',
    '💎' => 'daayimendii',
    '🔇' => 'sagalee guddistuu ukkaamfame',
    '🔈' => 'sagalee guddistuu iyya gadi aanaa',
    '🔉' => 'sagalee guddistuu iyya gidduugaleessaa',
    '🔊' => 'sagalee guddistuu iyya olaanaa',
    '📢' => 'sagalee guddistuu',
    '📣' => 'meeggaafoonii',
    '📯' => 'xurumbaa poostaa',
    '🔔' => 'belbelaa',
    '🔕' => 'belbelli dhorkaadha',
    '🎼' => 'qabxiiwwan muuziqaa',
    '🎵' => 'noottaa muuziqaa',
    '🎶' => 'noottaawwan muuziqaa',
    '🎙' => 'maayikiraafoonii istuudiyoo',
    '🎚' => 'sochoostuu sadarkaa',
    '🎛' => 'qafoo to’annoo',
    '🎤' => 'maayikiraafoonii',
    '🎧' => 'dhaggeeffattuu gurraa',
    '📻' => 'raadiyoo',
    '🎷' => 'saaksifoonii',
    '🎺' => 'tiraampeetii',
    '🪊' => 'tiraamboonii',
    '🪗' => 'akkoordiyoon',
    '🎸' => 'gitaara',
    '🎹' => 'kiiboordii muuziqaa',
    '🎻' => 'vaayoliinii',
    '🪕' => 'baanjoo',
    '🥁' => 'diraamii',
    '🪘' => 'dibbee dheeraa',
    '🪇' => 'marakaas',
    '🪈' => 'uluullee',
    '🪉' => 'baganaa',
    '📱' => 'bilbila harkaa',
    '📲' => 'bilbila harkaa xiyya waliin',
    '☎' => 'bilbila',
    '📞' => 'fudhataa bilbilaa',
    '📟' => 'paajeerii',
    '📠' => 'maashinii faaksii',
    '🔋' => 'baatirii',
    '🪫' => 'baatirii gadaanaa',
    '🔌' => 'elektirikii suuqamu',
    '💻' => 'laaptooppii',
    '🖥' => 'kompiitera deeskitooppii',
    '🖨' => 'priinterii',
    '⌨' => 'Kiiboordii',
    '🖱' => 'hantuutee kompiiteraa',
    '🖲' => 'kubbaa faana dhahuu',
    '💽' => 'diiskii kompiiteraa',
    '💾' => 'diiskii filooppii',
    '💿' => 'diiskii optikaalii',
    '📀' => 'dvd',
    '🧮' => 'abaakasii',
    '🎥' => 'kaameraa fiilmii',
    '🎞' => 'fireemiiwwan fiilmii',
    '📽' => 'calaqqisiistuu fiilmii',
    '🎬' => 'gabatee walitti rukutuu',
    '📺' => 'televijinii',
    '📷' => 'kaameraa',
    '📸' => 'kaameraa ifa waliin',
    '📹' => 'kaameraa suursagalee',
    '📼' => 'kaasseettii suursagalee',
    '🔍' => 'daawwitii ol guddisu bitatti naanna’e',
    '🔎' => 'daawwitii ol guddisu mirgatti naanna’e',
    '🕯' => 'shaamaa',
    '💡' => 'ampuulii',
    '🔦' => 'baatirii harkaa',
    '🏮' => 'afuuffee warqaa diimaa',
    '🪔' => 'ibsaa diyaa',
    '📔' => 'dabtara yaadannoo faayaan golgame',
    '📕' => 'kitaaba cufaa',
    '📖' => 'kitaaba banaa',
    '📗' => 'kitaaba magariisa',
    '📘' => 'kitaaba cuquliisa',
    '📙' => 'kitaaba burtukaana',
    '📚' => 'kitaabilee',
    '📓' => 'dabtara yaadannoo',
    '📒' => 'galmee',
    '📃' => 'fuula waraqaa dabe',
    '📜' => 'maraa',
    '📄' => 'fuula waraqaa ol garagale',
    '📰' => 'gaazexaa',
    '🗞' => 'gaazexaa marame',
    '📑' => 'fuulota mallattoo kitaabaa',
    '🔖' => 'mallattoo kitaabaa',
    '🏷' => 'mallattoo',
    '🪙' => 'saantima',
    '🪎' => 'sanduuqa faayaa',
    '💴' => 'dabtara baankii yeen',
    '💵' => 'dabtara baankii doolaaraa',
    '💶' => 'dabtara baankii yuuroo',
    '💷' => 'dabtara baankii paawondii',
    '💸' => 'maallaqa koochoo waliin',
    '💳' => 'kaardii liqii',
    '🧾' => 'nagayee',
    '💹' => 'chaartii yeenii guddachaa jiru',
    '✉' => 'poostaa',
    '📧' => 'imeelii',
    '📨' => 'poostaa dhufu',
    '📩' => 'poostaa xiyya waliin',
    '📤' => 'dirra ala bahu',
    '📥' => 'dirra keessa seenu',
    '📦' => 'kuufama',
    '📫' => 'sanduuqa ergaa cufame alaabaa ol qabame waliin',
    '📪' => 'sanduuqa ergaa cufame alaabaa gadi qabame waliin',
    '📬' => 'sanduuqa ergaa banaa alaabaa ol qabame waliin',
    '📭' => 'sanduuqa ergaa banaa alaabaa gadi qabame waliin',
    '📮' => 'sabduuqa poostaa',
    '🗳' => 'sanduuqa filannoo kan filannoo waliinii',
    '✏' => 'qubeessaa',
    '✒' => 'ija qalamaa gurraacha',
    '🖋' => 'qalama burqaa',
    '🖊' => 'qalama',
    '🖌' => 'buruushii fakkii',
    '🖍' => 'kiraayoonii',
    '📝' => 'yaadannoo',
    '💼' => 'borsaa sanadaa',
    '📁' => 'kuusaa faayilaa',
    '📂' => 'kuusaa faayilaa banaa',
    '🗂' => 'qoodduu akeektuu kaardii',
    '📅' => 'dhaba baraa',
    '📆' => 'dhaba baraa garagalu',
    '🗒' => 'yaadannoo garagalu',
    '🗓' => 'dhaha baraa gagaragalu',
    '📇' => 'agarsiistuu kaardii',
    '📈' => 'chaartii guddachaa jiru',
    '📉' => 'chaarxii xiqqaachaa jiru',
    '📊' => 'chaartii sarara furdaa',
    '📋' => 'kiliipboordii',
    '📌' => 'maxxansituu',
    '📍' => 'maxxansituu geengoo',
    '📎' => 'qabduu wwaraqaa',
    '🖇' => 'waraqaa wal qabsiifame',
    '📏' => 'sarartuu kallattii',
    '📐' => 'sarartuu rogsadee',
    '✂' => 'maqasii',
    '🗃' => 'sanduuqa faayilaa kaardii',
    '🗄' => 'bakka taa’umsa faayilaa',
    '🗑' => 'guuboo balfaa',
    '🔒' => 'cufamaa',
    '🔓' => 'banamaa',
    '🔏' => 'qalamaan kan cufame',
    '🔐' => 'furttuidhaan kan cufame',
    '🔑' => 'furtuu',
    '🗝' => 'furtuu durii',
    '🔨' => 'burruusa',
    '🪓' => 'qottoo',
    '⛏' => 'doomaa',
    '⚒' => 'burruusaa fi doomaa',
    '🛠' => 'burruusaa fi furtuu',
    '🗡' => 'cuubee',
    '⚔' => 'seefii wal qaxxaamure',
    '💣' => 'boombii',
    '🪃' => 'murxuxxee',
    '🏹' => 'xiyyaa fi qiyya',
    '🛡' => 'gaachana',
    '🪚' => 'murtuu mukaa',
    '🔧' => 'hiiktuu',
    '🪛' => 'hiiktuu iskiriwuu',
    '🔩' => 'naatii fi booltii',
    '⚙' => 'ilkaan motoraa',
    '🗜' => 'kilaampii',
    '⚖' => 'madaallii',
    '🦯' => 'shimala adii',
    '🔗' => 'hidhoo',
    '⛓' => 'cancala',
    '🪝' => 'qabduu',
    '🧰' => 'sanduuqa meeshaa',
    '🧲' => 'maagineetii',
    '🪜' => 'yaabannoo',
    '🪏' => 'shoofoo',
    '⚗' => 'albeemikii',
    '🧪' => 'ujummoo yaalii',
    '🧫' => 'fuulessaa ifaa',
    '🧬' => 'dna',
    '🔬' => 'maayikirooskooppii',
    '🔭' => 'teleskooppii',
    '📡' => 'anteenaa',
    '💉' => 'lilmoo',
    '🩸' => 'copha dhiigaa',
    '💊' => 'qoricha',
    '🩹' => 'hiituu maxxanu',
    '🩼' => 'kiraanchii',
    '🩺' => 'isteetiskooppii',
    '🩻' => 'eksireyii',
    '🚪' => 'balbala',
    '🛗' => 'liiftii',
    '🪞' => 'of ilaallee',
    '🪟' => 'foddaa',
    '🛏' => 'siree',
    '🛋' => 'soofaa fi ibsaa',
    '🪑' => 'teessuma',
    '🚽' => 'mana fincaanii',
    '🪠' => 'pilaangerii',
    '🚿' => 'shaaworii',
    '🛁' => 'gabatee qama dhiqannaa',
    '🪤' => 'kiyyoo hantuutaa',
    '🪒' => 'qarabaa',
    '🧴' => 'qaruuraa looshinii',
    '🧷' => 'lilmoo eeggannoo',
    '🧹' => 'haxooftuu',
    '🧺' => 'guuboo',
    '🧻' => 'maraa waraqaa',
    '🪣' => 'baaldii',
    '🧼' => 'saamunaa',
    '🫧' => 'afuuffeewwan',
    '🪥' => 'buruushii ilkaanii',
    '🧽' => 'ispoonjii',
    '🧯' => 'ibidda dhaamsituu',
    '🛒' => 'gaarii ittiin meeshaa bitatan',
    '🚬' => 'tamboo',
    '⚰' => 'sanduuqa reeffaa',
    '🪦' => 'siidaa awwaalchaa',
    '⚱' => 'xuwwee awwaalchaa',
    '🧿' => 'naazaar amuuleet',
    '🪬' => 'haamsaa',
    '🗿' => 'mo’aayii',
    '🪧' => 'taappeellaa',
    '🪪' => 'kaardii adda baastuu',
    '🏧' => 'mallattoo ATM',
    '🚮' => 'mallattoo kosii gatuu',
    '🚰' => 'bishaan waraabamu',
    '♿' => 'mallattoo wiilcherii',
    '🚹' => 'kutaa dhiirotaa',
    '🚺' => 'kutaa dubartootaa',
    '🚻' => 'kutaa boqonnaa',
    '🚼' => 'mallattoo daa’imaa',
    '🚾' => 'bishaan kuufamaa',
    '🛂' => 'to’annoo paaspoortii',
    '🛃' => 'gumuruka',
    '🛄' => 'boorsaa imalaa oolfachuu',
    '🛅' => 'boorsaa bitaa',
    '⚠' => 'akeekkachiisa',
    '🚸' => 'daa’imman qaxxaamuran',
    '⛔' => 'seenuun dhorkaadha',
    '🚫' => 'dhorkaadha',
    '🚳' => 'biskileetiin dhorkaadha',
    '🚭' => 'tamboo aarsuun dhorkaadha',
    '🚯' => 'kosii gatuun dhorkaadha',
    '🚱' => 'bishaan hin waraabamne',
    '🚷' => 'miilaan deemuun dhorkaadha',
    '📵' => 'bilbilli harkaa dhorkaadha',
    '🔞' => 'kudha saddetii gadi dhorkaadha',
    '☢' => 'raadiyoo’aktiivii',
    '☣' => 'baayoohaazaardii',
    '⬆' => 'xiyya olee',
    '↗' => 'xiyya olee-mirgaa',
    '➡' => 'xiyya mirgaa',
    '↘' => 'xiyya gadee-mirgaa',
    '⬇' => 'xiyya gadee',
    '↙' => 'xiyya gadee-bitaa',
    '⬅' => 'xiyya bitaa',
    '↖' => 'xiyya olee-bitaa',
    '↕' => 'xiyya olee-gadii',
    '↔' => 'xiyya bitaa-mirgaa',
    '↩' => 'xiyya mirgaa bitatti jallatu',
    '↪' => 'xiyya bitaa mirgatti jallatu',
    '⤴' => 'xiyya mirgaa ol jallatu',
    '⤵' => 'xiyya mirgaa gadi jallatu',
    '🔃' => 'xiyyoota olee kallattii sa’aattiitti naanna’an',
    '🔄' => 'xiyyoota olee faallaa sa’aattiitti naanna’an',
    '🔙' => 'xiyya DUUBAA',
    '🔚' => 'xiyya XUMURAA',
    '🔛' => 'xiyya BANI!',
    '🔜' => 'xiyya DHIYOO',
    '🔝' => 'xiyya GUBBAA',
    '🛐' => 'bakka waaqeffannaa',
    '⚛' => 'mallattoo atoomii',
    '🕉' => 'oomii',
    '✡' => 'urjii daawwit',
    '☸' => 'goommaa daarmaa',
    '☯' => 'yiin yaang',
    '✝' => 'fannoo laatinii',
    '☦' => 'fannoo ortodooksii',
    '☪' => 'urjii fi ji’a',
    '☮' => 'mallattoo nagaa',
    '🕎' => 'menooraa',
    '🔯' => 'tuqaa urjii qabxii jaha',
    '🪯' => 'kaandaa',
    '♈' => 'Ariyees',
    '♉' => 'Tawuruus',
    '♊' => 'Jeeminii',
    '♋' => 'Kaanserii',
    '♌' => 'Liyoo',
    '♍' => 'Viirgoo',
    '♎' => 'Libraa',
    '♏' => 'Iskoorpiyoo',
    '♐' => 'Sagitaariyees',
    '♑' => 'Kaappirikoorn',
    '♒' => 'Akuwaariyaa',
    '♓' => 'Pisees',
    '⛎' => 'Ofiyookas',
    '🔀' => 'qabduu daandii waljala darbuu',
    '🔁' => 'qabduu irra deebii',
    '🔂' => 'qabduu yeroo tokko irra deebi’ii',
    '▶' => 'qabduu taphadhuu',
    '⏩' => 'qabduu saffisaan-fuulduratti',
    '⏭' => 'qabduu tiraakii itti aanu',
    '⏯' => 'qabduu taphachuu yookiin dhaabuu',
    '◀' => 'qabduu duubatti deebisuu',
    '⏪' => 'qabduu saffisaan duubatti',
    '⏮' => 'qabduu tiraakii dhumaa',
    '🔼' => 'qabduu olee',
    '⏫' => 'qabduu saffisaan ol',
    '🔽' => 'qabduu gadee',
    '⏬' => 'qabduu saffisaan gadi',
    '⏸' => 'qabduu yeroo dhaabii',
    '⏹' => 'qabduu dhaabii',
    '⏺' => 'qabduu waraabbii',
    '⏏' => 'qabduu buqqisuu',
    '🎦' => 'sinimaa',
    '🔅' => 'qabduu dimimmisaa',
    '🔆' => 'qabduu ifaa',
    '📶' => 'sararoota anteenaa',
    '🛜' => 'sarara maleessa',
    '📳' => 'tooftaa hollannaa',
    '📴' => 'bilbila harkaa cufaa',
    '♀' => 'mallattoo dhalaa',
    '♂' => 'mallattoo dhiiraa',
    '⚧' => 'mallattoo saala jijjiirachuu',
    '✖' => 'baay’isuu',
    '➕' => 'ida’uu',
    '➖' => 'hir’isuu',
    '➗' => 'hiruu',
    '🟰' => 'mallattoo walqixaa guddaa',
    '♾' => 'infiniitii',
    '‼' => 'mallattoo raajjeffannoo dachaa',
    '⁉' => 'mallattoo rajjeffannoo gaaffii',
    '❓' => 'mallattoo gaaffii diimaa',
    '❔' => 'mallattoo gaaffii adii',
    '❕' => 'mallattoo raajeffannoo adii',
    '❗' => 'mallattoo raajeffannoo diimaa',
    '〰' => 'sarara xiqqaa dambalii',
    '💱' => 'jijjiirraa sharafaa',
    '💲' => 'mallattoo doolaaraa guddaa',
    '⚕' => 'mallattoo meedikaalaa',
    '♻' => 'mallattoo marsaa',
    '⚜' => 'filuur-de-liis',
    '🔱' => 'aasxaa qara sadii',
    '📛' => 'baajii maqaa',
    '🔰' => 'mallattoo Jaappaan jalqabaaf',
    '⭕' => 'qaawwa geengoo diimaa',
    '✅' => 'qabduu mallattoo mirkanaa',
    '☑' => 'sanduuqa mirkaneessaa mirkanaa’e',
    '✔' => 'mallattoo mirkanaa',
    '❌' => 'mallattoo fannoo',
    '❎' => 'qabduu mallattoo fannoo',
    '➰' => 'marsaa qaxxaamuraa',
    '➿' => 'marsaa yeroo lama qaxxaamuru',
    '〽' => 'mallattoo wal jijjiirraa kutaa',
    '✳' => 'urjii dubbattuu saddet',
    '✴' => 'urjii qabxii saddetii',
    '❇' => 'calaqqee',
    '™' => 'mallattoo dandalaa',
    '🫟' => 'dhangala’aa faca’u',
    '🔠' => 'qubee guddaa laatinii galchi',
    '🔡' => 'qubee xiqqaa laatinii galchi',
    '🔢' => 'lakkoofsota galchi',
    '🔣' => 'mallattoolee galchi',
    '🔤' => 'qubeewwan laatinii galchi',
    '🅰' => 'qabduu A (gosa dhiigaa)',
    '🆎' => 'qabduu AB (gosa dhiigaa)',
    '🅱' => 'qabduu B (gosa dhiigaa)',
    '🆑' => 'qabduu CL',
    '🆒' => 'qabduu QORRAA',
    '🆓' => 'qabduu BILISAA',
    'ℹ' => 'odeeffannoo',
    '🆔' => 'qabduu ID',
    'Ⓜ' => 'M geenga’e',
    '🆕' => 'qabduu HAARAA',
    '🆖' => 'qabduu NG',
    '🅾' => 'qabduu O (gosa dhiigaa)',
    '🆗' => 'qabduu TOLE',
    '🅿' => 'qabduu P',
    '🆘' => 'qabduu SOS',
    '🆙' => 'qabduu UP!',
    '🆚' => 'qabduu VS',
    '🈁' => 'qabduu “ishee” Jaappaan',
    '🈂' => 'qabduu “gatii tajaajilaa” Jaappaan',
    '🈷' => 'qabduu “hagamtaa ji’aa” Jaappaan',
    '🈶' => 'qabduu “kaffaltii irraa bilisa miti” Jaappaan',
    '🈯' => 'qabduu “qabameera” Jaappaan',
    '🉐' => 'qabduu “daldalaaf waliin dubbachuu” Jaappaan',
    '🈹' => 'qabduu “hir’ifama gatii” Jaappaan',
    '🈚' => 'qabduu “kaffaltii irraa bilisa” Jaappaan',
    '🈲' => 'qabduu “dhorkaadha” Jaappaan',
    '🉑' => 'qabduu “fudhatamaa” Jaappaan',
    '🈸' => 'qabduu “appilikeeshinii” Jaappaan',
    '🈴' => 'qabduu “qabxii darbinsaa” Jaappaan',
    '🈳' => 'qabduu “gita hojii banaa” Jaappaan',
    '㊗' => 'qabduu “baga gammaddee” Jaappaan',
    '㊙' => 'qabduu “dhoksaa” Jaappaan',
    '🈺' => 'qabduu “daldalaaf banaa” Jaappaan',
    '🈵' => 'qabduu “giti hojii banaa hin jiru” Jaappaan',
    '🔴' => 'geengoo diimaa',
    '🟠' => 'geengoo burtukaana',
    '🟡' => 'geengoo keelloo',
    '🟢' => 'geengoo magariisa',
    '🔵' => 'geengoo cuquliisa',
    '🟣' => 'geengoo siddisaa',
    '🟤' => 'geengoo magaala',
    '⚫' => 'geengoo gurraacha',
    '⚪' => 'geengoo adii',
    '🟥' => 'iskuweerii diimaa',
    '🟧' => 'iskuweerii burtukaana',
    '🟨' => 'iskuweerii keelloo',
    '🟩' => 'iskuweerii magariisa',
    '🟦' => 'iskuweerii cuquliisa',
    '🟪' => 'iskuweerii siddisa',
    '🟫' => 'iskuweerii magaala',
    '⬛' => 'iskuweerii guddaa gurraacha',
    '⬜' => 'iskuweerii guddaa adii',
    '◼' => 'iskuweerii giddugaleessa gurraacha',
    '◻' => 'iskuweerii giddugaleessa adii',
    '◾' => 'iskuweerii giddugaleessa-xiqqoo gurraacha',
    '◽' => 'iskuweerii giddugaleessa-xiqqoo adii',
    '▪' => 'iskuweerii xiqqoo gurraacha',
    '▫' => 'iskuweerii xiqqoo adii',
    '🔶' => 'diyaamendii burtukaanii guddaa',
    '🔷' => 'diyaamendii cuquliisa guddaa',
    '🔸' => 'diyaamendii burtukaanii xiqqaa',
    '🔹' => 'diyaamendii cuquliisa xiqqaa',
    '🔺' => 'rogsadee diimaa ol garagale',
    '🔻' => 'rogsadee diimaa gadi garagale',
    '💠' => 'daayimendii tuqaa waliin',
    '🔘' => 'qabduu raadiyoo',
    '🔳' => 'qabduu iskuweerii adii',
    '🔲' => 'qabduu iskuweerii gurraacha',
    '🏁' => 'alaabaa mallattoon itti godhame',
    '🚩' => 'alaabaa rogsadee',
    '🎌' => 'alaabaa wal qaxxaamure',
    '🏴' => 'alaabaa gurraacha',
    '🏳' => 'alaabaa adii',
];
