<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'se póškajucy pórik: dorosćony, dorosćony, swětła barwa kóže a srjejźnoswětła barwa kóže',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'se póškajucy pórik: dorosćony, dorosćony, swětła barwa kóže a wósrědna barwa kóže',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'se póškajucy pórik: dorosćony, dorosćony, swětła barwa kóže a srjejźnośamna barwa kóže',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'se póškajucy pórik: dorosćony, dorosćony, swětła barwa kóže a śamna barwa kóže',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'se póškajucy pórik: dorosćony, dorosćony, srjejźnoswětła barwa kóže a swětła barwa kóže',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'se póškajucy pórik: dorosćony, dorosćony, srjejźnoswětła barwa kóže a wósrědna barwa kóže',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'se póškajucy pórik: dorosćony, dorosćony, srjejźnoswětła barwa kóže a srjejźnośamna barwa kóže',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'se póškajucy pórik: dorosćony, dorosćony, srjejźnoswětła barwa kóže a śamna barwa kóže',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'se póškajucy pórik: dorosćony, dorosćony, wósrědna barwa kóže a swětła barwa kóže',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'se póškajucy pórik: dorosćony, dorosćony, wósrědna barwa kóže a srjejźnoswětła barwa kóže',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'se póškajucy pórik: dorosćony, dorosćony, wósrědna barwa kóže a srjejźnośamna barwa kóže',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'se póškajucy pórik: dorosćony, dorosćony, wósrědna barwa kóže a śamna barwa kóže',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'se póškajucy pórik: dorosćony, dorosćony, srjejźnośamna barwa kóže a swětła barwa kóže',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'se póškajucy pórik: dorosćony, dorosćony, srjejźnośamna barwa kóže a srjejźnoswětła barwa kóže',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'se póškajucy pórik: dorosćony, dorosćony, srjejźnośamna barwa kóže a wósrědna barwa kóže',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'se póškajucy pórik: dorosćony, dorosćony, srjejźnośamna barwa kóže a śamna barwa kóže',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'se póškajucy pórik: dorosćony, dorosćony, śamna barwa kóže a swětła barwa kóže',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'se póškajucy pórik: dorosćony, dorosćony, śamna barwa kóže a srjejźnoswětła barwa kóže',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'se póškajucy pórik: dorosćony, dorosćony, śamna barwa kóže a wósrědna barwa kóže',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'se póškajucy pórik: dorosćony, dorosćony, śamna barwa kóže a srjejźnośamna barwa kóže',
    '👨🏻‍❤‍💋‍👨🏻' => 'se póškajucy pórik: muski, muski a swětła barwa kóže',
    '👨🏻‍❤‍💋‍👨🏼' => 'se póškajucy pórik: muski, muski, swětła barwa kóže a srjejźnoswětła barwa kóže',
    '👨🏻‍❤‍💋‍👨🏽' => 'se póškajucy pórik: muski, muski, swětła barwa kóže a wósrědna barwa kóže',
    '👨🏻‍❤‍💋‍👨🏾' => 'se póškajucy pórik: muski, muski, swětła barwa kóže a srjejźnośamna barwa kóže',
    '👨🏻‍❤‍💋‍👨🏿' => 'se póškajucy pórik: muski, muski, swětła barwa kóže a śamna barwa kóže',
    '👨🏼‍❤‍💋‍👨🏻' => 'se póškajucy pórik: muski, muski, srjejźnoswětła barwa kóže a swětła barwa kóže',
    '👨🏼‍❤‍💋‍👨🏼' => 'se póškajucy pórik: muski, muski a srjejźnoswětła barwa kóže',
    '👨🏼‍❤‍💋‍👨🏽' => 'se póškajucy pórik: muski, muski, srjejźnoswětła barwa kóže a wósrědna barwa kóže',
    '👨🏼‍❤‍💋‍👨🏾' => 'se póškajucy pórik: muski, muski, srjejźnoswětła barwa kóže a srjejźnośamna barwa kóže',
    '👨🏼‍❤‍💋‍👨🏿' => 'se póškajucy pórik: muski, muski, srjejźnoswětła barwa kóže a śamna barwa kóže',
    '👨🏽‍❤‍💋‍👨🏻' => 'se póškajucy pórik: muski, muski, wósrědna barwa kóže a swětła barwa kóže',
    '👨🏽‍❤‍💋‍👨🏼' => 'se póškajucy pórik: muski, muski, wósrědna barwa kóže a srjejźnoswětła barwa kóže',
    '👨🏽‍❤‍💋‍👨🏽' => 'se póškajucy pórik: muski, muski a wósrědna barwa kóže',
    '👨🏽‍❤‍💋‍👨🏾' => 'se póškajucy pórik: muski, muski, wósrědna barwa kóže a srjejźnośamna barwa kóže',
    '👨🏽‍❤‍💋‍👨🏿' => 'se póškajucy pórik: muski, muski, wósrědna barwa kóže a śamna barwa kóže',
    '👨🏾‍❤‍💋‍👨🏻' => 'se póškajucy pórik: muski, muski, srjejźnośamna barwa kóže a swětła barwa kóže',
    '👨🏾‍❤‍💋‍👨🏼' => 'se póškajucy pórik: muski, muski, srjejźnośamna barwa kóže a srjejźnoswětła barwa kóže',
    '👨🏾‍❤‍💋‍👨🏽' => 'se póškajucy pórik: muski, muski, srjejźnośamna barwa kóže a wósrědna barwa kóže',
    '👨🏾‍❤‍💋‍👨🏾' => 'se póškajucy pórik: muski, muski a srjejźnośamna barwa kóže',
    '👨🏾‍❤‍💋‍👨🏿' => 'se póškajucy pórik: muski, muski, srjejźnośamna barwa kóže a śamna barwa kóže',
    '👨🏿‍❤‍💋‍👨🏻' => 'se póškajucy pórik: muski, muski, śamna barwa kóže a swětła barwa kóže',
    '👨🏿‍❤‍💋‍👨🏼' => 'se póškajucy pórik: muski, muski, śamna barwa kóže a srjejźnoswětła barwa kóže',
    '👨🏿‍❤‍💋‍👨🏽' => 'se póškajucy pórik: muski, muski, śamna barwa kóže a wósrědna barwa kóže',
    '👨🏿‍❤‍💋‍👨🏾' => 'se póškajucy pórik: muski, muski, śamna barwa kóže a srjejźnośamna barwa kóže',
    '👨🏿‍❤‍💋‍👨🏿' => 'se póškajucy pórik: muski, muski a śamna barwa kóže',
    '👩🏻‍❤‍💋‍👨🏻' => 'se póškajucy pórik: žeńska, muski a swětła barwa kóže',
    '👩🏻‍❤‍💋‍👨🏼' => 'se póškajucy pórik: žeńska, muski, swětła barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏻‍❤‍💋‍👨🏽' => 'se póškajucy pórik: žeńska, muski, swětła barwa kóže a wósrědna barwa kóže',
    '👩🏻‍❤‍💋‍👨🏾' => 'se póškajucy pórik: žeńska, muski, swětła barwa kóže a srjejźnośamna barwa kóže',
    '👩🏻‍❤‍💋‍👨🏿' => 'se póškajucy pórik: žeńska, muski, swětła barwa kóže a śamna barwa kóže',
    '👩🏼‍❤‍💋‍👨🏻' => 'se póškajucy pórik: žeńska, muski, srjejźnoswětła barwa kóže a swětła barwa kóže',
    '👩🏼‍❤‍💋‍👨🏼' => 'se póškajucy pórik: žeńska, muski a srjejźnoswětła barwa kóže',
    '👩🏼‍❤‍💋‍👨🏽' => 'se póškajucy pórik: žeńska, muski, srjejźnoswětła barwa kóže a wósrědna barwa kóže',
    '👩🏼‍❤‍💋‍👨🏾' => 'se póškajucy pórik: žeńska, muski, srjejźnoswětła barwa kóže a srjejźnośamna barwa kóže',
    '👩🏼‍❤‍💋‍👨🏿' => 'se póškajucy pórik: žeńska, muski, srjejźnoswětła barwa kóže a śamna barwa kóže',
    '👩🏽‍❤‍💋‍👨🏻' => 'se póškajucy pórik: žeńska, muski, wósrědna barwa kóže a swětła barwa kóže',
    '👩🏽‍❤‍💋‍👨🏼' => 'se póškajucy pórik: žeńska, muski, wósrědna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏽‍❤‍💋‍👨🏽' => 'se póškajucy pórik: žeńska, muski a wósrědna barwa kóže',
    '👩🏽‍❤‍💋‍👨🏾' => 'se póškajucy pórik: žeńska, muski, wósrědna barwa kóže a srjejźnośamna barwa kóže',
    '👩🏽‍❤‍💋‍👨🏿' => 'se póškajucy pórik: žeńska, muski, wósrědna barwa kóže a śamna barwa kóže',
    '👩🏾‍❤‍💋‍👨🏻' => 'se póškajucy pórik: žeńska, muski, srjejźnośamna barwa kóže a swětła barwa kóže',
    '👩🏾‍❤‍💋‍👨🏼' => 'se póškajucy pórik: žeńska, muski, srjejźnośamna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏾‍❤‍💋‍👨🏽' => 'se póškajucy pórik: žeńska, muski, srjejźnośamna barwa kóže a wósrědna barwa kóže',
    '👩🏾‍❤‍💋‍👨🏾' => 'se póškajucy pórik: žeńska, muski a srjejźnośamna barwa kóže',
    '👩🏾‍❤‍💋‍👨🏿' => 'se póškajucy pórik: žeńska, muski, srjejźnośamna barwa kóže a śamna barwa kóže',
    '👩🏿‍❤‍💋‍👨🏻' => 'se póškajucy pórik: žeńska, muski, śamna barwa kóže a swětła barwa kóže',
    '👩🏿‍❤‍💋‍👨🏼' => 'se póškajucy pórik: žeńska, muski, śamna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏿‍❤‍💋‍👨🏽' => 'se póškajucy pórik: žeńska, muski, śamna barwa kóže a wósrědna barwa kóže',
    '👩🏿‍❤‍💋‍👨🏾' => 'se póškajucy pórik: žeńska, muski, śamna barwa kóže a srjejźnośamna barwa kóže',
    '👩🏿‍❤‍💋‍👨🏿' => 'se póškajucy pórik: žeńska, muski a śamna barwa kóže',
    '👩🏻‍❤‍💋‍👩🏻' => 'se póškajucy pórik: žeńska, žeńska a swětła barwa kóže',
    '👩🏻‍❤‍💋‍👩🏼' => 'se póškajucy pórik: žeńska, žeńska, swětła barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏻‍❤‍💋‍👩🏽' => 'se póškajucy pórik: žeńska, žeńska, swětła barwa kóže a wósrědna barwa kóže',
    '👩🏻‍❤‍💋‍👩🏾' => 'se póškajucy pórik: žeńska, žeńska, swětła barwa kóže a srjejźnośamna barwa kóže',
    '👩🏻‍❤‍💋‍👩🏿' => 'se póškajucy pórik: žeńska, žeńska, swětła barwa kóže a śamna barwa kóže',
    '👩🏼‍❤‍💋‍👩🏻' => 'se póškajucy pórik: žeńska, žeńska, srjejźnoswětła barwa kóže a swětła barwa kóže',
    '👩🏼‍❤‍💋‍👩🏼' => 'se póškajucy pórik: žeńska, žeńska a srjejźnoswětła barwa kóže',
    '👩🏼‍❤‍💋‍👩🏽' => 'se póškajucy pórik: žeńska, žeńska, srjejźnoswětła barwa kóže a wósrědna barwa kóže',
    '👩🏼‍❤‍💋‍👩🏾' => 'se póškajucy pórik: žeńska, žeńska, srjejźnoswětła barwa kóže a srjejźnośamna barwa kóže',
    '👩🏼‍❤‍💋‍👩🏿' => 'se póškajucy pórik: žeńska, žeńska, srjejźnoswětła barwa kóže a śamna barwa kóže',
    '👩🏽‍❤‍💋‍👩🏻' => 'se póškajucy pórik: žeńska, žeńska, wósrědna barwa kóže a swětła barwa kóže',
    '👩🏽‍❤‍💋‍👩🏼' => 'se póškajucy pórik: žeńska, žeńska, wósrědna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏽‍❤‍💋‍👩🏽' => 'se póškajucy pórik: žeńska, žeńska a wósrědna barwa kóže',
    '👩🏽‍❤‍💋‍👩🏾' => 'se póškajucy pórik: žeńska, žeńska, wósrědna barwa kóže a srjejźnośamna barwa kóže',
    '👩🏽‍❤‍💋‍👩🏿' => 'se póškajucy pórik: žeńska, žeńska, wósrědna barwa kóže a śamna barwa kóže',
    '👩🏾‍❤‍💋‍👩🏻' => 'se póškajucy pórik: žeńska, žeńska, srjejźnośamna barwa kóže a swětła barwa kóže',
    '👩🏾‍❤‍💋‍👩🏼' => 'se póškajucy pórik: žeńska, žeńska, srjejźnośamna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏾‍❤‍💋‍👩🏽' => 'se póškajucy pórik: žeńska, žeńska, srjejźnośamna barwa kóže a wósrědna barwa kóže',
    '👩🏾‍❤‍💋‍👩🏾' => 'se póškajucy pórik: žeńska, žeńska a srjejźnośamna barwa kóže',
    '👩🏾‍❤‍💋‍👩🏿' => 'se póškajucy pórik: žeńska, žeńska, srjejźnośamna barwa kóže a śamna barwa kóže',
    '👩🏿‍❤‍💋‍👩🏻' => 'se póškajucy pórik: žeńska, žeńska, śamna barwa kóže a swětła barwa kóže',
    '👩🏿‍❤‍💋‍👩🏼' => 'se póškajucy pórik: žeńska, žeńska, śamna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏿‍❤‍💋‍👩🏽' => 'se póškajucy pórik: žeńska, žeńska, śamna barwa kóže a wósrědna barwa kóže',
    '👩🏿‍❤‍💋‍👩🏾' => 'se póškajucy pórik: žeńska, žeńska, śamna barwa kóže a srjejźnośamna barwa kóže',
    '👩🏿‍❤‍💋‍👩🏿' => 'se póškajucy pórik: žeńska, žeńska a śamna barwa kóže',
    '🧑🏻‍🫯‍🧑🏼' => 'se běźecej wósobje: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏻‍🫯‍🧑🏽' => 'se běźecej wósobje: swětła barwa kóže, wósrědna barwa kóže',
    '🧑🏻‍🫯‍🧑🏾' => 'se běźecej wósobje: swětła barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏻‍🫯‍🧑🏿' => 'se běźecej wósobje: swětła barwa kóže, śamna barwa kóže',
    '🧑🏼‍🫯‍🧑🏻' => 'se běźecej wósobje: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '🧑🏼‍🫯‍🧑🏽' => 'se běźecej wósobje: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '🧑🏼‍🫯‍🧑🏾' => 'se běźecej wósobje: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏼‍🫯‍🧑🏿' => 'se běźecej wósobje: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '🧑🏽‍🫯‍🧑🏻' => 'se běźecej wósobje: wósrědna barwa kóže, swětła barwa kóže',
    '🧑🏽‍🫯‍🧑🏼' => 'se běźecej wósobje: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏽‍🫯‍🧑🏾' => 'se běźecej wósobje: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏽‍🫯‍🧑🏿' => 'se běźecej wósobje: wósrědna barwa kóže, śamna barwa kóže',
    '🧑🏾‍🫯‍🧑🏻' => 'se běźecej wósobje: srjejźnośamna barwa kóže, swětła barwa kóže',
    '🧑🏾‍🫯‍🧑🏼' => 'se běźecej wósobje: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏾‍🫯‍🧑🏽' => 'se běźecej wósobje: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '🧑🏾‍🫯‍🧑🏿' => 'se běźecej wósobje: srjejźnośamna barwa kóže, śamna barwa kóže',
    '🧑🏿‍🫯‍🧑🏻' => 'se běźecej wósobje: śamna barwa kóže, swětła barwa kóže',
    '🧑🏿‍🫯‍🧑🏼' => 'se běźecej wósobje: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏿‍🫯‍🧑🏽' => 'se běźecej wósobje: śamna barwa kóže, wósrědna barwa kóže',
    '🧑🏿‍🫯‍🧑🏾' => 'se běźecej wósobje: śamna barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏻‍❤‍🧑🏼' => 'pórik z wutšobku: dorosćony, dorosćony, swětła barwa kóže a srjejźnoswětła barwa kóže',
    '🧑🏻‍❤‍🧑🏽' => 'pórik z wutšobku: dorosćony, dorosćony, swětła barwa kóže a wósrědna barwa kóže',
    '🧑🏻‍❤‍🧑🏾' => 'pórik z wutšobku: dorosćony, dorosćony, swětła barwa kóže a srjejźnośamna barwa kóže',
    '🧑🏻‍❤‍🧑🏿' => 'pórik z wutšobku: dorosćony, dorosćony, swětła barwa kóže a śamna barwa kóže',
    '🧑🏼‍❤‍🧑🏻' => 'pórik z wutšobku: dorosćony, dorosćony, srjejźnoswětła barwa kóže a swětła barwa kóže',
    '🧑🏼‍❤‍🧑🏽' => 'pórik z wutšobku: dorosćony, dorosćony, srjejźnoswětła barwa kóže a wósrědna barwa kóže',
    '🧑🏼‍❤‍🧑🏾' => 'pórik z wutšobku: dorosćony, dorosćony, srjejźnoswětła barwa kóže a srjejźnośamna barwa kóže',
    '🧑🏼‍❤‍🧑🏿' => 'pórik z wutšobku: dorosćony, dorosćony, srjejźnoswětła barwa kóže a śamna barwa kóže',
    '🧑🏽‍❤‍🧑🏻' => 'pórik z wutšobku: dorosćony, dorosćony, wósrědna barwa kóže a swětła barwa kóže',
    '🧑🏽‍❤‍🧑🏼' => 'pórik z wutšobku: dorosćony, dorosćony, wósrědna barwa kóže a srjejźnoswětła barwa kóže',
    '🧑🏽‍❤‍🧑🏾' => 'pórik z wutšobku: dorosćony, dorosćony, wósrědna barwa kóže a srjejźnośamna barwa kóže',
    '🧑🏽‍❤‍🧑🏿' => 'pórik z wutšobku: dorosćony, dorosćony, wósrědna barwa kóže a śamna barwa kóže',
    '🧑🏾‍❤‍🧑🏻' => 'pórik z wutšobku: dorosćony, dorosćony, srjejźnośamna barwa kóže a swětła barwa kóže',
    '🧑🏾‍❤‍🧑🏼' => 'pórik z wutšobku: dorosćony, dorosćony, srjejźnośamna barwa kóže a srjejźnoswětła barwa kóže',
    '🧑🏾‍❤‍🧑🏽' => 'pórik z wutšobku: dorosćony, dorosćony, srjejźnośamna barwa kóže a wósrědna barwa kóže',
    '🧑🏾‍❤‍🧑🏿' => 'pórik z wutšobku: dorosćony, dorosćony, srjejźnośamna barwa kóže a śamna barwa kóže',
    '🧑🏿‍❤‍🧑🏻' => 'pórik z wutšobku: dorosćony, dorosćony, śamna barwa kóže a swětła barwa kóže',
    '🧑🏿‍❤‍🧑🏼' => 'pórik z wutšobku: dorosćony, dorosćony, śamna barwa kóže a srjejźnoswětła barwa kóže',
    '🧑🏿‍❤‍🧑🏽' => 'pórik z wutšobku: dorosćony, dorosćony, śamna barwa kóže a wósrědna barwa kóže',
    '🧑🏿‍❤‍🧑🏾' => 'pórik z wutšobku: dorosćony, dorosćony, śamna barwa kóže a srjejźnośamna barwa kóže',
    '🧑🏻‍🐰‍🧑🏼' => 'wósobje z wuchacowyma wušyma: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏻‍🐰‍🧑🏽' => 'wósobje z wuchacowyma wušyma: swětła barwa kóže, wósrědna barwa kóže',
    '🧑🏻‍🐰‍🧑🏾' => 'wósobje z wuchacowyma wušyma: swětła barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏻‍🐰‍🧑🏿' => 'wósobje z wuchacowyma wušyma: swětła barwa kóže, śamna barwa kóže',
    '🧑🏼‍🐰‍🧑🏻' => 'wósobje z wuchacowyma wušyma: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '🧑🏼‍🐰‍🧑🏽' => 'wósobje z wuchacowyma wušyma: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '🧑🏼‍🐰‍🧑🏾' => 'wósobje z wuchacowyma wušyma: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏼‍🐰‍🧑🏿' => 'wósobje z wuchacowyma wušyma: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '🧑🏽‍🐰‍🧑🏻' => 'wósobje z wuchacowyma wušyma: wósrědna barwa kóže, swětła barwa kóže',
    '🧑🏽‍🐰‍🧑🏼' => 'wósobje z wuchacowyma wušyma: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏽‍🐰‍🧑🏾' => 'wósobje z wuchacowyma wušyma: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏽‍🐰‍🧑🏿' => 'wósobje z wuchacowyma wušyma: wósrědna barwa kóže, śamna barwa kóže',
    '🧑🏾‍🐰‍🧑🏻' => 'wósobje z wuchacowyma wušyma: srjejźnośamna barwa kóže, swětła barwa kóže',
    '🧑🏾‍🐰‍🧑🏼' => 'wósobje z wuchacowyma wušyma: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏾‍🐰‍🧑🏽' => 'wósobje z wuchacowyma wušyma: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '🧑🏾‍🐰‍🧑🏿' => 'wósobje z wuchacowyma wušyma: srjejźnośamna barwa kóže, śamna barwa kóže',
    '🧑🏿‍🐰‍🧑🏻' => 'wósobje z wuchacowyma wušyma: śamna barwa kóže, swětła barwa kóže',
    '🧑🏿‍🐰‍🧑🏼' => 'wósobje z wuchacowyma wušyma: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏿‍🐰‍🧑🏽' => 'wósobje z wuchacowyma wušyma: śamna barwa kóže, wósrědna barwa kóže',
    '🧑🏿‍🐰‍🧑🏾' => 'wósobje z wuchacowyma wušyma: śamna barwa kóže, srjejźnośamna barwa kóže',
    '👨🏻‍🫯‍👨🏼' => 'se běźecej muskej: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏻‍🫯‍👨🏽' => 'se běźecej muskej: swětła barwa kóže, wósrědna barwa kóže',
    '👨🏻‍🫯‍👨🏾' => 'se běźecej muskej: swětła barwa kóže, srjejźnośamna barwa kóže',
    '👨🏻‍🫯‍👨🏿' => 'se běźecej muskej: swětła barwa kóže, śamna barwa kóže',
    '👨🏼‍🫯‍👨🏻' => 'se běźecej muskej: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '👨🏼‍🫯‍👨🏽' => 'se běźecej muskej: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '👨🏼‍🫯‍👨🏾' => 'se běźecej muskej: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '👨🏼‍🫯‍👨🏿' => 'se běźecej muskej: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '👨🏽‍🫯‍👨🏻' => 'se běźecej muskej: wósrědna barwa kóže, swětła barwa kóže',
    '👨🏽‍🫯‍👨🏼' => 'se běźecej muskej: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏽‍🫯‍👨🏾' => 'se běźecej muskej: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '👨🏽‍🫯‍👨🏿' => 'se běźecej muskej: wósrědna barwa kóže, śamna barwa kóže',
    '👨🏾‍🫯‍👨🏻' => 'se běźecej muskej: srjejźnośamna barwa kóže, swětła barwa kóže',
    '👨🏾‍🫯‍👨🏼' => 'se běźecej muskej: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏾‍🫯‍👨🏽' => 'se běźecej muskej: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '👨🏾‍🫯‍👨🏿' => 'se běźecej muskej: srjejźnośamna barwa kóže, śamna barwa kóže',
    '👨🏿‍🫯‍👨🏻' => 'se běźecej muskej: śamna barwa kóže, swětła barwa kóže',
    '👨🏿‍🫯‍👨🏼' => 'se běźecej muskej: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏿‍🫯‍👨🏽' => 'se běźecej muskej: śamna barwa kóže, wósrědna barwa kóže',
    '👨🏿‍🫯‍👨🏾' => 'se běźecej muskej: śamna barwa kóže, srjejźnośamna barwa kóže',
    '👨🏻‍❤‍👨🏻' => 'pórik z wutšobku: muski, muski a swětła barwa kóže',
    '👨🏻‍❤‍👨🏼' => 'pórik z wutšobku: muski, muski, swětła barwa kóže a srjejźnoswětła barwa kóže',
    '👨🏻‍❤‍👨🏽' => 'pórik z wutšobku: muski, muski, swětła barwa kóže a wósrědna barwa kóže',
    '👨🏻‍❤‍👨🏾' => 'pórik z wutšobku: muski, muski, swětła barwa kóže a srjejźnośamna barwa kóže',
    '👨🏻‍❤‍👨🏿' => 'pórik z wutšobku: muski, muski, swětła barwa kóže a śamna barwa kóže',
    '👨🏼‍❤‍👨🏻' => 'pórik z wutšobku: muski, muski, srjejźnoswětła barwa kóže a swětła barwa kóže',
    '👨🏼‍❤‍👨🏼' => 'pórik z wutšobku: muski, muski a srjejźnoswětła barwa kóže',
    '👨🏼‍❤‍👨🏽' => 'pórik z wutšobku: muski, muski, srjejźnoswětła barwa kóže a wósrědna barwa kóže',
    '👨🏼‍❤‍👨🏾' => 'pórik z wutšobku: muski, muski, srjejźnoswětła barwa kóže a srjejźnośamna barwa kóže',
    '👨🏼‍❤‍👨🏿' => 'pórik z wutšobku: muski, muski, srjejźnoswětła barwa kóže a śamna barwa kóže',
    '👨🏽‍❤‍👨🏻' => 'pórik z wutšobku: muski, muski, wósrědna barwa kóže a swětła barwa kóže',
    '👨🏽‍❤‍👨🏼' => 'pórik z wutšobku: muski, muski, wósrědna barwa kóže a srjejźnoswětła barwa kóže',
    '👨🏽‍❤‍👨🏽' => 'pórik z wutšobku: muski, muski a wósrědna barwa kóže',
    '👨🏽‍❤‍👨🏾' => 'pórik z wutšobku: muski, muski, wósrědna barwa kóže a srjejźnośamna barwa kóže',
    '👨🏽‍❤‍👨🏿' => 'pórik z wutšobku: muski, muski, wósrědna barwa kóže a śamna barwa kóže',
    '👨🏾‍❤‍👨🏻' => 'pórik z wutšobku: muski, muski, srjejźnośamna barwa kóže a swětła barwa kóže',
    '👨🏾‍❤‍👨🏼' => 'pórik z wutšobku: muski, muski, srjejźnośamna barwa kóže a srjejźnoswětła barwa kóže',
    '👨🏾‍❤‍👨🏽' => 'pórik z wutšobku: muski, muski, srjejźnośamna barwa kóže a wósrědna barwa kóže',
    '👨🏾‍❤‍👨🏾' => 'pórik z wutšobku: muski, muski a srjejźnośamna barwa kóže',
    '👨🏾‍❤‍👨🏿' => 'pórik z wutšobku: muski, muski, srjejźnośamna barwa kóže a śamna barwa kóže',
    '👨🏿‍❤‍👨🏻' => 'pórik z wutšobku: muski, muski, śamna barwa kóže a swětła barwa kóže',
    '👨🏿‍❤‍👨🏼' => 'pórik z wutšobku: muski, muski, śamna barwa kóže a srjejźnoswětła barwa kóže',
    '👨🏿‍❤‍👨🏽' => 'pórik z wutšobku: muski, muski, śamna barwa kóže a wósrědna barwa kóže',
    '👨🏿‍❤‍👨🏾' => 'pórik z wutšobku: muski, muski, śamna barwa kóže a srjejźnośamna barwa kóže',
    '👨🏿‍❤‍👨🏿' => 'pórik z wutšobku: muski, muski a śamna barwa kóže',
    '👨🏻‍🐰‍👨🏼' => 'muskej z wuchacowyma wušyma: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏻‍🐰‍👨🏽' => 'muskej z wuchacowyma wušyma: swětła barwa kóže, wósrědna barwa kóže',
    '👨🏻‍🐰‍👨🏾' => 'muskej z wuchacowyma wušyma: swětła barwa kóže, srjejźnośamna barwa kóže',
    '👨🏻‍🐰‍👨🏿' => 'muskej z wuchacowyma wušyma: swětła barwa kóže, śamna barwa kóže',
    '👨🏼‍🐰‍👨🏻' => 'muskej z wuchacowyma wušyma: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '👨🏼‍🐰‍👨🏽' => 'muskej z wuchacowyma wušyma: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '👨🏼‍🐰‍👨🏾' => 'muskej z wuchacowyma wušyma: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '👨🏼‍🐰‍👨🏿' => 'muskej z wuchacowyma wušyma: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '👨🏽‍🐰‍👨🏻' => 'muskej z wuchacowyma wušyma: wósrědna barwa kóže, swětła barwa kóže',
    '👨🏽‍🐰‍👨🏼' => 'muskej z wuchacowyma wušyma: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏽‍🐰‍👨🏾' => 'muskej z wuchacowyma wušyma: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '👨🏽‍🐰‍👨🏿' => 'muskej z wuchacowyma wušyma: wósrědna barwa kóže, śamna barwa kóže',
    '👨🏾‍🐰‍👨🏻' => 'muskej z wuchacowyma wušyma: srjejźnośamna barwa kóže, swětła barwa kóže',
    '👨🏾‍🐰‍👨🏼' => 'muskej z wuchacowyma wušyma: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏾‍🐰‍👨🏽' => 'muskej z wuchacowyma wušyma: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '👨🏾‍🐰‍👨🏿' => 'muskej z wuchacowyma wušyma: srjejźnośamna barwa kóže, śamna barwa kóže',
    '👨🏿‍🐰‍👨🏻' => 'muskej z wuchacowyma wušyma: śamna barwa kóže, swětła barwa kóže',
    '👨🏿‍🐰‍👨🏼' => 'muskej z wuchacowyma wušyma: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏿‍🐰‍👨🏽' => 'muskej z wuchacowyma wušyma: śamna barwa kóže, wósrědna barwa kóže',
    '👨🏿‍🐰‍👨🏾' => 'muskej z wuchacowyma wušyma: śamna barwa kóže, srjejźnośamna barwa kóže',
    '👩🏻‍🫯‍👩🏼' => 'se běźecej žeńsce I: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏻‍🫯‍👩🏽' => 'se běźecej žeńsce I: swětła barwa kóže, wósrědna barwa kóže',
    '👩🏻‍🫯‍👩🏾' => 'se běźecej žeńsce I: swětła barwa kóže, srjejźnośamna barwa kóže',
    '👩🏻‍🫯‍👩🏿' => 'se běźecej žeńsce I: swětła barwa kóže, śamna barwa kóže',
    '👩🏼‍🫯‍👩🏻' => 'se běźecej žeńsce I: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '👩🏼‍🫯‍👩🏽' => 'se běźecej žeńsce I: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '👩🏼‍🫯‍👩🏾' => 'se běźecej žeńsce I: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '👩🏼‍🫯‍👩🏿' => 'se běźecej žeńsce I: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '👩🏽‍🫯‍👩🏻' => 'se běźecej žeńsce I: wósrědna barwa kóže, swětła barwa kóže',
    '👩🏽‍🫯‍👩🏼' => 'se běźecej žeńsce I: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏽‍🫯‍👩🏾' => 'se běźecej žeńsce I: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '👩🏽‍🫯‍👩🏿' => 'se běźecej žeńsce I: wósrědna barwa kóže, śamna barwa kóže',
    '👩🏾‍🫯‍👩🏻' => 'se běźecej žeńsce I: srjejźnośamna barwa kóže, swětła barwa kóže',
    '👩🏾‍🫯‍👩🏼' => 'se běźecej žeńsce I: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏾‍🫯‍👩🏽' => 'se běźecej žeńsce I: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '👩🏾‍🫯‍👩🏿' => 'se běźecej žeńsce I: srjejźnośamna barwa kóže, śamna barwa kóže',
    '👩🏿‍🫯‍👩🏻' => 'se běźecej žeńsce I: śamna barwa kóže, swětła barwa kóže',
    '👩🏿‍🫯‍👩🏼' => 'se běźecej žeńsce I: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏿‍🫯‍👩🏽' => 'se běźecej žeńsce I: śamna barwa kóže, wósrědna barwa kóže',
    '👩🏿‍🫯‍👩🏾' => 'se běźecej žeńsce I: śamna barwa kóže, srjejźnośamna barwa kóže',
    '👩🏻‍❤‍👨🏻' => 'pórik z wutšobku: žeńska, muski a swětła barwa kóže',
    '👩🏻‍❤‍👨🏼' => 'pórik z wutšobku: žeńska, muski, swětła barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏻‍❤‍👨🏽' => 'pórik z wutšobku: žeńska, muski, swětła barwa kóže a wósrědna barwa kóže',
    '👩🏻‍❤‍👨🏾' => 'pórik z wutšobku: žeńska, muski, swětła barwa kóže a srjejźnośamna barwa kóže',
    '👩🏻‍❤‍👨🏿' => 'pórik z wutšobku: žeńska, muski, swětła barwa kóže a śamna barwa kóže',
    '👩🏼‍❤‍👨🏻' => 'pórik z wutšobku: žeńska, muski, srjejźnoswětła barwa kóže a swětła barwa kóže',
    '👩🏼‍❤‍👨🏼' => 'pórik z wutšobku: žeńska, muski a srjejźnoswětła barwa kóže',
    '👩🏼‍❤‍👨🏽' => 'pórik z wutšobku: žeńska, muski, srjejźnoswětła barwa kóže a wósrědna barwa kóže',
    '👩🏼‍❤‍👨🏾' => 'pórik z wutšobku: žeńska, muski, srjejźnoswětła barwa kóže a srjejźnośamna barwa kóže',
    '👩🏼‍❤‍👨🏿' => 'pórik z wutšobku: žeńska, muski, srjejźnoswětła barwa kóže a śamna barwa kóže',
    '👩🏽‍❤‍👨🏻' => 'pórik z wutšobku: žeńska, muski, wósrědna barwa kóže a swětła barwa kóže',
    '👩🏽‍❤‍👨🏼' => 'pórik z wutšobku: žeńska, muski, wósrědna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏽‍❤‍👨🏽' => 'pórik z wutšobku: žeńska, muski a wósrědna barwa kóže',
    '👩🏽‍❤‍👨🏾' => 'pórik z wutšobku: žeńska, muski, wósrědna barwa kóže a srjejźnośamna barwa kóže',
    '👩🏽‍❤‍👨🏿' => 'pórik z wutšobku: žeńska, muski, wósrědna barwa kóže a śamna barwa kóže',
    '👩🏾‍❤‍👨🏻' => 'pórik z wutšobku: žeńska, muski, srjejźnośamna barwa kóže a swětła barwa kóže',
    '👩🏾‍❤‍👨🏼' => 'pórik z wutšobku: žeńska, muski, srjejźnośamna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏾‍❤‍👨🏽' => 'pórik z wutšobku: žeńska, muski, srjejźnośamna barwa kóže a wósrědna barwa kóže',
    '👩🏾‍❤‍👨🏾' => 'pórik z wutšobku: žeńska, muski a srjejźnośamna barwa kóže',
    '👩🏾‍❤‍👨🏿' => 'pórik z wutšobku: žeńska, muski, srjejźnośamna barwa kóže a śamna barwa kóže',
    '👩🏿‍❤‍👨🏻' => 'pórik z wutšobku: žeńska, muski, śamna barwa kóže a swětła barwa kóže',
    '👩🏿‍❤‍👨🏼' => 'pórik z wutšobku: žeńska, muski, śamna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏿‍❤‍👨🏽' => 'pórik z wutšobku: žeńska, muski, śamna barwa kóže a wósrědna barwa kóže',
    '👩🏿‍❤‍👨🏾' => 'pórik z wutšobku: žeńska, muski, śamna barwa kóže a srjejźnośamna barwa kóže',
    '👩🏿‍❤‍👨🏿' => 'pórik z wutšobku: žeńska, muski a śamna barwa kóže',
    '👩🏻‍❤‍👩🏻' => 'pórik z wutšobku: žeńska, žeńska a swětła barwa kóže',
    '👩🏻‍❤‍👩🏼' => 'pórik z wutšobku: žeńska, žeńska, swětła barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏻‍❤‍👩🏽' => 'pórik z wutšobku: žeńska, žeńska, swětła barwa kóže a wósrědna barwa kóže',
    '👩🏻‍❤‍👩🏾' => 'pórik z wutšobku: žeńska, žeńska, swětła barwa kóže a srjejźnośamna barwa kóže',
    '👩🏻‍❤‍👩🏿' => 'pórik z wutšobku: žeńska, žeńska, swětła barwa kóže a śamna barwa kóže',
    '👩🏼‍❤‍👩🏻' => 'pórik z wutšobku: žeńska, žeńska, srjejźnoswětła barwa kóže a swětła barwa kóže',
    '👩🏼‍❤‍👩🏼' => 'pórik z wutšobku: žeńska, žeńska a srjejźnoswětła barwa kóže',
    '👩🏼‍❤‍👩🏽' => 'pórik z wutšobku: žeńska, žeńska, srjejźnoswětła barwa kóže a wósrědna barwa kóže',
    '👩🏼‍❤‍👩🏾' => 'pórik z wutšobku: žeńska, žeńska, srjejźnoswětła barwa kóže a srjejźnośamna barwa kóže',
    '👩🏼‍❤‍👩🏿' => 'pórik z wutšobku: žeńska, žeńska, srjejźnoswětła barwa kóže a śamna barwa kóže',
    '👩🏽‍❤‍👩🏻' => 'pórik z wutšobku: žeńska, žeńska, wósrědna barwa kóže a swětła barwa kóže',
    '👩🏽‍❤‍👩🏼' => 'pórik z wutšobku: žeńska, žeńska, wósrědna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏽‍❤‍👩🏽' => 'pórik z wutšobku: žeńska, žeńska a wósrědna barwa kóže',
    '👩🏽‍❤‍👩🏾' => 'pórik z wutšobku: žeńska, žeńska, wósrědna barwa kóže a srjejźnośamna barwa kóže',
    '👩🏽‍❤‍👩🏿' => 'pórik z wutšobku: žeńska, žeńska, wósrědna barwa kóže a śamna barwa kóže',
    '👩🏾‍❤‍👩🏻' => 'pórik z wutšobku: žeńska, žeńska, srjejźnośamna barwa kóže a swětła barwa kóže',
    '👩🏾‍❤‍👩🏼' => 'pórik z wutšobku: žeńska, žeńska, srjejźnośamna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏾‍❤‍👩🏽' => 'pórik z wutšobku: žeńska, žeńska, srjejźnośamna barwa kóže a wósrědna barwa kóže',
    '👩🏾‍❤‍👩🏾' => 'pórik z wutšobku: žeńska, žeńska a srjejźnośamna barwa kóže',
    '👩🏾‍❤‍👩🏿' => 'pórik z wutšobku: žeńska, žeńska, srjejźnośamna barwa kóže a śamna barwa kóže',
    '👩🏿‍❤‍👩🏻' => 'pórik z wutšobku: žeńska, žeńska, śamna barwa kóže a swětła barwa kóže',
    '👩🏿‍❤‍👩🏼' => 'pórik z wutšobku: žeńska, žeńska, śamna barwa kóže a srjejźnoswětła barwa kóže',
    '👩🏿‍❤‍👩🏽' => 'pórik z wutšobku: žeńska, žeńska, śamna barwa kóže a wósrědna barwa kóže',
    '👩🏿‍❤‍👩🏾' => 'pórik z wutšobku: žeńska, žeńska, śamna barwa kóže a srjejźnośamna barwa kóže',
    '👩🏿‍❤‍👩🏿' => 'pórik z wutšobku: žeńska, žeńska a śamna barwa kóže',
    '👩🏻‍🐰‍👩🏼' => 'žeńsce z wuchacowamy wušyma: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏻‍🐰‍👩🏽' => 'žeńsce z wuchacowamy wušyma: swětła barwa kóže, wósrědna barwa kóže',
    '👩🏻‍🐰‍👩🏾' => 'žeńsce z wuchacowamy wušyma: swětła barwa kóže, srjejźnośamna barwa kóže',
    '👩🏻‍🐰‍👩🏿' => 'žeńsce z wuchacowamy wušyma: swětła barwa kóže, śamna barwa kóže',
    '👩🏼‍🐰‍👩🏻' => 'žeńsce z wuchacowamy wušyma: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '👩🏼‍🐰‍👩🏽' => 'žeńsce z wuchacowamy wušyma: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '👩🏼‍🐰‍👩🏾' => 'žeńsce z wuchacowamy wušyma: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '👩🏼‍🐰‍👩🏿' => 'žeńsce z wuchacowamy wušyma: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '👩🏽‍🐰‍👩🏻' => 'žeńsce z wuchacowamy wušyma: wósrědna barwa kóže, swětła barwa kóže',
    '👩🏽‍🐰‍👩🏼' => 'žeńsce z wuchacowamy wušyma: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏽‍🐰‍👩🏾' => 'žeńsce z wuchacowamy wušyma: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '👩🏽‍🐰‍👩🏿' => 'žeńsce z wuchacowamy wušyma: wósrědna barwa kóže, śamna barwa kóže',
    '👩🏾‍🐰‍👩🏻' => 'žeńsce z wuchacowamy wušyma: srjejźnośamna barwa kóže, swětła barwa kóže',
    '👩🏾‍🐰‍👩🏼' => 'žeńsce z wuchacowamy wušyma: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏾‍🐰‍👩🏽' => 'žeńsce z wuchacowamy wušyma: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '👩🏾‍🐰‍👩🏿' => 'žeńsce z wuchacowamy wušyma: srjejźnośamna barwa kóže, śamna barwa kóže',
    '👩🏿‍🐰‍👩🏻' => 'žeńsce z wuchacowamy wušyma: śamna barwa kóže, swětła barwa kóže',
    '👩🏿‍🐰‍👩🏼' => 'žeńsce z wuchacowamy wušyma: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏿‍🐰‍👩🏽' => 'žeńsce z wuchacowamy wušyma: śamna barwa kóže, wósrědna barwa kóže',
    '👩🏿‍🐰‍👩🏾' => 'žeńsce z wuchacowamy wušyma: śamna barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏻‍🤝‍🧑🏻' => 'se za ruku źaržecej wósobje: swětła barwa kóže',
    '🧑🏻‍🤝‍🧑🏼' => 'se za ruku źaržecej wósobje: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏻‍🤝‍🧑🏽' => 'se za ruku źaržecej wósobje: swětła barwa kóže, wósrědna barwa kóže',
    '🧑🏻‍🤝‍🧑🏾' => 'se za ruku źaržecej wósobje: swětła barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏻‍🤝‍🧑🏿' => 'se za ruku źaržecej wósobje: swětła barwa kóže, śamna barwa kóže',
    '🧑🏼‍🤝‍🧑🏻' => 'se za ruku źaržecej wósobje: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '🧑🏼‍🤝‍🧑🏼' => 'se za ruku źaržecej wósobje: srjejźnoswětła barwa kóže',
    '🧑🏼‍🤝‍🧑🏽' => 'se za ruku źaržecej wósobje: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '🧑🏼‍🤝‍🧑🏾' => 'se za ruku źaržecej wósobje: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏼‍🤝‍🧑🏿' => 'se za ruku źaržecej wósobje: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '🧑🏽‍🤝‍🧑🏻' => 'se za ruku źaržecej wósobje: wósrědna barwa kóže, swětła barwa kóže',
    '🧑🏽‍🤝‍🧑🏼' => 'se za ruku źaržecej wósobje: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏽‍🤝‍🧑🏽' => 'se za ruku źaržecej wósobje: wósrědna barwa kóže',
    '🧑🏽‍🤝‍🧑🏾' => 'se za ruku źaržecej wósobje: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏽‍🤝‍🧑🏿' => 'se za ruku źaržecej wósobje: wósrědna barwa kóže, śamna barwa kóže',
    '🧑🏾‍🤝‍🧑🏻' => 'se za ruku źaržecej wósobje: srjejźnośamna barwa kóže, swětła barwa kóže',
    '🧑🏾‍🤝‍🧑🏼' => 'se za ruku źaržecej wósobje: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏾‍🤝‍🧑🏽' => 'se za ruku źaržecej wósobje: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '🧑🏾‍🤝‍🧑🏾' => 'se za ruku źaržecej wósobje: srjejźnośamna barwa kóže',
    '🧑🏾‍🤝‍🧑🏿' => 'se za ruku źaržecej wósobje: srjejźnośamna barwa kóže, śamna barwa kóže',
    '🧑🏿‍🤝‍🧑🏻' => 'se za ruku źaržecej wósobje: śamna barwa kóže, swětła barwa kóže',
    '🧑🏿‍🤝‍🧑🏼' => 'se za ruku źaržecej wósobje: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '🧑🏿‍🤝‍🧑🏽' => 'se za ruku źaržecej wósobje: śamna barwa kóže, wósrědna barwa kóže',
    '🧑🏿‍🤝‍🧑🏾' => 'se za ruku źaržecej wósobje: śamna barwa kóže, srjejźnośamna barwa kóže',
    '🧑🏿‍🤝‍🧑🏿' => 'se za ruku źaržecej wósobje: śamna barwa kóže',
    '👩🏻‍🤝‍👩🏼' => 'se za ruku źaržecej žeńsce: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏻‍🤝‍👩🏽' => 'se za ruku źaržecej žeńsce: swětła barwa kóže, wósrědna barwa kóže',
    '👩🏻‍🤝‍👩🏾' => 'se za ruku źaržecej žeńsce: swětła barwa kóže, srjejźnośamna barwa kóže',
    '👩🏻‍🤝‍👩🏿' => 'se za ruku źaržecej žeńsce: swětła barwa kóže, śamna barwa kóže',
    '👩🏼‍🤝‍👩🏻' => 'se za ruku źaržecej žeńsce: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '👩🏼‍🤝‍👩🏽' => 'se za ruku źaržecej žeńsce: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '👩🏼‍🤝‍👩🏾' => 'se za ruku źaržecej žeńsce: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '👩🏼‍🤝‍👩🏿' => 'se za ruku źaržecej žeńsce: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '👩🏽‍🤝‍👩🏻' => 'se za ruku źaržecej žeńsce: wósrědna barwa kóže, swětła barwa kóže',
    '👩🏽‍🤝‍👩🏼' => 'se za ruku źaržecej žeńsce: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏽‍🤝‍👩🏾' => 'se za ruku źaržecej žeńsce: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '👩🏽‍🤝‍👩🏿' => 'se za ruku źaržecej žeńsce: wósrědna barwa kóže, śamna barwa kóže',
    '👩🏾‍🤝‍👩🏻' => 'se za ruku źaržecej žeńsce: srjejźnośamna barwa kóže, swětła barwa kóže',
    '👩🏾‍🤝‍👩🏼' => 'se za ruku źaržecej žeńsce: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏾‍🤝‍👩🏽' => 'se za ruku źaržecej žeńsce: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '👩🏾‍🤝‍👩🏿' => 'se za ruku źaržecej žeńsce: srjejźnośamna barwa kóže, śamna barwa kóže',
    '👩🏿‍🤝‍👩🏻' => 'se za ruku źaržecej žeńsce: śamna barwa kóže, swětła barwa kóže',
    '👩🏿‍🤝‍👩🏼' => 'se za ruku źaržecej žeńsce: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏿‍🤝‍👩🏽' => 'se za ruku źaržecej žeńsce: śamna barwa kóže, wósrědna barwa kóže',
    '👩🏿‍🤝‍👩🏾' => 'se za ruku źaržecej žeńsce: śamna barwa kóže, srjejźnośamna barwa kóže',
    '👩🏻‍🤝‍👨🏼' => 'se za ruku źaržecej muski a žeńska: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏻‍🤝‍👨🏽' => 'se za ruku źaržecej muski a žeńska: swětła barwa kóže, wósrědna barwa kóže',
    '👩🏻‍🤝‍👨🏾' => 'se za ruku źaržecej muski a žeńska: swětła barwa kóže, srjejźnośamna barwa kóže',
    '👩🏻‍🤝‍👨🏿' => 'se za ruku źaržecej muski a žeńska: swětła barwa kóže, śamna barwa kóže',
    '👩🏼‍🤝‍👨🏻' => 'se za ruku źaržecej muski a žeńska: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '👩🏼‍🤝‍👨🏽' => 'se za ruku źaržecej muski a žeńska: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '👩🏼‍🤝‍👨🏾' => 'se za ruku źaržecej muski a žeńska: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '👩🏼‍🤝‍👨🏿' => 'se za ruku źaržecej muski a žeńska: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '👩🏽‍🤝‍👨🏻' => 'se za ruku źaržecej muski a žeńska: wósrědna barwa kóže, swětła barwa kóže',
    '👩🏽‍🤝‍👨🏼' => 'se za ruku źaržecej muski a žeńska: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏽‍🤝‍👨🏾' => 'se za ruku źaržecej muski a žeńska: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '👩🏽‍🤝‍👨🏿' => 'se za ruku źaržecej muski a žeńska: wósrědna barwa kóže, śamna barwa kóže',
    '👩🏾‍🤝‍👨🏻' => 'se za ruku źaržecej muski a žeńska: srjejźnośamna barwa kóže, swětła barwa kóže',
    '👩🏾‍🤝‍👨🏼' => 'se za ruku źaržecej muski a žeńska: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏾‍🤝‍👨🏽' => 'se za ruku źaržecej muski a žeńska: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '👩🏾‍🤝‍👨🏿' => 'se za ruku źaržecej muski a žeńska: srjejźnośamna barwa kóže, śamna barwa kóže',
    '👩🏿‍🤝‍👨🏻' => 'se za ruku źaržecej muski a žeńska: śamna barwa kóže, swětła barwa kóže',
    '👩🏿‍🤝‍👨🏼' => 'se za ruku źaržecej muski a žeńska: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '👩🏿‍🤝‍👨🏽' => 'se za ruku źaržecej muski a žeńska: śamna barwa kóže, wósrědna barwa kóže',
    '👩🏿‍🤝‍👨🏾' => 'se za ruku źaržecej muski a žeńska: śamna barwa kóže, srjejźnośamna barwa kóže',
    '👨🏻‍🤝‍👨🏼' => 'muskej se źaržytej za ruku: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏻‍🤝‍👨🏽' => 'muskej se źaržytej za ruku: swětła barwa kóže, wósrědna barwa kóže',
    '👨🏻‍🤝‍👨🏾' => 'muskej se źaržytej za ruku: swětła barwa kóže, srjejźnośamna barwa kóže',
    '👨🏻‍🤝‍👨🏿' => 'muskej se źaržytej za ruku: swětła barwa kóže, śamna barwa kóže',
    '👨🏼‍🤝‍👨🏻' => 'muskej se źaržytej za ruku: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '👨🏼‍🤝‍👨🏽' => 'muskej se źaržytej za ruku: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '👨🏼‍🤝‍👨🏾' => 'muskej se źaržytej za ruku: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '👨🏼‍🤝‍👨🏿' => 'muskej se źaržytej za ruku: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '👨🏽‍🤝‍👨🏻' => 'muskej se źaržytej za ruku: wósrědna barwa kóže, swětła barwa kóže',
    '👨🏽‍🤝‍👨🏼' => 'muskej se źaržytej za ruku: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏽‍🤝‍👨🏾' => 'muskej se źaržytej za ruku: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '👨🏽‍🤝‍👨🏿' => 'muskej se źaržytej za ruku: wósrědna barwa kóže, śamna barwa kóže',
    '👨🏾‍🤝‍👨🏻' => 'muskej se źaržytej za ruku: srjejźnośamna barwa kóže, swětła barwa kóže',
    '👨🏾‍🤝‍👨🏼' => 'muskej se źaržytej za ruku: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏾‍🤝‍👨🏽' => 'muskej se źaržytej za ruku: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '👨🏾‍🤝‍👨🏿' => 'muskej se źaržytej za ruku: srjejźnośamna barwa kóže, śamna barwa kóže',
    '👨🏿‍🤝‍👨🏻' => 'muskej se źaržytej za ruku: śamna barwa kóže, swětła barwa kóže',
    '👨🏿‍🤝‍👨🏼' => 'muskej se źaržytej za ruku: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '👨🏿‍🤝‍👨🏽' => 'muskej se źaržytej za ruku: śamna barwa kóže, wósrědna barwa kóže',
    '👨🏿‍🤝‍👨🏾' => 'muskej se źaržytej za ruku: śamna barwa kóže, srjejźnośamna barwa kóže',
    '👩‍❤‍💋‍👨' => 'se póškajucy pórik: žeńska, muski',
    '👨‍❤‍💋‍👨' => 'se póškajucy pórik: muski, muski',
    '👩‍❤‍💋‍👩' => 'se póškajucy pórik: žeńska, žeńska',
    '👨‍👩‍👧‍👦' => 'familija: muski, žeńska, źowćo a gólc',
    '👨‍👩‍👦‍👦' => 'familija: muski, žeńska, gólc a gólc',
    '👨‍👩‍👧‍👧' => 'familija: muski, žeńska, źowćo a źowćo',
    '👨‍👨‍👧‍👦' => 'familija: muski, muski, źowćo a gólc',
    '👨‍👨‍👦‍👦' => 'familija: muski, muski, gólc a gólc',
    '👨‍👨‍👧‍👧' => 'familija: muski, muski, źowćo a źowćo',
    '👩‍👩‍👧‍👦' => 'familija: žeńska, žeńska, źowćo a gólc',
    '👩‍👩‍👦‍👦' => 'familija: žeńska, žeńska, gólc a gólc',
    '👩‍👩‍👧‍👧' => 'familija: žeńska, žeńska, źowćo a źowćo',
    '🧑‍🧑‍🧒‍🧒' => 'familija: dorosćonej a góleśi',
    '🚶🏻‍♀‍➡' => 'pěškaŕka: swětła barwa kóže, napšawo',
    '🚶🏼‍♀‍➡' => 'pěškaŕka: srjejźnoswětła barwa kóže, napšawo',
    '🚶🏽‍♀‍➡' => 'pěškaŕka: wósrědna barwa kóže, napšawo',
    '🚶🏾‍♀‍➡' => 'pěškaŕka: srjejźnośamna barwa kóže, napšawo',
    '🚶🏿‍♀‍➡' => 'pěškaŕka: śamna barwa kóže, napšawo',
    '🚶🏻‍♂‍➡' => 'pěškaŕ: swětła barwa kóže, napšawo',
    '🚶🏼‍♂‍➡' => 'pěškaŕ: srjejźnoswětła barwa kóže, napšawo',
    '🚶🏽‍♂‍➡' => 'pěškaŕ: wósrědna barwa kóže, napšawo',
    '🚶🏾‍♂‍➡' => 'pěškaŕ: srjejźnośamna barwa kóže, napšawo',
    '🚶🏿‍♂‍➡' => 'pěškaŕ: śamna barwa kóže, napšawo',
    '🧎🏻‍♀‍➡' => 'kólenkujuca žeńska: swětła barwa kóže, napšawo',
    '🧎🏼‍♀‍➡' => 'kólenkujuca žeńska: srjejźnoswětła barwa kóže, napšawo',
    '🧎🏽‍♀‍➡' => 'kólenkujuca žeńska: wósrědna barwa kóže, napšawo',
    '🧎🏾‍♀‍➡' => 'kólenkujuca žeńska: srjejźnośamna barwa kóže, napšawo',
    '🧎🏿‍♀‍➡' => 'kólenkujuca žeńska: śamna barwa kóže, napšawo',
    '🧎🏻‍♂‍➡' => 'kólenkujucy muski: swětła barwa kóže, napšawo',
    '🧎🏼‍♂‍➡' => 'kólenkujucy muski: srjejźnoswětła barwa kóže, napšawo',
    '🧎🏽‍♂‍➡' => 'kólenkujucy muski: wósrědna barwa kóže, napšawo',
    '🧎🏾‍♂‍➡' => 'kólenkujucy muski: srjejźnośamna barwa kóže, napšawo',
    '🧎🏿‍♂‍➡' => 'kólenkujucy muski: śamna barwa kóže, napšawo',
    '🧑🏻‍🦯‍➡' => 'wósoba z kijom za slěpych: swětła barwa kóže, napšawo',
    '🧑🏼‍🦯‍➡' => 'wósoba z kijom za slěpych: srjejźnoswětła barwa kóže, napšawo',
    '🧑🏽‍🦯‍➡' => 'wósoba z kijom za slěpych: wósrědna barwa kóže, napšawo',
    '🧑🏾‍🦯‍➡' => 'wósoba z kijom za slěpych: srjejźnośamna barwa kóže, napšawo',
    '🧑🏿‍🦯‍➡' => 'wósoba z kijom za slěpych: śamna barwa kóže, napšawo',
    '👨🏻‍🦯‍➡' => 'muski z kijom za slěpych: swětła barwa kóže, napšawo',
    '👨🏼‍🦯‍➡' => 'muski z kijom za slěpych: srjejźnoswětła barwa kóže, napšawo',
    '👨🏽‍🦯‍➡' => 'muski z kijom za slěpych: wósrědna barwa kóže, napšawo',
    '👨🏾‍🦯‍➡' => 'muski z kijom za slěpych: srjejźnośamna barwa kóže, napšawo',
    '👨🏿‍🦯‍➡' => 'muski z kijom za slěpych: śamna barwa kóže, napšawo',
    '👩🏻‍🦯‍➡' => 'žeńska z kijom za slěpych: swětła barwa kóže, napšawo',
    '👩🏼‍🦯‍➡' => 'žeńska z kijom za slěpych: srjejźnoswětła barwa kóže, napšawo',
    '👩🏽‍🦯‍➡' => 'žeńska z kijom za slěpych: wósrědna barwa kóže, napšawo',
    '👩🏾‍🦯‍➡' => 'žeńska z kijom za slěpych: srjejźnośamna barwa kóže, napšawo',
    '👩🏿‍🦯‍➡' => 'žeńska z kijom za slěpych: śamna barwa kóže, napšawo',
    '🧑🏻‍🦼‍➡' => 'wósoba w elektriskem jězdnem stole: swětła barwa kóže, napšawo',
    '🧑🏼‍🦼‍➡' => 'wósoba w elektriskem jězdnem stole: srjejźnoswětła barwa kóže, napšawo',
    '🧑🏽‍🦼‍➡' => 'wósoba w elektriskem jězdnem stole: wósrědna barwa kóže, napšawo',
    '🧑🏾‍🦼‍➡' => 'wósoba w elektriskem jězdnem stole: srjejźnośamna barwa kóže, napšawo',
    '🧑🏿‍🦼‍➡' => 'wósoba w elektriskem jězdnem stole: śamna barwa kóže, napšawo',
    '👨🏻‍🦼‍➡' => 'muski w elektriskem jězdnem stole: swětła barwa kóže, napšawo',
    '👨🏼‍🦼‍➡' => 'muski w elektriskem jězdnem stole: srjejźnoswětła barwa kóže, napšawo',
    '👨🏽‍🦼‍➡' => 'muski w elektriskem jězdnem stole: wósrědna barwa kóže, napšawo',
    '👨🏾‍🦼‍➡' => 'muski w elektriskem jězdnem stole: srjejźnośamna barwa kóže, napšawo',
    '👨🏿‍🦼‍➡' => 'muski w elektriskem jězdnem stole: śamna barwa kóže, napšawo',
    '👩🏻‍🦼‍➡' => 'žeńska w elektriskem jězdnem stole: swětła barwa kóže, napšawo',
    '👩🏼‍🦼‍➡' => 'žeńska w elektriskem jězdnem stole: srjejźnoswětła barwa kóže, napšawo',
    '👩🏽‍🦼‍➡' => 'žeńska w elektriskem jězdnem stole: wósrědna barwa kóže, napšawo',
    '👩🏾‍🦼‍➡' => 'žeńska w elektriskem jězdnem stole: srjejźnośamna barwa kóže, napšawo',
    '👩🏿‍🦼‍➡' => 'žeńska w elektriskem jězdnem stole: śamna barwa kóže, napšawo',
    '🧑🏻‍🦽‍➡' => 'wósoba w jězdnem stole: swětła barwa kóže, napšawo',
    '🧑🏼‍🦽‍➡' => 'wósoba w jězdnem stole: srjejźnoswětła barwa kóže, napšawo',
    '🧑🏽‍🦽‍➡' => 'wósoba w jězdnem stole: wósrědna barwa kóže, napšawo',
    '🧑🏾‍🦽‍➡' => 'wósoba w jězdnem stole: srjejźnośamna barwa kóže, napšawo',
    '🧑🏿‍🦽‍➡' => 'wósoba w jězdnem stole: śamna barwa kóže, napšawo',
    '👨🏻‍🦽‍➡' => 'muski w jězdnem stole: swětła barwa kóže, napšawo',
    '👨🏼‍🦽‍➡' => 'muski w jězdnem stole: srjejźnoswětła barwa kóže, napšawo',
    '👨🏽‍🦽‍➡' => 'muski w jězdnem stole: wósrědna barwa kóže, napšawo',
    '👨🏾‍🦽‍➡' => 'muski w jězdnem stole: srjejźnośamna barwa kóže, napšawo',
    '👨🏿‍🦽‍➡' => 'muski w jězdnem stole: śamna barwa kóže, napšawo',
    '👩🏻‍🦽‍➡' => 'žeńska w jězdnem stole: swětła barwa kóže, napšawo',
    '👩🏼‍🦽‍➡' => 'žeńska w jězdnem stole: srjejźnoswětła barwa kóže, napšawo',
    '👩🏽‍🦽‍➡' => 'žeńska w jězdnem stole: wósrědna barwa kóže, napšawo',
    '👩🏾‍🦽‍➡' => 'žeńska w jězdnem stole: srjejźnośamna barwa kóže, napšawo',
    '👩🏿‍🦽‍➡' => 'žeńska w jězdnem stole: śamna barwa kóže, napšawo',
    '🏃🏻‍♀‍➡' => 'ganjajuca žeńska: swětła barwa kóže, napšawo',
    '🏃🏼‍♀‍➡' => 'ganjajuca žeńska: srjejźnoswětła barwa kóže, napšawo',
    '🏃🏽‍♀‍➡' => 'ganjajuca žeńska: wósrědna barwa kóže, napšawo',
    '🏃🏾‍♀‍➡' => 'ganjajuca žeńska: srjejźnośamna barwa kóže, napšawo',
    '🏃🏿‍♀‍➡' => 'ganjajuca žeńska: śamna barwa kóže, napšawo',
    '🏃🏻‍♂‍➡' => 'ganjajucy muski: swětła barwa kóže, napšawo',
    '🏃🏼‍♂‍➡' => 'ganjajucy muski: srjejźnoswětła barwa kóže, napšawo',
    '🏃🏽‍♂‍➡' => 'ganjajucy muski: wósrědna barwa kóže, napšawo',
    '🏃🏾‍♂‍➡' => 'ganjajucy muski: srjejźnośamna barwa kóže, napšawo',
    '🏃🏿‍♂‍➡' => 'ganjajucy muski: śamna barwa kóže, napšawo',
    '🫱🏻‍🫲🏼' => 'pódaśe ruki: swětła barwa kóže, srjejźnoswětła barwa kóže',
    '🫱🏻‍🫲🏽' => 'pódaśe ruki: swětła barwa kóže, wósrědna barwa kóže',
    '🫱🏻‍🫲🏾' => 'pódaśe ruki: swětła barwa kóže, srjejźnośamna barwa kóže',
    '🫱🏻‍🫲🏿' => 'pódaśe ruki: swětła barwa kóže, śamna barwa kóže',
    '🫱🏼‍🫲🏻' => 'pódaśe ruki: srjejźnoswětła barwa kóže, swětła barwa kóže',
    '🫱🏼‍🫲🏽' => 'pódaśe ruki: srjejźnoswětła barwa kóže, wósrědna barwa kóže',
    '🫱🏼‍🫲🏾' => 'pódaśe ruki: srjejźnoswětła barwa kóže, srjejźnośamna barwa kóže',
    '🫱🏼‍🫲🏿' => 'pódaśe ruki: srjejźnoswětła barwa kóže, śamna barwa kóže',
    '🫱🏽‍🫲🏻' => 'pódaśe ruki: wósrědna barwa kóže, swětła barwa kóže',
    '🫱🏽‍🫲🏼' => 'pódaśe ruki: wósrědna barwa kóže, srjejźnoswětła barwa kóže',
    '🫱🏽‍🫲🏾' => 'pódaśe ruki: wósrědna barwa kóže, srjejźnośamna barwa kóže',
    '🫱🏽‍🫲🏿' => 'pódaśe ruki: wósrědna barwa kóže, śamna barwa kóže',
    '🫱🏾‍🫲🏻' => 'pódaśe ruki: srjejźnośamna barwa kóže, swětła barwa kóže',
    '🫱🏾‍🫲🏼' => 'pódaśe ruki: srjejźnośamna barwa kóže, srjejźnoswětła barwa kóže',
    '🫱🏾‍🫲🏽' => 'pódaśe ruki: srjejźnośamna barwa kóže, wósrědna barwa kóže',
    '🫱🏾‍🫲🏿' => 'pódaśe ruki: srjejźnośamna barwa kóže, śamna barwa kóže',
    '🫱🏿‍🫲🏻' => 'pódaśe ruki: śamna barwa kóže, swětła barwa kóže',
    '🫱🏿‍🫲🏼' => 'pódaśe ruki: śamna barwa kóže, srjejźnoswětła barwa kóže',
    '🫱🏿‍🫲🏽' => 'pódaśe ruki: śamna barwa kóže, wósrědna barwa kóže',
    '🫱🏿‍🫲🏾' => 'pódaśe ruki: śamna barwa kóže, srjejźnośamna barwa kóže',
    '🚶‍♀‍➡' => 'pěškaŕka: napšawo',
    '🚶‍♂‍➡' => 'pěškaŕ: napšawo',
    '🧎‍♀‍➡' => 'kólenkujuca žeńska: napšawo',
    '🧎‍♂‍➡' => 'kólenkujucy muski: napšawo',
    '🧑‍🦯‍➡' => 'wósoba z kijom za slěpych: napšawo',
    '👨‍🦯‍➡' => 'muski z kijom za slěpych: napšawo',
    '👩‍🦯‍➡' => 'žeńska z kijom za slěpych: napšawo',
    '🧑‍🦼‍➡' => 'wósoba w elektriskem jězdnem stole: napšawo',
    '👨‍🦼‍➡' => 'muski w elektriskem jězdnem stole: napšawo',
    '👩‍🦼‍➡' => 'žeńska w elektriskem jězdnem stole: napšawo',
    '🧑‍🦽‍➡' => 'wósoba w jězdnem stole: napšawo',
    '👨‍🦽‍➡' => 'muski w jězdnem stole: napšawo',
    '👩‍🦽‍➡' => 'žeńska w jězdnem stole: napšawo',
    '🏃‍♀‍➡' => 'ganjajuca žeńska: napšawo',
    '🏃‍♂‍➡' => 'ganjajucy muski: napšawo',
    '👩‍❤‍👨' => 'pórik z wutšobku: žeńska, muski',
    '👨‍❤‍👨' => 'pórik z wutšobku: muski, muski',
    '👩‍❤‍👩' => 'pórik z wutšobku: žeńska, žeńska',
    '👨‍👩‍👦' => 'familija: muski, žeńska a gólc',
    '👨‍👩‍👧' => 'familija: muski, žeńska a źowćo',
    '👨‍👨‍👦' => 'familija: muski, muski a gólc',
    '👨‍👨‍👧' => 'familija: muski, muski a źowćo',
    '👩‍👩‍👦' => 'familija: žeńska, žeńska a gólc',
    '👩‍👩‍👧' => 'familija: žeńska, žeńska a źowćo',
    '👨‍👦‍👦' => 'familija: muski, gólc a gólc',
    '👨‍👧‍👦' => 'familija: muski, źowćo a gólc',
    '👨‍👧‍👧' => 'familija: muski, źowćo a źowćo',
    '👩‍👦‍👦' => 'familija: žeńska, gólc a gólc',
    '👩‍👧‍👦' => 'familija: žeńska, źowćo a gólc',
    '👩‍👧‍👧' => 'familija: žeńska, źowćo a źowćo',
    '🧑‍🤝‍🧑' => 'se za ruku źaržecej wósobje',
    '🧑‍🧑‍🧒' => 'familija: dorosćonej a góle',
    '🧑‍🧒‍🧒' => 'familija: dorosćony a góleśi',
    '🧑🏻‍🦰' => 'dorosćony: swětła barwa kóže, cerwjene włosy',
    '🧑🏼‍🦰' => 'dorosćony: srjejźnoswětła barwa kóže, cerwjene włosy',
    '🧑🏽‍🦰' => 'dorosćony: wósrědna barwa kóže, cerwjene włosy',
    '🧑🏾‍🦰' => 'dorosćony: srjejźnośamna barwa kóže, cerwjene włosy',
    '🧑🏿‍🦰' => 'dorosćony: śamna barwa kóže, cerwjene włosy',
    '🧑🏻‍🦱' => 'dorosćony: swětła barwa kóže, kuźerate włosy',
    '🧑🏼‍🦱' => 'dorosćony: srjejźnoswětła barwa kóže, kuźerate włosy',
    '🧑🏽‍🦱' => 'dorosćony: wósrědna barwa kóže, kuźerate włosy',
    '🧑🏾‍🦱' => 'dorosćony: srjejźnośamna barwa kóže, kuźerate włosy',
    '🧑🏿‍🦱' => 'dorosćony: śamna barwa kóže, kuźerate włosy',
    '🧑🏻‍🦳' => 'dorosćony: swětła barwa kóže, běłe włosy',
    '🧑🏼‍🦳' => 'dorosćony: srjejźnoswětła barwa kóže, běłe włosy',
    '🧑🏽‍🦳' => 'dorosćony: wósrědna barwa kóže, běłe włosy',
    '🧑🏾‍🦳' => 'dorosćony: srjejźnośamna barwa kóže, běłe włosy',
    '🧑🏿‍🦳' => 'dorosćony: śamna barwa kóže, běłe włosy',
    '🧑🏻‍🦲' => 'dorosćony: swětła barwa kóže, plěch',
    '🧑🏼‍🦲' => 'dorosćony: srjejźnoswětła barwa kóže, plěch',
    '🧑🏽‍🦲' => 'dorosćony: wósrědna barwa kóže, plěch',
    '🧑🏾‍🦲' => 'dorosćony: srjejźnośamna barwa kóže, plěch',
    '🧑🏿‍🦲' => 'dorosćony: śamna barwa kóže, plěch',
    '🧑🏻‍🩰' => 'baletowa rejowaŕka: swětła barwa kóže',
    '🧑🏼‍🩰' => 'baletowa rejowaŕka: srjejźnoswětła barwa kóže',
    '🧑🏽‍🩰' => 'baletowa rejowaŕka: wósrědna barwa kóže',
    '🧑🏾‍🩰' => 'baletowa rejowaŕka: srjejźnośamna barwa kóže',
    '🧑🏿‍🩰' => 'baletowa rejowaŕka: śamna barwa kóže',
    '🧔🏻‍♂' => 'muski: swětła barwa kóže, broda',
    '🧔🏼‍♂' => 'muski: srjejźnoswětła barwa kóže, broda',
    '🧔🏽‍♂' => 'muski: wósrědna barwa kóže, broda',
    '🧔🏾‍♂' => 'muski: srjejźnośamna barwa kóže, broda',
    '🧔🏿‍♂' => 'muski: śamna barwa kóže, broda',
    '👱🏻‍♂' => 'muski: swětła barwa kóže, swětłowłosaty',
    '👱🏼‍♂' => 'muski: srjejźnoswětła barwa kóže, swětłowłosaty',
    '👱🏽‍♂' => 'muski: wósrědna barwa kóže, swětłowłosaty',
    '👱🏾‍♂' => 'muski: srjejźnośamna barwa kóže, swětłowłosaty',
    '👱🏿‍♂' => 'muski: śamna barwa kóže, swětłowłosaty',
    '👨🏻‍🦰' => 'muski: swětła barwa kóže, cerwjene włosy',
    '👨🏼‍🦰' => 'muski: srjejźnoswětła barwa kóže, cerwjene włosy',
    '👨🏽‍🦰' => 'muski: wósrědna barwa kóže, cerwjene włosy',
    '👨🏾‍🦰' => 'muski: srjejźnośamna barwa kóže, cerwjene włosy',
    '👨🏿‍🦰' => 'muski: śamna barwa kóže, cerwjene włosy',
    '👨🏻‍🦱' => 'muski: swětła barwa kóže, kuźerate włosy',
    '👨🏼‍🦱' => 'muski: srjejźnoswětła barwa kóže, kuźerate włosy',
    '👨🏽‍🦱' => 'muski: wósrědna barwa kóže, kuźerate włosy',
    '👨🏾‍🦱' => 'muski: srjejźnośamna barwa kóže, kuźerate włosy',
    '👨🏿‍🦱' => 'muski: śamna barwa kóže, kuźerate włosy',
    '👨🏻‍🦳' => 'muski: swětła barwa kóže, běłe włosy',
    '👨🏼‍🦳' => 'muski: srjejźnoswětła barwa kóže, běłe włosy',
    '👨🏽‍🦳' => 'muski: wósrědna barwa kóže, běłe włosy',
    '👨🏾‍🦳' => 'muski: srjejźnośamna barwa kóže, běłe włosy',
    '👨🏿‍🦳' => 'muski: śamna barwa kóže, běłe włosy',
    '👨🏻‍🦲' => 'muski: swětła barwa kóže, plěch',
    '👨🏼‍🦲' => 'muski: srjejźnoswětła barwa kóže, plěch',
    '👨🏽‍🦲' => 'muski: wósrědna barwa kóže, plěch',
    '👨🏾‍🦲' => 'muski: srjejźnośamna barwa kóže, plěch',
    '👨🏿‍🦲' => 'muski: śamna barwa kóže, plěch',
    '🧔🏻‍♀' => 'žeńska: swětła barwa kóže, broda',
    '🧔🏼‍♀' => 'žeńska: srjejźnoswětła barwa kóže, broda',
    '🧔🏽‍♀' => 'žeńska: wósrědna barwa kóže, broda',
    '🧔🏾‍♀' => 'žeńska: srjejźnośamna barwa kóže, broda',
    '🧔🏿‍♀' => 'žeńska: śamna barwa kóže, broda',
    '👱🏻‍♀' => 'žeńska: swětła barwa kóže, swětłowłosata',
    '👱🏼‍♀' => 'žeńska: srjejźnoswětła barwa kóže, swětłowłosata',
    '👱🏽‍♀' => 'žeńska: wósrědna barwa kóže, swětłowłosata',
    '👱🏾‍♀' => 'žeńska: srjejźnośamna barwa kóže, swětłowłosata',
    '👱🏿‍♀' => 'žeńska: śamna barwa kóže, swětłowłosata',
    '👩🏻‍🦰' => 'žeńska: swětła barwa kóže, cerwjene włosy',
    '👩🏼‍🦰' => 'žeńska: srjejźnoswětła barwa kóže, cerwjene włosy',
    '👩🏽‍🦰' => 'žeńska: wósrědna barwa kóže, cerwjene włosy',
    '👩🏾‍🦰' => 'žeńska: srjejźnośamna barwa kóže, cerwjene włosy',
    '👩🏿‍🦰' => 'žeńska: śamna barwa kóže, cerwjene włosy',
    '👩🏻‍🦱' => 'žeńska: swětła barwa kóže, kuźerate włosy',
    '👩🏼‍🦱' => 'žeńska: srjejźnoswětła barwa kóže, kuźerate włosy',
    '👩🏽‍🦱' => 'žeńska: wósrědna barwa kóže, kuźerate włosy',
    '👩🏾‍🦱' => 'žeńska: srjejźnośamna barwa kóže, kuźerate włosy',
    '👩🏿‍🦱' => 'žeńska: śamna barwa kóže, kuźerate włosy',
    '👩🏻‍🦳' => 'žeńska: swětła barwa kóže, běłe włosy',
    '👩🏼‍🦳' => 'žeńska: srjejźnoswětła barwa kóže, běłe włosy',
    '👩🏽‍🦳' => 'žeńska: wósrědna barwa kóže, běłe włosy',
    '👩🏾‍🦳' => 'žeńska: srjejźnośamna barwa kóže, běłe włosy',
    '👩🏿‍🦳' => 'žeńska: śamna barwa kóže, běłe włosy',
    '👩🏻‍🦲' => 'žeńska: swětła barwa kóže, plěch',
    '👩🏼‍🦲' => 'žeńska: srjejźnoswětła barwa kóže, plěch',
    '👩🏽‍🦲' => 'žeńska: wósrědna barwa kóže, plěch',
    '👩🏾‍🦲' => 'žeńska: srjejźnośamna barwa kóže, plěch',
    '👩🏿‍🦲' => 'žeńska: śamna barwa kóže, plěch',
    '🙍🏻‍♂' => 'wobuzny muski: swětła barwa kóže',
    '🙍🏼‍♂' => 'wobuzny muski: srjejźnoswětła barwa kóže',
    '🙍🏽‍♂' => 'wobuzny muski: wósrědna barwa kóže',
    '🙍🏾‍♂' => 'wobuzny muski: srjejźnośamna barwa kóže',
    '🙍🏿‍♂' => 'wobuzny muski: śamna barwa kóže',
    '🙍🏻‍♀' => 'wobuzna žeńska: swětła barwa kóže',
    '🙍🏼‍♀' => 'wobuzna žeńska: srjejźnoswětła barwa kóže',
    '🙍🏽‍♀' => 'wobuzna žeńska: wósrědna barwa kóže',
    '🙍🏾‍♀' => 'wobuzna žeńska: srjejźnośamna barwa kóže',
    '🙍🏿‍♀' => 'wobuzna žeńska: śamna barwa kóže',
    '🙎🏻‍♂' => 'premplecy muski: swětła barwa kóže',
    '🙎🏼‍♂' => 'premplecy muski: srjejźnoswětła barwa kóže',
    '🙎🏽‍♂' => 'premplecy muski: wósrědna barwa kóže',
    '🙎🏾‍♂' => 'premplecy muski: srjejźnośamna barwa kóže',
    '🙎🏿‍♂' => 'premplecy muski: śamna barwa kóže',
    '🙎🏻‍♀' => 'prempleca žeńska: swětła barwa kóže',
    '🙎🏼‍♀' => 'prempleca žeńska: srjejźnoswětła barwa kóže',
    '🙎🏽‍♀' => 'prempleca žeńska: wósrědna barwa kóže',
    '🙎🏾‍♀' => 'prempleca žeńska: srjejźnośamna barwa kóže',
    '🙎🏿‍♀' => 'prempleca žeńska: śamna barwa kóže',
    '🙅🏻‍♂' => 'muski z pśekśicnjonyma rukoma: swětła barwa kóže',
    '🙅🏼‍♂' => 'muski z pśekśicnjonyma rukoma: srjejźnoswětła barwa kóže',
    '🙅🏽‍♂' => 'muski z pśekśicnjonyma rukoma: wósrědna barwa kóže',
    '🙅🏾‍♂' => 'muski z pśekśicnjonyma rukoma: srjejźnośamna barwa kóže',
    '🙅🏿‍♂' => 'muski z pśekśicnjonyma rukoma: śamna barwa kóže',
    '🙅🏻‍♀' => 'žeńska z pśekśicnjonyma rukoma: swětła barwa kóže',
    '🙅🏼‍♀' => 'žeńska z pśekśicnjonyma rukoma: srjejźnoswětła barwa kóže',
    '🙅🏽‍♀' => 'žeńska z pśekśicnjonyma rukoma: wósrědna barwa kóže',
    '🙅🏾‍♀' => 'žeńska z pśekśicnjonyma rukoma: srjejźnośamna barwa kóže',
    '🙅🏿‍♀' => 'žeńska z pśekśicnjonyma rukoma: śamna barwa kóže',
    '🙆🏻‍♂' => 'muski z rukoma na głowje: swětła barwa kóže',
    '🙆🏼‍♂' => 'muski z rukoma na głowje: srjejźnoswětła barwa kóže',
    '🙆🏽‍♂' => 'muski z rukoma na głowje: wósrědna barwa kóže',
    '🙆🏾‍♂' => 'muski z rukoma na głowje: srjejźnośamna barwa kóže',
    '🙆🏿‍♂' => 'muski z rukoma na głowje: śamna barwa kóže',
    '🙆🏻‍♀' => 'žeńska z rukoma na głowje: swětła barwa kóže',
    '🙆🏼‍♀' => 'žeńska z rukoma na głowje: srjejźnoswětła barwa kóže',
    '🙆🏽‍♀' => 'žeńska z rukoma na głowje: wósrědna barwa kóže',
    '🙆🏾‍♀' => 'žeńska z rukoma na głowje: srjejźnośamna barwa kóže',
    '🙆🏿‍♀' => 'žeńska z rukoma na głowje: śamna barwa kóže',
    '💁🏻‍♂' => 'muski z dłonju górjej: swětła barwa kóže',
    '💁🏼‍♂' => 'muski z dłonju górjej: srjejźnoswětła barwa kóže',
    '💁🏽‍♂' => 'muski z dłonju górjej: wósrědna barwa kóže',
    '💁🏾‍♂' => 'muski z dłonju górjej: srjejźnośamna barwa kóže',
    '💁🏿‍♂' => 'muski z dłonju górjej: śamna barwa kóže',
    '💁🏻‍♀' => 'žeńska z dłonju górjej: swětła barwa kóže',
    '💁🏼‍♀' => 'žeńska z dłonju górjej: srjejźnoswětła barwa kóže',
    '💁🏽‍♀' => 'žeńska z dłonju górjej: wósrědna barwa kóže',
    '💁🏾‍♀' => 'žeńska z dłonju górjej: srjejźnośamna barwa kóže',
    '💁🏿‍♀' => 'žeńska z dłonju górjej: śamna barwa kóže',
    '🙋🏻‍♂' => 'muski z pózwignjoneju ruku: swětła barwa kóže',
    '🙋🏼‍♂' => 'muski z pózwignjoneju ruku: srjejźnoswětła barwa kóže',
    '🙋🏽‍♂' => 'muski z pózwignjoneju ruku: wósrědna barwa kóže',
    '🙋🏾‍♂' => 'muski z pózwignjoneju ruku: srjejźnośamna barwa kóže',
    '🙋🏿‍♂' => 'muski z pózwignjoneju ruku: śamna barwa kóže',
    '🙋🏻‍♀' => 'žeńska z pózwignjoneju ruku: swětła barwa kóže',
    '🙋🏼‍♀' => 'žeńska z pózwignjoneju ruku: srjejźnoswětła barwa kóže',
    '🙋🏽‍♀' => 'žeńska z pózwignjoneju ruku: wósrědna barwa kóže',
    '🙋🏾‍♀' => 'žeńska z pózwignjoneju ruku: srjejźnośamna barwa kóže',
    '🙋🏿‍♀' => 'žeńska z pózwignjoneju ruku: śamna barwa kóže',
    '🧏🏻‍♂' => 'njesłyšajucy muski: swětła barwa kóže',
    '🧏🏼‍♂' => 'njesłyšajucy muski: srjejźnoswětła barwa kóže',
    '🧏🏽‍♂' => 'njesłyšajucy muski: wósrědna barwa kóže',
    '🧏🏾‍♂' => 'njesłyšajucy muski: srjejźnośamna barwa kóže',
    '🧏🏿‍♂' => 'njesłyšajucy muski: śamna barwa kóže',
    '🧏🏻‍♀' => 'njesłyšajuca žeńska: swětła barwa kóže',
    '🧏🏼‍♀' => 'njesłyšajuca žeńska: srjejźnoswětła barwa kóže',
    '🧏🏽‍♀' => 'njesłyšajuca žeńska: wósrědna barwa kóže',
    '🧏🏾‍♀' => 'njesłyšajuca žeńska: srjejźnośamna barwa kóže',
    '🧏🏿‍♀' => 'njesłyšajuca žeńska: śamna barwa kóže',
    '🙇🏻‍♂' => 'se pókłonjecy muski: swětła barwa kóže',
    '🙇🏼‍♂' => 'se pókłonjecy muski: srjejźnoswětła barwa kóže',
    '🙇🏽‍♂' => 'se pókłonjecy muski: wósrědna barwa kóže',
    '🙇🏾‍♂' => 'se pókłonjecy muski: srjejźnośamna barwa kóže',
    '🙇🏿‍♂' => 'se pókłonjecy muski: śamna barwa kóže',
    '🙇🏻‍♀' => 'se pókłonjeca žeńska: swětła barwa kóže',
    '🙇🏼‍♀' => 'se pókłonjeca žeńska: srjejźnoswětła barwa kóže',
    '🙇🏽‍♀' => 'se pókłonjeca žeńska: wósrědna barwa kóže',
    '🙇🏾‍♀' => 'se pókłonjeca žeńska: srjejźnośamna barwa kóže',
    '🙇🏿‍♀' => 'se pókłonjeca žeńska: śamna barwa kóže',
    '🤦🏻‍♂' => 'se za głowu pśimjecy muski: swětła barwa kóže',
    '🤦🏼‍♂' => 'se za głowu pśimjecy muski: srjejźnoswětła barwa kóže',
    '🤦🏽‍♂' => 'se za głowu pśimjecy muski: wósrědna barwa kóže',
    '🤦🏾‍♂' => 'se za głowu pśimjecy muski: srjejźnośamna barwa kóže',
    '🤦🏿‍♂' => 'se za głowu pśimjecy muski: śamna barwa kóže',
    '🤦🏻‍♀' => 'se za głowu pśimjeca žeńska: swětła barwa kóže',
    '🤦🏼‍♀' => 'se za głowu pśimjeca žeńska: srjejźnoswětła barwa kóže',
    '🤦🏽‍♀' => 'se za głowu pśimjeca žeńska: wósrědna barwa kóže',
    '🤦🏾‍♀' => 'se za głowu pśimjeca žeńska: srjejźnośamna barwa kóže',
    '🤦🏿‍♀' => 'se za głowu pśimjeca žeńska: śamna barwa kóže',
    '🤷🏻‍♂' => 'z ramjenjoma sukotajucy muski: swětła barwa kóže',
    '🤷🏼‍♂' => 'z ramjenjoma sukotajucy muski: srjejźnoswětła barwa kóže',
    '🤷🏽‍♂' => 'z ramjenjoma sukotajucy muski: wósrědna barwa kóže',
    '🤷🏾‍♂' => 'z ramjenjoma sukotajucy muski: srjejźnośamna barwa kóže',
    '🤷🏿‍♂' => 'z ramjenjoma sukotajucy muski: śamna barwa kóže',
    '🤷🏻‍♀' => 'z ramjenjoma sukotajuca žeńska: swětła barwa kóže',
    '🤷🏼‍♀' => 'z ramjenjoma sukotajuca žeńska: srjejźnoswětła barwa kóže',
    '🤷🏽‍♀' => 'z ramjenjoma sukotajuca žeńska: wósrědna barwa kóže',
    '🤷🏾‍♀' => 'z ramjenjoma sukotajuca žeńska: srjejźnośamna barwa kóže',
    '🤷🏿‍♀' => 'z ramjenjoma sukotajuca žeńska: śamna barwa kóže',
    '🧑🏻‍⚕' => 'gójc/gójcowka: swětła barwa kóže',
    '🧑🏼‍⚕' => 'gójc/gójcowka: srjejźnoswětła barwa kóže',
    '🧑🏽‍⚕' => 'gójc/gójcowka: wósrědna barwa kóže',
    '🧑🏾‍⚕' => 'gójc/gójcowka: srjejźnośamna barwa kóže',
    '🧑🏿‍⚕' => 'gójc/gójcowka: śamna barwa kóže',
    '👨🏻‍⚕' => 'doktor: swětła barwa kóže',
    '👨🏼‍⚕' => 'doktor: srjejźnoswětła barwa kóže',
    '👨🏽‍⚕' => 'doktor: wósrědna barwa kóže',
    '👨🏾‍⚕' => 'doktor: srjejźnośamna barwa kóže',
    '👨🏿‍⚕' => 'doktor: śamna barwa kóže',
    '👩🏻‍⚕' => 'gójcowka: swětła barwa kóže',
    '👩🏼‍⚕' => 'gójcowka: srjejźnoswětła barwa kóže',
    '👩🏽‍⚕' => 'gójcowka: wósrědna barwa kóže',
    '👩🏾‍⚕' => 'gójcowka: srjejźnośamna barwa kóže',
    '👩🏿‍⚕' => 'gójcowka: śamna barwa kóže',
    '🧑🏻‍🎓' => 'student(ka): swětła barwa kóže',
    '🧑🏼‍🎓' => 'student(ka): srjejźnoswětła barwa kóže',
    '🧑🏽‍🎓' => 'student(ka): wósrědna barwa kóže',
    '🧑🏾‍🎓' => 'student(ka): srjejźnośamna barwa kóže',
    '🧑🏿‍🎓' => 'student(ka): śamna barwa kóže',
    '👨🏻‍🎓' => 'student: swětła barwa kóže',
    '👨🏼‍🎓' => 'student: srjejźnoswětła barwa kóže',
    '👨🏽‍🎓' => 'student: wósrědna barwa kóže',
    '👨🏾‍🎓' => 'student: srjejźnośamna barwa kóže',
    '👨🏿‍🎓' => 'student: śamna barwa kóže',
    '👩🏻‍🎓' => 'studentka: swětła barwa kóže',
    '👩🏼‍🎓' => 'studentka: srjejźnoswětła barwa kóže',
    '👩🏽‍🎓' => 'studentka: wósrědna barwa kóže',
    '👩🏾‍🎓' => 'studentka: srjejźnośamna barwa kóže',
    '👩🏿‍🎓' => 'studentka: śamna barwa kóže',
    '🧑🏻‍🏫' => 'wucabnik/wucabnica: swětła barwa kóže',
    '🧑🏼‍🏫' => 'wucabnik/wucabnica: srjejźnoswětła barwa kóže',
    '🧑🏽‍🏫' => 'wucabnik/wucabnica: wósrědna barwa kóže',
    '🧑🏾‍🏫' => 'wucabnik/wucabnica: srjejźnośamna barwa kóže',
    '🧑🏿‍🏫' => 'wucabnik/wucabnica: śamna barwa kóže',
    '👨🏻‍🏫' => 'wucabnik: swětła barwa kóže',
    '👨🏼‍🏫' => 'wucabnik: srjejźnoswětła barwa kóže',
    '👨🏽‍🏫' => 'wucabnik: wósrědna barwa kóže',
    '👨🏾‍🏫' => 'wucabnik: srjejźnośamna barwa kóže',
    '👨🏿‍🏫' => 'wucabnik: śamna barwa kóže',
    '👩🏻‍🏫' => 'wucabnica: swětła barwa kóže',
    '👩🏼‍🏫' => 'wucabnica: srjejźnoswětła barwa kóže',
    '👩🏽‍🏫' => 'wucabnica: wósrědna barwa kóže',
    '👩🏾‍🏫' => 'wucabnica: srjejźnośamna barwa kóže',
    '👩🏿‍🏫' => 'wucabnica: śamna barwa kóže',
    '🧑🏻‍⚖' => 'sudnik/sudnica: swětła barwa kóže',
    '🧑🏼‍⚖' => 'sudnik/sudnica: srjejźnoswětła barwa kóže',
    '🧑🏽‍⚖' => 'sudnik/sudnica: wósrědna barwa kóže',
    '🧑🏾‍⚖' => 'sudnik/sudnica: srjejźnośamna barwa kóže',
    '🧑🏿‍⚖' => 'sudnik/sudnica: śamna barwa kóže',
    '👨🏻‍⚖' => 'sudnik: swětła barwa kóže',
    '👨🏼‍⚖' => 'sudnik: srjejźnoswětła barwa kóže',
    '👨🏽‍⚖' => 'sudnik: wósrědna barwa kóže',
    '👨🏾‍⚖' => 'sudnik: srjejźnośamna barwa kóže',
    '👨🏿‍⚖' => 'sudnik: śamna barwa kóže',
    '👩🏻‍⚖' => 'sudnica: swětła barwa kóže',
    '👩🏼‍⚖' => 'sudnica: srjejźnoswětła barwa kóže',
    '👩🏽‍⚖' => 'sudnica: wósrědna barwa kóže',
    '👩🏾‍⚖' => 'sudnica: srjejźnośamna barwa kóže',
    '👩🏿‍⚖' => 'sudnica: śamna barwa kóže',
    '🧑🏻‍🌾' => 'bur/burowka: swětła barwa kóže',
    '🧑🏼‍🌾' => 'bur/burowka: srjejźnoswětła barwa kóže',
    '🧑🏽‍🌾' => 'bur/burowka: wósrědna barwa kóže',
    '🧑🏾‍🌾' => 'bur/burowka: srjejźnośamna barwa kóže',
    '🧑🏿‍🌾' => 'bur/burowka: śamna barwa kóže',
    '👨🏻‍🌾' => 'bur: swětła barwa kóže',
    '👨🏼‍🌾' => 'bur: srjejźnoswětła barwa kóže',
    '👨🏽‍🌾' => 'bur: wósrědna barwa kóže',
    '👨🏾‍🌾' => 'bur: srjejźnośamna barwa kóže',
    '👨🏿‍🌾' => 'bur: śamna barwa kóže',
    '👩🏻‍🌾' => 'burowka: swětła barwa kóže',
    '👩🏼‍🌾' => 'burowka: srjejźnoswětła barwa kóže',
    '👩🏽‍🌾' => 'burowka: wósrědna barwa kóže',
    '👩🏾‍🌾' => 'burowka: srjejźnośamna barwa kóže',
    '👩🏿‍🌾' => 'burowka: śamna barwa kóže',
    '🧑🏻‍🍳' => 'kuchaŕ/kuchaŕka: swětła barwa kóže',
    '🧑🏼‍🍳' => 'kuchaŕ/kuchaŕka: srjejźnoswětła barwa kóže',
    '🧑🏽‍🍳' => 'kuchaŕ/kuchaŕka: wósrědna barwa kóže',
    '🧑🏾‍🍳' => 'kuchaŕ/kuchaŕka: srjejźnośamna barwa kóže',
    '🧑🏿‍🍳' => 'kuchaŕ/kuchaŕka: śamna barwa kóže',
    '👨🏻‍🍳' => 'kuchaŕ: swětła barwa kóže',
    '👨🏼‍🍳' => 'kuchaŕ: srjejźnoswětła barwa kóže',
    '👨🏽‍🍳' => 'kuchaŕ: wósrědna barwa kóže',
    '👨🏾‍🍳' => 'kuchaŕ: srjejźnośamna barwa kóže',
    '👨🏿‍🍳' => 'kuchaŕ: śamna barwa kóže',
    '👩🏻‍🍳' => 'kuchaŕka: swětła barwa kóže',
    '👩🏼‍🍳' => 'kuchaŕka: srjejźnoswětła barwa kóže',
    '👩🏽‍🍳' => 'kuchaŕka: wósrědna barwa kóže',
    '👩🏾‍🍳' => 'kuchaŕka: srjejźnośamna barwa kóže',
    '👩🏿‍🍳' => 'kuchaŕka: śamna barwa kóže',
    '🧑🏻‍🔧' => 'mechanikaŕ: swětła barwa kóže',
    '🧑🏼‍🔧' => 'mechanikaŕ: srjejźnoswětła barwa kóže',
    '🧑🏽‍🔧' => 'mechanikaŕ: wósrědna barwa kóže',
    '🧑🏾‍🔧' => 'mechanikaŕ: srjejźnośamna barwa kóže',
    '🧑🏿‍🔧' => 'mechanikaŕ: śamna barwa kóže',
    '👨🏻‍🔧' => 'muskecy mechanikaŕ/ka: swětła barwa kóže',
    '👨🏼‍🔧' => 'muskecy mechanikaŕ/ka: srjejźnoswětła barwa kóže',
    '👨🏽‍🔧' => 'muskecy mechanikaŕ/ka: wósrědna barwa kóže',
    '👨🏾‍🔧' => 'muskecy mechanikaŕ/ka: srjejźnośamna barwa kóže',
    '👨🏿‍🔧' => 'muskecy mechanikaŕ/ka: śamna barwa kóže',
    '👩🏻‍🔧' => 'mechanikaŕka: swětła barwa kóže',
    '👩🏼‍🔧' => 'mechanikaŕka: srjejźnoswětła barwa kóže',
    '👩🏽‍🔧' => 'mechanikaŕka: wósrědna barwa kóže',
    '👩🏾‍🔧' => 'mechanikaŕka: srjejźnośamna barwa kóže',
    '👩🏿‍🔧' => 'mechanikaŕka: śamna barwa kóže',
    '🧑🏻‍🏭' => 'źěłaśeŕ: swětła barwa kóže',
    '🧑🏼‍🏭' => 'źěłaśeŕ: srjejźnoswětła barwa kóže',
    '🧑🏽‍🏭' => 'źěłaśeŕ: wósrědna barwa kóže',
    '🧑🏾‍🏭' => 'źěłaśeŕ: srjejźnośamna barwa kóže',
    '🧑🏿‍🏭' => 'źěłaśeŕ: śamna barwa kóže',
    '👨🏻‍🏭' => 'fabrikowy źěłaśer: swětła barwa kóže',
    '👨🏼‍🏭' => 'fabrikowy źěłaśer: srjejźnoswětła barwa kóže',
    '👨🏽‍🏭' => 'fabrikowy źěłaśer: wósrědna barwa kóže',
    '👨🏾‍🏭' => 'fabrikowy źěłaśer: srjejźnośamna barwa kóže',
    '👨🏿‍🏭' => 'fabrikowy źěłaśer: śamna barwa kóže',
    '👩🏻‍🏭' => 'fabrikowa źěłaśeŕka: swětła barwa kóže',
    '👩🏼‍🏭' => 'fabrikowa źěłaśeŕka: srjejźnoswětła barwa kóže',
    '👩🏽‍🏭' => 'fabrikowa źěłaśeŕka: wósrědna barwa kóže',
    '👩🏾‍🏭' => 'fabrikowa źěłaśeŕka: srjejźnośamna barwa kóže',
    '👩🏿‍🏭' => 'fabrikowa źěłaśeŕka: śamna barwa kóže',
    '🧑🏻‍💼' => 'w běrowje pśistajona/y: swětła barwa kóže',
    '🧑🏼‍💼' => 'w běrowje pśistajona/y: srjejźnoswětła barwa kóže',
    '🧑🏽‍💼' => 'w běrowje pśistajona/y: wósrědna barwa kóže',
    '🧑🏾‍💼' => 'w běrowje pśistajona/y: srjejźnośamna barwa kóže',
    '🧑🏿‍💼' => 'w běrowje pśistajona/y: śamna barwa kóže',
    '👨🏻‍💼' => 'w běrowje pśistajony: swětła barwa kóže',
    '👨🏼‍💼' => 'w běrowje pśistajony: srjejźnoswětła barwa kóže',
    '👨🏽‍💼' => 'w běrowje pśistajony: wósrědna barwa kóže',
    '👨🏾‍💼' => 'w běrowje pśistajony: srjejźnośamna barwa kóže',
    '👨🏿‍💼' => 'w běrowje pśistajony: śamna barwa kóže',
    '👩🏻‍💼' => 'w běrowje pśistajona: swětła barwa kóže',
    '👩🏼‍💼' => 'w běrowje pśistajona: srjejźnoswětła barwa kóže',
    '👩🏽‍💼' => 'w běrowje pśistajona: wósrědna barwa kóže',
    '👩🏾‍💼' => 'w běrowje pśistajona: srjejźnośamna barwa kóže',
    '👩🏿‍💼' => 'w běrowje pśistajona: śamna barwa kóže',
    '🧑🏻‍🔬' => 'wědomnostnik/ wědomnostnica: swětła barwa kóže',
    '🧑🏼‍🔬' => 'wědomnostnik/ wědomnostnica: srjejźnoswětła barwa kóže',
    '🧑🏽‍🔬' => 'wědomnostnik/ wědomnostnica: wósrědna barwa kóže',
    '🧑🏾‍🔬' => 'wědomnostnik/ wědomnostnica: srjejźnośamna barwa kóže',
    '🧑🏿‍🔬' => 'wědomnostnik/ wědomnostnica: śamna barwa kóže',
    '👨🏻‍🔬' => 'wědomnostnik: swětła barwa kóže',
    '👨🏼‍🔬' => 'wědomnostnik: srjejźnoswětła barwa kóže',
    '👨🏽‍🔬' => 'wědomnostnik: wósrědna barwa kóže',
    '👨🏾‍🔬' => 'wědomnostnik: srjejźnośamna barwa kóže',
    '👨🏿‍🔬' => 'wědomnostnik: śamna barwa kóže',
    '👩🏻‍🔬' => 'wědomnostnica: swětła barwa kóže',
    '👩🏼‍🔬' => 'wědomnostnica: srjejźnoswětła barwa kóže',
    '👩🏽‍🔬' => 'wědomnostnica: wósrědna barwa kóže',
    '👩🏾‍🔬' => 'wědomnostnica: srjejźnośamna barwa kóže',
    '👩🏿‍🔬' => 'wědomnostnica: śamna barwa kóže',
    '🧑🏻‍💻' => 'technolog/owka: swětła barwa kóže',
    '🧑🏼‍💻' => 'technolog/owka: srjejźnoswětła barwa kóže',
    '🧑🏽‍💻' => 'technolog/owka: wósrědna barwa kóže',
    '🧑🏾‍💻' => 'technolog/owka: srjejźnośamna barwa kóže',
    '🧑🏿‍💻' => 'technolog/owka: śamna barwa kóže',
    '👨🏻‍💻' => 'technolog: swětła barwa kóže',
    '👨🏼‍💻' => 'technolog: srjejźnoswětła barwa kóže',
    '👨🏽‍💻' => 'technolog: wósrědna barwa kóže',
    '👨🏾‍💻' => 'technolog: srjejźnośamna barwa kóže',
    '👨🏿‍💻' => 'technolog: śamna barwa kóže',
    '👩🏻‍💻' => 'technologowka: swětła barwa kóže',
    '👩🏼‍💻' => 'technologowka: srjejźnoswětła barwa kóže',
    '👩🏽‍💻' => 'technologowka: wósrědna barwa kóže',
    '👩🏾‍💻' => 'technologowka: srjejźnośamna barwa kóže',
    '👩🏿‍💻' => 'technologowka: śamna barwa kóže',
    '🧑🏻‍🎤' => 'spiwaŕ(ka): swětła barwa kóže',
    '🧑🏼‍🎤' => 'spiwaŕ(ka): srjejźnoswětła barwa kóže',
    '🧑🏽‍🎤' => 'spiwaŕ(ka): wósrědna barwa kóže',
    '🧑🏾‍🎤' => 'spiwaŕ(ka): srjejźnośamna barwa kóže',
    '🧑🏿‍🎤' => 'spiwaŕ(ka): śamna barwa kóže',
    '👨🏻‍🎤' => 'spiwaŕ: swětła barwa kóže',
    '👨🏼‍🎤' => 'spiwaŕ: srjejźnoswětła barwa kóže',
    '👨🏽‍🎤' => 'spiwaŕ: wósrědna barwa kóže',
    '👨🏾‍🎤' => 'spiwaŕ: srjejźnośamna barwa kóže',
    '👨🏿‍🎤' => 'spiwaŕ: śamna barwa kóže',
    '👩🏻‍🎤' => 'spiwaŕka: swětła barwa kóže',
    '👩🏼‍🎤' => 'spiwaŕka: srjejźnoswětła barwa kóže',
    '👩🏽‍🎤' => 'spiwaŕka: wósrědna barwa kóže',
    '👩🏾‍🎤' => 'spiwaŕka: srjejźnośamna barwa kóže',
    '👩🏿‍🎤' => 'spiwaŕka: śamna barwa kóže',
    '🧑🏻‍🎨' => 'wuměłc(owka): swětła barwa kóže',
    '🧑🏼‍🎨' => 'wuměłc(owka): srjejźnoswětła barwa kóže',
    '🧑🏽‍🎨' => 'wuměłc(owka): wósrědna barwa kóže',
    '🧑🏾‍🎨' => 'wuměłc(owka): srjejźnośamna barwa kóže',
    '🧑🏿‍🎨' => 'wuměłc(owka): śamna barwa kóže',
    '👨🏻‍🎨' => 'wuměłc: swětła barwa kóže',
    '👨🏼‍🎨' => 'wuměłc: srjejźnoswětła barwa kóže',
    '👨🏽‍🎨' => 'wuměłc: wósrědna barwa kóže',
    '👨🏾‍🎨' => 'wuměłc: srjejźnośamna barwa kóže',
    '👨🏿‍🎨' => 'wuměłc: śamna barwa kóže',
    '👩🏻‍🎨' => 'wuměłcowka: swětła barwa kóže',
    '👩🏼‍🎨' => 'wuměłcowka: srjejźnoswětła barwa kóže',
    '👩🏽‍🎨' => 'wuměłcowka: wósrědna barwa kóže',
    '👩🏾‍🎨' => 'wuměłcowka: srjejźnośamna barwa kóže',
    '👩🏿‍🎨' => 'wuměłcowka: śamna barwa kóže',
    '🧑🏻‍✈' => 'pilot(owka): swětła barwa kóže',
    '🧑🏼‍✈' => 'pilot(owka): srjejźnoswětła barwa kóže',
    '🧑🏽‍✈' => 'pilot(owka): wósrědna barwa kóže',
    '🧑🏾‍✈' => 'pilot(owka): srjejźnośamna barwa kóže',
    '🧑🏿‍✈' => 'pilot(owka): śamna barwa kóže',
    '👨🏻‍✈' => 'pilot: swětła barwa kóže',
    '👨🏼‍✈' => 'pilot: srjejźnoswětła barwa kóže',
    '👨🏽‍✈' => 'pilot: wósrědna barwa kóže',
    '👨🏾‍✈' => 'pilot: srjejźnośamna barwa kóže',
    '👨🏿‍✈' => 'pilot: śamna barwa kóže',
    '👩🏻‍✈' => 'pilotowka: swětła barwa kóže',
    '👩🏼‍✈' => 'pilotowka: srjejźnoswětła barwa kóže',
    '👩🏽‍✈' => 'pilotowka: wósrědna barwa kóže',
    '👩🏾‍✈' => 'pilotowka: srjejźnośamna barwa kóže',
    '👩🏿‍✈' => 'pilotowka: śamna barwa kóže',
    '🧑🏻‍🚀' => 'astronawt(owka): swětła barwa kóže',
    '🧑🏼‍🚀' => 'astronawt(owka): srjejźnoswětła barwa kóže',
    '🧑🏽‍🚀' => 'astronawt(owka): wósrědna barwa kóže',
    '🧑🏾‍🚀' => 'astronawt(owka): srjejźnośamna barwa kóže',
    '🧑🏿‍🚀' => 'astronawt(owka): śamna barwa kóže',
    '👨🏻‍🚀' => 'astronawt: swětła barwa kóže',
    '👨🏼‍🚀' => 'astronawt: srjejźnoswětła barwa kóže',
    '👨🏽‍🚀' => 'astronawt: wósrědna barwa kóže',
    '👨🏾‍🚀' => 'astronawt: srjejźnośamna barwa kóže',
    '👨🏿‍🚀' => 'astronawt: śamna barwa kóže',
    '👩🏻‍🚀' => 'astronawtowka: swětła barwa kóže',
    '👩🏼‍🚀' => 'astronawtowka: srjejźnoswětła barwa kóže',
    '👩🏽‍🚀' => 'astronawtowka: wósrědna barwa kóže',
    '👩🏾‍🚀' => 'astronawtowka: srjejźnośamna barwa kóže',
    '👩🏿‍🚀' => 'astronawtowka: śamna barwa kóže',
    '🧑🏻‍🚒' => 'wognjowy wobornik / wognjowa wobornica: swětła barwa kóže',
    '🧑🏼‍🚒' => 'wognjowy wobornik / wognjowa wobornica: srjejźnoswětła barwa kóže',
    '🧑🏽‍🚒' => 'wognjowy wobornik / wognjowa wobornica: wósrědna barwa kóže',
    '🧑🏾‍🚒' => 'wognjowy wobornik / wognjowa wobornica: srjejźnośamna barwa kóže',
    '🧑🏿‍🚒' => 'wognjowy wobornik / wognjowa wobornica: śamna barwa kóže',
    '👨🏻‍🚒' => 'wognjowy wobornik: swětła barwa kóže',
    '👨🏼‍🚒' => 'wognjowy wobornik: srjejźnoswětła barwa kóže',
    '👨🏽‍🚒' => 'wognjowy wobornik: wósrědna barwa kóže',
    '👨🏾‍🚒' => 'wognjowy wobornik: srjejźnośamna barwa kóže',
    '👨🏿‍🚒' => 'wognjowy wobornik: śamna barwa kóže',
    '👩🏻‍🚒' => 'wognjowa wobornica: swětła barwa kóže',
    '👩🏼‍🚒' => 'wognjowa wobornica: srjejźnoswětła barwa kóže',
    '👩🏽‍🚒' => 'wognjowa wobornica: wósrědna barwa kóže',
    '👩🏾‍🚒' => 'wognjowa wobornica: srjejźnośamna barwa kóže',
    '👩🏿‍🚒' => 'wognjowa wobornica: śamna barwa kóže',
    '👮🏻‍♂' => 'policist: swětła barwa kóže',
    '👮🏼‍♂' => 'policist: srjejźnoswětła barwa kóže',
    '👮🏽‍♂' => 'policist: wósrědna barwa kóže',
    '👮🏾‍♂' => 'policist: srjejźnośamna barwa kóže',
    '👮🏿‍♂' => 'policist: śamna barwa kóže',
    '👮🏻‍♀' => 'policistaka: swětła barwa kóže',
    '👮🏼‍♀' => 'policistaka: srjejźnoswětła barwa kóže',
    '👮🏽‍♀' => 'policistaka: wósrědna barwa kóže',
    '👮🏾‍♀' => 'policistaka: srjejźnośamna barwa kóže',
    '👮🏿‍♀' => 'policistaka: śamna barwa kóže',
    '🕵🏻‍♂' => 'dedektiw: swětła barwa kóže',
    '🕵🏼‍♂' => 'dedektiw: srjejźnoswětła barwa kóže',
    '🕵🏽‍♂' => 'dedektiw: wósrědna barwa kóže',
    '🕵🏾‍♂' => 'dedektiw: srjejźnośamna barwa kóže',
    '🕵🏿‍♂' => 'dedektiw: śamna barwa kóže',
    '🕵🏻‍♀' => 'dedektiwka: swětła barwa kóže',
    '🕵🏼‍♀' => 'dedektiwka: srjejźnoswětła barwa kóže',
    '🕵🏽‍♀' => 'dedektiwka: wósrědna barwa kóže',
    '🕵🏾‍♀' => 'dedektiwka: srjejźnośamna barwa kóže',
    '🕵🏿‍♀' => 'dedektiwka: śamna barwa kóže',
    '💂🏻‍♂' => 'stražnik: swětła barwa kóže',
    '💂🏼‍♂' => 'stražnik: srjejźnoswětła barwa kóže',
    '💂🏽‍♂' => 'stražnik: wósrědna barwa kóže',
    '💂🏾‍♂' => 'stražnik: srjejźnośamna barwa kóže',
    '💂🏿‍♂' => 'stražnik: śamna barwa kóže',
    '💂🏻‍♀' => 'stražnica: swětła barwa kóže',
    '💂🏼‍♀' => 'stražnica: srjejźnoswětła barwa kóže',
    '💂🏽‍♀' => 'stražnica: wósrědna barwa kóže',
    '💂🏾‍♀' => 'stražnica: srjejźnośamna barwa kóže',
    '💂🏿‍♀' => 'stražnica: śamna barwa kóže',
    '👷🏻‍♂' => 'twaŕski źěłaśeŕ: swětła barwa kóže',
    '👷🏼‍♂' => 'twaŕski źěłaśeŕ: srjejźnoswětła barwa kóže',
    '👷🏽‍♂' => 'twaŕski źěłaśeŕ: wósrědna barwa kóže',
    '👷🏾‍♂' => 'twaŕski źěłaśeŕ: srjejźnośamna barwa kóže',
    '👷🏿‍♂' => 'twaŕski źěłaśeŕ: śamna barwa kóže',
    '👷🏻‍♀' => 'twaŕska źěłaśeŕka: swětła barwa kóže',
    '👷🏼‍♀' => 'twaŕska źěłaśeŕka: srjejźnoswětła barwa kóže',
    '👷🏽‍♀' => 'twaŕska źěłaśeŕka: wósrědna barwa kóže',
    '👷🏾‍♀' => 'twaŕska źěłaśeŕka: srjejźnośamna barwa kóže',
    '👷🏿‍♀' => 'twaŕska źěłaśeŕka: śamna barwa kóže',
    '👳🏻‍♂' => 'muski z turbanom: swětła barwa kóže',
    '👳🏼‍♂' => 'muski z turbanom: srjejźnoswětła barwa kóže',
    '👳🏽‍♂' => 'muski z turbanom: wósrědna barwa kóže',
    '👳🏾‍♂' => 'muski z turbanom: srjejźnośamna barwa kóže',
    '👳🏿‍♂' => 'muski z turbanom: śamna barwa kóže',
    '👳🏻‍♀' => 'žeńska z turbanom: swětła barwa kóže',
    '👳🏼‍♀' => 'žeńska z turbanom: srjejźnoswětła barwa kóže',
    '👳🏽‍♀' => 'žeńska z turbanom: wósrědna barwa kóže',
    '👳🏾‍♀' => 'žeńska z turbanom: srjejźnośamna barwa kóže',
    '👳🏿‍♀' => 'žeńska z turbanom: śamna barwa kóže',
    '🤵🏻‍♂' => 'muski w smokingu: swětła barwa kóže',
    '🤵🏼‍♂' => 'muski w smokingu: srjejźnoswětła barwa kóže',
    '🤵🏽‍♂' => 'muski w smokingu: wósrědna barwa kóže',
    '🤵🏾‍♂' => 'muski w smokingu: srjejźnośamna barwa kóže',
    '🤵🏿‍♂' => 'muski w smokingu: śamna barwa kóže',
    '🤵🏻‍♀' => 'žeńska w smokingu I: swětła barwa kóže',
    '🤵🏼‍♀' => 'žeńska w smokingu I: srjejźnoswětła barwa kóže',
    '🤵🏽‍♀' => 'žeńska w smokingu I: wósrědna barwa kóže',
    '🤵🏾‍♀' => 'žeńska w smokingu I: srjejźnośamna barwa kóže',
    '🤵🏿‍♀' => 'žeńska w smokingu I: śamna barwa kóže',
    '👰🏻‍♂' => 'muski ze šlewjerjom: swětła barwa kóže',
    '👰🏼‍♂' => 'muski ze šlewjerjom: srjejźnoswětła barwa kóže',
    '👰🏽‍♂' => 'muski ze šlewjerjom: wósrědna barwa kóže',
    '👰🏾‍♂' => 'muski ze šlewjerjom: srjejźnośamna barwa kóže',
    '👰🏿‍♂' => 'muski ze šlewjerjom: śamna barwa kóže',
    '👰🏻‍♀' => 'žeńska ze šlewjerjom: swětła barwa kóže',
    '👰🏼‍♀' => 'žeńska ze šlewjerjom: srjejźnoswětła barwa kóže',
    '👰🏽‍♀' => 'žeńska ze šlewjerjom: wósrědna barwa kóže',
    '👰🏾‍♀' => 'žeńska ze šlewjerjom: srjejźnośamna barwa kóže',
    '👰🏿‍♀' => 'žeńska ze šlewjerjom: śamna barwa kóže',
    '👩🏻‍🍼' => 'seśeca žeńska: swětła barwa kóže',
    '👩🏼‍🍼' => 'seśeca žeńska: srjejźnoswětła barwa kóže',
    '👩🏽‍🍼' => 'seśeca žeńska: wósrědna barwa kóže',
    '👩🏾‍🍼' => 'seśeca žeńska: srjejźnośamna barwa kóže',
    '👩🏿‍🍼' => 'seśeca žeńska: śamna barwa kóže',
    '👨🏻‍🍼' => 'góletkoju mloko dawajucy muski: swětła barwa kóže',
    '👨🏼‍🍼' => 'góletkoju mloko dawajucy muski: srjejźnoswětła barwa kóže',
    '👨🏽‍🍼' => 'góletkoju mloko dawajucy muski: wósrědna barwa kóže',
    '👨🏾‍🍼' => 'góletkoju mloko dawajucy muski: srjejźnośamna barwa kóže',
    '👨🏿‍🍼' => 'góletkoju mloko dawajucy muski: śamna barwa kóže',
    '🧑🏻‍🍼' => 'góletkoju mloko dawajuca wósoba: swětła barwa kóže',
    '🧑🏼‍🍼' => 'góletkoju mloko dawajuca wósoba: srjejźnoswětła barwa kóže',
    '🧑🏽‍🍼' => 'góletkoju mloko dawajuca wósoba: wósrědna barwa kóže',
    '🧑🏾‍🍼' => 'góletkoju mloko dawajuca wósoba: srjejźnośamna barwa kóže',
    '🧑🏿‍🍼' => 'góletkoju mloko dawajuca wósoba: śamna barwa kóže',
    '🧑🏻‍🎄' => 'gódy: swětła barwa kóže',
    '🧑🏼‍🎄' => 'gódy: srjejźnoswětła barwa kóže',
    '🧑🏽‍🎄' => 'gódy: wósrědna barwa kóže',
    '🧑🏾‍🎄' => 'gódy: srjejźnośamna barwa kóže',
    '🧑🏿‍🎄' => 'gódy: śamna barwa kóže',
    '🦸🏻‍♂' => 'muskecy superryśaŕ: swětła barwa kóže',
    '🦸🏼‍♂' => 'muskecy superryśaŕ: srjejźnoswětła barwa kóže',
    '🦸🏽‍♂' => 'muskecy superryśaŕ: wósrědna barwa kóže',
    '🦸🏾‍♂' => 'muskecy superryśaŕ: srjejźnośamna barwa kóže',
    '🦸🏿‍♂' => 'muskecy superryśaŕ: śamna barwa kóže',
    '🦸🏻‍♀' => 'superryśaŕka: swětła barwa kóže',
    '🦸🏼‍♀' => 'superryśaŕka: srjejźnoswětła barwa kóže',
    '🦸🏽‍♀' => 'superryśaŕka: wósrědna barwa kóže',
    '🦸🏾‍♀' => 'superryśaŕka: srjejźnośamna barwa kóže',
    '🦸🏿‍♀' => 'superryśaŕka: śamna barwa kóže',
    '🦹🏻‍♂' => 'muskecy supernjeknicomnik: swětła barwa kóže',
    '🦹🏼‍♂' => 'muskecy supernjeknicomnik: srjejźnoswětła barwa kóže',
    '🦹🏽‍♂' => 'muskecy supernjeknicomnik: wósrědna barwa kóže',
    '🦹🏾‍♂' => 'muskecy supernjeknicomnik: srjejźnośamna barwa kóže',
    '🦹🏿‍♂' => 'muskecy supernjeknicomnik: śamna barwa kóže',
    '🦹🏻‍♀' => 'supernjeknicomnica: swětła barwa kóže',
    '🦹🏼‍♀' => 'supernjeknicomnica: srjejźnoswětła barwa kóže',
    '🦹🏽‍♀' => 'supernjeknicomnica: wósrědna barwa kóže',
    '🦹🏾‍♀' => 'supernjeknicomnica: srjejźnośamna barwa kóže',
    '🦹🏿‍♀' => 'supernjeknicomnica: śamna barwa kóže',
    '🧙🏻‍♂' => 'muskecy gusłowaŕ: swětła barwa kóže',
    '🧙🏼‍♂' => 'muskecy gusłowaŕ: srjejźnoswětła barwa kóže',
    '🧙🏽‍♂' => 'muskecy gusłowaŕ: wósrědna barwa kóže',
    '🧙🏾‍♂' => 'muskecy gusłowaŕ: srjejźnośamna barwa kóže',
    '🧙🏿‍♂' => 'muskecy gusłowaŕ: śamna barwa kóže',
    '🧙🏻‍♀' => 'magijaŕka: swětła barwa kóže',
    '🧙🏼‍♀' => 'magijaŕka: srjejźnoswětła barwa kóže',
    '🧙🏽‍♀' => 'magijaŕka: wósrědna barwa kóže',
    '🧙🏾‍♀' => 'magijaŕka: srjejźnośamna barwa kóže',
    '🧙🏿‍♀' => 'magijaŕka: śamna barwa kóže',
    '🧚🏻‍♂' => 'muskeca wiła: swětła barwa kóže',
    '🧚🏼‍♂' => 'muskeca wiła: srjejźnoswětła barwa kóže',
    '🧚🏽‍♂' => 'muskeca wiła: wósrědna barwa kóže',
    '🧚🏾‍♂' => 'muskeca wiła: srjejźnośamna barwa kóže',
    '🧚🏿‍♂' => 'muskeca wiła: śamna barwa kóže',
    '🧚🏻‍♀' => 'žeńskeca wiła: swětła barwa kóže',
    '🧚🏼‍♀' => 'žeńskeca wiła: srjejźnoswětła barwa kóže',
    '🧚🏽‍♀' => 'žeńskeca wiła: wósrědna barwa kóže',
    '🧚🏾‍♀' => 'žeńskeca wiła: srjejźnośamna barwa kóže',
    '🧚🏿‍♀' => 'žeńskeca wiła: śamna barwa kóže',
    '🧛🏻‍♂' => 'wampir: swětła barwa kóže',
    '🧛🏼‍♂' => 'wampir: srjejźnoswětła barwa kóže',
    '🧛🏽‍♂' => 'wampir: wósrědna barwa kóže',
    '🧛🏾‍♂' => 'wampir: srjejźnośamna barwa kóže',
    '🧛🏿‍♂' => 'wampir: śamna barwa kóže',
    '🧛🏻‍♀' => 'wampirka: swětła barwa kóže',
    '🧛🏼‍♀' => 'wampirka: srjejźnoswětła barwa kóže',
    '🧛🏽‍♀' => 'wampirka: wósrědna barwa kóže',
    '🧛🏾‍♀' => 'wampirka: srjejźnośamna barwa kóže',
    '🧛🏿‍♀' => 'wampirka: śamna barwa kóže',
    '🧜🏻‍♂' => 'nykus: swětła barwa kóže',
    '🧜🏼‍♂' => 'nykus: srjejźnoswětła barwa kóže',
    '🧜🏽‍♂' => 'nykus: wósrědna barwa kóže',
    '🧜🏾‍♂' => 'nykus: srjejźnośamna barwa kóže',
    '🧜🏿‍♂' => 'nykus: śamna barwa kóže',
    '🧜🏻‍♀' => 'mórska kněžna: swětła barwa kóže',
    '🧜🏼‍♀' => 'mórska kněžna: srjejźnoswětła barwa kóže',
    '🧜🏽‍♀' => 'mórska kněžna: wósrědna barwa kóže',
    '🧜🏾‍♀' => 'mórska kněžna: srjejźnośamna barwa kóže',
    '🧜🏿‍♀' => 'mórska kněžna: śamna barwa kóže',
    '🧝🏻‍♂' => 'muskecy elf: swětła barwa kóže',
    '🧝🏼‍♂' => 'muskecy elf: srjejźnoswětła barwa kóže',
    '🧝🏽‍♂' => 'muskecy elf: wósrědna barwa kóže',
    '🧝🏾‍♂' => 'muskecy elf: srjejźnośamna barwa kóže',
    '🧝🏿‍♂' => 'muskecy elf: śamna barwa kóže',
    '🧝🏻‍♀' => 'žeńskecy elf: swětła barwa kóže',
    '🧝🏼‍♀' => 'žeńskecy elf: srjejźnoswětła barwa kóže',
    '🧝🏽‍♀' => 'žeńskecy elf: wósrědna barwa kóže',
    '🧝🏾‍♀' => 'žeńskecy elf: srjejźnośamna barwa kóže',
    '🧝🏿‍♀' => 'žeńskecy elf: śamna barwa kóže',
    '💆🏻‍♂' => 'muski, kenž dostanjo masažu głowy: swětła barwa kóže',
    '💆🏼‍♂' => 'muski, kenž dostanjo masažu głowy: srjejźnoswětła barwa kóže',
    '💆🏽‍♂' => 'muski, kenž dostanjo masažu głowy: wósrědna barwa kóže',
    '💆🏾‍♂' => 'muski, kenž dostanjo masažu głowy: srjejźnośamna barwa kóže',
    '💆🏿‍♂' => 'muski, kenž dostanjo masažu głowy: śamna barwa kóže',
    '💆🏻‍♀' => 'žeńska, kenž dostanjo masažu głowy: swětła barwa kóže',
    '💆🏼‍♀' => 'žeńska, kenž dostanjo masažu głowy: srjejźnoswětła barwa kóže',
    '💆🏽‍♀' => 'žeńska, kenž dostanjo masažu głowy: wósrědna barwa kóže',
    '💆🏾‍♀' => 'žeńska, kenž dostanjo masažu głowy: srjejźnośamna barwa kóže',
    '💆🏿‍♀' => 'žeńska, kenž dostanjo masažu głowy: śamna barwa kóže',
    '💇🏻‍♂' => 'muski, kenž dajo se włosy stśigaś: swětła barwa kóže',
    '💇🏼‍♂' => 'muski, kenž dajo se włosy stśigaś: srjejźnoswětła barwa kóže',
    '💇🏽‍♂' => 'muski, kenž dajo se włosy stśigaś: wósrědna barwa kóže',
    '💇🏾‍♂' => 'muski, kenž dajo se włosy stśigaś: srjejźnośamna barwa kóže',
    '💇🏿‍♂' => 'muski, kenž dajo se włosy stśigaś: śamna barwa kóže',
    '💇🏻‍♀' => 'žeńska , kenž dajo se włosy stśigaś: swětła barwa kóže',
    '💇🏼‍♀' => 'žeńska , kenž dajo se włosy stśigaś: srjejźnoswětła barwa kóže',
    '💇🏽‍♀' => 'žeńska , kenž dajo se włosy stśigaś: wósrědna barwa kóže',
    '💇🏾‍♀' => 'žeńska , kenž dajo se włosy stśigaś: srjejźnośamna barwa kóže',
    '💇🏿‍♀' => 'žeńska , kenž dajo se włosy stśigaś: śamna barwa kóže',
    '🚶🏻‍♂' => 'pěškaŕ: swětła barwa kóže',
    '🚶🏼‍♂' => 'pěškaŕ: srjejźnoswětła barwa kóže',
    '🚶🏽‍♂' => 'pěškaŕ: wósrědna barwa kóže',
    '🚶🏾‍♂' => 'pěškaŕ: srjejźnośamna barwa kóže',
    '🚶🏿‍♂' => 'pěškaŕ: śamna barwa kóže',
    '🚶🏻‍♀' => 'pěškaŕka: swětła barwa kóže',
    '🚶🏼‍♀' => 'pěškaŕka: srjejźnoswětła barwa kóže',
    '🚶🏽‍♀' => 'pěškaŕka: wósrědna barwa kóže',
    '🚶🏾‍♀' => 'pěškaŕka: srjejźnośamna barwa kóže',
    '🚶🏿‍♀' => 'pěškaŕka: śamna barwa kóže',
    '🚶🏻‍➡' => 'pěšy duca wósoba: swětła barwa kóže, napšawo',
    '🚶🏼‍➡' => 'pěšy duca wósoba: srjejźnoswětła barwa kóže, napšawo',
    '🚶🏽‍➡' => 'pěšy duca wósoba: wósrědna barwa kóže, napšawo',
    '🚶🏾‍➡' => 'pěšy duca wósoba: srjejźnośamna barwa kóže, napšawo',
    '🚶🏿‍➡' => 'pěšy duca wósoba: śamna barwa kóže, napšawo',
    '🧍🏻‍♂' => 'stojecy muski: swětła barwa kóže',
    '🧍🏼‍♂' => 'stojecy muski: srjejźnoswětła barwa kóže',
    '🧍🏽‍♂' => 'stojecy muski: wósrědna barwa kóže',
    '🧍🏾‍♂' => 'stojecy muski: srjejźnośamna barwa kóže',
    '🧍🏿‍♂' => 'stojecy muski: śamna barwa kóže',
    '🧍🏻‍♀' => 'stojeca žeńska: swětła barwa kóže',
    '🧍🏼‍♀' => 'stojeca žeńska: srjejźnoswětła barwa kóže',
    '🧍🏽‍♀' => 'stojeca žeńska: wósrědna barwa kóže',
    '🧍🏾‍♀' => 'stojeca žeńska: srjejźnośamna barwa kóže',
    '🧍🏿‍♀' => 'stojeca žeńska: śamna barwa kóže',
    '🧎🏻‍♂' => 'kólenkujucy muski: swětła barwa kóže',
    '🧎🏼‍♂' => 'kólenkujucy muski: srjejźnoswětła barwa kóže',
    '🧎🏽‍♂' => 'kólenkujucy muski: wósrědna barwa kóže',
    '🧎🏾‍♂' => 'kólenkujucy muski: srjejźnośamna barwa kóže',
    '🧎🏿‍♂' => 'kólenkujucy muski: śamna barwa kóže',
    '🧎🏻‍♀' => 'kólenkujuca žeńska: swětła barwa kóže',
    '🧎🏼‍♀' => 'kólenkujuca žeńska: srjejźnoswětła barwa kóže',
    '🧎🏽‍♀' => 'kólenkujuca žeńska: wósrědna barwa kóže',
    '🧎🏾‍♀' => 'kólenkujuca žeńska: srjejźnośamna barwa kóže',
    '🧎🏿‍♀' => 'kólenkujuca žeńska: śamna barwa kóže',
    '🧎🏻‍➡' => 'kólenkujuca wósoba: swětła barwa kóže, napšawo',
    '🧎🏼‍➡' => 'kólenkujuca wósoba: srjejźnoswětła barwa kóže, napšawo',
    '🧎🏽‍➡' => 'kólenkujuca wósoba: wósrědna barwa kóže, napšawo',
    '🧎🏾‍➡' => 'kólenkujuca wósoba: srjejźnośamna barwa kóže, napšawo',
    '🧎🏿‍➡' => 'kólenkujuca wósoba: śamna barwa kóže, napšawo',
    '🧑🏻‍🦯' => 'wósoba z kijom za slěpych: swětła barwa kóže',
    '🧑🏼‍🦯' => 'wósoba z kijom za slěpych: srjejźnoswětła barwa kóže',
    '🧑🏽‍🦯' => 'wósoba z kijom za slěpych: wósrědna barwa kóže',
    '🧑🏾‍🦯' => 'wósoba z kijom za slěpych: srjejźnośamna barwa kóže',
    '🧑🏿‍🦯' => 'wósoba z kijom za slěpych: śamna barwa kóže',
    '👨🏻‍🦯' => 'muski z kijom za slěpych: swětła barwa kóže',
    '👨🏼‍🦯' => 'muski z kijom za slěpych: srjejźnoswětła barwa kóže',
    '👨🏽‍🦯' => 'muski z kijom za slěpych: wósrědna barwa kóže',
    '👨🏾‍🦯' => 'muski z kijom za slěpych: srjejźnośamna barwa kóže',
    '👨🏿‍🦯' => 'muski z kijom za slěpych: śamna barwa kóže',
    '👩🏻‍🦯' => 'žeńska z kijom za slěpych: swětła barwa kóže',
    '👩🏼‍🦯' => 'žeńska z kijom za slěpych: srjejźnoswětła barwa kóže',
    '👩🏽‍🦯' => 'žeńska z kijom za slěpych: wósrědna barwa kóže',
    '👩🏾‍🦯' => 'žeńska z kijom za slěpych: srjejźnośamna barwa kóže',
    '👩🏿‍🦯' => 'žeńska z kijom za slěpych: śamna barwa kóže',
    '🧑🏻‍🦼' => 'wósoba w elektriskem jězdnem stole: swětła barwa kóže',
    '🧑🏼‍🦼' => 'wósoba w elektriskem jězdnem stole: srjejźnoswětła barwa kóže',
    '🧑🏽‍🦼' => 'wósoba w elektriskem jězdnem stole: wósrědna barwa kóže',
    '🧑🏾‍🦼' => 'wósoba w elektriskem jězdnem stole: srjejźnośamna barwa kóže',
    '🧑🏿‍🦼' => 'wósoba w elektriskem jězdnem stole: śamna barwa kóže',
    '👨🏻‍🦼' => 'muski w elektriskem jězdnem stole: swětła barwa kóže',
    '👨🏼‍🦼' => 'muski w elektriskem jězdnem stole: srjejźnoswětła barwa kóže',
    '👨🏽‍🦼' => 'muski w elektriskem jězdnem stole: wósrědna barwa kóže',
    '👨🏾‍🦼' => 'muski w elektriskem jězdnem stole: srjejźnośamna barwa kóže',
    '👨🏿‍🦼' => 'muski w elektriskem jězdnem stole: śamna barwa kóže',
    '👩🏻‍🦼' => 'žeńska w elektriskem jězdnem stole: swětła barwa kóže',
    '👩🏼‍🦼' => 'žeńska w elektriskem jězdnem stole: srjejźnoswětła barwa kóže',
    '👩🏽‍🦼' => 'žeńska w elektriskem jězdnem stole: wósrědna barwa kóže',
    '👩🏾‍🦼' => 'žeńska w elektriskem jězdnem stole: srjejźnośamna barwa kóže',
    '👩🏿‍🦼' => 'žeńska w elektriskem jězdnem stole: śamna barwa kóže',
    '🧑🏻‍🦽' => 'wósoba w jězdnem stole: swětła barwa kóže',
    '🧑🏼‍🦽' => 'wósoba w jězdnem stole: srjejźnoswětła barwa kóže',
    '🧑🏽‍🦽' => 'wósoba w jězdnem stole: wósrědna barwa kóže',
    '🧑🏾‍🦽' => 'wósoba w jězdnem stole: srjejźnośamna barwa kóže',
    '🧑🏿‍🦽' => 'wósoba w jězdnem stole: śamna barwa kóže',
    '👨🏻‍🦽' => 'muski w jězdnem stole: swětła barwa kóže',
    '👨🏼‍🦽' => 'muski w jězdnem stole: srjejźnoswětła barwa kóže',
    '👨🏽‍🦽' => 'muski w jězdnem stole: wósrědna barwa kóže',
    '👨🏾‍🦽' => 'muski w jězdnem stole: srjejźnośamna barwa kóže',
    '👨🏿‍🦽' => 'muski w jězdnem stole: śamna barwa kóže',
    '👩🏻‍🦽' => 'žeńska w jězdnem stole: swětła barwa kóže',
    '👩🏼‍🦽' => 'žeńska w jězdnem stole: srjejźnoswětła barwa kóže',
    '👩🏽‍🦽' => 'žeńska w jězdnem stole: wósrědna barwa kóže',
    '👩🏾‍🦽' => 'žeńska w jězdnem stole: srjejźnośamna barwa kóže',
    '👩🏿‍🦽' => 'žeńska w jězdnem stole: śamna barwa kóže',
    '🏃🏻‍♂' => 'ganjajucy muski: swětła barwa kóže',
    '🏃🏼‍♂' => 'ganjajucy muski: srjejźnoswětła barwa kóže',
    '🏃🏽‍♂' => 'ganjajucy muski: wósrědna barwa kóže',
    '🏃🏾‍♂' => 'ganjajucy muski: srjejźnośamna barwa kóže',
    '🏃🏿‍♂' => 'ganjajucy muski: śamna barwa kóže',
    '🏃🏻‍♀' => 'ganjajuca žeńska: swětła barwa kóže',
    '🏃🏼‍♀' => 'ganjajuca žeńska: srjejźnoswětła barwa kóže',
    '🏃🏽‍♀' => 'ganjajuca žeńska: wósrědna barwa kóže',
    '🏃🏾‍♀' => 'ganjajuca žeńska: srjejźnośamna barwa kóže',
    '🏃🏿‍♀' => 'ganjajuca žeńska: śamna barwa kóže',
    '🏃🏻‍➡' => 'ganjajuca wósoba: swětła barwa kóže, napšawo',
    '🏃🏼‍➡' => 'ganjajuca wósoba: srjejźnoswětła barwa kóže, napšawo',
    '🏃🏽‍➡' => 'ganjajuca wósoba: wósrědna barwa kóže, napšawo',
    '🏃🏾‍➡' => 'ganjajuca wósoba: srjejźnośamna barwa kóže, napšawo',
    '🏃🏿‍➡' => 'ganjajuca wósoba: śamna barwa kóže, napšawo',
    '👯🏻‍♀' => 'žeńsce z wuchacowamy wušyma: swětła barwa kóže',
    '👯🏼‍♀' => 'žeńsce z wuchacowamy wušyma: srjejźnoswětła barwa kóže',
    '👯🏽‍♀' => 'žeńsce z wuchacowamy wušyma: wósrědna barwa kóže',
    '👯🏾‍♀' => 'žeńsce z wuchacowamy wušyma: srjejźnośamna barwa kóže',
    '👯🏿‍♀' => 'žeńsce z wuchacowamy wušyma: śamna barwa kóže',
    '👯🏻‍♂' => 'muskej z wuchacowyma wušyma: swětła barwa kóže',
    '👯🏼‍♂' => 'muskej z wuchacowyma wušyma: srjejźnoswětła barwa kóže',
    '👯🏽‍♂' => 'muskej z wuchacowyma wušyma: wósrědna barwa kóže',
    '👯🏾‍♂' => 'muskej z wuchacowyma wušyma: srjejźnośamna barwa kóže',
    '👯🏿‍♂' => 'muskej z wuchacowyma wušyma: śamna barwa kóže',
    '🧖🏻‍♂' => 'muski w sawnje: swětła barwa kóže',
    '🧖🏼‍♂' => 'muski w sawnje: srjejźnoswětła barwa kóže',
    '🧖🏽‍♂' => 'muski w sawnje: wósrědna barwa kóže',
    '🧖🏾‍♂' => 'muski w sawnje: srjejźnośamna barwa kóže',
    '🧖🏿‍♂' => 'muski w sawnje: śamna barwa kóže',
    '🧖🏻‍♀' => 'žeńska w sawnje: swětła barwa kóže',
    '🧖🏼‍♀' => 'žeńska w sawnje: srjejźnoswětła barwa kóže',
    '🧖🏽‍♀' => 'žeńska w sawnje: wósrědna barwa kóže',
    '🧖🏾‍♀' => 'žeńska w sawnje: srjejźnośamna barwa kóže',
    '🧖🏿‍♀' => 'žeńska w sawnje: śamna barwa kóže',
    '🧗🏻‍♂' => 'alpinist: swětła barwa kóže',
    '🧗🏼‍♂' => 'alpinist: srjejźnoswětła barwa kóže',
    '🧗🏽‍♂' => 'alpinist: wósrědna barwa kóže',
    '🧗🏾‍♂' => 'alpinist: srjejźnośamna barwa kóže',
    '🧗🏿‍♂' => 'alpinist: śamna barwa kóže',
    '🧗🏻‍♀' => 'alpinistka: swětła barwa kóže',
    '🧗🏼‍♀' => 'alpinistka: srjejźnoswětła barwa kóže',
    '🧗🏽‍♀' => 'alpinistka: wósrědna barwa kóže',
    '🧗🏾‍♀' => 'alpinistka: srjejźnośamna barwa kóže',
    '🧗🏿‍♀' => 'alpinistka: śamna barwa kóže',
    '🏌🏻‍♂' => 'grajaŕ golfa: swětła barwa kóže',
    '🏌🏼‍♂' => 'grajaŕ golfa: srjejźnoswětła barwa kóže',
    '🏌🏽‍♂' => 'grajaŕ golfa: wósrědna barwa kóže',
    '🏌🏾‍♂' => 'grajaŕ golfa: srjejźnośamna barwa kóže',
    '🏌🏿‍♂' => 'grajaŕ golfa: śamna barwa kóže',
    '🏌🏻‍♀' => 'golfowaŕka: swětła barwa kóže',
    '🏌🏼‍♀' => 'golfowaŕka: srjejźnoswětła barwa kóže',
    '🏌🏽‍♀' => 'golfowaŕka: wósrědna barwa kóže',
    '🏌🏾‍♀' => 'golfowaŕka: srjejźnośamna barwa kóže',
    '🏌🏿‍♀' => 'golfowaŕka: śamna barwa kóže',
    '🏄🏻‍♂' => 'surfowaŕ: swětła barwa kóže',
    '🏄🏼‍♂' => 'surfowaŕ: srjejźnoswětła barwa kóže',
    '🏄🏽‍♂' => 'surfowaŕ: wósrědna barwa kóže',
    '🏄🏾‍♂' => 'surfowaŕ: srjejźnośamna barwa kóže',
    '🏄🏿‍♂' => 'surfowaŕ: śamna barwa kóže',
    '🏄🏻‍♀' => 'surfowaŕka: swětła barwa kóže',
    '🏄🏼‍♀' => 'surfowaŕka: srjejźnoswětła barwa kóže',
    '🏄🏽‍♀' => 'surfowaŕka: wósrědna barwa kóže',
    '🏄🏾‍♀' => 'surfowaŕka: srjejźnośamna barwa kóže',
    '🏄🏿‍♀' => 'surfowaŕka: śamna barwa kóže',
    '🚣🏻‍♂' => 'wjasłowaŕ: swětła barwa kóže',
    '🚣🏼‍♂' => 'wjasłowaŕ: srjejźnoswětła barwa kóže',
    '🚣🏽‍♂' => 'wjasłowaŕ: wósrědna barwa kóže',
    '🚣🏾‍♂' => 'wjasłowaŕ: srjejźnośamna barwa kóže',
    '🚣🏿‍♂' => 'wjasłowaŕ: śamna barwa kóže',
    '🚣🏻‍♀' => 'wjasłowaŕka: swětła barwa kóže',
    '🚣🏼‍♀' => 'wjasłowaŕka: srjejźnoswětła barwa kóže',
    '🚣🏽‍♀' => 'wjasłowaŕka: wósrědna barwa kóže',
    '🚣🏾‍♀' => 'wjasłowaŕka: srjejźnośamna barwa kóže',
    '🚣🏿‍♀' => 'wjasłowaŕka: śamna barwa kóže',
    '🏊🏻‍♂' => 'plěwaŕ: swětła barwa kóže',
    '🏊🏼‍♂' => 'plěwaŕ: srjejźnoswětła barwa kóže',
    '🏊🏽‍♂' => 'plěwaŕ: wósrědna barwa kóže',
    '🏊🏾‍♂' => 'plěwaŕ: srjejźnośamna barwa kóže',
    '🏊🏿‍♂' => 'plěwaŕ: śamna barwa kóže',
    '🏊🏻‍♀' => 'plěwaŕka: swětła barwa kóže',
    '🏊🏼‍♀' => 'plěwaŕka: srjejźnoswětła barwa kóže',
    '🏊🏽‍♀' => 'plěwaŕka: wósrědna barwa kóže',
    '🏊🏾‍♀' => 'plěwaŕka: srjejźnośamna barwa kóže',
    '🏊🏿‍♀' => 'plěwaŕka: śamna barwa kóže',
    '⛹🏻‍♂' => 'muski z balom: swětła barwa kóže',
    '⛹🏼‍♂' => 'muski z balom: srjejźnoswětła barwa kóže',
    '⛹🏽‍♂' => 'muski z balom: wósrědna barwa kóže',
    '⛹🏾‍♂' => 'muski z balom: srjejźnośamna barwa kóže',
    '⛹🏿‍♂' => 'muski z balom: śamna barwa kóže',
    '⛹🏻‍♀' => 'žeńska z balom: swětła barwa kóže',
    '⛹🏼‍♀' => 'žeńska z balom: srjejźnoswětła barwa kóže',
    '⛹🏽‍♀' => 'žeńska z balom: wósrědna barwa kóže',
    '⛹🏾‍♀' => 'žeńska z balom: srjejźnośamna barwa kóže',
    '⛹🏿‍♀' => 'žeńska z balom: śamna barwa kóže',
    '🏋🏻‍♂' => 'zwigaŕ wažydłow: swětła barwa kóže',
    '🏋🏼‍♂' => 'zwigaŕ wažydłow: srjejźnoswětła barwa kóže',
    '🏋🏽‍♂' => 'zwigaŕ wažydłow: wósrědna barwa kóže',
    '🏋🏾‍♂' => 'zwigaŕ wažydłow: srjejźnośamna barwa kóže',
    '🏋🏿‍♂' => 'zwigaŕ wažydłow: śamna barwa kóže',
    '🏋🏻‍♀' => 'zwigaŕka wažydłow: swětła barwa kóže',
    '🏋🏼‍♀' => 'zwigaŕka wažydłow: srjejźnoswětła barwa kóže',
    '🏋🏽‍♀' => 'zwigaŕka wažydłow: wósrědna barwa kóže',
    '🏋🏾‍♀' => 'zwigaŕka wažydłow: srjejźnośamna barwa kóže',
    '🏋🏿‍♀' => 'zwigaŕka wažydłow: śamna barwa kóže',
    '🚴🏻‍♂' => 'kólasowaŕ: swětła barwa kóže',
    '🚴🏼‍♂' => 'kólasowaŕ: srjejźnoswětła barwa kóže',
    '🚴🏽‍♂' => 'kólasowaŕ: wósrědna barwa kóže',
    '🚴🏾‍♂' => 'kólasowaŕ: srjejźnośamna barwa kóže',
    '🚴🏿‍♂' => 'kólasowaŕ: śamna barwa kóže',
    '🚴🏻‍♀' => 'kólasowaŕka: swětła barwa kóže',
    '🚴🏼‍♀' => 'kólasowaŕka: srjejźnoswětła barwa kóže',
    '🚴🏽‍♀' => 'kólasowaŕka: wósrědna barwa kóže',
    '🚴🏾‍♀' => 'kólasowaŕka: srjejźnośamna barwa kóže',
    '🚴🏿‍♀' => 'kólasowaŕka: śamna barwa kóže',
    '🚵🏻‍♂' => 'mountainbikaŕ: swětła barwa kóže',
    '🚵🏼‍♂' => 'mountainbikaŕ: srjejźnoswětła barwa kóže',
    '🚵🏽‍♂' => 'mountainbikaŕ: wósrědna barwa kóže',
    '🚵🏾‍♂' => 'mountainbikaŕ: srjejźnośamna barwa kóže',
    '🚵🏿‍♂' => 'mountainbikaŕ: śamna barwa kóže',
    '🚵🏻‍♀' => 'mountainbikaŕka: swětła barwa kóže',
    '🚵🏼‍♀' => 'mountainbikaŕka: srjejźnoswětła barwa kóže',
    '🚵🏽‍♀' => 'mountainbikaŕka: wósrědna barwa kóže',
    '🚵🏾‍♀' => 'mountainbikaŕka: srjejźnośamna barwa kóže',
    '🚵🏿‍♀' => 'mountainbikaŕka: śamna barwa kóže',
    '🤸🏻‍♂' => 'muski, kenž se na bok pśewjertujo: swětła barwa kóže',
    '🤸🏼‍♂' => 'muski, kenž se na bok pśewjertujo: srjejźnoswětła barwa kóže',
    '🤸🏽‍♂' => 'muski, kenž se na bok pśewjertujo: wósrědna barwa kóže',
    '🤸🏾‍♂' => 'muski, kenž se na bok pśewjertujo: srjejźnośamna barwa kóže',
    '🤸🏿‍♂' => 'muski, kenž se na bok pśewjertujo: śamna barwa kóže',
    '🤸🏻‍♀' => 'se na bok pśewjertujuca žeńska: swětła barwa kóže',
    '🤸🏼‍♀' => 'se na bok pśewjertujuca žeńska: srjejźnoswětła barwa kóže',
    '🤸🏽‍♀' => 'se na bok pśewjertujuca žeńska: wósrědna barwa kóže',
    '🤸🏾‍♀' => 'se na bok pśewjertujuca žeńska: srjejźnośamna barwa kóže',
    '🤸🏿‍♀' => 'se na bok pśewjertujuca žeńska: śamna barwa kóže',
    '🤼🏻‍♀' => 'se běźecej žeńsce I: swětła barwa kóže',
    '🤼🏼‍♀' => 'se běźecej žeńsce I: srjejźnoswětła barwa kóže',
    '🤼🏽‍♀' => 'se běźecej žeńsce I: wósrědna barwa kóže',
    '🤼🏾‍♀' => 'se běźecej žeńsce I: srjejźnośamna barwa kóže',
    '🤼🏿‍♀' => 'se běźecej žeńsce I: śamna barwa kóže',
    '🤼🏻‍♂' => 'se běźecej muskej: swětła barwa kóže',
    '🤼🏼‍♂' => 'se běźecej muskej: srjejźnoswětła barwa kóže',
    '🤼🏽‍♂' => 'se běźecej muskej: wósrědna barwa kóže',
    '🤼🏾‍♂' => 'se běźecej muskej: srjejźnośamna barwa kóže',
    '🤼🏿‍♂' => 'se běźecej muskej: śamna barwa kóže',
    '🤽🏻‍♂' => 'grajaŕ wódnego bala: swětła barwa kóže',
    '🤽🏼‍♂' => 'grajaŕ wódnego bala: srjejźnoswětła barwa kóže',
    '🤽🏽‍♂' => 'grajaŕ wódnego bala: wósrědna barwa kóže',
    '🤽🏾‍♂' => 'grajaŕ wódnego bala: srjejźnośamna barwa kóže',
    '🤽🏿‍♂' => 'grajaŕ wódnego bala: śamna barwa kóže',
    '🤽🏻‍♀' => 'grajaŕka wódnego bala: swětła barwa kóže',
    '🤽🏼‍♀' => 'grajaŕka wódnego bala: srjejźnoswětła barwa kóže',
    '🤽🏽‍♀' => 'grajaŕka wódnego bala: wósrědna barwa kóže',
    '🤽🏾‍♀' => 'grajaŕka wódnego bala: srjejźnośamna barwa kóže',
    '🤽🏿‍♀' => 'grajaŕka wódnego bala: śamna barwa kóže',
    '🤾🏻‍♂' => 'chytańcaŕ: swětła barwa kóže',
    '🤾🏼‍♂' => 'chytańcaŕ: srjejźnoswětła barwa kóže',
    '🤾🏽‍♂' => 'chytańcaŕ: wósrědna barwa kóže',
    '🤾🏾‍♂' => 'chytańcaŕ: srjejźnośamna barwa kóže',
    '🤾🏿‍♂' => 'chytańcaŕ: śamna barwa kóže',
    '🤾🏻‍♀' => 'chytańcaŕka: swětła barwa kóže',
    '🤾🏼‍♀' => 'chytańcaŕka: srjejźnoswětła barwa kóže',
    '🤾🏽‍♀' => 'chytańcaŕka: wósrědna barwa kóže',
    '🤾🏾‍♀' => 'chytańcaŕka: srjejźnośamna barwa kóže',
    '🤾🏿‍♀' => 'chytańcaŕka: śamna barwa kóže',
    '🤹🏻‍♂' => 'žongler: swětła barwa kóže',
    '🤹🏼‍♂' => 'žongler: srjejźnoswětła barwa kóže',
    '🤹🏽‍♂' => 'žongler: wósrědna barwa kóže',
    '🤹🏾‍♂' => 'žongler: srjejźnośamna barwa kóže',
    '🤹🏿‍♂' => 'žongler: śamna barwa kóže',
    '🤹🏻‍♀' => 'žonglerka: swětła barwa kóže',
    '🤹🏼‍♀' => 'žonglerka: srjejźnoswětła barwa kóže',
    '🤹🏽‍♀' => 'žonglerka: wósrědna barwa kóže',
    '🤹🏾‍♀' => 'žonglerka: srjejźnośamna barwa kóže',
    '🤹🏿‍♀' => 'žonglerka: śamna barwa kóže',
    '🧘🏻‍♂' => 'muski w lotosowem sejźenju: swětła barwa kóže',
    '🧘🏼‍♂' => 'muski w lotosowem sejźenju: srjejźnoswětła barwa kóže',
    '🧘🏽‍♂' => 'muski w lotosowem sejźenju: wósrědna barwa kóže',
    '🧘🏾‍♂' => 'muski w lotosowem sejźenju: srjejźnośamna barwa kóže',
    '🧘🏿‍♂' => 'muski w lotosowem sejźenju: śamna barwa kóže',
    '🧘🏻‍♀' => 'žeńska w lotosowem sejźenju: swětła barwa kóže',
    '🧘🏼‍♀' => 'žeńska w lotosowem sejźenju: srjejźnoswětła barwa kóže',
    '🧘🏽‍♀' => 'žeńska w lotosowem sejźenju: wósrědna barwa kóže',
    '🧘🏾‍♀' => 'žeńska w lotosowem sejźenju: srjejźnośamna barwa kóže',
    '🧘🏿‍♀' => 'žeńska w lotosowem sejźenju: śamna barwa kóže',
    '🧑‍🦰' => 'dorosćony: cerwjene włosy',
    '🧑‍🦱' => 'dorosćony: kuźerate włosy',
    '🧑‍🦳' => 'dorosćony: běłe włosy',
    '🧑‍🦲' => 'dorosćony: plěch',
    '👨‍🦰' => 'muski: cerwjene włosy',
    '👨‍🦱' => 'muski: kuźerate włosy',
    '👨‍🦳' => 'muski: běłe włosy',
    '👨‍🦲' => 'muski: plěch',
    '👩‍🦰' => 'žeńska: cerwjene włosy',
    '👩‍🦱' => 'žeńska: kuźerate włosy',
    '👩‍🦳' => 'žeńska: běłe włosy',
    '👩‍🦲' => 'žeńska: plěch',
    '🚶‍➡' => 'pěšy duca wósoba: napšawo',
    '🧎‍➡' => 'kólenkujuca wósoba: napšawo',
    '🏃‍➡' => 'ganjajuca wósoba: napšawo',
    '👨‍👦' => 'familija: muski, gólc',
    '👨‍👧' => 'familija: muski, źowćo',
    '👩‍👦' => 'familija: žeńska, gólc',
    '👩‍👧' => 'familija: žeńska, źowćo',
    '😶‍🌫' => 'woblico w mrokawach',
    '😮‍💨' => 'wudychajuce woblico',
    '🙂‍↕' => 'woblico, kenž nyga',
    '😵‍💫' => 'woblico ze špiralojtyma wócyma',
    '❤‍🔥' => 'wutšobka se pali',
    '❤‍🩹' => 'wutšobu gójś',
    '👁‍🗨' => 'wócko w powědańskem puchorje',
    '🧔‍♂' => 'muski: broda',
    '👱‍♂' => 'muski: swětłowłosaty',
    '🧔‍♀' => 'žeńska: broda',
    '👱‍♀' => 'žeńska: swětłowłosata',
    '🙍‍♂' => 'wobuzny muski',
    '🙍‍♀' => 'wobuzna žeńska',
    '🙎‍♂' => 'premplecy muski',
    '🙎‍♀' => 'prempleca žeńska',
    '🙅‍♂' => 'muski z pśekśicnjonyma rukoma',
    '🙅‍♀' => 'žeńska z pśekśicnjonyma rukoma',
    '🙆‍♂' => 'muski z rukoma na głowje',
    '🙆‍♀' => 'žeńska z rukoma na głowje',
    '💁‍♂' => 'muski z dłonju górjej',
    '💁‍♀' => 'žeńska z dłonju górjej',
    '🙋‍♂' => 'muski z pózwignjoneju ruku',
    '🙋‍♀' => 'žeńska z pózwignjoneju ruku',
    '🧏‍♂' => 'njesłyšajucy muski',
    '🧏‍♀' => 'njesłyšajuca žeńska',
    '🙇‍♂' => 'se pókłonjecy muski',
    '🙇‍♀' => 'se pókłonjeca žeńska',
    '🤦‍♂' => 'se za głowu pśimjecy muski',
    '🤦‍♀' => 'se za głowu pśimjeca žeńska',
    '🤷‍♂' => 'z ramjenjoma sukotajucy muski',
    '🤷‍♀' => 'z ramjenjoma sukotajuca žeńska',
    '🧑‍⚕' => 'gójc/gójcowka',
    '👨‍⚕' => 'doktor',
    '👩‍⚕' => 'gójcowka',
    '🧑‍🎓' => 'student(ka)',
    '👨‍🎓' => 'student',
    '👩‍🎓' => 'studentka',
    '🧑‍🏫' => 'wucabnik/wucabnica',
    '👨‍🏫' => 'wucabnik',
    '👩‍🏫' => 'wucabnica',
    '🧑‍⚖' => 'sudnik/sudnica',
    '👨‍⚖' => 'sudnik',
    '👩‍⚖' => 'sudnica',
    '🧑‍🌾' => 'bur/burowka',
    '👨‍🌾' => 'bur',
    '👩‍🌾' => 'burowka',
    '🧑‍🍳' => 'kuchaŕ/kuchaŕka',
    '👨‍🍳' => 'kuchaŕ',
    '👩‍🍳' => 'kuchaŕka',
    '🧑‍🔧' => 'mechanikaŕ',
    '👨‍🔧' => 'muskecy mechanikaŕ/ka',
    '👩‍🔧' => 'mechanikaŕka',
    '🧑‍🏭' => 'źěłaśeŕ',
    '👨‍🏭' => 'fabrikowy źěłaśer',
    '👩‍🏭' => 'fabrikowa źěłaśeŕka',
    '🧑‍💼' => 'w běrowje pśistajona/y',
    '👨‍💼' => 'w běrowje pśistajony',
    '👩‍💼' => 'w běrowje pśistajona',
    '🧑‍🔬' => 'wědomnostnik/ wědomnostnica',
    '👨‍🔬' => 'wědomnostnik',
    '👩‍🔬' => 'wědomnostnica',
    '🧑‍💻' => 'technolog/owka',
    '👨‍💻' => 'technolog',
    '👩‍💻' => 'technologowka',
    '🧑‍🎤' => 'spiwaŕ(ka)',
    '👨‍🎤' => 'spiwaŕ',
    '👩‍🎤' => 'spiwaŕka',
    '🧑‍🎨' => 'wuměłc(owka)',
    '👨‍🎨' => 'wuměłc',
    '👩‍🎨' => 'wuměłcowka',
    '🧑‍✈' => 'pilot(owka)',
    '👨‍✈' => 'pilot',
    '👩‍✈' => 'pilotowka',
    '🧑‍🚀' => 'astronawt(owka)',
    '👨‍🚀' => 'astronawt',
    '👩‍🚀' => 'astronawtowka',
    '🧑‍🚒' => 'wognjowy wobornik / wognjowa wobornica',
    '👨‍🚒' => 'wognjowy wobornik',
    '👩‍🚒' => 'wognjowa wobornica',
    '👮‍♂' => 'policist',
    '👮‍♀' => 'policistaka',
    '🕵‍♂' => 'dedektiw',
    '🕵‍♀' => 'dedektiwka',
    '💂‍♂' => 'stražnik',
    '💂‍♀' => 'stražnica',
    '👷‍♂' => 'twaŕski źěłaśeŕ',
    '👷‍♀' => 'twaŕska źěłaśeŕka',
    '👳‍♂' => 'muski z turbanom',
    '👳‍♀' => 'žeńska z turbanom',
    '🤵‍♂' => 'muski w smokingu',
    '🤵‍♀' => 'žeńska w smokingu I',
    '👰‍♂' => 'muski ze šlewjerjom',
    '👰‍♀' => 'žeńska ze šlewjerjom',
    '👩‍🍼' => 'seśeca žeńska',
    '👨‍🍼' => 'góletkoju mloko dawajucy muski',
    '🧑‍🍼' => 'góletkoju mloko dawajuca wósoba',
    '🧑‍🎄' => 'gódy',
    '🦸‍♂' => 'muskecy superryśaŕ',
    '🦸‍♀' => 'superryśaŕka',
    '🦹‍♂' => 'muskecy supernjeknicomnik',
    '🦹‍♀' => 'supernjeknicomnica',
    '🧙‍♂' => 'muskecy gusłowaŕ',
    '🧙‍♀' => 'magijaŕka',
    '🧚‍♂' => 'muskeca wiła',
    '🧚‍♀' => 'žeńskeca wiła',
    '🧛‍♂' => 'wampir',
    '🧛‍♀' => 'wampirka',
    '🧜‍♂' => 'nykus',
    '🧜‍♀' => 'mórska kněžna',
    '🧝‍♂' => 'muskecy elf',
    '🧝‍♀' => 'žeńskecy elf',
    '🧞‍♂' => 'kuskecy duch z flaše',
    '🧞‍♀' => 'žeńskecy duch z flaše',
    '🧟‍♂' => 'muskecy combie',
    '🧟‍♀' => 'žeńskcy combie',
    '💆‍♂' => 'muski, kenž dostanjo masažu głowy',
    '💆‍♀' => 'žeńska, kenž dostanjo masažu głowy',
    '💇‍♂' => 'muski, kenž dajo se włosy stśigaś',
    '💇‍♀' => 'žeńska , kenž dajo se włosy stśigaś',
    '🚶‍♂' => 'pěškaŕ',
    '🚶‍♀' => 'pěškaŕka',
    '🧍‍♂' => 'stojecy muski',
    '🧍‍♀' => 'stojeca žeńska',
    '🧎‍♂' => 'kólenkujucy muski',
    '🧎‍♀' => 'kólenkujuca žeńska',
    '🧑‍🦯' => 'wósoba z kijom za slěpych',
    '👨‍🦯' => 'muski z kijom za slěpych',
    '👩‍🦯' => 'žeńska z kijom za slěpych',
    '🧑‍🦼' => 'wósoba w elektriskem jězdnem stole',
    '👨‍🦼' => 'muski w elektriskem jězdnem stole',
    '👩‍🦼' => 'žeńska w elektriskem jězdnem stole',
    '🧑‍🦽' => 'wósoba w jězdnem stole',
    '👨‍🦽' => 'muski w jězdnem stole',
    '👩‍🦽' => 'žeńska w jězdnem stole',
    '🏃‍♂' => 'ganjajucy muski',
    '🏃‍♀' => 'ganjajuca žeńska',
    '🧑‍🩰' => 'baletowa rejowaŕka',
    '👯‍♂' => 'muskej z wuchacowyma wušyma',
    '👯‍♀' => 'žeńsce z wuchacowamy wušyma',
    '🧖‍♂' => 'muski w sawnje',
    '🧖‍♀' => 'žeńska w sawnje',
    '🧗‍♂' => 'alpinist',
    '🧗‍♀' => 'alpinistka',
    '🏌‍♂' => 'grajaŕ golfa',
    '🏌‍♀' => 'golfowaŕka',
    '🏄‍♂' => 'surfowaŕ',
    '🏄‍♀' => 'surfowaŕka',
    '🚣‍♂' => 'wjasłowaŕ',
    '🚣‍♀' => 'wjasłowaŕka',
    '🏊‍♂' => 'plěwaŕ',
    '🏊‍♀' => 'plěwaŕka',
    '⛹‍♂' => 'muski z balom',
    '⛹‍♀' => 'žeńska z balom',
    '🏋‍♂' => 'zwigaŕ wažydłow',
    '🏋‍♀' => 'zwigaŕka wažydłow',
    '🚴‍♂' => 'kólasowaŕ',
    '🚴‍♀' => 'kólasowaŕka',
    '🚵‍♂' => 'mountainbikaŕ',
    '🚵‍♀' => 'mountainbikaŕka',
    '🤸‍♂' => 'muski, kenž se na bok pśewjertujo',
    '🤸‍♀' => 'se na bok pśewjertujuca žeńska',
    '🤼‍♂' => 'se běźecej muskej',
    '🤼‍♀' => 'se běźecej žeńsce I',
    '🤽‍♂' => 'grajaŕ wódnego bala',
    '🤽‍♀' => 'grajaŕka wódnego bala',
    '🤾‍♂' => 'chytańcaŕ',
    '🤾‍♀' => 'chytańcaŕka',
    '🤹‍♂' => 'žongler',
    '🤹‍♀' => 'žonglerka',
    '🧘‍♂' => 'muski w lotosowem sejźenju',
    '🧘‍♀' => 'žeńska w lotosowem sejźenju',
    '🧑‍🧒' => 'familija: dorosćony a góle',
    '🐕‍🦺' => 'słužbny pjas',
    '🐈‍⬛' => 'carna kócka',
    '🐻‍❄' => 'běły mjadwjeź',
    '🐦‍⬛' => 'carny ptašk',
    '🐦‍🔥' => 'feniks',
    '🍋‍🟩' => 'limona',
    '🍄‍🟫' => 'bruny grib',
    '⛓‍💥' => 'roztergnjony rjeśaz',
    '🏳‍🌈' => 'tycaty chórgoj',
    '🏳‍⚧' => 'transgenderowa chórgoj',
    '🏴‍☠' => 'piratowa chórgoj',
    '👋🏻' => 'kiwajuca ruka: swětła barwa kóže',
    '👋🏼' => 'kiwajuca ruka: srjejźnoswětła barwa kóže',
    '👋🏽' => 'kiwajuca ruka: wósrědna barwa kóže',
    '👋🏾' => 'kiwajuca ruka: srjejźnośamna barwa kóže',
    '👋🏿' => 'kiwajuca ruka: śamna barwa kóže',
    '🤚🏻' => 'pózwignjona ruka wót slědka: swětła barwa kóže',
    '🤚🏼' => 'pózwignjona ruka wót slědka: srjejźnoswětła barwa kóže',
    '🤚🏽' => 'pózwignjona ruka wót slědka: wósrědna barwa kóže',
    '🤚🏾' => 'pózwignjona ruka wót slědka: srjejźnośamna barwa kóže',
    '🤚🏿' => 'pózwignjona ruka wót slědka: śamna barwa kóže',
    '🖐🏻' => 'ruka z rozpśestrětymi palcami: swětła barwa kóže',
    '🖐🏼' => 'ruka z rozpśestrětymi palcami: srjejźnoswětła barwa kóže',
    '🖐🏽' => 'ruka z rozpśestrětymi palcami: wósrědna barwa kóže',
    '🖐🏾' => 'ruka z rozpśestrětymi palcami: srjejźnośamna barwa kóže',
    '🖐🏿' => 'ruka z rozpśestrětymi palcami: śamna barwa kóže',
    '✋🏻' => 'pózwignjona ruka: swětła barwa kóže',
    '✋🏼' => 'pózwignjona ruka: srjejźnoswětła barwa kóže',
    '✋🏽' => 'pózwignjona ruka: wósrědna barwa kóže',
    '✋🏾' => 'pózwignjona ruka: srjejźnośamna barwa kóže',
    '✋🏿' => 'pózwignjona ruka: śamna barwa kóže',
    '🖖🏻' => 'wulkaniske póstrowjenje: swětła barwa kóže',
    '🖖🏼' => 'wulkaniske póstrowjenje: srjejźnoswětła barwa kóže',
    '🖖🏽' => 'wulkaniske póstrowjenje: wósrědna barwa kóže',
    '🖖🏾' => 'wulkaniske póstrowjenje: srjejźnośamna barwa kóže',
    '🖖🏿' => 'wulkaniske póstrowjenje: śamna barwa kóže',
    '🫱🏻' => 'ruka napšawo: swětła barwa kóže',
    '🫱🏼' => 'ruka napšawo: srjejźnoswětła barwa kóže',
    '🫱🏽' => 'ruka napšawo: wósrědna barwa kóže',
    '🫱🏾' => 'ruka napšawo: srjejźnośamna barwa kóže',
    '🫱🏿' => 'ruka napšawo: śamna barwa kóže',
    '🫲🏻' => 'ruka nalěwo: swětła barwa kóže',
    '🫲🏼' => 'ruka nalěwo: srjejźnoswětła barwa kóže',
    '🫲🏽' => 'ruka nalěwo: wósrědna barwa kóže',
    '🫲🏾' => 'ruka nalěwo: srjejźnośamna barwa kóže',
    '🫲🏿' => 'ruka nalěwo: śamna barwa kóže',
    '🫳🏻' => 'dłoń pokazujo dołoj: swětła barwa kóže',
    '🫳🏼' => 'dłoń pokazujo dołoj: srjejźnoswětła barwa kóže',
    '🫳🏽' => 'dłoń pokazujo dołoj: wósrědna barwa kóže',
    '🫳🏾' => 'dłoń pokazujo dołoj: srjejźnośamna barwa kóže',
    '🫳🏿' => 'dłoń pokazujo dołoj: śamna barwa kóže',
    '🫴🏻' => 'dłoń pokazujo górjej: swětła barwa kóže',
    '🫴🏼' => 'dłoń pokazujo górjej: srjejźnoswětła barwa kóže',
    '🫴🏽' => 'dłoń pokazujo górjej: wósrědna barwa kóže',
    '🫴🏾' => 'dłoń pokazujo górjej: srjejźnośamna barwa kóže',
    '🫴🏿' => 'dłoń pokazujo górjej: śamna barwa kóže',
    '🫷🏻' => 'ruka, ak tłocy nalěwo: swětła barwa kóže',
    '🫷🏼' => 'ruka, ak tłocy nalěwo: srjejźnoswětła barwa kóže',
    '🫷🏽' => 'ruka, ak tłocy nalěwo: wósrědna barwa kóže',
    '🫷🏾' => 'ruka, ak tłocy nalěwo: srjejźnośamna barwa kóže',
    '🫷🏿' => 'ruka, ak tłocy nalěwo: śamna barwa kóže',
    '🫸🏻' => 'ruka, ak tłocy napšawo: swětła barwa kóže',
    '🫸🏼' => 'ruka, ak tłocy napšawo: srjejźnoswětła barwa kóže',
    '🫸🏽' => 'ruka, ak tłocy napšawo: wósrědna barwa kóže',
    '🫸🏾' => 'ruka, ak tłocy napšawo: srjejźnośamna barwa kóže',
    '🫸🏿' => 'ruka, ak tłocy napšawo: śamna barwa kóže',
    '👌🏻' => 'ok-gesta: swětła barwa kóže',
    '👌🏼' => 'ok-gesta: srjejźnoswětła barwa kóže',
    '👌🏽' => 'ok-gesta: wósrědna barwa kóže',
    '👌🏾' => 'ok-gesta: srjejźnośamna barwa kóže',
    '👌🏿' => 'ok-gesta: śamna barwa kóže',
    '🤌🏻' => 'gromadu stłocone palce: swětła barwa kóže',
    '🤌🏼' => 'gromadu stłocone palce: srjejźnoswětła barwa kóže',
    '🤌🏽' => 'gromadu stłocone palce: wósrědna barwa kóže',
    '🤌🏾' => 'gromadu stłocone palce: srjejźnośamna barwa kóže',
    '🤌🏿' => 'gromadu stłocone palce: śamna barwa kóže',
    '🤏🏻' => 'mało-gesta: swětła barwa kóže',
    '🤏🏼' => 'mało-gesta: srjejźnoswětła barwa kóže',
    '🤏🏽' => 'mało-gesta: wósrědna barwa kóže',
    '🤏🏾' => 'mało-gesta: srjejźnośamna barwa kóže',
    '🤏🏿' => 'mało-gesta: śamna barwa kóže',
    '✌🏻' => 'dobyśaŕska gesta: swětła barwa kóže',
    '✌🏼' => 'dobyśaŕska gesta: srjejźnoswětła barwa kóže',
    '✌🏽' => 'dobyśaŕska gesta: wósrědna barwa kóže',
    '✌🏾' => 'dobyśaŕska gesta: srjejźnośamna barwa kóže',
    '✌🏿' => 'dobyśaŕska gesta: śamna barwa kóže',
    '🤞🏻' => 'ruka z pśekśicnjonyma palcoma: swětła barwa kóže',
    '🤞🏼' => 'ruka z pśekśicnjonyma palcoma: srjejźnoswětła barwa kóže',
    '🤞🏽' => 'ruka z pśekśicnjonyma palcoma: wósrědna barwa kóže',
    '🤞🏾' => 'ruka z pśekśicnjonyma palcoma: srjejźnośamna barwa kóže',
    '🤞🏿' => 'ruka z pśekśicnjonyma palcoma: śamna barwa kóže',
    '🫰🏻' => 'ruka, z pśekśicowanym pokazowarjom a palcom: swětła barwa kóže',
    '🫰🏼' => 'ruka, z pśekśicowanym pokazowarjom a palcom: srjejźnoswětła barwa kóže',
    '🫰🏽' => 'ruka, z pśekśicowanym pokazowarjom a palcom: wósrědna barwa kóže',
    '🫰🏾' => 'ruka, z pśekśicowanym pokazowarjom a palcom: srjejźnośamna barwa kóže',
    '🫰🏿' => 'ruka, z pśekśicowanym pokazowarjom a palcom: śamna barwa kóže',
    '🤟🏻' => 'gesta "ja śi lubujom": swětła barwa kóže',
    '🤟🏼' => 'gesta "ja śi lubujom": srjejźnoswětła barwa kóže',
    '🤟🏽' => 'gesta "ja śi lubujom": wósrědna barwa kóže',
    '🤟🏾' => 'gesta "ja śi lubujom": srjejźnośamna barwa kóže',
    '🤟🏿' => 'gesta "ja śi lubujom": śamna barwa kóže',
    '🤘🏻' => 'cartowe póstrowjenje: swětła barwa kóže',
    '🤘🏼' => 'cartowe póstrowjenje: srjejźnoswětła barwa kóže',
    '🤘🏽' => 'cartowe póstrowjenje: wósrědna barwa kóže',
    '🤘🏾' => 'cartowe póstrowjenje: srjejźnośamna barwa kóže',
    '🤘🏿' => 'cartowe póstrowjenje: śamna barwa kóže',
    '🤙🏻' => 'gesta "zawołaj na mnjo": swětła barwa kóže',
    '🤙🏼' => 'gesta "zawołaj na mnjo": srjejźnoswětła barwa kóže',
    '🤙🏽' => 'gesta "zawołaj na mnjo": wósrědna barwa kóže',
    '🤙🏾' => 'gesta "zawołaj na mnjo": srjejźnośamna barwa kóže',
    '🤙🏿' => 'gesta "zawołaj na mnjo": śamna barwa kóže',
    '👈🏻' => 'nalěwo pokazujucy drugi palc: swětła barwa kóže',
    '👈🏼' => 'nalěwo pokazujucy drugi palc: srjejźnoswětła barwa kóže',
    '👈🏽' => 'nalěwo pokazujucy drugi palc: wósrědna barwa kóže',
    '👈🏾' => 'nalěwo pokazujucy drugi palc: srjejźnośamna barwa kóže',
    '👈🏿' => 'nalěwo pokazujucy drugi palc: śamna barwa kóže',
    '👉🏻' => 'napšawo pokazujucy drugii palc: swětła barwa kóže',
    '👉🏼' => 'napšawo pokazujucy drugii palc: srjejźnoswětła barwa kóže',
    '👉🏽' => 'napšawo pokazujucy drugii palc: wósrědna barwa kóže',
    '👉🏾' => 'napšawo pokazujucy drugii palc: srjejźnośamna barwa kóže',
    '👉🏿' => 'napšawo pokazujucy drugii palc: śamna barwa kóže',
    '👆🏻' => 'górjej pokazujucy drugi palc wót slědka: swětła barwa kóže',
    '👆🏼' => 'górjej pokazujucy drugi palc wót slědka: srjejźnoswětła barwa kóže',
    '👆🏽' => 'górjej pokazujucy drugi palc wót slědka: wósrědna barwa kóže',
    '👆🏾' => 'górjej pokazujucy drugi palc wót slědka: srjejźnośamna barwa kóže',
    '👆🏿' => 'górjej pokazujucy drugi palc wót slědka: śamna barwa kóže',
    '🖕🏻' => 'wósrědny palc: swětła barwa kóže',
    '🖕🏼' => 'wósrědny palc: srjejźnoswětła barwa kóže',
    '🖕🏽' => 'wósrědny palc: wósrědna barwa kóže',
    '🖕🏾' => 'wósrědny palc: srjejźnośamna barwa kóže',
    '🖕🏿' => 'wósrědny palc: śamna barwa kóže',
    '👇🏻' => 'dołoj pokazujucy drugi palc: swětła barwa kóže',
    '👇🏼' => 'dołoj pokazujucy drugi palc: srjejźnoswětła barwa kóže',
    '👇🏽' => 'dołoj pokazujucy drugi palc: wósrědna barwa kóže',
    '👇🏾' => 'dołoj pokazujucy drugi palc: srjejźnośamna barwa kóže',
    '👇🏿' => 'dołoj pokazujucy drugi palc: śamna barwa kóže',
    '☝🏻' => 'górjej pokazujucy drugi palc wót prědka: swětła barwa kóže',
    '☝🏼' => 'górjej pokazujucy drugi palc wót prědka: srjejźnoswětła barwa kóže',
    '☝🏽' => 'górjej pokazujucy drugi palc wót prědka: wósrědna barwa kóže',
    '☝🏾' => 'górjej pokazujucy drugi palc wót prědka: srjejźnośamna barwa kóže',
    '☝🏿' => 'górjej pokazujucy drugi palc wót prědka: śamna barwa kóže',
    '🫵🏻' => 'pokazowaŕ, wusměrjony na glědajucego: swětła barwa kóže',
    '🫵🏼' => 'pokazowaŕ, wusměrjony na glědajucego: srjejźnoswětła barwa kóže',
    '🫵🏽' => 'pokazowaŕ, wusměrjony na glědajucego: wósrědna barwa kóže',
    '🫵🏾' => 'pokazowaŕ, wusměrjony na glědajucego: srjejźnośamna barwa kóže',
    '🫵🏿' => 'pokazowaŕ, wusměrjony na glědajucego: śamna barwa kóže',
    '👍🏻' => 'tłusty palc górjej: swětła barwa kóže',
    '👍🏼' => 'tłusty palc górjej: srjejźnoswětła barwa kóže',
    '👍🏽' => 'tłusty palc górjej: wósrědna barwa kóže',
    '👍🏾' => 'tłusty palc górjej: srjejźnośamna barwa kóže',
    '👍🏿' => 'tłusty palc górjej: śamna barwa kóže',
    '👎🏻' => 'tłusty palc dołoj: swětła barwa kóže',
    '👎🏼' => 'tłusty palc dołoj: srjejźnoswětła barwa kóže',
    '👎🏽' => 'tłusty palc dołoj: wósrědna barwa kóže',
    '👎🏾' => 'tłusty palc dołoj: srjejźnośamna barwa kóže',
    '👎🏿' => 'tłusty palc dołoj: śamna barwa kóže',
    '✊🏻' => 'pózwignjona pěsć: swětła barwa kóže',
    '✊🏼' => 'pózwignjona pěsć: srjejźnoswětła barwa kóže',
    '✊🏽' => 'pózwignjona pěsć: wósrědna barwa kóže',
    '✊🏾' => 'pózwignjona pěsć: srjejźnośamna barwa kóže',
    '✊🏿' => 'pózwignjona pěsć: śamna barwa kóže',
    '👊🏻' => 'zamknjona pěsć: swětła barwa kóže',
    '👊🏼' => 'zamknjona pěsć: srjejźnoswětła barwa kóže',
    '👊🏽' => 'zamknjona pěsć: wósrědna barwa kóže',
    '👊🏾' => 'zamknjona pěsć: srjejźnośamna barwa kóže',
    '👊🏿' => 'zamknjona pěsć: śamna barwa kóže',
    '🤛🏻' => 'pěsć nalěwo: swětła barwa kóže',
    '🤛🏼' => 'pěsć nalěwo: srjejźnoswětła barwa kóže',
    '🤛🏽' => 'pěsć nalěwo: wósrědna barwa kóže',
    '🤛🏾' => 'pěsć nalěwo: srjejźnośamna barwa kóže',
    '🤛🏿' => 'pěsć nalěwo: śamna barwa kóže',
    '🤜🏻' => 'pěsć napšawo: swětła barwa kóže',
    '🤜🏼' => 'pěsć napšawo: srjejźnoswětła barwa kóže',
    '🤜🏽' => 'pěsć napšawo: wósrědna barwa kóže',
    '🤜🏾' => 'pěsć napšawo: srjejźnośamna barwa kóže',
    '🤜🏿' => 'pěsć napšawo: śamna barwa kóže',
    '👏🏻' => 'pśiklaskujuce ruki: swětła barwa kóže',
    '👏🏼' => 'pśiklaskujuce ruki: srjejźnoswětła barwa kóže',
    '👏🏽' => 'pśiklaskujuce ruki: wósrědna barwa kóže',
    '👏🏾' => 'pśiklaskujuce ruki: srjejźnośamna barwa kóže',
    '👏🏿' => 'pśiklaskujuce ruki: śamna barwa kóže',
    '🙌🏻' => 'pózwignjonej ruce: swětła barwa kóže',
    '🙌🏼' => 'pózwignjonej ruce: srjejźnoswětła barwa kóže',
    '🙌🏽' => 'pózwignjonej ruce: wósrědna barwa kóže',
    '🙌🏾' => 'pózwignjonej ruce: srjejźnośamna barwa kóže',
    '🙌🏿' => 'pózwignjonej ruce: śamna barwa kóže',
    '🫶🏻' => 'ruce twóritej formu wutšoby: swětła barwa kóže',
    '🫶🏼' => 'ruce twóritej formu wutšoby: srjejźnoswětła barwa kóže',
    '🫶🏽' => 'ruce twóritej formu wutšoby: wósrědna barwa kóže',
    '🫶🏾' => 'ruce twóritej formu wutšoby: srjejźnośamna barwa kóže',
    '🫶🏿' => 'ruce twóritej formu wutšoby: śamna barwa kóže',
    '👐🏻' => 'wótwórjonej ruce: swětła barwa kóže',
    '👐🏼' => 'wótwórjonej ruce: srjejźnoswětła barwa kóže',
    '👐🏽' => 'wótwórjonej ruce: wósrědna barwa kóže',
    '👐🏾' => 'wótwórjonej ruce: srjejźnośamna barwa kóže',
    '👐🏿' => 'wótwórjonej ruce: śamna barwa kóže',
    '🤲🏻' => 'dłoni górjej: swětła barwa kóže',
    '🤲🏼' => 'dłoni górjej: srjejźnoswětła barwa kóže',
    '🤲🏽' => 'dłoni górjej: wósrědna barwa kóže',
    '🤲🏾' => 'dłoni górjej: srjejźnośamna barwa kóže',
    '🤲🏿' => 'dłoni górjej: śamna barwa kóže',
    '🤝🏻' => 'pódaśe ruki: swětła barwa kóže',
    '🤝🏼' => 'pódaśe ruki: srjejźnoswětła barwa kóže',
    '🤝🏽' => 'pódaśe ruki: wósrědna barwa kóže',
    '🤝🏾' => 'pódaśe ruki: srjejźnośamna barwa kóže',
    '🤝🏿' => 'pódaśe ruki: śamna barwa kóže',
    '🙏🏻' => 'bjatujuce ruki: swětła barwa kóže',
    '🙏🏼' => 'bjatujuce ruki: srjejźnoswětła barwa kóže',
    '🙏🏽' => 'bjatujuce ruki: wósrědna barwa kóže',
    '🙏🏾' => 'bjatujuce ruki: srjejźnośamna barwa kóže',
    '🙏🏿' => 'bjatujuce ruki: śamna barwa kóže',
    '✍🏻' => 'pišuca ruka: swětła barwa kóže',
    '✍🏼' => 'pišuca ruka: srjejźnoswětła barwa kóže',
    '✍🏽' => 'pišuca ruka: wósrědna barwa kóže',
    '✍🏾' => 'pišuca ruka: srjejźnośamna barwa kóže',
    '✍🏿' => 'pišuca ruka: śamna barwa kóže',
    '💅🏻' => 'nokśowy lak: swětła barwa kóže',
    '💅🏼' => 'nokśowy lak: srjejźnoswětła barwa kóže',
    '💅🏽' => 'nokśowy lak: wósrědna barwa kóže',
    '💅🏾' => 'nokśowy lak: srjejźnośamna barwa kóže',
    '💅🏿' => 'nokśowy lak: śamna barwa kóže',
    '🤳🏻' => 'selfie: swětła barwa kóže',
    '🤳🏼' => 'selfie: srjejźnoswětła barwa kóže',
    '🤳🏽' => 'selfie: wósrědna barwa kóže',
    '🤳🏾' => 'selfie: srjejźnośamna barwa kóže',
    '🤳🏿' => 'selfie: śamna barwa kóže',
    '💪🏻' => 'napněty biceps: swětła barwa kóže',
    '💪🏼' => 'napněty biceps: srjejźnoswětła barwa kóže',
    '💪🏽' => 'napněty biceps: wósrědna barwa kóže',
    '💪🏾' => 'napněty biceps: srjejźnośamna barwa kóže',
    '💪🏿' => 'napněty biceps: śamna barwa kóže',
    '🦵🏻' => 'ceła noga: swětła barwa kóže',
    '🦵🏼' => 'ceła noga: srjejźnoswětła barwa kóže',
    '🦵🏽' => 'ceła noga: wósrědna barwa kóže',
    '🦵🏾' => 'ceła noga: srjejźnośamna barwa kóže',
    '🦵🏿' => 'ceła noga: śamna barwa kóže',
    '🦶🏻' => 'spódna noga: swětła barwa kóže',
    '🦶🏼' => 'spódna noga: srjejźnoswětła barwa kóže',
    '🦶🏽' => 'spódna noga: wósrědna barwa kóže',
    '🦶🏾' => 'spódna noga: srjejźnośamna barwa kóže',
    '🦶🏿' => 'spódna noga: śamna barwa kóže',
    '👂🏻' => 'wucho: swětła barwa kóže',
    '👂🏼' => 'wucho: srjejźnoswětła barwa kóže',
    '👂🏽' => 'wucho: wósrědna barwa kóže',
    '👂🏾' => 'wucho: srjejźnośamna barwa kóže',
    '👂🏿' => 'wucho: śamna barwa kóže',
    '🦻🏻' => 'wucho ze słušańskeju pomocu: swětła barwa kóže',
    '🦻🏼' => 'wucho ze słušańskeju pomocu: srjejźnoswětła barwa kóže',
    '🦻🏽' => 'wucho ze słušańskeju pomocu: wósrědna barwa kóže',
    '🦻🏾' => 'wucho ze słušańskeju pomocu: srjejźnośamna barwa kóže',
    '🦻🏿' => 'wucho ze słušańskeju pomocu: śamna barwa kóže',
    '👃🏻' => 'nos: swětła barwa kóže',
    '👃🏼' => 'nos: srjejźnoswětła barwa kóže',
    '👃🏽' => 'nos: wósrědna barwa kóže',
    '👃🏾' => 'nos: srjejźnośamna barwa kóže',
    '👃🏿' => 'nos: śamna barwa kóže',
    '👶🏻' => 'góletko: swětła barwa kóže',
    '👶🏼' => 'góletko: srjejźnoswětła barwa kóže',
    '👶🏽' => 'góletko: wósrědna barwa kóže',
    '👶🏾' => 'góletko: srjejźnośamna barwa kóže',
    '👶🏿' => 'góletko: śamna barwa kóže',
    '🧒🏻' => 'góle: swětła barwa kóže',
    '🧒🏼' => 'góle: srjejźnoswětła barwa kóže',
    '🧒🏽' => 'góle: wósrědna barwa kóže',
    '🧒🏾' => 'góle: srjejźnośamna barwa kóže',
    '🧒🏿' => 'góle: śamna barwa kóže',
    '👦🏻' => 'gólc: swětła barwa kóže',
    '👦🏼' => 'gólc: srjejźnoswětła barwa kóže',
    '👦🏽' => 'gólc: wósrědna barwa kóže',
    '👦🏾' => 'gólc: srjejźnośamna barwa kóže',
    '👦🏿' => 'gólc: śamna barwa kóže',
    '👧🏻' => 'źowćo: swětła barwa kóže',
    '👧🏼' => 'źowćo: srjejźnoswětła barwa kóže',
    '👧🏽' => 'źowćo: wósrědna barwa kóže',
    '👧🏾' => 'źowćo: srjejźnośamna barwa kóže',
    '👧🏿' => 'źowćo: śamna barwa kóže',
    '🧑🏻' => 'dorosćony: swětła barwa kóže',
    '🧑🏼' => 'dorosćony: srjejźnoswětła barwa kóže',
    '🧑🏽' => 'dorosćony: wósrědna barwa kóže',
    '🧑🏾' => 'dorosćony: srjejźnośamna barwa kóže',
    '🧑🏿' => 'dorosćony: śamna barwa kóže',
    '👱🏻' => 'wósoba: swětła barwa kóže, swětłe włosy',
    '👱🏼' => 'wósoba: srjejźnoswětła barwa kóže, swětłe włosy',
    '👱🏽' => 'wósoba: wósrědna barwa kóže, swětłe włosy',
    '👱🏾' => 'wósoba: srjejźnośamna barwa kóže, swětłe włosy',
    '👱🏿' => 'wósoba: śamna barwa kóže, swětłe włosy',
    '👨🏻' => 'muski: swětła barwa kóže',
    '👨🏼' => 'muski: srjejźnoswětła barwa kóže',
    '👨🏽' => 'muski: wósrědna barwa kóže',
    '👨🏾' => 'muski: srjejźnośamna barwa kóže',
    '👨🏿' => 'muski: śamna barwa kóže',
    '🧔🏻' => 'wósoba: swětła barwa kóže, broda',
    '🧔🏼' => 'wósoba: srjejźnoswětła barwa kóže, broda',
    '🧔🏽' => 'wósoba: wósrědna barwa kóže, broda',
    '🧔🏾' => 'wósoba: srjejźnośamna barwa kóže, broda',
    '🧔🏿' => 'wósoba: śamna barwa kóže, broda',
    '👩🏻' => 'žeńska: swětła barwa kóže',
    '👩🏼' => 'žeńska: srjejźnoswětła barwa kóže',
    '👩🏽' => 'žeńska: wósrědna barwa kóže',
    '👩🏾' => 'žeńska: srjejźnośamna barwa kóže',
    '👩🏿' => 'žeńska: śamna barwa kóže',
    '🧓🏻' => 'starša wósoba: swětła barwa kóže',
    '🧓🏼' => 'starša wósoba: srjejźnoswětła barwa kóže',
    '🧓🏽' => 'starša wósoba: wósrědna barwa kóže',
    '🧓🏾' => 'starša wósoba: srjejźnośamna barwa kóže',
    '🧓🏿' => 'starša wósoba: śamna barwa kóže',
    '👴🏻' => 'staršy muski: swětła barwa kóže',
    '👴🏼' => 'staršy muski: srjejźnoswětła barwa kóže',
    '👴🏽' => 'staršy muski: wósrědna barwa kóže',
    '👴🏾' => 'staršy muski: srjejźnośamna barwa kóže',
    '👴🏿' => 'staršy muski: śamna barwa kóže',
    '👵🏻' => 'starša žeńska: swětła barwa kóže',
    '👵🏼' => 'starša žeńska: srjejźnoswětła barwa kóže',
    '👵🏽' => 'starša žeńska: wósrědna barwa kóže',
    '👵🏾' => 'starša žeńska: srjejźnośamna barwa kóže',
    '👵🏿' => 'starša žeńska: śamna barwa kóže',
    '🙍🏻' => 'wobuzna wósoba: swětła barwa kóže',
    '🙍🏼' => 'wobuzna wósoba: srjejźnoswětła barwa kóže',
    '🙍🏽' => 'wobuzna wósoba: wósrědna barwa kóže',
    '🙍🏾' => 'wobuzna wósoba: srjejźnośamna barwa kóže',
    '🙍🏿' => 'wobuzna wósoba: śamna barwa kóže',
    '🙎🏻' => 'prempleca wósoba: swětła barwa kóže',
    '🙎🏼' => 'prempleca wósoba: srjejźnoswětła barwa kóže',
    '🙎🏽' => 'prempleca wósoba: wósrědna barwa kóže',
    '🙎🏾' => 'prempleca wósoba: srjejźnośamna barwa kóže',
    '🙎🏿' => 'prempleca wósoba: śamna barwa kóže',
    '🙅🏻' => 'wósoba z pśekśicnjonyma rukoma: swětła barwa kóže',
    '🙅🏼' => 'wósoba z pśekśicnjonyma rukoma: srjejźnoswětła barwa kóže',
    '🙅🏽' => 'wósoba z pśekśicnjonyma rukoma: wósrědna barwa kóže',
    '🙅🏾' => 'wósoba z pśekśicnjonyma rukoma: srjejźnośamna barwa kóže',
    '🙅🏿' => 'wósoba z pśekśicnjonyma rukoma: śamna barwa kóže',
    '🙆🏻' => 'wósoba z rukoma na głowje: swětła barwa kóže',
    '🙆🏼' => 'wósoba z rukoma na głowje: srjejźnoswětła barwa kóže',
    '🙆🏽' => 'wósoba z rukoma na głowje: wósrědna barwa kóže',
    '🙆🏾' => 'wósoba z rukoma na głowje: srjejźnośamna barwa kóže',
    '🙆🏿' => 'wósoba z rukoma na głowje: śamna barwa kóže',
    '💁🏻' => 'wósoba z dłonju górjej: swětła barwa kóže',
    '💁🏼' => 'wósoba z dłonju górjej: srjejźnoswětła barwa kóže',
    '💁🏽' => 'wósoba z dłonju górjej: wósrědna barwa kóže',
    '💁🏾' => 'wósoba z dłonju górjej: srjejźnośamna barwa kóže',
    '💁🏿' => 'wósoba z dłonju górjej: śamna barwa kóže',
    '🙋🏻' => 'wósoba z pózwignjoneju ruku: swětła barwa kóže',
    '🙋🏼' => 'wósoba z pózwignjoneju ruku: srjejźnoswětła barwa kóže',
    '🙋🏽' => 'wósoba z pózwignjoneju ruku: wósrědna barwa kóže',
    '🙋🏾' => 'wósoba z pózwignjoneju ruku: srjejźnośamna barwa kóže',
    '🙋🏿' => 'wósoba z pózwignjoneju ruku: śamna barwa kóže',
    '🧏🏻' => 'njesłyšajuca wósoba: swětła barwa kóže',
    '🧏🏼' => 'njesłyšajuca wósoba: srjejźnoswětła barwa kóže',
    '🧏🏽' => 'njesłyšajuca wósoba: wósrědna barwa kóže',
    '🧏🏾' => 'njesłyšajuca wósoba: srjejźnośamna barwa kóže',
    '🧏🏿' => 'njesłyšajuca wósoba: śamna barwa kóže',
    '🙇🏻' => 'se pókłonjeca wósoba: swětła barwa kóže',
    '🙇🏼' => 'se pókłonjeca wósoba: srjejźnoswětła barwa kóže',
    '🙇🏽' => 'se pókłonjeca wósoba: wósrědna barwa kóže',
    '🙇🏾' => 'se pókłonjeca wósoba: srjejźnośamna barwa kóže',
    '🙇🏿' => 'se pókłonjeca wósoba: śamna barwa kóže',
    '🤦🏻' => 'se za głowu pśimjeca wósoba: swětła barwa kóže',
    '🤦🏼' => 'se za głowu pśimjeca wósoba: srjejźnoswětła barwa kóže',
    '🤦🏽' => 'se za głowu pśimjeca wósoba: wósrědna barwa kóže',
    '🤦🏾' => 'se za głowu pśimjeca wósoba: srjejźnośamna barwa kóže',
    '🤦🏿' => 'se za głowu pśimjeca wósoba: śamna barwa kóže',
    '🤷🏻' => 'z ramjenjoma sukotajuca wósoba: swětła barwa kóže',
    '🤷🏼' => 'z ramjenjoma sukotajuca wósoba: srjejźnoswětła barwa kóže',
    '🤷🏽' => 'z ramjenjoma sukotajuca wósoba: wósrědna barwa kóže',
    '🤷🏾' => 'z ramjenjoma sukotajuca wósoba: srjejźnośamna barwa kóže',
    '🤷🏿' => 'z ramjenjoma sukotajuca wósoba: śamna barwa kóže',
    '👮🏻' => 'policist/ka: swětła barwa kóže',
    '👮🏼' => 'policist/ka: srjejźnoswětła barwa kóže',
    '👮🏽' => 'policist/ka: wósrědna barwa kóže',
    '👮🏾' => 'policist/ka: srjejźnośamna barwa kóže',
    '👮🏿' => 'policist/ka: śamna barwa kóže',
    '🕵🏻' => 'dedektiw/ka: swětła barwa kóže',
    '🕵🏼' => 'dedektiw/ka: srjejźnoswětła barwa kóže',
    '🕵🏽' => 'dedektiw/ka: wósrědna barwa kóže',
    '🕵🏾' => 'dedektiw/ka: srjejźnośamna barwa kóže',
    '🕵🏿' => 'dedektiw/ka: śamna barwa kóže',
    '💂🏻' => 'stražnik/stražnica: swětła barwa kóže',
    '💂🏼' => 'stražnik/stražnica: srjejźnoswětła barwa kóže',
    '💂🏽' => 'stražnik/stražnica: wósrědna barwa kóže',
    '💂🏾' => 'stražnik/stražnica: srjejźnośamna barwa kóže',
    '💂🏿' => 'stražnik/stražnica: śamna barwa kóže',
    '🥷🏻' => 'ninja: swětła barwa kóže',
    '🥷🏼' => 'ninja: srjejźnoswětła barwa kóže',
    '🥷🏽' => 'ninja: wósrědna barwa kóže',
    '🥷🏾' => 'ninja: srjejźnośamna barwa kóže',
    '🥷🏿' => 'ninja: śamna barwa kóže',
    '👷🏻' => 'twaŕski źěłaśeŕ/ka: swětła barwa kóže',
    '👷🏼' => 'twaŕski źěłaśeŕ/ka: srjejźnoswětła barwa kóže',
    '👷🏽' => 'twaŕski źěłaśeŕ/ka: wósrědna barwa kóže',
    '👷🏾' => 'twaŕski źěłaśeŕ/ka: srjejźnośamna barwa kóže',
    '👷🏿' => 'twaŕski źěłaśeŕ/ka: śamna barwa kóže',
    '🫅🏻' => 'wósoba z kronu: swětła barwa kóže',
    '🫅🏼' => 'wósoba z kronu: srjejźnoswětła barwa kóže',
    '🫅🏽' => 'wósoba z kronu: wósrědna barwa kóže',
    '🫅🏾' => 'wósoba z kronu: srjejźnośamna barwa kóže',
    '🫅🏿' => 'wósoba z kronu: śamna barwa kóže',
    '🤴🏻' => 'princ: swětła barwa kóže',
    '🤴🏼' => 'princ: srjejźnoswětła barwa kóže',
    '🤴🏽' => 'princ: wósrědna barwa kóže',
    '🤴🏾' => 'princ: srjejźnośamna barwa kóže',
    '🤴🏿' => 'princ: śamna barwa kóže',
    '👸🏻' => 'princesna: swětła barwa kóže',
    '👸🏼' => 'princesna: srjejźnoswětła barwa kóže',
    '👸🏽' => 'princesna: wósrědna barwa kóže',
    '👸🏾' => 'princesna: srjejźnośamna barwa kóže',
    '👸🏿' => 'princesna: śamna barwa kóže',
    '👳🏻' => 'wósoba z turbanom: swětła barwa kóže',
    '👳🏼' => 'wósoba z turbanom: srjejźnoswětła barwa kóže',
    '👳🏽' => 'wósoba z turbanom: wósrědna barwa kóže',
    '👳🏾' => 'wósoba z turbanom: srjejźnośamna barwa kóže',
    '👳🏿' => 'wósoba z turbanom: śamna barwa kóže',
    '👲🏻' => 'muski z chinskeju šapku: swětła barwa kóže',
    '👲🏼' => 'muski z chinskeju šapku: srjejźnoswětła barwa kóže',
    '👲🏽' => 'muski z chinskeju šapku: wósrědna barwa kóže',
    '👲🏾' => 'muski z chinskeju šapku: srjejźnośamna barwa kóže',
    '👲🏿' => 'muski z chinskeju šapku: śamna barwa kóže',
    '🧕🏻' => 'žeńska z lapu: swětła barwa kóže',
    '🧕🏼' => 'žeńska z lapu: srjejźnoswětła barwa kóže',
    '🧕🏽' => 'žeńska z lapu: wósrědna barwa kóže',
    '🧕🏾' => 'žeńska z lapu: srjejźnośamna barwa kóže',
    '🧕🏿' => 'žeńska z lapu: śamna barwa kóže',
    '🤵🏻' => 'wósoba w smokingu: swětła barwa kóže',
    '🤵🏼' => 'wósoba w smokingu: srjejźnoswětła barwa kóže',
    '🤵🏽' => 'wósoba w smokingu: wósrědna barwa kóže',
    '🤵🏾' => 'wósoba w smokingu: srjejźnośamna barwa kóže',
    '🤵🏿' => 'wósoba w smokingu: śamna barwa kóže',
    '👰🏻' => 'wósoba ze šlewjerjom: swětła barwa kóže',
    '👰🏼' => 'wósoba ze šlewjerjom: srjejźnoswětła barwa kóže',
    '👰🏽' => 'wósoba ze šlewjerjom: wósrědna barwa kóže',
    '👰🏾' => 'wósoba ze šlewjerjom: srjejźnośamna barwa kóže',
    '👰🏿' => 'wósoba ze šlewjerjom: śamna barwa kóže',
    '🤰🏻' => 'samodruga: swětła barwa kóže',
    '🤰🏼' => 'samodruga: srjejźnoswětła barwa kóže',
    '🤰🏽' => 'samodruga: wósrědna barwa kóže',
    '🤰🏾' => 'samodruga: srjejźnośamna barwa kóže',
    '🤰🏿' => 'samodruga: śamna barwa kóže',
    '🫃🏻' => 'samodrugi muski: swětła barwa kóže',
    '🫃🏼' => 'samodrugi muski: srjejźnoswětła barwa kóže',
    '🫃🏽' => 'samodrugi muski: wósrědna barwa kóže',
    '🫃🏾' => 'samodrugi muski: srjejźnośamna barwa kóže',
    '🫃🏿' => 'samodrugi muski: śamna barwa kóže',
    '🫄🏻' => 'samodruga wósoba: swětła barwa kóže',
    '🫄🏼' => 'samodruga wósoba: srjejźnoswětła barwa kóže',
    '🫄🏽' => 'samodruga wósoba: wósrědna barwa kóže',
    '🫄🏾' => 'samodruga wósoba: srjejźnośamna barwa kóže',
    '🫄🏿' => 'samodruga wósoba: śamna barwa kóže',
    '🤱🏻' => 'seśiś: swětła barwa kóže',
    '🤱🏼' => 'seśiś: srjejźnoswětła barwa kóže',
    '🤱🏽' => 'seśiś: wósrědna barwa kóže',
    '🤱🏾' => 'seśiś: srjejźnośamna barwa kóže',
    '🤱🏿' => 'seśiś: śamna barwa kóže',
    '👼🏻' => 'janźelik: swětła barwa kóže',
    '👼🏼' => 'janźelik: srjejźnoswětła barwa kóže',
    '👼🏽' => 'janźelik: wósrědna barwa kóže',
    '👼🏾' => 'janźelik: srjejźnośamna barwa kóže',
    '👼🏿' => 'janźelik: śamna barwa kóže',
    '🎅🏻' => 'ruprajcht: swětła barwa kóže',
    '🎅🏼' => 'ruprajcht: srjejźnoswětła barwa kóže',
    '🎅🏽' => 'ruprajcht: wósrědna barwa kóže',
    '🎅🏾' => 'ruprajcht: srjejźnośamna barwa kóže',
    '🎅🏿' => 'ruprajcht: śamna barwa kóže',
    '🤶🏻' => 'ruprajchtowka: swětła barwa kóže',
    '🤶🏼' => 'ruprajchtowka: srjejźnoswětła barwa kóže',
    '🤶🏽' => 'ruprajchtowka: wósrědna barwa kóže',
    '🤶🏾' => 'ruprajchtowka: srjejźnośamna barwa kóže',
    '🤶🏿' => 'ruprajchtowka: śamna barwa kóže',
    '🦸🏻' => 'superryśaŕ: swětła barwa kóže',
    '🦸🏼' => 'superryśaŕ: srjejźnoswětła barwa kóže',
    '🦸🏽' => 'superryśaŕ: wósrědna barwa kóže',
    '🦸🏾' => 'superryśaŕ: srjejźnośamna barwa kóže',
    '🦸🏿' => 'superryśaŕ: śamna barwa kóže',
    '🦹🏻' => 'supernjeknicomnik: swětła barwa kóže',
    '🦹🏼' => 'supernjeknicomnik: srjejźnoswětła barwa kóže',
    '🦹🏽' => 'supernjeknicomnik: wósrědna barwa kóže',
    '🦹🏾' => 'supernjeknicomnik: srjejźnośamna barwa kóže',
    '🦹🏿' => 'supernjeknicomnik: śamna barwa kóže',
    '🧙🏻' => 'gusłowaŕ: swětła barwa kóže',
    '🧙🏼' => 'gusłowaŕ: srjejźnoswětła barwa kóže',
    '🧙🏽' => 'gusłowaŕ: wósrědna barwa kóže',
    '🧙🏾' => 'gusłowaŕ: srjejźnośamna barwa kóže',
    '🧙🏿' => 'gusłowaŕ: śamna barwa kóže',
    '🧚🏻' => 'wiła: swětła barwa kóže',
    '🧚🏼' => 'wiła: srjejźnoswětła barwa kóže',
    '🧚🏽' => 'wiła: wósrědna barwa kóže',
    '🧚🏾' => 'wiła: srjejźnośamna barwa kóže',
    '🧚🏿' => 'wiła: śamna barwa kóže',
    '🧛🏻' => 'wampir/ka: swětła barwa kóže',
    '🧛🏼' => 'wampir/ka: srjejźnoswětła barwa kóže',
    '🧛🏽' => 'wampir/ka: wósrědna barwa kóže',
    '🧛🏾' => 'wampir/ka: srjejźnośamna barwa kóže',
    '🧛🏿' => 'wampir/ka: śamna barwa kóže',
    '🧜🏻' => 'wósoba z mórja: swětła barwa kóže',
    '🧜🏼' => 'wósoba z mórja: srjejźnoswětła barwa kóže',
    '🧜🏽' => 'wósoba z mórja: wósrědna barwa kóže',
    '🧜🏾' => 'wósoba z mórja: srjejźnośamna barwa kóže',
    '🧜🏿' => 'wósoba z mórja: śamna barwa kóže',
    '🧝🏻' => 'elf: swětła barwa kóže',
    '🧝🏼' => 'elf: srjejźnoswětła barwa kóže',
    '🧝🏽' => 'elf: wósrědna barwa kóže',
    '🧝🏾' => 'elf: srjejźnośamna barwa kóže',
    '🧝🏿' => 'elf: śamna barwa kóže',
    '💆🏻' => 'wósoba, kenž dostanjo masažu głowy: swětła barwa kóže',
    '💆🏼' => 'wósoba, kenž dostanjo masažu głowy: srjejźnoswětła barwa kóže',
    '💆🏽' => 'wósoba, kenž dostanjo masažu głowy: wósrědna barwa kóže',
    '💆🏾' => 'wósoba, kenž dostanjo masažu głowy: srjejźnośamna barwa kóže',
    '💆🏿' => 'wósoba, kenž dostanjo masažu głowy: śamna barwa kóže',
    '💇🏻' => 'wósoba, kenž dajo se włosy stśigaś: swětła barwa kóže',
    '💇🏼' => 'wósoba, kenž dajo se włosy stśigaś: srjejźnoswětła barwa kóže',
    '💇🏽' => 'wósoba, kenž dajo se włosy stśigaś: wósrědna barwa kóže',
    '💇🏾' => 'wósoba, kenž dajo se włosy stśigaś: srjejźnośamna barwa kóže',
    '💇🏿' => 'wósoba, kenž dajo se włosy stśigaś: śamna barwa kóže',
    '🚶🏻' => 'pěšy duca wósoba: swětła barwa kóže',
    '🚶🏼' => 'pěšy duca wósoba: srjejźnoswětła barwa kóže',
    '🚶🏽' => 'pěšy duca wósoba: wósrědna barwa kóže',
    '🚶🏾' => 'pěšy duca wósoba: srjejźnośamna barwa kóže',
    '🚶🏿' => 'pěšy duca wósoba: śamna barwa kóže',
    '🧍🏻' => 'stojeca wósoba: swětła barwa kóže',
    '🧍🏼' => 'stojeca wósoba: srjejźnoswětła barwa kóže',
    '🧍🏽' => 'stojeca wósoba: wósrědna barwa kóže',
    '🧍🏾' => 'stojeca wósoba: srjejźnośamna barwa kóže',
    '🧍🏿' => 'stojeca wósoba: śamna barwa kóže',
    '🧎🏻' => 'kólenkujuca wósoba: swětła barwa kóže',
    '🧎🏼' => 'kólenkujuca wósoba: srjejźnoswětła barwa kóže',
    '🧎🏽' => 'kólenkujuca wósoba: wósrědna barwa kóže',
    '🧎🏾' => 'kólenkujuca wósoba: srjejźnośamna barwa kóže',
    '🧎🏿' => 'kólenkujuca wósoba: śamna barwa kóže',
    '🏃🏻' => 'ganjajuca wósoba: swětła barwa kóže',
    '🏃🏼' => 'ganjajuca wósoba: srjejźnoswětła barwa kóže',
    '🏃🏽' => 'ganjajuca wósoba: wósrědna barwa kóže',
    '🏃🏾' => 'ganjajuca wósoba: srjejźnośamna barwa kóže',
    '🏃🏿' => 'ganjajuca wósoba: śamna barwa kóže',
    '💃🏻' => 'rejujuca žeńska: swětła barwa kóže',
    '💃🏼' => 'rejujuca žeńska: srjejźnoswětła barwa kóže',
    '💃🏽' => 'rejujuca žeńska: wósrědna barwa kóže',
    '💃🏾' => 'rejujuca žeńska: srjejźnośamna barwa kóže',
    '💃🏿' => 'rejujuca žeńska: śamna barwa kóže',
    '🕺🏻' => 'rejujucy muski: swětła barwa kóže',
    '🕺🏼' => 'rejujucy muski: srjejźnoswětła barwa kóže',
    '🕺🏽' => 'rejujucy muski: wósrědna barwa kóže',
    '🕺🏾' => 'rejujucy muski: srjejźnośamna barwa kóže',
    '🕺🏿' => 'rejujucy muski: śamna barwa kóže',
    '🕴🏻' => 'se znosujucy muski we woblaku: swětła barwa kóže',
    '🕴🏼' => 'se znosujucy muski we woblaku: srjejźnoswětła barwa kóže',
    '🕴🏽' => 'se znosujucy muski we woblaku: wósrědna barwa kóže',
    '🕴🏾' => 'se znosujucy muski we woblaku: srjejźnośamna barwa kóže',
    '🕴🏿' => 'se znosujucy muski we woblaku: śamna barwa kóže',
    '👯🏻' => 'wósobje z wuchacowyma wušyma: swětła barwa kóže',
    '👯🏼' => 'wósobje z wuchacowyma wušyma: srjejźnoswětła barwa kóže',
    '👯🏽' => 'wósobje z wuchacowyma wušyma: wósrědna barwa kóže',
    '👯🏾' => 'wósobje z wuchacowyma wušyma: srjejźnośamna barwa kóže',
    '👯🏿' => 'wósobje z wuchacowyma wušyma: śamna barwa kóže',
    '🧖🏻' => 'wósoba w sawnje: swětła barwa kóže',
    '🧖🏼' => 'wósoba w sawnje: srjejźnoswětła barwa kóže',
    '🧖🏽' => 'wósoba w sawnje: wósrědna barwa kóže',
    '🧖🏾' => 'wósoba w sawnje: srjejźnośamna barwa kóže',
    '🧖🏿' => 'wósoba w sawnje: śamna barwa kóže',
    '🧗🏻' => 'alpinist/ka: swětła barwa kóže',
    '🧗🏼' => 'alpinist/ka: srjejźnoswětła barwa kóže',
    '🧗🏽' => 'alpinist/ka: wósrědna barwa kóže',
    '🧗🏾' => 'alpinist/ka: srjejźnośamna barwa kóže',
    '🧗🏿' => 'alpinist/ka: śamna barwa kóže',
    '🏇🏻' => 'wuběgowanje na kónjach: swětła barwa kóže',
    '🏇🏼' => 'wuběgowanje na kónjach: srjejźnoswětła barwa kóže',
    '🏇🏽' => 'wuběgowanje na kónjach: wósrědna barwa kóže',
    '🏇🏾' => 'wuběgowanje na kónjach: srjejźnośamna barwa kóže',
    '🏇🏿' => 'wuběgowanje na kónjach: śamna barwa kóže',
    '🏂🏻' => 'snowborder /ka: swětła barwa kóže',
    '🏂🏼' => 'snowborder /ka: srjejźnoswětła barwa kóže',
    '🏂🏽' => 'snowborder /ka: wósrědna barwa kóže',
    '🏂🏾' => 'snowborder /ka: srjejźnośamna barwa kóže',
    '🏂🏿' => 'snowborder /ka: śamna barwa kóže',
    '🏌🏻' => 'golfowaŕ: swětła barwa kóže',
    '🏌🏼' => 'golfowaŕ: srjejźnoswětła barwa kóže',
    '🏌🏽' => 'golfowaŕ: wósrědna barwa kóže',
    '🏌🏾' => 'golfowaŕ: srjejźnośamna barwa kóže',
    '🏌🏿' => 'golfowaŕ: śamna barwa kóže',
    '🏄🏻' => 'wósoba pśi surfowanju: swětła barwa kóže',
    '🏄🏼' => 'wósoba pśi surfowanju: srjejźnoswětła barwa kóže',
    '🏄🏽' => 'wósoba pśi surfowanju: wósrědna barwa kóže',
    '🏄🏾' => 'wósoba pśi surfowanju: srjejźnośamna barwa kóže',
    '🏄🏿' => 'wósoba pśi surfowanju: śamna barwa kóže',
    '🚣🏻' => 'wósoba pśi wjasłowanju: swětła barwa kóže',
    '🚣🏼' => 'wósoba pśi wjasłowanju: srjejźnoswětła barwa kóže',
    '🚣🏽' => 'wósoba pśi wjasłowanju: wósrědna barwa kóže',
    '🚣🏾' => 'wósoba pśi wjasłowanju: srjejźnośamna barwa kóže',
    '🚣🏿' => 'wósoba pśi wjasłowanju: śamna barwa kóže',
    '🏊🏻' => 'plějuca wósoba: swětła barwa kóže',
    '🏊🏼' => 'plějuca wósoba: srjejźnoswětła barwa kóže',
    '🏊🏽' => 'plějuca wósoba: wósrědna barwa kóže',
    '🏊🏾' => 'plějuca wósoba: srjejźnośamna barwa kóže',
    '🏊🏿' => 'plějuca wósoba: śamna barwa kóže',
    '⛹🏻' => 'wósoba z balom: swětła barwa kóže',
    '⛹🏼' => 'wósoba z balom: srjejźnoswětła barwa kóže',
    '⛹🏽' => 'wósoba z balom: wósrědna barwa kóže',
    '⛹🏾' => 'wósoba z balom: srjejźnośamna barwa kóže',
    '⛹🏿' => 'wósoba z balom: śamna barwa kóže',
    '🏋🏻' => 'wósoba, kenž zwiga wažydła: swětła barwa kóže',
    '🏋🏼' => 'wósoba, kenž zwiga wažydła: srjejźnoswětła barwa kóže',
    '🏋🏽' => 'wósoba, kenž zwiga wažydła: wósrědna barwa kóže',
    '🏋🏾' => 'wósoba, kenž zwiga wažydła: srjejźnośamna barwa kóže',
    '🏋🏿' => 'wósoba, kenž zwiga wažydła: śamna barwa kóže',
    '🚴🏻' => 'wósoba, kenž kólasujo: swětła barwa kóže',
    '🚴🏼' => 'wósoba, kenž kólasujo: srjejźnoswětła barwa kóže',
    '🚴🏽' => 'wósoba, kenž kólasujo: wósrědna barwa kóže',
    '🚴🏾' => 'wósoba, kenž kólasujo: srjejźnośamna barwa kóže',
    '🚴🏿' => 'wósoba, kenž kólasujo: śamna barwa kóže',
    '🚵🏻' => 'wósoba, kenž z mountainbikom jězdźi: swětła barwa kóže',
    '🚵🏼' => 'wósoba, kenž z mountainbikom jězdźi: srjejźnoswětła barwa kóže',
    '🚵🏽' => 'wósoba, kenž z mountainbikom jězdźi: wósrědna barwa kóže',
    '🚵🏾' => 'wósoba, kenž z mountainbikom jězdźi: srjejźnośamna barwa kóže',
    '🚵🏿' => 'wósoba, kenž z mountainbikom jězdźi: śamna barwa kóže',
    '🤸🏻' => 'wósoba, kenž se na bok pśewjertujo: swětła barwa kóže',
    '🤸🏼' => 'wósoba, kenž se na bok pśewjertujo: srjejźnoswětła barwa kóže',
    '🤸🏽' => 'wósoba, kenž se na bok pśewjertujo: wósrědna barwa kóže',
    '🤸🏾' => 'wósoba, kenž se na bok pśewjertujo: srjejźnośamna barwa kóže',
    '🤸🏿' => 'wósoba, kenž se na bok pśewjertujo: śamna barwa kóže',
    '🤼🏻' => 'se běźecej wósobje: swětła barwa kóže',
    '🤼🏼' => 'se běźecej wósobje: srjejźnoswětła barwa kóže',
    '🤼🏽' => 'se běźecej wósobje: wósrědna barwa kóže',
    '🤼🏾' => 'se běźecej wósobje: srjejźnośamna barwa kóže',
    '🤼🏿' => 'se běźecej wósobje: śamna barwa kóže',
    '🤽🏻' => 'wódne balo grajuca wósoba: swětła barwa kóže',
    '🤽🏼' => 'wódne balo grajuca wósoba: srjejźnoswětła barwa kóže',
    '🤽🏽' => 'wódne balo grajuca wósoba: wósrědna barwa kóže',
    '🤽🏾' => 'wódne balo grajuca wósoba: srjejźnośamna barwa kóže',
    '🤽🏿' => 'wódne balo grajuca wósoba: śamna barwa kóže',
    '🤾🏻' => 'chytańcu grajuca wósoba: swětła barwa kóže',
    '🤾🏼' => 'chytańcu grajuca wósoba: srjejźnoswětła barwa kóže',
    '🤾🏽' => 'chytańcu grajuca wósoba: wósrědna barwa kóže',
    '🤾🏾' => 'chytańcu grajuca wósoba: srjejźnośamna barwa kóže',
    '🤾🏿' => 'chytańcu grajuca wósoba: śamna barwa kóže',
    '🤹🏻' => 'žonglěrujuca wósoba: swětła barwa kóže',
    '🤹🏼' => 'žonglěrujuca wósoba: srjejźnoswětła barwa kóže',
    '🤹🏽' => 'žonglěrujuca wósoba: wósrědna barwa kóže',
    '🤹🏾' => 'žonglěrujuca wósoba: srjejźnośamna barwa kóže',
    '🤹🏿' => 'žonglěrujuca wósoba: śamna barwa kóže',
    '🧘🏻' => 'wósoba w lotosowem sejźenju: swětła barwa kóže',
    '🧘🏼' => 'wósoba w lotosowem sejźenju: srjejźnoswětła barwa kóže',
    '🧘🏽' => 'wósoba w lotosowem sejźenju: wósrědna barwa kóže',
    '🧘🏾' => 'wósoba w lotosowem sejźenju: srjejźnośamna barwa kóže',
    '🧘🏿' => 'wósoba w lotosowem sejźenju: śamna barwa kóže',
    '🛀🏻' => 'se kupajuca wósoba: swětła barwa kóže',
    '🛀🏼' => 'se kupajuca wósoba: srjejźnoswětła barwa kóže',
    '🛀🏽' => 'se kupajuca wósoba: wósrědna barwa kóže',
    '🛀🏾' => 'se kupajuca wósoba: srjejźnośamna barwa kóže',
    '🛀🏿' => 'se kupajuca wósoba: śamna barwa kóže',
    '🛌🏻' => 'wósoba w póstoli: swětła barwa kóže',
    '🛌🏼' => 'wósoba w póstoli: srjejźnoswětła barwa kóže',
    '🛌🏽' => 'wósoba w póstoli: wósrědna barwa kóže',
    '🛌🏾' => 'wósoba w póstoli: srjejźnośamna barwa kóže',
    '🛌🏿' => 'wósoba w póstoli: śamna barwa kóže',
    '👭🏻' => 'se za ruku źaržecej žeńsce: swětła barwa kóže',
    '👭🏼' => 'se za ruku źaržecej žeńsce: srjejźnoswětła barwa kóže',
    '👭🏽' => 'se za ruku źaržecej žeńsce: wósrědna barwa kóže',
    '👭🏾' => 'se za ruku źaržecej žeńsce: srjejźnośamna barwa kóže',
    '👭🏿' => 'se za ruku źaržecej žeńsce: śamna barwa kóže',
    '👫🏻' => 'se za ruku źaržecej muski a žeńska: swětła barwa kóže',
    '👫🏼' => 'se za ruku źaržecej muski a žeńska: srjejźnoswětła barwa kóže',
    '👫🏽' => 'se za ruku źaržecej muski a žeńska: wósrědna barwa kóže',
    '👫🏾' => 'se za ruku źaržecej muski a žeńska: srjejźnośamna barwa kóže',
    '👫🏿' => 'se za ruku źaržecej muski a žeńska: śamna barwa kóže',
    '👬🏻' => 'muskej se źaržytej za ruku: swětła barwa kóže',
    '👬🏼' => 'muskej se źaržytej za ruku: srjejźnoswětła barwa kóže',
    '👬🏽' => 'muskej se źaržytej za ruku: wósrědna barwa kóže',
    '👬🏾' => 'muskej se źaržytej za ruku: srjejźnośamna barwa kóže',
    '👬🏿' => 'muskej se źaržytej za ruku: śamna barwa kóže',
    '💏🏻' => 'se póškajucy pórik: swětła barwa kóže',
    '💏🏼' => 'se póškajucy pórik: srjejźnoswětła barwa kóže',
    '💏🏽' => 'se póškajucy pórik: wósrědna barwa kóže',
    '💏🏾' => 'se póškajucy pórik: srjejźnośamna barwa kóže',
    '💏🏿' => 'se póškajucy pórik: śamna barwa kóže',
    '💑🏻' => 'pórik z wutšobku: swětła barwa kóže',
    '💑🏼' => 'pórik z wutšobku: srjejźnoswětła barwa kóže',
    '💑🏽' => 'pórik z wutšobku: wósrědna barwa kóže',
    '💑🏾' => 'pórik z wutšobku: srjejźnośamna barwa kóže',
    '💑🏿' => 'pórik z wutšobku: śamna barwa kóže',
    '🇦🇨' => 'chórgoj: Ascension',
    '🇦🇩' => 'chórgoj: Andorra',
    '🇦🇪' => 'chórgoj: Zjadnośone arabiske emiraty',
    '🇦🇫' => 'chórgoj: Afghanistan',
    '🇦🇬' => 'chórgoj: Antigua a Barbuda',
    '🇦🇮' => 'chórgoj: Anguilla',
    '🇦🇱' => 'chórgoj: Albańska',
    '🇦🇲' => 'chórgoj: Armeńska',
    '🇦🇴' => 'chórgoj: Angola',
    '🇦🇶' => 'chórgoj: Antarktis',
    '🇦🇷' => 'chórgoj: Argentinska',
    '🇦🇸' => 'chórgoj: Ameriska Samoa',
    '🇦🇹' => 'chórgoj: Awstriska',
    '🇦🇺' => 'chórgoj: Awstralska',
    '🇦🇼' => 'chórgoj: Aruba',
    '🇦🇽' => 'chórgoj: Åland',
    '🇦🇿' => 'chórgoj: Azerbajdžan',
    '🇧🇦' => 'chórgoj: Bosniska a Hercegowina',
    '🇧🇧' => 'chórgoj: Barbados',
    '🇧🇩' => 'chórgoj: Bangladeš',
    '🇧🇪' => 'chórgoj: Belgiska',
    '🇧🇫' => 'chórgoj: Burkina Faso',
    '🇧🇬' => 'chórgoj: Bulgarska',
    '🇧🇭' => 'chórgoj: Bahrain',
    '🇧🇮' => 'chórgoj: Burundi',
    '🇧🇯' => 'chórgoj: Benin',
    '🇧🇱' => 'chórgoj: St. Barthélemy',
    '🇧🇲' => 'chórgoj: Bermudy',
    '🇧🇳' => 'chórgoj: Brunei',
    '🇧🇴' => 'chórgoj: Boliwiska',
    '🇧🇶' => 'chórgoj: Karibiska Nižozemska',
    '🇧🇷' => 'chórgoj: Brazilska',
    '🇧🇸' => 'chórgoj: Bahamy',
    '🇧🇹' => 'chórgoj: Bhutan',
    '🇧🇻' => 'chórgoj: Bouvetowa kupa',
    '🇧🇼' => 'chórgoj: Botswana',
    '🇧🇾' => 'chórgoj: Běłoruska',
    '🇧🇿' => 'chórgoj: Belize',
    '🇨🇦' => 'chórgoj: Kanada',
    '🇨🇨' => 'chórgoj: Kokosowe kupy',
    '🇨🇩' => 'chórgoj: Kongo-Kinshasa',
    '🇨🇫' => 'chórgoj: Centralnoafriska republika',
    '🇨🇬' => 'chórgoj: Kongo-Brazzaville',
    '🇨🇭' => 'chórgoj: Šwicarska',
    '🇨🇮' => 'chórgoj: Côte d’Ivoire',
    '🇨🇰' => 'chórgoj: Cookowe kupy',
    '🇨🇱' => 'chórgoj: Chilska',
    '🇨🇲' => 'chórgoj: Kamerun',
    '🇨🇳' => 'chórgoj: China',
    '🇨🇴' => 'chórgoj: Kolumbiska',
    '🇨🇵' => 'chórgoj: Clippertonowa kupa',
    '🇨🇶' => 'chórgoj: Sark',
    '🇨🇷' => 'chórgoj: Kosta Rika',
    '🇨🇺' => 'chórgoj: Kuba',
    '🇨🇻' => 'chórgoj: Kap Verde',
    '🇨🇼' => 'chórgoj: Curaçao',
    '🇨🇽' => 'chórgoj: Gódowne kupy',
    '🇨🇾' => 'chórgoj: Cypriska',
    '🇨🇿' => 'chórgoj: Česka republika',
    '🇩🇪' => 'chórgoj: Nimska',
    '🇩🇬' => 'chórgoj: Diego Garcia',
    '🇩🇯' => 'chórgoj: Džibuti',
    '🇩🇰' => 'chórgoj: Dańska',
    '🇩🇲' => 'chórgoj: Dominika',
    '🇩🇴' => 'chórgoj: Dominikańska republika',
    '🇩🇿' => 'chórgoj: Algeriska',
    '🇪🇦' => 'chórgoj: Ceuta a Melilla',
    '🇪🇨' => 'chórgoj: Ekwador',
    '🇪🇪' => 'chórgoj: Estniska',
    '🇪🇬' => 'chórgoj: Egyptojska',
    '🇪🇭' => 'chórgoj: Pódwjacorna Sahara',
    '🇪🇷' => 'chórgoj: Eritreja',
    '🇪🇸' => 'chórgoj: Špańska',
    '🇪🇹' => 'chórgoj: Etiopiska',
    '🇪🇺' => 'chórgoj: Europska unija',
    '🇫🇮' => 'chórgoj: Finska',
    '🇫🇯' => 'chórgoj: Fidži',
    '🇫🇰' => 'chórgoj: Falklandske kupy',
    '🇫🇲' => 'chórgoj: Mikroneziska',
    '🇫🇴' => 'chórgoj: Färöje',
    '🇫🇷' => 'chórgoj: Francojska',
    '🇬🇦' => 'chórgoj: Gabun',
    '🇬🇧' => 'chórgoj: Zjadnośone kralejstwo',
    '🇬🇩' => 'chórgoj: Grenada',
    '🇬🇪' => 'chórgoj: Georgiska',
    '🇬🇫' => 'chórgoj: Francojska Guyana',
    '🇬🇬' => 'chórgoj: Guernsey',
    '🇬🇭' => 'chórgoj: Ghana',
    '🇬🇮' => 'chórgoj: Gibraltar',
    '🇬🇱' => 'chórgoj: Grönlandska',
    '🇬🇲' => 'chórgoj: Gambija',
    '🇬🇳' => 'chórgoj: Gineja',
    '🇬🇵' => 'chórgoj: Guadeloupe',
    '🇬🇶' => 'chórgoj: Ekwatorialna Gineja',
    '🇬🇷' => 'chórgoj: Grichiska',
    '🇬🇸' => 'chórgoj: Pódpołdnjowa Georgiska a Pódpołdnjowe Sandwichowe kupy',
    '🇬🇹' => 'chórgoj: Guatemala',
    '🇬🇺' => 'chórgoj: Guam',
    '🇬🇼' => 'chórgoj: Gineja-Bissau',
    '🇬🇾' => 'chórgoj: Guyana',
    '🇭🇰' => 'chórgoj: Wósebna zastojnstwowa cona Hongkong',
    '🇭🇲' => 'chórgoj: Heardowa kupa a McDonaldowe kupy',
    '🇭🇳' => 'chórgoj: Honduras',
    '🇭🇷' => 'chórgoj: Chorwatska',
    '🇭🇹' => 'chórgoj: Haiti',
    '🇭🇺' => 'chórgoj: Hungorska',
    '🇮🇨' => 'chórgoj: Kanariske kupy',
    '🇮🇩' => 'chórgoj: Indoneziska',
    '🇮🇪' => 'chórgoj: Irska',
    '🇮🇱' => 'chórgoj: Israel',
    '🇮🇲' => 'chórgoj: Man',
    '🇮🇳' => 'chórgoj: Indiska',
    '🇮🇴' => 'chórgoj: Britiski indiskooceaniski teritorium',
    '🇮🇶' => 'chórgoj: Irak',
    '🇮🇷' => 'chórgoj: Iran',
    '🇮🇸' => 'chórgoj: Islandska',
    '🇮🇹' => 'chórgoj: Italska',
    '🇯🇪' => 'chórgoj: Jersey',
    '🇯🇲' => 'chórgoj: Jamaika',
    '🇯🇴' => 'chórgoj: Jordaniska',
    '🇯🇵' => 'chórgoj: Japańska',
    '🇰🇪' => 'chórgoj: Kenia',
    '🇰🇬' => 'chórgoj: Kirgizistan',
    '🇰🇭' => 'chórgoj: Kambodža',
    '🇰🇮' => 'chórgoj: Kiribati',
    '🇰🇲' => 'chórgoj: Komory',
    '🇰🇳' => 'chórgoj: St. Kitts a Nevis',
    '🇰🇵' => 'chórgoj: Pódpołnocna Koreja',
    '🇰🇷' => 'chórgoj: Pódpołdnjowa Koreja',
    '🇰🇼' => 'chórgoj: Kuwait',
    '🇰🇾' => 'chórgoj: Kajmaniske kupy',
    '🇰🇿' => 'chórgoj: Kazachstan',
    '🇱🇦' => 'chórgoj: Laos',
    '🇱🇧' => 'chórgoj: Libanon',
    '🇱🇨' => 'chórgoj: St. Lucia',
    '🇱🇮' => 'chórgoj: Liechtenstein',
    '🇱🇰' => 'chórgoj: Sri Lanka',
    '🇱🇷' => 'chórgoj: Liberija',
    '🇱🇸' => 'chórgoj: Lesotho',
    '🇱🇹' => 'chórgoj: Litawska',
    '🇱🇺' => 'chórgoj: Luxemburgska',
    '🇱🇻' => 'chórgoj: Letiska',
    '🇱🇾' => 'chórgoj: Libyska',
    '🇲🇦' => 'chórgoj: Marokko',
    '🇲🇨' => 'chórgoj: Monaco',
    '🇲🇩' => 'chórgoj: Moldawska',
    '🇲🇪' => 'chórgoj: Carna Góra',
    '🇲🇫' => 'chórgoj: St. Martin',
    '🇲🇬' => 'chórgoj: Madagaskar',
    '🇲🇭' => 'chórgoj: Marshallowe kupy',
    '🇲🇰' => 'chórgoj: Pódpołnocna Makedańska',
    '🇲🇱' => 'chórgoj: Mali',
    '🇲🇲' => 'chórgoj: Myanmar',
    '🇲🇳' => 'chórgoj: Mongolska',
    '🇲🇴' => 'chórgoj: Wósebna zastojnstwowa cona Macao',
    '🇲🇵' => 'chórgoj: Pódpołnocne Mariany',
    '🇲🇶' => 'chórgoj: Martinique',
    '🇲🇷' => 'chórgoj: Mawretańska',
    '🇲🇸' => 'chórgoj: Montserrat',
    '🇲🇹' => 'chórgoj: Malta',
    '🇲🇺' => 'chórgoj: Mauritius',
    '🇲🇻' => 'chórgoj: Malediwy',
    '🇲🇼' => 'chórgoj: Malawi',
    '🇲🇽' => 'chórgoj: Mexiko',
    '🇲🇾' => 'chórgoj: Malajzija',
    '🇲🇿' => 'chórgoj: Mosambik',
    '🇳🇦' => 'chórgoj: Namibija',
    '🇳🇨' => 'chórgoj: Nowa Kaledoniska',
    '🇳🇪' => 'chórgoj: Niger',
    '🇳🇫' => 'chórgoj: Norfolkowa kupa',
    '🇳🇬' => 'chórgoj: Nigerija',
    '🇳🇮' => 'chórgoj: Nikaragua',
    '🇳🇱' => 'chórgoj: Nižozemska',
    '🇳🇴' => 'chórgoj: Norwegska',
    '🇳🇵' => 'chórgoj: Nepal',
    '🇳🇷' => 'chórgoj: Nauru',
    '🇳🇺' => 'chórgoj: Niue',
    '🇳🇿' => 'chórgoj: Nowoseelandska',
    '🇴🇲' => 'chórgoj: Oman',
    '🇵🇦' => 'chórgoj: Panama',
    '🇵🇪' => 'chórgoj: Peru',
    '🇵🇫' => 'chórgoj: Francojska Polyneziska',
    '🇵🇬' => 'chórgoj: Papua-Neuguinea',
    '🇵🇭' => 'chórgoj: Filipiny',
    '🇵🇰' => 'chórgoj: Pakistan',
    '🇵🇱' => 'chórgoj: Pólska',
    '🇵🇲' => 'chórgoj: St. Pierre a Miquelon',
    '🇵🇳' => 'chórgoj: Pitcairnowe kupy',
    '🇵🇷' => 'chórgoj: Puerto Rico',
    '🇵🇸' => 'chórgoj: Palestinski awtonomny teritorium',
    '🇵🇹' => 'chórgoj: Portugalska',
    '🇵🇼' => 'chórgoj: Palau',
    '🇵🇾' => 'chórgoj: Paraguay',
    '🇶🇦' => 'chórgoj: Katar',
    '🇷🇪' => 'chórgoj: Réunion',
    '🇷🇴' => 'chórgoj: Rumuńska',
    '🇷🇸' => 'chórgoj: Serbiska',
    '🇷🇺' => 'chórgoj: Ruska',
    '🇷🇼' => 'chórgoj: Ruanda',
    '🇸🇦' => 'chórgoj: Saudi-Arabiska',
    '🇸🇧' => 'chórgoj: Salomony',
    '🇸🇨' => 'chórgoj: Seychelle',
    '🇸🇩' => 'chórgoj: Sudan',
    '🇸🇪' => 'chórgoj: Šwedska',
    '🇸🇬' => 'chórgoj: Singapur',
    '🇸🇭' => 'chórgoj: St. Helena',
    '🇸🇮' => 'chórgoj: Słowjeńska',
    '🇸🇯' => 'chórgoj: Svalbard a Jan Mayen',
    '🇸🇰' => 'chórgoj: Słowakska',
    '🇸🇱' => 'chórgoj: Sierra Leone',
    '🇸🇲' => 'chórgoj: San Marino',
    '🇸🇳' => 'chórgoj: Senegal',
    '🇸🇴' => 'chórgoj: Somalija',
    '🇸🇷' => 'chórgoj: Surinamska',
    '🇸🇸' => 'chórgoj: Pódpołdnjowy Sudan',
    '🇸🇹' => 'chórgoj: São Tomé a Príncipe',
    '🇸🇻' => 'chórgoj: El Salvador',
    '🇸🇽' => 'chórgoj: Sint Maarten',
    '🇸🇾' => 'chórgoj: Syriska',
    '🇸🇿' => 'chórgoj: Swasiska',
    '🇹🇦' => 'chórgoj: Tristan da Cunha',
    '🇹🇨' => 'chórgoj: Turks a Caicos kupy',
    '🇹🇩' => 'chórgoj: Čad',
    '🇹🇫' => 'chórgoj: Francojski pódpołdnjowy a antarktiski teritorium',
    '🇹🇬' => 'chórgoj: Togo',
    '🇹🇭' => 'chórgoj: Thailandska',
    '🇹🇯' => 'chórgoj: Tadźikistan',
    '🇹🇰' => 'chórgoj: Tokelau',
    '🇹🇱' => 'chórgoj: Timor-Leste',
    '🇹🇲' => 'chórgoj: Turkmeniska',
    '🇹🇳' => 'chórgoj: Tuneziska',
    '🇹🇴' => 'chórgoj: Tonga',
    '🇹🇷' => 'chórgoj: Turkojska',
    '🇹🇹' => 'chórgoj: Trinidad a Tobago',
    '🇹🇻' => 'chórgoj: Tuvalu',
    '🇹🇼' => 'chórgoj: Taiwan',
    '🇹🇿' => 'chórgoj: Tansanija',
    '🇺🇦' => 'chórgoj: Ukraina',
    '🇺🇬' => 'chórgoj: Uganda',
    '🇺🇲' => 'chórgoj: Ameriska Oceaniska',
    '🇺🇳' => 'chórgoj: Zjadnośone narody',
    '🇺🇸' => 'chórgoj: Zjadnośone staty Ameriki',
    '🇺🇾' => 'chórgoj: Uruguay',
    '🇺🇿' => 'chórgoj: Uzbekistan',
    '🇻🇦' => 'chórgoj: Vatikańske město',
    '🇻🇨' => 'chórgoj: St. Vincent a Grenadiny',
    '🇻🇪' => 'chórgoj: Venezuela',
    '🇻🇬' => 'chórgoj: Britiske kněžniske kupy',
    '🇻🇮' => 'chórgoj: Ameriske kněžniske kupy',
    '🇻🇳' => 'chórgoj: Vietnam',
    '🇻🇺' => 'chórgoj: Vanuatu',
    '🇼🇫' => 'chórgoj: Wallis a Futuna',
    '🇼🇸' => 'chórgoj: Samoa',
    '🇽🇰' => 'chórgoj: Kosowo',
    '🇾🇪' => 'chórgoj: Jemen',
    '🇾🇹' => 'chórgoj: Mayotte',
    '🇿🇦' => 'chórgoj: Pódpołdnjowa Afrika (Republika)',
    '🇿🇲' => 'chórgoj: Sambija',
    '🇿🇼' => 'chórgoj: Simbabwe',
    '🔟' => 'tasta: 10',
    '🏻' => 'swětła barwa kóže',
    '🏼' => 'srjejźnoswětła barwa kóže',
    '🏽' => 'wósrědna barwa kóže',
    '🏾' => 'srjejźnośamna barwa kóže',
    '🏿' => 'śamna barwa kóže',
    '😀' => 'se zubjece woblico',
    '😃' => 'se zubjece woblico z wjelikima wócyma',
    '😄' => 'se zubjece woblico ze se smjejucyma wócyma',
    '😁' => 'woblico z glucnym smjaśim a se smjejucyma wócyma',
    '😆' => 'se zubjece woblico z pśizacynjomoma wócyma',
    '😅' => 'se zubjece woblico ze znojowymi chrapkami',
    '🤣' => 'se smjaśa dla na špundowanju walaś',
    '😂' => 'woblico ze łdzami wjasela',
    '🙂' => 'tšošku se smjejuce woblico',
    '🙃' => 'znak stojece woblico',
    '🫠' => 'rozbězěce woblico',
    '😉' => 'mykotajuce woblico',
    '😊' => 'smjejuce woblico ze se smjejucyma wócyma',
    '😇' => 'se smjejkotajuce woblico ze swětym swětłom',
    '🥰' => 'se smjejkotajuce woblico z wutšobkami',
    '😍' => 'se smjejkotajuce woblico z wutšobojtyma wócyma',
    '🤩' => 'pśemóžony',
    '😘' => 'pśipóšknjece woblico',
    '😗' => 'póškajuce woblico',
    '☺' => 'se smjejkotajuce woblico',
    '😚' => 'póškajuce woblico ze zacynjonyma wócyma',
    '😙' => 'póškajuce woblico ze se smjejkotajucyma wócyma',
    '🥲' => 'se smjejuce woblico ze łdzu',
    '😋' => 'se gubje lizajuce woblico',
    '😛' => 'woblico z wusunjonym jězykom',
    '😜' => 'mykotajuce woblico z wusunjonym jězykom',
    '🤪' => 'błudne woblico',
    '😝' => 'woblico z wusunjonym jězykom a pśizacynjonyma wócyma',
    '🤑' => 'woblico z dolarowymi znamuškami',
    '🤗' => 'woblico z wobejmjecyma rukoma',
    '🤭' => 'woblico z ruku pśed gubu',
    '🫢' => 'woblico z wócynjonyma wócyma a ruku na gubje',
    '🫣' => 'woblico z kukajucym wóckom',
    '🤫' => 'napominajuce woblico',
    '🤔' => 'rozmyslowate woblico',
    '🫡' => 'salutěrujuce woblico',
    '🤐' => 'woblico ze zasuwałkowateju gubu',
    '🤨' => 'woblico z natśěgnjonyma wobwócyma',
    '😐' => 'neutralne woblico',
    '😑' => 'njewurazne woblico',
    '😶' => 'woblico bźez guby',
    '🫥' => 'woblico z dypkowaneju smužku',
    '😏' => 'sebjespódobnje se zubjece woblico',
    '😒' => 'wobuzne woblico',
    '🙄' => 'wócy wobwalujuce woblico',
    '😬' => 'grimasu śěgujuce woblico',
    '🤥' => 'łdgajuce woblico',
    '🫨' => 'tśěskotate woblico',
    '😌' => 'wólažcone woblico',
    '😔' => 'wjelgin rozmyslowate woblico',
    '😪' => 'zaspane woblico',
    '🤤' => 'slinjece woblico',
    '😴' => 'spice woblico',
    '🫩' => 'woblico ze łdzowyma měškoma pód wócyma',
    '😷' => 'woblico z dychańskeju šćitneju masku',
    '🤒' => 'woblico ze zymnicowym termometerom',
    '🤕' => 'woblico ze zawobalenim głowy',
    '🤢' => 'dajecy woblico',
    '🤮' => 'bluwajuce woblico',
    '🤧' => 'tśichajuce woblico',
    '🥵' => 'se znojece woblico',
    '🥶' => 'marznjece woblico',
    '🥴' => 'wjelgin zwite woblico',
    '😵' => 'pógłušone woblico',
    '🤯' => 'rozbuchnjeca głowa',
    '🤠' => 'woblico z cowbojowym kłobykom',
    '🥳' => 'partyjowe woblico',
    '🥸' => 'pśewoblacone woblico',
    '😎' => 'se smjejkotajuce woblico ze słyńcneju brylu',
    '🤓' => 'woblico procowarja',
    '🧐' => 'woblico z monokelom',
    '😕' => 'zacwiblowane woblico',
    '🫤' => 'woblico z diagonalneju gubu',
    '😟' => 'starosćiwe woblico',
    '🙁' => 'wobtužne woblico',
    '☹' => 'póchmurne woblico',
    '😮' => 'woblico z wótcynjoneju gubu',
    '😯' => 'zaźiwane woblico',
    '😲' => 'wjelgin zacwiblowane woblico',
    '😳' => 'zacerwjenjone woblico z wjelikima wócyma',
    '🫪' => 'spryšćone woblico',
    '🥺' => 'pšosece woblico',
    '🥹' => 'łdzy zaźaržujuce woblico',
    '😦' => 'wuźěsone woblico',
    '😧' => 'drěcowane woblico',
    '😨' => 'tšašywe woblico',
    '😰' => 'starosćiwe woblico ze znojowymi chrapkami',
    '😥' => 'tužne abo wólažcone woblico',
    '😢' => 'płakuce woblico',
    '😭' => 'bjacece woblico',
    '😱' => 'tšacha dla se kśikajuce woblico',
    '😖' => 'zwite woblico',
    '😣' => 'rozsuźone woblico',
    '😞' => 'pśechwatane woblico',
    '😓' => 'zdušone woblico z chrapku znojom',
    '😩' => 'dopórane woblico',
    '😫' => 'mucne woblico',
    '🥱' => 'zewajuce woblico',
    '😤' => 'smarkajuce woblico',
    '😡' => 'premplece woblico',
    '😠' => 'rozgórjone woblico',
    '🤬' => 'woblico ze symbolami wušej guby',
    '😈' => 'ze zubjece woblico z rogoma',
    '👿' => 'se sćaklece woblico z rogoma',
    '💀' => 'nop',
    '☠' => 'nop z pśekśicnjonyma kósćoma',
    '💩' => 'gownowa kopica',
    '🤡' => 'woblico klowna',
    '👹' => 'wogawa',
    '👺' => 'larba kobołta',
    '👻' => 'tšašydło',
    '👽' => 'alien',
    '👾' => 'monster z computerowego graśa',
    '🤖' => 'roboter',
    '😺' => 'se zubjeca kócka',
    '😸' => 'se zubjeca kócka ze se smjejucyma wócyma',
    '😹' => 'kócka ze łdzami wjasela',
    '😻' => 'se smjejuca kócka z wutšobickojtym wócyma',
    '😼' => 'zwažnje se smjejkotajuca kócka',
    '😽' => 'póškajuca kócka',
    '🙀' => 'dopórany kócka',
    '😿' => 'płakuca kócka',
    '😾' => 'prempleca kócka',
    '🙈' => 'se wócy zaźaržujuca nałpa',
    '🙉' => 'se wušy zaźaržujuca nałpa',
    '🙊' => 'se gubu zaźaržujuca nałpa',
    '💌' => 'lubosćinski list',
    '💘' => 'wutšobka ze šypu',
    '💝' => 'wutšobka ze šlejfku',
    '💖' => 'se błyšćeca wutšoba',
    '💗' => 'rosćeca wutšobka',
    '💓' => 'bijuca wutšoba',
    '💞' => 'kružecej wutšobce',
    '💕' => 'dwě wutšobce',
    '💟' => 'dekoracija z wutšobu',
    '❣' => 'wutšoba ako wuwołak',
    '💔' => 'rozłamana wutšobka',
    '❤' => 'cerwjena wutšobka',
    '🩷' => 'rožojta wutšoba',
    '🧡' => 'oranžojta wutšoba',
    '💛' => 'žołta wutšobka',
    '💚' => 'zelena wutšobka',
    '💙' => 'módra wutšobka',
    '🩵' => 'swětłomódra wutšoba',
    '💜' => 'lylowa wutšobka',
    '🤎' => 'bruna wutšobka',
    '🖤' => 'carna wutšobka',
    '🩶' => 'šera wutšoba',
    '🤍' => 'běła wutšobka',
    '💋' => 'wótśišć póška',
    '💯' => '100 dypkow',
    '💢' => 'górjenje',
    '🫯' => 'mrokawa wójowanja',
    '💥' => 'kolizija',
    '💫' => 'zwity',
    '💦' => 'chrapki znoja',
    '💨' => 'prochowa mrokawa',
    '🕳' => 'źěra',
    '💬' => 'powědański puchor z tśimi dykami',
    '🗨' => 'powědański puchor nalěwo',
    '🗯' => 'powědański puchor za sćakłe wugrono napšawo',
    '💭' => 'myslowy puchor',
    '💤' => 'spanje',
    '👋' => 'kiwajuca ruka',
    '🤚' => 'pózwignjona ruka wót slědka',
    '🖐' => 'ruka z rozpśestrětymi palcami',
    '✋' => 'pózwignjona ruka',
    '🖖' => 'wulkaniske póstrowjenje',
    '🫱' => 'ruka napšawo',
    '🫲' => 'ruka nalěwo',
    '🫳' => 'dłoń pokazujo dołoj',
    '🫴' => 'dłoń pokazujo górjej',
    '🫷' => 'ruka, ak tłocy nalěwo',
    '🫸' => 'ruka, ak tłocy napšawo',
    '👌' => 'ok-gesta',
    '🤌' => 'gromadu stłocone palce',
    '🤏' => 'mało-gesta',
    '✌' => 'dobyśaŕska gesta',
    '🤞' => 'ruka z pśekśicnjonyma palcoma',
    '🫰' => 'ruka, z pśekśicowanym pokazowarjom a palcom',
    '🤟' => 'gesta "ja śi lubujom"',
    '🤘' => 'cartowe póstrowjenje',
    '🤙' => 'gesta "zawołaj na mnjo"',
    '👈' => 'nalěwo pokazujucy drugi palc',
    '👉' => 'napšawo pokazujucy drugii palc',
    '👆' => 'górjej pokazujucy drugi palc wót slědka',
    '🖕' => 'wósrědny palc',
    '👇' => 'dołoj pokazujucy drugi palc',
    '☝' => 'górjej pokazujucy drugi palc wót prědka',
    '🫵' => 'pokazowaŕ, wusměrjony na glědajucego',
    '👍' => 'tłusty palc górjej',
    '👎' => 'tłusty palc dołoj',
    '✊' => 'pózwignjona pěsć',
    '👊' => 'zamknjona pěsć',
    '🤛' => 'pěsć nalěwo',
    '🤜' => 'pěsć napšawo',
    '👏' => 'pśiklaskujuce ruki',
    '🙌' => 'pózwignjonej ruce',
    '🫶' => 'ruce twóritej formu wutšoby',
    '👐' => 'wótwórjonej ruce',
    '🤲' => 'dłoni górjej',
    '🤝' => 'pódaśe ruki',
    '🙏' => 'bjatujuce ruki',
    '✍' => 'pišuca ruka',
    '💅' => 'nokśowy lak',
    '🤳' => 'selfie',
    '💪' => 'napněty biceps',
    '🦾' => 'proteza ruki',
    '🦿' => 'proteza nogi',
    '🦵' => 'ceła noga',
    '🦶' => 'spódna noga',
    '👂' => 'wucho',
    '🦻' => 'wucho ze słušańskeju pomocu',
    '👃' => 'nos',
    '🧠' => 'mórzgi',
    '🫀' => 'wutšoba (organ)',
    '🫁' => 'płuca',
    '🦷' => 'zub',
    '🦴' => 'kósć',
    '👀' => 'wócy',
    '👁' => 'woko',
    '👅' => 'jězyk',
    '👄' => 'guba',
    '🫦' => 'guba, kenž se do spódneje guby kusnjo',
    '👶' => 'góletko',
    '🧒' => 'góle',
    '👦' => 'gólc',
    '👧' => 'źowćo',
    '🧑' => 'dorosćony',
    '👱' => 'wósoba: swětłe włosy',
    '👨' => 'muski',
    '🧔' => 'wósoba: broda',
    '👩' => 'žeńska',
    '🧓' => 'starša wósoba',
    '👴' => 'staršy muski',
    '👵' => 'starša žeńska',
    '🙍' => 'wobuzna wósoba',
    '🙎' => 'prempleca wósoba',
    '🙅' => 'wósoba z pśekśicnjonyma rukoma',
    '🙆' => 'wósoba z rukoma na głowje',
    '💁' => 'wósoba z dłonju górjej',
    '🙋' => 'wósoba z pózwignjoneju ruku',
    '🧏' => 'njesłyšajuca wósoba',
    '🙇' => 'se pókłonjeca wósoba',
    '🤦' => 'se za głowu pśimjeca wósoba',
    '🤷' => 'z ramjenjoma sukotajuca wósoba',
    '👮' => 'policist/ka',
    '🕵' => 'dedektiw/ka',
    '💂' => 'stražnik/stražnica',
    '🥷' => 'ninja',
    '👷' => 'twaŕski źěłaśeŕ/ka',
    '🫅' => 'wósoba z kronu',
    '🤴' => 'princ',
    '👸' => 'princesna',
    '👳' => 'wósoba z turbanom',
    '👲' => 'muski z chinskeju šapku',
    '🧕' => 'žeńska z lapu',
    '🤵' => 'wósoba w smokingu',
    '👰' => 'wósoba ze šlewjerjom',
    '🤰' => 'samodruga',
    '🫃' => 'samodrugi muski',
    '🫄' => 'samodruga wósoba',
    '🤱' => 'seśiś',
    '👼' => 'janźelik',
    '🎅' => 'ruprajcht',
    '🤶' => 'ruprajchtowka',
    '🦸' => 'superryśaŕ',
    '🦹' => 'supernjeknicomnik',
    '🧙' => 'gusłowaŕ',
    '🧚' => 'wiła',
    '🧛' => 'wampir/ka',
    '🧜' => 'wósoba z mórja',
    '🧝' => 'elf',
    '🧞' => 'duch z flaše',
    '🧟' => 'combie',
    '🧌' => 'kobołt',
    '🫈' => 'kósmata stwóŕba',
    '💆' => 'wósoba, kenž dostanjo masažu głowy',
    '💇' => 'wósoba, kenž dajo se włosy stśigaś',
    '🚶' => 'pěšy duca wósoba',
    '🧍' => 'stojeca wósoba',
    '🧎' => 'kólenkujuca wósoba',
    '🏃' => 'ganjajuca wósoba',
    '💃' => 'rejujuca žeńska',
    '🕺' => 'rejujucy muski',
    '🕴' => 'se znosujucy muski we woblaku',
    '👯' => 'wósobje z wuchacowyma wušyma',
    '🧖' => 'wósoba w sawnje',
    '🧗' => 'alpinist/ka',
    '🤺' => 'fechtaŕ/ka',
    '🏇' => 'wuběgowanje na kónjach',
    '⛷' => 'sněgakowaŕ/ka',
    '🏂' => 'snowborder /ka',
    '🏌' => 'golfowaŕ',
    '🏄' => 'wósoba pśi surfowanju',
    '🚣' => 'wósoba pśi wjasłowanju',
    '🏊' => 'plějuca wósoba',
    '⛹' => 'wósoba z balom',
    '🏋' => 'wósoba, kenž zwiga wažydła',
    '🚴' => 'wósoba, kenž kólasujo',
    '🚵' => 'wósoba, kenž z mountainbikom jězdźi',
    '🤸' => 'wósoba, kenž se na bok pśewjertujo',
    '🤼' => 'se běźecej wósobje',
    '🤽' => 'wódne balo grajuca wósoba',
    '🤾' => 'chytańcu grajuca wósoba',
    '🤹' => 'žonglěrujuca wósoba',
    '🧘' => 'wósoba w lotosowem sejźenju',
    '🛀' => 'se kupajuca wósoba',
    '🛌' => 'wósoba w póstoli',
    '👭' => 'se za ruku źaržecej žeńsce',
    '👫' => 'se za ruku źaržecej muski a žeńska',
    '👬' => 'muskej se źaržytej za ruku',
    '💏' => 'se póškajucy pórik',
    '💑' => 'pórik z wutšobku',
    '🗣' => 'powědajuca głowa',
    '👤' => 'silueta wósoby',
    '👥' => 'silueta wósobowu',
    '🫂' => 'se wobejmjecej wósobje',
    '👪' => 'familija',
    '👣' => 'stopje',
    '🫆' => 'wótśišć palca',
    '🦰' => 'cerwjene włosy',
    '🦱' => 'kuźerate włosy',
    '🦳' => 'běłe włosy',
    '🦲' => 'plěch',
    '🐵' => 'woblico nałpy',
    '🐒' => 'nałpa',
    '🦍' => 'gorila',
    '🦧' => 'orang-utan',
    '🐶' => 'psowa głowa',
    '🐕' => 'pjas',
    '🦮' => 'pjas za slěpych',
    '🐩' => 'pudel',
    '🐺' => 'wjelk',
    '🦊' => 'liška',
    '🦝' => 'šup',
    '🐱' => 'głowa kócki',
    '🐈' => 'kócka',
    '🦁' => 'law',
    '🐯' => 'woblico tigra',
    '🐅' => 'tiger',
    '🐆' => 'leopard',
    '🐴' => 'głowa kónja',
    '🫎' => 'głowa łosa',
    '🫏' => 'wósolik',
    '🐎' => 'kóń',
    '🦄' => 'jadnorogac',
    '🦓' => 'cebra',
    '🦌' => 'jeleń',
    '🦬' => 'bizon',
    '🐮' => 'woblico krowy',
    '🐂' => 'woł',
    '🐃' => 'wódny buwoł',
    '🐄' => 'krowa',
    '🐷' => 'głowa krowy',
    '🐖' => 'swinja',
    '🐗' => 'głowa źiwejej swinje',
    '🐽' => 'swinjecy pysk',
    '🐏' => 'baran',
    '🐑' => 'wójca',
    '🐐' => 'kóza',
    '🐪' => 'dromedar',
    '🐫' => 'kamel',
    '🦙' => 'lama',
    '🦒' => 'girafa',
    '🐘' => 'elefant',
    '🦣' => 'mamut',
    '🦏' => 'nosorogak',
    '🦛' => 'wódny kóń',
    '🐭' => 'myšeca głowa',
    '🐁' => 'myš',
    '🐀' => 'ratwa',
    '🐹' => 'głowa zemcygarja',
    '🐰' => 'woblico wuchaca',
    '🐇' => 'wuchac',
    '🐿' => 'smugata wjewjericka',
    '🦫' => 'bobr',
    '🦔' => 'jež',
    '🦇' => 'njetopyŕ',
    '🐻' => 'mjadwjeź',
    '🐨' => 'głowa koale',
    '🐼' => 'panda',
    '🦥' => 'gnilawa',
    '🦦' => 'wudra',
    '🦨' => 'skunk',
    '🦘' => 'kengeru',
    '🦡' => 'jazw',
    '🐾' => 'wótśišć pacow',
    '🦃' => 'turk',
    '🐔' => 'kokoš',
    '🐓' => 'kokot',
    '🐣' => 'se wukluwajuce kurje',
    '🐤' => 'kurje',
    '🐥' => 'kurje wótprědka',
    '🐦' => 'ptašk',
    '🐧' => 'pinguin',
    '🕊' => 'gołub',
    '🦅' => 'hodlaŕ',
    '🦆' => 'kacka',
    '🦢' => 'šwon',
    '🦉' => 'sowa',
    '🦤' => 'dodo',
    '🪶' => 'pjero',
    '🦩' => 'flamingo',
    '🦚' => 'paw',
    '🦜' => 'papagaj',
    '🪽' => 'kśidło',
    '🪿' => 'gus',
    '🐸' => 'žaba',
    '🐊' => 'krokodil',
    '🐢' => 'nopawa',
    '🦎' => 'jašćerica',
    '🐍' => 'wuž',
    '🐲' => 'woblico plona',
    '🐉' => 'mytologiski plon',
    '🦕' => 'sauropoda',
    '🦖' => 'tyrannosaurus rex',
    '🐳' => 'wódu bryzgajuca wjelryba',
    '🐋' => 'wjelryba',
    '🐬' => 'delfin',
    '🫍' => 'orka',
    '🦭' => 'mórski pjas',
    '🐟' => 'ryba',
    '🐠' => 'tropiska ryba',
    '🐡' => 'kulowa ryba',
    '🦈' => 'žrawik',
    '🐙' => 'oktopus',
    '🐚' => 'slinikowy konk',
    '🪸' => 'korala',
    '🪼' => 'kwala',
    '🦀' => 'rak',
    '🦞' => 'humer',
    '🦐' => 'garnela',
    '🦑' => 'tintowa ryba',
    '🦪' => 'wustrica',
    '🐌' => 'slinik',
    '🦋' => 'mjatel',
    '🐛' => 'gusenica',
    '🐜' => 'mrowja',
    '🐝' => 'pcołka',
    '🪲' => 'bruk',
    '🐞' => 'słyńcko',
    '🦗' => 'šwjerc',
    '🪳' => 'šwoba',
    '🕷' => 'pawk',
    '🕸' => 'pawcyna',
    '🦂' => 'skorpion',
    '🦟' => 'moskito',
    '🪰' => 'mucha',
    '🪱' => 'wužeńc',
    '🦠' => 'mikroba',
    '💐' => 'strus',
    '🌸' => 'kwiśonka wišnje',
    '💮' => 'běła kwiśonka',
    '🪷' => 'lotusowa kwiśonka',
    '🏵' => 'roseta',
    '🌹' => 'roža',
    '🥀' => 'woprěta kwětka',
    '🌺' => 'hibiskus',
    '🌻' => 'słyńca',
    '🌼' => 'kwiśonka',
    '🌷' => 'tulpa',
    '🪻' => 'hyacinta',
    '🌱' => 'pšut',
    '🪴' => 'rostlina w gjarnyšku',
    '🌲' => 'jeglina',
    '🌳' => 'listowy bom',
    '🌴' => 'palma',
    '🌵' => 'kaktus',
    '🌾' => 'rajsowy kłosk',
    '🌿' => 'zela',
    '☘' => 'kwiśinowe łopjeno',
    '🍀' => 'gluka',
    '🍁' => 'łopjeno jawora',
    '🍂' => 'list',
    '🍃' => 'łopjena we wětšu',
    '🪹' => 'prozne gnězdo',
    '🪺' => 'gnězdo z jajkoma',
    '🍄' => 'muchoradło',
    '🪾' => 'bom bźez lista',
    '🍇' => 'winowa granka',
    '🍈' => 'mjodowa melona',
    '🍉' => 'wódna melona',
    '🍊' => 'mandarina',
    '🍋' => 'citrona',
    '🍌' => 'banana',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'cerwjene jabłuko',
    '🍏' => 'zelene jabłuko',
    '🍐' => 'kšuška',
    '🍑' => 'rjacchen',
    '🍒' => 'wišnje',
    '🍓' => 'słynica',
    '🫐' => 'carnica',
    '🥝' => 'kiwi',
    '🍅' => 'tomata',
    '🫒' => 'oliwa',
    '🥥' => 'kokosowy wórjech',
    '🥑' => 'awokado',
    '🍆' => 'aubergina',
    '🥔' => 'kulka',
    '🥕' => 'marchwej',
    '🌽' => 'majsowa bažula',
    '🌶' => 'peperoni',
    '🫑' => 'paprika',
    '🥒' => 'górka',
    '🥬' => 'zelene',
    '🥦' => 'brokoli',
    '🧄' => 'kobołk',
    '🧅' => 'cybula',
    '🥜' => 'zemski wórjech',
    '🫘' => 'boby',
    '🌰' => 'kastanija',
    '🫚' => 'ingwer',
    '🫛' => 'tšuka grocha',
    '🫜' => 'kóruškata zelenina',
    '🍞' => 'klěb',
    '🥐' => 'croissant',
    '🥖' => 'baguett',
    '🫓' => 'płony kołac',
    '🥨' => 'kringel',
    '🥯' => 'bagel',
    '🥞' => 'pampug',
    '🧇' => 'wafla',
    '🧀' => 'kusk twarožka',
    '🍖' => 'měso na kósći',
    '🍗' => 'kokotow sćognyško',
    '🥩' => 'kus měsa',
    '🥓' => 'tuk',
    '🍔' => 'hamburger',
    '🍟' => 'pomfritki',
    '🍕' => 'pizza',
    '🌭' => 'hotdog',
    '🥪' => 'pókłaźona skibka',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'dejner',
    '🧆' => 'falafel',
    '🥚' => 'jajo',
    '🍳' => 'pjacone jajo I',
    '🥘' => 'panwej z jězu',
    '🍲' => 'gjarnc z jězu',
    '🫕' => 'fondue',
    '🥣' => 'škla ze łžycu',
    '🥗' => 'salat',
    '🍿' => 'popcorn',
    '🧈' => 'butra',
    '🧂' => 'sol',
    '🥫' => 'konserwowa tejza',
    '🍱' => 'bento tejza',
    '🍘' => 'rajsowy cracker',
    '🍙' => 'rajsowa kulka',
    '🍚' => 'zwarjony rajs',
    '🍛' => 'rajs z curryjom',
    '🍜' => 'škla z góruceju jězu',
    '🍝' => 'spageti',
    '🍠' => 'wopjacona słodka kulka',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'fritěrowana garnela',
    '🍥' => 'kamaboko',
    '🥮' => 'mjaseckowy mazańc',
    '🍡' => 'dango',
    '🥟' => 'piroga',
    '🥠' => 'wobgluceński keks',
    '🥡' => 'tejzka za jězu',
    '🍦' => 'lodowa krema',
    '🍧' => 'strěty lod',
    '🍨' => 'lodowa krema w nopašku',
    '🍩' => 'donut',
    '🍪' => 'keks',
    '🎂' => 'narodninski mazańc',
    '🍰' => 'kusk torty',
    '🧁' => 'mazańc',
    '🥧' => 'kusk mazańca',
    '🍫' => 'tofla šokolady',
    '🍬' => 'boms',
    '🍭' => 'lizak',
    '🍮' => 'puding',
    '🍯' => 'gjarnyšk mjodu',
    '🍼' => 'góletkowa flaška',
    '🥛' => 'głažk mloka',
    '☕' => 'górucye piśe',
    '🫖' => 'tejowa kana',
    '🍵' => 'tejowa taska bźez wuška',
    '🍶' => 'sake',
    '🍾' => 'flaša sekta',
    '🍷' => 'winowy głažk',
    '🍸' => 'cocktailowy głažk',
    '🍹' => 'tropiski cocktail',
    '🍺' => 'piwowy kružk',
    '🍻' => 'piwowe kružki',
    '🥂' => 'sektowe głažki',
    '🥃' => 'k piśeju głažk',
    '🫗' => 'kapalinu wulaś',
    '🥤' => 'głažk ze spłom',
    '🧋' => 'bubble tea',
    '🧃' => 'piśe w pakśiku',
    '🧉' => 'mate-tej',
    '🧊' => 'lodowa kóstka',
    '🥢' => 'jěźne kołki',
    '🍽' => 'talaŕ z nožom a widlickami',
    '🍴' => 'widlicki a nož',
    '🥄' => 'łžyca',
    '🔪' => 'hapka',
    '🫙' => 'sudobje',
    '🏺' => 'amfora',
    '🌍' => 'globus z Europu a Afriku',
    '🌎' => 'globus z Ameriku',
    '🌏' => 'globus z Aziju a Awstraliju',
    '🌐' => 'globus z meridianami',
    '🗺' => 'swětowa kórta',
    '🗾' => 'kórta Japańskeje',
    '🧭' => 'kompas',
    '🏔' => 'góra ze zasněgowanym wjerchom',
    '⛰' => 'góra',
    '🛘' => 'wótwalenje zemje',
    '🌋' => 'wulkan',
    '🗻' => 'góra Fuji',
    '🏕' => 'camping',
    '🏖' => 'pśibrjog z pśesłyńcnikom',
    '🏜' => 'pusćina',
    '🏝' => 'samotna kupa',
    '🏞' => 'narodny park',
    '🏟' => 'stadion',
    '🏛' => 'antikne twarjenje',
    '🏗' => 'twarnišćo',
    '🧱' => 'cygel',
    '🪨' => 'skała',
    '🪵' => 'drjewo',
    '🛖' => 'chałupa',
    '🏘' => 'bydleńske domy',
    '🏚' => 'rozpadany dom',
    '🏠' => 'dom',
    '🏡' => 'dom z gumnyškom',
    '🏢' => 'běrowowe twarjenje',
    '🏣' => 'japański post',
    '🏤' => 'twarjenje posta',
    '🏥' => 'chórownja',
    '🏦' => 'banka',
    '🏨' => 'hotel I',
    '🏩' => 'góźinski hotel',
    '🏪' => 'wobchod wšednych pótrjebow',
    '🏫' => 'šula',
    '🏬' => 'kupnica',
    '🏭' => 'fabrika',
    '🏯' => 'japański grod',
    '🏰' => 'grod',
    '💒' => 'swajźba',
    '🗼' => 'Tokioski torm',
    '🗽' => 'Póstawa lichoty',
    '⛪' => 'cerkwja',
    '🕌' => 'mašeja',
    '🛕' => 'hinduistiski tempel',
    '🕍' => 'synagoga',
    '⛩' => 'šintojska lodka z relikwijami',
    '🕋' => 'Haaba',
    '⛲' => 'fontejna',
    '⛺' => 'stan',
    '🌁' => 'kurjawojte',
    '🌃' => 'gwězdojte njebjo',
    '🏙' => 'skyline',
    '🌄' => 'schadanje słyńca wušej górow',
    '🌅' => 'schadanje słyńca wušej mórja',
    '🌆' => 'změrkanje w měsće',
    '🌇' => 'chowanje słyńca w měsće',
    '🌉' => 'móst w nocy',
    '♨' => 'góruce žrědła',
    '🎠' => 'karaselowy kónik',
    '🛝' => 'suwadło na grajkanišću',
    '🎡' => 'wjelicke kólaso',
    '🎢' => 'padata zeleznicka',
    '💈' => 'frizerski słup',
    '🎪' => 'cirkusowy stan',
    '🚂' => 'sparna lokomotiwa',
    '🚃' => 'zeleznica',
    '🚄' => 'śěg wjelikeje spěšnosći',
    '🚅' => 'spěšnik',
    '🚆' => 'śěg',
    '🚇' => 'metro',
    '🚈' => 'měsćańska zeleznica',
    '🚉' => 'stacija',
    '🚊' => 'elektriska',
    '🚝' => 'jadnokólejowa zeleznica',
    '🚞' => 'górska zeleznica',
    '🚋' => 'tramwajka',
    '🚌' => 'bus',
    '🚍' => 'bus wótprědka',
    '🚎' => 'trolejbus',
    '🚐' => 'małobus',
    '🚑' => 'chórobne awto',
    '🚒' => 'awto wognjoweje wobory',
    '🚓' => 'policajske awto',
    '🚔' => 'policajske awto wótprědka',
    '🚕' => 'taksi',
    '🚖' => 'taksi wótprědka',
    '🚗' => 'awto',
    '🚘' => 'awto wótprědka',
    '🚙' => 'bydleński mobil',
    '🛻' => 'pickup',
    '🚚' => 'transportne awto',
    '🚛' => 'sodłowy wlacak',
    '🚜' => 'traktor',
    '🏎' => 'wuběźowańske awto',
    '🏍' => 'motorske',
    '🛵' => 'motorrolller',
    '🦽' => 'rucny jězdny stoł',
    '🦼' => 'elektriski jězdny stoł',
    '🛺' => 'awtorikša',
    '🚲' => 'kólaso ako jězdźidło',
    '🛴' => 'roler k teptanju',
    '🛹' => 'skateboard',
    '🛼' => 'rulkowanki',
    '🚏' => 'busowe zastanišćo',
    '🛣' => 'awtodroga',
    '🛤' => 'zeleznicowe kóleje',
    '🛢' => 'wólejowy sud',
    '⛽' => 'tankowański słup',
    '🛞' => 'kólaso',
    '🚨' => 'policajske swětło',
    '🚥' => 'wódorowna ampla',
    '🚦' => 'padorowna ampla',
    '🛑' => 'sopowe znamje',
    '🚧' => 'twarnišćowa tofla',
    '⚓' => 'kokula',
    '🛟' => 'wumožaŕska boja',
    '⛵' => 'płachtak',
    '🛶' => 'kanu',
    '🚤' => 'spěšna łoź',
    '🛳' => 'pasažěrska łoź',
    '⛴' => 'prama',
    '🛥' => 'motorowy cołn',
    '🚢' => 'łoź',
    '✈' => 'lětadło',
    '🛩' => 'małe lětadło',
    '🛫' => 'wótlět lětadła',
    '🛬' => 'pśizemjenje lětadła',
    '🪂' => 'padadło',
    '💺' => 'městno k sejźenju',
    '🚁' => 'helikopter',
    '🚟' => 'wisata zeleznica',
    '🚠' => 'górska wisata zeleznica',
    '🚡' => 'górska powrjozowa zeleznica',
    '🛰' => 'satelit',
    '🚀' => 'raketa',
    '🛸' => 'lětajuca šklicka',
    '🛎' => 'zwónašk recepcije',
    '🧳' => 'brěmjenja',
    '⌛' => 'pěskowy zeger',
    '⏳' => 'běžecy pěskowy zeger',
    '⌚' => 'rucne zegerk',
    '⏰' => 'buźak',
    '⏱' => 'stopowka',
    '⏲' => 'na cas šaltujucy zeger',
    '🕰' => 'kaminowy zeger',
    '🕛' => 'cyfrina zeger dwanasćich',
    '🕧' => 'napoł jadnogo',
    '🕐' => 'zeger jadnogo',
    '🕜' => 'napoł dweju',
    '🕑' => 'zeger dweju',
    '🕝' => 'napoł tśich',
    '🕒' => 'zeger tśich',
    '🕞' => 'napoł styrich',
    '🕓' => 'zeger styrich',
    '🕟' => 'napoł pěśich',
    '🕔' => 'zeger pěśich',
    '🕠' => 'napoł šesćich',
    '🕕' => 'zeger šesćich',
    '🕡' => 'napoł sedymich',
    '🕖' => 'zeger sedymich',
    '🕢' => 'napoł wósymich',
    '🕗' => 'zeger wósymich I',
    '🕣' => 'napoł źewjeśich',
    '🕘' => 'zeger źewjeśich',
    '🕤' => 'napoł źaseśich',
    '🕙' => 'zeger źaseśich',
    '🕥' => 'napoł jadnasćich',
    '🕚' => 'zeger jadnasćich',
    '🕦' => 'napoł dwanasćich',
    '🌑' => 'młody mjaseck',
    '🌒' => 'pśiběrajucy mjaseck',
    '🌓' => 'pśiběrajucy połmjaseck',
    '🌔' => 'pśisamem połny mjaseck',
    '🌕' => 'połny mjaseck',
    '🌖' => 'južo njepołny mjaseck',
    '🌗' => 'wóteběrajucy połmjaseck',
    '🌘' => 'wóteběrajucy mjaseck',
    '🌙' => 'mjaseckowy serp',
    '🌚' => 'woblico młodego mjasecka',
    '🌛' => 'mjaseckowy serp z woblicom nalěwo',
    '🌜' => 'mjaseckowy serp z woblicom napšawo',
    '🌡' => 'termometer',
    '☀' => 'słyńco',
    '🌝' => 'połny mjaseck z woblicom',
    '🌞' => 'słyńco z woblicom',
    '🪐' => 'planet z rinkom',
    '⭐' => 'gwězda srjejźneje wjelikosći',
    '🌟' => 'se błyšćeca gwězda',
    '🌠' => 'gwězdnica',
    '🌌' => 'Ptaškowa droga',
    '☁' => 'mrokawa',
    '⛅' => 'słyńco za mrokawu',
    '⛈' => 'mrokawa z błyskom a dešćom',
    '🌤' => 'słyńco slěz mrokawki',
    '🌥' => 'słyńco za wjelikeju mrokawu',
    '🌦' => 'słyńco slěz dešćoweju mrokawu',
    '🌧' => 'mrokawa z dešćom',
    '🌨' => 'mrokawa ze sněgom',
    '🌩' => 'mrokawa z błyskom',
    '🌪' => 'tergaty štorm',
    '🌫' => 'kurjawa',
    '🌬' => 'wětš',
    '🌀' => 'cyklon',
    '🌈' => 'tyca',
    '🌂' => 'zacynjony pśedešćnik',
    '☂' => 'pśedešćnik',
    '☔' => 'pśedešćnik w dešću',
    '⛱' => 'nastajony pśesłyńcnik',
    '⚡' => 'wusoke napněśe',
    '❄' => 'sněžynka',
    '☃' => 'muž',
    '⛄' => 'sněgowa muž bźez sněžynkow',
    '☄' => 'komet',
    '🔥' => 'wogeń',
    '💧' => 'chrapka',
    '🌊' => 'žwała',
    '🎃' => 'latarnja z banje',
    '🎄' => 'gódowny bom',
    '🎆' => 'wognjopraskot',
    '🎇' => 'škrickotata swěcka',
    '🧨' => 'wognjopraskotak',
    '✨' => 'se błyšćece gwězdy',
    '🎈' => 'baloncyk',
    '🎉' => 'konfetijowa kanuna',
    '🎊' => 'konfetijowa kula',
    '🎋' => 'bom žycenjow',
    '🎍' => 'pinijowa dekoracija',
    '🎎' => 'japańske pupki',
    '🎏' => 'japańske karpowe chórgoje',
    '🎐' => 'japańske wětšowe graśe',
    '🎑' => 'mjaseckowy swěźeń',
    '🧧' => 'cerwjena wobalka',
    '🎀' => 'šlejfa',
    '🎁' => 'dar',
    '🎗' => 'wopomnjeńska šlejfa',
    '🎟' => 'zastupne lisćiki',
    '🎫' => 'tiket',
    '🎖' => 'wójaŕski rěd',
    '🏆' => 'pokal',
    '🏅' => 'soportowa medalja',
    '🥇' => 'złota medalja',
    '🥈' => 'slobrana medalja',
    '🥉' => 'bronzowa medalja',
    '⚽' => 'kopańcowe balo',
    '⚾' => 'baseballowe balo',
    '🥎' => 'softbalo',
    '🏀' => 'basketballowe balo',
    '🏐' => 'wolejbalo',
    '🏈' => 'fottballowe balo',
    '🏉' => 'rugbyjowe balo',
    '🎾' => 'tenisowe balo',
    '🥏' => 'frisbee',
    '🎳' => 'bowling',
    '🏏' => 'kriket',
    '🏑' => 'pólny hokej',
    '🏒' => 'lodowy hokej',
    '🥍' => 'lacrossse',
    '🏓' => 'blidowy tenis',
    '🏸' => 'badminton',
    '🥊' => 'boksaŕske rukajce',
    '🥋' => 'woblak za wójowański sport',
    '🥅' => 'wrota',
    '⛳' => 'golfowa chórgojcka',
    '⛸' => 'šuflity',
    '🎣' => 'wuda z rybu',
    '🤿' => 'nurjaŕska maska',
    '🎽' => 'běgaŕski shirt',
    '🎿' => 'sněgaki',
    '🛷' => 'sańki',
    '🥌' => 'curlingowy kamjeń',
    '🎯' => 'darts',
    '🪀' => 'jojo',
    '🪁' => 'plon za pušćanje',
    '🔫' => 'pistola',
    '🎱' => 'billardowa kula',
    '🔮' => 'kristalowa kula',
    '🪄' => 'guslowaŕski kij',
    '🎮' => 'gamepad',
    '🕹' => 'joystick',
    '🎰' => 'grajny awtomat',
    '🎲' => 'kóstka',
    '🧩' => 'źěl puzzla',
    '🧸' => 'tedij',
    '🪅' => 'pinjata',
    '🪩' => 'glědałkowa kula',
    '🪆' => 'matrjoška',
    '♠' => 'pik',
    '♥' => 'wutšoby',
    '♦' => 'karo',
    '♣' => 'kśicka na grajnej kórśe',
    '♟' => 'burik',
    '🃏' => 'joker',
    '🀄' => 'mahjong-kamušk',
    '🎴' => 'japańska kětkowa kórta',
    '🎭' => 'masce',
    '🖼' => 'wobraz w ramiku',
    '🎨' => 'mólaŕska paleta',
    '🧵' => 'nitka',
    '🪡' => 'šywalna glicka',
    '🧶' => 'kłubašk wałmy',
    '🪢' => 'suk',
    '👓' => 'bryla',
    '🕶' => 'słyńcna bryla',
    '🥽' => 'šćitna bryla',
    '🥼' => 'laborowa kitel',
    '🦺' => 'wěstotny bruslac',
    '👔' => 'krawata',
    '👕' => 't-shirt',
    '👖' => 'jeanse',
    '🧣' => 'šal',
    '🧤' => 'rukajce',
    '🧥' => 'płašć',
    '🧦' => 'štrumpica',
    '👗' => 'suknja',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'kupański woblak',
    '🩲' => 'slip',
    '🩳' => 'shortse',
    '👙' => 'bikini',
    '👚' => 'bluza',
    '🪭' => 'machawka za pśewětšenje',
    '👛' => 'móšynka',
    '👜' => 'rucna tobołka',
    '👝' => 'pódpažna tobołka',
    '🛍' => 'nakupowańske taše',
    '🎒' => 'šulska toboła',
    '🩴' => 'palcowa sandaletka',
    '👞' => 'muskecy crjeje',
    '👟' => 'sportowe crjeje',
    '🥾' => 'drogowańske škórnje',
    '🥿' => 'płone crjeje',
    '👠' => 'śańkopětaty crjej',
    '👡' => 'žeńskeca sandala',
    '🩰' => 'baletowe crjeje',
    '👢' => 'žeńskece škórnje',
    '🪮' => 'spinka za włose',
    '👑' => 'krona',
    '👒' => 'žeńskecy kłobyk',
    '🎩' => 'cylinder',
    '🎓' => 'doktorski kłobyk',
    '🧢' => 'basebalowa šapka',
    '🪖' => 'wójaŕski nagłownik',
    '⛑' => 'wumožaŕski nagłownik',
    '📿' => 'paśerc',
    '💄' => 'nagubny barwik',
    '💍' => 'pjeršćeń',
    '💎' => 'drogotny kamušk',
    '🔇' => 'pśešmarnjony głosnik',
    '🔈' => 'głosnik z niskeju głosnosću',
    '🔉' => 'głosnik ze srjejźneju głosnosću',
    '🔊' => 'głosnik z wusokeju głosnosću',
    '📢' => 'głosnik',
    '📣' => 'megafon',
    '📯' => 'postowy rog',
    '🔔' => 'zwón',
    '🔕' => 'pśešmarnjony zwón',
    '🎼' => 'notowy kluc',
    '🎵' => 'nota',
    '🎶' => 'noty',
    '🎙' => 'studijowy mikrofon',
    '🎚' => 'suwański regler',
    '🎛' => 'wobwjertny regler',
    '🎤' => 'mikrofon',
    '🎧' => 'nagłowne słuchatko',
    '📻' => 'radijo',
    '🎷' => 'saksofon',
    '🎺' => 'trompeta',
    '🪊' => 'pozawna',
    '🪗' => 'akordeon',
    '🎸' => 'gitara',
    '🎹' => 'klawiatura',
    '🎻' => 'fidle',
    '🪕' => 'banjo',
    '🥁' => 'bubon',
    '🪘' => 'afrikański bubon',
    '🪇' => 'maracasy',
    '🪈' => 'pišćałka',
    '🪉' => 'harfa',
    '📱' => 'mobilny telefon',
    '📲' => 'mobilny telefon ze šypu',
    '☎' => 'telefon',
    '📞' => 'słuchatko',
    '📟' => 'pager',
    '📠' => 'faks',
    '🔋' => 'baterija',
    '🪫' => 'słaba baterija',
    '🔌' => 'tykack',
    '💻' => 'laptop',
    '🖥' => 'desktopowy kompjuter',
    '🖨' => 'śišćak',
    '⌨' => 'tastatura',
    '🖱' => 'muška',
    '🖲' => 'trackball',
    '💽' => 'minidisk kompjuter',
    '💾' => 'disketa',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🧮' => 'licbowak',
    '🎥' => 'filmowa kamera',
    '🎞' => 'filmowa pask',
    '📽' => 'filmowa projektor',
    '🎬' => 'filmowa klapa',
    '📺' => 'telewizor',
    '📷' => 'fotoaparat',
    '📸' => 'fotoaparat z błyskom',
    '📹' => 'wideokamera',
    '📼' => 'wideokaseta',
    '🔍' => 'lupa nalěwo schylona',
    '🔎' => 'lupa napšawo schylona',
    '🕯' => 'swěcka',
    '💡' => 'žaglawka',
    '🔦' => 'kapsna lampa',
    '🏮' => 'cerwjeny lampionk',
    '🪔' => 'wólejowa lampa',
    '📔' => 'zapisnik z rědneju wobalku',
    '📕' => 'zacynjone knigły',
    '📖' => 'wótcynjone knigły',
    '📗' => 'zelene knigły',
    '📘' => 'módre knigły',
    '📙' => 'oranžojte knigły',
    '📚' => 'knigły',
    '📓' => 'zapisnik',
    '📒' => 'žołty zapisnik',
    '📃' => 'pitśku zwite łopjeno',
    '📜' => 'zawita pismowa rula',
    '📄' => 'prědny bok łopjena',
    '📰' => 'casniki',
    '🗞' => 'zawite casniki',
    '📑' => 'boki z cytańskim znamjenjami',
    '🔖' => 'cytańske znamje',
    '🏷' => 'etiket',
    '🪙' => 'minca',
    '💰' => 'měšk pjenjez',
    '🪎' => 'lodka z pókładom',
    '💴' => 'yenowa bankowka',
    '💵' => 'dolarowa bankowka',
    '💶' => 'eurowa bankowka',
    '💷' => 'puntowa bankowka',
    '💸' => 'bankowka z kśidłoma',
    '💳' => 'kreditna kórtka',
    '🧾' => 'dokład',
    '💹' => 'diagram pśirosta z yen-znamuškom',
    '✉' => 'listowa wobalka',
    '📧' => 'e-mail',
    '📨' => 'dochadajuca listowa wobalka',
    '📩' => 'wobalka ze šypu',
    '📤' => 'wuchad posta',
    '📥' => 'wótkładnica za dochadajucy post',
    '📦' => 'pakśik',
    '📫' => 'zacynjony listowy kašćik z postom',
    '📪' => 'zacynjony listowy kašćik bźez posta',
    '📬' => 'wótcynjony listowy kašći z postom',
    '📭' => 'wótcynjony listowy kašćik bźez posta',
    '📮' => 'listowy kašćik',
    '🗳' => 'urna z wólbnym lisćikom',
    '✏' => 'wołojnik',
    '✒' => 'carny pjerownik',
    '🖋' => 'pjerownik',
    '🖊' => 'kuli',
    '🖌' => 'šćotka',
    '🖍' => 'wóskowy barwik',
    '📝' => 'papjerka a wołojnik',
    '💼' => 'aktowka',
    '📁' => 'zarědnik',
    '📂' => 'wótcynjony zarědnik',
    '🗂' => 'kartoteka',
    '📅' => 'kalendaŕ',
    '📆' => 'wótrywański kalendaŕ',
    '🗒' => 'spiralny zapisnik',
    '🗓' => 'kalendaŕ ze špiralneju wězbu',
    '📇' => 'rotaciska kartaja',
    '📈' => 'rosćecy diagram',
    '📉' => 'spadujucy diagram',
    '📊' => 'słupikowy diagram',
    '📋' => 'mjazywótkładnica',
    '📌' => 'pśipinawka',
    '📍' => 'głowkata glicka',
    '📎' => 'spinka',
    '🖇' => 'skokulowane spinki',
    '📏' => 'lineal',
    '📐' => 'tśirožkaty lineal',
    '✂' => 'nožyce',
    '🗃' => 'kartajny kašćik',
    '🗄' => 'aktowa spižka',
    '🗑' => 'papjernik',
    '🔒' => 'zacynjony zamk',
    '🔓' => 'wótcynjony zamk',
    '🔏' => 'zamk z pjerownikom',
    '🔐' => 'zamk z klucykom',
    '🔑' => 'kluc',
    '🗝' => 'stary kluc',
    '🔨' => 'klapac',
    '🪓' => 'sekera',
    '⛏' => 'štapc',
    '⚒' => 'klapac a štapc',
    '🛠' => 'klapac a šrubowy kluc',
    '🗡' => 'kałak',
    '⚔' => 'pśekśicnjonej mjaca',
    '💣' => 'bomba',
    '🪃' => 'bumerang',
    '🏹' => 'šypa a pšužyna',
    '🛡' => 'šćit',
    '🪚' => 'rucna piła',
    '🔧' => 'šrubowy kluc',
    '🪛' => 'šrubowak',
    '🔩' => 'šrubnica a šruba',
    '⚙' => 'zubickate kólasko',
    '🗜' => 'šrubowańska spina',
    '⚖' => 'waga',
    '🦯' => 'běły kij',
    '🔗' => 'symbol zwězanja',
    '⛓' => 'rjeśaze',
    '🪝' => 'kokulka',
    '🧰' => 'kašćik ze źěłowym rědom',
    '🧲' => 'magnet',
    '🪜' => 'jabeŕ',
    '🪏' => 'šupa',
    '⚗' => 'destilaciski aparat',
    '🧪' => 'reagencowy głažk',
    '🧫' => 'Petrijowa šklicka',
    '🧬' => 'DNA',
    '🔬' => 'mikroskop',
    '🔭' => 'teleskop',
    '📡' => 'satelitowa škla',
    '💉' => 'sykawka',
    '🩸' => 'chrapka kšwě',
    '💊' => 'kapsla',
    '🩹' => 'pśilipny flastaŕ',
    '🩼' => 'zepěra',
    '🩺' => 'stetoskop',
    '🩻' => 'roentgenowy wobraz',
    '🚪' => 'źurja',
    '🛗' => 'lift',
    '🪞' => 'glědałko',
    '🪟' => 'wokno',
    '🛏' => 'póstola',
    '🛋' => 'zofa a lampa',
    '🪑' => 'stoł',
    '🚽' => 'toaleta',
    '🪠' => 'srěbadło',
    '🚿' => 'duša',
    '🛁' => 'kupańska wana',
    '🪤' => 'myšyna pasle',
    '🪒' => 'gólidła',
    '🧴' => 'flaška z kremu',
    '🧷' => 'zapinata glicka',
    '🧹' => 'chóžyšćo',
    '🧺' => 'kórb',
    '🧻' => 'rulka kuchnineje papjery',
    '🪣' => 'zbórk',
    '🧼' => 'mydło',
    '🫧' => 'puchorje',
    '🪥' => 'zubny šćotka',
    '🧽' => 'gubiba',
    '🧯' => 'wogeńgasak',
    '🛒' => 'nakupowański wózyk',
    '🚬' => 'cigareta',
    '⚰' => 'kašć',
    '🪦' => 'narowny kamjeń',
    '⚱' => 'popjelnica',
    '🧿' => 'nazar-amulet',
    '🪬' => 'hamsa',
    '🗿' => 'statuwa',
    '🪧' => 'plakat',
    '🪪' => 'wupokaz',
    '🏧' => 'symbol "pjenjezny awtomat"',
    '🚮' => 'symbol "papjernik"',
    '🚰' => 'symbol "pitna wóda"',
    '♿' => 'symbol "jězdny stoł"',
    '🚹' => 'symbol za "muskeca toaleta"',
    '🚺' => 'symbol za "žeńskeca toaleta"',
    '🚻' => 'symbol "toalety"',
    '🚼' => 'symbol "góle"',
    '🚾' => 'WC',
    '🛂' => 'pasowa kontrola',
    '🛃' => 'cłońska kontrola',
    '🛄' => 'wudawanje brěmjenjow',
    '🛅' => 'chowanje brěmjenjow',
    '⚠' => 'warnowanje',
    '🚸' => 'źiśi pśejdu pśez drogu',
    '⛔' => 'zastup zakazany',
    '🚫' => 'zakazane',
    '🚳' => 'za kólasa zakazane',
    '🚭' => 'zakaz krjenja',
    '🚯' => 'wótoadki njewótchytaś',
    '🚱' => 'žedna pitna wóda',
    '🚷' => 'za pěškarjow zakazane',
    '📵' => 'wužywanje mobilnych telefonow zakazane',
    '🔞' => 'za małolětnych zakazane',
    '☢' => 'radioaktiwne',
    '☣' => 'biologiske wobgrozenje',
    '⬆' => 'šypa górjej',
    '↗' => 'šypa napšawo górjej',
    '➡' => 'šypa napšawo',
    '↘' => 'šypa napšawo dołoj',
    '⬇' => 'šypa dołoj',
    '↙' => 'šypa nalěwo dołoj',
    '⬅' => 'šypa nalěwo',
    '↖' => 'šypa nalěwo górjej',
    '↕' => 'šypa górjej a dołoj',
    '↔' => 'šypa nalěwo a napšawo',
    '↩' => 'zwjertnjona šypa nalěwo',
    '↪' => 'šypa nalěwo zwjertnjo se napšawo',
    '⤴' => 'šypa napšawo zwjertnjo se górjej',
    '⤵' => 'šypa napšawo zwjertnjo se dołoj',
    '🔃' => 'wertikalnej šypje w směrje zegera',
    '🔄' => 'napśeśiwnej šypje pśeśiwo směroju zegera',
    '🔙' => 'šypa z napisom BACK',
    '🔚' => 'šypa z napisom END',
    '🔛' => 'šypa z napisom ON!',
    '🔜' => 'šypa z napisom SOON',
    '🔝' => 'šypa z napisom TOP',
    '🛐' => 'kultnišćo',
    '⚛' => 'symbol atoma',
    '🕉' => 'om',
    '✡' => 'Dawidowa gwězda',
    '☸' => 'dharma-krejz',
    '☯' => 'jin a jang',
    '✝' => 'łatyńska kśica',
    '☦' => 'ortodoksna kśica',
    '☪' => 'gwězda a połmjaseck',
    '☮' => 'symbol měra',
    '🕎' => 'menora',
    '🔯' => 'heksagram z dypkom',
    '🪯' => 'khanda',
    '♈' => 'Baran (gwězdne znamje)',
    '♉' => 'Byk (gwězdne znamje)',
    '♊' => 'Dwójnika (gwězdne znamje)',
    '♋' => 'Rak (gwězdne znamje)',
    '♌' => 'Law (gwězdne znamje)',
    '♍' => 'Kněžna (gwězdne znamje)',
    '♎' => 'Waga (gwězdne znamje)',
    '♏' => 'Skorpion (gwězdne znamje)',
    '♐' => 'Stśělc (gwězdne znamje)',
    '♑' => 'Kózyrožk (gwězdne znamje)',
    '♒' => 'Wódny muž (gwězdne znamje)',
    '♓' => 'Ryby (gwězdne znamje)',
    '⛎' => 'Ofiuchus',
    '🔀' => 'tasta wuběranja z pśigódy',
    '🔁' => 'tasta "wóspjetuj"',
    '🔂' => 'tasta "wóspjetuj jaden spiw"',
    '▶' => 'tasta "wótgrawaj"',
    '⏩' => 'tasta "wótgrawaj malsnjej"',
    '⏭' => 'tasta "skóc k pśiducemu titeloju"',
    '⏯' => 'tasta "wótgrawaj abo cyń pśestawku"',
    '◀' => 'tasta "wjerś slědk"',
    '⏪' => 'tasta "wjerś malsnjej slědk"',
    '⏮' => 'tasta " skóc k pśedchadnemu titeloju"',
    '🔼' => 'tasta "górjej"',
    '⏫' => 'tasta "malsnje górjej"',
    '🔽' => 'tasta "dołoj"',
    '⏬' => 'tasta "malsnje dołoj"',
    '⏸' => 'tasta "pśestawka"',
    '⏹' => 'tasta "stop"',
    '⏺' => 'tasta "nagrawaj"',
    '⏏' => 'tasta "wusuń"',
    '🎦' => 'kino',
    '🔅' => 'tasta "śamnej"',
    '🔆' => 'tasta "swětlej"',
    '📶' => 'mócnosć signala',
    '🛜' => 'bźez kabla',
    '📳' => 'tasta "wibraciski modus"',
    '📴' => 'tasta "wušaltuj handy"',
    '♀' => 'symbol za žeńskecy rod',
    '♂' => 'symbol za muskecy rod',
    '⚧' => 'transgenderowy symbol',
    '✖' => 'znamuško multiplikacije',
    '➕' => 'znamuško plus',
    '➖' => 'znamuško minus',
    '➗' => 'znamuško diwizije',
    '🟰' => 'tłuste znamje jo rowno',
    '♾' => 'njeskóńcnosć',
    '‼' => 'dwójny wuwołak',
    '⁉' => 'wuwołak a pšašak',
    '❓' => 'cerwjeny pšašak',
    '❔' => 'běły pšašak',
    '❕' => 'běły wuwołak',
    '❗' => 'cerwjeny wuwołak',
    '〰' => 'žwałkata linija',
    '💱' => 'zaměna pjenjez',
    '💲' => 'tucny symbol za dolar',
    '⚕' => 'gójcojski symbol',
    '♻' => 'symbol recyclinga',
    '⚜' => 'heraldiska leluja',
    '🔱' => 'tšojozubak',
    '📛' => 'toflicka z mjenim',
    '🔰' => 'japańske zachopjeńkaŕske znamje',
    '⭕' => 'prozny cerwjeny krejz',
    '✅' => 'šaltowańske pólo z běłeju kokulku',
    '☑' => 'kontrolny kašćik z kokulku',
    '✔' => 'tucna kokulka',
    '❌' => 'kśicka',
    '❎' => 'šaltowańske pólo z kśicku',
    '➰' => 'zawrośeńska šlejfa',
    '➿' => 'dwójna šlejfa',
    '〽' => 'japański symbol za zachopjeńk spiwa',
    '✳' => 'wósymrožkata gwězda',
    '✴' => 'gwězda z wósym rožkami',
    '❇' => 'błyskotanje',
    '™' => 'znamje marki',
    '🫟' => 'kalnjenje',
    '🔠' => 'zapódaj łatyńske wjelike pismiki',
    '🔡' => 'zapódaj łatyńske małe pismiki',
    '🔢' => 'zapódaj licby',
    '🔣' => 'zapódawański symbol wósebne znamuška',
    '🔤' => 'zapódaj łatyńske pismiki',
    '🅰' => 'znamuško A (kšejna kupka)',
    '🆎' => 'znamuško AB (kšejna kupka)',
    '🅱' => 'znamuško B (kšejna kupka)',
    '🆑' => 'znamuško CL',
    '🆒' => 'znamuško COOL',
    '🆓' => 'znamuško FREE',
    'ℹ' => 'informacija',
    '🆔' => 'znamuško ID',
    'Ⓜ' => 'M w krejzu',
    '🆕' => 'znamuško New',
    '🆖' => 'znamuško NG',
    '🅾' => 'znamuško 0',
    '🆗' => 'znamuško OK',
    '🅿' => 'znamuško P',
    '🆘' => 'SOS-znamje',
    '🆙' => 'znamje Up',
    '🆚' => 'znamuško VS',
    '🈁' => 'japańske pismikowe znamuško "how"',
    '🈂' => 'japańske pismikowe znamuško za "pśepijank"',
    '🈷' => 'japańske pismikowe znamuško za "mjasecny pśinosk"',
    '🈶' => 'japańske pismikowe znamuško za "njejo zadermo"',
    '🈯' => 'pismowe znamuško za "reserwěrowane"',
    '🉐' => 'japańske pismikowe znamuško za "wułapotk"',
    '🈹' => 'japańske pismikowe znamuško za "rabat"',
    '🈚' => 'japańske pismikowe znamuško za "zadermo"',
    '🈲' => 'japańske pismikowe znamuško "zakazane"',
    '🉑' => 'japańske pismikowe znamuško za "akceptěrowane"',
    '🈸' => 'japańske pismikowe znamuško za "napšašowanje"',
    '🈴' => 'japańske pismikowe znamuško za "pozitiwne pósuźenje"',
    '🈳' => 'japańske pismikowe znamuško za "liche"',
    '㊗' => 'pismowe znamuško za "gratulacija"',
    '㊙' => 'japańske pismikowe znamuško "pótajmne"',
    '🈺' => 'japańske pismikowe znamuško za "wótwórjone"',
    '🈵' => 'japańske pismikowe znamuško "wobsajźone"',
    '🔴' => 'cerwjeny krejz',
    '🟠' => 'oranžowy krejz',
    '🟡' => 'žołty krejz',
    '🟢' => 'zeleny krejz',
    '🔵' => 'módry krejz',
    '🟣' => 'lylowy krejz',
    '🟤' => 'bruny krejz',
    '⚫' => 'carny krejz',
    '⚪' => 'běły krejz',
    '🟥' => 'cerwjeny styrirožk',
    '🟧' => 'oranžowy styrirožk',
    '🟨' => 'žołty styrirožk',
    '🟩' => 'zeleny styrirožk',
    '🟦' => 'módry styrirožk',
    '🟪' => 'lylowy styrirožk',
    '🟫' => 'bruny styrirožk',
    '⬛' => 'wjeliki carny kwadrat',
    '⬜' => 'wjeliki běły kwadrat',
    '◼' => 'srjejźnowjeliki carny kwadrat',
    '◻' => 'srjejźnowjeliki běły kwadrat',
    '◾' => 'srjejźnomały carny kwadrat',
    '◽' => 'srjejźnomały běły kwadrat',
    '▪' => 'mały carny kwadrat',
    '▫' => 'mały běły kwadrat',
    '🔶' => 'wjeliki oranžojty rombus',
    '🔷' => 'wjeliki módry rombus',
    '🔸' => 'mały oranžojty rombus',
    '🔹' => 'mały módry rombus',
    '🔺' => 'cerwjeny tśirožk ze špicom górjej',
    '🔻' => 'cerwjeny tśirožk ze špicom dołoj',
    '💠' => 'rombus z dypkom',
    '🔘' => 'opciske pólo',
    '🔳' => 'běłe kwadratiske šaltowańske pólo',
    '🔲' => 'carne kwadratiske šaltowańske pólo',
    '🏁' => 'celowa chórgojcka',
    '🚩' => 'tśirožkata chórgojcka',
    '🎌' => 'pśekśicowane chórgoje',
    '🏴' => 'carna chórgoj',
    '🏳' => 'běła chórgoj',
];
