<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'ຈູບ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏻‍❤‍💋‍👨🏻' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ',
    '👨🏻‍❤‍💋‍👨🏼' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏻‍❤‍💋‍👨🏽' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👨🏻‍❤‍💋‍👨🏾' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏻‍❤‍💋‍👨🏿' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👨🏼‍❤‍💋‍👨🏻' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏼‍❤‍💋‍👨🏼' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏼‍❤‍💋‍👨🏽' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏼‍❤‍💋‍👨🏾' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏼‍❤‍💋‍👨🏿' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏽‍❤‍💋‍👨🏻' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏽‍❤‍💋‍👨🏼' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍❤‍💋‍👨🏽' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ',
    '👨🏽‍❤‍💋‍👨🏾' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏽‍❤‍💋‍👨🏿' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏾‍❤‍💋‍👨🏻' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏾‍❤‍💋‍👨🏼' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏾‍❤‍💋‍👨🏽' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏾‍❤‍💋‍👨🏾' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏾‍❤‍💋‍👨🏿' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏿‍❤‍💋‍👨🏻' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👨🏿‍❤‍💋‍👨🏼' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏿‍❤‍💋‍👨🏽' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👨🏿‍❤‍💋‍👨🏾' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍❤‍💋‍👨🏿' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ',
    '👩🏻‍❤‍💋‍👨🏻' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ',
    '👩🏻‍❤‍💋‍👨🏼' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏻‍❤‍💋‍👨🏽' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👩🏻‍❤‍💋‍👨🏾' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍❤‍💋‍👨🏿' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👩🏼‍❤‍💋‍👨🏻' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏼‍❤‍💋‍👨🏼' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏼‍❤‍💋‍👨🏽' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏼‍❤‍💋‍👨🏾' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏼‍❤‍💋‍👨🏿' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏽‍❤‍💋‍👨🏻' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏽‍❤‍💋‍👨🏼' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍❤‍💋‍👨🏽' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ',
    '👩🏽‍❤‍💋‍👨🏾' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏽‍❤‍💋‍👨🏿' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏾‍❤‍💋‍👨🏻' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏾‍❤‍💋‍👨🏼' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏾‍❤‍💋‍👨🏽' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏾‍❤‍💋‍👨🏾' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏾‍❤‍💋‍👨🏿' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏿‍❤‍💋‍👨🏻' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👩🏿‍❤‍💋‍👨🏼' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏿‍❤‍💋‍👨🏽' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👩🏿‍❤‍💋‍👨🏾' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍❤‍💋‍👨🏿' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ',
    '👩🏻‍❤‍💋‍👩🏻' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ',
    '👩🏻‍❤‍💋‍👩🏼' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏻‍❤‍💋‍👩🏽' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👩🏻‍❤‍💋‍👩🏾' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍❤‍💋‍👩🏿' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👩🏼‍❤‍💋‍👩🏻' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏼‍❤‍💋‍👩🏼' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏼‍❤‍💋‍👩🏽' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏼‍❤‍💋‍👩🏾' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏼‍❤‍💋‍👩🏿' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏽‍❤‍💋‍👩🏻' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏽‍❤‍💋‍👩🏼' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍❤‍💋‍👩🏽' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ',
    '👩🏽‍❤‍💋‍👩🏾' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏽‍❤‍💋‍👩🏿' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏾‍❤‍💋‍👩🏻' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏾‍❤‍💋‍👩🏼' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏾‍❤‍💋‍👩🏽' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏾‍❤‍💋‍👩🏾' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏾‍❤‍💋‍👩🏿' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏿‍❤‍💋‍👩🏻' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👩🏿‍❤‍💋‍👩🏼' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏿‍❤‍💋‍👩🏽' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👩🏿‍❤‍💋‍👩🏾' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍❤‍💋‍👩🏿' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ',
    '🧑🏻‍🫯‍🧑🏼' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏻‍🫯‍🧑🏽' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '🧑🏻‍🫯‍🧑🏾' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏻‍🫯‍🧑🏿' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '🧑🏼‍🫯‍🧑🏻' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏼‍🫯‍🧑🏽' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏼‍🫯‍🧑🏾' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏼‍🫯‍🧑🏿' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏽‍🫯‍🧑🏻' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏽‍🫯‍🧑🏼' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🫯‍🧑🏾' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏽‍🫯‍🧑🏿' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏾‍🫯‍🧑🏻' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏾‍🫯‍🧑🏼' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏾‍🫯‍🧑🏽' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🫯‍🧑🏿' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏿‍🫯‍🧑🏻' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '🧑🏿‍🫯‍🧑🏼' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏿‍🫯‍🧑🏽' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '🧑🏿‍🫯‍🧑🏾' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏻‍❤‍🧑🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏻‍❤‍🧑🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '🧑🏻‍❤‍🧑🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏻‍❤‍🧑🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '🧑🏼‍❤‍🧑🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏼‍❤‍🧑🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏼‍❤‍🧑🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏼‍❤‍🧑🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏽‍❤‍🧑🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏽‍❤‍🧑🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍❤‍🧑🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏽‍❤‍🧑🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏾‍❤‍🧑🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏾‍❤‍🧑🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏾‍❤‍🧑🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏾‍❤‍🧑🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏿‍❤‍🧑🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '🧑🏿‍❤‍🧑🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏿‍❤‍🧑🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '🧑🏿‍❤‍🧑🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏻‍🐰‍🧑🏼' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏻‍🐰‍🧑🏽' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '🧑🏻‍🐰‍🧑🏾' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏻‍🐰‍🧑🏿' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '🧑🏼‍🐰‍🧑🏻' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏼‍🐰‍🧑🏽' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏼‍🐰‍🧑🏾' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏼‍🐰‍🧑🏿' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏽‍🐰‍🧑🏻' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏽‍🐰‍🧑🏼' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🐰‍🧑🏾' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏽‍🐰‍🧑🏿' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏾‍🐰‍🧑🏻' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏾‍🐰‍🧑🏼' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏾‍🐰‍🧑🏽' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🐰‍🧑🏿' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏿‍🐰‍🧑🏻' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '🧑🏿‍🐰‍🧑🏼' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏿‍🐰‍🧑🏽' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '🧑🏿‍🐰‍🧑🏾' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏻‍🫯‍👨🏼' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏻‍🫯‍👨🏽' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👨🏻‍🫯‍👨🏾' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏻‍🫯‍👨🏿' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👨🏼‍🫯‍👨🏻' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏼‍🫯‍👨🏽' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏼‍🫯‍👨🏾' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏼‍🫯‍👨🏿' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏽‍🫯‍👨🏻' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏽‍🫯‍👨🏼' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🫯‍👨🏾' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏽‍🫯‍👨🏿' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏾‍🫯‍👨🏻' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏾‍🫯‍👨🏼' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏾‍🫯‍👨🏽' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏾‍🫯‍👨🏿' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏿‍🫯‍👨🏻' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👨🏿‍🫯‍👨🏼' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏿‍🫯‍👨🏽' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👨🏿‍🫯‍👨🏾' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏻‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ',
    '👨🏻‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏻‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👨🏻‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏻‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👨🏼‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏼‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏼‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏼‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏼‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏽‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏽‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ',
    '👨🏽‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏽‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏾‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏾‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏾‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏾‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏾‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏿‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👨🏿‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏿‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👨🏿‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ',
    '👨🏻‍🐰‍👨🏼' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏻‍🐰‍👨🏽' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👨🏻‍🐰‍👨🏾' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏻‍🐰‍👨🏿' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👨🏼‍🐰‍👨🏻' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏼‍🐰‍👨🏽' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏼‍🐰‍👨🏾' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏼‍🐰‍👨🏿' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏽‍🐰‍👨🏻' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏽‍🐰‍👨🏼' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🐰‍👨🏾' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏽‍🐰‍👨🏿' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏾‍🐰‍👨🏻' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏾‍🐰‍👨🏼' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏾‍🐰‍👨🏽' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏾‍🐰‍👨🏿' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏿‍🐰‍👨🏻' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👨🏿‍🐰‍👨🏼' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏿‍🐰‍👨🏽' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👨🏿‍🐰‍👨🏾' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍🫯‍👩🏼' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏻‍🫯‍👩🏽' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👩🏻‍🫯‍👩🏾' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍🫯‍👩🏿' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👩🏼‍🫯‍👩🏻' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏼‍🫯‍👩🏽' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏼‍🫯‍👩🏾' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏼‍🫯‍👩🏿' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏽‍🫯‍👩🏻' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏽‍🫯‍👩🏼' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🫯‍👩🏾' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏽‍🫯‍👩🏿' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏾‍🫯‍👩🏻' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏾‍🫯‍👩🏼' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏾‍🫯‍👩🏽' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏾‍🫯‍👩🏿' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏿‍🫯‍👩🏻' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👩🏿‍🫯‍👩🏼' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏿‍🫯‍👩🏽' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👩🏿‍🫯‍👩🏾' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ',
    '👩🏻‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏻‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👩🏻‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👩🏼‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏼‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏼‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏼‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏼‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏽‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏽‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ',
    '👩🏽‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏽‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏾‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏾‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏾‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏾‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏾‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏿‍❤‍👨🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👩🏿‍❤‍👨🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏿‍❤‍👨🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👩🏿‍❤‍👨🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍❤‍👨🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ, ສີຜິວໂທນດຳ',
    '👩🏻‍❤‍👩🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ',
    '👩🏻‍❤‍👩🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏻‍❤‍👩🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👩🏻‍❤‍👩🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍❤‍👩🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👩🏼‍❤‍👩🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏼‍❤‍👩🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏼‍❤‍👩🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏼‍❤‍👩🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏼‍❤‍👩🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏽‍❤‍👩🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏽‍❤‍👩🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍❤‍👩🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ',
    '👩🏽‍❤‍👩🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏽‍❤‍👩🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏾‍❤‍👩🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏾‍❤‍👩🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏾‍❤‍👩🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏾‍❤‍👩🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏾‍❤‍👩🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏿‍❤‍👩🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👩🏿‍❤‍👩🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏿‍❤‍👩🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👩🏿‍❤‍👩🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍❤‍👩🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ, ສີຜິວໂທນດຳ',
    '👩🏻‍🐰‍👩🏼' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏻‍🐰‍👩🏽' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👩🏻‍🐰‍👩🏾' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍🐰‍👩🏿' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👩🏼‍🐰‍👩🏻' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏼‍🐰‍👩🏽' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏼‍🐰‍👩🏾' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏼‍🐰‍👩🏿' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏽‍🐰‍👩🏻' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏽‍🐰‍👩🏼' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🐰‍👩🏾' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏽‍🐰‍👩🏿' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏾‍🐰‍👩🏻' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏾‍🐰‍👩🏼' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏾‍🐰‍👩🏽' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏾‍🐰‍👩🏿' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏿‍🐰‍👩🏻' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👩🏿‍🐰‍👩🏼' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏿‍🐰‍👩🏽' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👩🏿‍🐰‍👩🏾' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏻‍🤝‍🧑🏻' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວ',
    '🧑🏻‍🤝‍🧑🏼' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏻‍🤝‍🧑🏽' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '🧑🏻‍🤝‍🧑🏾' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏻‍🤝‍🧑🏿' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '🧑🏼‍🤝‍🧑🏻' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏼‍🤝‍🧑🏼' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏼‍🤝‍🧑🏽' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏼‍🤝‍🧑🏾' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏼‍🤝‍🧑🏿' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏽‍🤝‍🧑🏻' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏽‍🤝‍🧑🏼' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🤝‍🧑🏽' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນປານກາງ',
    '🧑🏽‍🤝‍🧑🏾' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏽‍🤝‍🧑🏿' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏾‍🤝‍🧑🏻' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '🧑🏾‍🤝‍🧑🏼' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏾‍🤝‍🧑🏽' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🤝‍🧑🏾' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏾‍🤝‍🧑🏿' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '🧑🏿‍🤝‍🧑🏻' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '🧑🏿‍🤝‍🧑🏼' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏿‍🤝‍🧑🏽' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '🧑🏿‍🤝‍🧑🏾' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🤝‍🧑🏿' => 'ຄົນຈັບມືກັນ: ສີຜິວໂທນດຳ',
    '👩🏻‍🤝‍👩🏼' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏻‍🤝‍👩🏽' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👩🏻‍🤝‍👩🏾' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍🤝‍👩🏿' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👩🏼‍🤝‍👩🏻' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏼‍🤝‍👩🏽' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏼‍🤝‍👩🏾' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏼‍🤝‍👩🏿' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏽‍🤝‍👩🏻' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏽‍🤝‍👩🏼' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🤝‍👩🏾' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏽‍🤝‍👩🏿' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏾‍🤝‍👩🏻' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏾‍🤝‍👩🏼' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏾‍🤝‍👩🏽' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏾‍🤝‍👩🏿' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏿‍🤝‍👩🏻' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👩🏿‍🤝‍👩🏼' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏿‍🤝‍👩🏽' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👩🏿‍🤝‍👩🏾' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍🤝‍👨🏼' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏻‍🤝‍👨🏽' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👩🏻‍🤝‍👨🏾' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏻‍🤝‍👨🏿' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👩🏼‍🤝‍👨🏻' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏼‍🤝‍👨🏽' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏼‍🤝‍👨🏾' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏼‍🤝‍👨🏿' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏽‍🤝‍👨🏻' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏽‍🤝‍👨🏼' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🤝‍👨🏾' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👩🏽‍🤝‍👨🏿' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏾‍🤝‍👨🏻' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👩🏾‍🤝‍👨🏼' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏾‍🤝‍👨🏽' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👩🏾‍🤝‍👨🏿' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👩🏿‍🤝‍👨🏻' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👩🏿‍🤝‍👨🏼' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👩🏿‍🤝‍👨🏽' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👩🏿‍🤝‍👨🏾' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏻‍🤝‍👨🏼' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏻‍🤝‍👨🏽' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '👨🏻‍🤝‍👨🏾' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏻‍🤝‍👨🏿' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '👨🏼‍🤝‍👨🏻' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏼‍🤝‍👨🏽' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏼‍🤝‍👨🏾' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏼‍🤝‍👨🏿' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏽‍🤝‍👨🏻' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏽‍🤝‍👨🏼' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🤝‍👨🏾' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '👨🏽‍🤝‍👨🏿' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏾‍🤝‍👨🏻' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '👨🏾‍🤝‍👨🏼' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏾‍🤝‍👨🏽' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '👨🏾‍🤝‍👨🏿' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '👨🏿‍🤝‍👨🏻' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '👨🏿‍🤝‍👨🏼' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '👨🏿‍🤝‍👨🏽' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '👨🏿‍🤝‍👨🏾' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '👩‍❤‍💋‍👨' => 'ຈູບ: ແມ່ຍິງ, ຜູ້ຊາຍ',
    '👨‍❤‍💋‍👨' => 'ຈູບ: ຜູ້ຊາຍ, ຜູ້ຊາຍ',
    '👩‍❤‍💋‍👩' => 'ຈູບ: ແມ່ຍິງ, ແມ່ຍິງ',
    '👨‍👩‍👧‍👦' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ແມ່ຍິງ, ເດັກຍິງ, ເດັກຊາຍ',
    '👨‍👩‍👦‍👦' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ແມ່ຍິງ, ເດັກຊາຍ, ເດັກຊາຍ',
    '👨‍👩‍👧‍👧' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ແມ່ຍິງ, ເດັກຍິງ, ເດັກຍິງ',
    '👨‍👨‍👧‍👦' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ເດັກຍິງ, ເດັກຊາຍ',
    '👨‍👨‍👦‍👦' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ເດັກຊາຍ, ເດັກຊາຍ',
    '👨‍👨‍👧‍👧' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ເດັກຍິງ, ເດັກຍິງ',
    '👩‍👩‍👧‍👦' => 'ຄອບຄົວ: ແມ່ຍິງ, ແມ່ຍິງ, ເດັກຍິງ, ເດັກຊາຍ',
    '👩‍👩‍👦‍👦' => 'ຄອບຄົວ: ແມ່ຍິງ, ແມ່ຍິງ, ເດັກຊາຍ, ເດັກຊາຍ',
    '👩‍👩‍👧‍👧' => 'ຄອບຄົວ: ແມ່ຍິງ, ແມ່ຍິງ, ເດັກຍິງ, ເດັກຍິງ',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'ທຸງ: ອັງກິດ',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'ທຸງ: ສະກັອດແລນ',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'ທຸງ: ເວລສ໌',
    '🧑‍🧑‍🧒‍🧒' => 'ຄອບຄົວ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ເດັກນ້ອຍ, ເດັກນ້ອຍ',
    '🚶🏻‍♀‍➡' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏼‍♀‍➡' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏽‍♀‍➡' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏾‍♀‍➡' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏿‍♀‍➡' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏻‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏼‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏽‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏾‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏿‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏻‍♀‍➡' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏼‍♀‍➡' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏽‍♀‍➡' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏾‍♀‍➡' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏿‍♀‍➡' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏻‍♂‍➡' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏼‍♂‍➡' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏽‍♂‍➡' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏾‍♂‍➡' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏿‍♂‍➡' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏻‍🦯‍➡' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏼‍🦯‍➡' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏽‍🦯‍➡' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏾‍🦯‍➡' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏿‍🦯‍➡' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏻‍🦯‍➡' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏼‍🦯‍➡' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏽‍🦯‍➡' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏾‍🦯‍➡' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏿‍🦯‍➡' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏻‍🦯‍➡' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏼‍🦯‍➡' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏽‍🦯‍➡' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏾‍🦯‍➡' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏿‍🦯‍➡' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏻‍🦼‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏼‍🦼‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏽‍🦼‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏾‍🦼‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏿‍🦼‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏻‍🦼‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏼‍🦼‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏽‍🦼‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏾‍🦼‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏿‍🦼‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏻‍🦼‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏼‍🦼‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏽‍🦼‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏾‍🦼‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏿‍🦼‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏻‍🦽‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏼‍🦽‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏽‍🦽‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏾‍🦽‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏿‍🦽‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏻‍🦽‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏼‍🦽‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏽‍🦽‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏾‍🦽‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👨🏿‍🦽‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏻‍🦽‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏼‍🦽‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏽‍🦽‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏾‍🦽‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '👩🏿‍🦽‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏻‍♀‍➡' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏼‍♀‍➡' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏽‍♀‍➡' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏾‍♀‍➡' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏿‍♀‍➡' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏻‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏼‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏽‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏾‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏿‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🫱🏻‍🫲🏼' => 'ຈັບມື: ສີຜິວໂທນຂາວ, ສີຜິວໂທນຂາວປານກາງ',
    '🫱🏻‍🫲🏽' => 'ຈັບມື: ສີຜິວໂທນຂາວ, ສີຜິວໂທນປານກາງ',
    '🫱🏻‍🫲🏾' => 'ຈັບມື: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳປານກາງ',
    '🫱🏻‍🫲🏿' => 'ຈັບມື: ສີຜິວໂທນຂາວ, ສີຜິວໂທນດຳ',
    '🫱🏼‍🫲🏻' => 'ຈັບມື: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນຂາວ',
    '🫱🏼‍🫲🏽' => 'ຈັບມື: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນປານກາງ',
    '🫱🏼‍🫲🏾' => 'ຈັບມື: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🫱🏼‍🫲🏿' => 'ຈັບມື: ສີຜິວໂທນຂາວປານກາງ, ສີຜິວໂທນດຳ',
    '🫱🏽‍🫲🏻' => 'ຈັບມື: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວ',
    '🫱🏽‍🫲🏼' => 'ຈັບມື: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🫱🏽‍🫲🏾' => 'ຈັບມື: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳປານກາງ',
    '🫱🏽‍🫲🏿' => 'ຈັບມື: ສີຜິວໂທນປານກາງ, ສີຜິວໂທນດຳ',
    '🫱🏾‍🫲🏻' => 'ຈັບມື: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວ',
    '🫱🏾‍🫲🏼' => 'ຈັບມື: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນຂາວປານກາງ',
    '🫱🏾‍🫲🏽' => 'ຈັບມື: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນປານກາງ',
    '🫱🏾‍🫲🏿' => 'ຈັບມື: ສີຜິວໂທນດຳປານກາງ, ສີຜິວໂທນດຳ',
    '🫱🏿‍🫲🏻' => 'ຈັບມື: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວ',
    '🫱🏿‍🫲🏼' => 'ຈັບມື: ສີຜິວໂທນດຳ, ສີຜິວໂທນຂາວປານກາງ',
    '🫱🏿‍🫲🏽' => 'ຈັບມື: ສີຜິວໂທນດຳ, ສີຜິວໂທນປານກາງ',
    '🫱🏿‍🫲🏾' => 'ຈັບມື: ສີຜິວໂທນດຳ, ສີຜິວໂທນດຳປານກາງ',
    '🚶‍♀‍➡' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ຫັນໄປເບື້ອງຂວາ',
    '🚶‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ຫັນໄປເບື້ອງຂວາ',
    '🧎‍♀‍➡' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ຫັນໄປເບື້ອງຂວາ',
    '🧎‍♂‍➡' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ຫັນໄປເບື້ອງຂວາ',
    '🧑‍🦯‍➡' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ຫັນໄປເບື້ອງຂວາ',
    '👨‍🦯‍➡' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ຫັນໄປເບື້ອງຂວາ',
    '👩‍🦯‍➡' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ຫັນໄປເບື້ອງຂວາ',
    '🧑‍🦼‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ຫັນໄປເບື້ອງຂວາ',
    '👨‍🦼‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ຫັນໄປເບື້ອງຂວາ',
    '👩‍🦼‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ຫັນໄປເບື້ອງຂວາ',
    '🧑‍🦽‍➡' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ຫັນໄປເບື້ອງຂວາ',
    '👨‍🦽‍➡' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ຫັນໄປເບື້ອງຂວາ',
    '👩‍🦽‍➡' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ຫັນໄປເບື້ອງຂວາ',
    '🏃‍♀‍➡' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ຫັນໄປເບື້ອງຂວາ',
    '🏃‍♂‍➡' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ຫັນໄປເບື້ອງຂວາ',
    '👩‍❤‍👨' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ຜູ້ຊາຍ',
    '👨‍❤‍👨' => 'ຄູ່ຮັກກັບຫົວໃຈ: ຜູ້ຊາຍ, ຜູ້ຊາຍ',
    '👩‍❤‍👩' => 'ຄູ່ຮັກກັບຫົວໃຈ: ແມ່ຍິງ, ແມ່ຍິງ',
    '👨‍👩‍👦' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ແມ່ຍິງ, ເດັກຊາຍ',
    '👨‍👩‍👧' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ແມ່ຍິງ, ເດັກຍິງ',
    '👨‍👨‍👦' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ເດັກຊາຍ',
    '👨‍👨‍👧' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ຜູ້ຊາຍ, ເດັກຍິງ',
    '👩‍👩‍👦' => 'ຄອບຄົວ: ແມ່ຍິງ, ແມ່ຍິງ, ເດັກຊາຍ',
    '👩‍👩‍👧' => 'ຄອບຄົວ: ແມ່ຍິງ, ແມ່ຍິງ, ເດັກຍິງ',
    '👨‍👦‍👦' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ເດັກຊາຍ, ເດັກຊາຍ',
    '👨‍👧‍👦' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ເດັກຍິງ, ເດັກຊາຍ',
    '👨‍👧‍👧' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ເດັກຍິງ, ເດັກຍິງ',
    '👩‍👦‍👦' => 'ຄອບຄົວ: ແມ່ຍິງ, ເດັກຊາຍ, ເດັກຊາຍ',
    '👩‍👧‍👦' => 'ຄອບຄົວ: ແມ່ຍິງ, ເດັກຍິງ, ເດັກຊາຍ',
    '👩‍👧‍👧' => 'ຄອບຄົວ: ແມ່ຍິງ, ເດັກຍິງ, ເດັກຍິງ',
    '🧑‍🤝‍🧑' => 'ຄົນຈັບມືກັນ',
    '🧑‍🧑‍🧒' => 'ຄອບຄົວ: ຜູ້ໃຫຍ່, ຜູ້ໃຫຍ່, ເດັກນ້ອຍ',
    '🧑‍🧒‍🧒' => 'ຄອບຄົວ: ຜູ້ໃຫຍ່, ເດັກນ້ອຍ, ເດັກນ້ອຍ',
    '🧑🏻‍🦰' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວ, ຜົມແດງ',
    '🧑🏼‍🦰' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວປານກາງ, ຜົມແດງ',
    '🧑🏽‍🦰' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນປານກາງ, ຜົມແດງ',
    '🧑🏾‍🦰' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳປານກາງ, ຜົມແດງ',
    '🧑🏿‍🦰' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳ, ຜົມແດງ',
    '🧑🏻‍🦱' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວ, ຜົມກູດ',
    '🧑🏼‍🦱' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວປານກາງ, ຜົມກູດ',
    '🧑🏽‍🦱' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນປານກາງ, ຜົມກູດ',
    '🧑🏾‍🦱' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳປານກາງ, ຜົມກູດ',
    '🧑🏿‍🦱' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳ, ຜົມກູດ',
    '🧑🏻‍🦳' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວ, ຜົມຫງອກ',
    '🧑🏼‍🦳' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວປານກາງ, ຜົມຫງອກ',
    '🧑🏽‍🦳' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນປານກາງ, ຜົມຫງອກ',
    '🧑🏾‍🦳' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳປານກາງ, ຜົມຫງອກ',
    '🧑🏿‍🦳' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳ, ຜົມຫງອກ',
    '🧑🏻‍🦲' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວ, ຫົວລ້ານ',
    '🧑🏼‍🦲' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວປານກາງ, ຫົວລ້ານ',
    '🧑🏽‍🦲' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນປານກາງ, ຫົວລ້ານ',
    '🧑🏾‍🦲' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳປານກາງ, ຫົວລ້ານ',
    '🧑🏿‍🦲' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳ, ຫົວລ້ານ',
    '🧑🏻‍🩰' => 'ນັກເຕັ້ນບາເລ້: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🩰' => 'ນັກເຕັ້ນບາເລ້: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🩰' => 'ນັກເຕັ້ນບາເລ້: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🩰' => 'ນັກເຕັ້ນບາເລ້: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🩰' => 'ນັກເຕັ້ນບາເລ້: ສີຜິວໂທນດຳ',
    '🧔🏻‍♂' => 'ຜູ້ຊາຍມີໜວດ: ສີຜິວໂທນຂາວ',
    '🧔🏼‍♂' => 'ຜູ້ຊາຍມີໜວດ: ສີຜິວໂທນຂາວປານກາງ',
    '🧔🏽‍♂' => 'ຜູ້ຊາຍມີໜວດ: ສີຜິວໂທນປານກາງ',
    '🧔🏾‍♂' => 'ຜູ້ຊາຍມີໜວດ: ສີຜິວໂທນດຳປານກາງ',
    '🧔🏿‍♂' => 'ຜູ້ຊາຍມີໜວດ: ສີຜິວໂທນດຳ',
    '👱🏻‍♂' => 'ຊາຍຜົມບລອນ: ສີຜິວໂທນຂາວ',
    '👱🏼‍♂' => 'ຊາຍຜົມບລອນ: ສີຜິວໂທນຂາວປານກາງ',
    '👱🏽‍♂' => 'ຊາຍຜົມບລອນ: ສີຜິວໂທນປານກາງ',
    '👱🏾‍♂' => 'ຊາຍຜົມບລອນ: ສີຜິວໂທນດຳປານກາງ',
    '👱🏿‍♂' => 'ຊາຍຜົມບລອນ: ສີຜິວໂທນດຳ',
    '👨🏻‍🦰' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວ, ຜົມແດງ',
    '👨🏼‍🦰' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ, ຜົມແດງ',
    '👨🏽‍🦰' => 'ຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ, ຜົມແດງ',
    '👨🏾‍🦰' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ, ຜົມແດງ',
    '👨🏿‍🦰' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳ, ຜົມແດງ',
    '👨🏻‍🦱' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວ, ຜົມກູດ',
    '👨🏼‍🦱' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ, ຜົມກູດ',
    '👨🏽‍🦱' => 'ຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ, ຜົມກູດ',
    '👨🏾‍🦱' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ, ຜົມກູດ',
    '👨🏿‍🦱' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳ, ຜົມກູດ',
    '👨🏻‍🦳' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວ, ຜົມຫງອກ',
    '👨🏼‍🦳' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ, ຜົມຫງອກ',
    '👨🏽‍🦳' => 'ຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ, ຜົມຫງອກ',
    '👨🏾‍🦳' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ, ຜົມຫງອກ',
    '👨🏿‍🦳' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳ, ຜົມຫງອກ',
    '👨🏻‍🦲' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວ, ຫົວລ້ານ',
    '👨🏼‍🦲' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ, ຫົວລ້ານ',
    '👨🏽‍🦲' => 'ຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ, ຫົວລ້ານ',
    '👨🏾‍🦲' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ, ຫົວລ້ານ',
    '👨🏿‍🦲' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳ, ຫົວລ້ານ',
    '🧔🏻‍♀' => 'ຜູ້ຍິງມີໜວດ: ສີຜິວໂທນຂາວ',
    '🧔🏼‍♀' => 'ຜູ້ຍິງມີໜວດ: ສີຜິວໂທນຂາວປານກາງ',
    '🧔🏽‍♀' => 'ຜູ້ຍິງມີໜວດ: ສີຜິວໂທນປານກາງ',
    '🧔🏾‍♀' => 'ຜູ້ຍິງມີໜວດ: ສີຜິວໂທນດຳປານກາງ',
    '🧔🏿‍♀' => 'ຜູ້ຍິງມີໜວດ: ສີຜິວໂທນດຳ',
    '👱🏻‍♀' => 'ຍິງຜົມບລອນ: ສີຜິວໂທນຂາວ',
    '👱🏼‍♀' => 'ຍິງຜົມບລອນ: ສີຜິວໂທນຂາວປານກາງ',
    '👱🏽‍♀' => 'ຍິງຜົມບລອນ: ສີຜິວໂທນປານກາງ',
    '👱🏾‍♀' => 'ຍິງຜົມບລອນ: ສີຜິວໂທນດຳປານກາງ',
    '👱🏿‍♀' => 'ຍິງຜົມບລອນ: ສີຜິວໂທນດຳ',
    '👩🏻‍🦰' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວ, ຜົມແດງ',
    '👩🏼‍🦰' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວປານກາງ, ຜົມແດງ',
    '👩🏽‍🦰' => 'ແມ່ຍິງ: ສີຜິວໂທນປານກາງ, ຜົມແດງ',
    '👩🏾‍🦰' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳປານກາງ, ຜົມແດງ',
    '👩🏿‍🦰' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳ, ຜົມແດງ',
    '👩🏻‍🦱' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວ, ຜົມກູດ',
    '👩🏼‍🦱' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວປານກາງ, ຜົມກູດ',
    '👩🏽‍🦱' => 'ແມ່ຍິງ: ສີຜິວໂທນປານກາງ, ຜົມກູດ',
    '👩🏾‍🦱' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳປານກາງ, ຜົມກູດ',
    '👩🏿‍🦱' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳ, ຜົມກູດ',
    '👩🏻‍🦳' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວ, ຜົມຫງອກ',
    '👩🏼‍🦳' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວປານກາງ, ຜົມຫງອກ',
    '👩🏽‍🦳' => 'ແມ່ຍິງ: ສີຜິວໂທນປານກາງ, ຜົມຫງອກ',
    '👩🏾‍🦳' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳປານກາງ, ຜົມຫງອກ',
    '👩🏿‍🦳' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳ, ຜົມຫງອກ',
    '👩🏻‍🦲' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວ, ຫົວລ້ານ',
    '👩🏼‍🦲' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວປານກາງ, ຫົວລ້ານ',
    '👩🏽‍🦲' => 'ແມ່ຍິງ: ສີຜິວໂທນປານກາງ, ຫົວລ້ານ',
    '👩🏾‍🦲' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳປານກາງ, ຫົວລ້ານ',
    '👩🏿‍🦲' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳ, ຫົວລ້ານ',
    '🙍🏻‍♂' => 'ຜູ້ຊາຍເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນຂາວ',
    '🙍🏼‍♂' => 'ຜູ້ຊາຍເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນຂາວປານກາງ',
    '🙍🏽‍♂' => 'ຜູ້ຊາຍເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນປານກາງ',
    '🙍🏾‍♂' => 'ຜູ້ຊາຍເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນດຳປານກາງ',
    '🙍🏿‍♂' => 'ຜູ້ຊາຍເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນດຳ',
    '🙍🏻‍♀' => 'ຜູ້ຍິງເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນຂາວ',
    '🙍🏼‍♀' => 'ຜູ້ຍິງເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນຂາວປານກາງ',
    '🙍🏽‍♀' => 'ຜູ້ຍິງເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນປານກາງ',
    '🙍🏾‍♀' => 'ຜູ້ຍິງເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນດຳປານກາງ',
    '🙍🏿‍♀' => 'ຜູ້ຍິງເຮັດໜ້າບຶ້ງ: ສີຜິວໂທນດຳ',
    '🙎🏻‍♂' => 'ຜູ້ຊາຍເບະສົບ: ສີຜິວໂທນຂາວ',
    '🙎🏼‍♂' => 'ຜູ້ຊາຍເບະສົບ: ສີຜິວໂທນຂາວປານກາງ',
    '🙎🏽‍♂' => 'ຜູ້ຊາຍເບະສົບ: ສີຜິວໂທນປານກາງ',
    '🙎🏾‍♂' => 'ຜູ້ຊາຍເບະສົບ: ສີຜິວໂທນດຳປານກາງ',
    '🙎🏿‍♂' => 'ຜູ້ຊາຍເບະສົບ: ສີຜິວໂທນດຳ',
    '🙎🏻‍♀' => 'ຜູ້ຍິງເບະສົບ: ສີຜິວໂທນຂາວ',
    '🙎🏼‍♀' => 'ຜູ້ຍິງເບະສົບ: ສີຜິວໂທນຂາວປານກາງ',
    '🙎🏽‍♀' => 'ຜູ້ຍິງເບະສົບ: ສີຜິວໂທນປານກາງ',
    '🙎🏾‍♀' => 'ຜູ້ຍິງເບະສົບ: ສີຜິວໂທນດຳປານກາງ',
    '🙎🏿‍♀' => 'ຜູ້ຍິງເບະສົບ: ສີຜິວໂທນດຳ',
    '🙅🏻‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນຂາວ',
    '🙅🏼‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນຂາວປານກາງ',
    '🙅🏽‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນປານກາງ',
    '🙅🏾‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນດຳປານກາງ',
    '🙅🏿‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນດຳ',
    '🙅🏻‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນຂາວ',
    '🙅🏼‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນຂາວປານກາງ',
    '🙅🏽‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນປານກາງ',
    '🙅🏾‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນດຳປານກາງ',
    '🙅🏿‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າບໍ່ໂອເຄ: ສີຜິວໂທນດຳ',
    '🙆🏻‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນຂາວ',
    '🙆🏼‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນຂາວປານກາງ',
    '🙆🏽‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນປານກາງ',
    '🙆🏾‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນດຳປານກາງ',
    '🙆🏿‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນດຳ',
    '🙆🏻‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນຂາວ',
    '🙆🏼‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນຂາວປານກາງ',
    '🙆🏽‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນປານກາງ',
    '🙆🏾‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນດຳປານກາງ',
    '🙆🏿‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າໂອເຄ: ສີຜິວໂທນດຳ',
    '💁🏻‍♂' => 'ຜູ້ຊາຍແບມື: ສີຜິວໂທນຂາວ',
    '💁🏼‍♂' => 'ຜູ້ຊາຍແບມື: ສີຜິວໂທນຂາວປານກາງ',
    '💁🏽‍♂' => 'ຜູ້ຊາຍແບມື: ສີຜິວໂທນປານກາງ',
    '💁🏾‍♂' => 'ຜູ້ຊາຍແບມື: ສີຜິວໂທນດຳປານກາງ',
    '💁🏿‍♂' => 'ຜູ້ຊາຍແບມື: ສີຜິວໂທນດຳ',
    '💁🏻‍♀' => 'ຜູ້ຍິງແບມື: ສີຜິວໂທນຂາວ',
    '💁🏼‍♀' => 'ຜູ້ຍິງແບມື: ສີຜິວໂທນຂາວປານກາງ',
    '💁🏽‍♀' => 'ຜູ້ຍິງແບມື: ສີຜິວໂທນປານກາງ',
    '💁🏾‍♀' => 'ຜູ້ຍິງແບມື: ສີຜິວໂທນດຳປານກາງ',
    '💁🏿‍♀' => 'ຜູ້ຍິງແບມື: ສີຜິວໂທນດຳ',
    '🙋🏻‍♂' => 'ຜູ້ຊາຍຍົກມື: ສີຜິວໂທນຂາວ',
    '🙋🏼‍♂' => 'ຜູ້ຊາຍຍົກມື: ສີຜິວໂທນຂາວປານກາງ',
    '🙋🏽‍♂' => 'ຜູ້ຊາຍຍົກມື: ສີຜິວໂທນປານກາງ',
    '🙋🏾‍♂' => 'ຜູ້ຊາຍຍົກມື: ສີຜິວໂທນດຳປານກາງ',
    '🙋🏿‍♂' => 'ຜູ້ຊາຍຍົກມື: ສີຜິວໂທນດຳ',
    '🙋🏻‍♀' => 'ຜູ້ຍິງຍົກມື: ສີຜິວໂທນຂາວ',
    '🙋🏼‍♀' => 'ຜູ້ຍິງຍົກມື: ສີຜິວໂທນຂາວປານກາງ',
    '🙋🏽‍♀' => 'ຜູ້ຍິງຍົກມື: ສີຜິວໂທນປານກາງ',
    '🙋🏾‍♀' => 'ຜູ້ຍິງຍົກມື: ສີຜິວໂທນດຳປານກາງ',
    '🙋🏿‍♀' => 'ຜູ້ຍິງຍົກມື: ສີຜິວໂທນດຳ',
    '🧏🏻‍♂' => 'ຜູ້​ຊາຍຫູ​ໜວກ: ສີຜິວໂທນຂາວ',
    '🧏🏼‍♂' => 'ຜູ້​ຊາຍຫູ​ໜວກ: ສີຜິວໂທນຂາວປານກາງ',
    '🧏🏽‍♂' => 'ຜູ້​ຊາຍຫູ​ໜວກ: ສີຜິວໂທນປານກາງ',
    '🧏🏾‍♂' => 'ຜູ້​ຊາຍຫູ​ໜວກ: ສີຜິວໂທນດຳປານກາງ',
    '🧏🏿‍♂' => 'ຜູ້​ຊາຍຫູ​ໜວກ: ສີຜິວໂທນດຳ',
    '🧏🏻‍♀' => 'ຜູ້​ຍິງ​ຫູ​ໜວກ: ສີຜິວໂທນຂາວ',
    '🧏🏼‍♀' => 'ຜູ້​ຍິງ​ຫູ​ໜວກ: ສີຜິວໂທນຂາວປານກາງ',
    '🧏🏽‍♀' => 'ຜູ້​ຍິງ​ຫູ​ໜວກ: ສີຜິວໂທນປານກາງ',
    '🧏🏾‍♀' => 'ຜູ້​ຍິງ​ຫູ​ໜວກ: ສີຜິວໂທນດຳປານກາງ',
    '🧏🏿‍♀' => 'ຜູ້​ຍິງ​ຫູ​ໜວກ: ສີຜິວໂທນດຳ',
    '🙇🏻‍♂' => 'ຜູ້ຊາຍກົ້ມຄຳນັບ: ສີຜິວໂທນຂາວ',
    '🙇🏼‍♂' => 'ຜູ້ຊາຍກົ້ມຄຳນັບ: ສີຜິວໂທນຂາວປານກາງ',
    '🙇🏽‍♂' => 'ຜູ້ຊາຍກົ້ມຄຳນັບ: ສີຜິວໂທນປານກາງ',
    '🙇🏾‍♂' => 'ຜູ້ຊາຍກົ້ມຄຳນັບ: ສີຜິວໂທນດຳປານກາງ',
    '🙇🏿‍♂' => 'ຜູ້ຊາຍກົ້ມຄຳນັບ: ສີຜິວໂທນດຳ',
    '🙇🏻‍♀' => 'ຜູ້ຍິງກົ້ມຄຳນັບ: ສີຜິວໂທນຂາວ',
    '🙇🏼‍♀' => 'ຜູ້ຍິງກົ້ມຄຳນັບ: ສີຜິວໂທນຂາວປານກາງ',
    '🙇🏽‍♀' => 'ຜູ້ຍິງກົ້ມຄຳນັບ: ສີຜິວໂທນປານກາງ',
    '🙇🏾‍♀' => 'ຜູ້ຍິງກົ້ມຄຳນັບ: ສີຜິວໂທນດຳປານກາງ',
    '🙇🏿‍♀' => 'ຜູ້ຍິງກົ້ມຄຳນັບ: ສີຜິວໂທນດຳ',
    '🤦🏻‍♂' => 'ຜູ້ຊາຍເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນຂາວ',
    '🤦🏼‍♂' => 'ຜູ້ຊາຍເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🤦🏽‍♂' => 'ຜູ້ຊາຍເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນປານກາງ',
    '🤦🏾‍♂' => 'ຜູ້ຊາຍເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🤦🏿‍♂' => 'ຜູ້ຊາຍເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນດຳ',
    '🤦🏻‍♀' => 'ຜູ້ຍິງເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນຂາວ',
    '🤦🏼‍♀' => 'ຜູ້ຍິງເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🤦🏽‍♀' => 'ຜູ້ຍິງເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນປານກາງ',
    '🤦🏾‍♀' => 'ຜູ້ຍິງເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🤦🏿‍♀' => 'ຜູ້ຍິງເອົາມືກ່າຍປິດໜ້າ: ສີຜິວໂທນດຳ',
    '🤷🏻‍♂' => 'ຜູ້ຊາຍຫໍ່ໄຫລ່: ສີຜິວໂທນຂາວ',
    '🤷🏼‍♂' => 'ຜູ້ຊາຍຫໍ່ໄຫລ່: ສີຜິວໂທນຂາວປານກາງ',
    '🤷🏽‍♂' => 'ຜູ້ຊາຍຫໍ່ໄຫລ່: ສີຜິວໂທນປານກາງ',
    '🤷🏾‍♂' => 'ຜູ້ຊາຍຫໍ່ໄຫລ່: ສີຜິວໂທນດຳປານກາງ',
    '🤷🏿‍♂' => 'ຜູ້ຊາຍຫໍ່ໄຫລ່: ສີຜິວໂທນດຳ',
    '🤷🏻‍♀' => 'ຜູ້ຍິງຫໍ່ໄຫລ່: ສີຜິວໂທນຂາວ',
    '🤷🏼‍♀' => 'ຜູ້ຍິງຫໍ່ໄຫລ່: ສີຜິວໂທນຂາວປານກາງ',
    '🤷🏽‍♀' => 'ຜູ້ຍິງຫໍ່ໄຫລ່: ສີຜິວໂທນປານກາງ',
    '🤷🏾‍♀' => 'ຜູ້ຍິງຫໍ່ໄຫລ່: ສີຜິວໂທນດຳປານກາງ',
    '🤷🏿‍♀' => 'ຜູ້ຍິງຫໍ່ໄຫລ່: ສີຜິວໂທນດຳ',
    '🧑🏻‍⚕' => 'ພະນັກງານກວດສຸຂະພາບ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍⚕' => 'ພະນັກງານກວດສຸຂະພາບ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍⚕' => 'ພະນັກງານກວດສຸຂະພາບ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍⚕' => 'ພະນັກງານກວດສຸຂະພາບ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍⚕' => 'ພະນັກງານກວດສຸຂະພາບ: ສີຜິວໂທນດຳ',
    '👨🏻‍⚕' => 'ຜູ້ຊາຍເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນຂາວ',
    '👨🏼‍⚕' => 'ຜູ້ຊາຍເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍⚕' => 'ຜູ້ຊາຍເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍⚕' => 'ຜູ້ຊາຍເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍⚕' => 'ຜູ້ຊາຍເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນດຳ',
    '👩🏻‍⚕' => 'ຜູ້ຍິງເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນຂາວ',
    '👩🏼‍⚕' => 'ຜູ້ຍິງເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍⚕' => 'ຜູ້ຍິງເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍⚕' => 'ຜູ້ຍິງເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍⚕' => 'ຜູ້ຍິງເຮັດວຽກສຸຂະພາບ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🎓' => 'ນັກຮຽນ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🎓' => 'ນັກຮຽນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🎓' => 'ນັກຮຽນ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🎓' => 'ນັກຮຽນ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🎓' => 'ນັກຮຽນ: ສີຜິວໂທນດຳ',
    '👨🏻‍🎓' => 'ນັກຮຽນຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🎓' => 'ນັກຮຽນຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🎓' => 'ນັກຮຽນຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🎓' => 'ນັກຮຽນຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🎓' => 'ນັກຮຽນຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🎓' => 'ນັກຮຽນຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🎓' => 'ນັກຮຽນຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🎓' => 'ນັກຮຽນຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🎓' => 'ນັກຮຽນຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🎓' => 'ນັກຮຽນຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🏫' => 'ອາຈານ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🏫' => 'ອາຈານ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🏫' => 'ອາຈານ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🏫' => 'ອາຈານ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🏫' => 'ອາຈານ: ສີຜິວໂທນດຳ',
    '👨🏻‍🏫' => 'ອາຈານຜູ້ຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🏫' => 'ອາຈານຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🏫' => 'ອາຈານຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🏫' => 'ອາຈານຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🏫' => 'ອາຈານຜູ້ຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🏫' => 'ອາຈານຜູ້ຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🏫' => 'ອາຈານຜູ້ຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🏫' => 'ອາຈານຜູ້ຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🏫' => 'ອາຈານຜູ້ຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🏫' => 'ອາຈານຜູ້ຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍⚖' => 'ຜູ້ພິພາກສາ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍⚖' => 'ຜູ້ພິພາກສາ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍⚖' => 'ຜູ້ພິພາກສາ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍⚖' => 'ຜູ້ພິພາກສາ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍⚖' => 'ຜູ້ພິພາກສາ: ສີຜິວໂທນດຳ',
    '👨🏻‍⚖' => 'ຜູ້ພິພາກສາຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍⚖' => 'ຜູ້ພິພາກສາຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍⚖' => 'ຜູ້ພິພາກສາຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍⚖' => 'ຜູ້ພິພາກສາຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍⚖' => 'ຜູ້ພິພາກສາຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍⚖' => 'ຜູ້ພິພາກສາຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍⚖' => 'ຜູ້ພິພາກສາຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍⚖' => 'ຜູ້ພິພາກສາຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍⚖' => 'ຜູ້ພິພາກສາຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍⚖' => 'ຜູ້ພິພາກສາຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🌾' => 'ຊາວນາ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🌾' => 'ຊາວນາ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🌾' => 'ຊາວນາ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🌾' => 'ຊາວນາ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🌾' => 'ຊາວນາ: ສີຜິວໂທນດຳ',
    '👨🏻‍🌾' => 'ຊາວນາຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🌾' => 'ຊາວນາຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🌾' => 'ຊາວນາຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🌾' => 'ຊາວນາຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🌾' => 'ຊາວນາຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🌾' => 'ຊາວນາຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🌾' => 'ຊາວນາຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🌾' => 'ຊາວນາຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🌾' => 'ຊາວນາຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🌾' => 'ຊາວນາຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🍳' => 'ແຕ່ງກິນ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🍳' => 'ແຕ່ງກິນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🍳' => 'ແຕ່ງກິນ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🍳' => 'ແຕ່ງກິນ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🍳' => 'ແຕ່ງກິນ: ສີຜິວໂທນດຳ',
    '👨🏻‍🍳' => 'ພໍ່ຄົວຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🍳' => 'ພໍ່ຄົວຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🍳' => 'ພໍ່ຄົວຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🍳' => 'ພໍ່ຄົວຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🍳' => 'ພໍ່ຄົວຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🍳' => 'ພໍ່ຄົວຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🍳' => 'ພໍ່ຄົວຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🍳' => 'ພໍ່ຄົວຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🍳' => 'ພໍ່ຄົວຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🍳' => 'ພໍ່ຄົວຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🔧' => 'ຊ່າງ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🔧' => 'ຊ່າງ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🔧' => 'ຊ່າງ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🔧' => 'ຊ່າງ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🔧' => 'ຊ່າງ: ສີຜິວໂທນດຳ',
    '👨🏻‍🔧' => 'ຊ່າງກົນຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🔧' => 'ຊ່າງກົນຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🔧' => 'ຊ່າງກົນຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🔧' => 'ຊ່າງກົນຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🔧' => 'ຊ່າງກົນຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🔧' => 'ຊ່າງກົນຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🔧' => 'ຊ່າງກົນຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🔧' => 'ຊ່າງກົນຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🔧' => 'ຊ່າງກົນຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🔧' => 'ຊ່າງກົນຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🏭' => 'ຄົນງານໃນໂຮງງານ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🏭' => 'ຄົນງານໃນໂຮງງານ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🏭' => 'ຄົນງານໃນໂຮງງານ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🏭' => 'ຄົນງານໃນໂຮງງານ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🏭' => 'ຄົນງານໃນໂຮງງານ: ສີຜິວໂທນດຳ',
    '👨🏻‍🏭' => 'ພະນັກງານໂຮງງານຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🏭' => 'ພະນັກງານໂຮງງານຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🏭' => 'ພະນັກງານໂຮງງານຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🏭' => 'ພະນັກງານໂຮງງານຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🏭' => 'ພະນັກງານໂຮງງານຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🏭' => 'ພະນັກງານໂຮງງານຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🏭' => 'ພະນັກງານໂຮງງານຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🏭' => 'ພະນັກງານໂຮງງານຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🏭' => 'ພະນັກງານໂຮງງານຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🏭' => 'ພະນັກງານໂຮງງານຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍💼' => 'ພະນັກງານຫ້ອງການ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍💼' => 'ພະນັກງານຫ້ອງການ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍💼' => 'ພະນັກງານຫ້ອງການ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍💼' => 'ພະນັກງານຫ້ອງການ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍💼' => 'ພະນັກງານຫ້ອງການ: ສີຜິວໂທນດຳ',
    '👨🏻‍💼' => 'ພະນັກງານຫ້ອງການຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍💼' => 'ພະນັກງານຫ້ອງການຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍💼' => 'ພະນັກງານຫ້ອງການຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍💼' => 'ພະນັກງານຫ້ອງການຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍💼' => 'ພະນັກງານຫ້ອງການຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍💼' => 'ພະນັກງານຫ້ອງການຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍💼' => 'ພະນັກງານຫ້ອງການຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍💼' => 'ພະນັກງານຫ້ອງການຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍💼' => 'ພະນັກງານຫ້ອງການຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍💼' => 'ພະນັກງານຫ້ອງການຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🔬' => 'ນັກວິທະຍາສາດ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🔬' => 'ນັກວິທະຍາສາດ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🔬' => 'ນັກວິທະຍາສາດ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🔬' => 'ນັກວິທະຍາສາດ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🔬' => 'ນັກວິທະຍາສາດ: ສີຜິວໂທນດຳ',
    '👨🏻‍🔬' => 'ນັກວິທະຍາສາດຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🔬' => 'ນັກວິທະຍາສາດຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🔬' => 'ນັກວິທະຍາສາດຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🔬' => 'ນັກວິທະຍາສາດຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🔬' => 'ນັກວິທະຍາສາດຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🔬' => 'ນັກວິທະຍາສາດຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🔬' => 'ນັກວິທະຍາສາດຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🔬' => 'ນັກວິທະຍາສາດຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🔬' => 'ນັກວິທະຍາສາດຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🔬' => 'ນັກວິທະຍາສາດຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍💻' => 'ນັກເຕັກນິກ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍💻' => 'ນັກເຕັກນິກ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍💻' => 'ນັກເຕັກນິກ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍💻' => 'ນັກເຕັກນິກ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍💻' => 'ນັກເຕັກນິກ: ສີຜິວໂທນດຳ',
    '👨🏻‍💻' => 'ນັກເທັກໂນໂລຢີຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍💻' => 'ນັກເທັກໂນໂລຢີຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍💻' => 'ນັກເທັກໂນໂລຢີຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍💻' => 'ນັກເທັກໂນໂລຢີຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍💻' => 'ນັກເທັກໂນໂລຢີຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍💻' => 'ນັກເທັກໂນໂລຢີຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍💻' => 'ນັກເທັກໂນໂລຢີຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍💻' => 'ນັກເທັກໂນໂລຢີຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍💻' => 'ນັກເທັກໂນໂລຢີຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍💻' => 'ນັກເທັກໂນໂລຢີຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🎤' => 'ນັກຮ້ອງ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🎤' => 'ນັກຮ້ອງ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🎤' => 'ນັກຮ້ອງ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🎤' => 'ນັກຮ້ອງ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🎤' => 'ນັກຮ້ອງ: ສີຜິວໂທນດຳ',
    '👨🏻‍🎤' => 'ນັກຮ້ອງຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🎤' => 'ນັກຮ້ອງຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🎤' => 'ນັກຮ້ອງຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🎤' => 'ນັກຮ້ອງຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🎤' => 'ນັກຮ້ອງຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🎤' => 'ນັກຮ້ອງຜູ້ຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🎤' => 'ນັກຮ້ອງຜູ້ຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🎤' => 'ນັກຮ້ອງຜູ້ຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🎤' => 'ນັກຮ້ອງຜູ້ຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🎤' => 'ນັກຮ້ອງຜູ້ຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🎨' => 'ສິນລະປິນ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🎨' => 'ສິນລະປິນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🎨' => 'ສິນລະປິນ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🎨' => 'ສິນລະປິນ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🎨' => 'ສິນລະປິນ: ສີຜິວໂທນດຳ',
    '👨🏻‍🎨' => 'ສິນລະປິນຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🎨' => 'ສິນລະປິນຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🎨' => 'ສິນລະປິນຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🎨' => 'ສິນລະປິນຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🎨' => 'ສິນລະປິນຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🎨' => 'ສິນລະປິນຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🎨' => 'ສິນລະປິນຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🎨' => 'ສິນລະປິນຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🎨' => 'ສິນລະປິນຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🎨' => 'ສິນລະປິນຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍✈' => 'ນັກບິນ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍✈' => 'ນັກບິນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍✈' => 'ນັກບິນ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍✈' => 'ນັກບິນ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍✈' => 'ນັກບິນ: ສີຜິວໂທນດຳ',
    '👨🏻‍✈' => 'ນັກບິນຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍✈' => 'ນັກບິນຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍✈' => 'ນັກບິນຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍✈' => 'ນັກບິນຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍✈' => 'ນັກບິນຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍✈' => 'ນັກບິນຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍✈' => 'ນັກບິນຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍✈' => 'ນັກບິນຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍✈' => 'ນັກບິນຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍✈' => 'ນັກບິນຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🚀' => 'ນັກບິນອາວະກາດ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🚀' => 'ນັກບິນອາວະກາດ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🚀' => 'ນັກບິນອາວະກາດ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🚀' => 'ນັກບິນອາວະກາດ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🚀' => 'ນັກບິນອາວະກາດ: ສີຜິວໂທນດຳ',
    '👨🏻‍🚀' => 'ນັກບິນອະວະກາດຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🚀' => 'ນັກບິນອະວະກາດຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🚀' => 'ນັກບິນອະວະກາດຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🚀' => 'ນັກບິນອະວະກາດຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🚀' => 'ນັກບິນອະວະກາດຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🚀' => 'ນັກບິນອະວະກາດຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🚀' => 'ນັກບິນອະວະກາດຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🚀' => 'ນັກບິນອະວະກາດຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🚀' => 'ນັກບິນອະວະກາດຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🚀' => 'ນັກບິນອະວະກາດຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🚒' => 'ນັກດັບເພິ້ງ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🚒' => 'ນັກດັບເພິ້ງ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🚒' => 'ນັກດັບເພິ້ງ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🚒' => 'ນັກດັບເພິ້ງ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🚒' => 'ນັກດັບເພິ້ງ: ສີຜິວໂທນດຳ',
    '👨🏻‍🚒' => 'ນັກດັບເພີງຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🚒' => 'ນັກດັບເພີງຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🚒' => 'ນັກດັບເພີງຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🚒' => 'ນັກດັບເພີງຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🚒' => 'ນັກດັບເພີງຊາຍ: ສີຜິວໂທນດຳ',
    '👩🏻‍🚒' => 'ນັກດັບເພີງຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🚒' => 'ນັກດັບເພີງຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🚒' => 'ນັກດັບເພີງຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🚒' => 'ນັກດັບເພີງຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🚒' => 'ນັກດັບເພີງຍິງ: ສີຜິວໂທນດຳ',
    '👮🏻‍♂' => 'ຕຳຫຼວດຊາຍ: ສີຜິວໂທນຂາວ',
    '👮🏼‍♂' => 'ຕຳຫຼວດຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👮🏽‍♂' => 'ຕຳຫຼວດຊາຍ: ສີຜິວໂທນປານກາງ',
    '👮🏾‍♂' => 'ຕຳຫຼວດຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👮🏿‍♂' => 'ຕຳຫຼວດຊາຍ: ສີຜິວໂທນດຳ',
    '👮🏻‍♀' => 'ຕຳຫຼວດຍິງ: ສີຜິວໂທນຂາວ',
    '👮🏼‍♀' => 'ຕຳຫຼວດຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👮🏽‍♀' => 'ຕຳຫຼວດຍິງ: ສີຜິວໂທນປານກາງ',
    '👮🏾‍♀' => 'ຕຳຫຼວດຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👮🏿‍♀' => 'ຕຳຫຼວດຍິງ: ສີຜິວໂທນດຳ',
    '🕵🏻‍♂' => 'ນັກສືບຊາຍ: ສີຜິວໂທນຂາວ',
    '🕵🏼‍♂' => 'ນັກສືບຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🕵🏽‍♂' => 'ນັກສືບຊາຍ: ສີຜິວໂທນປານກາງ',
    '🕵🏾‍♂' => 'ນັກສືບຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🕵🏿‍♂' => 'ນັກສືບຊາຍ: ສີຜິວໂທນດຳ',
    '🕵🏻‍♀' => 'ນັກສືບຍິງ: ສີຜິວໂທນຂາວ',
    '🕵🏼‍♀' => 'ນັກສືບຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '🕵🏽‍♀' => 'ນັກສືບຍິງ: ສີຜິວໂທນປານກາງ',
    '🕵🏾‍♀' => 'ນັກສືບຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '🕵🏿‍♀' => 'ນັກສືບຍິງ: ສີຜິວໂທນດຳ',
    '💂🏻‍♂' => 'ເວນຍາມຊາຍ: ສີຜິວໂທນຂາວ',
    '💂🏼‍♂' => 'ເວນຍາມຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '💂🏽‍♂' => 'ເວນຍາມຊາຍ: ສີຜິວໂທນປານກາງ',
    '💂🏾‍♂' => 'ເວນຍາມຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '💂🏿‍♂' => 'ເວນຍາມຊາຍ: ສີຜິວໂທນດຳ',
    '💂🏻‍♀' => 'ເວນຍາມຍິງ: ສີຜິວໂທນຂາວ',
    '💂🏼‍♀' => 'ເວນຍາມຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '💂🏽‍♀' => 'ເວນຍາມຍິງ: ສີຜິວໂທນປານກາງ',
    '💂🏾‍♀' => 'ເວນຍາມຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '💂🏿‍♀' => 'ເວນຍາມຍິງ: ສີຜິວໂທນດຳ',
    '👷🏻‍♂' => 'ແຮງງານກໍ່ສ້າງຊາຍ: ສີຜິວໂທນຂາວ',
    '👷🏼‍♂' => 'ແຮງງານກໍ່ສ້າງຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👷🏽‍♂' => 'ແຮງງານກໍ່ສ້າງຊາຍ: ສີຜິວໂທນປານກາງ',
    '👷🏾‍♂' => 'ແຮງງານກໍ່ສ້າງຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👷🏿‍♂' => 'ແຮງງານກໍ່ສ້າງຊາຍ: ສີຜິວໂທນດຳ',
    '👷🏻‍♀' => 'ແຮງງານກໍ່ສ້າງຍິງ: ສີຜິວໂທນຂາວ',
    '👷🏼‍♀' => 'ແຮງງານກໍ່ສ້າງຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👷🏽‍♀' => 'ແຮງງານກໍ່ສ້າງຍິງ: ສີຜິວໂທນປານກາງ',
    '👷🏾‍♀' => 'ແຮງງານກໍ່ສ້າງຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👷🏿‍♀' => 'ແຮງງານກໍ່ສ້າງຍິງ: ສີຜິວໂທນດຳ',
    '👳🏻‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນຂາວ',
    '👳🏼‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນຂາວປານກາງ',
    '👳🏽‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນປານກາງ',
    '👳🏾‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນດຳປານກາງ',
    '👳🏿‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນດຳ',
    '👳🏻‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນຂາວ',
    '👳🏼‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນຂາວປານກາງ',
    '👳🏽‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນປານກາງ',
    '👳🏾‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນດຳປານກາງ',
    '👳🏿‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າໂພກຫົວ: ສີຜິວໂທນດຳ',
    '🤵🏻‍♂' => 'ຜູ້​ຊາຍໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນຂາວ',
    '🤵🏼‍♂' => 'ຜູ້​ຊາຍໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນຂາວປານກາງ',
    '🤵🏽‍♂' => 'ຜູ້​ຊາຍໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນປານກາງ',
    '🤵🏾‍♂' => 'ຜູ້​ຊາຍໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນດຳປານກາງ',
    '🤵🏿‍♂' => 'ຜູ້​ຊາຍໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນດຳ',
    '🤵🏻‍♀' => 'ຜູ້​ຍິງໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນຂາວ',
    '🤵🏼‍♀' => 'ຜູ້​ຍິງໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນຂາວປານກາງ',
    '🤵🏽‍♀' => 'ຜູ້​ຍິງໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນປານກາງ',
    '🤵🏾‍♀' => 'ຜູ້​ຍິງໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນດຳປານກາງ',
    '🤵🏿‍♀' => 'ຜູ້​ຍິງໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນດຳ',
    '👰🏻‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນຂາວ',
    '👰🏼‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '👰🏽‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນປານກາງ',
    '👰🏾‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນດຳປານກາງ',
    '👰🏿‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນດຳ',
    '👰🏻‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນຂາວ',
    '👰🏼‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '👰🏽‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນປານກາງ',
    '👰🏾‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນດຳປານກາງ',
    '👰🏿‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນດຳ',
    '👩🏻‍🍼' => 'ຜູ້​ຍິງປ້ອນນົມ​ລູກ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🍼' => 'ຜູ້​ຍິງປ້ອນນົມ​ລູກ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🍼' => 'ຜູ້​ຍິງປ້ອນນົມ​ລູກ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🍼' => 'ຜູ້​ຍິງປ້ອນນົມ​ລູກ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🍼' => 'ຜູ້​ຍິງປ້ອນນົມ​ລູກ: ສີຜິວໂທນດຳ',
    '👨🏻‍🍼' => 'ຜູ້​ຊາຍປ້ອນນົມ​ລູກ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🍼' => 'ຜູ້​ຊາຍປ້ອນນົມ​ລູກ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🍼' => 'ຜູ້​ຊາຍປ້ອນນົມ​ລູກ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🍼' => 'ຜູ້​ຊາຍປ້ອນນົມ​ລູກ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🍼' => 'ຜູ້​ຊາຍປ້ອນນົມ​ລູກ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🍼' => 'ຄົນປ້ອນນົມ​ລູກ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🍼' => 'ຄົນປ້ອນນົມ​ລູກ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🍼' => 'ຄົນປ້ອນນົມ​ລູກ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🍼' => 'ຄົນປ້ອນນົມ​ລູກ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🍼' => 'ຄົນປ້ອນນົມ​ລູກ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🎄' => 'ຄລັອສ (ບໍ່​ລະ​ບຸ​ເພດ): ສີຜິວໂທນຂາວ',
    '🧑🏼‍🎄' => 'ຄລັອສ (ບໍ່​ລະ​ບຸ​ເພດ): ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🎄' => 'ຄລັອສ (ບໍ່​ລະ​ບຸ​ເພດ): ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🎄' => 'ຄລັອສ (ບໍ່​ລະ​ບຸ​ເພດ): ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🎄' => 'ຄລັອສ (ບໍ່​ລະ​ບຸ​ເພດ): ສີຜິວໂທນດຳ',
    '🦸🏻‍♂' => 'ພະເອກຍອດຊາຍ: ສີຜິວໂທນຂາວ',
    '🦸🏼‍♂' => 'ພະເອກຍອດຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🦸🏽‍♂' => 'ພະເອກຍອດຊາຍ: ສີຜິວໂທນປານກາງ',
    '🦸🏾‍♂' => 'ພະເອກຍອດຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🦸🏿‍♂' => 'ພະເອກຍອດຊາຍ: ສີຜິວໂທນດຳ',
    '🦸🏻‍♀' => 'ສຸດຍອດນາງເອກ: ສີຜິວໂທນຂາວ',
    '🦸🏼‍♀' => 'ສຸດຍອດນາງເອກ: ສີຜິວໂທນຂາວປານກາງ',
    '🦸🏽‍♀' => 'ສຸດຍອດນາງເອກ: ສີຜິວໂທນປານກາງ',
    '🦸🏾‍♀' => 'ສຸດຍອດນາງເອກ: ສີຜິວໂທນດຳປານກາງ',
    '🦸🏿‍♀' => 'ສຸດຍອດນາງເອກ: ສີຜິວໂທນດຳ',
    '🦹🏻‍♂' => 'ພະຍາມານຈອມວາຍລ້າຍ: ສີຜິວໂທນຂາວ',
    '🦹🏼‍♂' => 'ພະຍາມານຈອມວາຍລ້າຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🦹🏽‍♂' => 'ພະຍາມານຈອມວາຍລ້າຍ: ສີຜິວໂທນປານກາງ',
    '🦹🏾‍♂' => 'ພະຍາມານຈອມວາຍລ້າຍ: ສີຜິວໂທນດຳປານກາງ',
    '🦹🏿‍♂' => 'ພະຍາມານຈອມວາຍລ້າຍ: ສີຜິວໂທນດຳ',
    '🦹🏻‍♀' => 'ນາງມານຈອມວາຍລ້າຍ: ສີຜິວໂທນຂາວ',
    '🦹🏼‍♀' => 'ນາງມານຈອມວາຍລ້າຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🦹🏽‍♀' => 'ນາງມານຈອມວາຍລ້າຍ: ສີຜິວໂທນປານກາງ',
    '🦹🏾‍♀' => 'ນາງມານຈອມວາຍລ້າຍ: ສີຜິວໂທນດຳປານກາງ',
    '🦹🏿‍♀' => 'ນາງມານຈອມວາຍລ້າຍ: ສີຜິວໂທນດຳ',
    '🧙🏻‍♂' => 'ຜູ້ວິເສດຊາຍ: ສີຜິວໂທນຂາວ',
    '🧙🏼‍♂' => 'ຜູ້ວິເສດຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🧙🏽‍♂' => 'ຜູ້ວິເສດຊາຍ: ສີຜິວໂທນປານກາງ',
    '🧙🏾‍♂' => 'ຜູ້ວິເສດຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🧙🏿‍♂' => 'ຜູ້ວິເສດຊາຍ: ສີຜິວໂທນດຳ',
    '🧙🏻‍♀' => 'ຜູ້ວິເສດຍິງ: ສີຜິວໂທນຂາວ',
    '🧙🏼‍♀' => 'ຜູ້ວິເສດຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '🧙🏽‍♀' => 'ຜູ້ວິເສດຍິງ: ສີຜິວໂທນປານກາງ',
    '🧙🏾‍♀' => 'ຜູ້ວິເສດຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '🧙🏿‍♀' => 'ຜູ້ວິເສດຍິງ: ສີຜິວໂທນດຳ',
    '🧚🏻‍♂' => 'ເທວະດາ: ສີຜິວໂທນຂາວ',
    '🧚🏼‍♂' => 'ເທວະດາ: ສີຜິວໂທນຂາວປານກາງ',
    '🧚🏽‍♂' => 'ເທວະດາ: ສີຜິວໂທນປານກາງ',
    '🧚🏾‍♂' => 'ເທວະດາ: ສີຜິວໂທນດຳປານກາງ',
    '🧚🏿‍♂' => 'ເທວະດາ: ສີຜິວໂທນດຳ',
    '🧚🏻‍♀' => 'ນາງຟ້າຍິງ: ສີຜິວໂທນຂາວ',
    '🧚🏼‍♀' => 'ນາງຟ້າຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '🧚🏽‍♀' => 'ນາງຟ້າຍິງ: ສີຜິວໂທນປານກາງ',
    '🧚🏾‍♀' => 'ນາງຟ້າຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '🧚🏿‍♀' => 'ນາງຟ້າຍິງ: ສີຜິວໂທນດຳ',
    '🧛🏻‍♂' => 'ແວມພາຍຊາຍ: ສີຜິວໂທນຂາວ',
    '🧛🏼‍♂' => 'ແວມພາຍຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🧛🏽‍♂' => 'ແວມພາຍຊາຍ: ສີຜິວໂທນປານກາງ',
    '🧛🏾‍♂' => 'ແວມພາຍຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🧛🏿‍♂' => 'ແວມພາຍຊາຍ: ສີຜິວໂທນດຳ',
    '🧛🏻‍♀' => 'ແວມພາຍຍິງ: ສີຜິວໂທນຂາວ',
    '🧛🏼‍♀' => 'ແວມພາຍຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '🧛🏽‍♀' => 'ແວມພາຍຍິງ: ສີຜິວໂທນປານກາງ',
    '🧛🏾‍♀' => 'ແວມພາຍຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '🧛🏿‍♀' => 'ແວມພາຍຍິງ: ສີຜິວໂທນດຳ',
    '🧜🏻‍♂' => 'ເງືອກຊາຍ: ສີຜິວໂທນຂາວ',
    '🧜🏼‍♂' => 'ເງືອກຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🧜🏽‍♂' => 'ເງືອກຊາຍ: ສີຜິວໂທນປານກາງ',
    '🧜🏾‍♂' => 'ເງືອກຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🧜🏿‍♂' => 'ເງືອກຊາຍ: ສີຜິວໂທນດຳ',
    '🧜🏻‍♀' => 'ນາງເງືອກ: ສີຜິວໂທນຂາວ',
    '🧜🏼‍♀' => 'ນາງເງືອກ: ສີຜິວໂທນຂາວປານກາງ',
    '🧜🏽‍♀' => 'ນາງເງືອກ: ສີຜິວໂທນປານກາງ',
    '🧜🏾‍♀' => 'ນາງເງືອກ: ສີຜິວໂທນດຳປານກາງ',
    '🧜🏿‍♀' => 'ນາງເງືອກ: ສີຜິວໂທນດຳ',
    '🧝🏻‍♂' => 'ເອວຟ໌ຜູ້ຊາຍ: ສີຜິວໂທນຂາວ',
    '🧝🏼‍♂' => 'ເອວຟ໌ຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🧝🏽‍♂' => 'ເອວຟ໌ຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ',
    '🧝🏾‍♂' => 'ເອວຟ໌ຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🧝🏿‍♂' => 'ເອວຟ໌ຜູ້ຊາຍ: ສີຜິວໂທນດຳ',
    '🧝🏻‍♀' => 'ເອວຟ໌ຜູ້ຍິງ: ສີຜິວໂທນຂາວ',
    '🧝🏼‍♀' => 'ເອວຟ໌ຜູ້ຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '🧝🏽‍♀' => 'ເອວຟ໌ຜູ້ຍິງ: ສີຜິວໂທນປານກາງ',
    '🧝🏾‍♀' => 'ເອວຟ໌ຜູ້ຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '🧝🏿‍♀' => 'ເອວຟ໌ຜູ້ຍິງ: ສີຜິວໂທນດຳ',
    '💆🏻‍♂' => 'ນວດໜ້າຜູ້ຊາຍ: ສີຜິວໂທນຂາວ',
    '💆🏼‍♂' => 'ນວດໜ້າຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '💆🏽‍♂' => 'ນວດໜ້າຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ',
    '💆🏾‍♂' => 'ນວດໜ້າຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '💆🏿‍♂' => 'ນວດໜ້າຜູ້ຊາຍ: ສີຜິວໂທນດຳ',
    '💆🏻‍♀' => 'ນວດໜ້າຜູ້ຍິງ: ສີຜິວໂທນຂາວ',
    '💆🏼‍♀' => 'ນວດໜ້າຜູ້ຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '💆🏽‍♀' => 'ນວດໜ້າຜູ້ຍິງ: ສີຜິວໂທນປານກາງ',
    '💆🏾‍♀' => 'ນວດໜ້າຜູ້ຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '💆🏿‍♀' => 'ນວດໜ້າຜູ້ຍິງ: ສີຜິວໂທນດຳ',
    '💇🏻‍♂' => 'ຕັດຜົມຜູ້ຊາຍ: ສີຜິວໂທນຂາວ',
    '💇🏼‍♂' => 'ຕັດຜົມຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '💇🏽‍♂' => 'ຕັດຜົມຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ',
    '💇🏾‍♂' => 'ຕັດຜົມຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '💇🏿‍♂' => 'ຕັດຜົມຜູ້ຊາຍ: ສີຜິວໂທນດຳ',
    '💇🏻‍♀' => 'ຕັດຜົມຜູ້ຍິງ: ສີຜິວໂທນຂາວ',
    '💇🏼‍♀' => 'ຕັດຜົມຜູ້ຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '💇🏽‍♀' => 'ຕັດຜົມຜູ້ຍິງ: ສີຜິວໂທນປານກາງ',
    '💇🏾‍♀' => 'ຕັດຜົມຜູ້ຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '💇🏿‍♀' => 'ຕັດຜົມຜູ້ຍິງ: ສີຜິວໂທນດຳ',
    '🚶🏻‍♂' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນຂາວ',
    '🚶🏼‍♂' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນຂາວປານກາງ',
    '🚶🏽‍♂' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນປານກາງ',
    '🚶🏾‍♂' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນດຳປານກາງ',
    '🚶🏿‍♂' => 'ຜູ້ຊາຍກຳລັງຍ່າງ: ສີຜິວໂທນດຳ',
    '🚶🏻‍♀' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນຂາວ',
    '🚶🏼‍♀' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນຂາວປານກາງ',
    '🚶🏽‍♀' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນປານກາງ',
    '🚶🏾‍♀' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນດຳປານກາງ',
    '🚶🏿‍♀' => 'ຜູ້ຍິງກຳລັງຍ່າງ: ສີຜິວໂທນດຳ',
    '🚶🏻‍➡' => 'ຄົນຍ່າງ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏼‍➡' => 'ຄົນຍ່າງ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏽‍➡' => 'ຄົນຍ່າງ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏾‍➡' => 'ຄົນຍ່າງ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🚶🏿‍➡' => 'ຄົນຍ່າງ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🧍🏻‍♂' => 'ຜູ້​ຊາຍ​ຢືນ: ສີຜິວໂທນຂາວ',
    '🧍🏼‍♂' => 'ຜູ້​ຊາຍ​ຢືນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧍🏽‍♂' => 'ຜູ້​ຊາຍ​ຢືນ: ສີຜິວໂທນປານກາງ',
    '🧍🏾‍♂' => 'ຜູ້​ຊາຍ​ຢືນ: ສີຜິວໂທນດຳປານກາງ',
    '🧍🏿‍♂' => 'ຜູ້​ຊາຍ​ຢືນ: ສີຜິວໂທນດຳ',
    '🧍🏻‍♀' => 'ຜູ້​ຍິງ​ຢືນ: ສີຜິວໂທນຂາວ',
    '🧍🏼‍♀' => 'ຜູ້​ຍິງ​ຢືນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧍🏽‍♀' => 'ຜູ້​ຍິງ​ຢືນ: ສີຜິວໂທນປານກາງ',
    '🧍🏾‍♀' => 'ຜູ້​ຍິງ​ຢືນ: ສີຜິວໂທນດຳປານກາງ',
    '🧍🏿‍♀' => 'ຜູ້​ຍິງ​ຢືນ: ສີຜິວໂທນດຳ',
    '🧎🏻‍♂' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວ',
    '🧎🏼‍♂' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວປານກາງ',
    '🧎🏽‍♂' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນປານກາງ',
    '🧎🏾‍♂' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳປານກາງ',
    '🧎🏿‍♂' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳ',
    '🧎🏻‍♀' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວ',
    '🧎🏼‍♀' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວປານກາງ',
    '🧎🏽‍♀' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນປານກາງ',
    '🧎🏾‍♀' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳປານກາງ',
    '🧎🏿‍♀' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳ',
    '🧎🏻‍➡' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏼‍➡' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏽‍➡' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏾‍➡' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🧎🏿‍➡' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '🧑🏻‍🦯' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🦯' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🦯' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🦯' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🦯' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ: ສີຜິວໂທນດຳ',
    '👨🏻‍🦯' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🦯' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🦯' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🦯' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🦯' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນດຳ',
    '👩🏻‍🦯' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🦯' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🦯' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🦯' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🦯' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ: ສີຜິວໂທນດຳ',
    '🧑🏻‍🦼' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🦼' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🦼' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🦼' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🦼' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳ',
    '👨🏻‍🦼' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວ',
    '👨🏼‍🦼' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🦼' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🦼' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🦼' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳ',
    '👩🏻‍🦼' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວ',
    '👩🏼‍🦼' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🦼' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🦼' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🦼' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້: ສີຜິວໂທນດຳ',
    '🧑🏻‍🦽' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວ',
    '🧑🏼‍🦽' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽‍🦽' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນປານກາງ',
    '🧑🏾‍🦽' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿‍🦽' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳ',
    '👨🏻‍🦽' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວ',
    '👨🏼‍🦽' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽‍🦽' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນປານກາງ',
    '👨🏾‍🦽' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿‍🦽' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳ',
    '👩🏻‍🦽' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວ',
    '👩🏼‍🦽' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽‍🦽' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນປານກາງ',
    '👩🏾‍🦽' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿‍🦽' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ: ສີຜິວໂທນດຳ',
    '🏃🏻‍♂' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນຂາວ',
    '🏃🏼‍♂' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🏃🏽‍♂' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນປານກາງ',
    '🏃🏾‍♂' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນດຳປານກາງ',
    '🏃🏿‍♂' => 'ຜູ້ຊາຍກຳລັງແລ່ນ: ສີຜິວໂທນດຳ',
    '🏃🏻‍♀' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນຂາວ',
    '🏃🏼‍♀' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🏃🏽‍♀' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນປານກາງ',
    '🏃🏾‍♀' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນດຳປານກາງ',
    '🏃🏿‍♀' => 'ຜູ້ຍິງກຳລັງແລ່ນ: ສີຜິວໂທນດຳ',
    '🏃🏻‍➡' => 'ຄົນແລ່ນ: ສີຜິວໂທນຂາວ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏼‍➡' => 'ຄົນແລ່ນ: ສີຜິວໂທນຂາວປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏽‍➡' => 'ຄົນແລ່ນ: ສີຜິວໂທນປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏾‍➡' => 'ຄົນແລ່ນ: ສີຜິວໂທນດຳປານກາງ, ຫັນໄປເບື້ອງຂວາ',
    '🏃🏿‍➡' => 'ຄົນແລ່ນ: ສີຜິວໂທນດຳ, ຫັນໄປເບື້ອງຂວາ',
    '👯🏻‍♀' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ',
    '👯🏼‍♀' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ',
    '👯🏽‍♀' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ',
    '👯🏾‍♀' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ',
    '👯🏿‍♀' => 'ຜູ້ຍິງກຳລັງປາຕີ້: ສີຜິວໂທນດຳ',
    '👯🏻‍♂' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວ',
    '👯🏼‍♂' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນຂາວປານກາງ',
    '👯🏽‍♂' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນປານກາງ',
    '👯🏾‍♂' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳປານກາງ',
    '👯🏿‍♂' => 'ຜູ້ຊາຍກຳລັງປາຕີ້: ສີຜິວໂທນດຳ',
    '🧖🏻‍♂' => 'ຜູ້ຊາຍໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນຂາວ',
    '🧖🏼‍♂' => 'ຜູ້ຊາຍໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນຂາວປານກາງ',
    '🧖🏽‍♂' => 'ຜູ້ຊາຍໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນປານກາງ',
    '🧖🏾‍♂' => 'ຜູ້ຊາຍໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນດຳປານກາງ',
    '🧖🏿‍♂' => 'ຜູ້ຊາຍໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນດຳ',
    '🧖🏻‍♀' => 'ຜູ້ຍິງໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນຂາວ',
    '🧖🏼‍♀' => 'ຜູ້ຍິງໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນຂາວປານກາງ',
    '🧖🏽‍♀' => 'ຜູ້ຍິງໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນປານກາງ',
    '🧖🏾‍♀' => 'ຜູ້ຍິງໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນດຳປານກາງ',
    '🧖🏿‍♀' => 'ຜູ້ຍິງໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນດຳ',
    '🧗🏻‍♂' => 'ຜູ້ຊາຍກຳລັງປີນ: ສີຜິວໂທນຂາວ',
    '🧗🏼‍♂' => 'ຜູ້ຊາຍກຳລັງປີນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧗🏽‍♂' => 'ຜູ້ຊາຍກຳລັງປີນ: ສີຜິວໂທນປານກາງ',
    '🧗🏾‍♂' => 'ຜູ້ຊາຍກຳລັງປີນ: ສີຜິວໂທນດຳປານກາງ',
    '🧗🏿‍♂' => 'ຜູ້ຊາຍກຳລັງປີນ: ສີຜິວໂທນດຳ',
    '🧗🏻‍♀' => 'ຜູ້ຍິງກຳລັງປີນ: ສີຜິວໂທນຂາວ',
    '🧗🏼‍♀' => 'ຜູ້ຍິງກຳລັງປີນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧗🏽‍♀' => 'ຜູ້ຍິງກຳລັງປີນ: ສີຜິວໂທນປານກາງ',
    '🧗🏾‍♀' => 'ຜູ້ຍິງກຳລັງປີນ: ສີຜິວໂທນດຳປານກາງ',
    '🧗🏿‍♀' => 'ຜູ້ຍິງກຳລັງປີນ: ສີຜິວໂທນດຳ',
    '🏌🏻‍♂' => 'ຜູ້ຊາຍຕີກັອບ: ສີຜິວໂທນຂາວ',
    '🏌🏼‍♂' => 'ຜູ້ຊາຍຕີກັອບ: ສີຜິວໂທນຂາວປານກາງ',
    '🏌🏽‍♂' => 'ຜູ້ຊາຍຕີກັອບ: ສີຜິວໂທນປານກາງ',
    '🏌🏾‍♂' => 'ຜູ້ຊາຍຕີກັອບ: ສີຜິວໂທນດຳປານກາງ',
    '🏌🏿‍♂' => 'ຜູ້ຊາຍຕີກັອບ: ສີຜິວໂທນດຳ',
    '🏌🏻‍♀' => 'ຜູ້ຍິງຕີກັອບ: ສີຜິວໂທນຂາວ',
    '🏌🏼‍♀' => 'ຜູ້ຍິງຕີກັອບ: ສີຜິວໂທນຂາວປານກາງ',
    '🏌🏽‍♀' => 'ຜູ້ຍິງຕີກັອບ: ສີຜິວໂທນປານກາງ',
    '🏌🏾‍♀' => 'ຜູ້ຍິງຕີກັອບ: ສີຜິວໂທນດຳປານກາງ',
    '🏌🏿‍♀' => 'ຜູ້ຍິງຕີກັອບ: ສີຜິວໂທນດຳ',
    '🏄🏻‍♂' => 'ຜູ້ຊາຍຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນຂາວ',
    '🏄🏼‍♂' => 'ຜູ້ຊາຍຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🏄🏽‍♂' => 'ຜູ້ຊາຍຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນປານກາງ',
    '🏄🏾‍♂' => 'ຜູ້ຊາຍຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນດຳປານກາງ',
    '🏄🏿‍♂' => 'ຜູ້ຊາຍຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນດຳ',
    '🏄🏻‍♀' => 'ຜູ້ຍິງຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນຂາວ',
    '🏄🏼‍♀' => 'ຜູ້ຍິງຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🏄🏽‍♀' => 'ຜູ້ຍິງຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນປານກາງ',
    '🏄🏾‍♀' => 'ຜູ້ຍິງຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນດຳປານກາງ',
    '🏄🏿‍♀' => 'ຜູ້ຍິງຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນດຳ',
    '🚣🏻‍♂' => 'ຜູ້ຊາຍຂີ່ເຮືອ: ສີຜິວໂທນຂາວ',
    '🚣🏼‍♂' => 'ຜູ້ຊາຍຂີ່ເຮືອ: ສີຜິວໂທນຂາວປານກາງ',
    '🚣🏽‍♂' => 'ຜູ້ຊາຍຂີ່ເຮືອ: ສີຜິວໂທນປານກາງ',
    '🚣🏾‍♂' => 'ຜູ້ຊາຍຂີ່ເຮືອ: ສີຜິວໂທນດຳປານກາງ',
    '🚣🏿‍♂' => 'ຜູ້ຊາຍຂີ່ເຮືອ: ສີຜິວໂທນດຳ',
    '🚣🏻‍♀' => 'ຜູ້ຍິງຂີ່ເຮືອ: ສີຜິວໂທນຂາວ',
    '🚣🏼‍♀' => 'ຜູ້ຍິງຂີ່ເຮືອ: ສີຜິວໂທນຂາວປານກາງ',
    '🚣🏽‍♀' => 'ຜູ້ຍິງຂີ່ເຮືອ: ສີຜິວໂທນປານກາງ',
    '🚣🏾‍♀' => 'ຜູ້ຍິງຂີ່ເຮືອ: ສີຜິວໂທນດຳປານກາງ',
    '🚣🏿‍♀' => 'ຜູ້ຍິງຂີ່ເຮືອ: ສີຜິວໂທນດຳ',
    '🏊🏻‍♂' => 'ຜູ້ຊາຍລອຍນໍ້າ: ສີຜິວໂທນຂາວ',
    '🏊🏼‍♂' => 'ຜູ້ຊາຍລອຍນໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🏊🏽‍♂' => 'ຜູ້ຊາຍລອຍນໍ້າ: ສີຜິວໂທນປານກາງ',
    '🏊🏾‍♂' => 'ຜູ້ຊາຍລອຍນໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🏊🏿‍♂' => 'ຜູ້ຊາຍລອຍນໍ້າ: ສີຜິວໂທນດຳ',
    '🏊🏻‍♀' => 'ຜູ້ຍິງລອຍນໍ້າ: ສີຜິວໂທນຂາວ',
    '🏊🏼‍♀' => 'ຜູ້ຍິງລອຍນໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🏊🏽‍♀' => 'ຜູ້ຍິງລອຍນໍ້າ: ສີຜິວໂທນປານກາງ',
    '🏊🏾‍♀' => 'ຜູ້ຍິງລອຍນໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🏊🏿‍♀' => 'ຜູ້ຍິງລອຍນໍ້າ: ສີຜິວໂທນດຳ',
    '⛹🏻‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານ: ສີຜິວໂທນຂາວ',
    '⛹🏼‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານ: ສີຜິວໂທນຂາວປານກາງ',
    '⛹🏽‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານ: ສີຜິວໂທນປານກາງ',
    '⛹🏾‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານ: ສີຜິວໂທນດຳປານກາງ',
    '⛹🏿‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານ: ສີຜິວໂທນດຳ',
    '⛹🏻‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານ: ສີຜິວໂທນຂາວ',
    '⛹🏼‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານ: ສີຜິວໂທນຂາວປານກາງ',
    '⛹🏽‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານ: ສີຜິວໂທນປານກາງ',
    '⛹🏾‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານ: ສີຜິວໂທນດຳປານກາງ',
    '⛹🏿‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານ: ສີຜິວໂທນດຳ',
    '🏋🏻‍♂' => 'ຜູ້ຊາຍຍົກນໍ້າໜັກ: ສີຜິວໂທນຂາວ',
    '🏋🏼‍♂' => 'ຜູ້ຊາຍຍົກນໍ້າໜັກ: ສີຜິວໂທນຂາວປານກາງ',
    '🏋🏽‍♂' => 'ຜູ້ຊາຍຍົກນໍ້າໜັກ: ສີຜິວໂທນປານກາງ',
    '🏋🏾‍♂' => 'ຜູ້ຊາຍຍົກນໍ້າໜັກ: ສີຜິວໂທນດຳປານກາງ',
    '🏋🏿‍♂' => 'ຜູ້ຊາຍຍົກນໍ້າໜັກ: ສີຜິວໂທນດຳ',
    '🏋🏻‍♀' => 'ຜູ້ຍິງຍົກນໍ້າໜັກ: ສີຜິວໂທນຂາວ',
    '🏋🏼‍♀' => 'ຜູ້ຍິງຍົກນໍ້າໜັກ: ສີຜິວໂທນຂາວປານກາງ',
    '🏋🏽‍♀' => 'ຜູ້ຍິງຍົກນໍ້າໜັກ: ສີຜິວໂທນປານກາງ',
    '🏋🏾‍♀' => 'ຜູ້ຍິງຍົກນໍ້າໜັກ: ສີຜິວໂທນດຳປານກາງ',
    '🏋🏿‍♀' => 'ຜູ້ຍິງຍົກນໍ້າໜັກ: ສີຜິວໂທນດຳ',
    '🚴🏻‍♂' => 'ຜູ້ຊາຍຖີບລົດ: ສີຜິວໂທນຂາວ',
    '🚴🏼‍♂' => 'ຜູ້ຊາຍຖີບລົດ: ສີຜິວໂທນຂາວປານກາງ',
    '🚴🏽‍♂' => 'ຜູ້ຊາຍຖີບລົດ: ສີຜິວໂທນປານກາງ',
    '🚴🏾‍♂' => 'ຜູ້ຊາຍຖີບລົດ: ສີຜິວໂທນດຳປານກາງ',
    '🚴🏿‍♂' => 'ຜູ້ຊາຍຖີບລົດ: ສີຜິວໂທນດຳ',
    '🚴🏻‍♀' => 'ຜູ້ຍິງຖີບລົດ: ສີຜິວໂທນຂາວ',
    '🚴🏼‍♀' => 'ຜູ້ຍິງຖີບລົດ: ສີຜິວໂທນຂາວປານກາງ',
    '🚴🏽‍♀' => 'ຜູ້ຍິງຖີບລົດ: ສີຜິວໂທນປານກາງ',
    '🚴🏾‍♀' => 'ຜູ້ຍິງຖີບລົດ: ສີຜິວໂທນດຳປານກາງ',
    '🚴🏿‍♀' => 'ຜູ້ຍິງຖີບລົດ: ສີຜິວໂທນດຳ',
    '🚵🏻‍♂' => 'ຜູ້ຊາຍຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນຂາວ',
    '🚵🏼‍♂' => 'ຜູ້ຊາຍຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນຂາວປານກາງ',
    '🚵🏽‍♂' => 'ຜູ້ຊາຍຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນປານກາງ',
    '🚵🏾‍♂' => 'ຜູ້ຊາຍຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນດຳປານກາງ',
    '🚵🏿‍♂' => 'ຜູ້ຊາຍຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນດຳ',
    '🚵🏻‍♀' => 'ຜູ້ຍິງຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນຂາວ',
    '🚵🏼‍♀' => 'ຜູ້ຍິງຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນຂາວປານກາງ',
    '🚵🏽‍♀' => 'ຜູ້ຍິງຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນປານກາງ',
    '🚵🏾‍♀' => 'ຜູ້ຍິງຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນດຳປານກາງ',
    '🚵🏿‍♀' => 'ຜູ້ຍິງຂີ່ລົດຖີບເສືອພູເຂົາ: ສີຜິວໂທນດຳ',
    '🤸🏻‍♂' => 'ຜູ້ຊາຍຕີລັງກາຍ: ສີຜິວໂທນຂາວ',
    '🤸🏼‍♂' => 'ຜູ້ຊາຍຕີລັງກາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🤸🏽‍♂' => 'ຜູ້ຊາຍຕີລັງກາຍ: ສີຜິວໂທນປານກາງ',
    '🤸🏾‍♂' => 'ຜູ້ຊາຍຕີລັງກາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🤸🏿‍♂' => 'ຜູ້ຊາຍຕີລັງກາຍ: ສີຜິວໂທນດຳ',
    '🤸🏻‍♀' => 'ຜູ້ຍິງຕີລັງກາ: ສີຜິວໂທນຂາວ',
    '🤸🏼‍♀' => 'ຜູ້ຍິງຕີລັງກາ: ສີຜິວໂທນຂາວປານກາງ',
    '🤸🏽‍♀' => 'ຜູ້ຍິງຕີລັງກາ: ສີຜິວໂທນປານກາງ',
    '🤸🏾‍♀' => 'ຜູ້ຍິງຕີລັງກາ: ສີຜິວໂທນດຳປານກາງ',
    '🤸🏿‍♀' => 'ຜູ້ຍິງຕີລັງກາ: ສີຜິວໂທນດຳ',
    '🤼🏻‍♀' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ',
    '🤼🏼‍♀' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🤼🏽‍♀' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ',
    '🤼🏾‍♀' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🤼🏿‍♀' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ',
    '🤼🏻‍♂' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວ',
    '🤼🏼‍♂' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🤼🏽‍♂' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນປານກາງ',
    '🤼🏾‍♂' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🤼🏿‍♂' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ: ສີຜິວໂທນດຳ',
    '🤽🏻‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນຂາວ',
    '🤽🏼‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🤽🏽‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນປານກາງ',
    '🤽🏾‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🤽🏿‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນດຳ',
    '🤽🏻‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນຂາວ',
    '🤽🏼‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🤽🏽‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນປານກາງ',
    '🤽🏾‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🤽🏿‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານນໍ້າ: ສີຜິວໂທນດຳ',
    '🤾🏻‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານມື: ສີຜິວໂທນຂາວ',
    '🤾🏼‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານມື: ສີຜິວໂທນຂາວປານກາງ',
    '🤾🏽‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານມື: ສີຜິວໂທນປານກາງ',
    '🤾🏾‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານມື: ສີຜິວໂທນດຳປານກາງ',
    '🤾🏿‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານມື: ສີຜິວໂທນດຳ',
    '🤾🏻‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານມື: ສີຜິວໂທນຂາວ',
    '🤾🏼‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານມື: ສີຜິວໂທນຂາວປານກາງ',
    '🤾🏽‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານມື: ສີຜິວໂທນປານກາງ',
    '🤾🏾‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານມື: ສີຜິວໂທນດຳປານກາງ',
    '🤾🏿‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານມື: ສີຜິວໂທນດຳ',
    '🤹🏻‍♂' => 'ຜູ້ຊາຍໂຍນບານຕໍ່ເນື່ອງ: ສີຜິວໂທນຂາວ',
    '🤹🏼‍♂' => 'ຜູ້ຊາຍໂຍນບານຕໍ່ເນື່ອງ: ສີຜິວໂທນຂາວປານກາງ',
    '🤹🏽‍♂' => 'ຜູ້ຊາຍໂຍນບານຕໍ່ເນື່ອງ: ສີຜິວໂທນປານກາງ',
    '🤹🏾‍♂' => 'ຜູ້ຊາຍໂຍນບານຕໍ່ເນື່ອງ: ສີຜິວໂທນດຳປານກາງ',
    '🤹🏿‍♂' => 'ຜູ້ຊາຍໂຍນບານຕໍ່ເນື່ອງ: ສີຜິວໂທນດຳ',
    '🤹🏻‍♀' => 'ຜູ້ຍິງໂຍນບານຕໍ່ເຮື່ອງ: ສີຜິວໂທນຂາວ',
    '🤹🏼‍♀' => 'ຜູ້ຍິງໂຍນບານຕໍ່ເຮື່ອງ: ສີຜິວໂທນຂາວປານກາງ',
    '🤹🏽‍♀' => 'ຜູ້ຍິງໂຍນບານຕໍ່ເຮື່ອງ: ສີຜິວໂທນປານກາງ',
    '🤹🏾‍♀' => 'ຜູ້ຍິງໂຍນບານຕໍ່ເຮື່ອງ: ສີຜິວໂທນດຳປານກາງ',
    '🤹🏿‍♀' => 'ຜູ້ຍິງໂຍນບານຕໍ່ເຮື່ອງ: ສີຜິວໂທນດຳ',
    '🧘🏻‍♂' => 'ຜູ້ຊາຍນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນຂາວ',
    '🧘🏼‍♂' => 'ຜູ້ຊາຍນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນຂາວປານກາງ',
    '🧘🏽‍♂' => 'ຜູ້ຊາຍນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນປານກາງ',
    '🧘🏾‍♂' => 'ຜູ້ຊາຍນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນດຳປານກາງ',
    '🧘🏿‍♂' => 'ຜູ້ຊາຍນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນດຳ',
    '🧘🏻‍♀' => 'ຜູ້ຍິງນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນຂາວ',
    '🧘🏼‍♀' => 'ຜູ້ຍິງນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນຂາວປານກາງ',
    '🧘🏽‍♀' => 'ຜູ້ຍິງນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນປານກາງ',
    '🧘🏾‍♀' => 'ຜູ້ຍິງນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນດຳປານກາງ',
    '🧘🏿‍♀' => 'ຜູ້ຍິງນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນດຳ',
    '🧑‍🦰' => 'ຜູ້ໃຫຍ່: ຜົມແດງ',
    '🧑‍🦱' => 'ຜູ້ໃຫຍ່: ຜົມກູດ',
    '🧑‍🦳' => 'ຜູ້ໃຫຍ່: ຜົມຫງອກ',
    '🧑‍🦲' => 'ຜູ້ໃຫຍ່: ຫົວລ້ານ',
    '👨‍🦰' => 'ຜູ້ຊາຍ: ຜົມແດງ',
    '👨‍🦱' => 'ຜູ້ຊາຍ: ຜົມກູດ',
    '👨‍🦳' => 'ຜູ້ຊາຍ: ຜົມຫງອກ',
    '👨‍🦲' => 'ຜູ້ຊາຍ: ຫົວລ້ານ',
    '👩‍🦰' => 'ແມ່ຍິງ: ຜົມແດງ',
    '👩‍🦱' => 'ແມ່ຍິງ: ຜົມກູດ',
    '👩‍🦳' => 'ແມ່ຍິງ: ຜົມຫງອກ',
    '👩‍🦲' => 'ແມ່ຍິງ: ຫົວລ້ານ',
    '🚶‍➡' => 'ຄົນຍ່າງ: ຫັນໄປເບື້ອງຂວາ',
    '🧎‍➡' => '​ຄົນ​ຄຸ​ເຂົ່າ: ຫັນໄປເບື້ອງຂວາ',
    '🏃‍➡' => 'ຄົນແລ່ນ: ຫັນໄປເບື້ອງຂວາ',
    '👨‍👦' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ເດັກຊາຍ',
    '👨‍👧' => 'ຄອບຄົວ: ຜູ້ຊາຍ, ເດັກຍິງ',
    '👩‍👦' => 'ຄອບຄົວ: ແມ່ຍິງ, ເດັກຊາຍ',
    '👩‍👧' => 'ຄອບຄົວ: ແມ່ຍິງ, ເດັກຍິງ',
    '😶‍🌫' => 'ໜ້າໃນເມກ',
    '😮‍💨' => 'ໜ້າຫາຍໃຈອອກ',
    '🙂‍↕' => 'ແກວ່ງຫົວແນວຕັ້ງ',
    '😵‍💫' => 'ໜ້າຫົວໝຸນ',
    '❤‍🔥' => 'ຫົວໃຈມີໄຟ',
    '❤‍🩹' => 'ດາມໃຈ',
    '👁‍🗨' => 'ຕາໃນປ່ອງຄຳເວົ້າ',
    '🧔‍♂' => 'ຜູ້ຊາຍມີໜວດ',
    '👱‍♂' => 'ຊາຍຜົມບລອນ',
    '🧔‍♀' => 'ຜູ້ຍິງມີໜວດ',
    '👱‍♀' => 'ຍິງຜົມບລອນ',
    '🙍‍♂' => 'ຜູ້ຊາຍເຮັດໜ້າບຶ້ງ',
    '🙍‍♀' => 'ຜູ້ຍິງເຮັດໜ້າບຶ້ງ',
    '🙎‍♂' => 'ຜູ້ຊາຍເບະສົບ',
    '🙎‍♀' => 'ຜູ້ຍິງເບະສົບ',
    '🙅‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າບໍ່ໂອເຄ',
    '🙅‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າບໍ່ໂອເຄ',
    '🙆‍♂' => 'ຜູ້ຊາຍເຮັດມືວ່າໂອເຄ',
    '🙆‍♀' => 'ຜູ້ຍິງເຮັດມືວ່າໂອເຄ',
    '💁‍♂' => 'ຜູ້ຊາຍແບມື',
    '💁‍♀' => 'ຜູ້ຍິງແບມື',
    '🙋‍♂' => 'ຜູ້ຊາຍຍົກມື',
    '🙋‍♀' => 'ຜູ້ຍິງຍົກມື',
    '🧏‍♂' => 'ຜູ້​ຊາຍຫູ​ໜວກ',
    '🧏‍♀' => 'ຜູ້​ຍິງ​ຫູ​ໜວກ',
    '🙇‍♂' => 'ຜູ້ຊາຍກົ້ມຄຳນັບ',
    '🙇‍♀' => 'ຜູ້ຍິງກົ້ມຄຳນັບ',
    '🤦‍♂' => 'ຜູ້ຊາຍເອົາມືກ່າຍປິດໜ້າ',
    '🤦‍♀' => 'ຜູ້ຍິງເອົາມືກ່າຍປິດໜ້າ',
    '🤷‍♂' => 'ຜູ້ຊາຍຫໍ່ໄຫລ່',
    '🤷‍♀' => 'ຜູ້ຍິງຫໍ່ໄຫລ່',
    '🧑‍⚕' => 'ພະນັກງານກວດສຸຂະພາບ',
    '👨‍⚕' => 'ຜູ້ຊາຍເຮັດວຽກສຸຂະພາບ',
    '👩‍⚕' => 'ຜູ້ຍິງເຮັດວຽກສຸຂະພາບ',
    '🧑‍🎓' => 'ນັກຮຽນ',
    '👨‍🎓' => 'ນັກຮຽນຊາຍ',
    '👩‍🎓' => 'ນັກຮຽນຍິງ',
    '🧑‍🏫' => 'ອາຈານ',
    '👨‍🏫' => 'ອາຈານຜູ້ຊາຍ',
    '👩‍🏫' => 'ອາຈານຜູ້ຍິງ',
    '🧑‍⚖' => 'ຜູ້ພິພາກສາ',
    '👨‍⚖' => 'ຜູ້ພິພາກສາຊາຍ',
    '👩‍⚖' => 'ຜູ້ພິພາກສາຍິງ',
    '🧑‍🌾' => 'ຊາວນາ',
    '👨‍🌾' => 'ຊາວນາຊາຍ',
    '👩‍🌾' => 'ຊາວນາຍິງ',
    '🧑‍🍳' => 'ແຕ່ງກິນ',
    '👨‍🍳' => 'ພໍ່ຄົວຊາຍ',
    '👩‍🍳' => 'ພໍ່ຄົວຍິງ',
    '🧑‍🔧' => 'ຊ່າງ',
    '👨‍🔧' => 'ຊ່າງກົນຊາຍ',
    '👩‍🔧' => 'ຊ່າງກົນຍິງ',
    '🧑‍🏭' => 'ຄົນງານໃນໂຮງງານ',
    '👨‍🏭' => 'ພະນັກງານໂຮງງານຊາຍ',
    '👩‍🏭' => 'ພະນັກງານໂຮງງານຍິງ',
    '🧑‍💼' => 'ພະນັກງານຫ້ອງການ',
    '👨‍💼' => 'ພະນັກງານຫ້ອງການຊາຍ',
    '👩‍💼' => 'ພະນັກງານຫ້ອງການຍິງ',
    '🧑‍🔬' => 'ນັກວິທະຍາສາດ',
    '👨‍🔬' => 'ນັກວິທະຍາສາດຊາຍ',
    '👩‍🔬' => 'ນັກວິທະຍາສາດຍິງ',
    '🧑‍💻' => 'ນັກເຕັກນິກ',
    '👨‍💻' => 'ນັກເທັກໂນໂລຢີຊາຍ',
    '👩‍💻' => 'ນັກເທັກໂນໂລຢີຍິງ',
    '🧑‍🎤' => 'ນັກຮ້ອງ',
    '👨‍🎤' => 'ນັກຮ້ອງຊາຍ',
    '👩‍🎤' => 'ນັກຮ້ອງຜູ້ຍິງ',
    '🧑‍🎨' => 'ສິນລະປິນ',
    '👨‍🎨' => 'ສິນລະປິນຊາຍ',
    '👩‍🎨' => 'ສິນລະປິນຍິງ',
    '🧑‍✈' => 'ນັກບິນ',
    '👨‍✈' => 'ນັກບິນຊາຍ',
    '👩‍✈' => 'ນັກບິນຍິງ',
    '🧑‍🚀' => 'ນັກບິນອາວະກາດ',
    '👨‍🚀' => 'ນັກບິນອະວະກາດຊາຍ',
    '👩‍🚀' => 'ນັກບິນອະວະກາດຍິງ',
    '🧑‍🚒' => 'ນັກດັບເພິ້ງ',
    '👨‍🚒' => 'ນັກດັບເພີງຊາຍ',
    '👩‍🚒' => 'ນັກດັບເພີງຍິງ',
    '👮‍♂' => 'ຕຳຫຼວດຊາຍ',
    '👮‍♀' => 'ຕຳຫຼວດຍິງ',
    '🕵‍♂' => 'ນັກສືບຊາຍ',
    '🕵‍♀' => 'ນັກສືບຍິງ',
    '💂‍♂' => 'ເວນຍາມຊາຍ',
    '💂‍♀' => 'ເວນຍາມຍິງ',
    '👷‍♂' => 'ແຮງງານກໍ່ສ້າງຊາຍ',
    '👷‍♀' => 'ແຮງງານກໍ່ສ້າງຍິງ',
    '👳‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າໂພກຫົວ',
    '👳‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າໂພກຫົວ',
    '🤵‍♂' => 'ຜູ້​ຊາຍໃສ່ຊຸດທັກຊິໂດ',
    '🤵‍♀' => 'ຜູ້​ຍິງໃສ່ຊຸດທັກຊິໂດ',
    '👰‍♂' => 'ຜູ້ຊາຍໃສ່ຜ້າຄຸມໜ້າ',
    '👰‍♀' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມໜ້າ',
    '👩‍🍼' => 'ຜູ້​ຍິງປ້ອນນົມ​ລູກ',
    '👨‍🍼' => 'ຜູ້​ຊາຍປ້ອນນົມ​ລູກ',
    '🧑‍🍼' => 'ຄົນປ້ອນນົມ​ລູກ',
    '🧑‍🎄' => 'ຄລັອສ (ບໍ່​ລະ​ບຸ​ເພດ)',
    '🦸‍♂' => 'ພະເອກຍອດຊາຍ',
    '🦸‍♀' => 'ສຸດຍອດນາງເອກ',
    '🦹‍♂' => 'ພະຍາມານຈອມວາຍລ້າຍ',
    '🦹‍♀' => 'ນາງມານຈອມວາຍລ້າຍ',
    '🧙‍♂' => 'ຜູ້ວິເສດຊາຍ',
    '🧙‍♀' => 'ຜູ້ວິເສດຍິງ',
    '🧚‍♂' => 'ເທວະດາ',
    '🧚‍♀' => 'ນາງຟ້າຍິງ',
    '🧛‍♂' => 'ແວມພາຍຊາຍ',
    '🧛‍♀' => 'ແວມພາຍຍິງ',
    '🧜‍♂' => 'ເງືອກຊາຍ',
    '🧜‍♀' => 'ນາງເງືອກ',
    '🧝‍♂' => 'ເອວຟ໌ຜູ້ຊາຍ',
    '🧝‍♀' => 'ເອວຟ໌ຜູ້ຍິງ',
    '🧞‍♂' => 'ຈິນີ່ຊາຍ',
    '🧞‍♀' => 'ຈິນີ່ຍິງ',
    '🧟‍♂' => 'ຊອມບີ້ຜູ້ຊາຍ',
    '🧟‍♀' => 'ຊອມບີ້ຍິງ',
    '💆‍♂' => 'ນວດໜ້າຜູ້ຊາຍ',
    '💆‍♀' => 'ນວດໜ້າຜູ້ຍິງ',
    '💇‍♂' => 'ຕັດຜົມຜູ້ຊາຍ',
    '💇‍♀' => 'ຕັດຜົມຜູ້ຍິງ',
    '🚶‍♂' => 'ຜູ້ຊາຍກຳລັງຍ່າງ',
    '🚶‍♀' => 'ຜູ້ຍິງກຳລັງຍ່າງ',
    '🧍‍♂' => 'ຜູ້​ຊາຍ​ຢືນ',
    '🧍‍♀' => 'ຜູ້​ຍິງ​ຢືນ',
    '🧎‍♂' => 'ຜູ້​ຊາຍ​ຄຸ​ເຂົ່າ',
    '🧎‍♀' => 'ຜູ້​ຍິງ​ຄຸ​ເຂົ່າ',
    '🧑‍🦯' => 'ຄົນກັບໄມ້ເທົ້າສີຂາວ',
    '👨‍🦯' => 'ຜູ້​ຊາຍ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ',
    '👩‍🦯' => 'ຜູ້​ຍິງ​ຖື​ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ',
    '🧑‍🦼' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້',
    '👨‍🦼' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້',
    '👩‍🦼' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້',
    '🧑‍🦽' => 'ຄົນນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ',
    '👨‍🦽' => 'ຜູ້​ຊາຍ​ນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ',
    '👩‍🦽' => 'ຜູ້​ຍິງນັ່ງ​ລໍ້​ຍູ້ແບບ​ບັງ​ຄັບ​ເອງ',
    '🏃‍♂' => 'ຜູ້ຊາຍກຳລັງແລ່ນ',
    '🏃‍♀' => 'ຜູ້ຍິງກຳລັງແລ່ນ',
    '🧑‍🩰' => 'ນັກເຕັ້ນບາເລ້',
    '👯‍♂' => 'ຜູ້ຊາຍກຳລັງປາຕີ້',
    '👯‍♀' => 'ຜູ້ຍິງກຳລັງປາຕີ້',
    '🧖‍♂' => 'ຜູ້ຊາຍໃນຫ້ອງອົບໄອນ້ຳ',
    '🧖‍♀' => 'ຜູ້ຍິງໃນຫ້ອງອົບໄອນ້ຳ',
    '🧗‍♂' => 'ຜູ້ຊາຍກຳລັງປີນ',
    '🧗‍♀' => 'ຜູ້ຍິງກຳລັງປີນ',
    '🏌‍♂' => 'ຜູ້ຊາຍຕີກັອບ',
    '🏌‍♀' => 'ຜູ້ຍິງຕີກັອບ',
    '🏄‍♂' => 'ຜູ້ຊາຍຫຼິ້ນໂຕ້ຄື້ນ',
    '🏄‍♀' => 'ຜູ້ຍິງຫຼິ້ນໂຕ້ຄື້ນ',
    '🚣‍♂' => 'ຜູ້ຊາຍຂີ່ເຮືອ',
    '🚣‍♀' => 'ຜູ້ຍິງຂີ່ເຮືອ',
    '🏊‍♂' => 'ຜູ້ຊາຍລອຍນໍ້າ',
    '🏊‍♀' => 'ຜູ້ຍິງລອຍນໍ້າ',
    '⛹‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານ',
    '⛹‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານ',
    '🏋‍♂' => 'ຜູ້ຊາຍຍົກນໍ້າໜັກ',
    '🏋‍♀' => 'ຜູ້ຍິງຍົກນໍ້າໜັກ',
    '🚴‍♂' => 'ຜູ້ຊາຍຖີບລົດ',
    '🚴‍♀' => 'ຜູ້ຍິງຖີບລົດ',
    '🚵‍♂' => 'ຜູ້ຊາຍຂີ່ລົດຖີບເສືອພູເຂົາ',
    '🚵‍♀' => 'ຜູ້ຍິງຂີ່ລົດຖີບເສືອພູເຂົາ',
    '🤸‍♂' => 'ຜູ້ຊາຍຕີລັງກາຍ',
    '🤸‍♀' => 'ຜູ້ຍິງຕີລັງກາ',
    '🤼‍♂' => 'ຜູ້ຊາຍຫຼິ້ນມວຍປໍ້າ',
    '🤼‍♀' => 'ຜູ້ຍິງຫຼິ້ນມວຍປໍ້າ',
    '🤽‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານນໍ້າ',
    '🤽‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານນໍ້າ',
    '🤾‍♂' => 'ຜູ້ຊາຍຫຼິ້ນບານມື',
    '🤾‍♀' => 'ຜູ້ຍິງຫຼິ້ນບານມື',
    '🤹‍♂' => 'ຜູ້ຊາຍໂຍນບານຕໍ່ເນື່ອງ',
    '🤹‍♀' => 'ຜູ້ຍິງໂຍນບານຕໍ່ເຮື່ອງ',
    '🧘‍♂' => 'ຜູ້ຊາຍນັ່ງທ່າຂັດສະມາທິ',
    '🧘‍♀' => 'ຜູ້ຍິງນັ່ງທ່າຂັດສະມາທິ',
    '🧑‍🧒' => 'ຄອບຄົວ: ຜູ້ໃຫຍ່, ເດັກນ້ອຍ',
    '🐕‍🦺' => '​ໝາ​ຊ່ວຍ​ເຫຼື​ອ',
    '🐈‍⬛' => 'ແມວ​ດຳ',
    '🐻‍❄' => 'ໝີ​ຂົ້ວ​ໂລກ',
    '🐦‍⬛' => 'ນົກດໍາ',
    '🐦‍🔥' => 'ນົກຟີນິກ',
    '🍋‍🟩' => 'ໝາກນາວຂຽວ',
    '🍄‍🟫' => 'ເຫັດສີນໍ້າຕານ',
    '⛓‍💥' => 'ໂສ້ຫັກ',
    '🏳‍🌈' => 'ທຸງສາຍຮຸ້ງ',
    '🏳‍⚧' => 'ສີຟ້າ, ສີບົວ, ແລະ ທຸງຂາວ',
    '🏴‍☠' => 'ທຸງໂຈນສະລັດ',
    '👋🏻' => 'ໂບກມື: ສີຜິວໂທນຂາວ',
    '👋🏼' => 'ໂບກມື: ສີຜິວໂທນຂາວປານກາງ',
    '👋🏽' => 'ໂບກມື: ສີຜິວໂທນປານກາງ',
    '👋🏾' => 'ໂບກມື: ສີຜິວໂທນດຳປານກາງ',
    '👋🏿' => 'ໂບກມື: ສີຜິວໂທນດຳ',
    '🤚🏻' => 'ຍົກຫຼັງມືຂຶ້ນ: ສີຜິວໂທນຂາວ',
    '🤚🏼' => 'ຍົກຫຼັງມືຂຶ້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🤚🏽' => 'ຍົກຫຼັງມືຂຶ້ນ: ສີຜິວໂທນປານກາງ',
    '🤚🏾' => 'ຍົກຫຼັງມືຂຶ້ນ: ສີຜິວໂທນດຳປານກາງ',
    '🤚🏿' => 'ຍົກຫຼັງມືຂຶ້ນ: ສີຜິວໂທນດຳ',
    '🖐🏻' => 'ຍົກມືຂຶ້ນໂດຍທີ່ນີ້ວມືຈ່າງອອກ: ສີຜິວໂທນຂາວ',
    '🖐🏼' => 'ຍົກມືຂຶ້ນໂດຍທີ່ນີ້ວມືຈ່າງອອກ: ສີຜິວໂທນຂາວປານກາງ',
    '🖐🏽' => 'ຍົກມືຂຶ້ນໂດຍທີ່ນີ້ວມືຈ່າງອອກ: ສີຜິວໂທນປານກາງ',
    '🖐🏾' => 'ຍົກມືຂຶ້ນໂດຍທີ່ນີ້ວມືຈ່າງອອກ: ສີຜິວໂທນດຳປານກາງ',
    '🖐🏿' => 'ຍົກມືຂຶ້ນໂດຍທີ່ນີ້ວມືຈ່າງອອກ: ສີຜິວໂທນດຳ',
    '✋🏻' => 'ຍົກມືຂຶ້ນ: ສີຜິວໂທນຂາວ',
    '✋🏼' => 'ຍົກມືຂຶ້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '✋🏽' => 'ຍົກມືຂຶ້ນ: ສີຜິວໂທນປານກາງ',
    '✋🏾' => 'ຍົກມືຂຶ້ນ: ສີຜິວໂທນດຳປານກາງ',
    '✋🏿' => 'ຍົກມືຂຶ້ນ: ສີຜິວໂທນດຳ',
    '🖖🏻' => 'ຊູນິ້ວແບບວັນແຄນ: ສີຜິວໂທນຂາວ',
    '🖖🏼' => 'ຊູນິ້ວແບບວັນແຄນ: ສີຜິວໂທນຂາວປານກາງ',
    '🖖🏽' => 'ຊູນິ້ວແບບວັນແຄນ: ສີຜິວໂທນປານກາງ',
    '🖖🏾' => 'ຊູນິ້ວແບບວັນແຄນ: ສີຜິວໂທນດຳປານກາງ',
    '🖖🏿' => 'ຊູນິ້ວແບບວັນແຄນ: ສີຜິວໂທນດຳ',
    '🫱🏻' => 'ມືຊີ້ໄປທາງຂວາ: ສີຜິວໂທນຂາວ',
    '🫱🏼' => 'ມືຊີ້ໄປທາງຂວາ: ສີຜິວໂທນຂາວປານກາງ',
    '🫱🏽' => 'ມືຊີ້ໄປທາງຂວາ: ສີຜິວໂທນປານກາງ',
    '🫱🏾' => 'ມືຊີ້ໄປທາງຂວາ: ສີຜິວໂທນດຳປານກາງ',
    '🫱🏿' => 'ມືຊີ້ໄປທາງຂວາ: ສີຜິວໂທນດຳ',
    '🫲🏻' => 'ມືຊີ້ໄປທາງຊ້າຍ: ສີຜິວໂທນຂາວ',
    '🫲🏼' => 'ມືຊີ້ໄປທາງຊ້າຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🫲🏽' => 'ມືຊີ້ໄປທາງຊ້າຍ: ສີຜິວໂທນປານກາງ',
    '🫲🏾' => 'ມືຊີ້ໄປທາງຊ້າຍ: ສີຜິວໂທນດຳປານກາງ',
    '🫲🏿' => 'ມືຊີ້ໄປທາງຊ້າຍ: ສີຜິວໂທນດຳ',
    '🫳🏻' => 'ຝາມືລົງ: ສີຜິວໂທນຂາວ',
    '🫳🏼' => 'ຝາມືລົງ: ສີຜິວໂທນຂາວປານກາງ',
    '🫳🏽' => 'ຝາມືລົງ: ສີຜິວໂທນປານກາງ',
    '🫳🏾' => 'ຝາມືລົງ: ສີຜິວໂທນດຳປານກາງ',
    '🫳🏿' => 'ຝາມືລົງ: ສີຜິວໂທນດຳ',
    '🫴🏻' => 'ແບຝາມື: ສີຜິວໂທນຂາວ',
    '🫴🏼' => 'ແບຝາມື: ສີຜິວໂທນຂາວປານກາງ',
    '🫴🏽' => 'ແບຝາມື: ສີຜິວໂທນປານກາງ',
    '🫴🏾' => 'ແບຝາມື: ສີຜິວໂທນດຳປານກາງ',
    '🫴🏿' => 'ແບຝາມື: ສີຜິວໂທນດຳ',
    '🫷🏻' => 'ປັດມືໄປທາງຊ້າຍ: ສີຜິວໂທນຂາວ',
    '🫷🏼' => 'ປັດມືໄປທາງຊ້າຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🫷🏽' => 'ປັດມືໄປທາງຊ້າຍ: ສີຜິວໂທນປານກາງ',
    '🫷🏾' => 'ປັດມືໄປທາງຊ້າຍ: ສີຜິວໂທນດຳປານກາງ',
    '🫷🏿' => 'ປັດມືໄປທາງຊ້າຍ: ສີຜິວໂທນດຳ',
    '🫸🏻' => 'ປັດມືໄປທາງຂວາ: ສີຜິວໂທນຂາວ',
    '🫸🏼' => 'ປັດມືໄປທາງຂວາ: ສີຜິວໂທນຂາວປານກາງ',
    '🫸🏽' => 'ປັດມືໄປທາງຂວາ: ສີຜິວໂທນປານກາງ',
    '🫸🏾' => 'ປັດມືໄປທາງຂວາ: ສີຜິວໂທນດຳປານກາງ',
    '🫸🏿' => 'ປັດມືໄປທາງຂວາ: ສີຜິວໂທນດຳ',
    '👌🏻' => 'ຍົກມືຕົກລົງ: ສີຜິວໂທນຂາວ',
    '👌🏼' => 'ຍົກມືຕົກລົງ: ສີຜິວໂທນຂາວປານກາງ',
    '👌🏽' => 'ຍົກມືຕົກລົງ: ສີຜິວໂທນປານກາງ',
    '👌🏾' => 'ຍົກມືຕົກລົງ: ສີຜິວໂທນດຳປານກາງ',
    '👌🏿' => 'ຍົກມືຕົກລົງ: ສີຜິວໂທນດຳ',
    '🤌🏻' => 'ຈຸ້ມ​ນິ້ວ​ມື: ສີຜິວໂທນຂາວ',
    '🤌🏼' => 'ຈຸ້ມ​ນິ້ວ​ມື: ສີຜິວໂທນຂາວປານກາງ',
    '🤌🏽' => 'ຈຸ້ມ​ນິ້ວ​ມື: ສີຜິວໂທນປານກາງ',
    '🤌🏾' => 'ຈຸ້ມ​ນິ້ວ​ມື: ສີຜິວໂທນດຳປານກາງ',
    '🤌🏿' => 'ຈຸ້ມ​ນິ້ວ​ມື: ສີຜິວໂທນດຳ',
    '🤏🏻' => 'ຢິບ​ມື: ສີຜິວໂທນຂາວ',
    '🤏🏼' => 'ຢິບ​ມື: ສີຜິວໂທນຂາວປານກາງ',
    '🤏🏽' => 'ຢິບ​ມື: ສີຜິວໂທນປານກາງ',
    '🤏🏾' => 'ຢິບ​ມື: ສີຜິວໂທນດຳປານກາງ',
    '🤏🏿' => 'ຢິບ​ມື: ສີຜິວໂທນດຳ',
    '✌🏻' => 'ຊູສອງນິ້ວ: ສີຜິວໂທນຂາວ',
    '✌🏼' => 'ຊູສອງນິ້ວ: ສີຜິວໂທນຂາວປານກາງ',
    '✌🏽' => 'ຊູສອງນິ້ວ: ສີຜິວໂທນປານກາງ',
    '✌🏾' => 'ຊູສອງນິ້ວ: ສີຜິວໂທນດຳປານກາງ',
    '✌🏿' => 'ຊູສອງນິ້ວ: ສີຜິວໂທນດຳ',
    '🤞🏻' => 'ນິ້ວໄຂວ່ກັນ: ສີຜິວໂທນຂາວ',
    '🤞🏼' => 'ນິ້ວໄຂວ່ກັນ: ສີຜິວໂທນຂາວປານກາງ',
    '🤞🏽' => 'ນິ້ວໄຂວ່ກັນ: ສີຜິວໂທນປານກາງ',
    '🤞🏾' => 'ນິ້ວໄຂວ່ກັນ: ສີຜິວໂທນດຳປານກາງ',
    '🤞🏿' => 'ນິ້ວໄຂວ່ກັນ: ສີຜິວໂທນດຳ',
    '🫰🏻' => 'ມືນິ້ວຊີ້ ແລະ ນິ້ວໂປ້ໄຂວ່ກັນ: ສີຜິວໂທນຂາວ',
    '🫰🏼' => 'ມືນິ້ວຊີ້ ແລະ ນິ້ວໂປ້ໄຂວ່ກັນ: ສີຜິວໂທນຂາວປານກາງ',
    '🫰🏽' => 'ມືນິ້ວຊີ້ ແລະ ນິ້ວໂປ້ໄຂວ່ກັນ: ສີຜິວໂທນປານກາງ',
    '🫰🏾' => 'ມືນິ້ວຊີ້ ແລະ ນິ້ວໂປ້ໄຂວ່ກັນ: ສີຜິວໂທນດຳປານກາງ',
    '🫰🏿' => 'ມືນິ້ວຊີ້ ແລະ ນິ້ວໂປ້ໄຂວ່ກັນ: ສີຜິວໂທນດຳ',
    '🤟🏻' => 'ທ່າເລີບຢູ: ສີຜິວໂທນຂາວ',
    '🤟🏼' => 'ທ່າເລີບຢູ: ສີຜິວໂທນຂາວປານກາງ',
    '🤟🏽' => 'ທ່າເລີບຢູ: ສີຜິວໂທນປານກາງ',
    '🤟🏾' => 'ທ່າເລີບຢູ: ສີຜິວໂທນດຳປານກາງ',
    '🤟🏿' => 'ທ່າເລີບຢູ: ສີຜິວໂທນດຳ',
    '🤘🏻' => 'ຊູນີ້ວແບບສັນຍາລັກເຂົາ: ສີຜິວໂທນຂາວ',
    '🤘🏼' => 'ຊູນີ້ວແບບສັນຍາລັກເຂົາ: ສີຜິວໂທນຂາວປານກາງ',
    '🤘🏽' => 'ຊູນີ້ວແບບສັນຍາລັກເຂົາ: ສີຜິວໂທນປານກາງ',
    '🤘🏾' => 'ຊູນີ້ວແບບສັນຍາລັກເຂົາ: ສີຜິວໂທນດຳປານກາງ',
    '🤘🏿' => 'ຊູນີ້ວແບບສັນຍາລັກເຂົາ: ສີຜິວໂທນດຳ',
    '🤙🏻' => 'ເຮັດມືໂທຫາຂ້ອຍ: ສີຜິວໂທນຂາວ',
    '🤙🏼' => 'ເຮັດມືໂທຫາຂ້ອຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🤙🏽' => 'ເຮັດມືໂທຫາຂ້ອຍ: ສີຜິວໂທນປານກາງ',
    '🤙🏾' => 'ເຮັດມືໂທຫາຂ້ອຍ: ສີຜິວໂທນດຳປານກາງ',
    '🤙🏿' => 'ເຮັດມືໂທຫາຂ້ອຍ: ສີຜິວໂທນດຳ',
    '👈🏻' => 'ນິ້ວຊີ້ໄປຊ້າຍ: ສີຜິວໂທນຂາວ',
    '👈🏼' => 'ນິ້ວຊີ້ໄປຊ້າຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👈🏽' => 'ນິ້ວຊີ້ໄປຊ້າຍ: ສີຜິວໂທນປານກາງ',
    '👈🏾' => 'ນິ້ວຊີ້ໄປຊ້າຍ: ສີຜິວໂທນດຳປານກາງ',
    '👈🏿' => 'ນິ້ວຊີ້ໄປຊ້າຍ: ສີຜິວໂທນດຳ',
    '👉🏻' => 'ນິ້ວຊີ້ໄປຂວາ: ສີຜິວໂທນຂາວ',
    '👉🏼' => 'ນິ້ວຊີ້ໄປຂວາ: ສີຜິວໂທນຂາວປານກາງ',
    '👉🏽' => 'ນິ້ວຊີ້ໄປຂວາ: ສີຜິວໂທນປານກາງ',
    '👉🏾' => 'ນິ້ວຊີ້ໄປຂວາ: ສີຜິວໂທນດຳປານກາງ',
    '👉🏿' => 'ນິ້ວຊີ້ໄປຂວາ: ສີຜິວໂທນດຳ',
    '👆🏻' => 'ຫຼັງມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນຂາວ',
    '👆🏼' => 'ຫຼັງມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '👆🏽' => 'ຫຼັງມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນປານກາງ',
    '👆🏾' => 'ຫຼັງມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນດຳປານກາງ',
    '👆🏿' => 'ຫຼັງມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນດຳ',
    '🖕🏻' => 'ນີ້ວກາງ: ສີຜິວໂທນຂາວ',
    '🖕🏼' => 'ນີ້ວກາງ: ສີຜິວໂທນຂາວປານກາງ',
    '🖕🏽' => 'ນີ້ວກາງ: ສີຜິວໂທນປານກາງ',
    '🖕🏾' => 'ນີ້ວກາງ: ສີຜິວໂທນດຳປານກາງ',
    '🖕🏿' => 'ນີ້ວກາງ: ສີຜິວໂທນດຳ',
    '👇🏻' => 'ຫຼັງມືນີ້ວຊີ້ລົງ: ສີຜິວໂທນຂາວ',
    '👇🏼' => 'ຫຼັງມືນີ້ວຊີ້ລົງ: ສີຜິວໂທນຂາວປານກາງ',
    '👇🏽' => 'ຫຼັງມືນີ້ວຊີ້ລົງ: ສີຜິວໂທນປານກາງ',
    '👇🏾' => 'ຫຼັງມືນີ້ວຊີ້ລົງ: ສີຜິວໂທນດຳປານກາງ',
    '👇🏿' => 'ຫຼັງມືນີ້ວຊີ້ລົງ: ສີຜິວໂທນດຳ',
    '☝🏻' => 'ຝ່າມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນຂາວ',
    '☝🏼' => 'ຝ່າມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '☝🏽' => 'ຝ່າມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນປານກາງ',
    '☝🏾' => 'ຝ່າມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນດຳປານກາງ',
    '☝🏿' => 'ຝ່າມືນີ້ວຊີ້ຂຶ້ນ: ສີຜິວໂທນດຳ',
    '🫵🏻' => 'ນີ້ວຊີ້ຊີ້ຜູ້ຊົມ: ສີຜິວໂທນຂາວ',
    '🫵🏼' => 'ນີ້ວຊີ້ຊີ້ຜູ້ຊົມ: ສີຜິວໂທນຂາວປານກາງ',
    '🫵🏽' => 'ນີ້ວຊີ້ຊີ້ຜູ້ຊົມ: ສີຜິວໂທນປານກາງ',
    '🫵🏾' => 'ນີ້ວຊີ້ຊີ້ຜູ້ຊົມ: ສີຜິວໂທນດຳປານກາງ',
    '🫵🏿' => 'ນີ້ວຊີ້ຊີ້ຜູ້ຊົມ: ສີຜິວໂທນດຳ',
    '👍🏻' => 'ໂປ້ມືຂຶ້ນ: ສີຜິວໂທນຂາວ',
    '👍🏼' => 'ໂປ້ມືຂຶ້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '👍🏽' => 'ໂປ້ມືຂຶ້ນ: ສີຜິວໂທນປານກາງ',
    '👍🏾' => 'ໂປ້ມືຂຶ້ນ: ສີຜິວໂທນດຳປານກາງ',
    '👍🏿' => 'ໂປ້ມືຂຶ້ນ: ສີຜິວໂທນດຳ',
    '👎🏻' => 'ໂປ້ມືລົງ: ສີຜິວໂທນຂາວ',
    '👎🏼' => 'ໂປ້ມືລົງ: ສີຜິວໂທນຂາວປານກາງ',
    '👎🏽' => 'ໂປ້ມືລົງ: ສີຜິວໂທນປານກາງ',
    '👎🏾' => 'ໂປ້ມືລົງ: ສີຜິວໂທນດຳປານກາງ',
    '👎🏿' => 'ໂປ້ມືລົງ: ສີຜິວໂທນດຳ',
    '✊🏻' => 'ຊູກຳປັ້ນ: ສີຜິວໂທນຂາວ',
    '✊🏼' => 'ຊູກຳປັ້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '✊🏽' => 'ຊູກຳປັ້ນ: ສີຜິວໂທນປານກາງ',
    '✊🏾' => 'ຊູກຳປັ້ນ: ສີຜິວໂທນດຳປານກາງ',
    '✊🏿' => 'ຊູກຳປັ້ນ: ສີຜິວໂທນດຳ',
    '👊🏻' => 'ກຳປັ້ນທີ່ຊັດເຂົ້າມາ: ສີຜິວໂທນຂາວ',
    '👊🏼' => 'ກຳປັ້ນທີ່ຊັດເຂົ້າມາ: ສີຜິວໂທນຂາວປານກາງ',
    '👊🏽' => 'ກຳປັ້ນທີ່ຊັດເຂົ້າມາ: ສີຜິວໂທນປານກາງ',
    '👊🏾' => 'ກຳປັ້ນທີ່ຊັດເຂົ້າມາ: ສີຜິວໂທນດຳປານກາງ',
    '👊🏿' => 'ກຳປັ້ນທີ່ຊັດເຂົ້າມາ: ສີຜິວໂທນດຳ',
    '🤛🏻' => 'ກໍາປັ້ນໄປທາງຊ້າຍ: ສີຜິວໂທນຂາວ',
    '🤛🏼' => 'ກໍາປັ້ນໄປທາງຊ້າຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🤛🏽' => 'ກໍາປັ້ນໄປທາງຊ້າຍ: ສີຜິວໂທນປານກາງ',
    '🤛🏾' => 'ກໍາປັ້ນໄປທາງຊ້າຍ: ສີຜິວໂທນດຳປານກາງ',
    '🤛🏿' => 'ກໍາປັ້ນໄປທາງຊ້າຍ: ສີຜິວໂທນດຳ',
    '🤜🏻' => 'ກໍາປັ້ນໄປທາງຂວາ: ສີຜິວໂທນຂາວ',
    '🤜🏼' => 'ກໍາປັ້ນໄປທາງຂວາ: ສີຜິວໂທນຂາວປານກາງ',
    '🤜🏽' => 'ກໍາປັ້ນໄປທາງຂວາ: ສີຜິວໂທນປານກາງ',
    '🤜🏾' => 'ກໍາປັ້ນໄປທາງຂວາ: ສີຜິວໂທນດຳປານກາງ',
    '🤜🏿' => 'ກໍາປັ້ນໄປທາງຂວາ: ສີຜິວໂທນດຳ',
    '👏🏻' => 'ຕົບມື: ສີຜິວໂທນຂາວ',
    '👏🏼' => 'ຕົບມື: ສີຜິວໂທນຂາວປານກາງ',
    '👏🏽' => 'ຕົບມື: ສີຜິວໂທນປານກາງ',
    '👏🏾' => 'ຕົບມື: ສີຜິວໂທນດຳປານກາງ',
    '👏🏿' => 'ຕົບມື: ສີຜິວໂທນດຳ',
    '🙌🏻' => 'ຄົນຍົກມືຂຶ້ນ: ສີຜິວໂທນຂາວ',
    '🙌🏼' => 'ຄົນຍົກມືຂຶ້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🙌🏽' => 'ຄົນຍົກມືຂຶ້ນ: ສີຜິວໂທນປານກາງ',
    '🙌🏾' => 'ຄົນຍົກມືຂຶ້ນ: ສີຜິວໂທນດຳປານກາງ',
    '🙌🏿' => 'ຄົນຍົກມືຂຶ້ນ: ສີຜິວໂທນດຳ',
    '🫶🏻' => 'ມືຮູບຊົງຫົວໃຈ: ສີຜິວໂທນຂາວ',
    '🫶🏼' => 'ມືຮູບຊົງຫົວໃຈ: ສີຜິວໂທນຂາວປານກາງ',
    '🫶🏽' => 'ມືຮູບຊົງຫົວໃຈ: ສີຜິວໂທນປານກາງ',
    '🫶🏾' => 'ມືຮູບຊົງຫົວໃຈ: ສີຜິວໂທນດຳປານກາງ',
    '🫶🏿' => 'ມືຮູບຊົງຫົວໃຈ: ສີຜິວໂທນດຳ',
    '👐🏻' => 'ແບມືອອກສອງຂ້າງ: ສີຜິວໂທນຂາວ',
    '👐🏼' => 'ແບມືອອກສອງຂ້າງ: ສີຜິວໂທນຂາວປານກາງ',
    '👐🏽' => 'ແບມືອອກສອງຂ້າງ: ສີຜິວໂທນປານກາງ',
    '👐🏾' => 'ແບມືອອກສອງຂ້າງ: ສີຜິວໂທນດຳປານກາງ',
    '👐🏿' => 'ແບມືອອກສອງຂ້າງ: ສີຜິວໂທນດຳ',
    '🤲🏻' => 'ຍົກຝ່າມືຂຶ້ນພ້ອມກັນ: ສີຜິວໂທນຂາວ',
    '🤲🏼' => 'ຍົກຝ່າມືຂຶ້ນພ້ອມກັນ: ສີຜິວໂທນຂາວປານກາງ',
    '🤲🏽' => 'ຍົກຝ່າມືຂຶ້ນພ້ອມກັນ: ສີຜິວໂທນປານກາງ',
    '🤲🏾' => 'ຍົກຝ່າມືຂຶ້ນພ້ອມກັນ: ສີຜິວໂທນດຳປານກາງ',
    '🤲🏿' => 'ຍົກຝ່າມືຂຶ້ນພ້ອມກັນ: ສີຜິວໂທນດຳ',
    '🤝🏻' => 'ຈັບມື: ສີຜິວໂທນຂາວ',
    '🤝🏼' => 'ຈັບມື: ສີຜິວໂທນຂາວປານກາງ',
    '🤝🏽' => 'ຈັບມື: ສີຜິວໂທນປານກາງ',
    '🤝🏾' => 'ຈັບມື: ສີຜິວໂທນດຳປານກາງ',
    '🤝🏿' => 'ຈັບມື: ສີຜິວໂທນດຳ',
    '🙏🏻' => 'ພະນົມມື: ສີຜິວໂທນຂາວ',
    '🙏🏼' => 'ພະນົມມື: ສີຜິວໂທນຂາວປານກາງ',
    '🙏🏽' => 'ພະນົມມື: ສີຜິວໂທນປານກາງ',
    '🙏🏾' => 'ພະນົມມື: ສີຜິວໂທນດຳປານກາງ',
    '🙏🏿' => 'ພະນົມມື: ສີຜິວໂທນດຳ',
    '✍🏻' => 'ມືກຳລັງຂຽນ: ສີຜິວໂທນຂາວ',
    '✍🏼' => 'ມືກຳລັງຂຽນ: ສີຜິວໂທນຂາວປານກາງ',
    '✍🏽' => 'ມືກຳລັງຂຽນ: ສີຜິວໂທນປານກາງ',
    '✍🏾' => 'ມືກຳລັງຂຽນ: ສີຜິວໂທນດຳປານກາງ',
    '✍🏿' => 'ມືກຳລັງຂຽນ: ສີຜິວໂທນດຳ',
    '💅🏻' => 'ທາເລັບມື: ສີຜິວໂທນຂາວ',
    '💅🏼' => 'ທາເລັບມື: ສີຜິວໂທນຂາວປານກາງ',
    '💅🏽' => 'ທາເລັບມື: ສີຜິວໂທນປານກາງ',
    '💅🏾' => 'ທາເລັບມື: ສີຜິວໂທນດຳປານກາງ',
    '💅🏿' => 'ທາເລັບມື: ສີຜິວໂທນດຳ',
    '🤳🏻' => 'ເຊວຟີ: ສີຜິວໂທນຂາວ',
    '🤳🏼' => 'ເຊວຟີ: ສີຜິວໂທນຂາວປານກາງ',
    '🤳🏽' => 'ເຊວຟີ: ສີຜິວໂທນປານກາງ',
    '🤳🏾' => 'ເຊວຟີ: ສີຜິວໂທນດຳປານກາງ',
    '🤳🏿' => 'ເຊວຟີ: ສີຜິວໂທນດຳ',
    '💪🏻' => 'ເບ່ງກ້າມ: ສີຜິວໂທນຂາວ',
    '💪🏼' => 'ເບ່ງກ້າມ: ສີຜິວໂທນຂາວປານກາງ',
    '💪🏽' => 'ເບ່ງກ້າມ: ສີຜິວໂທນປານກາງ',
    '💪🏾' => 'ເບ່ງກ້າມ: ສີຜິວໂທນດຳປານກາງ',
    '💪🏿' => 'ເບ່ງກ້າມ: ສີຜິວໂທນດຳ',
    '🦵🏻' => 'ຂາ: ສີຜິວໂທນຂາວ',
    '🦵🏼' => 'ຂາ: ສີຜິວໂທນຂາວປານກາງ',
    '🦵🏽' => 'ຂາ: ສີຜິວໂທນປານກາງ',
    '🦵🏾' => 'ຂາ: ສີຜິວໂທນດຳປານກາງ',
    '🦵🏿' => 'ຂາ: ສີຜິວໂທນດຳ',
    '🦶🏻' => 'ຕີນ: ສີຜິວໂທນຂາວ',
    '🦶🏼' => 'ຕີນ: ສີຜິວໂທນຂາວປານກາງ',
    '🦶🏽' => 'ຕີນ: ສີຜິວໂທນປານກາງ',
    '🦶🏾' => 'ຕີນ: ສີຜິວໂທນດຳປານກາງ',
    '🦶🏿' => 'ຕີນ: ສີຜິວໂທນດຳ',
    '👂🏻' => 'ຫູ: ສີຜິວໂທນຂາວ',
    '👂🏼' => 'ຫູ: ສີຜິວໂທນຂາວປານກາງ',
    '👂🏽' => 'ຫູ: ສີຜິວໂທນປານກາງ',
    '👂🏾' => 'ຫູ: ສີຜິວໂທນດຳປານກາງ',
    '👂🏿' => 'ຫູ: ສີຜິວໂທນດຳ',
    '🦻🏻' => 'ຫູ​​ມີເຄື່​ອງ​ຊ່ວຍ​ຟັງ: ສີຜິວໂທນຂາວ',
    '🦻🏼' => 'ຫູ​​ມີເຄື່​ອງ​ຊ່ວຍ​ຟັງ: ສີຜິວໂທນຂາວປານກາງ',
    '🦻🏽' => 'ຫູ​​ມີເຄື່​ອງ​ຊ່ວຍ​ຟັງ: ສີຜິວໂທນປານກາງ',
    '🦻🏾' => 'ຫູ​​ມີເຄື່​ອງ​ຊ່ວຍ​ຟັງ: ສີຜິວໂທນດຳປານກາງ',
    '🦻🏿' => 'ຫູ​​ມີເຄື່​ອງ​ຊ່ວຍ​ຟັງ: ສີຜິວໂທນດຳ',
    '👃🏻' => 'ດັງ: ສີຜິວໂທນຂາວ',
    '👃🏼' => 'ດັງ: ສີຜິວໂທນຂາວປານກາງ',
    '👃🏽' => 'ດັງ: ສີຜິວໂທນປານກາງ',
    '👃🏾' => 'ດັງ: ສີຜິວໂທນດຳປານກາງ',
    '👃🏿' => 'ດັງ: ສີຜິວໂທນດຳ',
    '👶🏻' => 'ແອນ້ອຍ: ສີຜິວໂທນຂາວ',
    '👶🏼' => 'ແອນ້ອຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👶🏽' => 'ແອນ້ອຍ: ສີຜິວໂທນປານກາງ',
    '👶🏾' => 'ແອນ້ອຍ: ສີຜິວໂທນດຳປານກາງ',
    '👶🏿' => 'ແອນ້ອຍ: ສີຜິວໂທນດຳ',
    '🧒🏻' => 'ເດັກ: ສີຜິວໂທນຂາວ',
    '🧒🏼' => 'ເດັກ: ສີຜິວໂທນຂາວປານກາງ',
    '🧒🏽' => 'ເດັກ: ສີຜິວໂທນປານກາງ',
    '🧒🏾' => 'ເດັກ: ສີຜິວໂທນດຳປານກາງ',
    '🧒🏿' => 'ເດັກ: ສີຜິວໂທນດຳ',
    '👦🏻' => 'ເດັກຊາຍ: ສີຜິວໂທນຂາວ',
    '👦🏼' => 'ເດັກຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👦🏽' => 'ເດັກຊາຍ: ສີຜິວໂທນປານກາງ',
    '👦🏾' => 'ເດັກຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👦🏿' => 'ເດັກຊາຍ: ສີຜິວໂທນດຳ',
    '👧🏻' => 'ເດັກຍິງ: ສີຜິວໂທນຂາວ',
    '👧🏼' => 'ເດັກຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👧🏽' => 'ເດັກຍິງ: ສີຜິວໂທນປານກາງ',
    '👧🏾' => 'ເດັກຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👧🏿' => 'ເດັກຍິງ: ສີຜິວໂທນດຳ',
    '🧑🏻' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວ',
    '🧑🏼' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນຂາວປານກາງ',
    '🧑🏽' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນປານກາງ',
    '🧑🏾' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳປານກາງ',
    '🧑🏿' => 'ຜູ້ໃຫຍ່: ສີຜິວໂທນດຳ',
    '👱🏻' => 'ຄົນຜົມສີເຫຼືອງອ່ອນ: ສີຜິວໂທນຂາວ',
    '👱🏼' => 'ຄົນຜົມສີເຫຼືອງອ່ອນ: ສີຜິວໂທນຂາວປານກາງ',
    '👱🏽' => 'ຄົນຜົມສີເຫຼືອງອ່ອນ: ສີຜິວໂທນປານກາງ',
    '👱🏾' => 'ຄົນຜົມສີເຫຼືອງອ່ອນ: ສີຜິວໂທນດຳປານກາງ',
    '👱🏿' => 'ຄົນຜົມສີເຫຼືອງອ່ອນ: ສີຜິວໂທນດຳ',
    '👨🏻' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວ',
    '👨🏼' => 'ຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👨🏽' => 'ຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ',
    '👨🏾' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '👨🏿' => 'ຜູ້ຊາຍ: ສີຜິວໂທນດຳ',
    '🧔🏻' => 'ຄົນມີໜວດ: ສີຜິວໂທນຂາວ',
    '🧔🏼' => 'ຄົນມີໜວດ: ສີຜິວໂທນຂາວປານກາງ',
    '🧔🏽' => 'ຄົນມີໜວດ: ສີຜິວໂທນປານກາງ',
    '🧔🏾' => 'ຄົນມີໜວດ: ສີຜິວໂທນດຳປານກາງ',
    '🧔🏿' => 'ຄົນມີໜວດ: ສີຜິວໂທນດຳ',
    '👩🏻' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວ',
    '👩🏼' => 'ແມ່ຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👩🏽' => 'ແມ່ຍິງ: ສີຜິວໂທນປານກາງ',
    '👩🏾' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👩🏿' => 'ແມ່ຍິງ: ສີຜິວໂທນດຳ',
    '🧓🏻' => 'ຜູ້ໃຫຍ່ທີ່ມີອາຍຸ: ສີຜິວໂທນຂາວ',
    '🧓🏼' => 'ຜູ້ໃຫຍ່ທີ່ມີອາຍຸ: ສີຜິວໂທນຂາວປານກາງ',
    '🧓🏽' => 'ຜູ້ໃຫຍ່ທີ່ມີອາຍຸ: ສີຜິວໂທນປານກາງ',
    '🧓🏾' => 'ຜູ້ໃຫຍ່ທີ່ມີອາຍຸ: ສີຜິວໂທນດຳປານກາງ',
    '🧓🏿' => 'ຜູ້ໃຫຍ່ທີ່ມີອາຍຸ: ສີຜິວໂທນດຳ',
    '👴🏻' => 'ຜູ້ຊາຍເຖົ້າ: ສີຜິວໂທນຂາວ',
    '👴🏼' => 'ຜູ້ຊາຍເຖົ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '👴🏽' => 'ຜູ້ຊາຍເຖົ້າ: ສີຜິວໂທນປານກາງ',
    '👴🏾' => 'ຜູ້ຊາຍເຖົ້າ: ສີຜິວໂທນດຳປານກາງ',
    '👴🏿' => 'ຜູ້ຊາຍເຖົ້າ: ສີຜິວໂທນດຳ',
    '👵🏻' => 'ແມ່ຍິງເຖົ້າ: ສີຜິວໂທນຂາວ',
    '👵🏼' => 'ແມ່ຍິງເຖົ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '👵🏽' => 'ແມ່ຍິງເຖົ້າ: ສີຜິວໂທນປານກາງ',
    '👵🏾' => 'ແມ່ຍິງເຖົ້າ: ສີຜິວໂທນດຳປານກາງ',
    '👵🏿' => 'ແມ່ຍິງເຖົ້າ: ສີຜິວໂທນດຳ',
    '🙍🏻' => 'ຄົນເຮັດໜ້າຫຍຸ້ງ: ສີຜິວໂທນຂາວ',
    '🙍🏼' => 'ຄົນເຮັດໜ້າຫຍຸ້ງ: ສີຜິວໂທນຂາວປານກາງ',
    '🙍🏽' => 'ຄົນເຮັດໜ້າຫຍຸ້ງ: ສີຜິວໂທນປານກາງ',
    '🙍🏾' => 'ຄົນເຮັດໜ້າຫຍຸ້ງ: ສີຜິວໂທນດຳປານກາງ',
    '🙍🏿' => 'ຄົນເຮັດໜ້າຫຍຸ້ງ: ສີຜິວໂທນດຳ',
    '🙎🏻' => 'ຄົນເຮັດໜ້າບໍ່ພໍໃຈ: ສີຜິວໂທນຂາວ',
    '🙎🏼' => 'ຄົນເຮັດໜ້າບໍ່ພໍໃຈ: ສີຜິວໂທນຂາວປານກາງ',
    '🙎🏽' => 'ຄົນເຮັດໜ້າບໍ່ພໍໃຈ: ສີຜິວໂທນປານກາງ',
    '🙎🏾' => 'ຄົນເຮັດໜ້າບໍ່ພໍໃຈ: ສີຜິວໂທນດຳປານກາງ',
    '🙎🏿' => 'ຄົນເຮັດໜ້າບໍ່ພໍໃຈ: ສີຜິວໂທນດຳ',
    '🙅🏻' => 'ທ່າທາງ ບໍ່: ສີຜິວໂທນຂາວ',
    '🙅🏼' => 'ທ່າທາງ ບໍ່: ສີຜິວໂທນຂາວປານກາງ',
    '🙅🏽' => 'ທ່າທາງ ບໍ່: ສີຜິວໂທນປານກາງ',
    '🙅🏾' => 'ທ່າທາງ ບໍ່: ສີຜິວໂທນດຳປານກາງ',
    '🙅🏿' => 'ທ່າທາງ ບໍ່: ສີຜິວໂທນດຳ',
    '🙆🏻' => 'ທ່າທາງ ຕົກລົງ: ສີຜິວໂທນຂາວ',
    '🙆🏼' => 'ທ່າທາງ ຕົກລົງ: ສີຜິວໂທນຂາວປານກາງ',
    '🙆🏽' => 'ທ່າທາງ ຕົກລົງ: ສີຜິວໂທນປານກາງ',
    '🙆🏾' => 'ທ່າທາງ ຕົກລົງ: ສີຜິວໂທນດຳປານກາງ',
    '🙆🏿' => 'ທ່າທາງ ຕົກລົງ: ສີຜິວໂທນດຳ',
    '💁🏻' => 'ໂຕະສອບຖາມຂໍ້ມູນ: ສີຜິວໂທນຂາວ',
    '💁🏼' => 'ໂຕະສອບຖາມຂໍ້ມູນ: ສີຜິວໂທນຂາວປານກາງ',
    '💁🏽' => 'ໂຕະສອບຖາມຂໍ້ມູນ: ສີຜິວໂທນປານກາງ',
    '💁🏾' => 'ໂຕະສອບຖາມຂໍ້ມູນ: ສີຜິວໂທນດຳປານກາງ',
    '💁🏿' => 'ໂຕະສອບຖາມຂໍ້ມູນ: ສີຜິວໂທນດຳ',
    '🙋🏻' => 'ຄົນດີໃຈຍົກມືຂຶ້ນ: ສີຜິວໂທນຂາວ',
    '🙋🏼' => 'ຄົນດີໃຈຍົກມືຂຶ້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🙋🏽' => 'ຄົນດີໃຈຍົກມືຂຶ້ນ: ສີຜິວໂທນປານກາງ',
    '🙋🏾' => 'ຄົນດີໃຈຍົກມືຂຶ້ນ: ສີຜິວໂທນດຳປານກາງ',
    '🙋🏿' => 'ຄົນດີໃຈຍົກມືຂຶ້ນ: ສີຜິວໂທນດຳ',
    '🧏🏻' => 'ຄົນ​ຫູ​ໜວກ: ສີຜິວໂທນຂາວ',
    '🧏🏼' => 'ຄົນ​ຫູ​ໜວກ: ສີຜິວໂທນຂາວປານກາງ',
    '🧏🏽' => 'ຄົນ​ຫູ​ໜວກ: ສີຜິວໂທນປານກາງ',
    '🧏🏾' => 'ຄົນ​ຫູ​ໜວກ: ສີຜິວໂທນດຳປານກາງ',
    '🧏🏿' => 'ຄົນ​ຫູ​ໜວກ: ສີຜິວໂທນດຳ',
    '🙇🏻' => 'ຄົນກົ້ມຂໍໂທດ: ສີຜິວໂທນຂາວ',
    '🙇🏼' => 'ຄົນກົ້ມຂໍໂທດ: ສີຜິວໂທນຂາວປານກາງ',
    '🙇🏽' => 'ຄົນກົ້ມຂໍໂທດ: ສີຜິວໂທນປານກາງ',
    '🙇🏾' => 'ຄົນກົ້ມຂໍໂທດ: ສີຜິວໂທນດຳປານກາງ',
    '🙇🏿' => 'ຄົນກົ້ມຂໍໂທດ: ສີຜິວໂທນດຳ',
    '🤦🏻' => 'ມືກ່າຍໜ້າ: ສີຜິວໂທນຂາວ',
    '🤦🏼' => 'ມືກ່າຍໜ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🤦🏽' => 'ມືກ່າຍໜ້າ: ສີຜິວໂທນປານກາງ',
    '🤦🏾' => 'ມືກ່າຍໜ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🤦🏿' => 'ມືກ່າຍໜ້າ: ສີຜິວໂທນດຳ',
    '🤷🏻' => 'ຍັກໄຫລ່: ສີຜິວໂທນຂາວ',
    '🤷🏼' => 'ຍັກໄຫລ່: ສີຜິວໂທນຂາວປານກາງ',
    '🤷🏽' => 'ຍັກໄຫລ່: ສີຜິວໂທນປານກາງ',
    '🤷🏾' => 'ຍັກໄຫລ່: ສີຜິວໂທນດຳປານກາງ',
    '🤷🏿' => 'ຍັກໄຫລ່: ສີຜິວໂທນດຳ',
    '👮🏻' => 'ເຈົ້າໜ້າທີ່ຕຳຫຼວດ: ສີຜິວໂທນຂາວ',
    '👮🏼' => 'ເຈົ້າໜ້າທີ່ຕຳຫຼວດ: ສີຜິວໂທນຂາວປານກາງ',
    '👮🏽' => 'ເຈົ້າໜ້າທີ່ຕຳຫຼວດ: ສີຜິວໂທນປານກາງ',
    '👮🏾' => 'ເຈົ້າໜ້າທີ່ຕຳຫຼວດ: ສີຜິວໂທນດຳປານກາງ',
    '👮🏿' => 'ເຈົ້າໜ້າທີ່ຕຳຫຼວດ: ສີຜິວໂທນດຳ',
    '🕵🏻' => 'ນັກສືບ: ສີຜິວໂທນຂາວ',
    '🕵🏼' => 'ນັກສືບ: ສີຜິວໂທນຂາວປານກາງ',
    '🕵🏽' => 'ນັກສືບ: ສີຜິວໂທນປານກາງ',
    '🕵🏾' => 'ນັກສືບ: ສີຜິວໂທນດຳປານກາງ',
    '🕵🏿' => 'ນັກສືບ: ສີຜິວໂທນດຳ',
    '💂🏻' => 'ຄົນເຝົ້າຢາມ: ສີຜິວໂທນຂາວ',
    '💂🏼' => 'ຄົນເຝົ້າຢາມ: ສີຜິວໂທນຂາວປານກາງ',
    '💂🏽' => 'ຄົນເຝົ້າຢາມ: ສີຜິວໂທນປານກາງ',
    '💂🏾' => 'ຄົນເຝົ້າຢາມ: ສີຜິວໂທນດຳປານກາງ',
    '💂🏿' => 'ຄົນເຝົ້າຢາມ: ສີຜິວໂທນດຳ',
    '🥷🏻' => 'ນິນຈາ: ສີຜິວໂທນຂາວ',
    '🥷🏼' => 'ນິນຈາ: ສີຜິວໂທນຂາວປານກາງ',
    '🥷🏽' => 'ນິນຈາ: ສີຜິວໂທນປານກາງ',
    '🥷🏾' => 'ນິນຈາ: ສີຜິວໂທນດຳປານກາງ',
    '🥷🏿' => 'ນິນຈາ: ສີຜິວໂທນດຳ',
    '👷🏻' => 'ຄົນງານກໍ່ສ້າງ: ສີຜິວໂທນຂາວ',
    '👷🏼' => 'ຄົນງານກໍ່ສ້າງ: ສີຜິວໂທນຂາວປານກາງ',
    '👷🏽' => 'ຄົນງານກໍ່ສ້າງ: ສີຜິວໂທນປານກາງ',
    '👷🏾' => 'ຄົນງານກໍ່ສ້າງ: ສີຜິວໂທນດຳປານກາງ',
    '👷🏿' => 'ຄົນງານກໍ່ສ້າງ: ສີຜິວໂທນດຳ',
    '🫅🏻' => 'ຄົນໃສ່ມົງກຸດ: ສີຜິວໂທນຂາວ',
    '🫅🏼' => 'ຄົນໃສ່ມົງກຸດ: ສີຜິວໂທນຂາວປານກາງ',
    '🫅🏽' => 'ຄົນໃສ່ມົງກຸດ: ສີຜິວໂທນປານກາງ',
    '🫅🏾' => 'ຄົນໃສ່ມົງກຸດ: ສີຜິວໂທນດຳປານກາງ',
    '🫅🏿' => 'ຄົນໃສ່ມົງກຸດ: ສີຜິວໂທນດຳ',
    '🤴🏻' => 'ເຈົ້າຊາຍ: ສີຜິວໂທນຂາວ',
    '🤴🏼' => 'ເຈົ້າຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🤴🏽' => 'ເຈົ້າຊາຍ: ສີຜິວໂທນປານກາງ',
    '🤴🏾' => 'ເຈົ້າຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🤴🏿' => 'ເຈົ້າຊາຍ: ສີຜິວໂທນດຳ',
    '👸🏻' => 'ເຈົ້າຍິງ: ສີຜິວໂທນຂາວ',
    '👸🏼' => 'ເຈົ້າຍິງ: ສີຜິວໂທນຂາວປານກາງ',
    '👸🏽' => 'ເຈົ້າຍິງ: ສີຜິວໂທນປານກາງ',
    '👸🏾' => 'ເຈົ້າຍິງ: ສີຜິວໂທນດຳປານກາງ',
    '👸🏿' => 'ເຈົ້າຍິງ: ສີຜິວໂທນດຳ',
    '👳🏻' => 'ຜູ້ຊາຍໃສ່ຜ້າພັນຫົວ: ສີຜິວໂທນຂາວ',
    '👳🏼' => 'ຜູ້ຊາຍໃສ່ຜ້າພັນຫົວ: ສີຜິວໂທນຂາວປານກາງ',
    '👳🏽' => 'ຜູ້ຊາຍໃສ່ຜ້າພັນຫົວ: ສີຜິວໂທນປານກາງ',
    '👳🏾' => 'ຜູ້ຊາຍໃສ່ຜ້າພັນຫົວ: ສີຜິວໂທນດຳປານກາງ',
    '👳🏿' => 'ຜູ້ຊາຍໃສ່ຜ້າພັນຫົວ: ສີຜິວໂທນດຳ',
    '👲🏻' => 'ຜູ້ຊາຍໃສ່ໝວກແກັບຈີນ: ສີຜິວໂທນຂາວ',
    '👲🏼' => 'ຜູ້ຊາຍໃສ່ໝວກແກັບຈີນ: ສີຜິວໂທນຂາວປານກາງ',
    '👲🏽' => 'ຜູ້ຊາຍໃສ່ໝວກແກັບຈີນ: ສີຜິວໂທນປານກາງ',
    '👲🏾' => 'ຜູ້ຊາຍໃສ່ໝວກແກັບຈີນ: ສີຜິວໂທນດຳປານກາງ',
    '👲🏿' => 'ຜູ້ຊາຍໃສ່ໝວກແກັບຈີນ: ສີຜິວໂທນດຳ',
    '🧕🏻' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມຫົວ: ສີຜິວໂທນຂາວ',
    '🧕🏼' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມຫົວ: ສີຜິວໂທນຂາວປານກາງ',
    '🧕🏽' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມຫົວ: ສີຜິວໂທນປານກາງ',
    '🧕🏾' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມຫົວ: ສີຜິວໂທນດຳປານກາງ',
    '🧕🏿' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມຫົວ: ສີຜິວໂທນດຳ',
    '🤵🏻' => 'ຄົນໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນຂາວ',
    '🤵🏼' => 'ຄົນໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນຂາວປານກາງ',
    '🤵🏽' => 'ຄົນໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນປານກາງ',
    '🤵🏾' => 'ຄົນໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນດຳປານກາງ',
    '🤵🏿' => 'ຄົນໃສ່ຊຸດທັກຊິໂດ: ສີຜິວໂທນດຳ',
    '👰🏻' => 'ເຈົ້າສາວໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນຂາວ',
    '👰🏼' => 'ເຈົ້າສາວໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '👰🏽' => 'ເຈົ້າສາວໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນປານກາງ',
    '👰🏾' => 'ເຈົ້າສາວໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນດຳປານກາງ',
    '👰🏿' => 'ເຈົ້າສາວໃສ່ຜ້າຄຸມໜ້າ: ສີຜິວໂທນດຳ',
    '🤰🏻' => 'ຜູ້ຍິງຖືພາ: ສີຜິວໂທນຂາວ',
    '🤰🏼' => 'ຜູ້ຍິງຖືພາ: ສີຜິວໂທນຂາວປານກາງ',
    '🤰🏽' => 'ຜູ້ຍິງຖືພາ: ສີຜິວໂທນປານກາງ',
    '🤰🏾' => 'ຜູ້ຍິງຖືພາ: ສີຜິວໂທນດຳປານກາງ',
    '🤰🏿' => 'ຜູ້ຍິງຖືພາ: ສີຜິວໂທນດຳ',
    '🫃🏻' => 'ຜູ້ຊາຍຖືພາ: ສີຜິວໂທນຂາວ',
    '🫃🏼' => 'ຜູ້ຊາຍຖືພາ: ສີຜິວໂທນຂາວປານກາງ',
    '🫃🏽' => 'ຜູ້ຊາຍຖືພາ: ສີຜິວໂທນປານກາງ',
    '🫃🏾' => 'ຜູ້ຊາຍຖືພາ: ສີຜິວໂທນດຳປານກາງ',
    '🫃🏿' => 'ຜູ້ຊາຍຖືພາ: ສີຜິວໂທນດຳ',
    '🫄🏻' => 'ຄົນຖືພາ: ສີຜິວໂທນຂາວ',
    '🫄🏼' => 'ຄົນຖືພາ: ສີຜິວໂທນຂາວປານກາງ',
    '🫄🏽' => 'ຄົນຖືພາ: ສີຜິວໂທນປານກາງ',
    '🫄🏾' => 'ຄົນຖືພາ: ສີຜິວໂທນດຳປານກາງ',
    '🫄🏿' => 'ຄົນຖືພາ: ສີຜິວໂທນດຳ',
    '🤱🏻' => 'ປ້ອນນົມ: ສີຜິວໂທນຂາວ',
    '🤱🏼' => 'ປ້ອນນົມ: ສີຜິວໂທນຂາວປານກາງ',
    '🤱🏽' => 'ປ້ອນນົມ: ສີຜິວໂທນປານກາງ',
    '🤱🏾' => 'ປ້ອນນົມ: ສີຜິວໂທນດຳປານກາງ',
    '🤱🏿' => 'ປ້ອນນົມ: ສີຜິວໂທນດຳ',
    '👼🏻' => 'ນາງຟ້າເດັກ: ສີຜິວໂທນຂາວ',
    '👼🏼' => 'ນາງຟ້າເດັກ: ສີຜິວໂທນຂາວປານກາງ',
    '👼🏽' => 'ນາງຟ້າເດັກ: ສີຜິວໂທນປານກາງ',
    '👼🏾' => 'ນາງຟ້າເດັກ: ສີຜິວໂທນດຳປານກາງ',
    '👼🏿' => 'ນາງຟ້າເດັກ: ສີຜິວໂທນດຳ',
    '🎅🏻' => 'ຊານຕາຄລັອສ: ສີຜິວໂທນຂາວ',
    '🎅🏼' => 'ຊານຕາຄລັອສ: ສີຜິວໂທນຂາວປານກາງ',
    '🎅🏽' => 'ຊານຕາຄລັອສ: ສີຜິວໂທນປານກາງ',
    '🎅🏾' => 'ຊານຕາຄລັອສ: ສີຜິວໂທນດຳປານກາງ',
    '🎅🏿' => 'ຊານຕາຄລັອສ: ສີຜິວໂທນດຳ',
    '🤶🏻' => 'ແມ່ຄຣິສມາສ: ສີຜິວໂທນຂາວ',
    '🤶🏼' => 'ແມ່ຄຣິສມາສ: ສີຜິວໂທນຂາວປານກາງ',
    '🤶🏽' => 'ແມ່ຄຣິສມາສ: ສີຜິວໂທນປານກາງ',
    '🤶🏾' => 'ແມ່ຄຣິສມາສ: ສີຜິວໂທນດຳປານກາງ',
    '🤶🏿' => 'ແມ່ຄຣິສມາສ: ສີຜິວໂທນດຳ',
    '🦸🏻' => 'ສຸດຍອດພະເອກ: ສີຜິວໂທນຂາວ',
    '🦸🏼' => 'ສຸດຍອດພະເອກ: ສີຜິວໂທນຂາວປານກາງ',
    '🦸🏽' => 'ສຸດຍອດພະເອກ: ສີຜິວໂທນປານກາງ',
    '🦸🏾' => 'ສຸດຍອດພະເອກ: ສີຜິວໂທນດຳປານກາງ',
    '🦸🏿' => 'ສຸດຍອດພະເອກ: ສີຜິວໂທນດຳ',
    '🦹🏻' => 'ຈອມວາຍລ້າຍ: ສີຜິວໂທນຂາວ',
    '🦹🏼' => 'ຈອມວາຍລ້າຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🦹🏽' => 'ຈອມວາຍລ້າຍ: ສີຜິວໂທນປານກາງ',
    '🦹🏾' => 'ຈອມວາຍລ້າຍ: ສີຜິວໂທນດຳປານກາງ',
    '🦹🏿' => 'ຈອມວາຍລ້າຍ: ສີຜິວໂທນດຳ',
    '🧙🏻' => 'ຜູ້ວິເສດ: ສີຜິວໂທນຂາວ',
    '🧙🏼' => 'ຜູ້ວິເສດ: ສີຜິວໂທນຂາວປານກາງ',
    '🧙🏽' => 'ຜູ້ວິເສດ: ສີຜິວໂທນປານກາງ',
    '🧙🏾' => 'ຜູ້ວິເສດ: ສີຜິວໂທນດຳປານກາງ',
    '🧙🏿' => 'ຜູ້ວິເສດ: ສີຜິວໂທນດຳ',
    '🧚🏻' => 'ນາງຟ້າ: ສີຜິວໂທນຂາວ',
    '🧚🏼' => 'ນາງຟ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🧚🏽' => 'ນາງຟ້າ: ສີຜິວໂທນປານກາງ',
    '🧚🏾' => 'ນາງຟ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🧚🏿' => 'ນາງຟ້າ: ສີຜິວໂທນດຳ',
    '🧛🏻' => 'ແວມພາຍ: ສີຜິວໂທນຂາວ',
    '🧛🏼' => 'ແວມພາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🧛🏽' => 'ແວມພາຍ: ສີຜິວໂທນປານກາງ',
    '🧛🏾' => 'ແວມພາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🧛🏿' => 'ແວມພາຍ: ສີຜິວໂທນດຳ',
    '🧜🏻' => 'ເງືອກຜູ້ຊາຍ: ສີຜິວໂທນຂາວ',
    '🧜🏼' => 'ເງືອກຜູ້ຊາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🧜🏽' => 'ເງືອກຜູ້ຊາຍ: ສີຜິວໂທນປານກາງ',
    '🧜🏾' => 'ເງືອກຜູ້ຊາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🧜🏿' => 'ເງືອກຜູ້ຊາຍ: ສີຜິວໂທນດຳ',
    '🧝🏻' => 'ເອວຟ໌: ສີຜິວໂທນຂາວ',
    '🧝🏼' => 'ເອວຟ໌: ສີຜິວໂທນຂາວປານກາງ',
    '🧝🏽' => 'ເອວຟ໌: ສີຜິວໂທນປານກາງ',
    '🧝🏾' => 'ເອວຟ໌: ສີຜິວໂທນດຳປານກາງ',
    '🧝🏿' => 'ເອວຟ໌: ສີຜິວໂທນດຳ',
    '💆🏻' => 'ນວດໜ້າ: ສີຜິວໂທນຂາວ',
    '💆🏼' => 'ນວດໜ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '💆🏽' => 'ນວດໜ້າ: ສີຜິວໂທນປານກາງ',
    '💆🏾' => 'ນວດໜ້າ: ສີຜິວໂທນດຳປານກາງ',
    '💆🏿' => 'ນວດໜ້າ: ສີຜິວໂທນດຳ',
    '💇🏻' => 'ຕັດຜົມ: ສີຜິວໂທນຂາວ',
    '💇🏼' => 'ຕັດຜົມ: ສີຜິວໂທນຂາວປານກາງ',
    '💇🏽' => 'ຕັດຜົມ: ສີຜິວໂທນປານກາງ',
    '💇🏾' => 'ຕັດຜົມ: ສີຜິວໂທນດຳປານກາງ',
    '💇🏿' => 'ຕັດຜົມ: ສີຜິວໂທນດຳ',
    '🚶🏻' => 'ຄົນຍ່າງ: ສີຜິວໂທນຂາວ',
    '🚶🏼' => 'ຄົນຍ່າງ: ສີຜິວໂທນຂາວປານກາງ',
    '🚶🏽' => 'ຄົນຍ່າງ: ສີຜິວໂທນປານກາງ',
    '🚶🏾' => 'ຄົນຍ່າງ: ສີຜິວໂທນດຳປານກາງ',
    '🚶🏿' => 'ຄົນຍ່າງ: ສີຜິວໂທນດຳ',
    '🧍🏻' => 'ຄົນ​ຢືນ: ສີຜິວໂທນຂາວ',
    '🧍🏼' => 'ຄົນ​ຢືນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧍🏽' => 'ຄົນ​ຢືນ: ສີຜິວໂທນປານກາງ',
    '🧍🏾' => 'ຄົນ​ຢືນ: ສີຜິວໂທນດຳປານກາງ',
    '🧍🏿' => 'ຄົນ​ຢືນ: ສີຜິວໂທນດຳ',
    '🧎🏻' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວ',
    '🧎🏼' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນຂາວປານກາງ',
    '🧎🏽' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນປານກາງ',
    '🧎🏾' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳປານກາງ',
    '🧎🏿' => '​ຄົນ​ຄຸ​ເຂົ່າ: ສີຜິວໂທນດຳ',
    '🏃🏻' => 'ຄົນແລ່ນ: ສີຜິວໂທນຂາວ',
    '🏃🏼' => 'ຄົນແລ່ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🏃🏽' => 'ຄົນແລ່ນ: ສີຜິວໂທນປານກາງ',
    '🏃🏾' => 'ຄົນແລ່ນ: ສີຜິວໂທນດຳປານກາງ',
    '🏃🏿' => 'ຄົນແລ່ນ: ສີຜິວໂທນດຳ',
    '💃🏻' => 'ຜູ້ຍິງກຳລັງເຕັ້ນລຳ: ສີຜິວໂທນຂາວ',
    '💃🏼' => 'ຜູ້ຍິງກຳລັງເຕັ້ນລຳ: ສີຜິວໂທນຂາວປານກາງ',
    '💃🏽' => 'ຜູ້ຍິງກຳລັງເຕັ້ນລຳ: ສີຜິວໂທນປານກາງ',
    '💃🏾' => 'ຜູ້ຍິງກຳລັງເຕັ້ນລຳ: ສີຜິວໂທນດຳປານກາງ',
    '💃🏿' => 'ຜູ້ຍິງກຳລັງເຕັ້ນລຳ: ສີຜິວໂທນດຳ',
    '🕺🏻' => 'ຜູ້ຊາຍເຕັ້ນ: ສີຜິວໂທນຂາວ',
    '🕺🏼' => 'ຜູ້ຊາຍເຕັ້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🕺🏽' => 'ຜູ້ຊາຍເຕັ້ນ: ສີຜິວໂທນປານກາງ',
    '🕺🏾' => 'ຜູ້ຊາຍເຕັ້ນ: ສີຜິວໂທນດຳປານກາງ',
    '🕺🏿' => 'ຜູ້ຊາຍເຕັ້ນ: ສີຜິວໂທນດຳ',
    '🕴🏻' => 'ຜູ້ຊາຍໃສ່ຊຸດທຸລະກິດລອຍໃນອາກາດ: ສີຜິວໂທນຂາວ',
    '🕴🏼' => 'ຜູ້ຊາຍໃສ່ຊຸດທຸລະກິດລອຍໃນອາກາດ: ສີຜິວໂທນຂາວປານກາງ',
    '🕴🏽' => 'ຜູ້ຊາຍໃສ່ຊຸດທຸລະກິດລອຍໃນອາກາດ: ສີຜິວໂທນປານກາງ',
    '🕴🏾' => 'ຜູ້ຊາຍໃສ່ຊຸດທຸລະກິດລອຍໃນອາກາດ: ສີຜິວໂທນດຳປານກາງ',
    '🕴🏿' => 'ຜູ້ຊາຍໃສ່ຊຸດທຸລະກິດລອຍໃນອາກາດ: ສີຜິວໂທນດຳ',
    '👯🏻' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວ',
    '👯🏼' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນຂາວປານກາງ',
    '👯🏽' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນປານກາງ',
    '👯🏾' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳປານກາງ',
    '👯🏿' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ: ສີຜິວໂທນດຳ',
    '🧖🏻' => 'ຄົນໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນຂາວ',
    '🧖🏼' => 'ຄົນໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນຂາວປານກາງ',
    '🧖🏽' => 'ຄົນໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນປານກາງ',
    '🧖🏾' => 'ຄົນໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນດຳປານກາງ',
    '🧖🏿' => 'ຄົນໃນຫ້ອງອົບໄອນ້ຳ: ສີຜິວໂທນດຳ',
    '🧗🏻' => 'ຄົນກຳລັງປີນ: ສີຜິວໂທນຂາວ',
    '🧗🏼' => 'ຄົນກຳລັງປີນ: ສີຜິວໂທນຂາວປານກາງ',
    '🧗🏽' => 'ຄົນກຳລັງປີນ: ສີຜິວໂທນປານກາງ',
    '🧗🏾' => 'ຄົນກຳລັງປີນ: ສີຜິວໂທນດຳປານກາງ',
    '🧗🏿' => 'ຄົນກຳລັງປີນ: ສີຜິວໂທນດຳ',
    '🏇🏻' => 'ການແຂ່ງມ້າ: ສີຜິວໂທນຂາວ',
    '🏇🏼' => 'ການແຂ່ງມ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🏇🏽' => 'ການແຂ່ງມ້າ: ສີຜິວໂທນປານກາງ',
    '🏇🏾' => 'ການແຂ່ງມ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🏇🏿' => 'ການແຂ່ງມ້າ: ສີຜິວໂທນດຳ',
    '🏂🏻' => 'ນັກຫຼິ້ນສະໂນບອດ: ສີຜິວໂທນຂາວ',
    '🏂🏼' => 'ນັກຫຼິ້ນສະໂນບອດ: ສີຜິວໂທນຂາວປານກາງ',
    '🏂🏽' => 'ນັກຫຼິ້ນສະໂນບອດ: ສີຜິວໂທນປານກາງ',
    '🏂🏾' => 'ນັກຫຼິ້ນສະໂນບອດ: ສີຜິວໂທນດຳປານກາງ',
    '🏂🏿' => 'ນັກຫຼິ້ນສະໂນບອດ: ສີຜິວໂທນດຳ',
    '🏌🏻' => 'ນັກກັອບ: ສີຜິວໂທນຂາວ',
    '🏌🏼' => 'ນັກກັອບ: ສີຜິວໂທນຂາວປານກາງ',
    '🏌🏽' => 'ນັກກັອບ: ສີຜິວໂທນປານກາງ',
    '🏌🏾' => 'ນັກກັອບ: ສີຜິວໂທນດຳປານກາງ',
    '🏌🏿' => 'ນັກກັອບ: ສີຜິວໂທນດຳ',
    '🏄🏻' => 'ນັກຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນຂາວ',
    '🏄🏼' => 'ນັກຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນຂາວປານກາງ',
    '🏄🏽' => 'ນັກຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນປານກາງ',
    '🏄🏾' => 'ນັກຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນດຳປານກາງ',
    '🏄🏿' => 'ນັກຫຼິ້ນໂຕ້ຄື້ນ: ສີຜິວໂທນດຳ',
    '🚣🏻' => 'ເຮືອພາຍ: ສີຜິວໂທນຂາວ',
    '🚣🏼' => 'ເຮືອພາຍ: ສີຜິວໂທນຂາວປານກາງ',
    '🚣🏽' => 'ເຮືອພາຍ: ສີຜິວໂທນປານກາງ',
    '🚣🏾' => 'ເຮືອພາຍ: ສີຜິວໂທນດຳປານກາງ',
    '🚣🏿' => 'ເຮືອພາຍ: ສີຜິວໂທນດຳ',
    '🏊🏻' => 'ນັກລອຍນໍ້າ: ສີຜິວໂທນຂາວ',
    '🏊🏼' => 'ນັກລອຍນໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🏊🏽' => 'ນັກລອຍນໍ້າ: ສີຜິວໂທນປານກາງ',
    '🏊🏾' => 'ນັກລອຍນໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🏊🏿' => 'ນັກລອຍນໍ້າ: ສີຜິວໂທນດຳ',
    '⛹🏻' => 'ຄົນຫຼິ້ນບານ: ສີຜິວໂທນຂາວ',
    '⛹🏼' => 'ຄົນຫຼິ້ນບານ: ສີຜິວໂທນຂາວປານກາງ',
    '⛹🏽' => 'ຄົນຫຼິ້ນບານ: ສີຜິວໂທນປານກາງ',
    '⛹🏾' => 'ຄົນຫຼິ້ນບານ: ສີຜິວໂທນດຳປານກາງ',
    '⛹🏿' => 'ຄົນຫຼິ້ນບານ: ສີຜິວໂທນດຳ',
    '🏋🏻' => 'ຄົນຍົກນໍ້າໜັກ: ສີຜິວໂທນຂາວ',
    '🏋🏼' => 'ຄົນຍົກນໍ້າໜັກ: ສີຜິວໂທນຂາວປານກາງ',
    '🏋🏽' => 'ຄົນຍົກນໍ້າໜັກ: ສີຜິວໂທນປານກາງ',
    '🏋🏾' => 'ຄົນຍົກນໍ້າໜັກ: ສີຜິວໂທນດຳປານກາງ',
    '🏋🏿' => 'ຄົນຍົກນໍ້າໜັກ: ສີຜິວໂທນດຳ',
    '🚴🏻' => 'ຄົນຂີ່ລົດຖີບ: ສີຜິວໂທນຂາວ',
    '🚴🏼' => 'ຄົນຂີ່ລົດຖີບ: ສີຜິວໂທນຂາວປານກາງ',
    '🚴🏽' => 'ຄົນຂີ່ລົດຖີບ: ສີຜິວໂທນປານກາງ',
    '🚴🏾' => 'ຄົນຂີ່ລົດຖີບ: ສີຜິວໂທນດຳປານກາງ',
    '🚴🏿' => 'ຄົນຂີ່ລົດຖີບ: ສີຜິວໂທນດຳ',
    '🚵🏻' => 'ນັກຂີ່ລົດຖີບພູເຂົາ: ສີຜິວໂທນຂາວ',
    '🚵🏼' => 'ນັກຂີ່ລົດຖີບພູເຂົາ: ສີຜິວໂທນຂາວປານກາງ',
    '🚵🏽' => 'ນັກຂີ່ລົດຖີບພູເຂົາ: ສີຜິວໂທນປານກາງ',
    '🚵🏾' => 'ນັກຂີ່ລົດຖີບພູເຂົາ: ສີຜິວໂທນດຳປານກາງ',
    '🚵🏿' => 'ນັກຂີ່ລົດຖີບພູເຂົາ: ສີຜິວໂທນດຳ',
    '🤸🏻' => 'ຕີລັງກາ: ສີຜິວໂທນຂາວ',
    '🤸🏼' => 'ຕີລັງກາ: ສີຜິວໂທນຂາວປານກາງ',
    '🤸🏽' => 'ຕີລັງກາ: ສີຜິວໂທນປານກາງ',
    '🤸🏾' => 'ຕີລັງກາ: ສີຜິວໂທນດຳປານກາງ',
    '🤸🏿' => 'ຕີລັງກາ: ສີຜິວໂທນດຳ',
    '🤼🏻' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວ',
    '🤼🏼' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🤼🏽' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນປານກາງ',
    '🤼🏾' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🤼🏿' => 'ນັກມວຍປໍ້າ: ສີຜິວໂທນດຳ',
    '🤽🏻' => 'ໂປໂລນໍ້າ: ສີຜິວໂທນຂາວ',
    '🤽🏼' => 'ໂປໂລນໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🤽🏽' => 'ໂປໂລນໍ້າ: ສີຜິວໂທນປານກາງ',
    '🤽🏾' => 'ໂປໂລນໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🤽🏿' => 'ໂປໂລນໍ້າ: ສີຜິວໂທນດຳ',
    '🤾🏻' => 'ບານມື: ສີຜິວໂທນຂາວ',
    '🤾🏼' => 'ບານມື: ສີຜິວໂທນຂາວປານກາງ',
    '🤾🏽' => 'ບານມື: ສີຜິວໂທນປານກາງ',
    '🤾🏾' => 'ບານມື: ສີຜິວໂທນດຳປານກາງ',
    '🤾🏿' => 'ບານມື: ສີຜິວໂທນດຳ',
    '🤹🏻' => 'ຫຼິ້ນກົນ: ສີຜິວໂທນຂາວ',
    '🤹🏼' => 'ຫຼິ້ນກົນ: ສີຜິວໂທນຂາວປານກາງ',
    '🤹🏽' => 'ຫຼິ້ນກົນ: ສີຜິວໂທນປານກາງ',
    '🤹🏾' => 'ຫຼິ້ນກົນ: ສີຜິວໂທນດຳປານກາງ',
    '🤹🏿' => 'ຫຼິ້ນກົນ: ສີຜິວໂທນດຳ',
    '🧘🏻' => 'ຄົນນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນຂາວ',
    '🧘🏼' => 'ຄົນນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນຂາວປານກາງ',
    '🧘🏽' => 'ຄົນນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນປານກາງ',
    '🧘🏾' => 'ຄົນນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນດຳປານກາງ',
    '🧘🏿' => 'ຄົນນັ່ງທ່າຂັດສະມາທິ: ສີຜິວໂທນດຳ',
    '🛀🏻' => 'ຄົນອາບນໍ້າ: ສີຜິວໂທນຂາວ',
    '🛀🏼' => 'ຄົນອາບນໍ້າ: ສີຜິວໂທນຂາວປານກາງ',
    '🛀🏽' => 'ຄົນອາບນໍ້າ: ສີຜິວໂທນປານກາງ',
    '🛀🏾' => 'ຄົນອາບນໍ້າ: ສີຜິວໂທນດຳປານກາງ',
    '🛀🏿' => 'ຄົນອາບນໍ້າ: ສີຜິວໂທນດຳ',
    '🛌🏻' => 'ຄົນນອນເທິງຕຽງ: ສີຜິວໂທນຂາວ',
    '🛌🏼' => 'ຄົນນອນເທິງຕຽງ: ສີຜິວໂທນຂາວປານກາງ',
    '🛌🏽' => 'ຄົນນອນເທິງຕຽງ: ສີຜິວໂທນປານກາງ',
    '🛌🏾' => 'ຄົນນອນເທິງຕຽງ: ສີຜິວໂທນດຳປານກາງ',
    '🛌🏿' => 'ຄົນນອນເທິງຕຽງ: ສີຜິວໂທນດຳ',
    '👭🏻' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ',
    '👭🏼' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ',
    '👭🏽' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ',
    '👭🏾' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ',
    '👭🏿' => 'ແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ',
    '👫🏻' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວ',
    '👫🏼' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ',
    '👫🏽' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນປານກາງ',
    '👫🏾' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ',
    '👫🏿' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ: ສີຜິວໂທນດຳ',
    '👬🏻' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວ',
    '👬🏼' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນຂາວປານກາງ',
    '👬🏽' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນປານກາງ',
    '👬🏾' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳປານກາງ',
    '👬🏿' => 'ຜູ້ຊາຍຈັບມືກັນ: ສີຜິວໂທນດຳ',
    '💏🏻' => 'ຈູບ: ສີຜິວໂທນຂາວ',
    '💏🏼' => 'ຈູບ: ສີຜິວໂທນຂາວປານກາງ',
    '💏🏽' => 'ຈູບ: ສີຜິວໂທນປານກາງ',
    '💏🏾' => 'ຈູບ: ສີຜິວໂທນດຳປານກາງ',
    '💏🏿' => 'ຈູບ: ສີຜິວໂທນດຳ',
    '💑🏻' => 'ຄູ່ຮັກກັບຫົວໃຈ: ສີຜິວໂທນຂາວ',
    '💑🏼' => 'ຄູ່ຮັກກັບຫົວໃຈ: ສີຜິວໂທນຂາວປານກາງ',
    '💑🏽' => 'ຄູ່ຮັກກັບຫົວໃຈ: ສີຜິວໂທນປານກາງ',
    '💑🏾' => 'ຄູ່ຮັກກັບຫົວໃຈ: ສີຜິວໂທນດຳປານກາງ',
    '💑🏿' => 'ຄູ່ຮັກກັບຫົວໃຈ: ສີຜິວໂທນດຳ',
    '🇦🇨' => 'ທຸງ: ເກາະອາເຊນຊັນ',
    '🇦🇩' => 'ທຸງ: ອັນດໍຣາ',
    '🇦🇪' => 'ທຸງ: ສະຫະລັດອາຣັບເອມິເຣດ',
    '🇦🇫' => 'ທຸງ: ອາຟການິດສະຖານ',
    '🇦🇬' => 'ທຸງ: ແອນທິກົວ ແລະ ບາບູດາ',
    '🇦🇮' => 'ທຸງ: ແອນກຸຍລາ',
    '🇦🇱' => 'ທຸງ: ແອວເບເນຍ',
    '🇦🇲' => 'ທຸງ: ອາເມເນຍ',
    '🇦🇴' => 'ທຸງ: ແອງໂກລາ',
    '🇦🇶' => 'ທຸງ: ແອນຕາດຕິກາ',
    '🇦🇷' => 'ທຸງ: ອາເຈນທິນາ',
    '🇦🇸' => 'ທຸງ: ອາເມຣິກາ ຊາມົວ',
    '🇦🇹' => 'ທຸງ: ອອສເທຣຍ',
    '🇦🇺' => 'ທຸງ: ອອສເຕຣເລຍ',
    '🇦🇼' => 'ທຸງ: ອາຣູບາ',
    '🇦🇽' => 'ທຸງ: ຫມູ່ເກາະໂອລັນ',
    '🇦🇿' => 'ທຸງ: ອາເຊີໄບຈານ',
    '🇧🇦' => 'ທຸງ: ບອດສະເນຍ ແລະ ແຮສໂກວີນາ',
    '🇧🇧' => 'ທຸງ: ບາບາໂດສ',
    '🇧🇩' => 'ທຸງ: ບັງກະລາເທດ',
    '🇧🇪' => 'ທຸງ: ເບວຢຽມ',
    '🇧🇫' => 'ທຸງ: ເບີກິນາ ຟາໂຊ',
    '🇧🇬' => 'ທຸງ: ບັງກາເຣຍ',
    '🇧🇭' => 'ທຸງ: ບາເຣນ',
    '🇧🇮' => 'ທຸງ: ບູຣຸນດິ',
    '🇧🇯' => 'ທຸງ: ເບນິນ',
    '🇧🇱' => 'ທຸງ: ເຊນ ບາເທເລມີ',
    '🇧🇲' => 'ທຸງ: ເບີມິວດາ',
    '🇧🇳' => 'ທຸງ: ບຣູໄນ',
    '🇧🇴' => 'ທຸງ: ໂບລິເວຍ',
    '🇧🇶' => 'ທຸງ: ຄາຣິບບຽນ ເນເທີແລນ',
    '🇧🇷' => 'ທຸງ: ບຣາຊິວ',
    '🇧🇸' => 'ທຸງ: ບາຮາມາສ',
    '🇧🇹' => 'ທຸງ: ພູຖານ',
    '🇧🇻' => 'ທຸງ: ເກາະບູເວດ',
    '🇧🇼' => 'ທຸງ: ບອດສະວານາ',
    '🇧🇾' => 'ທຸງ: ເບລາຣຸສ',
    '🇧🇿' => 'ທຸງ: ເບລີຊ',
    '🇨🇦' => 'ທຸງ: ແຄນາດາ',
    '🇨🇨' => 'ທຸງ: ຫມູ່ເກາະໂກໂກສ',
    '🇨🇩' => 'ທຸງ: ຄອງໂກ - ຄິນຊາຊາ',
    '🇨🇫' => 'ທຸງ: ສາທາລະນະລັດອາຟຣິກາກາງ',
    '🇨🇬' => 'ທຸງ: ຄອງໂກ - ບຣາຊາວິວ',
    '🇨🇭' => 'ທຸງ: ສະວິດເຊີແລນ',
    '🇨🇮' => 'ທຸງ: ໂຄຕີ ວົວ',
    '🇨🇰' => 'ທຸງ: ໝູ່ເກາະຄຸກ',
    '🇨🇱' => 'ທຸງ: ຊິລີ',
    '🇨🇲' => 'ທຸງ: ຄາເມຣູນ',
    '🇨🇳' => 'ທຸງ: ຈີນ',
    '🇨🇴' => 'ທຸງ: ໂຄລົມເບຍ',
    '🇨🇵' => 'ທຸງ: ເກາະຄລິບເປີຕັນ',
    '🇨🇶' => 'ທຸງ: ຊາກຄ໌',
    '🇨🇷' => 'ທຸງ: ໂຄສຕາ ຣິກາ',
    '🇨🇺' => 'ທຸງ: ຄິວບາ',
    '🇨🇻' => 'ທຸງ: ເຄບ ເວີດ',
    '🇨🇼' => 'ທຸງ: ຄູຣາຊາວ',
    '🇨🇽' => 'ທຸງ: ເກາະຄຣິສມາດ',
    '🇨🇾' => 'ທຸງ: ໄຊປຣັສ',
    '🇨🇿' => 'ທຸງ: ເຊັກເຊຍ',
    '🇩🇪' => 'ທຸງ: ເຢຍລະມັນ',
    '🇩🇬' => 'ທຸງ: ດິເອໂກ ກາເຊຍ',
    '🇩🇯' => 'ທຸງ: ຈິບູຕິ',
    '🇩🇰' => 'ທຸງ: ເດນມາກ',
    '🇩🇲' => 'ທຸງ: ໂດມີນິຄາ',
    '🇩🇴' => 'ທຸງ: ສາທາລະນະລັດ ໂດມິນິກັນ',
    '🇩🇿' => 'ທຸງ: ອັລຈິເຣຍ',
    '🇪🇦' => 'ທຸງ: ເຊວຕາ & ເມລິນລາ',
    '🇪🇨' => 'ທຸງ: ເອກວາດໍ',
    '🇪🇪' => 'ທຸງ: ເອສໂຕເນຍ',
    '🇪🇬' => 'ທຸງ: ອີຢິບ',
    '🇪🇭' => 'ທຸງ: ຊາຮາຣາຕາເວັນຕົກ',
    '🇪🇷' => 'ທຸງ: ເອຣິເທຣຍ',
    '🇪🇸' => 'ທຸງ: ສະເປນ',
    '🇪🇹' => 'ທຸງ: ອີທິໂອເປຍ',
    '🇪🇺' => 'ທຸງ: ສະຫະພາບຢູໂຣບ',
    '🇫🇮' => 'ທຸງ: ຟິນແລນ',
    '🇫🇯' => 'ທຸງ: ຟິຈິ',
    '🇫🇰' => 'ທຸງ: ຫມູ່ເກາະຟອກແລນ',
    '🇫🇲' => 'ທຸງ: ໄມໂຄຣນີເຊຍ',
    '🇫🇴' => 'ທຸງ: ຫມູ່ເກາະແຟໂຣ',
    '🇫🇷' => 'ທຸງ: ຝຣັ່ງ',
    '🇬🇦' => 'ທຸງ: ກາບອນ',
    '🇬🇧' => 'ທຸງ: ສະຫະລາດຊະອະນາຈັກ',
    '🇬🇩' => 'ທຸງ: ເກຣເນດາ',
    '🇬🇪' => 'ທຸງ: ຈໍເຈຍ',
    '🇬🇫' => 'ທຸງ: ເຟຣນຊ໌ ກຸຍອານາ',
    '🇬🇬' => 'ທຸງ: ເກີນຊີ',
    '🇬🇭' => 'ທຸງ: ການາ',
    '🇬🇮' => 'ທຸງ: ຈິບບຣອນທາ',
    '🇬🇱' => 'ທຸງ: ກຣີນແລນ',
    '🇬🇲' => 'ທຸງ: ສາທາລະນະລັດແກມເບຍ',
    '🇬🇳' => 'ທຸງ: ກິນີ',
    '🇬🇵' => 'ທຸງ: ກົວດາລູບ',
    '🇬🇶' => 'ທຸງ: ເອຄົວໂທຣຽວ ກີນີ',
    '🇬🇷' => 'ທຸງ: ກຣີຊ',
    '🇬🇸' => 'ທຸງ: ໝູ່ເກາະ ຈໍເຈຍຕອນໃຕ້ ແລະ ແຊນວິດຕອນໃຕ້',
    '🇬🇹' => 'ທຸງ: ກົວເທມາລາ',
    '🇬🇺' => 'ທຸງ: ກວາມ',
    '🇬🇼' => 'ທຸງ: ກິນີ-ບິສເຊົາ',
    '🇬🇾' => 'ທຸງ: ກາຍຢານາ',
    '🇭🇰' => 'ທຸງ: ຮົງກົງ ເຂດປົກຄອງພິເສດ ຈີນ',
    '🇭🇲' => 'ທຸງ: ໝູ່ເກາະເຮີດ & ແມັກໂດນອລ',
    '🇭🇳' => 'ທຸງ: ຮອນດູຣັສ',
    '🇭🇷' => 'ທຸງ: ໂຄຣເອເທຍ',
    '🇭🇹' => 'ທຸງ: ໄຮຕິ',
    '🇭🇺' => 'ທຸງ: ຮັງກາຣີ',
    '🇮🇨' => 'ທຸງ: ໝູ່ເກາະຄານາຣີ',
    '🇮🇩' => 'ທຸງ: ອິນໂດເນເຊຍ',
    '🇮🇪' => 'ທຸງ: ໄອແລນ',
    '🇮🇱' => 'ທຸງ: ອິສຣາເອວ',
    '🇮🇲' => 'ທຸງ: ເອວ ອອບ ແມນ',
    '🇮🇳' => 'ທຸງ: ອິນເດຍ',
    '🇮🇴' => 'ທຸງ: ເຂດແດນອັງກິດໃນມະຫາສະໝຸດອິນເດຍ',
    '🇮🇶' => 'ທຸງ: ອີຣັກ',
    '🇮🇷' => 'ທຸງ: ອີຣານ',
    '🇮🇸' => 'ທຸງ: ໄອສແລນ',
    '🇮🇹' => 'ທຸງ: ອິຕາລີ',
    '🇯🇪' => 'ທຸງ: ເຈີຊີ',
    '🇯🇲' => 'ທຸງ: ຈາໄມຄາ',
    '🇯🇴' => 'ທຸງ: ຈໍແດນ',
    '🇯🇵' => 'ທຸງ: ຍີ່ປຸ່ນ',
    '🇰🇪' => 'ທຸງ: ເຄນຢາ',
    '🇰🇬' => 'ທຸງ: ຄຽກກິດສະຖານ',
    '🇰🇭' => 'ທຸງ: ກຳປູເຈຍ',
    '🇰🇮' => 'ທຸງ: ຄິຣິບາທິ',
    '🇰🇲' => 'ທຸງ: ໂຄໂມໂຣສ',
    '🇰🇳' => 'ທຸງ: ເຊນ ຄິດ ແລະ ເນວິສ',
    '🇰🇵' => 'ທຸງ: ເກົາຫລີເໜືອ',
    '🇰🇷' => 'ທຸງ: ເກົາຫລີໃຕ້',
    '🇰🇼' => 'ທຸງ: ກູເວດ',
    '🇰🇾' => 'ທຸງ: ໝູ່ເກາະ ເຄແມນ',
    '🇰🇿' => 'ທຸງ: ຄາຊັກສະຖານ',
    '🇱🇦' => 'ທຸງ: ລາວ',
    '🇱🇧' => 'ທຸງ: ເລບານອນ',
    '🇱🇨' => 'ທຸງ: ເຊນ ລູເຊຍ',
    '🇱🇮' => 'ທຸງ: ລິດເທນສະຕາຍ',
    '🇱🇰' => 'ທຸງ: ສີລັງກາ',
    '🇱🇷' => 'ທຸງ: ລິເບີເຣຍ',
    '🇱🇸' => 'ທຸງ: ເລໂຊໂທ',
    '🇱🇹' => 'ທຸງ: ລິທົວເນຍ',
    '🇱🇺' => 'ທຸງ: ລຸກແຊມເບີກ',
    '🇱🇻' => 'ທຸງ: ລັດເວຍ',
    '🇱🇾' => 'ທຸງ: ລິເບຍ',
    '🇲🇦' => 'ທຸງ: ໂມຣັອກໂຄ',
    '🇲🇨' => 'ທຸງ: ໂມນາໂຄ',
    '🇲🇩' => 'ທຸງ: ໂມນໂດວາ',
    '🇲🇪' => 'ທຸງ: ມອນເຕເນໂກຣ',
    '🇲🇫' => 'ທຸງ: ເຊນ ມາທິນ',
    '🇲🇬' => 'ທຸງ: ມາດາກາສະກາ',
    '🇲🇭' => 'ທຸງ: ຫມູ່ເກາະມາແຊວ',
    '🇲🇰' => 'ທຸງ: ແມຊິໂດເນຍເໜືອ',
    '🇲🇱' => 'ທຸງ: ມາລີ',
    '🇲🇲' => 'ທຸງ: ມຽນມາ (ເບີມາ)',
    '🇲🇳' => 'ທຸງ: ມອງໂກເລຍ',
    '🇲🇴' => 'ທຸງ: ມາກາວ ເຂດປົກຄອງພິເສດ ຈີນ',
    '🇲🇵' => 'ທຸງ: ໝູ່ເກາະມາເຣຍນາຕອນເໜືອ',
    '🇲🇶' => 'ທຸງ: ມາຕິນີກ',
    '🇲🇷' => 'ທຸງ: ມົວຣິເທເນຍ',
    '🇲🇸' => 'ທຸງ: ມອນເຊີຣາດ',
    '🇲🇹' => 'ທຸງ: ມອນທາ',
    '🇲🇺' => 'ທຸງ: ມົວຣິຊຽສ',
    '🇲🇻' => 'ທຸງ: ມັນດິຟ',
    '🇲🇼' => 'ທຸງ: ມາລາວີ',
    '🇲🇽' => 'ທຸງ: ເມັກຊິໂກ',
    '🇲🇾' => 'ທຸງ: ມາເລເຊຍ',
    '🇲🇿' => 'ທຸງ: ໂມແຊມບິກ',
    '🇳🇦' => 'ທຸງ: ນາມີເບຍ',
    '🇳🇨' => 'ທຸງ: ນິວ ຄາເລໂດເນຍ',
    '🇳🇪' => 'ທຸງ: ນິເຈີ',
    '🇳🇫' => 'ທຸງ: ເກາະນໍໂຟກ',
    '🇳🇬' => 'ທຸງ: ໄນຈີເຣຍ',
    '🇳🇮' => 'ທຸງ: ນິກຄາຣາກົວ',
    '🇳🇱' => 'ທຸງ: ເນເທີແລນ',
    '🇳🇴' => 'ທຸງ: ນໍເວ',
    '🇳🇵' => 'ທຸງ: ເນປານ',
    '🇳🇷' => 'ທຸງ: ນາອູຣູ',
    '🇳🇺' => 'ທຸງ: ນີອູເອ',
    '🇳🇿' => 'ທຸງ: ນິວຊີແລນ',
    '🇴🇲' => 'ທຸງ: ໂອມານ',
    '🇵🇦' => 'ທຸງ: ພານາມາ',
    '🇵🇪' => 'ທຸງ: ເປຣູ',
    '🇵🇫' => 'ທຸງ: ເຟຣນຊ໌ ໂພລິນີເຊຍ',
    '🇵🇬' => 'ທຸງ: ປາປົວນິວກີນີ',
    '🇵🇭' => 'ທຸງ: ຟິລິບປິນ',
    '🇵🇰' => 'ທຸງ: ປາກິດສະຖານ',
    '🇵🇱' => 'ທຸງ: ໂປແລນ',
    '🇵🇲' => 'ທຸງ: ເຊນ ປີແອ ມິເກວລອນ',
    '🇵🇳' => 'ທຸງ: ໝູ່ເກາະພິດແຄນ',
    '🇵🇷' => 'ທຸງ: ເພືອໂຕ ຣິໂກ',
    '🇵🇸' => 'ທຸງ: ດິນແດນປາເລດສະຕິນ',
    '🇵🇹' => 'ທຸງ: ພອລທູໂກ',
    '🇵🇼' => 'ທຸງ: ປາລາວ',
    '🇵🇾' => 'ທຸງ: ພາຣາກວຍ',
    '🇶🇦' => 'ທຸງ: ກາຕາ',
    '🇷🇪' => 'ທຸງ: ເຣອູນິຍົງ',
    '🇷🇴' => 'ທຸງ: ໂຣແມເນຍ',
    '🇷🇸' => 'ທຸງ: ເຊີເບຍ',
    '🇷🇺' => 'ທຸງ: ຣັດເຊຍ',
    '🇷🇼' => 'ທຸງ: ຣວັນດາ',
    '🇸🇦' => 'ທຸງ: ຊາອຸດິ ອາຣາເບຍ',
    '🇸🇧' => 'ທຸງ: ຫມູ່ເກາະໂຊໂລມອນ',
    '🇸🇨' => 'ທຸງ: ເຊເຊວເລສ',
    '🇸🇩' => 'ທຸງ: ຊູດານ',
    '🇸🇪' => 'ທຸງ: ສະວີເດັນ',
    '🇸🇬' => 'ທຸງ: ສິງກະໂປ',
    '🇸🇭' => 'ທຸງ: ເຊນ ເຮເລນາ',
    '🇸🇮' => 'ທຸງ: ສະໂລເວເນຍ',
    '🇸🇯' => 'ທຸງ: ສະວາບາ ແລະ ແຢນ ມາເຢນ',
    '🇸🇰' => 'ທຸງ: ສະໂລວາເກຍ',
    '🇸🇱' => 'ທຸງ: ເຊຍຣາ ລີໂອນ',
    '🇸🇲' => 'ທຸງ: ແຊນ ມາຣິໂນ',
    '🇸🇳' => 'ທຸງ: ເຊນີໂກລ',
    '🇸🇴' => 'ທຸງ: ໂຊມາເລຍ',
    '🇸🇷' => 'ທຸງ: ຊູຣິນາມ',
    '🇸🇸' => 'ທຸງ: ຊູດານໃຕ້',
    '🇸🇹' => 'ທຸງ: ເຊົາທູເມ ແລະ ພຣິນຊິບ',
    '🇸🇻' => 'ທຸງ: ເອວ ຊໍວາດໍ',
    '🇸🇽' => 'ທຸງ: ຊິນ ມາເທັນ',
    '🇸🇾' => 'ທຸງ: ຊີເຣຍ',
    '🇸🇿' => 'ທຸງ: ​ເອ​ສະ​ວາ​ຕິ​ນີ',
    '🇹🇦' => 'ທຸງ: ທຣິສຕັນ ດາ ກັນຮາ',
    '🇹🇨' => 'ທຸງ: ໝູ່ເກາະ ເທີກ ແລະ ໄຄໂຄສ',
    '🇹🇩' => 'ທຸງ: ຊາດ',
    '🇹🇫' => 'ທຸງ: ເຂດແດນທາງໃຕ້ຂອງຝຮັ່ງ',
    '🇹🇬' => 'ທຸງ: ໂຕໂກ',
    '🇹🇭' => 'ທຸງ: ໄທ',
    '🇹🇯' => 'ທຸງ: ທາຈິກິດສະຖານ',
    '🇹🇰' => 'ທຸງ: ໂຕເກເລົາ',
    '🇹🇱' => 'ທຸງ: ທິມໍ-ເລສເຕ',
    '🇹🇲' => 'ທຸງ: ເທີກເມນິສະຖານ',
    '🇹🇳' => 'ທຸງ: ຕູນິເຊຍ',
    '🇹🇴' => 'ທຸງ: ທອງກາ',
    '🇹🇷' => 'ທຸງ: ເທີຄີ',
    '🇹🇹' => 'ທຸງ: ທຣິນິແດດ ແລະ ໂທແບໂກ',
    '🇹🇻' => 'ທຸງ: ຕູວາລູ',
    '🇹🇼' => 'ທຸງ: ໄຕ້ຫວັນ',
    '🇹🇿' => 'ທຸງ: ທານຊາເນຍ',
    '🇺🇦' => 'ທຸງ: ຢູເຄຣນ',
    '🇺🇬' => 'ທຸງ: ອູການດາ',
    '🇺🇲' => 'ທຸງ: ໝູ່ເກາະຮອບນອກຂອງສະຫະລັດຯ',
    '🇺🇳' => 'ທຸງ: ສະຫະປະຊາຊາດ',
    '🇺🇸' => 'ທຸງ: ສະຫະລັດ',
    '🇺🇾' => 'ທຸງ: ອູຣຸກວຍ',
    '🇺🇿' => 'ທຸງ: ອຸສເບກິສະຖານ',
    '🇻🇦' => 'ທຸງ: ນະຄອນ ວາຕິກັນ',
    '🇻🇨' => 'ທຸງ: ເຊນ ວິນເຊນ ແລະ ເກຣເນດິນ',
    '🇻🇪' => 'ທຸງ: ເວເນຊູເອລາ',
    '🇻🇬' => 'ທຸງ: ໝູ່ເກາະ ເວີຈິນຂອງອັງກິດ',
    '🇻🇮' => 'ທຸງ: ໝູ່ເກາະ ເວີຈິນ ຂອງສະຫະລັດ',
    '🇻🇳' => 'ທຸງ: ຫວຽດນາມ',
    '🇻🇺' => 'ທຸງ: ວານົວຕູ',
    '🇼🇫' => 'ທຸງ: ວາລລິສ ແລະ ຟູຕູນາ',
    '🇼🇸' => 'ທຸງ: ຊາມົວ',
    '🇽🇰' => 'ທຸງ: ໂຄໂຊໂວ',
    '🇾🇪' => 'ທຸງ: ເຢເມນ',
    '🇾🇹' => 'ທຸງ: ມາຢັອດ',
    '🇿🇦' => 'ທຸງ: ອາຟຣິກາໃຕ້',
    '🇿🇲' => 'ທຸງ: ແຊມເບຍ',
    '🇿🇼' => 'ທຸງ: ຊິມບັບເວ',
    '🔟' => 'ແປ້ນແຄັບ: 10',
    '🏻' => 'ສີຜິວໂທນຂາວ',
    '🏼' => 'ສີຜິວໂທນຂາວປານກາງ',
    '🏽' => 'ສີຜິວໂທນປານກາງ',
    '🏾' => 'ສີຜິວໂທນດຳປານກາງ',
    '🏿' => 'ສີຜິວໂທນດຳ',
    '😀' => 'ໜ້າຍິ້ມຍິ່ງແຂ້ວ',
    '😃' => 'ໜ້າຍິ້ມອ້າປາກ',
    '😄' => 'ໜ້າຍິ້ມຕາຍິ້ມ ແລະອ້າປາກ',
    '😁' => 'ໜ້າຍິ້ມຍິ່ງແຂ້ວຕາຍິ້ມ',
    '😆' => 'ໜ້າຍິ້ມອ້າປາກ ແລະຫຼັບຕາ',
    '😅' => 'ໜ້າຍິ້ມອ້າປາກ ແລະເຫື່ອຕົກ',
    '🤣' => 'ຫົວຈົນນອນກິ້ງຢູ່ພື້ນ',
    '😂' => 'ຮ້ອງໄຫ້ດີໃຈ',
    '🙂' => 'ໜ້າຍິ້ມບາງໆ',
    '🙃' => 'ໜ້າປີ້ນຫົວ',
    '🫠' => 'ໜ້າລະລາຍ',
    '😉' => 'ໜ້າຍິບຕາ',
    '😊' => 'ໜ້າຍິ້ມຕາຍິ້ມ',
    '😇' => 'ຍິ້ມເທວະດາ',
    '🥰' => 'ໃບໜ້າຍີ້ມແຍ້ມພ້ອມຫົວໃຈ 3 ດວງ',
    '😍' => 'ໜ້າຍິ້ມທີ່ມີຕາຮູບຫົວໃຈ',
    '🤩' => 'ຕະລຶງງັນ',
    '😘' => 'ໜ້າສົ່ງຈູບ',
    '😗' => 'ໜ້າກຳລັງຈູບ',
    '☺' => 'ໜ້າຍິ້ມ',
    '😚' => 'ຫຼັບຕາສົ່ງຈູບ',
    '😙' => 'ໜ້າຍິ້ມສົ່ງຈູບ',
    '🥲' => 'ໜ້າຍິ້ມດ້ວຍນຳ້ຕາ',
    '😋' => 'ນໍ້າລາຍໄຫຼ',
    '😛' => 'ໜ້າແລບລິ້ນ',
    '😜' => 'ໜ້າແລບລິ້ນ ແລະຍິບຕາ',
    '🤪' => 'ໜ້າຜີບ້າ',
    '😝' => 'ໜ້າແລບລິ້ນ ແລະຫຼັບຕາ',
    '🤑' => 'ໜ້າຄາບເງິນໃນປາກ',
    '🤗' => 'ຍິ້ມກອດ',
    '🤭' => 'ໜ້າເອົາມືປ້ອງປາກ',
    '🫢' => 'ໜ້າມືນຕາ ແລະ ເອົາມືປິດປາກ',
    '🫣' => 'ໜ້າທີ່ກໍາລັງລັກເບິ່ງ',
    '🤫' => 'ໜ້າງຽບ',
    '🤔' => 'ໜ້າກຳລັງຄິດ',
    '🫡' => 'ໜ້າຄໍານັບ',
    '🤐' => 'ໜ້າຮູດຊິບປາກ',
    '🤨' => 'ໜ້າພ້ອມຕາເບິ່ງຂຶ້ນເທິງ',
    '😐' => 'ໜ້າເສີຍໆ',
    '😑' => 'ໜ້າເຢັນຊາ',
    '😶' => 'ໜ້າບໍ່ມີປາກ',
    '🫥' => 'ໜ້າເສັ້ນຈຸດ',
    '😏' => 'ໜ້າຍິ້ມເຍາະເຍີ້ຍ',
    '😒' => 'ໜ້າບໍ່ມ່ວນຊື່ນ',
    '🙄' => 'ໜ້າທີ່ມີຕາລັອກແລັກ',
    '😬' => 'ໜ້າບູດບ້ຽວ',
    '🤥' => 'ໜ້າຂີ້ຕົວ',
    '🫨' => 'ແກວ່ງຫົວ',
    '😌' => 'ໜ້າຜ່ອນຄາຍ',
    '😔' => 'ໜ້າຄິດບໍ່ອອກ',
    '😪' => 'ໜ້າເງົານອນ',
    '🤤' => 'ໜ້ານໍ້າລາຍໄຫຼ',
    '😴' => 'ໜ້ານອນຫຼັບ',
    '🫩' => 'ໜ້າຕາບວມ',
    '😷' => 'ໜ້າໃສ່ຜ້າອັດປາກ',
    '🤒' => 'ໜ້າອົມບາຫຼອດ',
    '🤕' => 'ໜ້າມີຜ້າພັນຫົວ',
    '🤢' => 'ໜ້າພະອືດພະອົມ',
    '🤮' => 'ໜ້າອາຈຽນ',
    '🤧' => 'ໜ້າກຳລັງຈາມ',
    '🥵' => 'ໃບໜ້າຮ້ອນໃໝ້',
    '🥶' => 'ໃບໜ້າຊຸ່ມເຢັນ',
    '🥴' => 'ໜ້າວິນວຽນ',
    '😵' => 'ໜ້າວິນຫົວ',
    '🤯' => 'ຫົວລະເບີດ',
    '🤠' => 'ໜ້າໃສ່ໝວກຄາວບອຍ',
    '🥳' => 'ໃບໜ້າໃນງານປາຕີ',
    '🥸' => 'ໜ້າປອມໂຕ',
    '😎' => 'ໜ້າຍິ້ມໃສ່ແວ່ນຕາກັນແດດ',
    '🤓' => 'ໜ້າຄົນໂງ່',
    '🧐' => 'ໜ້າໃສ່ແວ່ນຂ້າງດຽວ',
    '😕' => 'ໜ້າສັບສົນ',
    '🫤' => 'ໜ້າທີ່ມີປາກອ່ຽງ',
    '😟' => 'ໜ້າກັງວົນ',
    '🙁' => 'ໜ້າຫຍຸ້ງເລັກນ້ອຍ',
    '☹' => 'ໜ້າຫຍຸ້ງ',
    '😮' => 'ໜ້າອ້າປາກ',
    '😯' => 'ໜ້າມິດ',
    '😲' => 'ໜ້າຕື່ນຕົກໃຈ',
    '😳' => 'ໜ້າແດງ',
    '🫪' => 'ໜ້າບ້ຽວ',
    '🥺' => 'ໃບໜ້າອ້ອນວອນ',
    '🥹' => 'ໜ້າກັ້ນນໍ້າຕາ',
    '😦' => 'ໜ້າຫຍຸ້ງອ້າປາກ',
    '😧' => 'ໜ້າເຈັບປວດ',
    '😨' => 'ໜ້າຢ້ານກົວ',
    '😰' => 'ໜ້າກັງວົນເຫື່ອຕົກ',
    '😥' => 'ໜ້າຜິດຫວັງແຕ່ຜ່ອນຄາຍ',
    '😢' => 'ໜ້າຮ້ອງໄຫ້',
    '😭' => 'ໜ້າຮ້ອງໄຫ້ສຽງດັງ',
    '😱' => 'ໜ້າກີດຮ້ອງຢ້ານກົວ',
    '😖' => 'ໜ້າງົງ',
    '😣' => 'ໜ້າອົດທົນ',
    '😞' => 'ໜ້າຜິດຫວັງ',
    '😓' => 'ໜ້າມີເຫື່ອເຢັນ',
    '😩' => 'ໜ້າເບື່ອໜ່າຍ',
    '😫' => 'ໜ້າອິດເມື່ອຍ',
    '🥱' => 'ໜ້າ​ຫາວນ​ອນ',
    '😤' => 'ໜ້າມີຄວັນອອກດັງ',
    '😡' => 'ໜ້າບໍ່ພໍໃຈ',
    '😠' => 'ໜ້າໃຈຮ້າຍ',
    '🤬' => 'ຜູ້ຊາຍມີສັນຍາລັກຢູ່ປາກ',
    '😈' => 'ໜ້າຍິ້ມມີເຂົາ',
    '👿' => 'ຜີເຜດນ້ອຍ',
    '💀' => 'ກະໂຫຼກຫົວ',
    '☠' => 'ກະໂຫຼກຫົວ ແລະກະດູກກາກະບາດ',
    '💩' => 'ກອງອາຈົມ',
    '🤡' => 'ໜ້າຕົວຕະຫລົກ',
    '👹' => 'ຍັກກິນຄົນ',
    '👺' => 'ຜີນ້ອຍ',
    '👻' => 'ຜີ',
    '👽' => 'ມະນຸດຕ່າງດາວ',
    '👾' => 'ປີສາດຕ່າງດາວ',
    '🤖' => 'ຫຸ່ນຍົນ',
    '😺' => 'ແມວຍິ້ມອ້າປາກ',
    '😸' => 'ແມວຍິ້ມຍິ່ງແຂ້ວຕາຍິ້ມ',
    '😹' => 'ແມວຮ້ອງໄຫ້ດີໃຈ',
    '😻' => 'ແມວຍິ້ມທີ່ມີຕາຮູບຫົວໃຈ',
    '😼' => 'ແມວຍິ້ມບິດບ້ຽວ',
    '😽' => 'ແມວສົ່ງຈູບ',
    '🙀' => 'ແມວຕົກໃຈ',
    '😿' => 'ແມວຮ້ອງໄຫ້',
    '😾' => 'ແມວໃຈຮ້າຍ',
    '🙈' => 'ລີງປິດຕາ',
    '🙉' => 'ລິງປິດຫູ',
    '🙊' => 'ລີງປິດປາກ',
    '💌' => 'ຈົດໝາຍຮັກ',
    '💘' => 'ຫົວໃຈມີລູກສອນປັກ',
    '💝' => 'ຫົວໃຈຜູກໂບ',
    '💖' => 'ຫົວໃຈເປັ່ງປະກາຍ',
    '💗' => 'ຫົວໃຈກຳລັງເຕີບໂຕ',
    '💓' => 'ຫົວໃຈກຳລັງເຕັ້ນ',
    '💞' => 'ຫົວໃຈກຳລັງໝູນຮອບ',
    '💕' => 'ຫົວໃຈສອງອັນ',
    '💟' => 'ການຕົບແຕ່ງຫົວໃຈ',
    '❣' => 'ເຄື່ອງໝາຍທ້ວງເປັນຮູບຫົວໃຈໃຫຍ່',
    '💔' => 'ຫົວໃຈແຕກ',
    '❤' => 'ຫົວໃຈສີແດງ',
    '🩷' => 'ຫົວໃຈສີບົວ',
    '🧡' => 'ຫົວໃຈໝາກກ້ຽງ',
    '💛' => 'ຫົວໃຈສີເຫຼືອງ',
    '💚' => 'ຫົວໃຈສີຂຽວ',
    '💙' => 'ຫົວໃຈສີຟ້າ',
    '🩵' => 'ຫົວໃຈສີຟ້າອ່ອນ',
    '💜' => 'ຫົວໃຈສີມ່ວງ',
    '🤎' => 'ຫົວ​ໃຈ​ນ້ຳ​ຕານ',
    '🖤' => 'ຫົວໃຈສີດຳ',
    '🩶' => 'ຫົວໃຈສີເທົາ',
    '🤍' => 'ຫົວ​ໃຈ​ຂາວ',
    '💋' => 'ຮອຍຈູບ',
    '💯' => 'ຄະແນນຮ້ອຍ',
    '💢' => 'ສັນຍາລັກໃຈຮ້າຍ',
    '🫯' => 'ຕີກັນ',
    '💥' => 'ການຕຳ',
    '💫' => 'ວຽນຫົວ',
    '💦' => 'ຢອດເຫື່ອ',
    '💨' => 'ເຄື່ອນທີ່ໄວ',
    '🕳' => 'ຮູ',
    '💬' => 'ປູມເປົ້າຄຳເວົ້າ',
    '🗨' => 'ລູກໂປ່ງຄຳເວົ້າຊ້າຍ',
    '🗯' => 'ລູກໂປ່ງໃຈຮ້າຍຂວາ',
    '💭' => 'ປູມເປົ້າຄວາມຄິດ',
    '💤' => 'zzz',
    '👋' => 'ໂບກມື',
    '🤚' => 'ຍົກຫຼັງມືຂຶ້ນ',
    '🖐' => 'ຍົກມືຂຶ້ນໂດຍທີ່ນີ້ວມືຈ່າງອອກ',
    '✋' => 'ຍົກມືຂຶ້ນ',
    '🖖' => 'ຊູນິ້ວແບບວັນແຄນ',
    '🫱' => 'ມືຊີ້ໄປທາງຂວາ',
    '🫲' => 'ມືຊີ້ໄປທາງຊ້າຍ',
    '🫳' => 'ຝາມືລົງ',
    '🫴' => 'ແບຝາມື',
    '🫷' => 'ປັດມືໄປທາງຊ້າຍ',
    '🫸' => 'ປັດມືໄປທາງຂວາ',
    '👌' => 'ຍົກມືຕົກລົງ',
    '🤌' => 'ຈຸ້ມ​ນິ້ວ​ມື',
    '🤏' => 'ຢິບ​ມື',
    '✌' => 'ຊູສອງນິ້ວ',
    '🤞' => 'ນິ້ວໄຂວ່ກັນ',
    '🫰' => 'ມືນິ້ວຊີ້ ແລະ ນິ້ວໂປ້ໄຂວ່ກັນ',
    '🤟' => 'ທ່າເລີບຢູ',
    '🤘' => 'ຊູນີ້ວແບບສັນຍາລັກເຂົາ',
    '🤙' => 'ເຮັດມືໂທຫາຂ້ອຍ',
    '👈' => 'ນິ້ວຊີ້ໄປຊ້າຍ',
    '👉' => 'ນິ້ວຊີ້ໄປຂວາ',
    '👆' => 'ຫຼັງມືນີ້ວຊີ້ຂຶ້ນ',
    '🖕' => 'ນີ້ວກາງ',
    '👇' => 'ຫຼັງມືນີ້ວຊີ້ລົງ',
    '☝' => 'ຝ່າມືນີ້ວຊີ້ຂຶ້ນ',
    '🫵' => 'ນີ້ວຊີ້ຊີ້ຜູ້ຊົມ',
    '👍' => 'ໂປ້ມືຂຶ້ນ',
    '👎' => 'ໂປ້ມືລົງ',
    '✊' => 'ຊູກຳປັ້ນ',
    '👊' => 'ກຳປັ້ນທີ່ຊັດເຂົ້າມາ',
    '🤛' => 'ກໍາປັ້ນໄປທາງຊ້າຍ',
    '🤜' => 'ກໍາປັ້ນໄປທາງຂວາ',
    '👏' => 'ຕົບມື',
    '🙌' => 'ຄົນຍົກມືຂຶ້ນ',
    '🫶' => 'ມືຮູບຊົງຫົວໃຈ',
    '👐' => 'ແບມືອອກສອງຂ້າງ',
    '🤲' => 'ຍົກຝ່າມືຂຶ້ນພ້ອມກັນ',
    '🤝' => 'ຈັບມື',
    '🙏' => 'ພະນົມມື',
    '✍' => 'ມືກຳລັງຂຽນ',
    '💅' => 'ທາເລັບມື',
    '🤳' => 'ເຊວຟີ',
    '💪' => 'ເບ່ງກ້າມ',
    '🦾' => 'ແຂນ​ທຽມ',
    '🦿' => 'ຂາ​ທຽມ',
    '🦵' => 'ຂາ',
    '🦶' => 'ຕີນ',
    '👂' => 'ຫູ',
    '🦻' => 'ຫູ​​ມີເຄື່​ອງ​ຊ່ວຍ​ຟັງ',
    '👃' => 'ດັງ',
    '🧠' => 'ສະໝອງ',
    '🫀' => 'ອະໄວຍະວະຫົວໃຈ',
    '🫁' => 'ປອດ',
    '🦷' => 'ແຂ້ວ',
    '🦴' => 'ກະດູກ',
    '👀' => 'ຕາສອງເບື້ອງ',
    '👁' => 'ຕາເບື້ອງໜຶ່ງ',
    '👅' => 'ລີ້ນ',
    '👄' => 'ປາກ',
    '🫦' => 'ກັດສົບ',
    '👶' => 'ແອນ້ອຍ',
    '🧒' => 'ເດັກ',
    '👦' => 'ເດັກຊາຍ',
    '👧' => 'ເດັກຍິງ',
    '🧑' => 'ຜູ້ໃຫຍ່',
    '👱' => 'ຄົນຜົມສີເຫຼືອງອ່ອນ',
    '👨' => 'ຜູ້ຊາຍ',
    '🧔' => 'ຄົນມີໜວດ',
    '👩' => 'ແມ່ຍິງ',
    '🧓' => 'ຜູ້ໃຫຍ່ທີ່ມີອາຍຸ',
    '👴' => 'ຜູ້ຊາຍເຖົ້າ',
    '👵' => 'ແມ່ຍິງເຖົ້າ',
    '🙍' => 'ຄົນເຮັດໜ້າຫຍຸ້ງ',
    '🙎' => 'ຄົນເຮັດໜ້າບໍ່ພໍໃຈ',
    '🙅' => 'ທ່າທາງ ບໍ່',
    '🙆' => 'ທ່າທາງ ຕົກລົງ',
    '💁' => 'ໂຕະສອບຖາມຂໍ້ມູນ',
    '🙋' => 'ຄົນດີໃຈຍົກມືຂຶ້ນ',
    '🧏' => 'ຄົນ​ຫູ​ໜວກ',
    '🙇' => 'ຄົນກົ້ມຂໍໂທດ',
    '🤦' => 'ມືກ່າຍໜ້າ',
    '🤷' => 'ຍັກໄຫລ່',
    '👮' => 'ເຈົ້າໜ້າທີ່ຕຳຫຼວດ',
    '🕵' => 'ນັກສືບ',
    '💂' => 'ຄົນເຝົ້າຢາມ',
    '🥷' => 'ນິນຈາ',
    '👷' => 'ຄົນງານກໍ່ສ້າງ',
    '🫅' => 'ຄົນໃສ່ມົງກຸດ',
    '🤴' => 'ເຈົ້າຊາຍ',
    '👸' => 'ເຈົ້າຍິງ',
    '👳' => 'ຜູ້ຊາຍໃສ່ຜ້າພັນຫົວ',
    '👲' => 'ຜູ້ຊາຍໃສ່ໝວກແກັບຈີນ',
    '🧕' => 'ຜູ້ຍິງໃສ່ຜ້າຄຸມຫົວ',
    '🤵' => 'ຄົນໃສ່ຊຸດທັກຊິໂດ',
    '👰' => 'ເຈົ້າສາວໃສ່ຜ້າຄຸມໜ້າ',
    '🤰' => 'ຜູ້ຍິງຖືພາ',
    '🫃' => 'ຜູ້ຊາຍຖືພາ',
    '🫄' => 'ຄົນຖືພາ',
    '🤱' => 'ປ້ອນນົມ',
    '👼' => 'ນາງຟ້າເດັກ',
    '🎅' => 'ຊານຕາຄລັອສ',
    '🤶' => 'ແມ່ຄຣິສມາສ',
    '🦸' => 'ສຸດຍອດພະເອກ',
    '🦹' => 'ຈອມວາຍລ້າຍ',
    '🧙' => 'ຜູ້ວິເສດ',
    '🧚' => 'ນາງຟ້າ',
    '🧛' => 'ແວມພາຍ',
    '🧜' => 'ເງືອກຜູ້ຊາຍ',
    '🧝' => 'ເອວຟ໌',
    '🧞' => 'ຈິນີ່',
    '🧟' => 'ຊອມບີ້',
    '🧌' => 'ຄົນເຕ້ຍ',
    '🫈' => 'ໂຕມີຂົນ',
    '💆' => 'ນວດໜ້າ',
    '💇' => 'ຕັດຜົມ',
    '🚶' => 'ຄົນຍ່າງ',
    '🧍' => 'ຄົນ​ຢືນ',
    '🧎' => '​ຄົນ​ຄຸ​ເຂົ່າ',
    '🏃' => 'ຄົນແລ່ນ',
    '💃' => 'ຜູ້ຍິງກຳລັງເຕັ້ນລຳ',
    '🕺' => 'ຜູ້ຊາຍເຕັ້ນ',
    '🕴' => 'ຜູ້ຊາຍໃສ່ຊຸດທຸລະກິດລອຍໃນອາກາດ',
    '👯' => 'ແມ່ຍິງໃນຊຸດຫູກະຕ່າຍ',
    '🧖' => 'ຄົນໃນຫ້ອງອົບໄອນ້ຳ',
    '🧗' => 'ຄົນກຳລັງປີນ',
    '🤺' => 'ນັກດາບ',
    '🏇' => 'ການແຂ່ງມ້າ',
    '⛷' => 'ນັກຫຼິ້ນສະກີ',
    '🏂' => 'ນັກຫຼິ້ນສະໂນບອດ',
    '🏌' => 'ນັກກັອບ',
    '🏄' => 'ນັກຫຼິ້ນໂຕ້ຄື້ນ',
    '🚣' => 'ເຮືອພາຍ',
    '🏊' => 'ນັກລອຍນໍ້າ',
    '⛹' => 'ຄົນຫຼິ້ນບານ',
    '🏋' => 'ຄົນຍົກນໍ້າໜັກ',
    '🚴' => 'ຄົນຂີ່ລົດຖີບ',
    '🚵' => 'ນັກຂີ່ລົດຖີບພູເຂົາ',
    '🤸' => 'ຕີລັງກາ',
    '🤼' => 'ນັກມວຍປໍ້າ',
    '🤽' => 'ໂປໂລນໍ້າ',
    '🤾' => 'ບານມື',
    '🤹' => 'ຫຼິ້ນກົນ',
    '🧘' => 'ຄົນນັ່ງທ່າຂັດສະມາທິ',
    '🛀' => 'ຄົນອາບນໍ້າ',
    '🛌' => 'ຄົນນອນເທິງຕຽງ',
    '👭' => 'ແມ່ຍິງຈັບມືກັນ',
    '👫' => 'ຜູ້ຊາຍ ແລະແມ່ຍິງຈັບມືກັນ',
    '👬' => 'ຜູ້ຊາຍຈັບມືກັນ',
    '💏' => 'ຈູບ',
    '💑' => 'ຄູ່ຮັກກັບຫົວໃຈ',
    '🗣' => 'ເງົາຄົນກຳລັງເວົ້າ',
    '👤' => 'ເງົາເຄິ່ງໂຕຄົນດຽວ',
    '👥' => 'ເງົາເຄິ່ງໂຕສອງຄົນ',
    '🫂' => 'ຄົນກອດກັນ',
    '👪' => 'ຄອບຄົວ',
    '👣' => 'ຮອຍຕີນ',
    '🫆' => 'ລາຍນິ້ວມື',
    '🦰' => 'ຜົມແດງ',
    '🦱' => 'ຜົມກູດ',
    '🦳' => 'ຜົມຫງອກ',
    '🦲' => 'ຫົວລ້ານ',
    '🐵' => 'ໜ້າລີງ',
    '🐒' => 'ລີງ',
    '🦍' => 'ກໍຣິລ່າ',
    '🦧' => 'ລີງ​ອຸ​ຣັງ​ອຸ​ຕັງ',
    '🐶' => 'ໜ້າໝາ',
    '🐕' => 'ໝາ',
    '🦮' => 'ໝ​າ​ນຳ​ທາງ',
    '🐩' => 'ໝາພຸດເລິນ',
    '🐺' => 'ໝາປ່າ',
    '🦊' => 'ໝາໄນ',
    '🦝' => 'ໂຕເຫງັນ',
    '🐱' => 'ໜ້າແມວ',
    '🐈' => 'ແມວ',
    '🦁' => 'ສິງໂຕ',
    '🐯' => 'ໜ້າເສືອ',
    '🐅' => 'ເສືອ',
    '🐆' => 'ເສືອດາວ',
    '🐴' => 'ໜ້າມ້າ',
    '🫎' => 'ກວາງມູຊ',
    '🫏' => 'ໂຕລາ',
    '🐎' => 'ມ້າ',
    '🦄' => 'ມ້າ​ຢູ​ນິ​ຄອນ',
    '🦓' => 'ມ້າລາຍ',
    '🦌' => 'ກວາງ',
    '🦬' => 'ກະ​ທິງ',
    '🐮' => 'ໜ້າງົວ',
    '🐂' => 'ງົວຜູ້',
    '🐃' => 'ຄວາຍ',
    '🐄' => 'ງົວແມ່',
    '🐷' => 'ໜ້າໝູ',
    '🐖' => 'ໝູ',
    '🐗' => 'ໝູປ່າ',
    '🐽' => 'ດັງໝູ',
    '🐏' => 'ແກະຜູ້',
    '🐑' => 'ແກະແມ່',
    '🐐' => 'ແບ້',
    '🐪' => 'ອູດ',
    '🐫' => 'ອູດສອງໜອກ',
    '🦙' => 'ໂຕລາມາ',
    '🦒' => 'ຢີຣາບ',
    '🐘' => 'ຊ້າງ',
    '🦣' => 'ຊ້າງ​ແມມມອດ',
    '🦏' => 'ແຮດ',
    '🦛' => 'ໂຕຮີໂປ',
    '🐭' => 'ໜ້າໜູ',
    '🐁' => 'ໜູ',
    '🐀' => 'ໜູໃຫຍ່',
    '🐹' => 'ໂຕແຮມສະເຕີ',
    '🐰' => 'ໜ້າກະຕ່າຍ',
    '🐇' => 'ກະຕ່າຍ',
    '🐿' => 'ກະຮອກ',
    '🦫' => 'ໂຕ​ບີ​ເວີ',
    '🦔' => 'ເໝັ້ນ',
    '🦇' => 'ເຈຍ',
    '🐻' => 'ໝີ',
    '🐨' => 'ໂຄອາລາ',
    '🐼' => 'ໜີແພນດາ',
    '🦥' => 'ໂຕ​ສະ​ລັອດ',
    '🦦' => '​ໂຕ​ນາກ',
    '🦨' => 'ໂຕ​ສະ​ກັງ',
    '🦘' => 'ໂຕໜູຖົງ',
    '🦡' => 'ໂຕໝີບາເກີ',
    '🐾' => 'ຮອຍຕີນສັດ',
    '🦃' => 'ໄກ່ງວງ',
    '🐔' => 'ໄກ່',
    '🐓' => 'ໄກ່ຜູ້',
    '🐣' => 'ລູກໄກ່ຈາກໄຂ່',
    '🐤' => 'ໄກ່ນ້ອຍ',
    '🐥' => 'ໄກ່ນ້ອຍຢືນ',
    '🐦' => 'ນົກ',
    '🐧' => 'ນົກເພນກິນ',
    '🕊' => 'ນົກເຂົາ',
    '🦅' => 'ອິນຊີ',
    '🦆' => 'ເປັດ',
    '🦢' => 'ຫົງ',
    '🦉' => 'ນົກເຄົ້າ',
    '🦤' => 'ນົກ​ໂດ​ໂດ',
    '🪶' => 'ຂົນ​ນົກ',
    '🦩' => 'ນົກ​ຟ​ລາ​ມິງ​ໂກ',
    '🦚' => 'ນົກຍຸງ',
    '🦜' => 'ນົກແກ້ວ',
    '🪽' => 'ປີກ',
    '🪿' => 'ຫ່ານ',
    '🐸' => 'ກົບ',
    '🐊' => 'ແຂ້',
    '🐢' => 'ເຕົ່າ',
    '🦎' => 'ສັດເລືອຄານ',
    '🐍' => 'ງູ',
    '🐲' => 'ໜ້າມັງກອນ',
    '🐉' => 'ມັງກອນ',
    '🦕' => 'ເຊົາໂຣພອດ',
    '🦖' => 'ທີເຣັກ',
    '🐳' => 'ປາວານພົ່ນນໍ້າ',
    '🐋' => 'ປາວານ',
    '🐬' => 'ປາ​ໂລ​ມາ',
    '🦭' => 'ແມວ​ນ້ຳ',
    '🐟' => 'ປາ',
    '🐠' => 'ປາເຂດຮ້ອນ',
    '🐡' => 'ປາເປົ້າ',
    '🦈' => 'ສະຫຼາມ',
    '🐙' => 'ປາມຶກ',
    '🐚' => 'ຫອຍ',
    '🪸' => 'ຫີນປະກາລັງ',
    '🪼' => 'ແມງກະພຸນ',
    '🦀' => 'ກະປູ',
    '🦞' => 'ກຸ້ງລອບສະເຕີ',
    '🦐' => 'ກຸ້ງ',
    '🦑' => 'ປາໝຶກ',
    '🦪' => 'ຫອຍ​ນາງ​ລົມ',
    '🐌' => 'ຫອຍທາກ',
    '🦋' => 'ແມງກະເບື້ອ',
    '🐛' => 'ແມງໄມ້',
    '🐜' => 'ມົດ',
    '🐝' => 'ເຜິ້ງ',
    '🪲' => 'ແມງ​ປີກ​ແຂງ',
    '🐞' => 'ແມງເຕົ່າທອງ',
    '🦗' => 'ຈິ້ງຫລີດ',
    '🪳' => 'ແມງ​ສາບ',
    '🕷' => 'ແມງມຸມ',
    '🕸' => 'ໃຍແມງມຸມ',
    '🦂' => 'ແມງເງົາ',
    '🦟' => 'ຍຸງ',
    '🪰' => 'ແມງວັນ',
    '🪱' => 'ໜອນ',
    '🦠' => 'ຈຸລະພືກ',
    '💐' => 'ຊໍ່ດອກໄມ້',
    '🌸' => 'ດອກເຊີຣີບານ',
    '💮' => 'ດອກໄມ້ສີຂາວ',
    '🪷' => 'ດອກບົວ',
    '🏵' => 'ໂບດອກກຸຫຼາບ',
    '🌹' => 'ດອກກຸຫຼາບ',
    '🥀' => 'ດອກໄມ້ແຫ່ວ',
    '🌺' => 'ດອກພຸດ',
    '🌻' => 'ດອກຕາເວັນ',
    '🌼' => 'ດອກໄມ້ບານ',
    '🌷' => 'ດອກທິວລິບ',
    '🪻' => 'ຜັກຕົບ',
    '🌱' => 'ເບ້ຍໄມ້',
    '🪴' => 'ຕົ້ນໄມ້ທີ່ປູກໃນໂຖ',
    '🌲' => 'ຕົ້ນໄມ້ຂຽວຕະຫຼອດປີ',
    '🌳' => 'ຕົ້ນໄມ້ປ່ຽນໃບ',
    '🌴' => 'ຕົ້ນປາມ',
    '🌵' => 'ຕົ້ນໜາມ',
    '🌾' => 'ຮວງເຂົ້າ',
    '🌿' => 'ສະໝຸນໄພ',
    '☘' => 'ດອກແຊມຣັອກ',
    '🍀' => 'ດອກຈິກສີ່ຊີກ',
    '🍁' => 'ໃບແມບໂພ',
    '🍂' => 'ໃບໄມ້ຫຼົ່ນ',
    '🍃' => 'ໃບໄມ້ປິວຕາມລົມ',
    '🪹' => 'ຮັງເປົ່າ',
    '🪺' => 'ຮັງມີໄຂ່',
    '🍄' => 'ເຫັດ',
    '🪾' => 'ຕົ້ນໄມ້',
    '🍇' => 'ອາງຸ່ນ',
    '🍈' => 'ໝາກເມລອນ',
    '🍉' => 'ໝາກໂມ',
    '🍊' => 'ໝາກກ້ຽງນ້ອຍ',
    '🍋' => 'ໝາກນາວ',
    '🍌' => 'ໝາກກ້ວຍ',
    '🍍' => 'ໝາກນັດ',
    '🥭' => 'ໝາກມ່ວງ',
    '🍎' => 'ໝາກແອັບເປີ້ນແດງ',
    '🍏' => 'ໝາກແອັບເປີ້ນຂຽວ',
    '🍐' => 'ໝາກແພ',
    '🍑' => 'ໝາກພີຈ',
    '🍒' => 'ໝາກເຊີຣີ',
    '🍓' => 'ໝາກສະຕໍເບີຣີ',
    '🫐' => 'ບຣູເບີ້ລີ້',
    '🥝' => 'ໝາກກີວີ',
    '🍅' => 'ໝາກເລັ່ນ',
    '🫒' => 'ໝາກກອກ',
    '🥥' => 'ໝາກພ້າວ',
    '🥑' => 'ອະໂວຄາໂດ',
    '🍆' => 'ໝາກເຂືອ',
    '🥔' => 'ມັນຝຣັ່ງ',
    '🥕' => 'ແຄຣັອດ',
    '🌽' => 'ຮວງສາລີ',
    '🌶' => 'ໝາກເຜັດ',
    '🫑' => 'ໝາກເຜັດໃຫຍ່',
    '🥒' => 'ໝາແຕງ',
    '🥬' => 'ໃບໄມ້ຂຽວ',
    '🥦' => 'ບຣັອກໂຄລີ',
    '🧄' => 'ກະ​ທ​ຽມ',
    '🧅' => '​ຫົວ​ຜັກ​ບົ່ວ​ໃຫຍ່',
    '🥜' => 'ໝາກຖົ່ວ',
    '🫘' => 'ຖົ່ວ',
    '🌰' => 'ໝາກກໍ່',
    '🫚' => 'ຫົວຂີງ',
    '🫛' => 'ຝັກຖົ່ວ',
    '🫜' => 'ຫົວຜັກກາດ',
    '🍞' => 'ເຂົ້າໜົມປັງ',
    '🥐' => 'ຄຣົວຊອງ',
    '🥖' => 'ເຂົ້າຈີ່',
    '🫓' => 'ເຂົ້າຈີ່ແຜ່ນ​ແປ',
    '🥨' => 'ເພຣັດເຊລ',
    '🥯' => 'ຂະໝົມແປ້ງ ບາເກວ',
    '🥞' => 'ແພນເຄັກ',
    '🧇' => 'ເຂົ້າ​ໜົມ​ຮັງ​ເຜິ້ງ',
    '🧀' => 'ກ້ອນຊີສ',
    '🍖' => 'ຊີ້ນຕິດກະດູກ',
    '🍗' => 'ຂາໄກ່',
    '🥩' => 'ຕ່ອນຊີ້ນ',
    '🥓' => 'ເບຄອນ',
    '🍔' => 'ແຮມເບີເກີ',
    '🍟' => 'ທອດມັນຝຣັ່ງ',
    '🍕' => 'ພິຊຊ່າ',
    '🌭' => 'ໄສ້ກອກ',
    '🥪' => 'ແຊນວິດ',
    '🌮' => 'ທາໂກ້',
    '🌯' => 'ເບີຣິໂຕ',
    '🫔' => 'ພັບ',
    '🥙' => 'ເຂົ້າຈີ່ແຜ່ນຍັດໄສ້',
    '🧆' => 'ຟາ​ລາ​ເຟວ',
    '🥚' => 'ໄຂ່',
    '🍳' => 'ແຕ່ງອາຫານ',
    '🥘' => 'ຈານອາຫານບາງໆ',
    '🍲' => 'ຖ້ວຍອາຫານ',
    '🫕' => 'ຟອງດູ',
    '🥣' => 'ຖ້ວຍກັບບ່ວງ',
    '🥗' => 'ສະລັດຂຽວ',
    '🍿' => 'ປັອບຄອນ',
    '🧈' => 'ເນີຍ',
    '🧂' => 'ເກືອ',
    '🥫' => 'ອາຫານກະປ໋ອງ',
    '🍱' => 'ເບັນໂຕະ',
    '🍘' => 'ເຂົ້າໜົມເຂົ້າ',
    '🍙' => 'ເຂົ້າປັ້ນ',
    '🍚' => 'ເຂົ້າສຸກ',
    '🍛' => 'ເຂົ້າແກງກະຫຼີ່',
    '🍜' => 'ຖ້ວຍທີ່ສົ່ງອາຍ',
    '🍝' => 'ສະປາເກັດຕີ້',
    '🍠' => 'ມັນຫວານໜຶ້ງ',
    '🍢' => 'ໂອເດ້ງສຽບໄມ້',
    '🍣' => 'ຊູຊິ',
    '🍤' => 'ກຸ້ງທອດ',
    '🍥' => 'ລູກຊີ້ນປາ',
    '🥮' => 'ຂະໜົມໄຫວ້ພະຈັນ',
    '🍡' => 'ດັງໂງະ',
    '🥟' => 'ກ້ອນໝີ່',
    '🥠' => 'ຄຸກກີ້ໂຊກດີ',
    '🥡' => 'ກ່ອງໃສ່ອາຫານ',
    '🍦' => 'ກະແລ໋ມນຸ້ມ',
    '🍧' => 'ນໍ້າກ້ອນບົດ',
    '🍨' => 'ກະແລ໋ມ',
    '🍩' => 'ໂດນັດ',
    '🍪' => 'ເຂົ້າໜົມຄຸກກີ້',
    '🎂' => 'ເຄັກວັນເກີດ',
    '🍰' => 'ເຄັກຊັອດ',
    '🧁' => 'ຄັບເຄັກ',
    '🥧' => 'ພາຍ',
    '🍫' => 'ແທ່ງຊັອກໂກແລັດ',
    '🍬' => 'ເຂົ້າໜົມອົມ',
    '🍭' => 'ອົມຍິ້ມ',
    '🍮' => 'ຄັສຕາດ',
    '🍯' => 'ໂຖນໍ້າເຜິ້ງ',
    '🍼' => 'ເຕົ້ານົມເດັກ',
    '🥛' => 'ຈອກນົມ',
    '☕' => 'ເຄື່ອງດື່ມຮ້ອນ',
    '🫖' => 'ການ້ຳຊາ',
    '🍵' => 'ຈອກຊາທີ່ບໍ່ມີງວງຈັບ',
    '🍶' => 'ເຫຼົ້າຊາເກະ',
    '🍾' => 'ແກ້ວເຫຼົ້າທີ່ມີຝາກະດອນອັດ',
    '🍷' => 'ຈອກແກ້ວເຫຼົ້າແວງ',
    '🍸' => 'ຈອກແກ້ວຄັອກເທວ',
    '🍹' => 'ເຄື່ອງດື່ມເຂດຮ້ອນ',
    '🍺' => 'ແກ້ວເບຍ',
    '🍻' => 'ຈອກເບຍຕຳກັນ',
    '🥂' => 'ຕຳຈອກ',
    '🥃' => 'ແກ້ວເຫຼົ້າ',
    '🫗' => 'ເຍັ້ນນໍ້າ',
    '🥤' => 'ຈອກມີຫຼອດດູດ',
    '🧋' => 'ຊາໄຂ່ມຸກ',
    '🧃' => 'ກ່​ອງ​ໃສ່​ເຄື່ອງ​ດື່ມ',
    '🧉' => 'ເມດ',
    '🧊' => 'ນ້ຳ​ກ້ອນ',
    '🥢' => 'ໄມ້ທູ່',
    '🍽' => 'ສ້ອມ ແລະ ມີດ ກັບຈານ',
    '🍴' => 'ສ້ອມ ແລະ ມີດ',
    '🥄' => 'ບ່ວງ',
    '🔪' => 'ມີດໃຊ້ໃນເຮືອນຄົວ',
    '🫙' => 'ໄຫ',
    '🏺' => 'ໂຖແອມໂພຣາ',
    '🌍' => 'ໜ່ວຍໂລກທີ່ສະແດງເອີຣົບ-ອາຝຣິກາ',
    '🌎' => 'ໜ່ວຍໂລກທີ່ສະແດງອາເມລິກາ',
    '🌏' => 'ໜ່ວຍໂລກທີ່ສະແດງອາຊີ-ອົດສະຕາລີ',
    '🌐' => 'ໜ່ວຍໂລກທີ່ມີເສັ້ນເມຣິດຽນ',
    '🗺' => 'ແຜນທີ່ໂລກ',
    '🗾' => 'ແຜນທີ່ຍີ່ປຸນ',
    '🧭' => 'ເຂັມທິດ',
    '🏔' => 'ພູເຂົາທີ່ປົກຄຸມດ້ວຍຫິມະ',
    '⛰' => 'ພູ',
    '🛘' => 'ດິນເຈື່ອນ',
    '🌋' => 'ພູເຂົາໄຟ',
    '🗻' => 'ພູເຂົາໄຟຟູຈິ',
    '🏕' => 'ການຕັ້ງແຄັມ',
    '🏖' => 'ຫາດຊາຍກັບຄັນຮົ່ມ',
    '🏜' => 'ທະເລຊາຍ',
    '🏝' => 'ເກາະທະເລຊາຍ',
    '🏞' => 'ປ່າສະຫງວນແຫ່ງຊາດ',
    '🏟' => 'ສະໜາມກິລາ',
    '🏛' => 'ອາຄານແບບຄລາສິກ',
    '🏗' => 'ການກໍ່ສ້າງອາຄານ',
    '🧱' => 'ກ້ອນດິນຈີ່',
    '🪨' => 'ໂງ່ນຫີນ',
    '🪵' => 'ຟືນ',
    '🛖' => 'ກະທົມ',
    '🏘' => 'ອາຄານເຮືອນຫຼາຍຫຼັງ',
    '🏚' => 'ອາຄານເຮືອນຮ້າງ',
    '🏠' => 'ອາຄານເຮືອນ',
    '🏡' => 'ເຮືອນກັບສວນຄົວ',
    '🏢' => 'ອາຄານຫ້ອງການ',
    '🏣' => 'ຫ້ອງການໄປສະນີຍີ່ປຸ່ນ',
    '🏤' => 'ຫ້ອງການໄປສະນີ',
    '🏥' => 'ໂຮງໝໍ',
    '🏦' => 'ທະນາຄານ',
    '🏨' => 'ໂຮງແຮມ',
    '🏩' => 'ໂຮງແຮມຄວາມຮັກ',
    '🏪' => 'ຮ້ານສະດວກຊື້',
    '🏫' => 'ໂຮງຮຽນ',
    '🏬' => 'ຮ້ານສັບພະສິນຄ້າ',
    '🏭' => 'ໂຮງງານ',
    '🏯' => 'ຫໍປະສາດຍີ່ປຸ່ນ',
    '🏰' => 'ຫໍປະສາດ',
    '💒' => 'ແຕ່ງດອງ',
    '🗼' => 'ຫໍຄອຍໂຕກຽວ',
    '🗽' => 'ເທພີເສລີພາບ',
    '⛪' => 'ໂບດ',
    '🕌' => 'ມັດສະຍິບ',
    '🛕' => 'ວັດ​ຮິນ​ດູ',
    '🕍' => 'ໂບດຊາວຢິວ',
    '⛩' => 'ສານເຈົ້າຊິນໂຕ',
    '🕋' => 'ວິຫານກະບະ',
    '⛲' => 'ນໍ້າພຸ',
    '⛺' => 'ເຕັນ',
    '🌁' => 'ໝອກລົງ',
    '🌃' => 'ກາງຄືນທີ່ມີດາວ',
    '🏙' => 'ພາບທິວທັດຂອງເມືອງ',
    '🌄' => 'ຕາເວັນຜ່ານພູເຂົາ',
    '🌅' => 'ຕາເວັນຂຶ້ນ',
    '🌆' => 'ພາບທິວທັດເມືອງເວລາຕາເວັນຕົກ',
    '🌇' => 'ຕາເວັນຕົກ',
    '🌉' => 'ຂົວໃນຕອນກາງຄືນ',
    '♨' => 'ນໍ້າພຸຮ້ອນ',
    '🎠' => 'ມ້າໝູນ',
    '🛝' => 'ຕະລູດ',
    '🎡' => 'ຊິງຊ້າສະຫວັນ',
    '🎢' => 'ລົດໄຟເຫາະ',
    '💈' => 'ຮ້ານຕັດຜົມ',
    '🎪' => 'ຊຸ້ມນອນໂຮງລະຄອນສັດ',
    '🚂' => 'ຫົວລົດຈັກ',
    '🚃' => 'ຕູ້ລົດໄຟ',
    '🚄' => 'ລົດໄຟຄວາມໄວສູງ',
    '🚅' => 'ລົດໄຟຄວາມໄວສູງຫົວລູກປືນ',
    '🚆' => 'ລົດໄຟ',
    '🚇' => 'ລົດໄຟໃຕ້ດິນ',
    '🚈' => 'ລາງລົດເບົາ',
    '🚉' => 'ສະຖານີ',
    '🚊' => 'ລົດລາງ',
    '🚝' => 'ລົດໄຟລາງດຽວ',
    '🚞' => 'ລາງລົດໄຟພູເຂົາ',
    '🚋' => 'ຕູ້ລົດລາງ',
    '🚌' => 'ລົດເມ',
    '🚍' => 'ລົດເມກຳລັງມາ',
    '🚎' => 'ລົດເມໄຟຟ້າ',
    '🚐' => 'ລົດເມນ້ອຍ',
    '🚑' => 'ລົດຄົນເຈັບ',
    '🚒' => 'ລົດດັບເພີງ',
    '🚓' => 'ລົດຕຳຫຼວດ',
    '🚔' => 'ລົດຕຳຫຼວດກຳລັງມາ',
    '🚕' => 'ລົດແທັກຊີ',
    '🚖' => 'ລົດແທັກຊີກຳລັງມາ',
    '🚗' => 'ລົດຍົນ',
    '🚘' => 'ລົດຍົນກຳລັງມາ',
    '🚙' => 'ລົດພັກຜ່ອນ',
    '🛻' => 'ລົດຂົນສົ່ງປິກອັບ',
    '🚚' => 'ລົດຂົນສົ່ງ',
    '🚛' => 'ລົດພວງບັນທຸກ',
    '🚜' => 'ລົດແທັກເຕີ',
    '🏎' => 'ລົດແຂ່ງ',
    '🏍' => 'ລົດຈັກ',
    '🛵' => 'ສະກູດເຕີ',
    '🦽' => 'ລໍ້​ຍູ້​ແບບ​ບັງ​ຄັບ​ເອງ',
    '🦼' => 'ລໍ້​ຍູ້​ແບບ​ຕິດ​ຕັ້ງ​ມໍ​ເຕີ້',
    '🛺' => 'ລົດ​ລາກ​ອັດ​ຕະ​ໂນ​ມັດ',
    '🚲' => 'ລົດຖີບ',
    '🛴' => 'ສະກູດເຕີແບບເຕະ',
    '🛹' => 'ແຜ່ນສະເກັດບອດ',
    '🛼' => 'ເກີບ​ສະ​ເກດ',
    '🚏' => 'ບ່ອນຈອດລົດເມ',
    '🛣' => 'ທາງດ່ວນ',
    '🛤' => 'ລາງລົດໄຟ',
    '🛢' => 'ຖັງນໍ້າມັນ',
    '⛽' => 'ປໍ້ານໍ້າມັນ',
    '🛞' => 'ລໍ້ລົດ',
    '🚨' => 'ໄຟສັນຍານລົດຕໍາຫຼວດ',
    '🚥' => 'ໄຟຈາລະຈອນແນວນອນ',
    '🚦' => 'ໄຟຈາລະຈອນແນວຕັ້ງ',
    '🛑' => 'ປ້າຍຢຸດ',
    '🚧' => 'ປ້າຍການກໍ່ສ້າງ',
    '⚓' => 'ສະໝໍ',
    '🛟' => 'ຫ່ວງຊູຊີບ',
    '⛵' => 'ເຮືອໃບ',
    '🛶' => 'ແຄໂນ',
    '🚤' => 'ເຮືອໄວ',
    '🛳' => 'ເຮືອໂດຍສານ',
    '⛴' => 'ເຮືອເຟີຣີ',
    '🛥' => 'ເຮືອຈັກ',
    '🚢' => 'ເຮືອກຳປັ່ນ',
    '✈' => 'ເຮືອບິນ',
    '🛩' => 'ເຮືອບິນຂະໜາດນ້ອຍ',
    '🛫' => 'ເຮືອບິນຂຶ້ນ',
    '🛬' => 'ເຮືອບິນລົງ',
    '🪂' => 'ຈ້​ອງ',
    '💺' => 'ບ່ອນນັ່ງ',
    '🚁' => 'ຍົນເຮລິຄອບເຕີ',
    '🚟' => 'ທາງລົດໄຟແຂວນ',
    '🚠' => 'ທາງສາຍເຄເບິນຜ່ານພູເຂົາ',
    '🚡' => 'ກະເຊົ້າລອຍຟ້າ',
    '🛰' => 'ດາວທຽມ',
    '🚀' => 'ຈະຫຼວດ',
    '🛸' => 'ຍົນຈານບິນ',
    '🛎' => 'ກະດິ່ງໂຮງແຮມ',
    '🧳' => 'ກະເປົາ',
    '⌛' => 'ໂມງຂີ້ຊາຍ',
    '⏳' => 'ໂມງຂີ້ຊາຍຈັບເວລາ',
    '⌚' => 'ໂມງ',
    '⏰' => 'ໂມງປຸກ',
    '⏱' => 'ໂມງຈັບເວລາ',
    '⏲' => 'ໂມງນັບຖອຍຫຼັງ',
    '🕰' => 'ໂມງເທິງແທ່ນໄມ້',
    '🕛' => 'ສິບສອງໂມງ',
    '🕧' => 'ສິບສອງໂມງເຄິ່ງ',
    '🕐' => 'ໜຶ່ງໂມງ',
    '🕜' => 'ໜຶ່ງໂມງເຄິ່ງ',
    '🕑' => 'ສອງໂມງ',
    '🕝' => 'ສອງໂມງເຄິ່ງ',
    '🕒' => 'ສາມໂມງ',
    '🕞' => 'ສາມໂມງເຄິ່ງ',
    '🕓' => 'ສີ່ໂມງ',
    '🕟' => 'ສີ່ໂມງເຄິ່ງ',
    '🕔' => 'ຫ້າໂມງ',
    '🕠' => 'ຫ້າໂມງເຄິ່ງ',
    '🕕' => 'ຫົກໂມງ',
    '🕡' => 'ຫົກໂມງເຄິ່ງ',
    '🕖' => 'ເຈັດໂມງ',
    '🕢' => 'ເຈັດໂມງເຄິ່ງ',
    '🕗' => 'ແປດໂມງ',
    '🕣' => 'ແປດໂມງເຄິ່ງ',
    '🕘' => 'ເກົ້າໂມງ',
    '🕤' => 'ເກົ້າໂມງເຄິ່ງ',
    '🕙' => 'ສິບໂມງ',
    '🕥' => 'ສິບໂມງເຄິ່ງ',
    '🕚' => 'ສິບເອັດໂມງ',
    '🕦' => 'ສິບເອັດໂມງເຄິ່ງ',
    '🌑' => 'ເດືອນດັບ',
    '🌒' => 'ເດືອນແຮມອອກໃໝ່',
    '🌓' => 'ເດືອນອອກໃໝ່ເຄິ່ງດວງ',
    '🌔' => 'ເດືອນອອກໃໝ່ຂ້ອນດວງ',
    '🌕' => 'ເດືອນອອກໃໝ່ເຕັມດວງ',
    '🌖' => 'ເດືອນດັບສ້ຽວດວງ',
    '🌗' => 'ເດືອນດັບເຄິ່ງດວງ',
    '🌘' => 'ເດືອນດັບຂ້ອນດວງ',
    '🌙' => 'ເດືອນສ້ຽວ',
    '🌚' => 'ໜ້າເດືອນດັບ',
    '🌛' => 'ໜ້າເດືອນເຄິ່ງດວງທຳອິດ',
    '🌜' => 'ໜ້າເດືອນເຄິ່ງດວງສຸດທ້າຍ',
    '🌡' => 'ເຄື່ອງວັດແທກອຸນຫະພູມ',
    '☀' => 'ຕາເວັນ',
    '🌝' => 'ໜ້າເດືອນເຕັມດວງ',
    '🌞' => 'ໜ້າຕາເວັນ',
    '🪐' => 'ວົງ​ແຫວນ​ດາວ​ເຄາະ',
    '⭐' => 'ດາວຂາວປານກາງ',
    '🌟' => 'ດາວເປັ່ງປະກາຍ',
    '🌠' => 'ດາວຕົກ',
    '🌌' => 'ທາງຊ້າງເຜືອກ',
    '☁' => 'ເມກ',
    '⛅' => 'ຕາເວັນຢູ່ຫຼັງເມກ',
    '⛈' => 'ຝົນຟ້າຄະນອງ',
    '🌤' => 'ເມກນ້ອຍບົດບັງຕາເວັນ',
    '🌥' => 'ເມກກ້ອນໃຫຍ່ບົດບັງຕາເວັນ',
    '🌦' => 'ເມກຝົນບົດບັງຕາເວັນ',
    '🌧' => 'ເມກຝົນ',
    '🌨' => 'ເມກແລະຫິມະ',
    '🌩' => 'ເມກແລະຟ້າເຫຼື້ອມ',
    '🌪' => 'ພະຍຸທໍນາໂດ',
    '🌫' => 'ໝອກ',
    '🌬' => 'ໜ້າເປົ່າລົມ',
    '🌀' => 'ລົມໝູນ',
    '🌈' => 'ຮຸ້ງກິນນໍ້າ',
    '🌂' => 'ຄັນຮົ່ມງັບໄວ້',
    '☂' => 'ຄັນຮົ່ມ',
    '☔' => 'ຄັນຮົ່ມກັບເມັດຝົນ',
    '⛱' => 'ຄັນຮົ່ມຢູ່ເທິງພື້ນດິນ',
    '⚡' => 'ໄຟຟ້າແຮງສູງ',
    '❄' => 'ເກັດຫິມະ',
    '☃' => 'ຮູບປັ້ນມະນຸດຫິມະ',
    '⛄' => 'ຮູບປັ້ນມະນຸດຫິມະທີ່ບໍ່ມີຫິມະ',
    '☄' => 'ດາວຫາງ',
    '🔥' => 'ໄຟ',
    '💧' => 'ຢອດນໍ້າ',
    '🌊' => 'ຄື້ນນໍ້າ',
    '🎃' => 'ໂຄມໄຟໝາກອຶ',
    '🎄' => 'ຕົ້ນຄຣິດມາສ',
    '🎆' => 'ດອກໄມ້ໄຟ',
    '🎇' => 'ດອກໄມ້ໄຟນ້ອຍ',
    '🧨' => 'ໝາກກະໂພກ',
    '✨' => 'ປະກາຍໄຟ',
    '🎈' => 'ໝາກປູມເປົ້າ',
    '🎉' => 'ພາຕີ້ປັອບເປີ',
    '🎊' => 'ລູກບານຄອນເຟຕີ',
    '🎋' => 'ຕົ້ນໄມ້ປະດັບຄຳອວຍພອນ',
    '🎍' => 'ການຕົບແຕ່ງຕົ້ນແປກ',
    '🎎' => 'ຕຸກກະຕາຍີ່ປຸ່ນ',
    '🎏' => 'ທຸງປາຄາບ',
    '🎐' => 'ລົມພັດລະຄັງ',
    '🎑' => 'ພິທີໄຫວ້ພະຈັນ',
    '🧧' => 'ຊອງຈົດໝາຍສີແດງ',
    '🎀' => 'ໂບ',
    '🎁' => 'ກ່ອງຂອງຂວັນ',
    '🎗' => 'ໂບລະນຶກ',
    '🎟' => 'ປີ້ເຂົ້າຊົມ',
    '🎫' => 'ປີ້',
    '🎖' => 'ຫຼຽນທະຫານ',
    '🏆' => 'ຖ້ວຍລາງວັນ',
    '🏅' => 'ຫຼຽນກິລາ',
    '🥇' => 'ຫຼຽນທີ 1',
    '🥈' => 'ຫຼຽນເງິນ',
    '🥉' => 'ຫຽນທອງແດງ',
    '⚽' => 'ໝາກບານເຕະ',
    '⚾' => 'ເບສບອລ',
    '🥎' => 'ໝາກບານເທນນິກ',
    '🏀' => 'ບານບ້ວງ',
    '🏐' => 'ບານສົ່ງ',
    '🏈' => 'ອາເມລິກັນຟຸດບອນ',
    '🏉' => 'ລູກຣັກບີ້',
    '🎾' => 'ເທັນນິສ',
    '🥏' => 'ຈານບິນ',
    '🎳' => 'ໂບລິ້ງ',
    '🏏' => 'ໄມ້ຄຣິກເກັດ',
    '🏑' => 'ຮັອກກີ',
    '🏒' => 'ໄມ້ແລະລູກຢາງກິລາຮັອກກີນໍ້າແຂງ',
    '🥍' => 'ລາໂກຼດ',
    '🏓' => 'ກິລາປິ່ງປ່ອງ',
    '🏸' => 'ກິລາດອກປີກໄກ່',
    '🥊' => 'ນວມມວຍ',
    '🥋' => 'ຊຸດສິນລະປະປ້ອງກັນຕົວ',
    '🥅' => 'ຕາຂ່າຍປະຕູ',
    '⛳' => 'ທຸງໃນຫຼຸມ',
    '⛸' => 'ສະເກດນໍ້າແຂງ',
    '🎣' => 'ຄັນເບັດ',
    '🤿' => 'ໜ້າ​ກາກ​ດຳ​ນ້ຳ',
    '🎽' => 'ເສື້ອສຳລັບແລ່ນ',
    '🎿' => 'ສະກີ',
    '🛷' => 'ລົດລາກ',
    '🥌' => 'ຫິນລູກຂ່າງ',
    '🎯' => 'ກາງເປົ້າ',
    '🪀' => 'ໂຢ​ໂຢ້',
    '🪁' => 'ວ່າວ',
    '🔫' => 'ປືນສັ້ນ',
    '🎱' => 'ສະນຸກເກີ',
    '🔮' => 'ແກ້ວຄຣິສໂຕ້',
    '🪄' => 'ໄມ້​ກາ​ຍະ​ສິດ',
    '🎮' => 'ວີດີໂອເກມ',
    '🕹' => 'ຄັນບັງຄັບ',
    '🎰' => 'ເຄື່ອງຫຼິ້ນເກມສະລອດ',
    '🎲' => 'ເກມລູກເຕົ໋າ',
    '🧩' => 'ຈິກຊໍ',
    '🧸' => 'ໝີເທດດີ',
    '🪅' => 'ພິນາຕາ',
    '🪩' => 'ໝາກບານກະຈົກ',
    '🪆' => 'ຕຸກກະຕາເປັນຮັງ',
    '♠' => 'ໂພດຳ',
    '♥' => 'ເກີ',
    '♦' => 'ໂລ',
    '♣' => 'ຈ່ວນ',
    '♟' => 'ໝາກລຸກ',
    '🃏' => 'ໂຈກເກີ',
    '🀄' => 'ໄພ້ນົກກະຈອກ',
    '🎴' => 'ໄພ້ດອກໄມ້',
    '🎭' => 'ສິລະປະການສະແດງ',
    '🖼' => 'ຂອບຮູບ',
    '🎨' => 'ຈານປະສົມສີ',
    '🧵' => 'ເສັ້ນດ້າຍ',
    '🪡' => 'ເຂັມຍິບ',
    '🧶' => 'ກໍ້ດ້າຍ',
    '🪢' => '​ຂອດ',
    '👓' => 'ແວ່ນຕາ',
    '🕶' => 'ແວ່ນຕາກັນແດດ',
    '🥽' => 'ແວ່ນຕາກັນລົມ',
    '🥼' => 'ທ່ານໝໍ',
    '🦺' => 'ເສື້​ອ​ກັນ​ໄພ',
    '👔' => 'ກາລະຫວັດ',
    '👕' => 'ເສື້ອຍືດ',
    '👖' => 'ໂສ້ງຢີນ',
    '🧣' => 'ຜ້າພັນຄໍ',
    '🧤' => 'ຖົງມື',
    '🧥' => 'ເສື້ອຂົນສັດ',
    '🧦' => 'ຖົງຕີນ',
    '👗' => 'ຊຸດກະໂປ່ງ',
    '👘' => 'ຊຸດກີໂມໂນ',
    '🥻' => 'ສ່າ​ຣີ',
    '🩱' => 'ຊຸດ​ລອຍ​ນ້ຳ​ແບບ​ສ່ວນ​ດຽວ',
    '🩲' => 'ໂສ້ງ​ຊ້ອນ​ໃນ​ຜູ້​ຊາຍ',
    '🩳' => 'ໂສ້ງ​ຂາ​ສັ້ນ',
    '👙' => 'ຊຸດຊັ້ນໃນ',
    '👚' => 'ເສື້ອຜ້າແມ່ຍິງ',
    '🪭' => 'ວີພັບ',
    '👛' => 'ກະເປົາເງິນ',
    '👜' => 'ກະເປົາແບບຖຶ',
    '👝' => 'ກະເປົາແບບຈັບເອົາ',
    '🛍' => 'ຖົງໃສ່ເຄື່ອງ',
    '🎒' => 'ກະເປົາເປ້',
    '🩴' => 'ເກີບແຕະສີທອງ',
    '👞' => 'ເກີບຜູ້ຊາຍ',
    '👟' => 'ເກີບສຳລັບແລ່ນ',
    '🥾' => 'ເກີບບົດ',
    '🥿' => 'ເກີບແຕະ',
    '👠' => 'ເກີບສົ້ນສູງ',
    '👡' => 'ເກີບແຕະແມ່ຍິງ',
    '🩰' => 'ເກີບ​ເຕັ້ນ​ບັນ​ເລ້',
    '👢' => 'ເກີບບູດແມ່ຍິງ',
    '🪮' => 'ຫວີ',
    '👑' => 'ມຸງກຸດ',
    '👒' => 'ໝວກແມ່ຍິງ',
    '🎩' => 'ໝວກກະບອກສູງ',
    '🎓' => 'ໝວກຮັບໃບປະກາດ',
    '🧢' => 'ໝວກແກັບ',
    '🪖' => 'ໝວກທະຫານ',
    '⛑' => 'ໝວກກັນກະທົບທີ່ມີກາກະບາດສີຂາວ',
    '📿' => 'ສາຍລູກປັດ',
    '💄' => 'ລິບສຕິກ',
    '💍' => 'ແຫວນ',
    '💎' => 'ເພັດພອຍ',
    '🔇' => 'ປິດລຳໂພງ',
    '🔈' => 'ລຳໂພງ',
    '🔉' => 'ເປີດລຳໂພງ',
    '🔊' => 'ລໍາໂພງດັງ',
    '📢' => 'ເຄື່ອງກະຈາຍສຽງ',
    '📣' => 'ທໍລະໂຄ່ງ',
    '📯' => 'ແກເຂົາສັດ',
    '🔔' => 'ກະດິ່ງ',
    '🔕' => 'ບໍ່ມີກະດິ່ງ',
    '🎼' => 'ສັນຍາລັກເພງ',
    '🎵' => 'ໂນດດົນຕີ',
    '🎶' => 'ໂນດເພງ',
    '🎙' => 'ໄມສະຕູດີໂອ',
    '🎚' => 'ຕົວເລື່ອນລະດັບສຽງ',
    '🎛' => 'ປຸ່ມຄວບຄຸມ',
    '🎤' => 'ໄມ',
    '🎧' => 'ຫູຟັງ',
    '📻' => 'ວິທະຍຸ',
    '🎷' => 'ແຊັກໂຊໂຟນ',
    '🎺' => 'ແກ',
    '🪊' => 'ທຣອມໂບນ',
    '🪗' => 'ຫີບເພງ',
    '🎸' => 'ກີຕາ',
    '🎹' => 'ເປຍໂນ',
    '🎻' => 'ໄວໂອລິນ',
    '🪕' => 'ແບນ​ໂຈ',
    '🥁' => 'ກອງ',
    '🪘' => 'ກອງຍາວ',
    '🪇' => 'ມາຣາຄັສ',
    '🪈' => 'ຂຸ່ຍ',
    '🪉' => 'ພິນ',
    '📱' => 'ໂທລະສັບມືຖື',
    '📲' => 'ໂທລະສັບມືຖືກັບລູກສອນ',
    '☎' => 'ໂທລະສັບ',
    '📞' => 'ຫູໂທລະສັບ',
    '📟' => 'ເຄື່ອງເພກເຈີ',
    '📠' => 'ເຄື່ອງຮັບສົ່ງແຟັກ',
    '🔋' => 'ແບັດເຕີຣີ',
    '🪫' => 'ແບັດເຕີຣີຕໍ່າ',
    '🔌' => 'ປັກສຽບໄຟ',
    '💻' => 'ຄອມພິວເຕີແລັບທັອບ',
    '🖥' => 'ຄອມພິວເຕີຕັ້ງໂຕະ',
    '🖨' => 'ເຄື່ອງພິມ',
    '⌨' => 'ແປ້ນພິມ',
    '🖱' => 'ເມົາສ໌ຄອມພິວເຕີ',
    '🖲' => 'ລູກກົມຄວບຄຸມ',
    '💽' => 'ແຜ່ນດິສ',
    '💾' => 'ຟລັອບປີ້ດິສ',
    '💿' => 'ອັອບຕີໂຄດິສ',
    '📀' => 'ດີວີດີ',
    '🧮' => 'ລູກຄິດ',
    '🎥' => 'ກ້ອງຖ່າຍຮູບເງົາ',
    '🎞' => 'ເຟຣມຮູບເງົາ',
    '📽' => 'ເຄື່ອງສາຍຮູບເງົາ',
    '🎬' => 'ແຜ່ນແຄລບເປີ',
    '📺' => 'ໂທລະພາບ',
    '📷' => 'ກ້ອງຖ່າຍຮູບ',
    '📸' => 'ກ້ອງຖ່າຍຮູບເປີດແຟຣັຊ',
    '📹' => 'ກ້ອງວິດີໂອ',
    '📼' => 'ກະແຊັດວິດີໂອ',
    '🔍' => 'ແວ່ນຂະຫຍາຍຊີ້ໄປຊ້າຍ',
    '🔎' => 'ແວ່ນຂະຫຍາຍຊີ້ໄປຂວາ',
    '🕯' => 'ທຽນ',
    '💡' => 'ດອກໄຟ',
    '🔦' => 'ໄຟສາຍ',
    '🏮' => 'ໂຄມໄຟເຈ້ຍສີແດງ',
    '🪔' => 'ຕະ​ກຽງດິ​ຢາ',
    '📔' => 'ປື້ມບັນທຶກທີໜ້າປົກໄດ້ຮັບການຕົບແຕ່ງ',
    '📕' => 'ປື້ມທີ່ປິດຢູ່',
    '📖' => 'ປື້ມທີ່ເປີດຢູ່',
    '📗' => 'ປື້ມສີຂຽວ',
    '📘' => 'ປື້ມສີຟ້າ',
    '📙' => 'ປື້ມສີໝາກກ້ຽງ',
    '📚' => 'ປື້ມຫຼາຍຫົວ',
    '📓' => 'ສະໝຸດບັນທຶກ',
    '📒' => 'ປື້ມບັນທຶກເຈາະຮູຂ້າງ',
    '📃' => 'ເຈ້ຍມ້ວນປາຍ',
    '📜' => 'ມ້ວນເຈ້ຍ',
    '📄' => 'ເຈ້ຍປີ້ນໜ້າຂຶ້ນ',
    '📰' => 'ໜັງສືພິມ',
    '🗞' => 'ກໍ້ໜັງສືພິມ',
    '📑' => 'ແຖບຂັ້ນໜ້າເຈ້ຍ',
    '🔖' => 'ແນວຂັ້ນໜ້າເຈ້ຍ',
    '🏷' => 'ປ້າຍກຳກັບ',
    '🪙' => 'ຫຼຽນ',
    '💰' => 'ຖົງເງິນ',
    '🪎' => 'ຫີບສົມບັດ',
    '💴' => 'ໃບເງິນເຢນ',
    '💵' => 'ໃບເງິນໂດລາ',
    '💶' => 'ໃບເງິນເອີໂຣ',
    '💷' => 'ໃບເງິນປອນ',
    '💸' => 'ເງິນທີ່ມີປີກ',
    '💳' => 'ບັດເຄຣດິດ',
    '🧾' => 'ໃບຮັບເງິນ',
    '💹' => 'ເສັ້ນສະແດງຄ່າເງິນເຢັນທີ່ເພີ່ມຂຶ້ນ',
    '✉' => 'ຊອງຈົດໝາຍ',
    '📧' => 'ອີເມວ',
    '📨' => 'ຈົດໝາຍເຂົ້າ',
    '📩' => 'ຈົດໝາຍອອກ',
    '📤' => 'ກ່ອງຂາເຂົ້າ',
    '📥' => 'ກ່ອງຂາອອກ',
    '📦' => 'ກ່ອງພັດສະດຸ',
    '📫' => 'ກ່ອງຈົດໝາຍປິດຍົກທຸງ',
    '📪' => 'ກ່ອງຈົດໝາຍປິດຂວໍ້າທຸງ',
    '📬' => 'ກ່ອງຈົດໝາຍເປີດຍົກທຸງ',
    '📭' => 'ກ່ອງຈົດໝາຍເປີດຂວໍ້າທຸງ',
    '📮' => 'ກ່ອງໄປສະນີ',
    '🗳' => 'ກ່ອງບັດລົງຄະແນນສຽງ',
    '✏' => 'ສໍ',
    '✒' => 'ປາກກາດຳ',
    '🖋' => 'ປາກກາມຶກຊຶມ',
    '🖊' => 'ບິກ',
    '🖌' => 'ຝອຍທາສີ',
    '🖍' => 'ສໍສີ',
    '📝' => 'ບັນທຶກ',
    '💼' => 'ກະເປົ່າເອກະສານ',
    '📁' => 'ແຟ້ມເອກະສານ',
    '📂' => 'ເປີດເອກະສານ',
    '🗂' => 'ແນວຂັ້ນບັດລາຍການ',
    '📅' => 'ປະຕິທິນ',
    '📆' => 'ປະຕິທິນແບບຈີກອອກ',
    '🗒' => 'ແຜ່ນບັນທຶກທີ່ມີສົ້ນແບບເປັນຫ່ວງ',
    '🗓' => 'ປະຕິທິນທີ່ມີສົ້ນແບບເປັນຫ່ວງ',
    '📇' => 'ກ່ອງໃສ່ບັດ',
    '📈' => 'ເສັ້ນສະແດງທີ່ເພີ່ມຂຶ້ນ',
    '📉' => 'ເສັ້ນສະແດງທີ່ຫຼຸດລົງ',
    '📊' => 'ຜັງສະແດງແບບເປັນທ່ອນ',
    '📋' => 'ຄລິບບອດ',
    '📌' => 'ເຂັມປັກໝຸດ',
    '📍' => 'ໝຸດປັກຫົວມົນ',
    '📎' => 'ຄລິບໜີບເຈ້ຍ',
    '🖇' => 'ເຫຼັກໜີບເຈ້ຍຄູ່',
    '📏' => 'ບັນທັດຊື່',
    '📐' => 'ບັນທັດສາມຫຼ່ຽມສາກ',
    '✂' => 'ມີດຕັດ',
    '🗃' => 'ກ່ອງບັນຈຸບັດ',
    '🗄' => 'ຕູ້ໃສ່ແຟ້ມເອກະສານ',
    '🗑' => 'ກະຕ່າຂີ້ເຫຍື້ອ',
    '🔒' => 'ໜ່ວຍກະແຈ',
    '🔓' => 'ໜ່ວຍກະແຈເປີດຢູ່',
    '🔏' => 'ໜ່ວຍກະແຈກັບປາກກາ',
    '🔐' => 'ໜ່ວຍກະແຈລັອກພ້ອມກັບລູກກະແຈ',
    '🔑' => 'ລູກກະແຈ',
    '🗝' => 'ລູກກະແຈເກົ່າ',
    '🔨' => 'ໄມ້ຄ້ອນ',
    '🪓' => 'ຂວານ',
    '⛏' => 'ເຫຼັກສັບຂຸດ',
    '⚒' => 'ໄມ້ຄ້ອນ ແລະ ເຫຼັກສັບຂຸດ',
    '🛠' => 'ໄມ້ຄ້ອນ ແລະ ກະແຈ',
    '🗡' => 'ດາບສັ້ນ',
    '⚔' => 'ດາບໄຂວ່ກັນ',
    '💣' => 'ລະເບີດ',
    '🪃' => 'ບູມເມີແລງ',
    '🏹' => 'ຄັນທະນູ ແລະ ລູກສອນ',
    '🛡' => 'ໂລ່ປ້ອງກັນ',
    '🪚' => 'ຊ່າງໄມ້',
    '🔧' => 'ປະແຈ',
    '🪛' => 'ໄຂຄວງ',
    '🔩' => 'ນັອດໂຕຜູ້ ແລະໂຕແມ່',
    '⚙' => 'ເຟືອງເກຍ',
    '🗜' => 'ເຄື່ອງບີບອັດ',
    '⚖' => 'ຕາຊິງ',
    '🦯' => 'ໄມ້​ຄັນ​ເທົ້າ​ນຳ​ທາງ',
    '🔗' => 'ຂໍ້ຕໍ່',
    '⛓' => 'ໂສ້',
    '🪝' => 'ຕະຂໍ',
    '🧰' => 'ກັບໃສ່ເຄື່ອງອຸປະກອນ',
    '🧲' => 'ພົງກິນເຫຼັກ',
    '🪜' => 'ຂັນໃດ',
    '🪏' => 'ຊວ້ານ',
    '⚗' => 'ພາຊະນະກັ່ນ',
    '🧪' => 'ຫຼອດທົດລອງ',
    '🧫' => 'ຖ້ວຍບັນຈຸທາດຫ້ອງທົດລອງ',
    '🧬' => 'DNA',
    '🔬' => 'ກ້ອງຈຸລະທັດ',
    '🔭' => 'ກ້ອງຊ່ອງທາງໄກ',
    '📡' => 'ເສົາອາກາດດາວທຽມ',
    '💉' => 'ຊະແລັງ',
    '🩸' => 'ຢົດ​ເລື​ອດ',
    '💊' => 'ເມັດຢາ',
    '🩹' => 'ຜ້າ​ພັນ​ບາດ​ແຜ',
    '🩼' => 'ໄມ້ຄໍ້າ',
    '🩺' => 'ຫູ​ຟັງ​ຂອງ​ແພດ',
    '🩻' => 'ສ່ອງໄຟຟ້າ',
    '🚪' => 'ປະຕູ',
    '🛗' => 'ລິບ',
    '🪞' => 'ແວ່ນ',
    '🪟' => 'ປ່ອງ​ຢ້ຽມ',
    '🛏' => 'ຕຽງນອນ',
    '🛋' => 'ໂຊຟາກັບໂຄມໄຟ',
    '🪑' => 'ຕັ່ງ',
    '🚽' => 'ວິດຖ່າຍ',
    '🪠' => 'ລູກສູບ',
    '🚿' => 'ຝັກບົວອາບນໍ້າ',
    '🛁' => 'ອ່າງອາບນໍ້າ',
    '🪤' => 'ກັບດັກໜູ',
    '🪒' => 'ມີດ​ແຖ',
    '🧴' => 'ຂວດໂລຊັ່ນ',
    '🧷' => 'ມຸດປັກກັນໄພ',
    '🧹' => 'ຟອຍປັດກວດ',
    '🧺' => 'ກະຕ່າ',
    '🧻' => 'ກໍ້ເຈ້ຍ',
    '🪣' => 'ຄຸ',
    '🧼' => 'ສະບູ',
    '🫧' => 'ຟອງສະບູ',
    '🪥' => 'ແປງຖູແຂ້ວ',
    '🧽' => 'ຟອງນ້ຳ',
    '🧯' => 'ເຕົ້່າດັບເຟີງ',
    '🛒' => 'ລົດເຂັນຊື້ເຄື່ອງ',
    '🚬' => 'ຢາສູບ',
    '⚰' => 'ໂລງສົບ',
    '🪦' => 'ສິລາເລີກ',
    '⚱' => 'ໂຖໃສ່ກະດູກ',
    '🧿' => 'ເຄື່ອງລາງຂອງຂັງ',
    '🪬' => 'ມືແຫ່ງການປົກປ້ອງ',
    '🗿' => 'ຮູບປັ້ນໂມໄອ',
    '🪧' => 'ປ້າຍປະກາດ',
    '🪪' => 'ບັດປະຈໍາຕົວ',
    '🏧' => 'ເອທີເອັມ',
    '🚮' => 'ຖິ້ມຂີ້ເຫຍື້ອໃສ່ຖັງ',
    '🚰' => 'ນໍ້າທີ່ດື່ມໄດ້',
    '♿' => 'ລົດນັ່ງຄົນພິການ',
    '🚹' => 'ຫ້ອງຜູ້ຊາຍ',
    '🚺' => 'ຫ້ອງແມ່ຍິງ',
    '🚻' => 'ຫ້ອງນໍ້າ',
    '🚼' => 'ສັນຍາລັກເດັກນ້ອຍ',
    '🚾' => 'ປ້າຍຫ້ອງນໍ້າ',
    '🛂' => 'ການຄວບຄຸມໜັງສືຜ່ານແດນ',
    '🛃' => 'ພາສີ',
    '🛄' => 'ບ່ອນເອົາກະເປົ໋າເດີນທາງ',
    '🛅' => 'ບໍລິການຝາກກະເປົ່າເດີນທາງ',
    '⚠' => 'ລະວັງ',
    '🚸' => 'ເດັກນ້ອຍຂ້າມທາງ',
    '⛔' => 'ຫ້າມເຂົ້າ',
    '🚫' => 'ຫ້າມຜ່ານ',
    '🚳' => 'ຫ້າມລົດຖີບ',
    '🚭' => 'ຫ້າມສູບຢາ',
    '🚯' => 'ຫ້າມຖິ້ມຂີ້ເຫຍື້ອ',
    '🚱' => 'ນໍ້າທີ່ດື່ມບໍ່ໄດ້',
    '🚷' => 'ຫ້າມຄົນຍ່າງ',
    '📵' => 'ຫ້າມໃຊ້ມືຖື',
    '🔞' => 'ຫ້າມອາຍຸຕໍ່າກວ່າ 18',
    '☢' => 'ກຳມັນຕະພາບລັງສີ',
    '☣' => 'ເຊື້ອພະຍາດອັນຕະລາຍ',
    '⬆' => 'ລູກສອນຂຶ້ນ',
    '↗' => 'ລູກສອນຂຶ້ນມຸມຂວາ',
    '➡' => 'ລູກສອນຂວາ',
    '↘' => 'ລູກສອນລົງມຸມຂວາ',
    '⬇' => 'ລູກສອນລົງ',
    '↙' => 'ລູກສອນລົງມຸມຊ້າຍ',
    '⬅' => 'ລູກສອນຊ້າຍ',
    '↖' => 'ລູກສອນຂຶ້ນມຸມຊ້າຍ',
    '↕' => 'ລູກສອນຂຶ້ນແລະລົງ',
    '↔' => 'ລູກສອນຊ້າຍຂວາ',
    '↩' => 'ລູກສອນໂຄ້ງຂວາໄປຊ້າຍ',
    '↪' => 'ລູກສອນໂຄ້ງຊ້າຍໄປຂວາ',
    '⤴' => 'ລູກສອນໂຄ້ງຂວາຂຶ້ນເທິງ',
    '⤵' => 'ລູກສອນໂຄ້ງຂວາລົງລຸ່ມ',
    '🔃' => 'ລູກສອນຕາມທິດເຂັມໂມງ',
    '🔄' => 'ລູກສອນທວນທິດເຂັມໂມງ',
    '🔙' => 'ລູກສອນກັບ',
    '🔚' => 'ລູກສອນສິ້ນສຸດ',
    '🔛' => 'ລູກສອນ ເປີດ!',
    '🔜' => 'ລູກສອນ ໄວໆນີ້',
    '🔝' => 'ລູກສອນຊີ້ຂຶ້ນ',
    '🛐' => 'ສະຖານທີ່ບູຊາ',
    '⚛' => 'ສັນຍາລັກອາຕອມ',
    '🕉' => 'ສັນຍາລັກໂອມ',
    '✡' => 'ຮູບດາວຫຼົກຫຼ່ຽມ',
    '☸' => 'ກົງລໍ້ແຫ່ງທຳມະ',
    '☯' => 'ຢິນຢາງ',
    '✝' => 'ໄມ້ກາງເຂນ',
    '☦' => 'ໄມ້ກາງເຂນໂອທໍດັອກ',
    '☪' => 'ພະຈັນສ້ຽວ ແລະ ດາວ',
    '☮' => 'ສັນຍາລັກສັນຕິພາບ',
    '🕎' => 'ສັນຍາລັກໂຄມປັກທຽນ',
    '🔯' => 'ດາວຫຼົກແຈມີຈໍ້າຢູ່ກາງ',
    '🪯' => 'ຄານດາ',
    '♈' => 'ລາສີເມກ',
    '♉' => 'ລາສີງົວ',
    '♊' => 'ລາສີເມຖຸນ',
    '♋' => 'ລາສີກົດ',
    '♌' => 'ລາສີສິງ',
    '♍' => 'ລາສີກັນ',
    '♎' => 'ລາສີຕຸລາ',
    '♏' => 'ລາສີພະຈິກ',
    '♐' => 'ລາສີທະນູ',
    '♑' => 'ລາສີມັງກອນ',
    '♒' => 'ລາສີກຸມ',
    '♓' => 'ລາສີມິນ',
    '⛎' => 'ລາສີງູ',
    '🔀' => 'ປຸ່ມສັບປ່ຽນແທຣັກ',
    '🔁' => 'ປຸ່ມຊໍ້າຄືນໄປມາ',
    '🔂' => 'ປຸ່ມຊໍ້າຄືນເທື່ອດຽວ',
    '▶' => 'ປຸ່ມຫຼິ້ນ',
    '⏩' => 'ປຸ່ມໄປໜ້າໄວ',
    '⏭' => 'ປຸ່ມໄປຫາແທຣັກຕໍ່ໄປ',
    '⏯' => 'ປຸ່ມຫຼິ້ນ ຫຼືຢຸດຊົ່ວຄາວ',
    '◀' => 'ປຸ່ມຖອຍຫຼັງ',
    '⏪' => 'ປຸ່ມຖອຍຫຼັງໄວ',
    '⏮' => 'ປຸ່ມໄປຫາແທຣັກກ່ອນນີ້',
    '🔼' => 'ປຸ່ມຂຶ້ນ',
    '⏫' => 'ປຸ່ມຂຶ້ນໄວ',
    '🔽' => 'ປຸ່ມລົງ',
    '⏬' => 'ປຸ່ມລົງໄວ',
    '⏸' => 'ປຸ່ມຢຸດໄວ້',
    '⏹' => 'ປຸ່ມຢຸດ',
    '⏺' => 'ປຸ່ມບັນທຶກ',
    '⏏' => 'ປຸ່ມດີດອອກ',
    '🎦' => 'ໂຮງຮູບເງົາ',
    '🔅' => 'ປຸ່ມປັບໃຫ້ມືດລົງ',
    '🔆' => 'ປຸ່ມປັບໃຫ້ສະຫວ່າງຂຶ້ນ',
    '📶' => 'ແຖບສັນຍານ',
    '🛜' => 'ໄຮ້ສາຍ',
    '📳' => 'ໂໝດສັ່ນ',
    '📴' => 'ປິດມືຖື',
    '♀' => 'ສັນຍາລັກຜູ້ຍິງ',
    '♂' => 'ສັນຍາລັກຜູ້ຊາຍ',
    '⚧' => 'ສັນຍາລັກຄົນ​ຂ້າມ​ເພດ',
    '✖' => 'ເຄື່ອງໝາຍຄູນ',
    '➕' => 'ເຄື່ອງໝາຍບວກ',
    '➖' => 'ເຄື່ອງໝາຍລົບ',
    '➗' => 'ຫານ',
    '🟰' => 'ເຄື່ອງໝາຍເທົ່າກັບ',
    '♾' => 'ອະສົງໄຂ',
    '‼' => 'ເຄື່ອງໝາຍທ້ວງຄູ່',
    '⁉' => 'ເຄື່ອງໝາຍທ້ວງກັບໝາຍຖາມ',
    '❓' => 'ເຄື່ອງໝາຍຖາມ',
    '❔' => 'ເຄື່ອງໝາຍຖາມສີຂາວ',
    '❕' => 'ເຄື່ອງໝາຍທ້ວງສີຂາວ',
    '❗' => 'ເຄື່ອງໝາຍທ້ວງ',
    '〰' => 'ເສັ້ນຄື້ນ',
    '💱' => 'ແລກປ່ຽນເງິນຕາ',
    '💲' => 'ສັນຍາລັກໂດລາໃຫຍ່ໜາ',
    '⚕' => 'ສັນຍາລັກການຢາ',
    '♻' => 'ສັນຍາລັກການນຳກັບມາໃຊ້ໃໝ່',
    '⚜' => 'ດອກໄອລິສ',
    '🔱' => 'ສະໝໍສາມງ່າມ',
    '📛' => 'ປ້າຍຊື່',
    '🔰' => 'ສັນຍາລັກຍີ່ປຸ່ນສຳລັບຜູ້ເລີ່ມຕົ້ນ',
    '⭕' => 'ວົງມົນເປັ​ນ​ຮູ​ສີ​ແດງ',
    '✅' => 'ເຄື່ອງໝາຍຕິກ',
    '☑' => 'ປ່ອງມີເຄື່ອງໝາຍຖືກ',
    '✔' => 'ເຄື່ອງໝາຍຕິກໃຫຍ່ໜາ',
    '❌' => 'ເຄື່ອງໝາຍກາກະບາດ',
    '❎' => 'ປຸ່ມເຄື່ອງໝາຍກາກະບາດ',
    '➰' => 'ຫ່ວງ',
    '➿' => 'ຫ່ວງຄູ່',
    '〽' => 'ເຄື່ອງໝາຍປ່ຽນສ່ວນ',
    '✳' => 'ເຄື່ອງໝາຍດອກຈັນ',
    '✴' => 'ດາວແປດແຈ',
    '❇' => 'ປະກາຍ',
    '™' => 'ເຄື່ອງໝາຍການຄ້າ',
    '🫟' => 'ສາດ',
    '🔠' => 'ປຸ່ມປ້ອນອັກສອນຕົວໃຫຍ່',
    '🔡' => 'ປຸ່ມປ້ອນອັກສອນຕົວນ້ອຍ',
    '🔢' => 'ປຸ່ມປ້ອນໝາຍເລກ',
    '🔣' => 'ປຸ່ມປ້ອນສັນຍາລັກ',
    '🔤' => 'ປຸ່ມປ້ອນອັກສອນລາຕິນ',
    '🅰' => 'ປຸ່ມ A',
    '🆎' => 'ປຸ່ມ AB',
    '🅱' => 'ປຸ່ມ B',
    '🆑' => 'ປຸ່ມ cl ສີ່ຫຼ່ຽມມົນທົນ',
    '🆒' => 'ປຸ່ມ cool',
    '🆓' => 'ປຸ່ມ free ສີ່ຫຼ່ຽມມົນທົນ',
    'ℹ' => 'ແຫຼ່ງຂໍ້ມູນ',
    '🆔' => 'ໝາຍເລກປະຈຳຕົວ',
    'Ⓜ' => 'ໂຕ m ໃນວົງມົນ',
    '🆕' => 'ໃໝ່',
    '🆖' => 'ປຸ່ມ NG',
    '🅾' => 'ເລືອກກຸ່ມໂອ',
    '🆗' => 'ຕົກລົງ',
    '🅿' => 'ບ່ອນຈອດລົດ',
    '🆘' => 'ຊ່ວຍແດ່',
    '🆙' => 'ຂຶ້ນ!',
    '🆚' => 'ຕໍ່ສູ້ກັບ',
    '🈁' => 'ພາສາຍີ່ປຸ່ນຢູ່ທີ່ນີ້',
    '🈂' => 'ພາສາຍີ່ປຸ່ນຄຳວ່າ ຊະ',
    '🈷' => 'ພາສາຍີ່ປຸ່ນຄຳວ່າ ພະຈັນ',
    '🈶' => 'ພາສາຍີ່ປຸ່ນຄຳວ່າ ມີ',
    '🈯' => 'ພາສາຍີ່ປຸ່ນຄຳວ່າ ຊີ້ນິ້ວ',
    '🉐' => 'ພາສາຍີ່ປຸ່ນຄຳວ່າ ປະໂຫຍດ',
    '🈹' => 'ພາສາຍີ່ປຸ່ນຄຳວ່າ ຫານ',
    '🈚' => 'ພາສາຍີ່ປຸ່ນຄຳວ່າ ບໍ່ມີ',
    '🈲' => 'ພາສາຍີ່ປຸ່ນຄຳວ່າ ຫ້າມ',
    '🉑' => 'ພາສາຈີນຄຳວ່າ ຍອມຮັບ',
    '🈸' => 'ພາສາຈີນຄຳວ່າ ໃຊ້',
    '🈴' => 'ພາສາຈີນຄຳວ່າ ຮ່ວມກັນ',
    '🈳' => 'ພາສາຈີນຄຳວ່າ ຫວ່າງເປົ່າ',
    '㊗' => 'ພາສາຈີນສະແດງຄວາມຍິນດີ',
    '㊙' => 'ພາສາຈີນຄຳວ່າ ຄວາມລັບ',
    '🈺' => 'ພາສາຈີນຄຳວ່າ ດຳເນີນງານ',
    '🈵' => 'ພາສາຈີນ ຄຳວ່າ ສົມບູນ',
    '🔴' => 'ວົງມົນແດງ',
    '🟠' => 'ວົງ​ມົນ​ສົ້ມ',
    '🟡' => 'ວົງ​ມົນ​ເຫຼືອງ',
    '🟢' => 'ວົງ​ມົນ​ຂຽວ',
    '🔵' => 'ວົງມົນຟ້າ',
    '🟣' => 'ວົງ​ມົນ​ມ່ວງ',
    '🟤' => 'ວົງ​ມົນ​ນ້ຳ​ຕານ',
    '⚫' => 'ວົງມົນດຳ',
    '⚪' => 'ວົງມົນຂາວ',
    '🟥' => 'ສີ່ຫຼ່ຽມ​ແດງ',
    '🟧' => 'ສີ່ຫຼ່ຽມ​ສົ້ມ',
    '🟨' => 'ສີ່ຫຼ່ຽມ​ເຫຼືອງ',
    '🟩' => 'ສີ່ຫຼ່ຽມ​ຂຽວ',
    '🟦' => 'ສີ່ຫຼ່ຽມ​ຟ້າ',
    '🟪' => 'ສີ່ຫຼ່ຽມ​ມ່ວງ',
    '🟫' => 'ສີ່ຫຼ່ຽມ​ນ້ຳ​ຕານ',
    '⬛' => 'ສີ່ຫຼ່ຽມໃຫຍ່ສີດຳ',
    '⬜' => 'ສີ່ຫຼ່ຽມໃຫຍ່ສີຂາວ',
    '◼' => 'ສີ່ຫຼ່ຽມປານກາງສີດຳ',
    '◻' => 'ສີ່ຫຼ່ຽມປານກາງສີຂາວ',
    '◾' => 'ສີ່ຫຼ່ຽມນ້ອຍ-ປານກາງສີດຳ',
    '◽' => 'ສີ່ຫຼ່ຽມນ້ອຍ-ປານກາງສີຂາວ',
    '▪' => 'ສີ່ຫຼ່ຽມນ້ອຍສີດໍາ',
    '▫' => 'ສີ່ຫຼ່ຽມນ້ອຍສີຂາວ',
    '🔶' => 'ຮູບເພັດສີໝາກກ້ຽງໃຫຍ່',
    '🔷' => 'ຮູບເພັດສີຟ້າໃຫຍ່',
    '🔸' => 'ຮູບເພັດສີໝາກກ້ຽງນ້ອຍ',
    '🔹' => 'ຮູບເພັດສີຟ້ານ້ອຍ',
    '🔺' => 'ຮູບສາມຫຼ່ຽມຫງາຍສີແດງ',
    '🔻' => 'ຮູບສາມຫຼ່ຽມຂວໍ້າສີແດງ',
    '💠' => 'ຮູບເພັດມີຈຸດ',
    '🔘' => 'ປຸ່ມວິທະຍຸ',
    '🔳' => 'ປຸ່ມສີ່ຫຼ່ຽມຂາວ',
    '🔲' => 'ປຸ່ມສີ່ຫຼ່ຽມດຳ',
    '🏁' => 'ທຸງລາຍດຳຂາວຕາກາໂຣ',
    '🚩' => 'ທຸງສາມຫຼ່ຽມ',
    '🎌' => 'ທຸງໄຂວ່ກັນ',
    '🏴' => 'ທຸງດຳທີ່ປິວສະບັດ',
    '🏳' => 'ທຸງຂາວທີ່ປິວສະບັດ',
];
