<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'skūpsts: pieaugušais, pieaugušais, gaišs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'skūpsts: pieaugušais, pieaugušais, gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'skūpsts: pieaugušais, pieaugušais, gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'skūpsts: pieaugušais, pieaugušais, gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'skūpsts: pieaugušais, pieaugušais, vidēji gaišs ādas tonis un gaišs ādas tonis',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'skūpsts: pieaugušais, pieaugušais, vidēji gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'skūpsts: pieaugušais, pieaugušais, vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'skūpsts: pieaugušais, pieaugušais, vidēji gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'skūpsts: pieaugušais, pieaugušais, vidējs ādas tonis un gaišs ādas tonis',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'skūpsts: pieaugušais, pieaugušais, vidējs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'skūpsts: pieaugušais, pieaugušais, vidējs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'skūpsts: pieaugušais, pieaugušais, vidējs ādas tonis un tumšs ādas tonis',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'skūpsts: pieaugušais, pieaugušais, vidēji tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'skūpsts: pieaugušais, pieaugušais, vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'skūpsts: pieaugušais, pieaugušais, vidēji tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'skūpsts: pieaugušais, pieaugušais, vidēji tumšs ādas tonis un tumšs ādas tonis',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'skūpsts: pieaugušais, pieaugušais, tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'skūpsts: pieaugušais, pieaugušais, tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'skūpsts: pieaugušais, pieaugušais, tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'skūpsts: pieaugušais, pieaugušais, tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏻‍❤‍💋‍👨🏻' => 'skūpsts: vīrietis, vīrietis un gaišs ādas tonis',
    '👨🏻‍❤‍💋‍👨🏼' => 'skūpsts: vīrietis, vīrietis, gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏻‍❤‍💋‍👨🏽' => 'skūpsts: vīrietis, vīrietis, gaišs ādas tonis un vidējs ādas tonis',
    '👨🏻‍❤‍💋‍👨🏾' => 'skūpsts: vīrietis, vīrietis, gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏻‍❤‍💋‍👨🏿' => 'skūpsts: vīrietis, vīrietis, gaišs ādas tonis un tumšs ādas tonis',
    '👨🏼‍❤‍💋‍👨🏻' => 'skūpsts: vīrietis, vīrietis, vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👨🏼‍❤‍💋‍👨🏼' => 'skūpsts: vīrietis, vīrietis un vidēji gaišs ādas tonis',
    '👨🏼‍❤‍💋‍👨🏽' => 'skūpsts: vīrietis, vīrietis, vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👨🏼‍❤‍💋‍👨🏾' => 'skūpsts: vīrietis, vīrietis, vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏼‍❤‍💋‍👨🏿' => 'skūpsts: vīrietis, vīrietis, vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👨🏽‍❤‍💋‍👨🏻' => 'skūpsts: vīrietis, vīrietis, vidējs ādas tonis un gaišs ādas tonis',
    '👨🏽‍❤‍💋‍👨🏼' => 'skūpsts: vīrietis, vīrietis, vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏽‍❤‍💋‍👨🏽' => 'skūpsts: vīrietis, vīrietis un vidējs ādas tonis',
    '👨🏽‍❤‍💋‍👨🏾' => 'skūpsts: vīrietis, vīrietis, vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏽‍❤‍💋‍👨🏿' => 'skūpsts: vīrietis, vīrietis, vidējs ādas tonis un tumšs ādas tonis',
    '👨🏾‍❤‍💋‍👨🏻' => 'skūpsts: vīrietis, vīrietis, vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👨🏾‍❤‍💋‍👨🏼' => 'skūpsts: vīrietis, vīrietis, vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏾‍❤‍💋‍👨🏽' => 'skūpsts: vīrietis, vīrietis, vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👨🏾‍❤‍💋‍👨🏾' => 'skūpsts: vīrietis, vīrietis un vidēji tumšs ādas tonis',
    '👨🏾‍❤‍💋‍👨🏿' => 'skūpsts: vīrietis, vīrietis, vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👨🏿‍❤‍💋‍👨🏻' => 'skūpsts: vīrietis, vīrietis, tumšs ādas tonis un gaišs ādas tonis',
    '👨🏿‍❤‍💋‍👨🏼' => 'skūpsts: vīrietis, vīrietis, tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏿‍❤‍💋‍👨🏽' => 'skūpsts: vīrietis, vīrietis, tumšs ādas tonis un vidējs ādas tonis',
    '👨🏿‍❤‍💋‍👨🏾' => 'skūpsts: vīrietis, vīrietis, tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏿‍❤‍💋‍👨🏿' => 'skūpsts: vīrietis, vīrietis un tumšs ādas tonis',
    '👩🏻‍❤‍💋‍👨🏻' => 'skūpsts: sieviete, vīrietis un gaišs ādas tonis',
    '👩🏻‍❤‍💋‍👨🏼' => 'skūpsts: sieviete, vīrietis, gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏻‍❤‍💋‍👨🏽' => 'skūpsts: sieviete, vīrietis, gaišs ādas tonis un vidējs ādas tonis',
    '👩🏻‍❤‍💋‍👨🏾' => 'skūpsts: sieviete, vīrietis, gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍❤‍💋‍👨🏿' => 'skūpsts: sieviete, vīrietis, gaišs ādas tonis un tumšs ādas tonis',
    '👩🏼‍❤‍💋‍👨🏻' => 'skūpsts: sieviete, vīrietis, vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👩🏼‍❤‍💋‍👨🏼' => 'skūpsts: sieviete, vīrietis un vidēji gaišs ādas tonis',
    '👩🏼‍❤‍💋‍👨🏽' => 'skūpsts: sieviete, vīrietis, vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👩🏼‍❤‍💋‍👨🏾' => 'skūpsts: sieviete, vīrietis, vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏼‍❤‍💋‍👨🏿' => 'skūpsts: sieviete, vīrietis, vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👩🏽‍❤‍💋‍👨🏻' => 'skūpsts: sieviete, vīrietis, vidējs ādas tonis un gaišs ādas tonis',
    '👩🏽‍❤‍💋‍👨🏼' => 'skūpsts: sieviete, vīrietis, vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏽‍❤‍💋‍👨🏽' => 'skūpsts: sieviete, vīrietis un vidējs ādas tonis',
    '👩🏽‍❤‍💋‍👨🏾' => 'skūpsts: sieviete, vīrietis, vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏽‍❤‍💋‍👨🏿' => 'skūpsts: sieviete, vīrietis, vidējs ādas tonis un tumšs ādas tonis',
    '👩🏾‍❤‍💋‍👨🏻' => 'skūpsts: sieviete, vīrietis, vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👩🏾‍❤‍💋‍👨🏼' => 'skūpsts: sieviete, vīrietis, vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏾‍❤‍💋‍👨🏽' => 'skūpsts: sieviete, vīrietis, vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👩🏾‍❤‍💋‍👨🏾' => 'skūpsts: sieviete, vīrietis un vidēji tumšs ādas tonis',
    '👩🏾‍❤‍💋‍👨🏿' => 'skūpsts: sieviete, vīrietis, vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👩🏿‍❤‍💋‍👨🏻' => 'skūpsts: sieviete, vīrietis, tumšs ādas tonis un gaišs ādas tonis',
    '👩🏿‍❤‍💋‍👨🏼' => 'skūpsts: sieviete, vīrietis, tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏿‍❤‍💋‍👨🏽' => 'skūpsts: sieviete, vīrietis, tumšs ādas tonis un vidējs ādas tonis',
    '👩🏿‍❤‍💋‍👨🏾' => 'skūpsts: sieviete, vīrietis, tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏿‍❤‍💋‍👨🏿' => 'skūpsts: sieviete, vīrietis un tumšs ādas tonis',
    '👩🏻‍❤‍💋‍👩🏻' => 'skūpsts: sieviete, sieviete un gaišs ādas tonis',
    '👩🏻‍❤‍💋‍👩🏼' => 'skūpsts: sieviete, sieviete, gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏻‍❤‍💋‍👩🏽' => 'skūpsts: sieviete, sieviete, gaišs ādas tonis un vidējs ādas tonis',
    '👩🏻‍❤‍💋‍👩🏾' => 'skūpsts: sieviete, sieviete, gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍❤‍💋‍👩🏿' => 'skūpsts: sieviete, sieviete, gaišs ādas tonis un tumšs ādas tonis',
    '👩🏼‍❤‍💋‍👩🏻' => 'skūpsts: sieviete, sieviete, vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👩🏼‍❤‍💋‍👩🏼' => 'skūpsts: sieviete, sieviete un vidēji gaišs ādas tonis',
    '👩🏼‍❤‍💋‍👩🏽' => 'skūpsts: sieviete, sieviete, vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👩🏼‍❤‍💋‍👩🏾' => 'skūpsts: sieviete, sieviete, vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏼‍❤‍💋‍👩🏿' => 'skūpsts: sieviete, sieviete, vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👩🏽‍❤‍💋‍👩🏻' => 'skūpsts: sieviete, sieviete, vidējs ādas tonis un gaišs ādas tonis',
    '👩🏽‍❤‍💋‍👩🏼' => 'skūpsts: sieviete, sieviete, vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏽‍❤‍💋‍👩🏽' => 'skūpsts: sieviete, sieviete un vidējs ādas tonis',
    '👩🏽‍❤‍💋‍👩🏾' => 'skūpsts: sieviete, sieviete, vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏽‍❤‍💋‍👩🏿' => 'skūpsts: sieviete, sieviete, vidējs ādas tonis un tumšs ādas tonis',
    '👩🏾‍❤‍💋‍👩🏻' => 'skūpsts: sieviete, sieviete, vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👩🏾‍❤‍💋‍👩🏼' => 'skūpsts: sieviete, sieviete, vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏾‍❤‍💋‍👩🏽' => 'skūpsts: sieviete, sieviete, vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👩🏾‍❤‍💋‍👩🏾' => 'skūpsts: sieviete, sieviete un vidēji tumšs ādas tonis',
    '👩🏾‍❤‍💋‍👩🏿' => 'skūpsts: sieviete, sieviete, vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👩🏿‍❤‍💋‍👩🏻' => 'skūpsts: sieviete, sieviete, tumšs ādas tonis un gaišs ādas tonis',
    '👩🏿‍❤‍💋‍👩🏼' => 'skūpsts: sieviete, sieviete, tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏿‍❤‍💋‍👩🏽' => 'skūpsts: sieviete, sieviete, tumšs ādas tonis un vidējs ādas tonis',
    '👩🏿‍❤‍💋‍👩🏾' => 'skūpsts: sieviete, sieviete, tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏿‍❤‍💋‍👩🏿' => 'skūpsts: sieviete, sieviete un tumšs ādas tonis',
    '🧑🏻‍🫯‍🧑🏼' => 'cīkstoņi: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏻‍🫯‍🧑🏽' => 'cīkstoņi: gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏻‍🫯‍🧑🏾' => 'cīkstoņi: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏻‍🫯‍🧑🏿' => 'cīkstoņi: gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏼‍🫯‍🧑🏻' => 'cīkstoņi: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '🧑🏼‍🫯‍🧑🏽' => 'cīkstoņi: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏼‍🫯‍🧑🏾' => 'cīkstoņi: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏼‍🫯‍🧑🏿' => 'cīkstoņi: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏽‍🫯‍🧑🏻' => 'cīkstoņi: vidējs ādas tonis un gaišs ādas tonis',
    '🧑🏽‍🫯‍🧑🏼' => 'cīkstoņi: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏽‍🫯‍🧑🏾' => 'cīkstoņi: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏽‍🫯‍🧑🏿' => 'cīkstoņi: vidējs ādas tonis un tumšs ādas tonis',
    '🧑🏾‍🫯‍🧑🏻' => 'cīkstoņi: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏾‍🫯‍🧑🏼' => 'cīkstoņi: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏾‍🫯‍🧑🏽' => 'cīkstoņi: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏾‍🫯‍🧑🏿' => 'cīkstoņi: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '🧑🏿‍🫯‍🧑🏻' => 'cīkstoņi: tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏿‍🫯‍🧑🏼' => 'cīkstoņi: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏿‍🫯‍🧑🏽' => 'cīkstoņi: tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏿‍🫯‍🧑🏾' => 'cīkstoņi: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏻‍❤‍🧑🏼' => 'pāris ar sirdi: pieaugušais, pieaugušais, gaišs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏻‍❤‍🧑🏽' => 'pāris ar sirdi: pieaugušais, pieaugušais, gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏻‍❤‍🧑🏾' => 'pāris ar sirdi: pieaugušais, pieaugušais, gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏻‍❤‍🧑🏿' => 'pāris ar sirdi: pieaugušais, pieaugušais, gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏼‍❤‍🧑🏻' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidēji gaišs ādas tonis un gaišs ādas tonis',
    '🧑🏼‍❤‍🧑🏽' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidēji gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏼‍❤‍🧑🏾' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏼‍❤‍🧑🏿' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidēji gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏽‍❤‍🧑🏻' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidējs ādas tonis un gaišs ādas tonis',
    '🧑🏽‍❤‍🧑🏼' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidējs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏽‍❤‍🧑🏾' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidējs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏽‍❤‍🧑🏿' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidējs ādas tonis un tumšs ādas tonis',
    '🧑🏾‍❤‍🧑🏻' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidēji tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏾‍❤‍🧑🏼' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏾‍❤‍🧑🏽' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidēji tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏾‍❤‍🧑🏿' => 'pāris ar sirdi: pieaugušais, pieaugušais, vidēji tumšs ādas tonis un tumšs ādas tonis',
    '🧑🏿‍❤‍🧑🏻' => 'pāris ar sirdi: pieaugušais, pieaugušais, tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏿‍❤‍🧑🏼' => 'pāris ar sirdi: pieaugušais, pieaugušais, tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏿‍❤‍🧑🏽' => 'pāris ar sirdi: pieaugušais, pieaugušais, tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏿‍❤‍🧑🏾' => 'pāris ar sirdi: pieaugušais, pieaugušais, tumšs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏻‍🐰‍🧑🏼' => 'dejotāju šovs: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏻‍🐰‍🧑🏽' => 'dejotāju šovs: gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏻‍🐰‍🧑🏾' => 'dejotāju šovs: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏻‍🐰‍🧑🏿' => 'dejotāju šovs: gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏼‍🐰‍🧑🏻' => 'dejotāju šovs: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '🧑🏼‍🐰‍🧑🏽' => 'dejotāju šovs: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏼‍🐰‍🧑🏾' => 'dejotāju šovs: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏼‍🐰‍🧑🏿' => 'dejotāju šovs: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏽‍🐰‍🧑🏻' => 'dejotāju šovs: vidējs ādas tonis un gaišs ādas tonis',
    '🧑🏽‍🐰‍🧑🏼' => 'dejotāju šovs: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏽‍🐰‍🧑🏾' => 'dejotāju šovs: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏽‍🐰‍🧑🏿' => 'dejotāju šovs: vidējs ādas tonis un tumšs ādas tonis',
    '🧑🏾‍🐰‍🧑🏻' => 'dejotāju šovs: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏾‍🐰‍🧑🏼' => 'dejotāju šovs: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏾‍🐰‍🧑🏽' => 'dejotāju šovs: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏾‍🐰‍🧑🏿' => 'dejotāju šovs: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '🧑🏿‍🐰‍🧑🏻' => 'dejotāju šovs: tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏿‍🐰‍🧑🏼' => 'dejotāju šovs: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏿‍🐰‍🧑🏽' => 'dejotāju šovs: tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏿‍🐰‍🧑🏾' => 'dejotāju šovs: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏻‍🫯‍👨🏼' => 'cīkstonis: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏻‍🫯‍👨🏽' => 'cīkstonis: gaišs ādas tonis un vidējs ādas tonis',
    '👨🏻‍🫯‍👨🏾' => 'cīkstonis: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏻‍🫯‍👨🏿' => 'cīkstonis: gaišs ādas tonis un tumšs ādas tonis',
    '👨🏼‍🫯‍👨🏻' => 'cīkstonis: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👨🏼‍🫯‍👨🏽' => 'cīkstonis: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👨🏼‍🫯‍👨🏾' => 'cīkstonis: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏼‍🫯‍👨🏿' => 'cīkstonis: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👨🏽‍🫯‍👨🏻' => 'cīkstonis: vidējs ādas tonis un gaišs ādas tonis',
    '👨🏽‍🫯‍👨🏼' => 'cīkstonis: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏽‍🫯‍👨🏾' => 'cīkstonis: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏽‍🫯‍👨🏿' => 'cīkstonis: vidējs ādas tonis un tumšs ādas tonis',
    '👨🏾‍🫯‍👨🏻' => 'cīkstonis: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👨🏾‍🫯‍👨🏼' => 'cīkstonis: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏾‍🫯‍👨🏽' => 'cīkstonis: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👨🏾‍🫯‍👨🏿' => 'cīkstonis: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👨🏿‍🫯‍👨🏻' => 'cīkstonis: tumšs ādas tonis un gaišs ādas tonis',
    '👨🏿‍🫯‍👨🏼' => 'cīkstonis: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏿‍🫯‍👨🏽' => 'cīkstonis: tumšs ādas tonis un vidējs ādas tonis',
    '👨🏿‍🫯‍👨🏾' => 'cīkstonis: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏻‍❤‍👨🏻' => 'pāris ar sirdi: vīrietis, vīrietis un gaišs ādas tonis',
    '👨🏻‍❤‍👨🏼' => 'pāris ar sirdi: vīrietis, vīrietis, gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏻‍❤‍👨🏽' => 'pāris ar sirdi: vīrietis, vīrietis, gaišs ādas tonis un vidējs ādas tonis',
    '👨🏻‍❤‍👨🏾' => 'pāris ar sirdi: vīrietis, vīrietis, gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏻‍❤‍👨🏿' => 'pāris ar sirdi: vīrietis, vīrietis, gaišs ādas tonis un tumšs ādas tonis',
    '👨🏼‍❤‍👨🏻' => 'pāris ar sirdi: vīrietis, vīrietis, vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👨🏼‍❤‍👨🏼' => 'pāris ar sirdi: vīrietis, vīrietis un vidēji gaišs ādas tonis',
    '👨🏼‍❤‍👨🏽' => 'pāris ar sirdi: vīrietis, vīrietis, vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👨🏼‍❤‍👨🏾' => 'pāris ar sirdi: vīrietis, vīrietis, vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏼‍❤‍👨🏿' => 'pāris ar sirdi: vīrietis, vīrietis, vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👨🏽‍❤‍👨🏻' => 'pāris ar sirdi: vīrietis, vīrietis, vidējs ādas tonis un gaišs ādas tonis',
    '👨🏽‍❤‍👨🏼' => 'pāris ar sirdi: vīrietis, vīrietis, vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏽‍❤‍👨🏽' => 'pāris ar sirdi: vīrietis, vīrietis un vidējs ādas tonis',
    '👨🏽‍❤‍👨🏾' => 'pāris ar sirdi: vīrietis, vīrietis, vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏽‍❤‍👨🏿' => 'pāris ar sirdi: vīrietis, vīrietis, vidējs ādas tonis un tumšs ādas tonis',
    '👨🏾‍❤‍👨🏻' => 'pāris ar sirdi: vīrietis, vīrietis, vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👨🏾‍❤‍👨🏼' => 'pāris ar sirdi: vīrietis, vīrietis, vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏾‍❤‍👨🏽' => 'pāris ar sirdi: vīrietis, vīrietis, vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👨🏾‍❤‍👨🏾' => 'pāris ar sirdi: vīrietis, vīrietis un vidēji tumšs ādas tonis',
    '👨🏾‍❤‍👨🏿' => 'pāris ar sirdi: vīrietis, vīrietis, vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👨🏿‍❤‍👨🏻' => 'pāris ar sirdi: vīrietis, vīrietis, tumšs ādas tonis un gaišs ādas tonis',
    '👨🏿‍❤‍👨🏼' => 'pāris ar sirdi: vīrietis, vīrietis, tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏿‍❤‍👨🏽' => 'pāris ar sirdi: vīrietis, vīrietis, tumšs ādas tonis un vidējs ādas tonis',
    '👨🏿‍❤‍👨🏾' => 'pāris ar sirdi: vīrietis, vīrietis, tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏿‍❤‍👨🏿' => 'pāris ar sirdi: vīrietis, vīrietis un tumšs ādas tonis',
    '👨🏻‍🐰‍👨🏼' => 'dejotāji: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏻‍🐰‍👨🏽' => 'dejotāji: gaišs ādas tonis un vidējs ādas tonis',
    '👨🏻‍🐰‍👨🏾' => 'dejotāji: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏻‍🐰‍👨🏿' => 'dejotāji: gaišs ādas tonis un tumšs ādas tonis',
    '👨🏼‍🐰‍👨🏻' => 'dejotāji: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👨🏼‍🐰‍👨🏽' => 'dejotāji: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👨🏼‍🐰‍👨🏾' => 'dejotāji: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏼‍🐰‍👨🏿' => 'dejotāji: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👨🏽‍🐰‍👨🏻' => 'dejotāji: vidējs ādas tonis un gaišs ādas tonis',
    '👨🏽‍🐰‍👨🏼' => 'dejotāji: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏽‍🐰‍👨🏾' => 'dejotāji: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏽‍🐰‍👨🏿' => 'dejotāji: vidējs ādas tonis un tumšs ādas tonis',
    '👨🏾‍🐰‍👨🏻' => 'dejotāji: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👨🏾‍🐰‍👨🏼' => 'dejotāji: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏾‍🐰‍👨🏽' => 'dejotāji: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👨🏾‍🐰‍👨🏿' => 'dejotāji: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👨🏿‍🐰‍👨🏻' => 'dejotāji: tumšs ādas tonis un gaišs ādas tonis',
    '👨🏿‍🐰‍👨🏼' => 'dejotāji: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏿‍🐰‍👨🏽' => 'dejotāji: tumšs ādas tonis un vidējs ādas tonis',
    '👨🏿‍🐰‍👨🏾' => 'dejotāji: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍🫯‍👩🏼' => 'cīkstone: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏻‍🫯‍👩🏽' => 'cīkstone: gaišs ādas tonis un vidējs ādas tonis',
    '👩🏻‍🫯‍👩🏾' => 'cīkstone: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍🫯‍👩🏿' => 'cīkstone: gaišs ādas tonis un tumšs ādas tonis',
    '👩🏼‍🫯‍👩🏻' => 'cīkstone: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👩🏼‍🫯‍👩🏽' => 'cīkstone: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👩🏼‍🫯‍👩🏾' => 'cīkstone: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏼‍🫯‍👩🏿' => 'cīkstone: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👩🏽‍🫯‍👩🏻' => 'cīkstone: vidējs ādas tonis un gaišs ādas tonis',
    '👩🏽‍🫯‍👩🏼' => 'cīkstone: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏽‍🫯‍👩🏾' => 'cīkstone: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏽‍🫯‍👩🏿' => 'cīkstone: vidējs ādas tonis un tumšs ādas tonis',
    '👩🏾‍🫯‍👩🏻' => 'cīkstone: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👩🏾‍🫯‍👩🏼' => 'cīkstone: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏾‍🫯‍👩🏽' => 'cīkstone: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👩🏾‍🫯‍👩🏿' => 'cīkstone: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👩🏿‍🫯‍👩🏻' => 'cīkstone: tumšs ādas tonis un gaišs ādas tonis',
    '👩🏿‍🫯‍👩🏼' => 'cīkstone: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏿‍🫯‍👩🏽' => 'cīkstone: tumšs ādas tonis un vidējs ādas tonis',
    '👩🏿‍🫯‍👩🏾' => 'cīkstone: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍❤‍👨🏻' => 'pāris ar sirdi: sieviete, vīrietis un gaišs ādas tonis',
    '👩🏻‍❤‍👨🏼' => 'pāris ar sirdi: sieviete, vīrietis, gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏻‍❤‍👨🏽' => 'pāris ar sirdi: sieviete, vīrietis, gaišs ādas tonis un vidējs ādas tonis',
    '👩🏻‍❤‍👨🏾' => 'pāris ar sirdi: sieviete, vīrietis, gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍❤‍👨🏿' => 'pāris ar sirdi: sieviete, vīrietis, gaišs ādas tonis un tumšs ādas tonis',
    '👩🏼‍❤‍👨🏻' => 'pāris ar sirdi: sieviete, vīrietis, vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👩🏼‍❤‍👨🏼' => 'pāris ar sirdi: sieviete, vīrietis un vidēji gaišs ādas tonis',
    '👩🏼‍❤‍👨🏽' => 'pāris ar sirdi: sieviete, vīrietis, vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👩🏼‍❤‍👨🏾' => 'pāris ar sirdi: sieviete, vīrietis, vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏼‍❤‍👨🏿' => 'pāris ar sirdi: sieviete, vīrietis, vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👩🏽‍❤‍👨🏻' => 'pāris ar sirdi: sieviete, vīrietis, vidējs ādas tonis un gaišs ādas tonis',
    '👩🏽‍❤‍👨🏼' => 'pāris ar sirdi: sieviete, vīrietis, vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏽‍❤‍👨🏽' => 'pāris ar sirdi: sieviete, vīrietis un vidējs ādas tonis',
    '👩🏽‍❤‍👨🏾' => 'pāris ar sirdi: sieviete, vīrietis, vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏽‍❤‍👨🏿' => 'pāris ar sirdi: sieviete, vīrietis, vidējs ādas tonis un tumšs ādas tonis',
    '👩🏾‍❤‍👨🏻' => 'pāris ar sirdi: sieviete, vīrietis, vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👩🏾‍❤‍👨🏼' => 'pāris ar sirdi: sieviete, vīrietis, vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏾‍❤‍👨🏽' => 'pāris ar sirdi: sieviete, vīrietis, vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👩🏾‍❤‍👨🏾' => 'pāris ar sirdi: sieviete, vīrietis un vidēji tumšs ādas tonis',
    '👩🏾‍❤‍👨🏿' => 'pāris ar sirdi: sieviete, vīrietis, vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👩🏿‍❤‍👨🏻' => 'pāris ar sirdi: sieviete, vīrietis, tumšs ādas tonis un gaišs ādas tonis',
    '👩🏿‍❤‍👨🏼' => 'pāris ar sirdi: sieviete, vīrietis, tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏿‍❤‍👨🏽' => 'pāris ar sirdi: sieviete, vīrietis, tumšs ādas tonis un vidējs ādas tonis',
    '👩🏿‍❤‍👨🏾' => 'pāris ar sirdi: sieviete, vīrietis, tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏿‍❤‍👨🏿' => 'pāris ar sirdi: sieviete, vīrietis un tumšs ādas tonis',
    '👩🏻‍❤‍👩🏻' => 'pāris ar sirdi: sieviete, sieviete un gaišs ādas tonis',
    '👩🏻‍❤‍👩🏼' => 'pāris ar sirdi: sieviete, sieviete, gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏻‍❤‍👩🏽' => 'pāris ar sirdi: sieviete, sieviete, gaišs ādas tonis un vidējs ādas tonis',
    '👩🏻‍❤‍👩🏾' => 'pāris ar sirdi: sieviete, sieviete, gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍❤‍👩🏿' => 'pāris ar sirdi: sieviete, sieviete, gaišs ādas tonis un tumšs ādas tonis',
    '👩🏼‍❤‍👩🏻' => 'pāris ar sirdi: sieviete, sieviete, vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👩🏼‍❤‍👩🏼' => 'pāris ar sirdi: sieviete, sieviete un vidēji gaišs ādas tonis',
    '👩🏼‍❤‍👩🏽' => 'pāris ar sirdi: sieviete, sieviete, vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👩🏼‍❤‍👩🏾' => 'pāris ar sirdi: sieviete, sieviete, vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏼‍❤‍👩🏿' => 'pāris ar sirdi: sieviete, sieviete, vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👩🏽‍❤‍👩🏻' => 'pāris ar sirdi: sieviete, sieviete, vidējs ādas tonis un gaišs ādas tonis',
    '👩🏽‍❤‍👩🏼' => 'pāris ar sirdi: sieviete, sieviete, vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏽‍❤‍👩🏽' => 'pāris ar sirdi: sieviete, sieviete un vidējs ādas tonis',
    '👩🏽‍❤‍👩🏾' => 'pāris ar sirdi: sieviete, sieviete, vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏽‍❤‍👩🏿' => 'pāris ar sirdi: sieviete, sieviete, vidējs ādas tonis un tumšs ādas tonis',
    '👩🏾‍❤‍👩🏻' => 'pāris ar sirdi: sieviete, sieviete, vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👩🏾‍❤‍👩🏼' => 'pāris ar sirdi: sieviete, sieviete, vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏾‍❤‍👩🏽' => 'pāris ar sirdi: sieviete, sieviete, vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👩🏾‍❤‍👩🏾' => 'pāris ar sirdi: sieviete, sieviete un vidēji tumšs ādas tonis',
    '👩🏾‍❤‍👩🏿' => 'pāris ar sirdi: sieviete, sieviete, vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👩🏿‍❤‍👩🏻' => 'pāris ar sirdi: sieviete, sieviete, tumšs ādas tonis un gaišs ādas tonis',
    '👩🏿‍❤‍👩🏼' => 'pāris ar sirdi: sieviete, sieviete, tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏿‍❤‍👩🏽' => 'pāris ar sirdi: sieviete, sieviete, tumšs ādas tonis un vidējs ādas tonis',
    '👩🏿‍❤‍👩🏾' => 'pāris ar sirdi: sieviete, sieviete, tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏿‍❤‍👩🏿' => 'pāris ar sirdi: sieviete, sieviete un tumšs ādas tonis',
    '👩🏻‍🐰‍👩🏼' => 'dejotājas: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏻‍🐰‍👩🏽' => 'dejotājas: gaišs ādas tonis un vidējs ādas tonis',
    '👩🏻‍🐰‍👩🏾' => 'dejotājas: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍🐰‍👩🏿' => 'dejotājas: gaišs ādas tonis un tumšs ādas tonis',
    '👩🏼‍🐰‍👩🏻' => 'dejotājas: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👩🏼‍🐰‍👩🏽' => 'dejotājas: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👩🏼‍🐰‍👩🏾' => 'dejotājas: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏼‍🐰‍👩🏿' => 'dejotājas: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👩🏽‍🐰‍👩🏻' => 'dejotājas: vidējs ādas tonis un gaišs ādas tonis',
    '👩🏽‍🐰‍👩🏼' => 'dejotājas: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏽‍🐰‍👩🏾' => 'dejotājas: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏽‍🐰‍👩🏿' => 'dejotājas: vidējs ādas tonis un tumšs ādas tonis',
    '👩🏾‍🐰‍👩🏻' => 'dejotājas: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👩🏾‍🐰‍👩🏼' => 'dejotājas: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏾‍🐰‍👩🏽' => 'dejotājas: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👩🏾‍🐰‍👩🏿' => 'dejotājas: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👩🏿‍🐰‍👩🏻' => 'dejotājas: tumšs ādas tonis un gaišs ādas tonis',
    '👩🏿‍🐰‍👩🏼' => 'dejotājas: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏿‍🐰‍👩🏽' => 'dejotājas: tumšs ādas tonis un vidējs ādas tonis',
    '👩🏿‍🐰‍👩🏾' => 'dejotājas: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏻‍🤝‍🧑🏻' => 'cilvēki sadevušies rokās: gaišs ādas tonis',
    '🧑🏻‍🤝‍🧑🏼' => 'cilvēki sadevušies rokās: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏻‍🤝‍🧑🏽' => 'cilvēki sadevušies rokās: gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏻‍🤝‍🧑🏾' => 'cilvēki sadevušies rokās: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏻‍🤝‍🧑🏿' => 'cilvēki sadevušies rokās: gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏼‍🤝‍🧑🏻' => 'cilvēki sadevušies rokās: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '🧑🏼‍🤝‍🧑🏼' => 'cilvēki sadevušies rokās: vidēji gaišs ādas tonis',
    '🧑🏼‍🤝‍🧑🏽' => 'cilvēki sadevušies rokās: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '🧑🏼‍🤝‍🧑🏾' => 'cilvēki sadevušies rokās: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏼‍🤝‍🧑🏿' => 'cilvēki sadevušies rokās: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '🧑🏽‍🤝‍🧑🏻' => 'cilvēki sadevušies rokās: vidējs ādas tonis un gaišs ādas tonis',
    '🧑🏽‍🤝‍🧑🏼' => 'cilvēki sadevušies rokās: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏽‍🤝‍🧑🏽' => 'cilvēki sadevušies rokās: vidējs ādas tonis',
    '🧑🏽‍🤝‍🧑🏾' => 'cilvēki sadevušies rokās: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏽‍🤝‍🧑🏿' => 'cilvēki sadevušies rokās: vidējs ādas tonis un tumšs ādas tonis',
    '🧑🏾‍🤝‍🧑🏻' => 'cilvēki sadevušies rokās: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏾‍🤝‍🧑🏼' => 'cilvēki sadevušies rokās: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏾‍🤝‍🧑🏽' => 'cilvēki sadevušies rokās: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏾‍🤝‍🧑🏾' => 'cilvēki sadevušies rokās: vidēji tumšs ādas tonis',
    '🧑🏾‍🤝‍🧑🏿' => 'cilvēki sadevušies rokās: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '🧑🏿‍🤝‍🧑🏻' => 'cilvēki sadevušies rokās: tumšs ādas tonis un gaišs ādas tonis',
    '🧑🏿‍🤝‍🧑🏼' => 'cilvēki sadevušies rokās: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🧑🏿‍🤝‍🧑🏽' => 'cilvēki sadevušies rokās: tumšs ādas tonis un vidējs ādas tonis',
    '🧑🏿‍🤝‍🧑🏾' => 'cilvēki sadevušies rokās: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '🧑🏿‍🤝‍🧑🏿' => 'cilvēki sadevušies rokās: tumšs ādas tonis',
    '👩🏻‍🤝‍👩🏼' => 'sievietes sadevušās rokās: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏻‍🤝‍👩🏽' => 'sievietes sadevušās rokās: gaišs ādas tonis un vidējs ādas tonis',
    '👩🏻‍🤝‍👩🏾' => 'sievietes sadevušās rokās: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍🤝‍👩🏿' => 'sievietes sadevušās rokās: gaišs ādas tonis un tumšs ādas tonis',
    '👩🏼‍🤝‍👩🏻' => 'sievietes sadevušās rokās: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👩🏼‍🤝‍👩🏽' => 'sievietes sadevušās rokās: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👩🏼‍🤝‍👩🏾' => 'sievietes sadevušās rokās: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏼‍🤝‍👩🏿' => 'sievietes sadevušās rokās: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👩🏽‍🤝‍👩🏻' => 'sievietes sadevušās rokās: vidējs ādas tonis un gaišs ādas tonis',
    '👩🏽‍🤝‍👩🏼' => 'sievietes sadevušās rokās: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏽‍🤝‍👩🏾' => 'sievietes sadevušās rokās: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏽‍🤝‍👩🏿' => 'sievietes sadevušās rokās: vidējs ādas tonis un tumšs ādas tonis',
    '👩🏾‍🤝‍👩🏻' => 'sievietes sadevušās rokās: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👩🏾‍🤝‍👩🏼' => 'sievietes sadevušās rokās: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏾‍🤝‍👩🏽' => 'sievietes sadevušās rokās: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👩🏾‍🤝‍👩🏿' => 'sievietes sadevušās rokās: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👩🏿‍🤝‍👩🏻' => 'sievietes sadevušās rokās: tumšs ādas tonis un gaišs ādas tonis',
    '👩🏿‍🤝‍👩🏼' => 'sievietes sadevušās rokās: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏿‍🤝‍👩🏽' => 'sievietes sadevušās rokās: tumšs ādas tonis un vidējs ādas tonis',
    '👩🏿‍🤝‍👩🏾' => 'sievietes sadevušās rokās: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍🤝‍👨🏼' => 'sieviete un vīrietis sadevušies rokās: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏻‍🤝‍👨🏽' => 'sieviete un vīrietis sadevušies rokās: gaišs ādas tonis un vidējs ādas tonis',
    '👩🏻‍🤝‍👨🏾' => 'sieviete un vīrietis sadevušies rokās: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏻‍🤝‍👨🏿' => 'sieviete un vīrietis sadevušies rokās: gaišs ādas tonis un tumšs ādas tonis',
    '👩🏼‍🤝‍👨🏻' => 'sieviete un vīrietis sadevušies rokās: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👩🏼‍🤝‍👨🏽' => 'sieviete un vīrietis sadevušies rokās: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👩🏼‍🤝‍👨🏾' => 'sieviete un vīrietis sadevušies rokās: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏼‍🤝‍👨🏿' => 'sieviete un vīrietis sadevušies rokās: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👩🏽‍🤝‍👨🏻' => 'sieviete un vīrietis sadevušies rokās: vidējs ādas tonis un gaišs ādas tonis',
    '👩🏽‍🤝‍👨🏼' => 'sieviete un vīrietis sadevušies rokās: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏽‍🤝‍👨🏾' => 'sieviete un vīrietis sadevušies rokās: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👩🏽‍🤝‍👨🏿' => 'sieviete un vīrietis sadevušies rokās: vidējs ādas tonis un tumšs ādas tonis',
    '👩🏾‍🤝‍👨🏻' => 'sieviete un vīrietis sadevušies rokās: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👩🏾‍🤝‍👨🏼' => 'sieviete un vīrietis sadevušies rokās: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏾‍🤝‍👨🏽' => 'sieviete un vīrietis sadevušies rokās: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👩🏾‍🤝‍👨🏿' => 'sieviete un vīrietis sadevušies rokās: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👩🏿‍🤝‍👨🏻' => 'sieviete un vīrietis sadevušies rokās: tumšs ādas tonis un gaišs ādas tonis',
    '👩🏿‍🤝‍👨🏼' => 'sieviete un vīrietis sadevušies rokās: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👩🏿‍🤝‍👨🏽' => 'sieviete un vīrietis sadevušies rokās: tumšs ādas tonis un vidējs ādas tonis',
    '👩🏿‍🤝‍👨🏾' => 'sieviete un vīrietis sadevušies rokās: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏻‍🤝‍👨🏼' => 'vīrieši sadevušies rokās: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏻‍🤝‍👨🏽' => 'vīrieši sadevušies rokās: gaišs ādas tonis un vidējs ādas tonis',
    '👨🏻‍🤝‍👨🏾' => 'vīrieši sadevušies rokās: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏻‍🤝‍👨🏿' => 'vīrieši sadevušies rokās: gaišs ādas tonis un tumšs ādas tonis',
    '👨🏼‍🤝‍👨🏻' => 'vīrieši sadevušies rokās: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '👨🏼‍🤝‍👨🏽' => 'vīrieši sadevušies rokās: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '👨🏼‍🤝‍👨🏾' => 'vīrieši sadevušies rokās: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏼‍🤝‍👨🏿' => 'vīrieši sadevušies rokās: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '👨🏽‍🤝‍👨🏻' => 'vīrieši sadevušies rokās: vidējs ādas tonis un gaišs ādas tonis',
    '👨🏽‍🤝‍👨🏼' => 'vīrieši sadevušies rokās: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏽‍🤝‍👨🏾' => 'vīrieši sadevušies rokās: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '👨🏽‍🤝‍👨🏿' => 'vīrieši sadevušies rokās: vidējs ādas tonis un tumšs ādas tonis',
    '👨🏾‍🤝‍👨🏻' => 'vīrieši sadevušies rokās: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '👨🏾‍🤝‍👨🏼' => 'vīrieši sadevušies rokās: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏾‍🤝‍👨🏽' => 'vīrieši sadevušies rokās: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '👨🏾‍🤝‍👨🏿' => 'vīrieši sadevušies rokās: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '👨🏿‍🤝‍👨🏻' => 'vīrieši sadevušies rokās: tumšs ādas tonis un gaišs ādas tonis',
    '👨🏿‍🤝‍👨🏼' => 'vīrieši sadevušies rokās: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '👨🏿‍🤝‍👨🏽' => 'vīrieši sadevušies rokās: tumšs ādas tonis un vidējs ādas tonis',
    '👨🏿‍🤝‍👨🏾' => 'vīrieši sadevušies rokās: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '👩‍❤‍💋‍👨' => 'skūpsts: sieviete un vīrietis',
    '👨‍❤‍💋‍👨' => 'skūpsts: vīrietis un vīrietis',
    '👩‍❤‍💋‍👩' => 'skūpsts: sieviete un sieviete',
    '👨‍👩‍👧‍👦' => 'ģimene: vīrietis, sieviete, meitene un zēns',
    '👨‍👩‍👦‍👦' => 'ģimene: vīrietis, sieviete, zēns un zēns',
    '👨‍👩‍👧‍👧' => 'ģimene: vīrietis, sieviete, meitene un meitene',
    '👨‍👨‍👧‍👦' => 'ģimene: vīrietis, vīrietis, meitene un zēns',
    '👨‍👨‍👦‍👦' => 'ģimene: vīrietis, vīrietis, zēns un zēns',
    '👨‍👨‍👧‍👧' => 'ģimene: vīrietis, vīrietis, meitene un meitene',
    '👩‍👩‍👧‍👦' => 'ģimene: sieviete, sieviete, meitene un zēns',
    '👩‍👩‍👦‍👦' => 'ģimene: sieviete, sieviete, zēns un zēns',
    '👩‍👩‍👧‍👧' => 'ģimene: sieviete, sieviete, meitene un meitene',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'karogs: Anglija',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'karogs: Skotija',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'karogs: Velsa',
    '🧑‍🧑‍🧒‍🧒' => 'ģimene: pieaugušais, pieaugušais, bērns, bērns',
    '🚶🏻‍♀‍➡' => 'sieviete pastaigājas: gaišs ādas tonis un skatās pa labi',
    '🚶🏼‍♀‍➡' => 'sieviete pastaigājas: vidēji gaišs ādas tonis un skatās pa labi',
    '🚶🏽‍♀‍➡' => 'sieviete pastaigājas: vidējs ādas tonis un skatās pa labi',
    '🚶🏾‍♀‍➡' => 'sieviete pastaigājas: vidēji tumšs ādas tonis un skatās pa labi',
    '🚶🏿‍♀‍➡' => 'sieviete pastaigājas: tumšs ādas tonis un skatās pa labi',
    '🚶🏻‍♂‍➡' => 'vīrietis pastaigājas: gaišs ādas tonis un skatās pa labi',
    '🚶🏼‍♂‍➡' => 'vīrietis pastaigājas: vidēji gaišs ādas tonis un skatās pa labi',
    '🚶🏽‍♂‍➡' => 'vīrietis pastaigājas: vidējs ādas tonis un skatās pa labi',
    '🚶🏾‍♂‍➡' => 'vīrietis pastaigājas: vidēji tumšs ādas tonis un skatās pa labi',
    '🚶🏿‍♂‍➡' => 'vīrietis pastaigājas: tumšs ādas tonis un skatās pa labi',
    '🧎🏻‍♀‍➡' => 'sieviete uz ceļiem: gaišs ādas tonis un skatās pa labi',
    '🧎🏼‍♀‍➡' => 'sieviete uz ceļiem: vidēji gaišs ādas tonis un skatās pa labi',
    '🧎🏽‍♀‍➡' => 'sieviete uz ceļiem: vidējs ādas tonis un skatās pa labi',
    '🧎🏾‍♀‍➡' => 'sieviete uz ceļiem: vidēji tumšs ādas tonis un skatās pa labi',
    '🧎🏿‍♀‍➡' => 'sieviete uz ceļiem: tumšs ādas tonis un skatās pa labi',
    '🧎🏻‍♂‍➡' => 'vīrietis uz ceļiem: gaišs ādas tonis un skatās pa labi',
    '🧎🏼‍♂‍➡' => 'vīrietis uz ceļiem: vidēji gaišs ādas tonis un skatās pa labi',
    '🧎🏽‍♂‍➡' => 'vīrietis uz ceļiem: vidējs ādas tonis un skatās pa labi',
    '🧎🏾‍♂‍➡' => 'vīrietis uz ceļiem: vidēji tumšs ādas tonis un skatās pa labi',
    '🧎🏿‍♂‍➡' => 'vīrietis uz ceļiem: tumšs ādas tonis un skatās pa labi',
    '🧑🏻‍🦯‍➡' => 'persona ar balto spieķi: gaišs ādas tonis un skatās pa labi',
    '🧑🏼‍🦯‍➡' => 'persona ar balto spieķi: vidēji gaišs ādas tonis un skatās pa labi',
    '🧑🏽‍🦯‍➡' => 'persona ar balto spieķi: vidējs ādas tonis un skatās pa labi',
    '🧑🏾‍🦯‍➡' => 'persona ar balto spieķi: vidēji tumšs ādas tonis un skatās pa labi',
    '🧑🏿‍🦯‍➡' => 'persona ar balto spieķi: tumšs ādas tonis un skatās pa labi',
    '👨🏻‍🦯‍➡' => 'vīrietis ar balto atbalsta spieķi: gaišs ādas tonis un skatās pa labi',
    '👨🏼‍🦯‍➡' => 'vīrietis ar balto atbalsta spieķi: vidēji gaišs ādas tonis un skatās pa labi',
    '👨🏽‍🦯‍➡' => 'vīrietis ar balto atbalsta spieķi: vidējs ādas tonis un skatās pa labi',
    '👨🏾‍🦯‍➡' => 'vīrietis ar balto atbalsta spieķi: vidēji tumšs ādas tonis un skatās pa labi',
    '👨🏿‍🦯‍➡' => 'vīrietis ar balto atbalsta spieķi: tumšs ādas tonis un skatās pa labi',
    '👩🏻‍🦯‍➡' => 'sieviete ar balto atbalsta spieķi: gaišs ādas tonis un skatās pa labi',
    '👩🏼‍🦯‍➡' => 'sieviete ar balto atbalsta spieķi: vidēji gaišs ādas tonis un skatās pa labi',
    '👩🏽‍🦯‍➡' => 'sieviete ar balto atbalsta spieķi: vidējs ādas tonis un skatās pa labi',
    '👩🏾‍🦯‍➡' => 'sieviete ar balto atbalsta spieķi: vidēji tumšs ādas tonis un skatās pa labi',
    '👩🏿‍🦯‍➡' => 'sieviete ar balto atbalsta spieķi: tumšs ādas tonis un skatās pa labi',
    '🧑🏻‍🦼‍➡' => 'persona ratiņkrēslā: gaišs ādas tonis un skatās pa labi',
    '🧑🏼‍🦼‍➡' => 'persona ratiņkrēslā: vidēji gaišs ādas tonis un skatās pa labi',
    '🧑🏽‍🦼‍➡' => 'persona ratiņkrēslā: vidējs ādas tonis un skatās pa labi',
    '🧑🏾‍🦼‍➡' => 'persona ratiņkrēslā: vidēji tumšs ādas tonis un skatās pa labi',
    '🧑🏿‍🦼‍➡' => 'persona ratiņkrēslā: tumšs ādas tonis un skatās pa labi',
    '👨🏻‍🦼‍➡' => 'vīrietis motorizētā ratiņkrēslā: gaišs ādas tonis un skatās pa labi',
    '👨🏼‍🦼‍➡' => 'vīrietis motorizētā ratiņkrēslā: vidēji gaišs ādas tonis un skatās pa labi',
    '👨🏽‍🦼‍➡' => 'vīrietis motorizētā ratiņkrēslā: vidējs ādas tonis un skatās pa labi',
    '👨🏾‍🦼‍➡' => 'vīrietis motorizētā ratiņkrēslā: vidēji tumšs ādas tonis un skatās pa labi',
    '👨🏿‍🦼‍➡' => 'vīrietis motorizētā ratiņkrēslā: tumšs ādas tonis un skatās pa labi',
    '👩🏻‍🦼‍➡' => 'sieviete motorizētā ratiņkrēslā: gaišs ādas tonis un skatās pa labi',
    '👩🏼‍🦼‍➡' => 'sieviete motorizētā ratiņkrēslā: vidēji gaišs ādas tonis un skatās pa labi',
    '👩🏽‍🦼‍➡' => 'sieviete motorizētā ratiņkrēslā: vidējs ādas tonis un skatās pa labi',
    '👩🏾‍🦼‍➡' => 'sieviete motorizētā ratiņkrēslā: vidēji tumšs ādas tonis un skatās pa labi',
    '👩🏿‍🦼‍➡' => 'sieviete motorizētā ratiņkrēslā: tumšs ādas tonis un skatās pa labi',
    '🧑🏻‍🦽‍➡' => 'persona manuālajā ratiņkrēslā: gaišs ādas tonis un skatās pa labi',
    '🧑🏼‍🦽‍➡' => 'persona manuālajā ratiņkrēslā: vidēji gaišs ādas tonis un skatās pa labi',
    '🧑🏽‍🦽‍➡' => 'persona manuālajā ratiņkrēslā: vidējs ādas tonis un skatās pa labi',
    '🧑🏾‍🦽‍➡' => 'persona manuālajā ratiņkrēslā: vidēji tumšs ādas tonis un skatās pa labi',
    '🧑🏿‍🦽‍➡' => 'persona manuālajā ratiņkrēslā: tumšs ādas tonis un skatās pa labi',
    '👨🏻‍🦽‍➡' => 'vīrietis manuālā ratiņkrēslā: gaišs ādas tonis un skatās pa labi',
    '👨🏼‍🦽‍➡' => 'vīrietis manuālā ratiņkrēslā: vidēji gaišs ādas tonis un skatās pa labi',
    '👨🏽‍🦽‍➡' => 'vīrietis manuālā ratiņkrēslā: vidējs ādas tonis un skatās pa labi',
    '👨🏾‍🦽‍➡' => 'vīrietis manuālā ratiņkrēslā: vidēji tumšs ādas tonis un skatās pa labi',
    '👨🏿‍🦽‍➡' => 'vīrietis manuālā ratiņkrēslā: tumšs ādas tonis un skatās pa labi',
    '👩🏻‍🦽‍➡' => 'sieviete manuālā ratiņkrēslā: gaišs ādas tonis un skatās pa labi',
    '👩🏼‍🦽‍➡' => 'sieviete manuālā ratiņkrēslā: vidēji gaišs ādas tonis un skatās pa labi',
    '👩🏽‍🦽‍➡' => 'sieviete manuālā ratiņkrēslā: vidējs ādas tonis un skatās pa labi',
    '👩🏾‍🦽‍➡' => 'sieviete manuālā ratiņkrēslā: vidēji tumšs ādas tonis un skatās pa labi',
    '👩🏿‍🦽‍➡' => 'sieviete manuālā ratiņkrēslā: tumšs ādas tonis un skatās pa labi',
    '🏃🏻‍♀‍➡' => 'sieviete skrien: gaišs ādas tonis un skatās pa labi',
    '🏃🏼‍♀‍➡' => 'sieviete skrien: vidēji gaišs ādas tonis un skatās pa labi',
    '🏃🏽‍♀‍➡' => 'sieviete skrien: vidējs ādas tonis un skatās pa labi',
    '🏃🏾‍♀‍➡' => 'sieviete skrien: vidēji tumšs ādas tonis un skatās pa labi',
    '🏃🏿‍♀‍➡' => 'sieviete skrien: tumšs ādas tonis un skatās pa labi',
    '🏃🏻‍♂‍➡' => 'vīrietis skrien: gaišs ādas tonis un skatās pa labi',
    '🏃🏼‍♂‍➡' => 'vīrietis skrien: vidēji gaišs ādas tonis un skatās pa labi',
    '🏃🏽‍♂‍➡' => 'vīrietis skrien: vidējs ādas tonis un skatās pa labi',
    '🏃🏾‍♂‍➡' => 'vīrietis skrien: vidēji tumšs ādas tonis un skatās pa labi',
    '🏃🏿‍♂‍➡' => 'vīrietis skrien: tumšs ādas tonis un skatās pa labi',
    '🫱🏻‍🫲🏼' => 'rokasspiediens: gaišs ādas tonis un vidēji gaišs ādas tonis',
    '🫱🏻‍🫲🏽' => 'rokasspiediens: gaišs ādas tonis un vidējs ādas tonis',
    '🫱🏻‍🫲🏾' => 'rokasspiediens: gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🫱🏻‍🫲🏿' => 'rokasspiediens: gaišs ādas tonis un tumšs ādas tonis',
    '🫱🏼‍🫲🏻' => 'rokasspiediens: vidēji gaišs ādas tonis un gaišs ādas tonis',
    '🫱🏼‍🫲🏽' => 'rokasspiediens: vidēji gaišs ādas tonis un vidējs ādas tonis',
    '🫱🏼‍🫲🏾' => 'rokasspiediens: vidēji gaišs ādas tonis un vidēji tumšs ādas tonis',
    '🫱🏼‍🫲🏿' => 'rokasspiediens: vidēji gaišs ādas tonis un tumšs ādas tonis',
    '🫱🏽‍🫲🏻' => 'rokasspiediens: vidējs ādas tonis un gaišs ādas tonis',
    '🫱🏽‍🫲🏼' => 'rokasspiediens: vidējs ādas tonis un vidēji gaišs ādas tonis',
    '🫱🏽‍🫲🏾' => 'rokasspiediens: vidējs ādas tonis un vidēji tumšs ādas tonis',
    '🫱🏽‍🫲🏿' => 'rokasspiediens: vidējs ādas tonis un tumšs ādas tonis',
    '🫱🏾‍🫲🏻' => 'rokasspiediens: vidēji tumšs ādas tonis un gaišs ādas tonis',
    '🫱🏾‍🫲🏼' => 'rokasspiediens: vidēji tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🫱🏾‍🫲🏽' => 'rokasspiediens: vidēji tumšs ādas tonis un vidējs ādas tonis',
    '🫱🏾‍🫲🏿' => 'rokasspiediens: vidēji tumšs ādas tonis un tumšs ādas tonis',
    '🫱🏿‍🫲🏻' => 'rokasspiediens: tumšs ādas tonis un gaišs ādas tonis',
    '🫱🏿‍🫲🏼' => 'rokasspiediens: tumšs ādas tonis un vidēji gaišs ādas tonis',
    '🫱🏿‍🫲🏽' => 'rokasspiediens: tumšs ādas tonis un vidējs ādas tonis',
    '🫱🏿‍🫲🏾' => 'rokasspiediens: tumšs ādas tonis un vidēji tumšs ādas tonis',
    '🚶‍♀‍➡' => 'sieviete pastaigājas: skatās pa labi',
    '🚶‍♂‍➡' => 'vīrietis pastaigājas: skatās pa labi',
    '🧎‍♀‍➡' => 'sieviete uz ceļiem: skatās pa labi',
    '🧎‍♂‍➡' => 'vīrietis uz ceļiem: skatās pa labi',
    '🧑‍🦯‍➡' => 'persona ar balto spieķi: skatās pa labi',
    '👨‍🦯‍➡' => 'vīrietis ar balto atbalsta spieķi: skatās pa labi',
    '👩‍🦯‍➡' => 'sieviete ar balto atbalsta spieķi: skatās pa labi',
    '🧑‍🦼‍➡' => 'persona ratiņkrēslā: skatās pa labi',
    '👨‍🦼‍➡' => 'vīrietis motorizētā ratiņkrēslā: skatās pa labi',
    '👩‍🦼‍➡' => 'sieviete motorizētā ratiņkrēslā: skatās pa labi',
    '🧑‍🦽‍➡' => 'persona manuālajā ratiņkrēslā: skatās pa labi',
    '👨‍🦽‍➡' => 'vīrietis manuālā ratiņkrēslā: skatās pa labi',
    '👩‍🦽‍➡' => 'sieviete manuālā ratiņkrēslā: skatās pa labi',
    '🏃‍♀‍➡' => 'sieviete skrien: skatās pa labi',
    '🏃‍♂‍➡' => 'vīrietis skrien: skatās pa labi',
    '👩‍❤‍👨' => 'pāris ar sirdi: sieviete un vīrietis',
    '👨‍❤‍👨' => 'pāris ar sirdi: vīrietis un vīrietis',
    '👩‍❤‍👩' => 'pāris ar sirdi: sieviete un sieviete',
    '👨‍👩‍👦' => 'ģimene: vīrietis, sieviete un zēns',
    '👨‍👩‍👧' => 'ģimene: vīrietis, sieviete un meitene',
    '👨‍👨‍👦' => 'ģimene: vīrietis, vīrietis un zēns',
    '👨‍👨‍👧' => 'ģimene: vīrietis, vīrietis un meitene',
    '👩‍👩‍👦' => 'ģimene: sieviete, sieviete un zēns',
    '👩‍👩‍👧' => 'ģimene: sieviete, sieviete un meitene',
    '👨‍👦‍👦' => 'ģimene: vīrietis, zēns un zēns',
    '👨‍👧‍👦' => 'ģimene: vīrietis, meitene un zēns',
    '👨‍👧‍👧' => 'ģimene: vīrietis, meitene un meitene',
    '👩‍👦‍👦' => 'ģimene: sieviete, zēns un zēns',
    '👩‍👧‍👦' => 'ģimene: sieviete, meitene un zēns',
    '👩‍👧‍👧' => 'ģimene: sieviete, meitene un meitene',
    '🧑‍🤝‍🧑' => 'cilvēki sadevušies rokās',
    '🧑‍🧑‍🧒' => 'ģimene: pieaugušais, pieaugušais, bērns',
    '🧑‍🧒‍🧒' => 'ģimene: pieaugušais, bērns, bērns',
    '🧑🏻‍🦰' => 'pieaugušais: gaišs ādas tonis un sarkani mati',
    '🧑🏼‍🦰' => 'pieaugušais: vidēji gaišs ādas tonis un sarkani mati',
    '🧑🏽‍🦰' => 'pieaugušais: vidējs ādas tonis un sarkani mati',
    '🧑🏾‍🦰' => 'pieaugušais: vidēji tumšs ādas tonis un sarkani mati',
    '🧑🏿‍🦰' => 'pieaugušais: tumšs ādas tonis un sarkani mati',
    '🧑🏻‍🦱' => 'pieaugušais: gaišs ādas tonis un sprogaini mati',
    '🧑🏼‍🦱' => 'pieaugušais: vidēji gaišs ādas tonis un sprogaini mati',
    '🧑🏽‍🦱' => 'pieaugušais: vidējs ādas tonis un sprogaini mati',
    '🧑🏾‍🦱' => 'pieaugušais: vidēji tumšs ādas tonis un sprogaini mati',
    '🧑🏿‍🦱' => 'pieaugušais: tumšs ādas tonis un sprogaini mati',
    '🧑🏻‍🦳' => 'pieaugušais: gaišs ādas tonis un sirmi mati',
    '🧑🏼‍🦳' => 'pieaugušais: vidēji gaišs ādas tonis un sirmi mati',
    '🧑🏽‍🦳' => 'pieaugušais: vidējs ādas tonis un sirmi mati',
    '🧑🏾‍🦳' => 'pieaugušais: vidēji tumšs ādas tonis un sirmi mati',
    '🧑🏿‍🦳' => 'pieaugušais: tumšs ādas tonis un sirmi mati',
    '🧑🏻‍🦲' => 'pieaugušais: gaišs ādas tonis un bez matiem',
    '🧑🏼‍🦲' => 'pieaugušais: vidēji gaišs ādas tonis un bez matiem',
    '🧑🏽‍🦲' => 'pieaugušais: vidējs ādas tonis un bez matiem',
    '🧑🏾‍🦲' => 'pieaugušais: vidēji tumšs ādas tonis un bez matiem',
    '🧑🏿‍🦲' => 'pieaugušais: tumšs ādas tonis un bez matiem',
    '🧑🏻‍🩰' => 'baletdejotājs: gaišs ādas tonis',
    '🧑🏼‍🩰' => 'baletdejotājs: vidēji gaišs ādas tonis',
    '🧑🏽‍🩰' => 'baletdejotājs: vidējs ādas tonis',
    '🧑🏾‍🩰' => 'baletdejotājs: vidēji tumšs ādas tonis',
    '🧑🏿‍🩰' => 'baletdejotājs: tumšs ādas tonis',
    '🧔🏻‍♂' => 'vīrietis ar bārdu: gaišs ādas tonis',
    '🧔🏼‍♂' => 'vīrietis ar bārdu: vidēji gaišs ādas tonis',
    '🧔🏽‍♂' => 'vīrietis ar bārdu: vidējs ādas tonis',
    '🧔🏾‍♂' => 'vīrietis ar bārdu: vidēji tumšs ādas tonis',
    '🧔🏿‍♂' => 'vīrietis ar bārdu: tumšs ādas tonis',
    '👱🏻‍♂' => 'blondīns: gaišs ādas tonis',
    '👱🏼‍♂' => 'blondīns: vidēji gaišs ādas tonis',
    '👱🏽‍♂' => 'blondīns: vidējs ādas tonis',
    '👱🏾‍♂' => 'blondīns: vidēji tumšs ādas tonis',
    '👱🏿‍♂' => 'blondīns: tumšs ādas tonis',
    '👨🏻‍🦰' => 'vīrietis: gaišs ādas tonis un sarkani mati',
    '👨🏼‍🦰' => 'vīrietis: vidēji gaišs ādas tonis un sarkani mati',
    '👨🏽‍🦰' => 'vīrietis: vidējs ādas tonis un sarkani mati',
    '👨🏾‍🦰' => 'vīrietis: vidēji tumšs ādas tonis un sarkani mati',
    '👨🏿‍🦰' => 'vīrietis: tumšs ādas tonis un sarkani mati',
    '👨🏻‍🦱' => 'vīrietis: gaišs ādas tonis un sprogaini mati',
    '👨🏼‍🦱' => 'vīrietis: vidēji gaišs ādas tonis un sprogaini mati',
    '👨🏽‍🦱' => 'vīrietis: vidējs ādas tonis un sprogaini mati',
    '👨🏾‍🦱' => 'vīrietis: vidēji tumšs ādas tonis un sprogaini mati',
    '👨🏿‍🦱' => 'vīrietis: tumšs ādas tonis un sprogaini mati',
    '👨🏻‍🦳' => 'vīrietis: gaišs ādas tonis un sirmi mati',
    '👨🏼‍🦳' => 'vīrietis: vidēji gaišs ādas tonis un sirmi mati',
    '👨🏽‍🦳' => 'vīrietis: vidējs ādas tonis un sirmi mati',
    '👨🏾‍🦳' => 'vīrietis: vidēji tumšs ādas tonis un sirmi mati',
    '👨🏿‍🦳' => 'vīrietis: tumšs ādas tonis un sirmi mati',
    '👨🏻‍🦲' => 'vīrietis: gaišs ādas tonis un bez matiem',
    '👨🏼‍🦲' => 'vīrietis: vidēji gaišs ādas tonis un bez matiem',
    '👨🏽‍🦲' => 'vīrietis: vidējs ādas tonis un bez matiem',
    '👨🏾‍🦲' => 'vīrietis: vidēji tumšs ādas tonis un bez matiem',
    '👨🏿‍🦲' => 'vīrietis: tumšs ādas tonis un bez matiem',
    '🧔🏻‍♀' => 'sieviete ar bārdu: gaišs ādas tonis',
    '🧔🏼‍♀' => 'sieviete ar bārdu: vidēji gaišs ādas tonis',
    '🧔🏽‍♀' => 'sieviete ar bārdu: vidējs ādas tonis',
    '🧔🏾‍♀' => 'sieviete ar bārdu: vidēji tumšs ādas tonis',
    '🧔🏿‍♀' => 'sieviete ar bārdu: tumšs ādas tonis',
    '👱🏻‍♀' => 'blondīne: gaišs ādas tonis',
    '👱🏼‍♀' => 'blondīne: vidēji gaišs ādas tonis',
    '👱🏽‍♀' => 'blondīne: vidējs ādas tonis',
    '👱🏾‍♀' => 'blondīne: vidēji tumšs ādas tonis',
    '👱🏿‍♀' => 'blondīne: tumšs ādas tonis',
    '👩🏻‍🦰' => 'sieviete: gaišs ādas tonis un sarkani mati',
    '👩🏼‍🦰' => 'sieviete: vidēji gaišs ādas tonis un sarkani mati',
    '👩🏽‍🦰' => 'sieviete: vidējs ādas tonis un sarkani mati',
    '👩🏾‍🦰' => 'sieviete: vidēji tumšs ādas tonis un sarkani mati',
    '👩🏿‍🦰' => 'sieviete: tumšs ādas tonis un sarkani mati',
    '👩🏻‍🦱' => 'sieviete: gaišs ādas tonis un sprogaini mati',
    '👩🏼‍🦱' => 'sieviete: vidēji gaišs ādas tonis un sprogaini mati',
    '👩🏽‍🦱' => 'sieviete: vidējs ādas tonis un sprogaini mati',
    '👩🏾‍🦱' => 'sieviete: vidēji tumšs ādas tonis un sprogaini mati',
    '👩🏿‍🦱' => 'sieviete: tumšs ādas tonis un sprogaini mati',
    '👩🏻‍🦳' => 'sieviete: gaišs ādas tonis un sirmi mati',
    '👩🏼‍🦳' => 'sieviete: vidēji gaišs ādas tonis un sirmi mati',
    '👩🏽‍🦳' => 'sieviete: vidējs ādas tonis un sirmi mati',
    '👩🏾‍🦳' => 'sieviete: vidēji tumšs ādas tonis un sirmi mati',
    '👩🏿‍🦳' => 'sieviete: tumšs ādas tonis un sirmi mati',
    '👩🏻‍🦲' => 'sieviete: gaišs ādas tonis un bez matiem',
    '👩🏼‍🦲' => 'sieviete: vidēji gaišs ādas tonis un bez matiem',
    '👩🏽‍🦲' => 'sieviete: vidējs ādas tonis un bez matiem',
    '👩🏾‍🦲' => 'sieviete: vidēji tumšs ādas tonis un bez matiem',
    '👩🏿‍🦲' => 'sieviete: tumšs ādas tonis un bez matiem',
    '🙍🏻‍♂' => 'norūpējies vīrietis: gaišs ādas tonis',
    '🙍🏼‍♂' => 'norūpējies vīrietis: vidēji gaišs ādas tonis',
    '🙍🏽‍♂' => 'norūpējies vīrietis: vidējs ādas tonis',
    '🙍🏾‍♂' => 'norūpējies vīrietis: vidēji tumšs ādas tonis',
    '🙍🏿‍♂' => 'norūpējies vīrietis: tumšs ādas tonis',
    '🙍🏻‍♀' => 'norūpējusies sieviete: gaišs ādas tonis',
    '🙍🏼‍♀' => 'norūpējusies sieviete: vidēji gaišs ādas tonis',
    '🙍🏽‍♀' => 'norūpējusies sieviete: vidējs ādas tonis',
    '🙍🏾‍♀' => 'norūpējusies sieviete: vidēji tumšs ādas tonis',
    '🙍🏿‍♀' => 'norūpējusies sieviete: tumšs ādas tonis',
    '🙎🏻‍♂' => 'sabozies vīrietis: gaišs ādas tonis',
    '🙎🏼‍♂' => 'sabozies vīrietis: vidēji gaišs ādas tonis',
    '🙎🏽‍♂' => 'sabozies vīrietis: vidējs ādas tonis',
    '🙎🏾‍♂' => 'sabozies vīrietis: vidēji tumšs ādas tonis',
    '🙎🏿‍♂' => 'sabozies vīrietis: tumšs ādas tonis',
    '🙎🏻‍♀' => 'sabozusies sieviete: gaišs ādas tonis',
    '🙎🏼‍♀' => 'sabozusies sieviete: vidēji gaišs ādas tonis',
    '🙎🏽‍♀' => 'sabozusies sieviete: vidējs ādas tonis',
    '🙎🏾‍♀' => 'sabozusies sieviete: vidēji tumšs ādas tonis',
    '🙎🏿‍♀' => 'sabozusies sieviete: tumšs ādas tonis',
    '🙅🏻‍♂' => 'vīrietis ar aizlieguma žestu: gaišs ādas tonis',
    '🙅🏼‍♂' => 'vīrietis ar aizlieguma žestu: vidēji gaišs ādas tonis',
    '🙅🏽‍♂' => 'vīrietis ar aizlieguma žestu: vidējs ādas tonis',
    '🙅🏾‍♂' => 'vīrietis ar aizlieguma žestu: vidēji tumšs ādas tonis',
    '🙅🏿‍♂' => 'vīrietis ar aizlieguma žestu: tumšs ādas tonis',
    '🙅🏻‍♀' => 'sieviete ar aizlieguma žestu: gaišs ādas tonis',
    '🙅🏼‍♀' => 'sieviete ar aizlieguma žestu: vidēji gaišs ādas tonis',
    '🙅🏽‍♀' => 'sieviete ar aizlieguma žestu: vidējs ādas tonis',
    '🙅🏾‍♀' => 'sieviete ar aizlieguma žestu: vidēji tumšs ādas tonis',
    '🙅🏿‍♀' => 'sieviete ar aizlieguma žestu: tumšs ādas tonis',
    '🙆🏻‍♂' => 'vīrietis ar apstiprinājuma žestu: gaišs ādas tonis',
    '🙆🏼‍♂' => 'vīrietis ar apstiprinājuma žestu: vidēji gaišs ādas tonis',
    '🙆🏽‍♂' => 'vīrietis ar apstiprinājuma žestu: vidējs ādas tonis',
    '🙆🏾‍♂' => 'vīrietis ar apstiprinājuma žestu: vidēji tumšs ādas tonis',
    '🙆🏿‍♂' => 'vīrietis ar apstiprinājuma žestu: tumšs ādas tonis',
    '🙆🏻‍♀' => 'sieviete ar apstiprinājuma žestu: gaišs ādas tonis',
    '🙆🏼‍♀' => 'sieviete ar apstiprinājuma žestu: vidēji gaišs ādas tonis',
    '🙆🏽‍♀' => 'sieviete ar apstiprinājuma žestu: vidējs ādas tonis',
    '🙆🏾‍♀' => 'sieviete ar apstiprinājuma žestu: vidēji tumšs ādas tonis',
    '🙆🏿‍♀' => 'sieviete ar apstiprinājuma žestu: tumšs ādas tonis',
    '💁🏻‍♂' => 'vīrietis ar pastieptu roku: gaišs ādas tonis',
    '💁🏼‍♂' => 'vīrietis ar pastieptu roku: vidēji gaišs ādas tonis',
    '💁🏽‍♂' => 'vīrietis ar pastieptu roku: vidējs ādas tonis',
    '💁🏾‍♂' => 'vīrietis ar pastieptu roku: vidēji tumšs ādas tonis',
    '💁🏿‍♂' => 'vīrietis ar pastieptu roku: tumšs ādas tonis',
    '💁🏻‍♀' => 'sieviete ar pastieptu roku: gaišs ādas tonis',
    '💁🏼‍♀' => 'sieviete ar pastieptu roku: vidēji gaišs ādas tonis',
    '💁🏽‍♀' => 'sieviete ar pastieptu roku: vidējs ādas tonis',
    '💁🏾‍♀' => 'sieviete ar pastieptu roku: vidēji tumšs ādas tonis',
    '💁🏿‍♀' => 'sieviete ar pastieptu roku: tumšs ādas tonis',
    '🙋🏻‍♂' => 'vīrietis ar paceltu roku: gaišs ādas tonis',
    '🙋🏼‍♂' => 'vīrietis ar paceltu roku: vidēji gaišs ādas tonis',
    '🙋🏽‍♂' => 'vīrietis ar paceltu roku: vidējs ādas tonis',
    '🙋🏾‍♂' => 'vīrietis ar paceltu roku: vidēji tumšs ādas tonis',
    '🙋🏿‍♂' => 'vīrietis ar paceltu roku: tumšs ādas tonis',
    '🙋🏻‍♀' => 'sieviete ar paceltu roku: gaišs ādas tonis',
    '🙋🏼‍♀' => 'sieviete ar paceltu roku: vidēji gaišs ādas tonis',
    '🙋🏽‍♀' => 'sieviete ar paceltu roku: vidējs ādas tonis',
    '🙋🏾‍♀' => 'sieviete ar paceltu roku: vidēji tumšs ādas tonis',
    '🙋🏿‍♀' => 'sieviete ar paceltu roku: tumšs ādas tonis',
    '🧏🏻‍♂' => 'nedzirdīgs vīrietis: gaišs ādas tonis',
    '🧏🏼‍♂' => 'nedzirdīgs vīrietis: vidēji gaišs ādas tonis',
    '🧏🏽‍♂' => 'nedzirdīgs vīrietis: vidējs ādas tonis',
    '🧏🏾‍♂' => 'nedzirdīgs vīrietis: vidēji tumšs ādas tonis',
    '🧏🏿‍♂' => 'nedzirdīgs vīrietis: tumšs ādas tonis',
    '🧏🏻‍♀' => 'nedzirdīga sieviete: gaišs ādas tonis',
    '🧏🏼‍♀' => 'nedzirdīga sieviete: vidēji gaišs ādas tonis',
    '🧏🏽‍♀' => 'nedzirdīga sieviete: vidējs ādas tonis',
    '🧏🏾‍♀' => 'nedzirdīga sieviete: vidēji tumšs ādas tonis',
    '🧏🏿‍♀' => 'nedzirdīga sieviete: tumšs ādas tonis',
    '🙇🏻‍♂' => 'vīrietis paklanās: gaišs ādas tonis',
    '🙇🏼‍♂' => 'vīrietis paklanās: vidēji gaišs ādas tonis',
    '🙇🏽‍♂' => 'vīrietis paklanās: vidējs ādas tonis',
    '🙇🏾‍♂' => 'vīrietis paklanās: vidēji tumšs ādas tonis',
    '🙇🏿‍♂' => 'vīrietis paklanās: tumšs ādas tonis',
    '🙇🏻‍♀' => 'sieviete paklanās: gaišs ādas tonis',
    '🙇🏼‍♀' => 'sieviete paklanās: vidēji gaišs ādas tonis',
    '🙇🏽‍♀' => 'sieviete paklanās: vidējs ādas tonis',
    '🙇🏾‍♀' => 'sieviete paklanās: vidēji tumšs ādas tonis',
    '🙇🏿‍♀' => 'sieviete paklanās: tumšs ādas tonis',
    '🤦🏻‍♂' => 'vīrietis ar saķertu galvu: gaišs ādas tonis',
    '🤦🏼‍♂' => 'vīrietis ar saķertu galvu: vidēji gaišs ādas tonis',
    '🤦🏽‍♂' => 'vīrietis ar saķertu galvu: vidējs ādas tonis',
    '🤦🏾‍♂' => 'vīrietis ar saķertu galvu: vidēji tumšs ādas tonis',
    '🤦🏿‍♂' => 'vīrietis ar saķertu galvu: tumšs ādas tonis',
    '🤦🏻‍♀' => 'sieviete ar saķertu galvu: gaišs ādas tonis',
    '🤦🏼‍♀' => 'sieviete ar saķertu galvu: vidēji gaišs ādas tonis',
    '🤦🏽‍♀' => 'sieviete ar saķertu galvu: vidējs ādas tonis',
    '🤦🏾‍♀' => 'sieviete ar saķertu galvu: vidēji tumšs ādas tonis',
    '🤦🏿‍♀' => 'sieviete ar saķertu galvu: tumšs ādas tonis',
    '🤷🏻‍♂' => 'vīrietis rausta plecus: gaišs ādas tonis',
    '🤷🏼‍♂' => 'vīrietis rausta plecus: vidēji gaišs ādas tonis',
    '🤷🏽‍♂' => 'vīrietis rausta plecus: vidējs ādas tonis',
    '🤷🏾‍♂' => 'vīrietis rausta plecus: vidēji tumšs ādas tonis',
    '🤷🏿‍♂' => 'vīrietis rausta plecus: tumšs ādas tonis',
    '🤷🏻‍♀' => 'sieviete rausta plecus: gaišs ādas tonis',
    '🤷🏼‍♀' => 'sieviete rausta plecus: vidēji gaišs ādas tonis',
    '🤷🏽‍♀' => 'sieviete rausta plecus: vidējs ādas tonis',
    '🤷🏾‍♀' => 'sieviete rausta plecus: vidēji tumšs ādas tonis',
    '🤷🏿‍♀' => 'sieviete rausta plecus: tumšs ādas tonis',
    '🧑🏻‍⚕' => 'veselības aprūpes darbinieks: gaišs ādas tonis',
    '🧑🏼‍⚕' => 'veselības aprūpes darbinieks: vidēji gaišs ādas tonis',
    '🧑🏽‍⚕' => 'veselības aprūpes darbinieks: vidējs ādas tonis',
    '🧑🏾‍⚕' => 'veselības aprūpes darbinieks: vidēji tumšs ādas tonis',
    '🧑🏿‍⚕' => 'veselības aprūpes darbinieks: tumšs ādas tonis',
    '👨🏻‍⚕' => 'veselības aprūpes speciālists: gaišs ādas tonis',
    '👨🏼‍⚕' => 'veselības aprūpes speciālists: vidēji gaišs ādas tonis',
    '👨🏽‍⚕' => 'veselības aprūpes speciālists: vidējs ādas tonis',
    '👨🏾‍⚕' => 'veselības aprūpes speciālists: vidēji tumšs ādas tonis',
    '👨🏿‍⚕' => 'veselības aprūpes speciālists: tumšs ādas tonis',
    '👩🏻‍⚕' => 'veselības aprūpes speciāliste: gaišs ādas tonis',
    '👩🏼‍⚕' => 'veselības aprūpes speciāliste: vidēji gaišs ādas tonis',
    '👩🏽‍⚕' => 'veselības aprūpes speciāliste: vidējs ādas tonis',
    '👩🏾‍⚕' => 'veselības aprūpes speciāliste: vidēji tumšs ādas tonis',
    '👩🏿‍⚕' => 'veselības aprūpes speciāliste: tumšs ādas tonis',
    '🧑🏻‍🎓' => 'absolvents: gaišs ādas tonis',
    '🧑🏼‍🎓' => 'absolvents: vidēji gaišs ādas tonis',
    '🧑🏽‍🎓' => 'absolvents: vidējs ādas tonis',
    '🧑🏾‍🎓' => 'absolvents: vidēji tumšs ādas tonis',
    '🧑🏿‍🎓' => 'absolvents: tumšs ādas tonis',
    '👨🏻‍🎓' => 'students: gaišs ādas tonis',
    '👨🏼‍🎓' => 'students: vidēji gaišs ādas tonis',
    '👨🏽‍🎓' => 'students: vidējs ādas tonis',
    '👨🏾‍🎓' => 'students: vidēji tumšs ādas tonis',
    '👨🏿‍🎓' => 'students: tumšs ādas tonis',
    '👩🏻‍🎓' => 'studente: gaišs ādas tonis',
    '👩🏼‍🎓' => 'studente: vidēji gaišs ādas tonis',
    '👩🏽‍🎓' => 'studente: vidējs ādas tonis',
    '👩🏾‍🎓' => 'studente: vidēji tumšs ādas tonis',
    '👩🏿‍🎓' => 'studente: tumšs ādas tonis',
    '🧑🏻‍🏫' => 'pedagogs: gaišs ādas tonis',
    '🧑🏼‍🏫' => 'pedagogs: vidēji gaišs ādas tonis',
    '🧑🏽‍🏫' => 'pedagogs: vidējs ādas tonis',
    '🧑🏾‍🏫' => 'pedagogs: vidēji tumšs ādas tonis',
    '🧑🏿‍🏫' => 'pedagogs: tumšs ādas tonis',
    '👨🏻‍🏫' => 'skolotājs: gaišs ādas tonis',
    '👨🏼‍🏫' => 'skolotājs: vidēji gaišs ādas tonis',
    '👨🏽‍🏫' => 'skolotājs: vidējs ādas tonis',
    '👨🏾‍🏫' => 'skolotājs: vidēji tumšs ādas tonis',
    '👨🏿‍🏫' => 'skolotājs: tumšs ādas tonis',
    '👩🏻‍🏫' => 'skolotāja: gaišs ādas tonis',
    '👩🏼‍🏫' => 'skolotāja: vidēji gaišs ādas tonis',
    '👩🏽‍🏫' => 'skolotāja: vidējs ādas tonis',
    '👩🏾‍🏫' => 'skolotāja: vidēji tumšs ādas tonis',
    '👩🏿‍🏫' => 'skolotāja: tumšs ādas tonis',
    '🧑🏻‍⚖' => 'soģis: gaišs ādas tonis',
    '🧑🏼‍⚖' => 'soģis: vidēji gaišs ādas tonis',
    '🧑🏽‍⚖' => 'soģis: vidējs ādas tonis',
    '🧑🏾‍⚖' => 'soģis: vidēji tumšs ādas tonis',
    '🧑🏿‍⚖' => 'soģis: tumšs ādas tonis',
    '👨🏻‍⚖' => 'tiesnesis: gaišs ādas tonis',
    '👨🏼‍⚖' => 'tiesnesis: vidēji gaišs ādas tonis',
    '👨🏽‍⚖' => 'tiesnesis: vidējs ādas tonis',
    '👨🏾‍⚖' => 'tiesnesis: vidēji tumšs ādas tonis',
    '👨🏿‍⚖' => 'tiesnesis: tumšs ādas tonis',
    '👩🏻‍⚖' => 'tiesnese: gaišs ādas tonis',
    '👩🏼‍⚖' => 'tiesnese: vidēji gaišs ādas tonis',
    '👩🏽‍⚖' => 'tiesnese: vidējs ādas tonis',
    '👩🏾‍⚖' => 'tiesnese: vidēji tumšs ādas tonis',
    '👩🏿‍⚖' => 'tiesnese: tumšs ādas tonis',
    '🧑🏻‍🌾' => 'fermeris: gaišs ādas tonis',
    '🧑🏼‍🌾' => 'fermeris: vidēji gaišs ādas tonis',
    '🧑🏽‍🌾' => 'fermeris: vidējs ādas tonis',
    '🧑🏾‍🌾' => 'fermeris: vidēji tumšs ādas tonis',
    '🧑🏿‍🌾' => 'fermeris: tumšs ādas tonis',
    '👨🏻‍🌾' => 'lauksaimnieks: gaišs ādas tonis',
    '👨🏼‍🌾' => 'lauksaimnieks: vidēji gaišs ādas tonis',
    '👨🏽‍🌾' => 'lauksaimnieks: vidējs ādas tonis',
    '👨🏾‍🌾' => 'lauksaimnieks: vidēji tumšs ādas tonis',
    '👨🏿‍🌾' => 'lauksaimnieks: tumšs ādas tonis',
    '👩🏻‍🌾' => 'lauksaimniece: gaišs ādas tonis',
    '👩🏼‍🌾' => 'lauksaimniece: vidēji gaišs ādas tonis',
    '👩🏽‍🌾' => 'lauksaimniece: vidējs ādas tonis',
    '👩🏾‍🌾' => 'lauksaimniece: vidēji tumšs ādas tonis',
    '👩🏿‍🌾' => 'lauksaimniece: tumšs ādas tonis',
    '🧑🏻‍🍳' => 'vīrietis pavārs: gaišs ādas tonis',
    '🧑🏼‍🍳' => 'vīrietis pavārs: vidēji gaišs ādas tonis',
    '🧑🏽‍🍳' => 'vīrietis pavārs: vidējs ādas tonis',
    '🧑🏾‍🍳' => 'vīrietis pavārs: vidēji tumšs ādas tonis',
    '🧑🏿‍🍳' => 'vīrietis pavārs: tumšs ādas tonis',
    '👨🏻‍🍳' => 'pavārs: gaišs ādas tonis',
    '👨🏼‍🍳' => 'pavārs: vidēji gaišs ādas tonis',
    '👨🏽‍🍳' => 'pavārs: vidējs ādas tonis',
    '👨🏾‍🍳' => 'pavārs: vidēji tumšs ādas tonis',
    '👨🏿‍🍳' => 'pavārs: tumšs ādas tonis',
    '👩🏻‍🍳' => 'pavāre: gaišs ādas tonis',
    '👩🏼‍🍳' => 'pavāre: vidēji gaišs ādas tonis',
    '👩🏽‍🍳' => 'pavāre: vidējs ādas tonis',
    '👩🏾‍🍳' => 'pavāre: vidēji tumšs ādas tonis',
    '👩🏿‍🍳' => 'pavāre: tumšs ādas tonis',
    '🧑🏻‍🔧' => 'vīrietis mehāniķis: gaišs ādas tonis',
    '🧑🏼‍🔧' => 'vīrietis mehāniķis: vidēji gaišs ādas tonis',
    '🧑🏽‍🔧' => 'vīrietis mehāniķis: vidējs ādas tonis',
    '🧑🏾‍🔧' => 'vīrietis mehāniķis: vidēji tumšs ādas tonis',
    '🧑🏿‍🔧' => 'vīrietis mehāniķis: tumšs ādas tonis',
    '👨🏻‍🔧' => 'mehāniķis: gaišs ādas tonis',
    '👨🏼‍🔧' => 'mehāniķis: vidēji gaišs ādas tonis',
    '👨🏽‍🔧' => 'mehāniķis: vidējs ādas tonis',
    '👨🏾‍🔧' => 'mehāniķis: vidēji tumšs ādas tonis',
    '👨🏿‍🔧' => 'mehāniķis: tumšs ādas tonis',
    '👩🏻‍🔧' => 'mehāniķe: gaišs ādas tonis',
    '👩🏼‍🔧' => 'mehāniķe: vidēji gaišs ādas tonis',
    '👩🏽‍🔧' => 'mehāniķe: vidējs ādas tonis',
    '👩🏾‍🔧' => 'mehāniķe: vidēji tumšs ādas tonis',
    '👩🏿‍🔧' => 'mehāniķe: tumšs ādas tonis',
    '🧑🏻‍🏭' => 'rūpnīcas strādnieks: gaišs ādas tonis',
    '🧑🏼‍🏭' => 'rūpnīcas strādnieks: vidēji gaišs ādas tonis',
    '🧑🏽‍🏭' => 'rūpnīcas strādnieks: vidējs ādas tonis',
    '🧑🏾‍🏭' => 'rūpnīcas strādnieks: vidēji tumšs ādas tonis',
    '🧑🏿‍🏭' => 'rūpnīcas strādnieks: tumšs ādas tonis',
    '👨🏻‍🏭' => 'fabrikas strādnieks: gaišs ādas tonis',
    '👨🏼‍🏭' => 'fabrikas strādnieks: vidēji gaišs ādas tonis',
    '👨🏽‍🏭' => 'fabrikas strādnieks: vidējs ādas tonis',
    '👨🏾‍🏭' => 'fabrikas strādnieks: vidēji tumšs ādas tonis',
    '👨🏿‍🏭' => 'fabrikas strādnieks: tumšs ādas tonis',
    '👩🏻‍🏭' => 'fabrikas strādniece: gaišs ādas tonis',
    '👩🏼‍🏭' => 'fabrikas strādniece: vidēji gaišs ādas tonis',
    '👩🏽‍🏭' => 'fabrikas strādniece: vidējs ādas tonis',
    '👩🏾‍🏭' => 'fabrikas strādniece: vidēji tumšs ādas tonis',
    '👩🏿‍🏭' => 'fabrikas strādniece: tumšs ādas tonis',
    '🧑🏻‍💼' => 'vīrietis biroja darbinieks: gaišs ādas tonis',
    '🧑🏼‍💼' => 'vīrietis biroja darbinieks: vidēji gaišs ādas tonis',
    '🧑🏽‍💼' => 'vīrietis biroja darbinieks: vidējs ādas tonis',
    '🧑🏾‍💼' => 'vīrietis biroja darbinieks: vidēji tumšs ādas tonis',
    '🧑🏿‍💼' => 'vīrietis biroja darbinieks: tumšs ādas tonis',
    '👨🏻‍💼' => 'biroja darbinieks: gaišs ādas tonis',
    '👨🏼‍💼' => 'biroja darbinieks: vidēji gaišs ādas tonis',
    '👨🏽‍💼' => 'biroja darbinieks: vidējs ādas tonis',
    '👨🏾‍💼' => 'biroja darbinieks: vidēji tumšs ādas tonis',
    '👨🏿‍💼' => 'biroja darbinieks: tumšs ādas tonis',
    '👩🏻‍💼' => 'biroja darbiniece: gaišs ādas tonis',
    '👩🏼‍💼' => 'biroja darbiniece: vidēji gaišs ādas tonis',
    '👩🏽‍💼' => 'biroja darbiniece: vidējs ādas tonis',
    '👩🏾‍💼' => 'biroja darbiniece: vidēji tumšs ādas tonis',
    '👩🏿‍💼' => 'biroja darbiniece: tumšs ādas tonis',
    '🧑🏻‍🔬' => 'vīrietis zinātnieks: gaišs ādas tonis',
    '🧑🏼‍🔬' => 'vīrietis zinātnieks: vidēji gaišs ādas tonis',
    '🧑🏽‍🔬' => 'vīrietis zinātnieks: vidējs ādas tonis',
    '🧑🏾‍🔬' => 'vīrietis zinātnieks: vidēji tumšs ādas tonis',
    '🧑🏿‍🔬' => 'vīrietis zinātnieks: tumšs ādas tonis',
    '👨🏻‍🔬' => 'zinātnieks: gaišs ādas tonis',
    '👨🏼‍🔬' => 'zinātnieks: vidēji gaišs ādas tonis',
    '👨🏽‍🔬' => 'zinātnieks: vidējs ādas tonis',
    '👨🏾‍🔬' => 'zinātnieks: vidēji tumšs ādas tonis',
    '👨🏿‍🔬' => 'zinātnieks: tumšs ādas tonis',
    '👩🏻‍🔬' => 'zinātniece: gaišs ādas tonis',
    '👩🏼‍🔬' => 'zinātniece: vidēji gaišs ādas tonis',
    '👩🏽‍🔬' => 'zinātniece: vidējs ādas tonis',
    '👩🏾‍🔬' => 'zinātniece: vidēji tumšs ādas tonis',
    '👩🏿‍🔬' => 'zinātniece: tumšs ādas tonis',
    '🧑🏻‍💻' => 'vīrietis tehniķis: gaišs ādas tonis',
    '🧑🏼‍💻' => 'vīrietis tehniķis: vidēji gaišs ādas tonis',
    '🧑🏽‍💻' => 'vīrietis tehniķis: vidējs ādas tonis',
    '🧑🏾‍💻' => 'vīrietis tehniķis: vidēji tumšs ādas tonis',
    '🧑🏿‍💻' => 'vīrietis tehniķis: tumšs ādas tonis',
    '👨🏻‍💻' => 'tehniķis: gaišs ādas tonis',
    '👨🏼‍💻' => 'tehniķis: vidēji gaišs ādas tonis',
    '👨🏽‍💻' => 'tehniķis: vidējs ādas tonis',
    '👨🏾‍💻' => 'tehniķis: vidēji tumšs ādas tonis',
    '👨🏿‍💻' => 'tehniķis: tumšs ādas tonis',
    '👩🏻‍💻' => 'tehniķe: gaišs ādas tonis',
    '👩🏼‍💻' => 'tehniķe: vidēji gaišs ādas tonis',
    '👩🏽‍💻' => 'tehniķe: vidējs ādas tonis',
    '👩🏾‍💻' => 'tehniķe: vidēji tumšs ādas tonis',
    '👩🏿‍💻' => 'tehniķe: tumšs ādas tonis',
    '🧑🏻‍🎤' => 'vīrietis dziedātājs: gaišs ādas tonis',
    '🧑🏼‍🎤' => 'vīrietis dziedātājs: vidēji gaišs ādas tonis',
    '🧑🏽‍🎤' => 'vīrietis dziedātājs: vidējs ādas tonis',
    '🧑🏾‍🎤' => 'vīrietis dziedātājs: vidēji tumšs ādas tonis',
    '🧑🏿‍🎤' => 'vīrietis dziedātājs: tumšs ādas tonis',
    '👨🏻‍🎤' => 'dziedātājs: gaišs ādas tonis',
    '👨🏼‍🎤' => 'dziedātājs: vidēji gaišs ādas tonis',
    '👨🏽‍🎤' => 'dziedātājs: vidējs ādas tonis',
    '👨🏾‍🎤' => 'dziedātājs: vidēji tumšs ādas tonis',
    '👨🏿‍🎤' => 'dziedātājs: tumšs ādas tonis',
    '👩🏻‍🎤' => 'dziedātāja: gaišs ādas tonis',
    '👩🏼‍🎤' => 'dziedātāja: vidēji gaišs ādas tonis',
    '👩🏽‍🎤' => 'dziedātāja: vidējs ādas tonis',
    '👩🏾‍🎤' => 'dziedātāja: vidēji tumšs ādas tonis',
    '👩🏿‍🎤' => 'dziedātāja: tumšs ādas tonis',
    '🧑🏻‍🎨' => 'vīrietis mākslinieks: gaišs ādas tonis',
    '🧑🏼‍🎨' => 'vīrietis mākslinieks: vidēji gaišs ādas tonis',
    '🧑🏽‍🎨' => 'vīrietis mākslinieks: vidējs ādas tonis',
    '🧑🏾‍🎨' => 'vīrietis mākslinieks: vidēji tumšs ādas tonis',
    '🧑🏿‍🎨' => 'vīrietis mākslinieks: tumšs ādas tonis',
    '👨🏻‍🎨' => 'mākslinieks: gaišs ādas tonis',
    '👨🏼‍🎨' => 'mākslinieks: vidēji gaišs ādas tonis',
    '👨🏽‍🎨' => 'mākslinieks: vidējs ādas tonis',
    '👨🏾‍🎨' => 'mākslinieks: vidēji tumšs ādas tonis',
    '👨🏿‍🎨' => 'mākslinieks: tumšs ādas tonis',
    '👩🏻‍🎨' => 'māksliniece: gaišs ādas tonis',
    '👩🏼‍🎨' => 'māksliniece: vidēji gaišs ādas tonis',
    '👩🏽‍🎨' => 'māksliniece: vidējs ādas tonis',
    '👩🏾‍🎨' => 'māksliniece: vidēji tumšs ādas tonis',
    '👩🏿‍🎨' => 'māksliniece: tumšs ādas tonis',
    '🧑🏻‍✈' => 'vīrietis pilots: gaišs ādas tonis',
    '🧑🏼‍✈' => 'vīrietis pilots: vidēji gaišs ādas tonis',
    '🧑🏽‍✈' => 'vīrietis pilots: vidējs ādas tonis',
    '🧑🏾‍✈' => 'vīrietis pilots: vidēji tumšs ādas tonis',
    '🧑🏿‍✈' => 'vīrietis pilots: tumšs ādas tonis',
    '👨🏻‍✈' => 'pilots: gaišs ādas tonis',
    '👨🏼‍✈' => 'pilots: vidēji gaišs ādas tonis',
    '👨🏽‍✈' => 'pilots: vidējs ādas tonis',
    '👨🏾‍✈' => 'pilots: vidēji tumšs ādas tonis',
    '👨🏿‍✈' => 'pilots: tumšs ādas tonis',
    '👩🏻‍✈' => 'pilote: gaišs ādas tonis',
    '👩🏼‍✈' => 'pilote: vidēji gaišs ādas tonis',
    '👩🏽‍✈' => 'pilote: vidējs ādas tonis',
    '👩🏾‍✈' => 'pilote: vidēji tumšs ādas tonis',
    '👩🏿‍✈' => 'pilote: tumšs ādas tonis',
    '🧑🏻‍🚀' => 'vīrietis astronauts: gaišs ādas tonis',
    '🧑🏼‍🚀' => 'vīrietis astronauts: vidēji gaišs ādas tonis',
    '🧑🏽‍🚀' => 'vīrietis astronauts: vidējs ādas tonis',
    '🧑🏾‍🚀' => 'vīrietis astronauts: vidēji tumšs ādas tonis',
    '🧑🏿‍🚀' => 'vīrietis astronauts: tumšs ādas tonis',
    '👨🏻‍🚀' => 'astronauts: gaišs ādas tonis',
    '👨🏼‍🚀' => 'astronauts: vidēji gaišs ādas tonis',
    '👨🏽‍🚀' => 'astronauts: vidējs ādas tonis',
    '👨🏾‍🚀' => 'astronauts: vidēji tumšs ādas tonis',
    '👨🏿‍🚀' => 'astronauts: tumšs ādas tonis',
    '👩🏻‍🚀' => 'astronaute: gaišs ādas tonis',
    '👩🏼‍🚀' => 'astronaute: vidēji gaišs ādas tonis',
    '👩🏽‍🚀' => 'astronaute: vidējs ādas tonis',
    '👩🏾‍🚀' => 'astronaute: vidēji tumšs ādas tonis',
    '👩🏿‍🚀' => 'astronaute: tumšs ādas tonis',
    '🧑🏻‍🚒' => 'vīrietis ugunsdzēsējs: gaišs ādas tonis',
    '🧑🏼‍🚒' => 'vīrietis ugunsdzēsējs: vidēji gaišs ādas tonis',
    '🧑🏽‍🚒' => 'vīrietis ugunsdzēsējs: vidējs ādas tonis',
    '🧑🏾‍🚒' => 'vīrietis ugunsdzēsējs: vidēji tumšs ādas tonis',
    '🧑🏿‍🚒' => 'vīrietis ugunsdzēsējs: tumšs ādas tonis',
    '👨🏻‍🚒' => 'ugunsdzēsējs: gaišs ādas tonis',
    '👨🏼‍🚒' => 'ugunsdzēsējs: vidēji gaišs ādas tonis',
    '👨🏽‍🚒' => 'ugunsdzēsējs: vidējs ādas tonis',
    '👨🏾‍🚒' => 'ugunsdzēsējs: vidēji tumšs ādas tonis',
    '👨🏿‍🚒' => 'ugunsdzēsējs: tumšs ādas tonis',
    '👩🏻‍🚒' => 'ugunsdzēsēja: gaišs ādas tonis',
    '👩🏼‍🚒' => 'ugunsdzēsēja: vidēji gaišs ādas tonis',
    '👩🏽‍🚒' => 'ugunsdzēsēja: vidējs ādas tonis',
    '👩🏾‍🚒' => 'ugunsdzēsēja: vidēji tumšs ādas tonis',
    '👩🏿‍🚒' => 'ugunsdzēsēja: tumšs ādas tonis',
    '👮🏻‍♂' => 'policijas virsnieks: gaišs ādas tonis',
    '👮🏼‍♂' => 'policijas virsnieks: vidēji gaišs ādas tonis',
    '👮🏽‍♂' => 'policijas virsnieks: vidējs ādas tonis',
    '👮🏾‍♂' => 'policijas virsnieks: vidēji tumšs ādas tonis',
    '👮🏿‍♂' => 'policijas virsnieks: tumšs ādas tonis',
    '👮🏻‍♀' => 'policiste: gaišs ādas tonis',
    '👮🏼‍♀' => 'policiste: vidēji gaišs ādas tonis',
    '👮🏽‍♀' => 'policiste: vidējs ādas tonis',
    '👮🏾‍♀' => 'policiste: vidēji tumšs ādas tonis',
    '👮🏿‍♀' => 'policiste: tumšs ādas tonis',
    '🕵🏻‍♂' => 'detektīvs (vīrietis): gaišs ādas tonis',
    '🕵🏼‍♂' => 'detektīvs (vīrietis): vidēji gaišs ādas tonis',
    '🕵🏽‍♂' => 'detektīvs (vīrietis): vidējs ādas tonis',
    '🕵🏾‍♂' => 'detektīvs (vīrietis): vidēji tumšs ādas tonis',
    '🕵🏿‍♂' => 'detektīvs (vīrietis): tumšs ādas tonis',
    '🕵🏻‍♀' => 'detektīve: gaišs ādas tonis',
    '🕵🏼‍♀' => 'detektīve: vidēji gaišs ādas tonis',
    '🕵🏽‍♀' => 'detektīve: vidējs ādas tonis',
    '🕵🏾‍♀' => 'detektīve: vidēji tumšs ādas tonis',
    '🕵🏿‍♀' => 'detektīve: tumšs ādas tonis',
    '💂🏻‍♂' => 'apsargs: gaišs ādas tonis',
    '💂🏼‍♂' => 'apsargs: vidēji gaišs ādas tonis',
    '💂🏽‍♂' => 'apsargs: vidējs ādas tonis',
    '💂🏾‍♂' => 'apsargs: vidēji tumšs ādas tonis',
    '💂🏿‍♂' => 'apsargs: tumšs ādas tonis',
    '💂🏻‍♀' => 'sardze: gaišs ādas tonis',
    '💂🏼‍♀' => 'sardze: vidēji gaišs ādas tonis',
    '💂🏽‍♀' => 'sardze: vidējs ādas tonis',
    '💂🏾‍♀' => 'sardze: vidēji tumšs ādas tonis',
    '💂🏿‍♀' => 'sardze: tumšs ādas tonis',
    '👷🏻‍♂' => 'būvstrādnieks: gaišs ādas tonis',
    '👷🏼‍♂' => 'būvstrādnieks: vidēji gaišs ādas tonis',
    '👷🏽‍♂' => 'būvstrādnieks: vidējs ādas tonis',
    '👷🏾‍♂' => 'būvstrādnieks: vidēji tumšs ādas tonis',
    '👷🏿‍♂' => 'būvstrādnieks: tumšs ādas tonis',
    '👷🏻‍♀' => 'būvstrādniece: gaišs ādas tonis',
    '👷🏼‍♀' => 'būvstrādniece: vidēji gaišs ādas tonis',
    '👷🏽‍♀' => 'būvstrādniece: vidējs ādas tonis',
    '👷🏾‍♀' => 'būvstrādniece: vidēji tumšs ādas tonis',
    '👷🏿‍♀' => 'būvstrādniece: tumšs ādas tonis',
    '👳🏻‍♂' => 'vīrietis ar turbānu: gaišs ādas tonis',
    '👳🏼‍♂' => 'vīrietis ar turbānu: vidēji gaišs ādas tonis',
    '👳🏽‍♂' => 'vīrietis ar turbānu: vidējs ādas tonis',
    '👳🏾‍♂' => 'vīrietis ar turbānu: vidēji tumšs ādas tonis',
    '👳🏿‍♂' => 'vīrietis ar turbānu: tumšs ādas tonis',
    '👳🏻‍♀' => 'sieviete ar turbānu: gaišs ādas tonis',
    '👳🏼‍♀' => 'sieviete ar turbānu: vidēji gaišs ādas tonis',
    '👳🏽‍♀' => 'sieviete ar turbānu: vidējs ādas tonis',
    '👳🏾‍♀' => 'sieviete ar turbānu: vidēji tumšs ādas tonis',
    '👳🏿‍♀' => 'sieviete ar turbānu: tumšs ādas tonis',
    '🤵🏻‍♂' => 'vīrietis smokingā: gaišs ādas tonis',
    '🤵🏼‍♂' => 'vīrietis smokingā: vidēji gaišs ādas tonis',
    '🤵🏽‍♂' => 'vīrietis smokingā: vidējs ādas tonis',
    '🤵🏾‍♂' => 'vīrietis smokingā: vidēji tumšs ādas tonis',
    '🤵🏿‍♂' => 'vīrietis smokingā: tumšs ādas tonis',
    '🤵🏻‍♀' => 'sieviete smokingā: gaišs ādas tonis',
    '🤵🏼‍♀' => 'sieviete smokingā: vidēji gaišs ādas tonis',
    '🤵🏽‍♀' => 'sieviete smokingā: vidējs ādas tonis',
    '🤵🏾‍♀' => 'sieviete smokingā: vidēji tumšs ādas tonis',
    '🤵🏿‍♀' => 'sieviete smokingā: tumšs ādas tonis',
    '👰🏻‍♂' => 'vīrietis ar plīvuru: gaišs ādas tonis',
    '👰🏼‍♂' => 'vīrietis ar plīvuru: vidēji gaišs ādas tonis',
    '👰🏽‍♂' => 'vīrietis ar plīvuru: vidējs ādas tonis',
    '👰🏾‍♂' => 'vīrietis ar plīvuru: vidēji tumšs ādas tonis',
    '👰🏿‍♂' => 'vīrietis ar plīvuru: tumšs ādas tonis',
    '👰🏻‍♀' => 'sieviete ar plīvuru: gaišs ādas tonis',
    '👰🏼‍♀' => 'sieviete ar plīvuru: vidēji gaišs ādas tonis',
    '👰🏽‍♀' => 'sieviete ar plīvuru: vidējs ādas tonis',
    '👰🏾‍♀' => 'sieviete ar plīvuru: vidēji tumšs ādas tonis',
    '👰🏿‍♀' => 'sieviete ar plīvuru: tumšs ādas tonis',
    '👩🏻‍🍼' => 'sieviete baro bērnu: gaišs ādas tonis',
    '👩🏼‍🍼' => 'sieviete baro bērnu: vidēji gaišs ādas tonis',
    '👩🏽‍🍼' => 'sieviete baro bērnu: vidējs ādas tonis',
    '👩🏾‍🍼' => 'sieviete baro bērnu: vidēji tumšs ādas tonis',
    '👩🏿‍🍼' => 'sieviete baro bērnu: tumšs ādas tonis',
    '👨🏻‍🍼' => 'bērnu barojošs cilvēks: gaišs ādas tonis',
    '👨🏼‍🍼' => 'bērnu barojošs cilvēks: vidēji gaišs ādas tonis',
    '👨🏽‍🍼' => 'bērnu barojošs cilvēks: vidējs ādas tonis',
    '👨🏾‍🍼' => 'bērnu barojošs cilvēks: vidēji tumšs ādas tonis',
    '👨🏿‍🍼' => 'bērnu barojošs cilvēks: tumšs ādas tonis',
    '🧑🏻‍🍼' => 'persona baro bērnu: gaišs ādas tonis',
    '🧑🏼‍🍼' => 'persona baro bērnu: vidēji gaišs ādas tonis',
    '🧑🏽‍🍼' => 'persona baro bērnu: vidējs ādas tonis',
    '🧑🏾‍🍼' => 'persona baro bērnu: vidēji tumšs ādas tonis',
    '🧑🏿‍🍼' => 'persona baro bērnu: tumšs ādas tonis',
    '🧑🏻‍🎄' => 'dzimumneitrāls santaklauss: gaišs ādas tonis',
    '🧑🏼‍🎄' => 'dzimumneitrāls santaklauss: vidēji gaišs ādas tonis',
    '🧑🏽‍🎄' => 'dzimumneitrāls santaklauss: vidējs ādas tonis',
    '🧑🏾‍🎄' => 'dzimumneitrāls santaklauss: vidēji tumšs ādas tonis',
    '🧑🏿‍🎄' => 'dzimumneitrāls santaklauss: tumšs ādas tonis',
    '🦸🏻‍♂' => 'vīrietis supervaronis: gaišs ādas tonis',
    '🦸🏼‍♂' => 'vīrietis supervaronis: vidēji gaišs ādas tonis',
    '🦸🏽‍♂' => 'vīrietis supervaronis: vidējs ādas tonis',
    '🦸🏾‍♂' => 'vīrietis supervaronis: vidēji tumšs ādas tonis',
    '🦸🏿‍♂' => 'vīrietis supervaronis: tumšs ādas tonis',
    '🦸🏻‍♀' => 'sieviete supervarone: gaišs ādas tonis',
    '🦸🏼‍♀' => 'sieviete supervarone: vidēji gaišs ādas tonis',
    '🦸🏽‍♀' => 'sieviete supervarone: vidējs ādas tonis',
    '🦸🏾‍♀' => 'sieviete supervarone: vidēji tumšs ādas tonis',
    '🦸🏿‍♀' => 'sieviete supervarone: tumšs ādas tonis',
    '🦹🏻‍♂' => 'superļaunais vīrietis: gaišs ādas tonis',
    '🦹🏼‍♂' => 'superļaunais vīrietis: vidēji gaišs ādas tonis',
    '🦹🏽‍♂' => 'superļaunais vīrietis: vidējs ādas tonis',
    '🦹🏾‍♂' => 'superļaunais vīrietis: vidēji tumšs ādas tonis',
    '🦹🏿‍♂' => 'superļaunais vīrietis: tumšs ādas tonis',
    '🦹🏻‍♀' => 'superļaunā sieviete: gaišs ādas tonis',
    '🦹🏼‍♀' => 'superļaunā sieviete: vidēji gaišs ādas tonis',
    '🦹🏽‍♀' => 'superļaunā sieviete: vidējs ādas tonis',
    '🦹🏾‍♀' => 'superļaunā sieviete: vidēji tumšs ādas tonis',
    '🦹🏿‍♀' => 'superļaunā sieviete: tumšs ādas tonis',
    '🧙🏻‍♂' => 'zintnieks: gaišs ādas tonis',
    '🧙🏼‍♂' => 'zintnieks: vidēji gaišs ādas tonis',
    '🧙🏽‍♂' => 'zintnieks: vidējs ādas tonis',
    '🧙🏾‍♂' => 'zintnieks: vidēji tumšs ādas tonis',
    '🧙🏿‍♂' => 'zintnieks: tumšs ādas tonis',
    '🧙🏻‍♀' => 'zintniece: gaišs ādas tonis',
    '🧙🏼‍♀' => 'zintniece: vidēji gaišs ādas tonis',
    '🧙🏽‍♀' => 'zintniece: vidējs ādas tonis',
    '🧙🏾‍♀' => 'zintniece: vidēji tumšs ādas tonis',
    '🧙🏿‍♀' => 'zintniece: tumšs ādas tonis',
    '🧚🏻‍♂' => 'laumiņš: gaišs ādas tonis',
    '🧚🏼‍♂' => 'laumiņš: vidēji gaišs ādas tonis',
    '🧚🏽‍♂' => 'laumiņš: vidējs ādas tonis',
    '🧚🏾‍♂' => 'laumiņš: vidēji tumšs ādas tonis',
    '🧚🏿‍♂' => 'laumiņš: tumšs ādas tonis',
    '🧚🏻‍♀' => 'laumiņa: gaišs ādas tonis',
    '🧚🏼‍♀' => 'laumiņa: vidēji gaišs ādas tonis',
    '🧚🏽‍♀' => 'laumiņa: vidējs ādas tonis',
    '🧚🏾‍♀' => 'laumiņa: vidēji tumšs ādas tonis',
    '🧚🏿‍♀' => 'laumiņa: tumšs ādas tonis',
    '🧛🏻‍♂' => 'vīriešu kārtas vampīrs: gaišs ādas tonis',
    '🧛🏼‍♂' => 'vīriešu kārtas vampīrs: vidēji gaišs ādas tonis',
    '🧛🏽‍♂' => 'vīriešu kārtas vampīrs: vidējs ādas tonis',
    '🧛🏾‍♂' => 'vīriešu kārtas vampīrs: vidēji tumšs ādas tonis',
    '🧛🏿‍♂' => 'vīriešu kārtas vampīrs: tumšs ādas tonis',
    '🧛🏻‍♀' => 'vampīre: gaišs ādas tonis',
    '🧛🏼‍♀' => 'vampīre: vidēji gaišs ādas tonis',
    '🧛🏽‍♀' => 'vampīre: vidējs ādas tonis',
    '🧛🏾‍♀' => 'vampīre: vidēji tumšs ādas tonis',
    '🧛🏿‍♀' => 'vampīre: tumšs ādas tonis',
    '🧜🏻‍♂' => 'vīrietis nāra: gaišs ādas tonis',
    '🧜🏼‍♂' => 'vīrietis nāra: vidēji gaišs ādas tonis',
    '🧜🏽‍♂' => 'vīrietis nāra: vidējs ādas tonis',
    '🧜🏾‍♂' => 'vīrietis nāra: vidēji tumšs ādas tonis',
    '🧜🏿‍♂' => 'vīrietis nāra: tumšs ādas tonis',
    '🧜🏻‍♀' => 'nāra: gaišs ādas tonis',
    '🧜🏼‍♀' => 'nāra: vidēji gaišs ādas tonis',
    '🧜🏽‍♀' => 'nāra: vidējs ādas tonis',
    '🧜🏾‍♀' => 'nāra: vidēji tumšs ādas tonis',
    '🧜🏿‍♀' => 'nāra: tumšs ādas tonis',
    '🧝🏻‍♂' => 'elfu vīrietis: gaišs ādas tonis',
    '🧝🏼‍♂' => 'elfu vīrietis: vidēji gaišs ādas tonis',
    '🧝🏽‍♂' => 'elfu vīrietis: vidējs ādas tonis',
    '🧝🏾‍♂' => 'elfu vīrietis: vidēji tumšs ādas tonis',
    '🧝🏿‍♂' => 'elfu vīrietis: tumšs ādas tonis',
    '🧝🏻‍♀' => 'elfa: gaišs ādas tonis',
    '🧝🏼‍♀' => 'elfa: vidēji gaišs ādas tonis',
    '🧝🏽‍♀' => 'elfa: vidējs ādas tonis',
    '🧝🏾‍♀' => 'elfa: vidēji tumšs ādas tonis',
    '🧝🏿‍♀' => 'elfa: tumšs ādas tonis',
    '💆🏻‍♂' => 'vīrietim masē seju: gaišs ādas tonis',
    '💆🏼‍♂' => 'vīrietim masē seju: vidēji gaišs ādas tonis',
    '💆🏽‍♂' => 'vīrietim masē seju: vidējs ādas tonis',
    '💆🏾‍♂' => 'vīrietim masē seju: vidēji tumšs ādas tonis',
    '💆🏿‍♂' => 'vīrietim masē seju: tumšs ādas tonis',
    '💆🏻‍♀' => 'sievietei masē seju: gaišs ādas tonis',
    '💆🏼‍♀' => 'sievietei masē seju: vidēji gaišs ādas tonis',
    '💆🏽‍♀' => 'sievietei masē seju: vidējs ādas tonis',
    '💆🏾‍♀' => 'sievietei masē seju: vidēji tumšs ādas tonis',
    '💆🏿‍♀' => 'sievietei masē seju: tumšs ādas tonis',
    '💇🏻‍♂' => 'vīrietis pie friziera: gaišs ādas tonis',
    '💇🏼‍♂' => 'vīrietis pie friziera: vidēji gaišs ādas tonis',
    '💇🏽‍♂' => 'vīrietis pie friziera: vidējs ādas tonis',
    '💇🏾‍♂' => 'vīrietis pie friziera: vidēji tumšs ādas tonis',
    '💇🏿‍♂' => 'vīrietis pie friziera: tumšs ādas tonis',
    '💇🏻‍♀' => 'sieviete pie friziera: gaišs ādas tonis',
    '💇🏼‍♀' => 'sieviete pie friziera: vidēji gaišs ādas tonis',
    '💇🏽‍♀' => 'sieviete pie friziera: vidējs ādas tonis',
    '💇🏾‍♀' => 'sieviete pie friziera: vidēji tumšs ādas tonis',
    '💇🏿‍♀' => 'sieviete pie friziera: tumšs ādas tonis',
    '🚶🏻‍♂' => 'vīrietis pastaigājas: gaišs ādas tonis',
    '🚶🏼‍♂' => 'vīrietis pastaigājas: vidēji gaišs ādas tonis',
    '🚶🏽‍♂' => 'vīrietis pastaigājas: vidējs ādas tonis',
    '🚶🏾‍♂' => 'vīrietis pastaigājas: vidēji tumšs ādas tonis',
    '🚶🏿‍♂' => 'vīrietis pastaigājas: tumšs ādas tonis',
    '🚶🏻‍♀' => 'sieviete pastaigājas: gaišs ādas tonis',
    '🚶🏼‍♀' => 'sieviete pastaigājas: vidēji gaišs ādas tonis',
    '🚶🏽‍♀' => 'sieviete pastaigājas: vidējs ādas tonis',
    '🚶🏾‍♀' => 'sieviete pastaigājas: vidēji tumšs ādas tonis',
    '🚶🏿‍♀' => 'sieviete pastaigājas: tumšs ādas tonis',
    '🚶🏻‍➡' => 'gājējs: gaišs ādas tonis un skatās pa labi',
    '🚶🏼‍➡' => 'gājējs: vidēji gaišs ādas tonis un skatās pa labi',
    '🚶🏽‍➡' => 'gājējs: vidējs ādas tonis un skatās pa labi',
    '🚶🏾‍➡' => 'gājējs: vidēji tumšs ādas tonis un skatās pa labi',
    '🚶🏿‍➡' => 'gājējs: tumšs ādas tonis un skatās pa labi',
    '🧍🏻‍♂' => 'stāvošs vīrietis: gaišs ādas tonis',
    '🧍🏼‍♂' => 'stāvošs vīrietis: vidēji gaišs ādas tonis',
    '🧍🏽‍♂' => 'stāvošs vīrietis: vidējs ādas tonis',
    '🧍🏾‍♂' => 'stāvošs vīrietis: vidēji tumšs ādas tonis',
    '🧍🏿‍♂' => 'stāvošs vīrietis: tumšs ādas tonis',
    '🧍🏻‍♀' => 'stāvoša sieviete: gaišs ādas tonis',
    '🧍🏼‍♀' => 'stāvoša sieviete: vidēji gaišs ādas tonis',
    '🧍🏽‍♀' => 'stāvoša sieviete: vidējs ādas tonis',
    '🧍🏾‍♀' => 'stāvoša sieviete: vidēji tumšs ādas tonis',
    '🧍🏿‍♀' => 'stāvoša sieviete: tumšs ādas tonis',
    '🧎🏻‍♂' => 'vīrietis uz ceļiem: gaišs ādas tonis',
    '🧎🏼‍♂' => 'vīrietis uz ceļiem: vidēji gaišs ādas tonis',
    '🧎🏽‍♂' => 'vīrietis uz ceļiem: vidējs ādas tonis',
    '🧎🏾‍♂' => 'vīrietis uz ceļiem: vidēji tumšs ādas tonis',
    '🧎🏿‍♂' => 'vīrietis uz ceļiem: tumšs ādas tonis',
    '🧎🏻‍♀' => 'sieviete uz ceļiem: gaišs ādas tonis',
    '🧎🏼‍♀' => 'sieviete uz ceļiem: vidēji gaišs ādas tonis',
    '🧎🏽‍♀' => 'sieviete uz ceļiem: vidējs ādas tonis',
    '🧎🏾‍♀' => 'sieviete uz ceļiem: vidēji tumšs ādas tonis',
    '🧎🏿‍♀' => 'sieviete uz ceļiem: tumšs ādas tonis',
    '🧎🏻‍➡' => 'persona uz ceļiem: gaišs ādas tonis un skatās pa labi',
    '🧎🏼‍➡' => 'persona uz ceļiem: vidēji gaišs ādas tonis un skatās pa labi',
    '🧎🏽‍➡' => 'persona uz ceļiem: vidējs ādas tonis un skatās pa labi',
    '🧎🏾‍➡' => 'persona uz ceļiem: vidēji tumšs ādas tonis un skatās pa labi',
    '🧎🏿‍➡' => 'persona uz ceļiem: tumšs ādas tonis un skatās pa labi',
    '🧑🏻‍🦯' => 'persona ar balto spieķi: gaišs ādas tonis',
    '🧑🏼‍🦯' => 'persona ar balto spieķi: vidēji gaišs ādas tonis',
    '🧑🏽‍🦯' => 'persona ar balto spieķi: vidējs ādas tonis',
    '🧑🏾‍🦯' => 'persona ar balto spieķi: vidēji tumšs ādas tonis',
    '🧑🏿‍🦯' => 'persona ar balto spieķi: tumšs ādas tonis',
    '👨🏻‍🦯' => 'vīrietis ar balto atbalsta spieķi: gaišs ādas tonis',
    '👨🏼‍🦯' => 'vīrietis ar balto atbalsta spieķi: vidēji gaišs ādas tonis',
    '👨🏽‍🦯' => 'vīrietis ar balto atbalsta spieķi: vidējs ādas tonis',
    '👨🏾‍🦯' => 'vīrietis ar balto atbalsta spieķi: vidēji tumšs ādas tonis',
    '👨🏿‍🦯' => 'vīrietis ar balto atbalsta spieķi: tumšs ādas tonis',
    '👩🏻‍🦯' => 'sieviete ar balto atbalsta spieķi: gaišs ādas tonis',
    '👩🏼‍🦯' => 'sieviete ar balto atbalsta spieķi: vidēji gaišs ādas tonis',
    '👩🏽‍🦯' => 'sieviete ar balto atbalsta spieķi: vidējs ādas tonis',
    '👩🏾‍🦯' => 'sieviete ar balto atbalsta spieķi: vidēji tumšs ādas tonis',
    '👩🏿‍🦯' => 'sieviete ar balto atbalsta spieķi: tumšs ādas tonis',
    '🧑🏻‍🦼' => 'persona ratiņkrēslā: gaišs ādas tonis',
    '🧑🏼‍🦼' => 'persona ratiņkrēslā: vidēji gaišs ādas tonis',
    '🧑🏽‍🦼' => 'persona ratiņkrēslā: vidējs ādas tonis',
    '🧑🏾‍🦼' => 'persona ratiņkrēslā: vidēji tumšs ādas tonis',
    '🧑🏿‍🦼' => 'persona ratiņkrēslā: tumšs ādas tonis',
    '👨🏻‍🦼' => 'vīrietis motorizētā ratiņkrēslā: gaišs ādas tonis',
    '👨🏼‍🦼' => 'vīrietis motorizētā ratiņkrēslā: vidēji gaišs ādas tonis',
    '👨🏽‍🦼' => 'vīrietis motorizētā ratiņkrēslā: vidējs ādas tonis',
    '👨🏾‍🦼' => 'vīrietis motorizētā ratiņkrēslā: vidēji tumšs ādas tonis',
    '👨🏿‍🦼' => 'vīrietis motorizētā ratiņkrēslā: tumšs ādas tonis',
    '👩🏻‍🦼' => 'sieviete motorizētā ratiņkrēslā: gaišs ādas tonis',
    '👩🏼‍🦼' => 'sieviete motorizētā ratiņkrēslā: vidēji gaišs ādas tonis',
    '👩🏽‍🦼' => 'sieviete motorizētā ratiņkrēslā: vidējs ādas tonis',
    '👩🏾‍🦼' => 'sieviete motorizētā ratiņkrēslā: vidēji tumšs ādas tonis',
    '👩🏿‍🦼' => 'sieviete motorizētā ratiņkrēslā: tumšs ādas tonis',
    '🧑🏻‍🦽' => 'persona manuālajā ratiņkrēslā: gaišs ādas tonis',
    '🧑🏼‍🦽' => 'persona manuālajā ratiņkrēslā: vidēji gaišs ādas tonis',
    '🧑🏽‍🦽' => 'persona manuālajā ratiņkrēslā: vidējs ādas tonis',
    '🧑🏾‍🦽' => 'persona manuālajā ratiņkrēslā: vidēji tumšs ādas tonis',
    '🧑🏿‍🦽' => 'persona manuālajā ratiņkrēslā: tumšs ādas tonis',
    '👨🏻‍🦽' => 'vīrietis manuālā ratiņkrēslā: gaišs ādas tonis',
    '👨🏼‍🦽' => 'vīrietis manuālā ratiņkrēslā: vidēji gaišs ādas tonis',
    '👨🏽‍🦽' => 'vīrietis manuālā ratiņkrēslā: vidējs ādas tonis',
    '👨🏾‍🦽' => 'vīrietis manuālā ratiņkrēslā: vidēji tumšs ādas tonis',
    '👨🏿‍🦽' => 'vīrietis manuālā ratiņkrēslā: tumšs ādas tonis',
    '👩🏻‍🦽' => 'sieviete manuālā ratiņkrēslā: gaišs ādas tonis',
    '👩🏼‍🦽' => 'sieviete manuālā ratiņkrēslā: vidēji gaišs ādas tonis',
    '👩🏽‍🦽' => 'sieviete manuālā ratiņkrēslā: vidējs ādas tonis',
    '👩🏾‍🦽' => 'sieviete manuālā ratiņkrēslā: vidēji tumšs ādas tonis',
    '👩🏿‍🦽' => 'sieviete manuālā ratiņkrēslā: tumšs ādas tonis',
    '🏃🏻‍♂' => 'vīrietis skrien: gaišs ādas tonis',
    '🏃🏼‍♂' => 'vīrietis skrien: vidēji gaišs ādas tonis',
    '🏃🏽‍♂' => 'vīrietis skrien: vidējs ādas tonis',
    '🏃🏾‍♂' => 'vīrietis skrien: vidēji tumšs ādas tonis',
    '🏃🏿‍♂' => 'vīrietis skrien: tumšs ādas tonis',
    '🏃🏻‍♀' => 'sieviete skrien: gaišs ādas tonis',
    '🏃🏼‍♀' => 'sieviete skrien: vidēji gaišs ādas tonis',
    '🏃🏽‍♀' => 'sieviete skrien: vidējs ādas tonis',
    '🏃🏾‍♀' => 'sieviete skrien: vidēji tumšs ādas tonis',
    '🏃🏿‍♀' => 'sieviete skrien: tumšs ādas tonis',
    '🏃🏻‍➡' => 'skrējējs: gaišs ādas tonis un skatās pa labi',
    '🏃🏼‍➡' => 'skrējējs: vidēji gaišs ādas tonis un skatās pa labi',
    '🏃🏽‍➡' => 'skrējējs: vidējs ādas tonis un skatās pa labi',
    '🏃🏾‍➡' => 'skrējējs: vidēji tumšs ādas tonis un skatās pa labi',
    '🏃🏿‍➡' => 'skrējējs: tumšs ādas tonis un skatās pa labi',
    '👯🏻‍♀' => 'dejotājas: gaišs ādas tonis',
    '👯🏼‍♀' => 'dejotājas: vidēji gaišs ādas tonis',
    '👯🏽‍♀' => 'dejotājas: vidējs ādas tonis',
    '👯🏾‍♀' => 'dejotājas: vidēji tumšs ādas tonis',
    '👯🏿‍♀' => 'dejotājas: tumšs ādas tonis',
    '👯🏻‍♂' => 'dejotāji: gaišs ādas tonis',
    '👯🏼‍♂' => 'dejotāji: vidēji gaišs ādas tonis',
    '👯🏽‍♂' => 'dejotāji: vidējs ādas tonis',
    '👯🏾‍♂' => 'dejotāji: vidēji tumšs ādas tonis',
    '👯🏿‍♂' => 'dejotāji: tumšs ādas tonis',
    '🧖🏻‍♂' => 'vīrietis tvaika telpā: gaišs ādas tonis',
    '🧖🏼‍♂' => 'vīrietis tvaika telpā: vidēji gaišs ādas tonis',
    '🧖🏽‍♂' => 'vīrietis tvaika telpā: vidējs ādas tonis',
    '🧖🏾‍♂' => 'vīrietis tvaika telpā: vidēji tumšs ādas tonis',
    '🧖🏿‍♂' => 'vīrietis tvaika telpā: tumšs ādas tonis',
    '🧖🏻‍♀' => 'sieviete tvaika telpā: gaišs ādas tonis',
    '🧖🏼‍♀' => 'sieviete tvaika telpā: vidēji gaišs ādas tonis',
    '🧖🏽‍♀' => 'sieviete tvaika telpā: vidējs ādas tonis',
    '🧖🏾‍♀' => 'sieviete tvaika telpā: vidēji tumšs ādas tonis',
    '🧖🏿‍♀' => 'sieviete tvaika telpā: tumšs ādas tonis',
    '🧗🏻‍♂' => 'alpīnists: gaišs ādas tonis',
    '🧗🏼‍♂' => 'alpīnists: vidēji gaišs ādas tonis',
    '🧗🏽‍♂' => 'alpīnists: vidējs ādas tonis',
    '🧗🏾‍♂' => 'alpīnists: vidēji tumšs ādas tonis',
    '🧗🏿‍♂' => 'alpīnists: tumšs ādas tonis',
    '🧗🏻‍♀' => 'alpīniste: gaišs ādas tonis',
    '🧗🏼‍♀' => 'alpīniste: vidēji gaišs ādas tonis',
    '🧗🏽‍♀' => 'alpīniste: vidējs ādas tonis',
    '🧗🏾‍♀' => 'alpīniste: vidēji tumšs ādas tonis',
    '🧗🏿‍♀' => 'alpīniste: tumšs ādas tonis',
    '🏌🏻‍♂' => 'vīrietis spēlē golfu: gaišs ādas tonis',
    '🏌🏼‍♂' => 'vīrietis spēlē golfu: vidēji gaišs ādas tonis',
    '🏌🏽‍♂' => 'vīrietis spēlē golfu: vidējs ādas tonis',
    '🏌🏾‍♂' => 'vīrietis spēlē golfu: vidēji tumšs ādas tonis',
    '🏌🏿‍♂' => 'vīrietis spēlē golfu: tumšs ādas tonis',
    '🏌🏻‍♀' => 'sieviete spēlē golfu: gaišs ādas tonis',
    '🏌🏼‍♀' => 'sieviete spēlē golfu: vidēji gaišs ādas tonis',
    '🏌🏽‍♀' => 'sieviete spēlē golfu: vidējs ādas tonis',
    '🏌🏾‍♀' => 'sieviete spēlē golfu: vidēji tumšs ādas tonis',
    '🏌🏿‍♀' => 'sieviete spēlē golfu: tumšs ādas tonis',
    '🏄🏻‍♂' => 'vīrietis sērfo: gaišs ādas tonis',
    '🏄🏼‍♂' => 'vīrietis sērfo: vidēji gaišs ādas tonis',
    '🏄🏽‍♂' => 'vīrietis sērfo: vidējs ādas tonis',
    '🏄🏾‍♂' => 'vīrietis sērfo: vidēji tumšs ādas tonis',
    '🏄🏿‍♂' => 'vīrietis sērfo: tumšs ādas tonis',
    '🏄🏻‍♀' => 'sieviete sērfo: gaišs ādas tonis',
    '🏄🏼‍♀' => 'sieviete sērfo: vidēji gaišs ādas tonis',
    '🏄🏽‍♀' => 'sieviete sērfo: vidējs ādas tonis',
    '🏄🏾‍♀' => 'sieviete sērfo: vidēji tumšs ādas tonis',
    '🏄🏿‍♀' => 'sieviete sērfo: tumšs ādas tonis',
    '🚣🏻‍♂' => 'airētājs: gaišs ādas tonis',
    '🚣🏼‍♂' => 'airētājs: vidēji gaišs ādas tonis',
    '🚣🏽‍♂' => 'airētājs: vidējs ādas tonis',
    '🚣🏾‍♂' => 'airētājs: vidēji tumšs ādas tonis',
    '🚣🏿‍♂' => 'airētājs: tumšs ādas tonis',
    '🚣🏻‍♀' => 'airētāja: gaišs ādas tonis',
    '🚣🏼‍♀' => 'airētāja: vidēji gaišs ādas tonis',
    '🚣🏽‍♀' => 'airētāja: vidējs ādas tonis',
    '🚣🏾‍♀' => 'airētāja: vidēji tumšs ādas tonis',
    '🚣🏿‍♀' => 'airētāja: tumšs ādas tonis',
    '🏊🏻‍♂' => 'vīrietis peld: gaišs ādas tonis',
    '🏊🏼‍♂' => 'vīrietis peld: vidēji gaišs ādas tonis',
    '🏊🏽‍♂' => 'vīrietis peld: vidējs ādas tonis',
    '🏊🏾‍♂' => 'vīrietis peld: vidēji tumšs ādas tonis',
    '🏊🏿‍♂' => 'vīrietis peld: tumšs ādas tonis',
    '🏊🏻‍♀' => 'peldētāja: gaišs ādas tonis',
    '🏊🏼‍♀' => 'peldētāja: vidēji gaišs ādas tonis',
    '🏊🏽‍♀' => 'peldētāja: vidējs ādas tonis',
    '🏊🏾‍♀' => 'peldētāja: vidēji tumšs ādas tonis',
    '🏊🏿‍♀' => 'peldētāja: tumšs ādas tonis',
    '⛹🏻‍♂' => 'vīrietis ar bumbu: gaišs ādas tonis',
    '⛹🏼‍♂' => 'vīrietis ar bumbu: vidēji gaišs ādas tonis',
    '⛹🏽‍♂' => 'vīrietis ar bumbu: vidējs ādas tonis',
    '⛹🏾‍♂' => 'vīrietis ar bumbu: vidēji tumšs ādas tonis',
    '⛹🏿‍♂' => 'vīrietis ar bumbu: tumšs ādas tonis',
    '⛹🏻‍♀' => 'sieviete ar bumbu: gaišs ādas tonis',
    '⛹🏼‍♀' => 'sieviete ar bumbu: vidēji gaišs ādas tonis',
    '⛹🏽‍♀' => 'sieviete ar bumbu: vidējs ādas tonis',
    '⛹🏾‍♀' => 'sieviete ar bumbu: vidēji tumšs ādas tonis',
    '⛹🏿‍♀' => 'sieviete ar bumbu: tumšs ādas tonis',
    '🏋🏻‍♂' => 'svarcēlājs: gaišs ādas tonis',
    '🏋🏼‍♂' => 'svarcēlājs: vidēji gaišs ādas tonis',
    '🏋🏽‍♂' => 'svarcēlājs: vidējs ādas tonis',
    '🏋🏾‍♂' => 'svarcēlājs: vidēji tumšs ādas tonis',
    '🏋🏿‍♂' => 'svarcēlājs: tumšs ādas tonis',
    '🏋🏻‍♀' => 'svarcēlāja: gaišs ādas tonis',
    '🏋🏼‍♀' => 'svarcēlāja: vidēji gaišs ādas tonis',
    '🏋🏽‍♀' => 'svarcēlāja: vidējs ādas tonis',
    '🏋🏾‍♀' => 'svarcēlāja: vidēji tumšs ādas tonis',
    '🏋🏿‍♀' => 'svarcēlāja: tumšs ādas tonis',
    '🚴🏻‍♂' => 'riteņbraucējs: gaišs ādas tonis',
    '🚴🏼‍♂' => 'riteņbraucējs: vidēji gaišs ādas tonis',
    '🚴🏽‍♂' => 'riteņbraucējs: vidējs ādas tonis',
    '🚴🏾‍♂' => 'riteņbraucējs: vidēji tumšs ādas tonis',
    '🚴🏿‍♂' => 'riteņbraucējs: tumšs ādas tonis',
    '🚴🏻‍♀' => 'riteņbraucēja: gaišs ādas tonis',
    '🚴🏼‍♀' => 'riteņbraucēja: vidēji gaišs ādas tonis',
    '🚴🏽‍♀' => 'riteņbraucēja: vidējs ādas tonis',
    '🚴🏾‍♀' => 'riteņbraucēja: vidēji tumšs ādas tonis',
    '🚴🏿‍♀' => 'riteņbraucēja: tumšs ādas tonis',
    '🚵🏻‍♂' => 'riteņbraucējs ar kalnu velosipēdu: gaišs ādas tonis',
    '🚵🏼‍♂' => 'riteņbraucējs ar kalnu velosipēdu: vidēji gaišs ādas tonis',
    '🚵🏽‍♂' => 'riteņbraucējs ar kalnu velosipēdu: vidējs ādas tonis',
    '🚵🏾‍♂' => 'riteņbraucējs ar kalnu velosipēdu: vidēji tumšs ādas tonis',
    '🚵🏿‍♂' => 'riteņbraucējs ar kalnu velosipēdu: tumšs ādas tonis',
    '🚵🏻‍♀' => 'riteņbraucēja ar kalnu velosipēdu: gaišs ādas tonis',
    '🚵🏼‍♀' => 'riteņbraucēja ar kalnu velosipēdu: vidēji gaišs ādas tonis',
    '🚵🏽‍♀' => 'riteņbraucēja ar kalnu velosipēdu: vidējs ādas tonis',
    '🚵🏾‍♀' => 'riteņbraucēja ar kalnu velosipēdu: vidēji tumšs ādas tonis',
    '🚵🏿‍♀' => 'riteņbraucēja ar kalnu velosipēdu: tumšs ādas tonis',
    '🤸🏻‍♂' => 'akrobāts: gaišs ādas tonis',
    '🤸🏼‍♂' => 'akrobāts: vidēji gaišs ādas tonis',
    '🤸🏽‍♂' => 'akrobāts: vidējs ādas tonis',
    '🤸🏾‍♂' => 'akrobāts: vidēji tumšs ādas tonis',
    '🤸🏿‍♂' => 'akrobāts: tumšs ādas tonis',
    '🤸🏻‍♀' => 'akrobāte: gaišs ādas tonis',
    '🤸🏼‍♀' => 'akrobāte: vidēji gaišs ādas tonis',
    '🤸🏽‍♀' => 'akrobāte: vidējs ādas tonis',
    '🤸🏾‍♀' => 'akrobāte: vidēji tumšs ādas tonis',
    '🤸🏿‍♀' => 'akrobāte: tumšs ādas tonis',
    '🤼🏻‍♀' => 'cīkstone: gaišs ādas tonis',
    '🤼🏼‍♀' => 'cīkstone: vidēji gaišs ādas tonis',
    '🤼🏽‍♀' => 'cīkstone: vidējs ādas tonis',
    '🤼🏾‍♀' => 'cīkstone: vidēji tumšs ādas tonis',
    '🤼🏿‍♀' => 'cīkstone: tumšs ādas tonis',
    '🤼🏻‍♂' => 'cīkstonis: gaišs ādas tonis',
    '🤼🏼‍♂' => 'cīkstonis: vidēji gaišs ādas tonis',
    '🤼🏽‍♂' => 'cīkstonis: vidējs ādas tonis',
    '🤼🏾‍♂' => 'cīkstonis: vidēji tumšs ādas tonis',
    '🤼🏿‍♂' => 'cīkstonis: tumšs ādas tonis',
    '🤽🏻‍♂' => 'ūdenspolo spēlētājs: gaišs ādas tonis',
    '🤽🏼‍♂' => 'ūdenspolo spēlētājs: vidēji gaišs ādas tonis',
    '🤽🏽‍♂' => 'ūdenspolo spēlētājs: vidējs ādas tonis',
    '🤽🏾‍♂' => 'ūdenspolo spēlētājs: vidēji tumšs ādas tonis',
    '🤽🏿‍♂' => 'ūdenspolo spēlētājs: tumšs ādas tonis',
    '🤽🏻‍♀' => 'ūdenspolo spēlētāja: gaišs ādas tonis',
    '🤽🏼‍♀' => 'ūdenspolo spēlētāja: vidēji gaišs ādas tonis',
    '🤽🏽‍♀' => 'ūdenspolo spēlētāja: vidējs ādas tonis',
    '🤽🏾‍♀' => 'ūdenspolo spēlētāja: vidēji tumšs ādas tonis',
    '🤽🏿‍♀' => 'ūdenspolo spēlētāja: tumšs ādas tonis',
    '🤾🏻‍♂' => 'rokasbumbas spēlētājs: gaišs ādas tonis',
    '🤾🏼‍♂' => 'rokasbumbas spēlētājs: vidēji gaišs ādas tonis',
    '🤾🏽‍♂' => 'rokasbumbas spēlētājs: vidējs ādas tonis',
    '🤾🏾‍♂' => 'rokasbumbas spēlētājs: vidēji tumšs ādas tonis',
    '🤾🏿‍♂' => 'rokasbumbas spēlētājs: tumšs ādas tonis',
    '🤾🏻‍♀' => 'rokasbumbas spēlētāja: gaišs ādas tonis',
    '🤾🏼‍♀' => 'rokasbumbas spēlētāja: vidēji gaišs ādas tonis',
    '🤾🏽‍♀' => 'rokasbumbas spēlētāja: vidējs ādas tonis',
    '🤾🏾‍♀' => 'rokasbumbas spēlētāja: vidēji tumšs ādas tonis',
    '🤾🏿‍♀' => 'rokasbumbas spēlētāja: tumšs ādas tonis',
    '🤹🏻‍♂' => 'žonglieris: gaišs ādas tonis',
    '🤹🏼‍♂' => 'žonglieris: vidēji gaišs ādas tonis',
    '🤹🏽‍♂' => 'žonglieris: vidējs ādas tonis',
    '🤹🏾‍♂' => 'žonglieris: vidēji tumšs ādas tonis',
    '🤹🏿‍♂' => 'žonglieris: tumšs ādas tonis',
    '🤹🏻‍♀' => 'žongliere: gaišs ādas tonis',
    '🤹🏼‍♀' => 'žongliere: vidēji gaišs ādas tonis',
    '🤹🏽‍♀' => 'žongliere: vidējs ādas tonis',
    '🤹🏾‍♀' => 'žongliere: vidēji tumšs ādas tonis',
    '🤹🏿‍♀' => 'žongliere: tumšs ādas tonis',
    '🧘🏻‍♂' => 'vīrietis lotosa pozā: gaišs ādas tonis',
    '🧘🏼‍♂' => 'vīrietis lotosa pozā: vidēji gaišs ādas tonis',
    '🧘🏽‍♂' => 'vīrietis lotosa pozā: vidējs ādas tonis',
    '🧘🏾‍♂' => 'vīrietis lotosa pozā: vidēji tumšs ādas tonis',
    '🧘🏿‍♂' => 'vīrietis lotosa pozā: tumšs ādas tonis',
    '🧘🏻‍♀' => 'sieviete lotosa pozā: gaišs ādas tonis',
    '🧘🏼‍♀' => 'sieviete lotosa pozā: vidēji gaišs ādas tonis',
    '🧘🏽‍♀' => 'sieviete lotosa pozā: vidējs ādas tonis',
    '🧘🏾‍♀' => 'sieviete lotosa pozā: vidēji tumšs ādas tonis',
    '🧘🏿‍♀' => 'sieviete lotosa pozā: tumšs ādas tonis',
    '🧑‍🦰' => 'pieaugušais: sarkani mati',
    '🧑‍🦱' => 'pieaugušais: sprogaini mati',
    '🧑‍🦳' => 'pieaugušais: sirmi mati',
    '🧑‍🦲' => 'pieaugušais: bez matiem',
    '👨‍🦰' => 'vīrietis: sarkani mati',
    '👨‍🦱' => 'vīrietis: sprogaini mati',
    '👨‍🦳' => 'vīrietis: sirmi mati',
    '👨‍🦲' => 'vīrietis: bez matiem',
    '👩‍🦰' => 'sieviete: sarkani mati',
    '👩‍🦱' => 'sieviete: sprogaini mati',
    '👩‍🦳' => 'sieviete: sirmi mati',
    '👩‍🦲' => 'sieviete: bez matiem',
    '🚶‍➡' => 'gājējs: skatās pa labi',
    '🧎‍➡' => 'persona uz ceļiem: skatās pa labi',
    '🏃‍➡' => 'skrējējs: skatās pa labi',
    '👨‍👦' => 'ģimene: vīrietis un zēns',
    '👨‍👧' => 'ģimene: vīrietis un meitene',
    '👩‍👦' => 'ģimene: sieviete un zēns',
    '👩‍👧' => 'ģimene: sieviete un meitene',
    '😶‍🌫' => 'seja mākoņos',
    '😮‍💨' => 'nopūta',
    '🙂‍↕' => 'krata galvu vertikāli',
    '😵‍💫' => 'seja ar spirālēm acu vietā',
    '❤‍🔥' => 'degoša sirds',
    '❤‍🩹' => 'pārsieta sirds',
    '👁‍🗨' => 'liecinieka zīme',
    '🧔‍♂' => 'vīrietis ar bārdu',
    '👱‍♂' => 'blondīns',
    '🧔‍♀' => 'sieviete ar bārdu',
    '👱‍♀' => 'blondīne',
    '🙍‍♂' => 'norūpējies vīrietis',
    '🙍‍♀' => 'norūpējusies sieviete',
    '🙎‍♂' => 'sabozies vīrietis',
    '🙎‍♀' => 'sabozusies sieviete',
    '🙅‍♂' => 'vīrietis ar aizlieguma žestu',
    '🙅‍♀' => 'sieviete ar aizlieguma žestu',
    '🙆‍♂' => 'vīrietis ar apstiprinājuma žestu',
    '🙆‍♀' => 'sieviete ar apstiprinājuma žestu',
    '💁‍♂' => 'vīrietis ar pastieptu roku',
    '💁‍♀' => 'sieviete ar pastieptu roku',
    '🙋‍♂' => 'vīrietis ar paceltu roku',
    '🙋‍♀' => 'sieviete ar paceltu roku',
    '🧏‍♂' => 'nedzirdīgs vīrietis',
    '🧏‍♀' => 'nedzirdīga sieviete',
    '🙇‍♂' => 'vīrietis paklanās',
    '🙇‍♀' => 'sieviete paklanās',
    '🤦‍♂' => 'vīrietis ar saķertu galvu',
    '🤦‍♀' => 'sieviete ar saķertu galvu',
    '🤷‍♂' => 'vīrietis rausta plecus',
    '🤷‍♀' => 'sieviete rausta plecus',
    '🧑‍⚕' => 'veselības aprūpes darbinieks',
    '👨‍⚕' => 'veselības aprūpes speciālists',
    '👩‍⚕' => 'veselības aprūpes speciāliste',
    '🧑‍🎓' => 'absolvents',
    '👨‍🎓' => 'students',
    '👩‍🎓' => 'studente',
    '🧑‍🏫' => 'pedagogs',
    '👨‍🏫' => 'skolotājs',
    '👩‍🏫' => 'skolotāja',
    '🧑‍⚖' => 'soģis',
    '👨‍⚖' => 'tiesnesis',
    '👩‍⚖' => 'tiesnese',
    '🧑‍🌾' => 'fermeris',
    '👨‍🌾' => 'lauksaimnieks',
    '👩‍🌾' => 'lauksaimniece',
    '🧑‍🍳' => 'vīrietis pavārs',
    '👨‍🍳' => 'pavārs',
    '👩‍🍳' => 'pavāre',
    '🧑‍🔧' => 'vīrietis mehāniķis',
    '👨‍🔧' => 'mehāniķis',
    '👩‍🔧' => 'mehāniķe',
    '🧑‍🏭' => 'rūpnīcas strādnieks',
    '👨‍🏭' => 'fabrikas strādnieks',
    '👩‍🏭' => 'fabrikas strādniece',
    '🧑‍💼' => 'vīrietis biroja darbinieks',
    '👨‍💼' => 'biroja darbinieks',
    '👩‍💼' => 'biroja darbiniece',
    '🧑‍🔬' => 'vīrietis zinātnieks',
    '👨‍🔬' => 'zinātnieks',
    '👩‍🔬' => 'zinātniece',
    '🧑‍💻' => 'vīrietis tehniķis',
    '👨‍💻' => 'tehniķis',
    '👩‍💻' => 'tehniķe',
    '🧑‍🎤' => 'vīrietis dziedātājs',
    '👨‍🎤' => 'dziedātājs',
    '👩‍🎤' => 'dziedātāja',
    '🧑‍🎨' => 'vīrietis mākslinieks',
    '👨‍🎨' => 'mākslinieks',
    '👩‍🎨' => 'māksliniece',
    '🧑‍✈' => 'vīrietis pilots',
    '👨‍✈' => 'pilots',
    '👩‍✈' => 'pilote',
    '🧑‍🚀' => 'vīrietis astronauts',
    '👨‍🚀' => 'astronauts',
    '👩‍🚀' => 'astronaute',
    '🧑‍🚒' => 'vīrietis ugunsdzēsējs',
    '👨‍🚒' => 'ugunsdzēsējs',
    '👩‍🚒' => 'ugunsdzēsēja',
    '👮‍♂' => 'policijas virsnieks',
    '👮‍♀' => 'policiste',
    '🕵‍♂' => 'detektīvs (vīrietis)',
    '🕵‍♀' => 'detektīve',
    '💂‍♂' => 'apsargs',
    '💂‍♀' => 'sardze',
    '👷‍♂' => 'būvstrādnieks',
    '👷‍♀' => 'būvstrādniece',
    '👳‍♂' => 'vīrietis ar turbānu',
    '👳‍♀' => 'sieviete ar turbānu',
    '🤵‍♂' => 'vīrietis smokingā',
    '🤵‍♀' => 'sieviete smokingā',
    '👰‍♂' => 'vīrietis ar plīvuru',
    '👰‍♀' => 'sieviete ar plīvuru',
    '👩‍🍼' => 'sieviete baro bērnu',
    '👨‍🍼' => 'bērnu barojošs cilvēks',
    '🧑‍🍼' => 'persona baro bērnu',
    '🧑‍🎄' => 'dzimumneitrāls santaklauss',
    '🦸‍♂' => 'vīrietis supervaronis',
    '🦸‍♀' => 'sieviete supervarone',
    '🦹‍♂' => 'superļaunais vīrietis',
    '🦹‍♀' => 'superļaunā sieviete',
    '🧙‍♂' => 'zintnieks',
    '🧙‍♀' => 'zintniece',
    '🧚‍♂' => 'laumiņš',
    '🧚‍♀' => 'laumiņa',
    '🧛‍♂' => 'vīriešu kārtas vampīrs',
    '🧛‍♀' => 'vampīre',
    '🧜‍♂' => 'vīrietis nāra',
    '🧜‍♀' => 'nāra',
    '🧝‍♂' => 'elfu vīrietis',
    '🧝‍♀' => 'elfa',
    '🧞‍♂' => 'vīrietis džins',
    '🧞‍♀' => 'sieviete džins',
    '🧟‍♂' => 'zombijvīrietis',
    '🧟‍♀' => 'zombijsieviete',
    '💆‍♂' => 'vīrietim masē seju',
    '💆‍♀' => 'sievietei masē seju',
    '💇‍♂' => 'vīrietis pie friziera',
    '💇‍♀' => 'sieviete pie friziera',
    '🚶‍♂' => 'vīrietis pastaigājas',
    '🚶‍♀' => 'sieviete pastaigājas',
    '🧍‍♂' => 'stāvošs vīrietis',
    '🧍‍♀' => 'stāvoša sieviete',
    '🧎‍♂' => 'vīrietis uz ceļiem',
    '🧎‍♀' => 'sieviete uz ceļiem',
    '🧑‍🦯' => 'persona ar balto spieķi',
    '👨‍🦯' => 'vīrietis ar balto atbalsta spieķi',
    '👩‍🦯' => 'sieviete ar balto atbalsta spieķi',
    '🧑‍🦼' => 'persona ratiņkrēslā',
    '👨‍🦼' => 'vīrietis motorizētā ratiņkrēslā',
    '👩‍🦼' => 'sieviete motorizētā ratiņkrēslā',
    '🧑‍🦽' => 'persona manuālajā ratiņkrēslā',
    '👨‍🦽' => 'vīrietis manuālā ratiņkrēslā',
    '👩‍🦽' => 'sieviete manuālā ratiņkrēslā',
    '🏃‍♂' => 'vīrietis skrien',
    '🏃‍♀' => 'sieviete skrien',
    '🧑‍🩰' => 'baletdejotājs',
    '👯‍♂' => 'dejotāji',
    '👯‍♀' => 'dejotājas',
    '🧖‍♂' => 'vīrietis tvaika telpā',
    '🧖‍♀' => 'sieviete tvaika telpā',
    '🧗‍♂' => 'alpīnists',
    '🧗‍♀' => 'alpīniste',
    '🏌‍♂' => 'vīrietis spēlē golfu',
    '🏌‍♀' => 'sieviete spēlē golfu',
    '🏄‍♂' => 'vīrietis sērfo',
    '🏄‍♀' => 'sieviete sērfo',
    '🚣‍♂' => 'airētājs',
    '🚣‍♀' => 'airētāja',
    '🏊‍♂' => 'vīrietis peld',
    '🏊‍♀' => 'peldētāja',
    '⛹‍♂' => 'vīrietis ar bumbu',
    '⛹‍♀' => 'sieviete ar bumbu',
    '🏋‍♂' => 'svarcēlājs',
    '🏋‍♀' => 'svarcēlāja',
    '🚴‍♂' => 'riteņbraucējs',
    '🚴‍♀' => 'riteņbraucēja',
    '🚵‍♂' => 'riteņbraucējs ar kalnu velosipēdu',
    '🚵‍♀' => 'riteņbraucēja ar kalnu velosipēdu',
    '🤸‍♂' => 'akrobāts',
    '🤸‍♀' => 'akrobāte',
    '🤼‍♂' => 'cīkstonis',
    '🤼‍♀' => 'cīkstone',
    '🤽‍♂' => 'ūdenspolo spēlētājs',
    '🤽‍♀' => 'ūdenspolo spēlētāja',
    '🤾‍♂' => 'rokasbumbas spēlētājs',
    '🤾‍♀' => 'rokasbumbas spēlētāja',
    '🤹‍♂' => 'žonglieris',
    '🤹‍♀' => 'žongliere',
    '🧘‍♂' => 'vīrietis lotosa pozā',
    '🧘‍♀' => 'sieviete lotosa pozā',
    '🧑‍🧒' => 'ģimene: pieaugušais, bērns',
    '🐕‍🦺' => 'dienesta suns',
    '🐈‍⬛' => 'melns kaķis',
    '🐻‍❄' => 'polārlācis',
    '🐦‍⬛' => 'melns putns',
    '🐦‍🔥' => 'fēnikss',
    '🍋‍🟩' => 'laims',
    '🍄‍🟫' => 'brūna sēne',
    '⛓‍💥' => 'saplēsta ķēde',
    '🏳‍🌈' => 'varavīksnes karogs',
    '🏳‍⚧' => 'zils, rozā un balts karogs',
    '🏴‍☠' => 'pirātu karogs',
    '👋🏻' => 'mājoša roka: gaišs ādas tonis',
    '👋🏼' => 'mājoša roka: vidēji gaišs ādas tonis',
    '👋🏽' => 'mājoša roka: vidējs ādas tonis',
    '👋🏾' => 'mājoša roka: vidēji tumšs ādas tonis',
    '👋🏿' => 'mājoša roka: tumšs ādas tonis',
    '🤚🏻' => 'pacelta plauksta: gaišs ādas tonis',
    '🤚🏼' => 'pacelta plauksta: vidēji gaišs ādas tonis',
    '🤚🏽' => 'pacelta plauksta: vidējs ādas tonis',
    '🤚🏾' => 'pacelta plauksta: vidēji tumšs ādas tonis',
    '🤚🏿' => 'pacelta plauksta: tumšs ādas tonis',
    '🖐🏻' => 'pacelta roka ar izvērstiem pirkstiem: gaišs ādas tonis',
    '🖐🏼' => 'pacelta roka ar izvērstiem pirkstiem: vidēji gaišs ādas tonis',
    '🖐🏽' => 'pacelta roka ar izvērstiem pirkstiem: vidējs ādas tonis',
    '🖐🏾' => 'pacelta roka ar izvērstiem pirkstiem: vidēji tumšs ādas tonis',
    '🖐🏿' => 'pacelta roka ar izvērstiem pirkstiem: tumšs ādas tonis',
    '✋🏻' => 'pacelta roka: gaišs ādas tonis',
    '✋🏼' => 'pacelta roka: vidēji gaišs ādas tonis',
    '✋🏽' => 'pacelta roka: vidējs ādas tonis',
    '✋🏾' => 'pacelta roka: vidēji tumšs ādas tonis',
    '✋🏿' => 'pacelta roka: tumšs ādas tonis',
    '🖖🏻' => 'vulkāniešu sveiciens: gaišs ādas tonis',
    '🖖🏼' => 'vulkāniešu sveiciens: vidēji gaišs ādas tonis',
    '🖖🏽' => 'vulkāniešu sveiciens: vidējs ādas tonis',
    '🖖🏾' => 'vulkāniešu sveiciens: vidēji tumšs ādas tonis',
    '🖖🏿' => 'vulkāniešu sveiciens: tumšs ādas tonis',
    '🫱🏻' => 'labā roka: gaišs ādas tonis',
    '🫱🏼' => 'labā roka: vidēji gaišs ādas tonis',
    '🫱🏽' => 'labā roka: vidējs ādas tonis',
    '🫱🏾' => 'labā roka: vidēji tumšs ādas tonis',
    '🫱🏿' => 'labā roka: tumšs ādas tonis',
    '🫲🏻' => 'kreiso roku: gaišs ādas tonis',
    '🫲🏼' => 'kreiso roku: vidēji gaišs ādas tonis',
    '🫲🏽' => 'kreiso roku: vidējs ādas tonis',
    '🫲🏾' => 'kreiso roku: vidēji tumšs ādas tonis',
    '🫲🏿' => 'kreiso roku: tumšs ādas tonis',
    '🫳🏻' => 'plaukstu uz leju: gaišs ādas tonis',
    '🫳🏼' => 'plaukstu uz leju: vidēji gaišs ādas tonis',
    '🫳🏽' => 'plaukstu uz leju: vidējs ādas tonis',
    '🫳🏾' => 'plaukstu uz leju: vidēji tumšs ādas tonis',
    '🫳🏿' => 'plaukstu uz leju: tumšs ādas tonis',
    '🫴🏻' => 'plaukstu uz augšu: gaišs ādas tonis',
    '🫴🏼' => 'plaukstu uz augšu: vidēji gaišs ādas tonis',
    '🫴🏽' => 'plaukstu uz augšu: vidējs ādas tonis',
    '🫴🏾' => 'plaukstu uz augšu: vidēji tumšs ādas tonis',
    '🫴🏿' => 'plaukstu uz augšu: tumšs ādas tonis',
    '🫷🏻' => 'pa kreisi spiedoša roka: gaišs ādas tonis',
    '🫷🏼' => 'pa kreisi spiedoša roka: vidēji gaišs ādas tonis',
    '🫷🏽' => 'pa kreisi spiedoša roka: vidējs ādas tonis',
    '🫷🏾' => 'pa kreisi spiedoša roka: vidēji tumšs ādas tonis',
    '🫷🏿' => 'pa kreisi spiedoša roka: tumšs ādas tonis',
    '🫸🏻' => 'pa labi spiedoša roka: gaišs ādas tonis',
    '🫸🏼' => 'pa labi spiedoša roka: vidēji gaišs ādas tonis',
    '🫸🏽' => 'pa labi spiedoša roka: vidējs ādas tonis',
    '🫸🏾' => 'pa labi spiedoša roka: vidēji tumšs ādas tonis',
    '🫸🏿' => 'pa labi spiedoša roka: tumšs ādas tonis',
    '👌🏻' => 'simbols OK: gaišs ādas tonis',
    '👌🏼' => 'simbols OK: vidēji gaišs ādas tonis',
    '👌🏽' => 'simbols OK: vidējs ādas tonis',
    '👌🏾' => 'simbols OK: vidēji tumšs ādas tonis',
    '👌🏿' => 'simbols OK: tumšs ādas tonis',
    '🤌🏻' => 'pastiepti pirksti: gaišs ādas tonis',
    '🤌🏼' => 'pastiepti pirksti: vidēji gaišs ādas tonis',
    '🤌🏽' => 'pastiepti pirksti: vidējs ādas tonis',
    '🤌🏾' => 'pastiepti pirksti: vidēji tumšs ādas tonis',
    '🤌🏿' => 'pastiepti pirksti: tumšs ādas tonis',
    '🤏🏻' => 'roka rāda drusciņu: gaišs ādas tonis',
    '🤏🏼' => 'roka rāda drusciņu: vidēji gaišs ādas tonis',
    '🤏🏽' => 'roka rāda drusciņu: vidējs ādas tonis',
    '🤏🏾' => 'roka rāda drusciņu: vidēji tumšs ādas tonis',
    '🤏🏿' => 'roka rāda drusciņu: tumšs ādas tonis',
    '✌🏻' => 'uzvaras simbols: gaišs ādas tonis',
    '✌🏼' => 'uzvaras simbols: vidēji gaišs ādas tonis',
    '✌🏽' => 'uzvaras simbols: vidējs ādas tonis',
    '✌🏾' => 'uzvaras simbols: vidēji tumšs ādas tonis',
    '✌🏿' => 'uzvaras simbols: tumšs ādas tonis',
    '🤞🏻' => 'sakrustoti pirksti: gaišs ādas tonis',
    '🤞🏼' => 'sakrustoti pirksti: vidēji gaišs ādas tonis',
    '🤞🏽' => 'sakrustoti pirksti: vidējs ādas tonis',
    '🤞🏾' => 'sakrustoti pirksti: vidēji tumšs ādas tonis',
    '🤞🏿' => 'sakrustoti pirksti: tumšs ādas tonis',
    '🫰🏻' => 'roka ar rādītājpirkstu un īkšķi sakrustota: gaišs ādas tonis',
    '🫰🏼' => 'roka ar rādītājpirkstu un īkšķi sakrustota: vidēji gaišs ādas tonis',
    '🫰🏽' => 'roka ar rādītājpirkstu un īkšķi sakrustota: vidējs ādas tonis',
    '🫰🏾' => 'roka ar rādītājpirkstu un īkšķi sakrustota: vidēji tumšs ādas tonis',
    '🫰🏿' => 'roka ar rādītājpirkstu un īkšķi sakrustota: tumšs ādas tonis',
    '🤟🏻' => 'mīlas žests: gaišs ādas tonis',
    '🤟🏼' => 'mīlas žests: vidēji gaišs ādas tonis',
    '🤟🏽' => 'mīlas žests: vidējs ādas tonis',
    '🤟🏾' => 'mīlas žests: vidēji tumšs ādas tonis',
    '🤟🏿' => 'mīlas žests: tumšs ādas tonis',
    '🤘🏻' => 'ragu simbols: gaišs ādas tonis',
    '🤘🏼' => 'ragu simbols: vidēji gaišs ādas tonis',
    '🤘🏽' => 'ragu simbols: vidējs ādas tonis',
    '🤘🏾' => 'ragu simbols: vidēji tumšs ādas tonis',
    '🤘🏿' => 'ragu simbols: tumšs ādas tonis',
    '🤙🏻' => 'piezvani man: gaišs ādas tonis',
    '🤙🏼' => 'piezvani man: vidēji gaišs ādas tonis',
    '🤙🏽' => 'piezvani man: vidējs ādas tonis',
    '🤙🏾' => 'piezvani man: vidēji tumšs ādas tonis',
    '🤙🏿' => 'piezvani man: tumšs ādas tonis',
    '👈🏻' => 'pa kreisi vērsts rādītājpirksts: gaišs ādas tonis',
    '👈🏼' => 'pa kreisi vērsts rādītājpirksts: vidēji gaišs ādas tonis',
    '👈🏽' => 'pa kreisi vērsts rādītājpirksts: vidējs ādas tonis',
    '👈🏾' => 'pa kreisi vērsts rādītājpirksts: vidēji tumšs ādas tonis',
    '👈🏿' => 'pa kreisi vērsts rādītājpirksts: tumšs ādas tonis',
    '👉🏻' => 'pa labi vērsts rādītājpirksts: gaišs ādas tonis',
    '👉🏼' => 'pa labi vērsts rādītājpirksts: vidēji gaišs ādas tonis',
    '👉🏽' => 'pa labi vērsts rādītājpirksts: vidējs ādas tonis',
    '👉🏾' => 'pa labi vērsts rādītājpirksts: vidēji tumšs ādas tonis',
    '👉🏿' => 'pa labi vērsts rādītājpirksts: tumšs ādas tonis',
    '👆🏻' => 'augšup vērsts rādītājpirksts ar prom vērstu delnu: gaišs ādas tonis',
    '👆🏼' => 'augšup vērsts rādītājpirksts ar prom vērstu delnu: vidēji gaišs ādas tonis',
    '👆🏽' => 'augšup vērsts rādītājpirksts ar prom vērstu delnu: vidējs ādas tonis',
    '👆🏾' => 'augšup vērsts rādītājpirksts ar prom vērstu delnu: vidēji tumšs ādas tonis',
    '👆🏿' => 'augšup vērsts rādītājpirksts ar prom vērstu delnu: tumšs ādas tonis',
    '🖕🏻' => 'vidējais pirksts: gaišs ādas tonis',
    '🖕🏼' => 'vidējais pirksts: vidēji gaišs ādas tonis',
    '🖕🏽' => 'vidējais pirksts: vidējs ādas tonis',
    '🖕🏾' => 'vidējais pirksts: vidēji tumšs ādas tonis',
    '🖕🏿' => 'vidējais pirksts: tumšs ādas tonis',
    '👇🏻' => 'lejup vērsts rādītājpirksts: gaišs ādas tonis',
    '👇🏼' => 'lejup vērsts rādītājpirksts: vidēji gaišs ādas tonis',
    '👇🏽' => 'lejup vērsts rādītājpirksts: vidējs ādas tonis',
    '👇🏾' => 'lejup vērsts rādītājpirksts: vidēji tumšs ādas tonis',
    '👇🏿' => 'lejup vērsts rādītājpirksts: tumšs ādas tonis',
    '☝🏻' => 'augšup vērsts rādītājpirksts: gaišs ādas tonis',
    '☝🏼' => 'augšup vērsts rādītājpirksts: vidēji gaišs ādas tonis',
    '☝🏽' => 'augšup vērsts rādītājpirksts: vidējs ādas tonis',
    '☝🏾' => 'augšup vērsts rādītājpirksts: vidēji tumšs ādas tonis',
    '☝🏿' => 'augšup vērsts rādītājpirksts: tumšs ādas tonis',
    '🫵🏻' => 'rādītājpirksts pret sevi: gaišs ādas tonis',
    '🫵🏼' => 'rādītājpirksts pret sevi: vidēji gaišs ādas tonis',
    '🫵🏽' => 'rādītājpirksts pret sevi: vidējs ādas tonis',
    '🫵🏾' => 'rādītājpirksts pret sevi: vidēji tumšs ādas tonis',
    '🫵🏿' => 'rādītājpirksts pret sevi: tumšs ādas tonis',
    '👍🏻' => 'augšupvērsts īkšķis: gaišs ādas tonis',
    '👍🏼' => 'augšupvērsts īkšķis: vidēji gaišs ādas tonis',
    '👍🏽' => 'augšupvērsts īkšķis: vidējs ādas tonis',
    '👍🏾' => 'augšupvērsts īkšķis: vidēji tumšs ādas tonis',
    '👍🏿' => 'augšupvērsts īkšķis: tumšs ādas tonis',
    '👎🏻' => 'lejupvērsts īkšķis: gaišs ādas tonis',
    '👎🏼' => 'lejupvērsts īkšķis: vidēji gaišs ādas tonis',
    '👎🏽' => 'lejupvērsts īkšķis: vidējs ādas tonis',
    '👎🏾' => 'lejupvērsts īkšķis: vidēji tumšs ādas tonis',
    '👎🏿' => 'lejupvērsts īkšķis: tumšs ādas tonis',
    '✊🏻' => 'pacelta dūre: gaišs ādas tonis',
    '✊🏼' => 'pacelta dūre: vidēji gaišs ādas tonis',
    '✊🏽' => 'pacelta dūre: vidējs ādas tonis',
    '✊🏾' => 'pacelta dūre: vidēji tumšs ādas tonis',
    '✊🏿' => 'pacelta dūre: tumšs ādas tonis',
    '👊🏻' => 'pretim vērsta dūre: gaišs ādas tonis',
    '👊🏼' => 'pretim vērsta dūre: vidēji gaišs ādas tonis',
    '👊🏽' => 'pretim vērsta dūre: vidējs ādas tonis',
    '👊🏾' => 'pretim vērsta dūre: vidēji tumšs ādas tonis',
    '👊🏿' => 'pretim vērsta dūre: tumšs ādas tonis',
    '🤛🏻' => 'dūre pa kreisi: gaišs ādas tonis',
    '🤛🏼' => 'dūre pa kreisi: vidēji gaišs ādas tonis',
    '🤛🏽' => 'dūre pa kreisi: vidējs ādas tonis',
    '🤛🏾' => 'dūre pa kreisi: vidēji tumšs ādas tonis',
    '🤛🏿' => 'dūre pa kreisi: tumšs ādas tonis',
    '🤜🏻' => 'dūre pa labi: gaišs ādas tonis',
    '🤜🏼' => 'dūre pa labi: vidēji gaišs ādas tonis',
    '🤜🏽' => 'dūre pa labi: vidējs ādas tonis',
    '🤜🏾' => 'dūre pa labi: vidēji tumšs ādas tonis',
    '🤜🏿' => 'dūre pa labi: tumšs ādas tonis',
    '👏🏻' => 'aplausi: gaišs ādas tonis',
    '👏🏼' => 'aplausi: vidēji gaišs ādas tonis',
    '👏🏽' => 'aplausi: vidējs ādas tonis',
    '👏🏾' => 'aplausi: vidēji tumšs ādas tonis',
    '👏🏿' => 'aplausi: tumšs ādas tonis',
    '🙌🏻' => 'paceltas rokas: gaišs ādas tonis',
    '🙌🏼' => 'paceltas rokas: vidēji gaišs ādas tonis',
    '🙌🏽' => 'paceltas rokas: vidējs ādas tonis',
    '🙌🏾' => 'paceltas rokas: vidēji tumšs ādas tonis',
    '🙌🏿' => 'paceltas rokas: tumšs ādas tonis',
    '🫶🏻' => 'sirds žests: gaišs ādas tonis',
    '🫶🏼' => 'sirds žests: vidēji gaišs ādas tonis',
    '🫶🏽' => 'sirds žests: vidējs ādas tonis',
    '🫶🏾' => 'sirds žests: vidēji tumšs ādas tonis',
    '🫶🏿' => 'sirds žests: tumšs ādas tonis',
    '👐🏻' => 'atvērtas rokas: gaišs ādas tonis',
    '👐🏼' => 'atvērtas rokas: vidēji gaišs ādas tonis',
    '👐🏽' => 'atvērtas rokas: vidējs ādas tonis',
    '👐🏾' => 'atvērtas rokas: vidēji tumšs ādas tonis',
    '👐🏿' => 'atvērtas rokas: tumšs ādas tonis',
    '🤲🏻' => 'plaukstas kopā: gaišs ādas tonis',
    '🤲🏼' => 'plaukstas kopā: vidēji gaišs ādas tonis',
    '🤲🏽' => 'plaukstas kopā: vidējs ādas tonis',
    '🤲🏾' => 'plaukstas kopā: vidēji tumšs ādas tonis',
    '🤲🏿' => 'plaukstas kopā: tumšs ādas tonis',
    '🤝🏻' => 'rokasspiediens: gaišs ādas tonis',
    '🤝🏼' => 'rokasspiediens: vidēji gaišs ādas tonis',
    '🤝🏽' => 'rokasspiediens: vidējs ādas tonis',
    '🤝🏾' => 'rokasspiediens: vidēji tumšs ādas tonis',
    '🤝🏿' => 'rokasspiediens: tumšs ādas tonis',
    '🙏🏻' => 'lūgšanā saliktas rokas: gaišs ādas tonis',
    '🙏🏼' => 'lūgšanā saliktas rokas: vidēji gaišs ādas tonis',
    '🙏🏽' => 'lūgšanā saliktas rokas: vidējs ādas tonis',
    '🙏🏾' => 'lūgšanā saliktas rokas: vidēji tumšs ādas tonis',
    '🙏🏿' => 'lūgšanā saliktas rokas: tumšs ādas tonis',
    '✍🏻' => 'rakstoša roka: gaišs ādas tonis',
    '✍🏼' => 'rakstoša roka: vidēji gaišs ādas tonis',
    '✍🏽' => 'rakstoša roka: vidējs ādas tonis',
    '✍🏾' => 'rakstoša roka: vidēji tumšs ādas tonis',
    '✍🏿' => 'rakstoša roka: tumšs ādas tonis',
    '💅🏻' => 'nagu laka: gaišs ādas tonis',
    '💅🏼' => 'nagu laka: vidēji gaišs ādas tonis',
    '💅🏽' => 'nagu laka: vidējs ādas tonis',
    '💅🏾' => 'nagu laka: vidēji tumšs ādas tonis',
    '💅🏿' => 'nagu laka: tumšs ādas tonis',
    '🤳🏻' => 'pašfoto: gaišs ādas tonis',
    '🤳🏼' => 'pašfoto: vidēji gaišs ādas tonis',
    '🤳🏽' => 'pašfoto: vidējs ādas tonis',
    '🤳🏾' => 'pašfoto: vidēji tumšs ādas tonis',
    '🤳🏿' => 'pašfoto: tumšs ādas tonis',
    '💪🏻' => 'bicepss: gaišs ādas tonis',
    '💪🏼' => 'bicepss: vidēji gaišs ādas tonis',
    '💪🏽' => 'bicepss: vidējs ādas tonis',
    '💪🏾' => 'bicepss: vidēji tumšs ādas tonis',
    '💪🏿' => 'bicepss: tumšs ādas tonis',
    '🦵🏻' => 'kāja: gaišs ādas tonis',
    '🦵🏼' => 'kāja: vidēji gaišs ādas tonis',
    '🦵🏽' => 'kāja: vidējs ādas tonis',
    '🦵🏾' => 'kāja: vidēji tumšs ādas tonis',
    '🦵🏿' => 'kāja: tumšs ādas tonis',
    '🦶🏻' => 'pēda: gaišs ādas tonis',
    '🦶🏼' => 'pēda: vidēji gaišs ādas tonis',
    '🦶🏽' => 'pēda: vidējs ādas tonis',
    '🦶🏾' => 'pēda: vidēji tumšs ādas tonis',
    '🦶🏿' => 'pēda: tumšs ādas tonis',
    '👂🏻' => 'auss: gaišs ādas tonis',
    '👂🏼' => 'auss: vidēji gaišs ādas tonis',
    '👂🏽' => 'auss: vidējs ādas tonis',
    '👂🏾' => 'auss: vidēji tumšs ādas tonis',
    '👂🏿' => 'auss: tumšs ādas tonis',
    '🦻🏻' => 'auss ar dzirdes aparātu: gaišs ādas tonis',
    '🦻🏼' => 'auss ar dzirdes aparātu: vidēji gaišs ādas tonis',
    '🦻🏽' => 'auss ar dzirdes aparātu: vidējs ādas tonis',
    '🦻🏾' => 'auss ar dzirdes aparātu: vidēji tumšs ādas tonis',
    '🦻🏿' => 'auss ar dzirdes aparātu: tumšs ādas tonis',
    '👃🏻' => 'deguns: gaišs ādas tonis',
    '👃🏼' => 'deguns: vidēji gaišs ādas tonis',
    '👃🏽' => 'deguns: vidējs ādas tonis',
    '👃🏾' => 'deguns: vidēji tumšs ādas tonis',
    '👃🏿' => 'deguns: tumšs ādas tonis',
    '👶🏻' => 'zīdainis: gaišs ādas tonis',
    '👶🏼' => 'zīdainis: vidēji gaišs ādas tonis',
    '👶🏽' => 'zīdainis: vidējs ādas tonis',
    '👶🏾' => 'zīdainis: vidēji tumšs ādas tonis',
    '👶🏿' => 'zīdainis: tumšs ādas tonis',
    '🧒🏻' => 'bērns: gaišs ādas tonis',
    '🧒🏼' => 'bērns: vidēji gaišs ādas tonis',
    '🧒🏽' => 'bērns: vidējs ādas tonis',
    '🧒🏾' => 'bērns: vidēji tumšs ādas tonis',
    '🧒🏿' => 'bērns: tumšs ādas tonis',
    '👦🏻' => 'zēns: gaišs ādas tonis',
    '👦🏼' => 'zēns: vidēji gaišs ādas tonis',
    '👦🏽' => 'zēns: vidējs ādas tonis',
    '👦🏾' => 'zēns: vidēji tumšs ādas tonis',
    '👦🏿' => 'zēns: tumšs ādas tonis',
    '👧🏻' => 'meitene: gaišs ādas tonis',
    '👧🏼' => 'meitene: vidēji gaišs ādas tonis',
    '👧🏽' => 'meitene: vidējs ādas tonis',
    '👧🏾' => 'meitene: vidēji tumšs ādas tonis',
    '👧🏿' => 'meitene: tumšs ādas tonis',
    '🧑🏻' => 'pieaugušais: gaišs ādas tonis',
    '🧑🏼' => 'pieaugušais: vidēji gaišs ādas tonis',
    '🧑🏽' => 'pieaugušais: vidējs ādas tonis',
    '🧑🏾' => 'pieaugušais: vidēji tumšs ādas tonis',
    '🧑🏿' => 'pieaugušais: tumšs ādas tonis',
    '👱🏻' => 'blonds cilvēks: gaišs ādas tonis',
    '👱🏼' => 'blonds cilvēks: vidēji gaišs ādas tonis',
    '👱🏽' => 'blonds cilvēks: vidējs ādas tonis',
    '👱🏾' => 'blonds cilvēks: vidēji tumšs ādas tonis',
    '👱🏿' => 'blonds cilvēks: tumšs ādas tonis',
    '👨🏻' => 'vīrietis: gaišs ādas tonis',
    '👨🏼' => 'vīrietis: vidēji gaišs ādas tonis',
    '👨🏽' => 'vīrietis: vidējs ādas tonis',
    '👨🏾' => 'vīrietis: vidēji tumšs ādas tonis',
    '👨🏿' => 'vīrietis: tumšs ādas tonis',
    '🧔🏻' => 'bārdains vīrietis: gaišs ādas tonis',
    '🧔🏼' => 'bārdains vīrietis: vidēji gaišs ādas tonis',
    '🧔🏽' => 'bārdains vīrietis: vidējs ādas tonis',
    '🧔🏾' => 'bārdains vīrietis: vidēji tumšs ādas tonis',
    '🧔🏿' => 'bārdains vīrietis: tumšs ādas tonis',
    '👩🏻' => 'sieviete: gaišs ādas tonis',
    '👩🏼' => 'sieviete: vidēji gaišs ādas tonis',
    '👩🏽' => 'sieviete: vidējs ādas tonis',
    '👩🏾' => 'sieviete: vidēji tumšs ādas tonis',
    '👩🏿' => 'sieviete: tumšs ādas tonis',
    '🧓🏻' => 'vecāks pieaugušais: gaišs ādas tonis',
    '🧓🏼' => 'vecāks pieaugušais: vidēji gaišs ādas tonis',
    '🧓🏽' => 'vecāks pieaugušais: vidējs ādas tonis',
    '🧓🏾' => 'vecāks pieaugušais: vidēji tumšs ādas tonis',
    '🧓🏿' => 'vecāks pieaugušais: tumšs ādas tonis',
    '👴🏻' => 'vecs vīrietis: gaišs ādas tonis',
    '👴🏼' => 'vecs vīrietis: vidēji gaišs ādas tonis',
    '👴🏽' => 'vecs vīrietis: vidējs ādas tonis',
    '👴🏾' => 'vecs vīrietis: vidēji tumšs ādas tonis',
    '👴🏿' => 'vecs vīrietis: tumšs ādas tonis',
    '👵🏻' => 'veca sieviete: gaišs ādas tonis',
    '👵🏼' => 'veca sieviete: vidēji gaišs ādas tonis',
    '👵🏽' => 'veca sieviete: vidējs ādas tonis',
    '👵🏾' => 'veca sieviete: vidēji tumšs ādas tonis',
    '👵🏿' => 'veca sieviete: tumšs ādas tonis',
    '🙍🏻' => 'norūpējies cilvēks: gaišs ādas tonis',
    '🙍🏼' => 'norūpējies cilvēks: vidēji gaišs ādas tonis',
    '🙍🏽' => 'norūpējies cilvēks: vidējs ādas tonis',
    '🙍🏾' => 'norūpējies cilvēks: vidēji tumšs ādas tonis',
    '🙍🏿' => 'norūpējies cilvēks: tumšs ādas tonis',
    '🙎🏻' => 'sabozies cilvēks: gaišs ādas tonis',
    '🙎🏼' => 'sabozies cilvēks: vidēji gaišs ādas tonis',
    '🙎🏽' => 'sabozies cilvēks: vidējs ādas tonis',
    '🙎🏾' => 'sabozies cilvēks: vidēji tumšs ādas tonis',
    '🙎🏿' => 'sabozies cilvēks: tumšs ādas tonis',
    '🙅🏻' => 'cilvēks ar aizlieguma žestu: gaišs ādas tonis',
    '🙅🏼' => 'cilvēks ar aizlieguma žestu: vidēji gaišs ādas tonis',
    '🙅🏽' => 'cilvēks ar aizlieguma žestu: vidējs ādas tonis',
    '🙅🏾' => 'cilvēks ar aizlieguma žestu: vidēji tumšs ādas tonis',
    '🙅🏿' => 'cilvēks ar aizlieguma žestu: tumšs ādas tonis',
    '🙆🏻' => 'cilvēks ar apstiprinājuma žestu: gaišs ādas tonis',
    '🙆🏼' => 'cilvēks ar apstiprinājuma žestu: vidēji gaišs ādas tonis',
    '🙆🏽' => 'cilvēks ar apstiprinājuma žestu: vidējs ādas tonis',
    '🙆🏾' => 'cilvēks ar apstiprinājuma žestu: vidēji tumšs ādas tonis',
    '🙆🏿' => 'cilvēks ar apstiprinājuma žestu: tumšs ādas tonis',
    '💁🏻' => 'persona ar pastieptu roku: gaišs ādas tonis',
    '💁🏼' => 'persona ar pastieptu roku: vidēji gaišs ādas tonis',
    '💁🏽' => 'persona ar pastieptu roku: vidējs ādas tonis',
    '💁🏾' => 'persona ar pastieptu roku: vidēji tumšs ādas tonis',
    '💁🏿' => 'persona ar pastieptu roku: tumšs ādas tonis',
    '🙋🏻' => 'cilvēks ar paceltu roku: gaišs ādas tonis',
    '🙋🏼' => 'cilvēks ar paceltu roku: vidēji gaišs ādas tonis',
    '🙋🏽' => 'cilvēks ar paceltu roku: vidējs ādas tonis',
    '🙋🏾' => 'cilvēks ar paceltu roku: vidēji tumšs ādas tonis',
    '🙋🏿' => 'cilvēks ar paceltu roku: tumšs ādas tonis',
    '🧏🏻' => 'nedzirdīga persona: gaišs ādas tonis',
    '🧏🏼' => 'nedzirdīga persona: vidēji gaišs ādas tonis',
    '🧏🏽' => 'nedzirdīga persona: vidējs ādas tonis',
    '🧏🏾' => 'nedzirdīga persona: vidēji tumšs ādas tonis',
    '🧏🏿' => 'nedzirdīga persona: tumšs ādas tonis',
    '🙇🏻' => 'cilvēks paklanās: gaišs ādas tonis',
    '🙇🏼' => 'cilvēks paklanās: vidēji gaišs ādas tonis',
    '🙇🏽' => 'cilvēks paklanās: vidējs ādas tonis',
    '🙇🏾' => 'cilvēks paklanās: vidēji tumšs ādas tonis',
    '🙇🏿' => 'cilvēks paklanās: tumšs ādas tonis',
    '🤦🏻' => 'cilvēks ar saķertu galvu: gaišs ādas tonis',
    '🤦🏼' => 'cilvēks ar saķertu galvu: vidēji gaišs ādas tonis',
    '🤦🏽' => 'cilvēks ar saķertu galvu: vidējs ādas tonis',
    '🤦🏾' => 'cilvēks ar saķertu galvu: vidēji tumšs ādas tonis',
    '🤦🏿' => 'cilvēks ar saķertu galvu: tumšs ādas tonis',
    '🤷🏻' => 'rausta plecus: gaišs ādas tonis',
    '🤷🏼' => 'rausta plecus: vidēji gaišs ādas tonis',
    '🤷🏽' => 'rausta plecus: vidējs ādas tonis',
    '🤷🏾' => 'rausta plecus: vidēji tumšs ādas tonis',
    '🤷🏿' => 'rausta plecus: tumšs ādas tonis',
    '👮🏻' => 'policists: gaišs ādas tonis',
    '👮🏼' => 'policists: vidēji gaišs ādas tonis',
    '👮🏽' => 'policists: vidējs ādas tonis',
    '👮🏾' => 'policists: vidēji tumšs ādas tonis',
    '👮🏿' => 'policists: tumšs ādas tonis',
    '🕵🏻' => 'detektīvs: gaišs ādas tonis',
    '🕵🏼' => 'detektīvs: vidēji gaišs ādas tonis',
    '🕵🏽' => 'detektīvs: vidējs ādas tonis',
    '🕵🏾' => 'detektīvs: vidēji tumšs ādas tonis',
    '🕵🏿' => 'detektīvs: tumšs ādas tonis',
    '💂🏻' => 'sargs: gaišs ādas tonis',
    '💂🏼' => 'sargs: vidēji gaišs ādas tonis',
    '💂🏽' => 'sargs: vidējs ādas tonis',
    '💂🏾' => 'sargs: vidēji tumšs ādas tonis',
    '💂🏿' => 'sargs: tumšs ādas tonis',
    '🥷🏻' => 'nindzja: gaišs ādas tonis',
    '🥷🏼' => 'nindzja: vidēji gaišs ādas tonis',
    '🥷🏽' => 'nindzja: vidējs ādas tonis',
    '🥷🏾' => 'nindzja: vidēji tumšs ādas tonis',
    '🥷🏿' => 'nindzja: tumšs ādas tonis',
    '👷🏻' => 'celtnieks: gaišs ādas tonis',
    '👷🏼' => 'celtnieks: vidēji gaišs ādas tonis',
    '👷🏽' => 'celtnieks: vidējs ādas tonis',
    '👷🏾' => 'celtnieks: vidēji tumšs ādas tonis',
    '👷🏿' => 'celtnieks: tumšs ādas tonis',
    '🫅🏻' => 'persona ar vainagu: gaišs ādas tonis',
    '🫅🏼' => 'persona ar vainagu: vidēji gaišs ādas tonis',
    '🫅🏽' => 'persona ar vainagu: vidējs ādas tonis',
    '🫅🏾' => 'persona ar vainagu: vidēji tumšs ādas tonis',
    '🫅🏿' => 'persona ar vainagu: tumšs ādas tonis',
    '🤴🏻' => 'princis: gaišs ādas tonis',
    '🤴🏼' => 'princis: vidēji gaišs ādas tonis',
    '🤴🏽' => 'princis: vidējs ādas tonis',
    '🤴🏾' => 'princis: vidēji tumšs ādas tonis',
    '🤴🏿' => 'princis: tumšs ādas tonis',
    '👸🏻' => 'princese: gaišs ādas tonis',
    '👸🏼' => 'princese: vidēji gaišs ādas tonis',
    '👸🏽' => 'princese: vidējs ādas tonis',
    '👸🏾' => 'princese: vidēji tumšs ādas tonis',
    '👸🏿' => 'princese: tumšs ādas tonis',
    '👳🏻' => 'persona ar turbānu: gaišs ādas tonis',
    '👳🏼' => 'persona ar turbānu: vidēji gaišs ādas tonis',
    '👳🏽' => 'persona ar turbānu: vidējs ādas tonis',
    '👳🏾' => 'persona ar turbānu: vidēji tumšs ādas tonis',
    '👳🏿' => 'persona ar turbānu: tumšs ādas tonis',
    '👲🏻' => 'vīrietis ar ķīniešu cepuri: gaišs ādas tonis',
    '👲🏼' => 'vīrietis ar ķīniešu cepuri: vidēji gaišs ādas tonis',
    '👲🏽' => 'vīrietis ar ķīniešu cepuri: vidējs ādas tonis',
    '👲🏾' => 'vīrietis ar ķīniešu cepuri: vidēji tumšs ādas tonis',
    '👲🏿' => 'vīrietis ar ķīniešu cepuri: tumšs ādas tonis',
    '🧕🏻' => 'sieviete ar lakatu: gaišs ādas tonis',
    '🧕🏼' => 'sieviete ar lakatu: vidēji gaišs ādas tonis',
    '🧕🏽' => 'sieviete ar lakatu: vidējs ādas tonis',
    '🧕🏾' => 'sieviete ar lakatu: vidēji tumšs ādas tonis',
    '🧕🏿' => 'sieviete ar lakatu: tumšs ādas tonis',
    '🤵🏻' => 'persona smokingā: gaišs ādas tonis',
    '🤵🏼' => 'persona smokingā: vidēji gaišs ādas tonis',
    '🤵🏽' => 'persona smokingā: vidējs ādas tonis',
    '🤵🏾' => 'persona smokingā: vidēji tumšs ādas tonis',
    '🤵🏿' => 'persona smokingā: tumšs ādas tonis',
    '👰🏻' => 'cilvēks ar plīvuru: gaišs ādas tonis',
    '👰🏼' => 'cilvēks ar plīvuru: vidēji gaišs ādas tonis',
    '👰🏽' => 'cilvēks ar plīvuru: vidējs ādas tonis',
    '👰🏾' => 'cilvēks ar plīvuru: vidēji tumšs ādas tonis',
    '👰🏿' => 'cilvēks ar plīvuru: tumšs ādas tonis',
    '🤰🏻' => 'sieviete stāvoklī: gaišs ādas tonis',
    '🤰🏼' => 'sieviete stāvoklī: vidēji gaišs ādas tonis',
    '🤰🏽' => 'sieviete stāvoklī: vidējs ādas tonis',
    '🤰🏾' => 'sieviete stāvoklī: vidēji tumšs ādas tonis',
    '🤰🏿' => 'sieviete stāvoklī: tumšs ādas tonis',
    '🫃🏻' => 'vīrietis stāvoklī: gaišs ādas tonis',
    '🫃🏼' => 'vīrietis stāvoklī: vidēji gaišs ādas tonis',
    '🫃🏽' => 'vīrietis stāvoklī: vidējs ādas tonis',
    '🫃🏾' => 'vīrietis stāvoklī: vidēji tumšs ādas tonis',
    '🫃🏿' => 'vīrietis stāvoklī: tumšs ādas tonis',
    '🫄🏻' => 'cilvēks stāvoklī: gaišs ādas tonis',
    '🫄🏼' => 'cilvēks stāvoklī: vidēji gaišs ādas tonis',
    '🫄🏽' => 'cilvēks stāvoklī: vidējs ādas tonis',
    '🫄🏾' => 'cilvēks stāvoklī: vidēji tumšs ādas tonis',
    '🫄🏿' => 'cilvēks stāvoklī: tumšs ādas tonis',
    '🤱🏻' => 'barošana ar krūti: gaišs ādas tonis',
    '🤱🏼' => 'barošana ar krūti: vidēji gaišs ādas tonis',
    '🤱🏽' => 'barošana ar krūti: vidējs ādas tonis',
    '🤱🏾' => 'barošana ar krūti: vidēji tumšs ādas tonis',
    '🤱🏿' => 'barošana ar krūti: tumšs ādas tonis',
    '👼🏻' => 'mazs eņģelītis: gaišs ādas tonis',
    '👼🏼' => 'mazs eņģelītis: vidēji gaišs ādas tonis',
    '👼🏽' => 'mazs eņģelītis: vidējs ādas tonis',
    '👼🏾' => 'mazs eņģelītis: vidēji tumšs ādas tonis',
    '👼🏿' => 'mazs eņģelītis: tumšs ādas tonis',
    '🎅🏻' => 'Ziemassvētku vecītis: gaišs ādas tonis',
    '🎅🏼' => 'Ziemassvētku vecītis: vidēji gaišs ādas tonis',
    '🎅🏽' => 'Ziemassvētku vecītis: vidējs ādas tonis',
    '🎅🏾' => 'Ziemassvētku vecītis: vidēji tumšs ādas tonis',
    '🎅🏿' => 'Ziemassvētku vecītis: tumšs ādas tonis',
    '🤶🏻' => 'Ziemassvētku omīte: gaišs ādas tonis',
    '🤶🏼' => 'Ziemassvētku omīte: vidēji gaišs ādas tonis',
    '🤶🏽' => 'Ziemassvētku omīte: vidējs ādas tonis',
    '🤶🏾' => 'Ziemassvētku omīte: vidēji tumšs ādas tonis',
    '🤶🏿' => 'Ziemassvētku omīte: tumšs ādas tonis',
    '🦸🏻' => 'supervaronis: gaišs ādas tonis',
    '🦸🏼' => 'supervaronis: vidēji gaišs ādas tonis',
    '🦸🏽' => 'supervaronis: vidējs ādas tonis',
    '🦸🏾' => 'supervaronis: vidēji tumšs ādas tonis',
    '🦸🏿' => 'supervaronis: tumšs ādas tonis',
    '🦹🏻' => 'superļaunais: gaišs ādas tonis',
    '🦹🏼' => 'superļaunais: vidēji gaišs ādas tonis',
    '🦹🏽' => 'superļaunais: vidējs ādas tonis',
    '🦹🏾' => 'superļaunais: vidēji tumšs ādas tonis',
    '🦹🏿' => 'superļaunais: tumšs ādas tonis',
    '🧙🏻' => 'mags: gaišs ādas tonis',
    '🧙🏼' => 'mags: vidēji gaišs ādas tonis',
    '🧙🏽' => 'mags: vidējs ādas tonis',
    '🧙🏾' => 'mags: vidēji tumšs ādas tonis',
    '🧙🏿' => 'mags: tumšs ādas tonis',
    '🧚🏻' => 'feja: gaišs ādas tonis',
    '🧚🏼' => 'feja: vidēji gaišs ādas tonis',
    '🧚🏽' => 'feja: vidējs ādas tonis',
    '🧚🏾' => 'feja: vidēji tumšs ādas tonis',
    '🧚🏿' => 'feja: tumšs ādas tonis',
    '🧛🏻' => 'vampīrs: gaišs ādas tonis',
    '🧛🏼' => 'vampīrs: vidēji gaišs ādas tonis',
    '🧛🏽' => 'vampīrs: vidējs ādas tonis',
    '🧛🏾' => 'vampīrs: vidēji tumšs ādas tonis',
    '🧛🏿' => 'vampīrs: tumšs ādas tonis',
    '🧜🏻' => 'cilvēks nāra: gaišs ādas tonis',
    '🧜🏼' => 'cilvēks nāra: vidēji gaišs ādas tonis',
    '🧜🏽' => 'cilvēks nāra: vidējs ādas tonis',
    '🧜🏾' => 'cilvēks nāra: vidēji tumšs ādas tonis',
    '🧜🏿' => 'cilvēks nāra: tumšs ādas tonis',
    '🧝🏻' => 'elfs: gaišs ādas tonis',
    '🧝🏼' => 'elfs: vidēji gaišs ādas tonis',
    '🧝🏽' => 'elfs: vidējs ādas tonis',
    '🧝🏾' => 'elfs: vidēji tumšs ādas tonis',
    '🧝🏿' => 'elfs: tumšs ādas tonis',
    '💆🏻' => 'sejas masāža: gaišs ādas tonis',
    '💆🏼' => 'sejas masāža: vidēji gaišs ādas tonis',
    '💆🏽' => 'sejas masāža: vidējs ādas tonis',
    '💆🏾' => 'sejas masāža: vidēji tumšs ādas tonis',
    '💆🏿' => 'sejas masāža: tumšs ādas tonis',
    '💇🏻' => 'frizūra: gaišs ādas tonis',
    '💇🏼' => 'frizūra: vidēji gaišs ādas tonis',
    '💇🏽' => 'frizūra: vidējs ādas tonis',
    '💇🏾' => 'frizūra: vidēji tumšs ādas tonis',
    '💇🏿' => 'frizūra: tumšs ādas tonis',
    '🚶🏻' => 'gājējs: gaišs ādas tonis',
    '🚶🏼' => 'gājējs: vidēji gaišs ādas tonis',
    '🚶🏽' => 'gājējs: vidējs ādas tonis',
    '🚶🏾' => 'gājējs: vidēji tumšs ādas tonis',
    '🚶🏿' => 'gājējs: tumšs ādas tonis',
    '🧍🏻' => 'stāvoša persona: gaišs ādas tonis',
    '🧍🏼' => 'stāvoša persona: vidēji gaišs ādas tonis',
    '🧍🏽' => 'stāvoša persona: vidējs ādas tonis',
    '🧍🏾' => 'stāvoša persona: vidēji tumšs ādas tonis',
    '🧍🏿' => 'stāvoša persona: tumšs ādas tonis',
    '🧎🏻' => 'persona uz ceļiem: gaišs ādas tonis',
    '🧎🏼' => 'persona uz ceļiem: vidēji gaišs ādas tonis',
    '🧎🏽' => 'persona uz ceļiem: vidējs ādas tonis',
    '🧎🏾' => 'persona uz ceļiem: vidēji tumšs ādas tonis',
    '🧎🏿' => 'persona uz ceļiem: tumšs ādas tonis',
    '🏃🏻' => 'skrējējs: gaišs ādas tonis',
    '🏃🏼' => 'skrējējs: vidēji gaišs ādas tonis',
    '🏃🏽' => 'skrējējs: vidējs ādas tonis',
    '🏃🏾' => 'skrējējs: vidēji tumšs ādas tonis',
    '🏃🏿' => 'skrējējs: tumšs ādas tonis',
    '💃🏻' => 'sieviete dejo: gaišs ādas tonis',
    '💃🏼' => 'sieviete dejo: vidēji gaišs ādas tonis',
    '💃🏽' => 'sieviete dejo: vidējs ādas tonis',
    '💃🏾' => 'sieviete dejo: vidēji tumšs ādas tonis',
    '💃🏿' => 'sieviete dejo: tumšs ādas tonis',
    '🕺🏻' => 'vīrietis dejo: gaišs ādas tonis',
    '🕺🏼' => 'vīrietis dejo: vidēji gaišs ādas tonis',
    '🕺🏽' => 'vīrietis dejo: vidējs ādas tonis',
    '🕺🏾' => 'vīrietis dejo: vidēji tumšs ādas tonis',
    '🕺🏿' => 'vīrietis dejo: tumšs ādas tonis',
    '🕴🏻' => 'levitējošs cilvēks uzvalkā: gaišs ādas tonis',
    '🕴🏼' => 'levitējošs cilvēks uzvalkā: vidēji gaišs ādas tonis',
    '🕴🏽' => 'levitējošs cilvēks uzvalkā: vidējs ādas tonis',
    '🕴🏾' => 'levitējošs cilvēks uzvalkā: vidēji tumšs ādas tonis',
    '🕴🏿' => 'levitējošs cilvēks uzvalkā: tumšs ādas tonis',
    '👯🏻' => 'dejotāju šovs: gaišs ādas tonis',
    '👯🏼' => 'dejotāju šovs: vidēji gaišs ādas tonis',
    '👯🏽' => 'dejotāju šovs: vidējs ādas tonis',
    '👯🏾' => 'dejotāju šovs: vidēji tumšs ādas tonis',
    '👯🏿' => 'dejotāju šovs: tumšs ādas tonis',
    '🧖🏻' => 'cilvēks tvaika telpā: gaišs ādas tonis',
    '🧖🏼' => 'cilvēks tvaika telpā: vidēji gaišs ādas tonis',
    '🧖🏽' => 'cilvēks tvaika telpā: vidējs ādas tonis',
    '🧖🏾' => 'cilvēks tvaika telpā: vidēji tumšs ādas tonis',
    '🧖🏿' => 'cilvēks tvaika telpā: tumšs ādas tonis',
    '🧗🏻' => 'kalnā kāpējs: gaišs ādas tonis',
    '🧗🏼' => 'kalnā kāpējs: vidēji gaišs ādas tonis',
    '🧗🏽' => 'kalnā kāpējs: vidējs ādas tonis',
    '🧗🏾' => 'kalnā kāpējs: vidēji tumšs ādas tonis',
    '🧗🏿' => 'kalnā kāpējs: tumšs ādas tonis',
    '🏇🏻' => 'zirgu skriešanās sacīkstes: gaišs ādas tonis',
    '🏇🏼' => 'zirgu skriešanās sacīkstes: vidēji gaišs ādas tonis',
    '🏇🏽' => 'zirgu skriešanās sacīkstes: vidējs ādas tonis',
    '🏇🏾' => 'zirgu skriešanās sacīkstes: vidēji tumšs ādas tonis',
    '🏇🏿' => 'zirgu skriešanās sacīkstes: tumšs ādas tonis',
    '🏂🏻' => 'snovbordists: gaišs ādas tonis',
    '🏂🏼' => 'snovbordists: vidēji gaišs ādas tonis',
    '🏂🏽' => 'snovbordists: vidējs ādas tonis',
    '🏂🏾' => 'snovbordists: vidēji tumšs ādas tonis',
    '🏂🏿' => 'snovbordists: tumšs ādas tonis',
    '🏌🏻' => 'golfa spēlētājs: gaišs ādas tonis',
    '🏌🏼' => 'golfa spēlētājs: vidēji gaišs ādas tonis',
    '🏌🏽' => 'golfa spēlētājs: vidējs ādas tonis',
    '🏌🏾' => 'golfa spēlētājs: vidēji tumšs ādas tonis',
    '🏌🏿' => 'golfa spēlētājs: tumšs ādas tonis',
    '🏄🏻' => 'sērfotājs: gaišs ādas tonis',
    '🏄🏼' => 'sērfotājs: vidēji gaišs ādas tonis',
    '🏄🏽' => 'sērfotājs: vidējs ādas tonis',
    '🏄🏾' => 'sērfotājs: vidēji tumšs ādas tonis',
    '🏄🏿' => 'sērfotājs: tumšs ādas tonis',
    '🚣🏻' => 'cilvēks airē: gaišs ādas tonis',
    '🚣🏼' => 'cilvēks airē: vidēji gaišs ādas tonis',
    '🚣🏽' => 'cilvēks airē: vidējs ādas tonis',
    '🚣🏾' => 'cilvēks airē: vidēji tumšs ādas tonis',
    '🚣🏿' => 'cilvēks airē: tumšs ādas tonis',
    '🏊🏻' => 'peldētājs: gaišs ādas tonis',
    '🏊🏼' => 'peldētājs: vidēji gaišs ādas tonis',
    '🏊🏽' => 'peldētājs: vidējs ādas tonis',
    '🏊🏾' => 'peldētājs: vidēji tumšs ādas tonis',
    '🏊🏿' => 'peldētājs: tumšs ādas tonis',
    '⛹🏻' => 'cilvēks driblē bumbu: gaišs ādas tonis',
    '⛹🏼' => 'cilvēks driblē bumbu: vidēji gaišs ādas tonis',
    '⛹🏽' => 'cilvēks driblē bumbu: vidējs ādas tonis',
    '⛹🏾' => 'cilvēks driblē bumbu: vidēji tumšs ādas tonis',
    '⛹🏿' => 'cilvēks driblē bumbu: tumšs ādas tonis',
    '🏋🏻' => 'cilvēks ar svaru stieni: gaišs ādas tonis',
    '🏋🏼' => 'cilvēks ar svaru stieni: vidēji gaišs ādas tonis',
    '🏋🏽' => 'cilvēks ar svaru stieni: vidējs ādas tonis',
    '🏋🏾' => 'cilvēks ar svaru stieni: vidēji tumšs ādas tonis',
    '🏋🏿' => 'cilvēks ar svaru stieni: tumšs ādas tonis',
    '🚴🏻' => 'velosipēdists: gaišs ādas tonis',
    '🚴🏼' => 'velosipēdists: vidēji gaišs ādas tonis',
    '🚴🏽' => 'velosipēdists: vidējs ādas tonis',
    '🚴🏾' => 'velosipēdists: vidēji tumšs ādas tonis',
    '🚴🏿' => 'velosipēdists: tumšs ādas tonis',
    '🚵🏻' => 'kalnu velosipēdists: gaišs ādas tonis',
    '🚵🏼' => 'kalnu velosipēdists: vidēji gaišs ādas tonis',
    '🚵🏽' => 'kalnu velosipēdists: vidējs ādas tonis',
    '🚵🏾' => 'kalnu velosipēdists: vidēji tumšs ādas tonis',
    '🚵🏿' => 'kalnu velosipēdists: tumšs ādas tonis',
    '🤸🏻' => 'ritenītis: gaišs ādas tonis',
    '🤸🏼' => 'ritenītis: vidēji gaišs ādas tonis',
    '🤸🏽' => 'ritenītis: vidējs ādas tonis',
    '🤸🏾' => 'ritenītis: vidēji tumšs ādas tonis',
    '🤸🏿' => 'ritenītis: tumšs ādas tonis',
    '🤼🏻' => 'cīkstoņi: gaišs ādas tonis',
    '🤼🏼' => 'cīkstoņi: vidēji gaišs ādas tonis',
    '🤼🏽' => 'cīkstoņi: vidējs ādas tonis',
    '🤼🏾' => 'cīkstoņi: vidēji tumšs ādas tonis',
    '🤼🏿' => 'cīkstoņi: tumšs ādas tonis',
    '🤽🏻' => 'ūdenspolo sportists: gaišs ādas tonis',
    '🤽🏼' => 'ūdenspolo sportists: vidēji gaišs ādas tonis',
    '🤽🏽' => 'ūdenspolo sportists: vidējs ādas tonis',
    '🤽🏾' => 'ūdenspolo sportists: vidēji tumšs ādas tonis',
    '🤽🏿' => 'ūdenspolo sportists: tumšs ādas tonis',
    '🤾🏻' => 'rokasbumba: gaišs ādas tonis',
    '🤾🏼' => 'rokasbumba: vidēji gaišs ādas tonis',
    '🤾🏽' => 'rokasbumba: vidējs ādas tonis',
    '🤾🏾' => 'rokasbumba: vidēji tumšs ādas tonis',
    '🤾🏿' => 'rokasbumba: tumšs ādas tonis',
    '🤹🏻' => 'žonglēšana: gaišs ādas tonis',
    '🤹🏼' => 'žonglēšana: vidēji gaišs ādas tonis',
    '🤹🏽' => 'žonglēšana: vidējs ādas tonis',
    '🤹🏾' => 'žonglēšana: vidēji tumšs ādas tonis',
    '🤹🏿' => 'žonglēšana: tumšs ādas tonis',
    '🧘🏻' => 'cilvēks lotosa pozā: gaišs ādas tonis',
    '🧘🏼' => 'cilvēks lotosa pozā: vidēji gaišs ādas tonis',
    '🧘🏽' => 'cilvēks lotosa pozā: vidējs ādas tonis',
    '🧘🏾' => 'cilvēks lotosa pozā: vidēji tumšs ādas tonis',
    '🧘🏿' => 'cilvēks lotosa pozā: tumšs ādas tonis',
    '🛀🏻' => 'cilvēks vannā: gaišs ādas tonis',
    '🛀🏼' => 'cilvēks vannā: vidēji gaišs ādas tonis',
    '🛀🏽' => 'cilvēks vannā: vidējs ādas tonis',
    '🛀🏾' => 'cilvēks vannā: vidēji tumšs ādas tonis',
    '🛀🏿' => 'cilvēks vannā: tumšs ādas tonis',
    '🛌🏻' => 'cilvēks gultā: gaišs ādas tonis',
    '🛌🏼' => 'cilvēks gultā: vidēji gaišs ādas tonis',
    '🛌🏽' => 'cilvēks gultā: vidējs ādas tonis',
    '🛌🏾' => 'cilvēks gultā: vidēji tumšs ādas tonis',
    '🛌🏿' => 'cilvēks gultā: tumšs ādas tonis',
    '👭🏻' => 'sievietes sadevušās rokās: gaišs ādas tonis',
    '👭🏼' => 'sievietes sadevušās rokās: vidēji gaišs ādas tonis',
    '👭🏽' => 'sievietes sadevušās rokās: vidējs ādas tonis',
    '👭🏾' => 'sievietes sadevušās rokās: vidēji tumšs ādas tonis',
    '👭🏿' => 'sievietes sadevušās rokās: tumšs ādas tonis',
    '👫🏻' => 'sieviete un vīrietis sadevušies rokās: gaišs ādas tonis',
    '👫🏼' => 'sieviete un vīrietis sadevušies rokās: vidēji gaišs ādas tonis',
    '👫🏽' => 'sieviete un vīrietis sadevušies rokās: vidējs ādas tonis',
    '👫🏾' => 'sieviete un vīrietis sadevušies rokās: vidēji tumšs ādas tonis',
    '👫🏿' => 'sieviete un vīrietis sadevušies rokās: tumšs ādas tonis',
    '👬🏻' => 'vīrieši sadevušies rokās: gaišs ādas tonis',
    '👬🏼' => 'vīrieši sadevušies rokās: vidēji gaišs ādas tonis',
    '👬🏽' => 'vīrieši sadevušies rokās: vidējs ādas tonis',
    '👬🏾' => 'vīrieši sadevušies rokās: vidēji tumšs ādas tonis',
    '👬🏿' => 'vīrieši sadevušies rokās: tumšs ādas tonis',
    '💏🏻' => 'skūpsts: gaišs ādas tonis',
    '💏🏼' => 'skūpsts: vidēji gaišs ādas tonis',
    '💏🏽' => 'skūpsts: vidējs ādas tonis',
    '💏🏾' => 'skūpsts: vidēji tumšs ādas tonis',
    '💏🏿' => 'skūpsts: tumšs ādas tonis',
    '💑🏻' => 'pāris ar sirdi: gaišs ādas tonis',
    '💑🏼' => 'pāris ar sirdi: vidēji gaišs ādas tonis',
    '💑🏽' => 'pāris ar sirdi: vidējs ādas tonis',
    '💑🏾' => 'pāris ar sirdi: vidēji tumšs ādas tonis',
    '💑🏿' => 'pāris ar sirdi: tumšs ādas tonis',
    '🇦🇨' => 'karogs: Debesbraukšanas sala',
    '🇦🇩' => 'karogs: Andora',
    '🇦🇪' => 'karogs: Apvienotie Arābu Emirāti',
    '🇦🇫' => 'karogs: Afganistāna',
    '🇦🇬' => 'karogs: Antigva un Barbuda',
    '🇦🇮' => 'karogs: Angilja',
    '🇦🇱' => 'karogs: Albānija',
    '🇦🇲' => 'karogs: Armēnija',
    '🇦🇴' => 'karogs: Angola',
    '🇦🇶' => 'karogs: Antarktika',
    '🇦🇷' => 'karogs: Argentīna',
    '🇦🇸' => 'karogs: ASV Samoa',
    '🇦🇹' => 'karogs: Austrija',
    '🇦🇺' => 'karogs: Austrālija',
    '🇦🇼' => 'karogs: Aruba',
    '🇦🇽' => 'karogs: Olandes salas',
    '🇦🇿' => 'karogs: Azerbaidžāna',
    '🇧🇦' => 'karogs: Bosnija un Hercegovina',
    '🇧🇧' => 'karogs: Barbadosa',
    '🇧🇩' => 'karogs: Bangladeša',
    '🇧🇪' => 'karogs: Beļģija',
    '🇧🇫' => 'karogs: Burkinafaso',
    '🇧🇬' => 'karogs: Bulgārija',
    '🇧🇭' => 'karogs: Bahreina',
    '🇧🇮' => 'karogs: Burundija',
    '🇧🇯' => 'karogs: Benina',
    '🇧🇱' => 'karogs: Senbartelmī',
    '🇧🇲' => 'karogs: Bermudu salas',
    '🇧🇳' => 'karogs: Bruneja',
    '🇧🇴' => 'karogs: Bolīvija',
    '🇧🇶' => 'karogs: Nīderlandes Karību salas',
    '🇧🇷' => 'karogs: Brazīlija',
    '🇧🇸' => 'karogs: Bahamu salas',
    '🇧🇹' => 'karogs: Butāna',
    '🇧🇻' => 'karogs: Buvē sala',
    '🇧🇼' => 'karogs: Botsvāna',
    '🇧🇾' => 'karogs: Baltkrievija',
    '🇧🇿' => 'karogs: Beliza',
    '🇨🇦' => 'karogs: Kanāda',
    '🇨🇨' => 'karogs: Kokosu (Kīlinga) salas',
    '🇨🇩' => 'karogs: Kongo (Kinšasa)',
    '🇨🇫' => 'karogs: Centrālāfrikas Republika',
    '🇨🇬' => 'karogs: Kongo (Brazavila)',
    '🇨🇭' => 'karogs: Šveice',
    '🇨🇮' => 'karogs: Kotdivuāra',
    '🇨🇰' => 'karogs: Kuka salas',
    '🇨🇱' => 'karogs: Čīle',
    '🇨🇲' => 'karogs: Kamerūna',
    '🇨🇳' => 'karogs: Ķīna',
    '🇨🇴' => 'karogs: Kolumbija',
    '🇨🇵' => 'karogs: Klipertona sala',
    '🇨🇶' => 'karogs: Sarka',
    '🇨🇷' => 'karogs: Kostarika',
    '🇨🇺' => 'karogs: Kuba',
    '🇨🇻' => 'karogs: Kaboverde',
    '🇨🇼' => 'karogs: Kirasao',
    '🇨🇽' => 'karogs: Ziemsvētku sala',
    '🇨🇾' => 'karogs: Kipra',
    '🇨🇿' => 'karogs: Čehija',
    '🇩🇪' => 'karogs: Vācija',
    '🇩🇬' => 'karogs: Djego Garsijas atols',
    '🇩🇯' => 'karogs: Džibutija',
    '🇩🇰' => 'karogs: Dānija',
    '🇩🇲' => 'karogs: Dominika',
    '🇩🇴' => 'karogs: Dominikāna',
    '🇩🇿' => 'karogs: Alžīrija',
    '🇪🇦' => 'karogs: Seūta un Melilja',
    '🇪🇨' => 'karogs: Ekvadora',
    '🇪🇪' => 'karogs: Igaunija',
    '🇪🇬' => 'karogs: Ēģipte',
    '🇪🇭' => 'karogs: Rietumsahāra',
    '🇪🇷' => 'karogs: Eritreja',
    '🇪🇸' => 'karogs: Spānija',
    '🇪🇹' => 'karogs: Etiopija',
    '🇪🇺' => 'karogs: Eiropas Savienība',
    '🇫🇮' => 'karogs: Somija',
    '🇫🇯' => 'karogs: Fidži',
    '🇫🇰' => 'karogs: Folklenda salas',
    '🇫🇲' => 'karogs: Mikronēzija',
    '🇫🇴' => 'karogs: Fēru salas',
    '🇫🇷' => 'karogs: Francija',
    '🇬🇦' => 'karogs: Gabona',
    '🇬🇧' => 'karogs: Apvienotā Karaliste',
    '🇬🇩' => 'karogs: Grenāda',
    '🇬🇪' => 'karogs: Gruzija',
    '🇬🇫' => 'karogs: Francijas Gviāna',
    '🇬🇬' => 'karogs: Gērnsija',
    '🇬🇭' => 'karogs: Gana',
    '🇬🇮' => 'karogs: Gibraltārs',
    '🇬🇱' => 'karogs: Grenlande',
    '🇬🇲' => 'karogs: Gambija',
    '🇬🇳' => 'karogs: Gvineja',
    '🇬🇵' => 'karogs: Gvadelupa',
    '🇬🇶' => 'karogs: Ekvatoriālā Gvineja',
    '🇬🇷' => 'karogs: Grieķija',
    '🇬🇸' => 'karogs: Dienviddžordžija un Dienvidsendviču salas',
    '🇬🇹' => 'karogs: Gvatemala',
    '🇬🇺' => 'karogs: Guama',
    '🇬🇼' => 'karogs: Gvineja-Bisava',
    '🇬🇾' => 'karogs: Gajāna',
    '🇭🇰' => 'karogs: Ķīnas īpašās pārvaldes apgabals Honkonga',
    '🇭🇲' => 'karogs: Hērda sala un Makdonalda salas',
    '🇭🇳' => 'karogs: Hondurasa',
    '🇭🇷' => 'karogs: Horvātija',
    '🇭🇹' => 'karogs: Haiti',
    '🇭🇺' => 'karogs: Ungārija',
    '🇮🇨' => 'karogs: Kanāriju salas',
    '🇮🇩' => 'karogs: Indonēzija',
    '🇮🇪' => 'karogs: Īrija',
    '🇮🇱' => 'karogs: Izraēla',
    '🇮🇲' => 'karogs: Menas sala',
    '🇮🇳' => 'karogs: Indija',
    '🇮🇴' => 'karogs: Indijas okeāna Britu teritorija',
    '🇮🇶' => 'karogs: Irāka',
    '🇮🇷' => 'karogs: Irāna',
    '🇮🇸' => 'karogs: Islande',
    '🇮🇹' => 'karogs: Itālija',
    '🇯🇪' => 'karogs: Džērsija',
    '🇯🇲' => 'karogs: Jamaika',
    '🇯🇴' => 'karogs: Jordānija',
    '🇯🇵' => 'karogs: Japāna',
    '🇰🇪' => 'karogs: Kenija',
    '🇰🇬' => 'karogs: Kirgizstāna',
    '🇰🇭' => 'karogs: Kambodža',
    '🇰🇮' => 'karogs: Kiribati',
    '🇰🇲' => 'karogs: Komoru salas',
    '🇰🇳' => 'karogs: Sentkitsa un Nevisa',
    '🇰🇵' => 'karogs: Ziemeļkoreja',
    '🇰🇷' => 'karogs: Dienvidkoreja',
    '🇰🇼' => 'karogs: Kuveita',
    '🇰🇾' => 'karogs: Kaimanu salas',
    '🇰🇿' => 'karogs: Kazahstāna',
    '🇱🇦' => 'karogs: Laosa',
    '🇱🇧' => 'karogs: Libāna',
    '🇱🇨' => 'karogs: Sentlūsija',
    '🇱🇮' => 'karogs: Lihtenšteina',
    '🇱🇰' => 'karogs: Šrilanka',
    '🇱🇷' => 'karogs: Libērija',
    '🇱🇸' => 'karogs: Lesoto',
    '🇱🇹' => 'karogs: Lietuva',
    '🇱🇺' => 'karogs: Luksemburga',
    '🇱🇻' => 'karogs: Latvija',
    '🇱🇾' => 'karogs: Lībija',
    '🇲🇦' => 'karogs: Maroka',
    '🇲🇨' => 'karogs: Monako',
    '🇲🇩' => 'karogs: Moldova',
    '🇲🇪' => 'karogs: Melnkalne',
    '🇲🇫' => 'karogs: Senmartēna',
    '🇲🇬' => 'karogs: Madagaskara',
    '🇲🇭' => 'karogs: Māršala salas',
    '🇲🇰' => 'karogs: Ziemeļmaķedonija',
    '🇲🇱' => 'karogs: Mali',
    '🇲🇲' => 'karogs: Mjanma (Birma)',
    '🇲🇳' => 'karogs: Mongolija',
    '🇲🇴' => 'karogs: ĶTR īpašais administratīvais reģions Makao',
    '🇲🇵' => 'karogs: Ziemeļu Marianas salas',
    '🇲🇶' => 'karogs: Martinika',
    '🇲🇷' => 'karogs: Mauritānija',
    '🇲🇸' => 'karogs: Montserrata',
    '🇲🇹' => 'karogs: Malta',
    '🇲🇺' => 'karogs: Maurīcija',
    '🇲🇻' => 'karogs: Maldīvija',
    '🇲🇼' => 'karogs: Malāvija',
    '🇲🇽' => 'karogs: Meksika',
    '🇲🇾' => 'karogs: Malaizija',
    '🇲🇿' => 'karogs: Mozambika',
    '🇳🇦' => 'karogs: Namībija',
    '🇳🇨' => 'karogs: Jaunkaledonija',
    '🇳🇪' => 'karogs: Nigēra',
    '🇳🇫' => 'karogs: Norfolkas sala',
    '🇳🇬' => 'karogs: Nigērija',
    '🇳🇮' => 'karogs: Nikaragva',
    '🇳🇱' => 'karogs: Nīderlande',
    '🇳🇴' => 'karogs: Norvēģija',
    '🇳🇵' => 'karogs: Nepāla',
    '🇳🇷' => 'karogs: Nauru',
    '🇳🇺' => 'karogs: Niue',
    '🇳🇿' => 'karogs: Jaunzēlande',
    '🇴🇲' => 'karogs: Omāna',
    '🇵🇦' => 'karogs: Panama',
    '🇵🇪' => 'karogs: Peru',
    '🇵🇫' => 'karogs: Francijas Polinēzija',
    '🇵🇬' => 'karogs: Papua-Jaungvineja',
    '🇵🇭' => 'karogs: Filipīnas',
    '🇵🇰' => 'karogs: Pakistāna',
    '🇵🇱' => 'karogs: Polija',
    '🇵🇲' => 'karogs: Senpjēra un Mikelona',
    '🇵🇳' => 'karogs: Pitkērnas salas',
    '🇵🇷' => 'karogs: Puertoriko',
    '🇵🇸' => 'karogs: Palestīnas teritorijas',
    '🇵🇹' => 'karogs: Portugāle',
    '🇵🇼' => 'karogs: Palau',
    '🇵🇾' => 'karogs: Paragvaja',
    '🇶🇦' => 'karogs: Katara',
    '🇷🇪' => 'karogs: Reinjona',
    '🇷🇴' => 'karogs: Rumānija',
    '🇷🇸' => 'karogs: Serbija',
    '🇷🇺' => 'karogs: Krievija',
    '🇷🇼' => 'karogs: Ruanda',
    '🇸🇦' => 'karogs: Saūda Arābija',
    '🇸🇧' => 'karogs: Zālamana salas',
    '🇸🇨' => 'karogs: Seišelu salas',
    '🇸🇩' => 'karogs: Sudāna',
    '🇸🇪' => 'karogs: Zviedrija',
    '🇸🇬' => 'karogs: Singapūra',
    '🇸🇭' => 'karogs: Sv.Helēnas sala',
    '🇸🇮' => 'karogs: Slovēnija',
    '🇸🇯' => 'karogs: Svalbāra un Jana Majena sala',
    '🇸🇰' => 'karogs: Slovākija',
    '🇸🇱' => 'karogs: Sjerraleone',
    '🇸🇲' => 'karogs: Sanmarīno',
    '🇸🇳' => 'karogs: Senegāla',
    '🇸🇴' => 'karogs: Somālija',
    '🇸🇷' => 'karogs: Surinama',
    '🇸🇸' => 'karogs: Dienvidsudāna',
    '🇸🇹' => 'karogs: Santome un Prinsipi',
    '🇸🇻' => 'karogs: Salvadora',
    '🇸🇽' => 'karogs: Sintmārtena',
    '🇸🇾' => 'karogs: Sīrija',
    '🇸🇿' => 'karogs: Svatini',
    '🇹🇦' => 'karogs: Tristana da Kuņjas salu teritorijas',
    '🇹🇨' => 'karogs: Tērksas un Kaikosas salas',
    '🇹🇩' => 'karogs: Čada',
    '🇹🇫' => 'karogs: Francijas Dienvidjūru teritorija',
    '🇹🇬' => 'karogs: Togo',
    '🇹🇭' => 'karogs: Taizeme',
    '🇹🇯' => 'karogs: Tadžikistāna',
    '🇹🇰' => 'karogs: Tokelau',
    '🇹🇱' => 'karogs: Austrumtimora',
    '🇹🇲' => 'karogs: Turkmenistāna',
    '🇹🇳' => 'karogs: Tunisija',
    '🇹🇴' => 'karogs: Tonga',
    '🇹🇷' => 'karogs: Turcija',
    '🇹🇹' => 'karogs: Trinidāda un Tobāgo',
    '🇹🇻' => 'karogs: Tuvalu',
    '🇹🇼' => 'karogs: Taivāna',
    '🇹🇿' => 'karogs: Tanzānija',
    '🇺🇦' => 'karogs: Ukraina',
    '🇺🇬' => 'karogs: Uganda',
    '🇺🇲' => 'karogs: ASV Mazās Aizjūras salas',
    '🇺🇳' => 'karogs: Apvienoto Nāciju Organizācija',
    '🇺🇸' => 'karogs: Amerikas Savienotās Valstis',
    '🇺🇾' => 'karogs: Urugvaja',
    '🇺🇿' => 'karogs: Uzbekistāna',
    '🇻🇦' => 'karogs: Vatikāns',
    '🇻🇨' => 'karogs: Sentvinsenta un Grenadīnas',
    '🇻🇪' => 'karogs: Venecuēla',
    '🇻🇬' => 'karogs: Britu Virdžīnas',
    '🇻🇮' => 'karogs: ASV Virdžīnas',
    '🇻🇳' => 'karogs: Vjetnama',
    '🇻🇺' => 'karogs: Vanuatu',
    '🇼🇫' => 'karogs: Volisa un Futunas salas',
    '🇼🇸' => 'karogs: Samoa',
    '🇽🇰' => 'karogs: Kosova',
    '🇾🇪' => 'karogs: Jemena',
    '🇾🇹' => 'karogs: Majota',
    '🇿🇦' => 'karogs: Dienvidāfrikas Republika',
    '🇿🇲' => 'karogs: Zambija',
    '🇿🇼' => 'karogs: Zimbabve',
    '🔟' => 'taustiņš: 10',
    '🏻' => 'gaišs ādas tonis',
    '🏼' => 'vidēji gaišs ādas tonis',
    '🏽' => 'vidējs ādas tonis',
    '🏾' => 'vidēji tumšs ādas tonis',
    '🏿' => 'tumšs ādas tonis',
    '😀' => 'smiekli',
    '😃' => 'plats smaids un lielas acis',
    '😄' => 'smaidoša seja ar atvērtu muti un smaidošām acīm',
    '😁' => 'plats smaids un smaidošas acis',
    '😆' => 'smaidoša seja ar atvērtu muti un aizmiegtām acīm',
    '😅' => 'plats smaids ar sviedru lāsi',
    '🤣' => 'vārtās smieklos pa grīdu',
    '😂' => 'seja ar prieka asarām',
    '🙂' => 'seja ar vieglu smaidu',
    '🙃' => 'apgriezta seja',
    '🫠' => 'kūstoša seja',
    '😉' => 'seja ar piemiegtu aci',
    '😊' => 'smaidoša seja ar smaidošām acīm',
    '😇' => 'smaidoša seja ar nimbu',
    '🥰' => 'smaidoša seja ar sirsniņām',
    '😍' => 'smaidoša seja ar sirds formas acīm',
    '🤩' => 'zvaigžņu pārņemts',
    '😘' => 'skūpstoša seja',
    '😗' => 'seja sniedz skūpstu',
    '☺' => 'smaidoša seja',
    '😚' => 'seja ar aizvērtām acīm sniedz skūpstu',
    '😙' => 'seja ar smaidošām acīm sniedz skūpstu',
    '🥲' => 'smaidoša seja ar asaru',
    '😋' => 'ēdienu baudoša seja',
    '😛' => 'seja ar izbāztu mēli',
    '😜' => 'seja ar izbāztu mēli un piemiegtu aci',
    '🤪' => 'traka seja',
    '😝' => 'seja ar izbāztu mēli un aizmiegtām acīm',
    '🤑' => 'seja ar naudu mutē',
    '🤗' => 'seja ar apskāvienu',
    '🤭' => 'seja ar roku pār muti',
    '🫢' => 'seja ar atvērtām acīm un roku pār muti',
    '🫣' => 'seja ar lūrošu aci',
    '🤫' => 'šušinoša seja',
    '🤔' => 'domīga seja',
    '🫡' => 'salutējoša seja',
    '🤐' => 'seja ar rāvējslēdzēju mutes vietā',
    '🤨' => 'seja ar paceltām uzacīm',
    '😐' => 'neitrāla seja',
    '😑' => 'seja bez izteiksmes',
    '😶' => 'seja bez mutes',
    '🫥' => 'punktētas līnijas seja',
    '😏' => 'smīnoša seja',
    '😒' => 'saīgusi seja',
    '🙄' => 'seja ar pārgrieztām acīm',
    '😬' => 'saviebta seja',
    '🤥' => 'melojoša seja',
    '🫨' => 'trīcoša seja',
    '😌' => 'seja ar atvieglojuma izteiksmi',
    '😔' => 'domās iegrimusi seja',
    '😪' => 'miegaina seja',
    '🤤' => 'siekalojas',
    '😴' => 'guļoša seja',
    '🫩' => 'seja ar maisiņiem zem acīm',
    '😷' => 'seja ar medicīnas masku',
    '🤒' => 'seja ar termometru',
    '🤕' => 'seja ar galvas apsēju',
    '🤢' => 'nelabums',
    '🤮' => 'vemjoša seja',
    '🤧' => 'šķauda',
    '🥵' => 'piesārtusi seja',
    '🥶' => 'nosalusi seja',
    '🥴' => 'noreibusi seja',
    '😵' => 'apreibusi seja',
    '🤯' => 'eksplodējoša galva',
    '🤠' => 'seja kovboja cepurē',
    '🥳' => 'ballīšu seja',
    '🥸' => 'paslēpta seja',
    '😎' => 'smaidoša seja ar saulesbrillēm',
    '🤓' => 'gudrītis',
    '🧐' => 'seja ar monokli',
    '😕' => 'apjukusi seja',
    '🫤' => 'seja ar diagonālu muti',
    '😟' => 'noraizējusies seja',
    '🙁' => 'nedaudz bēdīga seja',
    '☹' => 'bēdīga seja',
    '😮' => 'seja ar atvērtu muti',
    '😯' => 'pārsteigta seja',
    '😲' => 'šokēta seja',
    '😳' => 'nosarkusi seja',
    '🫪' => 'sašķobīta seja',
    '🥺' => 'lūdzoša seja',
    '🥹' => 'seja ar aizturētām asarām',
    '😦' => 'bēdīga seja ar atvērtu muti',
    '😧' => 'sāpjpilna seja',
    '😨' => 'nobijusies seja',
    '😰' => 'seja ar atvērtu muti un aukstiem sviedriem',
    '😥' => 'vīlusies un atvieglota seja',
    '😢' => 'raudoša seja',
    '😭' => 'aizgūtnēm raudoša seja',
    '😱' => 'bailēs kliedzoša seja',
    '😖' => 'apmulsusi seja',
    '😣' => 'piepūlēta seja',
    '😞' => 'vīlusies seja',
    '😓' => 'seja ar aukstu sviedru lāsi',
    '😩' => 'nogurdināta seja',
    '😫' => 'nogurusi seja',
    '🥱' => 'seja žāvājas',
    '😤' => 'seja ar tvaiku no deguna',
    '😡' => 'sabozusies seja',
    '😠' => 'dusmīga seja',
    '🤬' => 'seja ar simboliem uz mutes',
    '😈' => 'smaidoša seja ar ragiem',
    '👿' => 'velniņš',
    '💀' => 'galvaskauss',
    '☠' => 'miroņgalva',
    '💩' => 'ekskrementi',
    '🤡' => 'klauna seja',
    '👹' => 'cilvēkēdājs',
    '👺' => 'goblins',
    '👻' => 'spoks',
    '👽' => 'citplanētietis',
    '👾' => 'citplanētiešu briesmonis',
    '🤖' => 'robots',
    '😺' => 'plati smaidošs kaķis',
    '😸' => 'plati smaidošs kaķis ar smaidošām acīm',
    '😹' => 'kaķis ar prieka asarām',
    '😻' => 'smaidošs kaķis ar sirds formas acīm',
    '😼' => 'kaķis ar viltīgu smaidu',
    '😽' => 'kaķis sniedz skūpstu',
    '🙀' => 'noraizējies kaķis',
    '😿' => 'raudošs kaķis',
    '😾' => 'sabozies kaķis',
    '🙈' => 'neko neredzu',
    '🙉' => 'neko nedzirdu',
    '🙊' => 'neko nesaku',
    '💌' => 'mīlestības vēstule',
    '💘' => 'sirds ar bultu',
    '💝' => 'sirds ar lentīti',
    '💖' => 'mirdzoša sirds',
    '💗' => 'augoša sirds',
    '💓' => 'pukstoša sirds',
    '💞' => 'rotējošas sirdis',
    '💕' => 'divas sirdis',
    '💟' => 'sirds rotājums',
    '❣' => 'izsaukuma zīme sirds formā',
    '💔' => 'salauzta sirds',
    '❤' => 'sarkana sirds',
    '🩷' => 'rozā sirds',
    '🧡' => 'oranža sirds',
    '💛' => 'dzeltena sirds',
    '💚' => 'zaļa sirds',
    '💙' => 'zila sirds',
    '🩵' => 'gaiši zila sirds',
    '💜' => 'violeta sirds',
    '🤎' => 'brūna sirds',
    '🖤' => 'melna sirds',
    '🩶' => 'pelēka sirds',
    '🤍' => 'balta sirds',
    '💋' => 'skūpsta nospiedums',
    '💯' => 'simt punktu',
    '💢' => 'dusmu simbols',
    '🫯' => 'juceklis',
    '💥' => 'sadursme',
    '💫' => 'apdullis',
    '💦' => 'sviedru lāses',
    '💨' => 'bēgšana',
    '🕳' => 'caurums',
    '💬' => 'runas burbulis',
    '🗨' => 'pa kreisi vērsts runas burbulis',
    '🗯' => 'pa labi vērsts dusmu burbulis',
    '💭' => 'domu burbulis',
    '💤' => 'zzz',
    '👋' => 'mājoša roka',
    '🤚' => 'pacelta plauksta',
    '🖐' => 'pacelta roka ar izvērstiem pirkstiem',
    '✋' => 'pacelta roka',
    '🖖' => 'vulkāniešu sveiciens',
    '🫱' => 'labā roka',
    '🫲' => 'kreiso roku',
    '🫳' => 'plaukstu uz leju',
    '🫴' => 'plaukstu uz augšu',
    '🫷' => 'pa kreisi spiedoša roka',
    '🫸' => 'pa labi spiedoša roka',
    '👌' => 'simbols OK',
    '🤌' => 'pastiepti pirksti',
    '🤏' => 'roka rāda drusciņu',
    '✌' => 'uzvaras simbols',
    '🤞' => 'sakrustoti pirksti',
    '🫰' => 'roka ar rādītājpirkstu un īkšķi sakrustota',
    '🤟' => 'mīlas žests',
    '🤘' => 'ragu simbols',
    '🤙' => 'piezvani man',
    '👈' => 'pa kreisi vērsts rādītājpirksts',
    '👉' => 'pa labi vērsts rādītājpirksts',
    '👆' => 'augšup vērsts rādītājpirksts ar prom vērstu delnu',
    '🖕' => 'vidējais pirksts',
    '👇' => 'lejup vērsts rādītājpirksts',
    '☝' => 'augšup vērsts rādītājpirksts',
    '🫵' => 'rādītājpirksts pret sevi',
    '👍' => 'augšupvērsts īkšķis',
    '👎' => 'lejupvērsts īkšķis',
    '✊' => 'pacelta dūre',
    '👊' => 'pretim vērsta dūre',
    '🤛' => 'dūre pa kreisi',
    '🤜' => 'dūre pa labi',
    '👏' => 'aplausi',
    '🙌' => 'paceltas rokas',
    '🫶' => 'sirds žests',
    '👐' => 'atvērtas rokas',
    '🤲' => 'plaukstas kopā',
    '🤝' => 'rokasspiediens',
    '🙏' => 'lūgšanā saliktas rokas',
    '✍' => 'rakstoša roka',
    '💅' => 'nagu laka',
    '🤳' => 'pašfoto',
    '💪' => 'bicepss',
    '🦾' => 'mehāniska roka',
    '🦿' => 'mehāniska kāja',
    '🦵' => 'kāja',
    '🦶' => 'pēda',
    '👂' => 'auss',
    '🦻' => 'auss ar dzirdes aparātu',
    '👃' => 'deguns',
    '🧠' => 'smadzenes',
    '🫀' => 'cilvēka sirds',
    '🫁' => 'plaušas',
    '🦷' => 'zobs',
    '🦴' => 'kauls',
    '👀' => 'acis',
    '👁' => 'acs',
    '👅' => 'mēle',
    '👄' => 'mute',
    '🫦' => 'košana lūpā',
    '👶' => 'zīdainis',
    '🧒' => 'bērns',
    '👦' => 'zēns',
    '👧' => 'meitene',
    '🧑' => 'pieaugušais',
    '👱' => 'blonds cilvēks',
    '👨' => 'vīrietis',
    '🧔' => 'bārdains vīrietis',
    '👩' => 'sieviete',
    '🧓' => 'vecāks pieaugušais',
    '👴' => 'vecs vīrietis',
    '👵' => 'veca sieviete',
    '🙍' => 'norūpējies cilvēks',
    '🙎' => 'sabozies cilvēks',
    '🙅' => 'cilvēks ar aizlieguma žestu',
    '🙆' => 'cilvēks ar apstiprinājuma žestu',
    '💁' => 'persona ar pastieptu roku',
    '🙋' => 'cilvēks ar paceltu roku',
    '🧏' => 'nedzirdīga persona',
    '🙇' => 'cilvēks paklanās',
    '🤦' => 'cilvēks ar saķertu galvu',
    '🤷' => 'rausta plecus',
    '👮' => 'policists',
    '🕵' => 'detektīvs',
    '💂' => 'sargs',
    '🥷' => 'nindzja',
    '👷' => 'celtnieks',
    '🫅' => 'persona ar vainagu',
    '🤴' => 'princis',
    '👸' => 'princese',
    '👳' => 'persona ar turbānu',
    '👲' => 'vīrietis ar ķīniešu cepuri',
    '🧕' => 'sieviete ar lakatu',
    '🤵' => 'persona smokingā',
    '👰' => 'cilvēks ar plīvuru',
    '🤰' => 'sieviete stāvoklī',
    '🫃' => 'vīrietis stāvoklī',
    '🫄' => 'cilvēks stāvoklī',
    '🤱' => 'barošana ar krūti',
    '👼' => 'mazs eņģelītis',
    '🎅' => 'Ziemassvētku vecītis',
    '🤶' => 'Ziemassvētku omīte',
    '🦸' => 'supervaronis',
    '🦹' => 'superļaunais',
    '🧙' => 'mags',
    '🧚' => 'feja',
    '🧛' => 'vampīrs',
    '🧜' => 'cilvēks nāra',
    '🧝' => 'elfs',
    '🧞' => 'džins',
    '🧟' => 'zombijs',
    '🧌' => 'trollis',
    '🫈' => 'matiem noaudzis radījums',
    '💆' => 'sejas masāža',
    '💇' => 'frizūra',
    '🚶' => 'gājējs',
    '🧍' => 'stāvoša persona',
    '🧎' => 'persona uz ceļiem',
    '🏃' => 'skrējējs',
    '💃' => 'sieviete dejo',
    '🕺' => 'vīrietis dejo',
    '🕴' => 'levitējošs cilvēks uzvalkā',
    '👯' => 'dejotāju šovs',
    '🧖' => 'cilvēks tvaika telpā',
    '🧗' => 'kalnā kāpējs',
    '🤺' => 'paukotājs',
    '🏇' => 'zirgu skriešanās sacīkstes',
    '⛷' => 'slēpotājs',
    '🏂' => 'snovbordists',
    '🏌' => 'golfa spēlētājs',
    '🏄' => 'sērfotājs',
    '🚣' => 'cilvēks airē',
    '🏊' => 'peldētājs',
    '⛹' => 'cilvēks driblē bumbu',
    '🏋' => 'cilvēks ar svaru stieni',
    '🚴' => 'velosipēdists',
    '🚵' => 'kalnu velosipēdists',
    '🤸' => 'ritenītis',
    '🤼' => 'cīkstoņi',
    '🤽' => 'ūdenspolo sportists',
    '🤾' => 'rokasbumba',
    '🤹' => 'žonglēšana',
    '🧘' => 'cilvēks lotosa pozā',
    '🛀' => 'cilvēks vannā',
    '🛌' => 'cilvēks gultā',
    '👭' => 'sievietes sadevušās rokās',
    '👫' => 'sieviete un vīrietis sadevušies rokās',
    '👬' => 'vīrieši sadevušies rokās',
    '💏' => 'skūpsts',
    '💑' => 'pāris ar sirdi',
    '🗣' => 'runājoša galva',
    '👤' => 'krūšutēla siluets',
    '👥' => 'divu krūšutēlu silueti',
    '🫂' => 'cilvēki apkampjas',
    '👪' => 'ģimene',
    '👣' => 'pēdu nospiedumi',
    '🫆' => 'pirksta nospiedums',
    '🦰' => 'sarkani mati',
    '🦱' => 'sprogaini mati',
    '🦳' => 'sirmi mati',
    '🦲' => 'bez matiem',
    '🐵' => 'pērtiķa galva',
    '🐒' => 'mērkaķis',
    '🦍' => 'gorilla',
    '🦧' => 'orangutans',
    '🐶' => 'suņa galva',
    '🐕' => 'suns',
    '🦮' => 'suns pavadonis',
    '🐩' => 'pūdelis',
    '🐺' => 'vilks',
    '🦊' => 'lapsa',
    '🦝' => 'jenots',
    '🐱' => 'kaķa galva',
    '🐈' => 'kaķis',
    '🦁' => 'lauva',
    '🐯' => 'tīģera galva',
    '🐅' => 'tīģeris',
    '🐆' => 'leopards',
    '🐴' => 'zirga galva',
    '🫎' => 'alnis',
    '🫏' => 'ēzelis',
    '🐎' => 'zirgs',
    '🦄' => 'vienradzis',
    '🦓' => 'zebra',
    '🦌' => 'briedis',
    '🦬' => 'bizons',
    '🐮' => 'govs galva',
    '🐂' => 'vērsis',
    '🐃' => 'bifelis',
    '🐄' => 'govs',
    '🐷' => 'cūkas galva',
    '🐖' => 'cūka',
    '🐗' => 'mežacūka',
    '🐽' => 'šņukurs',
    '🐏' => 'auns',
    '🐑' => 'aita',
    '🐐' => 'kaza',
    '🐪' => 'kamielis',
    '🐫' => 'divkupru kamielis',
    '🦙' => 'lama',
    '🦒' => 'žirafe',
    '🐘' => 'zilonis',
    '🦣' => 'mamuts',
    '🦏' => 'degunradzis',
    '🦛' => 'nīlzirgs',
    '🐭' => 'peles galva',
    '🐁' => 'pele',
    '🐀' => 'žurka',
    '🐹' => 'kāmis',
    '🐰' => 'truša galva',
    '🐇' => 'trusis',
    '🐿' => 'burunduks',
    '🦫' => 'bebrs',
    '🦔' => 'ezis',
    '🦇' => 'sikspārnis',
    '🐻' => 'lācis',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'sliņķis',
    '🦦' => 'ūdrs',
    '🦨' => 'skunkss',
    '🦘' => 'ķengurs',
    '🦡' => 'āpsis',
    '🐾' => 'ķepu nospiedumi',
    '🦃' => 'tītars',
    '🐔' => 'vista',
    '🐓' => 'gailis',
    '🐣' => 'cālis šķiļas',
    '🐤' => 'cālis',
    '🐥' => 'cālis no priekšpuses',
    '🐦' => 'putns',
    '🐧' => 'pingvīns',
    '🕊' => 'dūja',
    '🦅' => 'ērglis',
    '🦆' => 'pīle',
    '🦢' => 'gulbis',
    '🦉' => 'pūce',
    '🦤' => 'dodo',
    '🪶' => 'spalva',
    '🦩' => 'flamingo',
    '🦚' => 'pāvs',
    '🦜' => 'papagailis',
    '🪽' => 'spārns',
    '🪿' => 'zoss',
    '🐸' => 'varde',
    '🐊' => 'krokodils',
    '🐢' => 'bruņurupucis',
    '🦎' => 'ķirzaka',
    '🐍' => 'čūska',
    '🐲' => 'pūķa galva',
    '🐉' => 'pūķis',
    '🦕' => 'zauropods',
    '🦖' => 'tiranozaurs',
    '🐳' => 'valis šļāc ūdeni',
    '🐋' => 'valis',
    '🐬' => 'delfīns',
    '🫍' => 'zobenvalis',
    '🦭' => 'ronis',
    '🐟' => 'zivs',
    '🐠' => 'tropu zivs',
    '🐡' => 'balonzivs',
    '🦈' => 'haizivs',
    '🐙' => 'astoņkājis',
    '🐚' => 'gliemežvāks',
    '🪸' => 'koraļļi',
    '🪼' => 'medūza',
    '🦀' => 'krabis',
    '🦞' => 'omārs',
    '🦐' => 'garnele',
    '🦑' => 'kalmārs',
    '🦪' => 'austere',
    '🐌' => 'gliemezis',
    '🦋' => 'taurenis',
    '🐛' => 'kukainis',
    '🐜' => 'skudra',
    '🐝' => 'bite',
    '🪲' => 'vabole',
    '🐞' => 'mārīte',
    '🦗' => 'circenis',
    '🪳' => 'tarakāns',
    '🕷' => 'zirneklis',
    '🕸' => 'zirnekļa tīkls',
    '🦂' => 'skorpions',
    '🦟' => 'ods',
    '🪰' => 'muša',
    '🪱' => 'tārps',
    '🦠' => 'mikrobs',
    '💐' => 'pušķis',
    '🌸' => 'ķiršu zieds',
    '💮' => 'balts zieds',
    '🪷' => 'lotoss',
    '🏵' => 'rozete',
    '🌹' => 'roze',
    '🥀' => 'novītusi puķe',
    '🌺' => 'hibisks',
    '🌻' => 'saulespuķe',
    '🌼' => 'zieds',
    '🌷' => 'tulpe',
    '🪻' => 'hiacinte',
    '🌱' => 'asns',
    '🪴' => 'augs podiņā',
    '🌲' => 'skujkoks',
    '🌳' => 'lapu koks',
    '🌴' => 'palma',
    '🌵' => 'kaktuss',
    '🌾' => 'rīsa augs',
    '🌿' => 'augs',
    '☘' => 'āboliņa lapa',
    '🍀' => 'četrlapu āboliņš',
    '🍁' => 'kļavas lapa',
    '🍂' => 'nokritusi lapa',
    '🍃' => 'vējā plīvojoša lapa',
    '🪹' => 'tukša ligzda',
    '🪺' => 'ligzda ar olām',
    '🍄' => 'sēne',
    '🪾' => 'koks bez lapām',
    '🍇' => 'vīnogas',
    '🍈' => 'melone',
    '🍉' => 'arbūzs',
    '🍊' => 'mandarīns',
    '🍋' => 'citrons',
    '🍌' => 'banāns',
    '🍍' => 'ananass',
    '🥭' => 'mango',
    '🍎' => 'sarkans ābols',
    '🍏' => 'zaļš ābols',
    '🍐' => 'bumbieris',
    '🍑' => 'persiks',
    '🍒' => 'ķirši',
    '🍓' => 'zemene',
    '🫐' => 'mellenes',
    '🥝' => 'kivi auglis',
    '🍅' => 'tomāts',
    '🫒' => 'olīva',
    '🥥' => 'kokosrieksts',
    '🥑' => 'avokado',
    '🍆' => 'baklažāns',
    '🥔' => 'kartupelis',
    '🥕' => 'burkāns',
    '🌽' => 'kukurūzas vālīte',
    '🌶' => 'asais pipars',
    '🫑' => 'paprika',
    '🥒' => 'gurķis',
    '🥬' => 'lapu dārzenis',
    '🥦' => 'brokoļi',
    '🧄' => 'ķiploks',
    '🧅' => 'sīpols',
    '🥜' => 'zemesrieksti',
    '🫘' => 'pupiņas',
    '🌰' => 'kastanis',
    '🫚' => 'ingvera sakne',
    '🫛' => 'zirņu pāksts',
    '🫜' => 'sakņu dārzenis',
    '🍞' => 'maize',
    '🥐' => 'kruasāns',
    '🥖' => 'bagete',
    '🫓' => 'plācenis',
    '🥨' => 'kliņģeris',
    '🥯' => 'beigelis',
    '🥞' => 'pankūkas',
    '🧇' => 'vafele',
    '🧀' => 'siera šķēle',
    '🍖' => 'kauls ar gaļu',
    '🍗' => 'putna kāja',
    '🥩' => 'gaļas gabals',
    '🥓' => 'bekons',
    '🍔' => 'hamburgers',
    '🍟' => 'frī kartupeļi',
    '🍕' => 'pica',
    '🌭' => 'hotdogs',
    '🥪' => 'sendvičs',
    '🌮' => 'tako',
    '🌯' => 'burito',
    '🫔' => 'tamale',
    '🥙' => 'pildīts lavašs',
    '🧆' => 'felāfels',
    '🥚' => 'ola',
    '🍳' => 'ēdiena gatavošana',
    '🥘' => 'sautējums pannā',
    '🍲' => 'ēdiena bļodiņa',
    '🫕' => 'fondī',
    '🥣' => 'bļoda ar karoti',
    '🥗' => 'zaļie salāti',
    '🍿' => 'popkorns',
    '🧈' => 'sviests',
    '🧂' => 'sāls',
    '🥫' => 'konservi',
    '🍱' => 'bento kastīte',
    '🍘' => 'rīsu galete',
    '🍙' => 'rīsu bumbiņa',
    '🍚' => 'vārīti rīsi',
    '🍛' => 'rīsu karijs',
    '🍜' => 'kūpoša bļodiņa',
    '🍝' => 'spageti',
    '🍠' => 'cepti saldie kartupeļi',
    '🍢' => 'ēdiens uz irbulīšiem',
    '🍣' => 'suši',
    '🍤' => 'cepta garnele',
    '🍥' => 'zivju pīrāgs ar rotājumu',
    '🥮' => 'Mēness kūka',
    '🍡' => 'dango',
    '🥟' => 'pelmeņi',
    '🥠' => 'laimes cepumiņš',
    '🥡' => 'kastīte līdzņemšanai',
    '🍦' => 'saldējums vafeļu glāzītē',
    '🍧' => 'smalcināts ledus ar sīrupu',
    '🍨' => 'saldējums',
    '🍩' => 'virtulis',
    '🍪' => 'cepums',
    '🎂' => 'dzimšanas dienas kūka',
    '🍰' => 'kūka',
    '🧁' => 'kēksiņš',
    '🥧' => 'pīrāgs',
    '🍫' => 'šokolādes tāfelīte',
    '🍬' => 'konfekte',
    '🍭' => 'konfekte uz kociņa',
    '🍮' => 'olu krēms',
    '🍯' => 'medus pods',
    '🍼' => 'bērna pudelīte',
    '🥛' => 'piena glāze',
    '☕' => 'karsts dzēriens',
    '🫖' => 'tējkanna',
    '🍵' => 'tējas tase bez osiņas',
    '🍶' => 'sakē',
    '🍾' => 'pudele ar izšautu korķi',
    '🍷' => 'vīna glāze',
    '🍸' => 'kokteiļa glāze',
    '🍹' => 'tropu kokteilis',
    '🍺' => 'alus kauss',
    '🍻' => 'saskandināti alus kausi',
    '🥂' => 'glāžu skandināšana',
    '🥃' => 'viskija glāze',
    '🫗' => 'ielejot šķidrumu',
    '🥤' => 'dzēriens ar salmiņu',
    '🧋' => 'burbuļtēja',
    '🧃' => 'dzēriena kārba',
    '🧉' => 'mate',
    '🧊' => 'ledus gabaliņš',
    '🥢' => 'irbulīši',
    '🍽' => 'nazis un dakša ar šķīvi',
    '🍴' => 'nazis un dakša',
    '🥄' => 'karote',
    '🔪' => 'virtuves nazis',
    '🫙' => 'burka',
    '🏺' => 'amfora',
    '🌍' => 'globuss ar Eiropu un Āfriku',
    '🌎' => 'globuss ar Ameriku',
    '🌏' => 'globuss ar Āziju un Austrāliju',
    '🌐' => 'globuss ar meridiāniem',
    '🗺' => 'pasaules karte',
    '🗾' => 'Japānas karte',
    '🧭' => 'kompass',
    '🏔' => 'sniegoti kalni',
    '⛰' => 'kalns',
    '🛘' => 'nogruvums',
    '🌋' => 'vulkāns',
    '🗻' => 'Fudzi kalns',
    '🏕' => 'kempings',
    '🏖' => 'pludmale ar saulessargu',
    '🏜' => 'tuksnesis',
    '🏝' => 'vientuļa sala',
    '🏞' => 'nacionālais parks',
    '🏟' => 'stadions',
    '🏛' => 'klasicisma stila ēka',
    '🏗' => 'būvlaukums',
    '🧱' => 'ķieģelis',
    '🪨' => 'akmens',
    '🪵' => 'koks',
    '🛖' => 'būda',
    '🏘' => 'ēkas',
    '🏚' => 'pamesta ēka',
    '🏠' => 'ēka',
    '🏡' => 'māja ar dārzu',
    '🏢' => 'biroju ēka',
    '🏣' => 'japāņu pasta nodaļa',
    '🏤' => 'pasta nodaļa',
    '🏥' => 'slimnīca',
    '🏦' => 'banka',
    '🏨' => 'viesnīca',
    '🏩' => 'mīlas viesnīca',
    '🏪' => 'diennakts veikals',
    '🏫' => 'skola',
    '🏬' => 'tirdzniecības centrs',
    '🏭' => 'rūpnīca',
    '🏯' => 'japāņu pils',
    '🏰' => 'pils',
    '💒' => 'kāzas',
    '🗼' => 'Tokijas tornis',
    '🗽' => 'Brīvības statuja',
    '⛪' => 'baznīca',
    '🕌' => 'mošeja',
    '🛕' => 'hinduistu templis',
    '🕍' => 'sinagoga',
    '⛩' => 'sintoistu svētnīca',
    '🕋' => 'kaaba',
    '⛲' => 'strūklaka',
    '⛺' => 'telts',
    '🌁' => 'miglains',
    '🌃' => 'zvaigžņota debess',
    '🏙' => 'pilsētas panorāma',
    '🌄' => 'saullēkts pār kalniem',
    '🌅' => 'saullēkts',
    '🌆' => 'pilsētas panorāma krēslā',
    '🌇' => 'saulriets',
    '🌉' => 'tilts naktī',
    '♨' => 'karstie avoti',
    '🎠' => 'karuseļa zirdziņš',
    '🛝' => 'rotaļu laukuma slidkalniņš',
    '🎡' => 'panorāmas rats',
    '🎢' => 'amerikāņu kalniņi',
    '💈' => 'friziera izkārtne',
    '🎪' => 'cirka telts',
    '🚂' => 'lokomotīve',
    '🚃' => 'dzelzceļa vagons',
    '🚄' => 'ātrvilciens',
    '🚅' => 'ātrvilciens ar noapaļotu priekšgalu',
    '🚆' => 'vilciens',
    '🚇' => 'metro',
    '🚈' => 'piepilsētas vilciens',
    '🚉' => 'stacija',
    '🚊' => 'tramvajs',
    '🚝' => 'viensliedes dzelzceļš',
    '🚞' => 'kalnu dzelzceļš',
    '🚋' => 'tramvaja vagons',
    '🚌' => 'autobuss',
    '🚍' => 'pretī braucošs autobuss',
    '🚎' => 'trolejbuss',
    '🚐' => 'mikroautobuss',
    '🚑' => 'ātrās palīdzības mašīna',
    '🚒' => 'ugunsdzēsēju mašīna',
    '🚓' => 'policijas mašīna',
    '🚔' => 'pretī braucoša policijas mašīna',
    '🚕' => 'taksometrs',
    '🚖' => 'pretī braucošs taksometrs',
    '🚗' => 'automašīna',
    '🚘' => 'pretī braucoša automašīna',
    '🚙' => 'kemperis',
    '🛻' => 'piegādes auto',
    '🚚' => 'kravas automašīna',
    '🚛' => 'smagā automašīna',
    '🚜' => 'traktors',
    '🏎' => 'sacīkšu automašīna',
    '🏍' => 'motocikls',
    '🛵' => 'motorollers',
    '🦽' => 'manuāli darbināms ratiņkrēsls',
    '🦼' => 'ar motoru darbināms ratiņkrēsls',
    '🛺' => 'autorikša',
    '🚲' => 'velosipēds',
    '🛴' => 'skuteris',
    '🛹' => 'skrituļdēlis',
    '🛼' => 'skrituļslida',
    '🚏' => 'autobusa pietura',
    '🛣' => 'automaģistrāle',
    '🛤' => 'dzelzceļa sliedes',
    '🛢' => 'eļļas tvertne',
    '⛽' => 'degvielas sūknis',
    '🛞' => 'ritenis',
    '🚨' => 'policijas mašīnas bākuguns',
    '🚥' => 'horizontāls luksofors',
    '🚦' => 'vertikāls luksofors',
    '🛑' => 'stopzīme',
    '🚧' => 'celtniecība',
    '⚓' => 'enkurs',
    '🛟' => 'gredzenu boja',
    '⛵' => 'buru laiva',
    '🛶' => 'kanoe',
    '🚤' => 'ātrlaiva',
    '🛳' => 'pasažieru kuģis',
    '⛴' => 'prāmis',
    '🛥' => 'motorlaiva',
    '🚢' => 'kuģis',
    '✈' => 'lidmašīna',
    '🛩' => 'maza lidmašīna',
    '🛫' => 'lidmašīnas pacelšanās',
    '🛬' => 'lidmašīnas nosēšanās',
    '🪂' => 'izpletnis',
    '💺' => 'sēdeklis',
    '🚁' => 'helikopters',
    '🚟' => 'trošu vilciens',
    '🚠' => 'kalnu trošu ceļš',
    '🚡' => 'gaisa tramvajs',
    '🛰' => 'satelīts',
    '🚀' => 'raķete',
    '🛸' => 'lidojošais šķīvītis',
    '🛎' => 'galda zvans',
    '🧳' => 'bagāža',
    '⌛' => 'iztecējis smilšu pulstenis',
    '⏳' => 'smilšu pulkstenis ar plūstošām smiltīm',
    '⌚' => 'rokaspulkstenis',
    '⏰' => 'modinātājpulkstenis',
    '⏱' => 'hronometrs',
    '⏲' => 'taimeris',
    '🕰' => 'kamīna pulkstenis',
    '🕛' => 'pulksten divpadsmit',
    '🕧' => 'pusviens',
    '🕐' => 'pulksten viens',
    '🕜' => 'pulksten pusdivi',
    '🕑' => 'pulksten divi',
    '🕝' => 'pustrīs',
    '🕒' => 'pulksten trīs',
    '🕞' => 'pusčetri',
    '🕓' => 'pulksten četri',
    '🕟' => 'puspieci',
    '🕔' => 'pulksten pieci',
    '🕠' => 'pusseši',
    '🕕' => 'pulksten seši',
    '🕡' => 'pusseptiņi',
    '🕖' => 'pulksten septiņi',
    '🕢' => 'pusastoņi',
    '🕗' => 'pulksten astoņi',
    '🕣' => 'pusdeviņi',
    '🕘' => 'pulksten deviņi',
    '🕤' => 'pusdesmit',
    '🕙' => 'pulksten desmit',
    '🕥' => 'pusvienpadsmit',
    '🕚' => 'pulksten vienpadsmit',
    '🕦' => 'pusdivpadsmit',
    '🌑' => 'jauns mēness',
    '🌒' => 'augoša mēness sirpis',
    '🌓' => 'augošs pusmēness',
    '🌔' => 'izliekts augošs mēness',
    '🌕' => 'pilnmēness',
    '🌖' => 'izliekts dilstošs mēness',
    '🌗' => 'dilstošs pusmēness',
    '🌘' => 'dilstoša mēness sirpis',
    '🌙' => 'mēness sirpis',
    '🌚' => 'jauna mēness seja',
    '🌛' => 'augoša mēness sirpja seja',
    '🌜' => 'dilstoša mēness sirpja seja',
    '🌡' => 'termometrs',
    '☀' => 'saule',
    '🌝' => 'pilnmēness seja',
    '🌞' => 'saules seja',
    '🪐' => 'gredzenota planēta',
    '⭐' => 'zvaigzne',
    '🌟' => 'spīdoša zvaigzne',
    '🌠' => 'krītoša zvaigzne',
    '🌌' => 'Piena ceļš',
    '☁' => 'mākonis',
    '⛅' => 'saule aiz mākoņa',
    '⛈' => 'mākonis ar zibeni un lietu',
    '🌤' => 'saule aiz maza mākoņa',
    '🌥' => 'saule aiz liela mākoņa',
    '🌦' => 'saule aiz lietus mākoņa',
    '🌧' => 'lietus mākonis',
    '🌨' => 'sniega mākonis',
    '🌩' => 'mākonis ar zibeni',
    '🌪' => 'tornado',
    '🌫' => 'migla',
    '🌬' => 'pūš vējš',
    '🌀' => 'ciklons',
    '🌈' => 'varavīksne',
    '🌂' => 'aizvērts lietussargs',
    '☂' => 'lietussargs',
    '☔' => 'lietussargs ar lietus lāsēm',
    '⛱' => 'saulessargs',
    '⚡' => 'augstspriegums',
    '❄' => 'sniegpārsla',
    '☃' => 'sniegavīrs',
    '⛄' => 'sniegavīrs bez sniega',
    '☄' => 'komēta',
    '🔥' => 'uguns',
    '💧' => 'lāse',
    '🌊' => 'vilnis',
    '🎃' => 'izgrebts ķirbis',
    '🎄' => 'Ziemassvētku eglīte',
    '🎆' => 'salūts',
    '🎇' => 'brīnumsvecīte',
    '🧨' => 'petarde',
    '✨' => 'zibšņi',
    '🎈' => 'balons',
    '🎉' => 'konfeti plaukšķene',
    '🎊' => 'konfeti bumbiņa',
    '🎋' => 'vēlmju koks',
    '🎍' => 'priedes dekorācija',
    '🎎' => 'japāņu lelles',
    '🎏' => 'zivju veida karodziņi',
    '🎐' => 'vēja zvans',
    '🎑' => 'mēness vērošanas ceremonija',
    '🧧' => 'sarkana aploksne',
    '🎀' => 'pušķītis',
    '🎁' => 'iesaiņota dāvana',
    '🎗' => 'atceres lentīte',
    '🎟' => 'ieejas biļetes',
    '🎫' => 'biļete',
    '🎖' => 'militāra medaļa',
    '🏆' => 'kauss',
    '🏅' => 'sporta medaļa',
    '🥇' => 'medaļa par 1. vietu',
    '🥈' => 'medaļa par 2. vietu',
    '🥉' => 'medaļa par 3. vietu',
    '⚽' => 'futbola bumba',
    '⚾' => 'beisbola bumba',
    '🥎' => 'softbols',
    '🏀' => 'basketbola bumba',
    '🏐' => 'volejbola bumba',
    '🏈' => 'amerikāņu futbola bumba',
    '🏉' => 'regbija bumba',
    '🎾' => 'tenisa bumbiņa',
    '🥏' => 'lidojošais šķīvis',
    '🎳' => 'boulings',
    '🏏' => 'krikets',
    '🏑' => 'lauka hokejs',
    '🏒' => 'hokejs uz ledus',
    '🥍' => 'lakross',
    '🏓' => 'galda teniss',
    '🏸' => 'badmintons',
    '🥊' => 'boksa cimds',
    '🥋' => 'cīņu sporta tērps',
    '🥅' => 'vārti ar tīklu',
    '⛳' => 'karodziņš bedrītē',
    '⛸' => 'slida',
    '🎣' => 'makšķere',
    '🤿' => 'niršanas maska',
    '🎽' => 'skriešanas krekls',
    '🎿' => 'slēpes',
    '🛷' => 'kamaniņas',
    '🥌' => 'kērlinga akmens',
    '🎯' => 'šautriņa mērķī',
    '🪀' => 'jojo',
    '🪁' => 'gaisa pūķis',
    '🔫' => 'ūdens pistole',
    '🎱' => 'biljarda bumbiņa',
    '🔮' => 'kristāla lode',
    '🪄' => 'burvju nūjiņa',
    '🎮' => 'videospēle',
    '🕹' => 'kursorsvira',
    '🎰' => 'spēļu automāts',
    '🎲' => 'metamais kauliņš',
    '🧩' => 'attēlu mīkla',
    '🧸' => 'lāčuks',
    '🪅' => 'pinjata',
    '🪩' => 'spoguļa bumba',
    '🪆' => 'matrjoškas',
    '♠' => 'pīķis',
    '♥' => 'ercens',
    '♦' => 'kāravs',
    '♣' => 'kreicis',
    '♟' => 'bandinieks',
    '🃏' => 'džokers',
    '🀄' => 'Mahjong kauliņš, sarkanais pūķis',
    '🎴' => 'ziedu kārtis',
    '🎭' => 'skatuves māksla',
    '🖼' => 'ierāmēta glezna',
    '🎨' => 'gleznotāja palete',
    '🧵' => 'pavediens',
    '🪡' => 'šujamadata',
    '🧶' => 'dzija',
    '🪢' => 'mezgls',
    '👓' => 'brilles',
    '🕶' => 'saulesbrilles',
    '🥽' => 'aizsargbrilles',
    '🥼' => 'laboratorijas halāts',
    '🦺' => 'drošības veste',
    '👔' => 'kaklasaite',
    '👕' => 'T krekls',
    '👖' => 'džinsi',
    '🧣' => 'šalle',
    '🧤' => 'cimdi',
    '🧥' => 'mētelis',
    '🧦' => 'zeķes',
    '👗' => 'kleita',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'kopējais peldkostīms',
    '🩲' => 'peldbikses',
    '🩳' => 'šorti',
    '👙' => 'bikini',
    '👚' => 'sieviešu drēbes',
    '🪭' => 'salokāms rokas vēdeklis',
    '👛' => 'naudasmaks',
    '👜' => 'rokassoma',
    '👝' => 'kosmētikas maciņš',
    '🛍' => 'iepirkumu maisiņi',
    '🎒' => 'mugursoma',
    '🩴' => 'siksniņsandale',
    '👞' => 'vīriešu kurpe',
    '👟' => 'skriešanas apavi',
    '🥾' => 'pārgājienu zābaks',
    '🥿' => 'baleta kurpe',
    '👠' => 'augstpapēžu kurpe',
    '👡' => 'sieviešu sandale',
    '🩰' => 'baleta kurpes',
    '👢' => 'sieviešu zābaks',
    '🪮' => 'matu ķemme',
    '👑' => 'kronis',
    '👒' => 'sieviešu cepure',
    '🎩' => 'cilindrs',
    '🎓' => 'izlaiduma cepure',
    '🧢' => 'cepure ar nagu',
    '🪖' => 'militārā ķivere',
    '⛑' => 'glābēja ķivere',
    '📿' => 'lūgšanu krelles',
    '💄' => 'lūpukrāsa',
    '💍' => 'gredzens',
    '💎' => 'dārgakmens',
    '🔇' => 'izslēgts skaļrunis',
    '🔈' => 'skaļrunis',
    '🔉' => 'ieslēgts skaļrunis',
    '🔊' => 'skaļš skaļrunis',
    '📢' => 'pastiprinātājs',
    '📣' => 'megafons',
    '📯' => 'pastnieka taure',
    '🔔' => 'zvans',
    '🔕' => 'pārsvītrots zvaniņš',
    '🎼' => 'nošu līnijas',
    '🎵' => 'nots',
    '🎶' => 'notis',
    '🎙' => 'studijas mikrofons',
    '🎚' => 'skaļuma slīdnis',
    '🎛' => 'slēdži',
    '🎤' => 'mikrofons',
    '🎧' => 'austiņas',
    '📻' => 'radio',
    '🎷' => 'saksofons',
    '🎺' => 'trompete',
    '🪊' => 'trombons',
    '🪗' => 'akordeons',
    '🎸' => 'ģitāra',
    '🎹' => 'klavieru taustiņi',
    '🎻' => 'vijole',
    '🪕' => 'bandžo',
    '🥁' => 'bungas',
    '🪘' => 'garās bungas',
    '🪇' => 'marakass',
    '🪈' => 'flauta',
    '🪉' => 'arfa',
    '📱' => 'mobilais tālrunis',
    '📲' => 'mobilais tālrunis ar bultiņu',
    '☎' => 'tālrunis',
    '📞' => 'tālruņa klausule',
    '📟' => 'peidžers',
    '📠' => 'fakss',
    '🔋' => 'baterija',
    '🪫' => 'zems akumulatora līmenis',
    '🔌' => 'kontaktdakša',
    '💻' => 'klēpjdators',
    '🖥' => 'galddators',
    '🖨' => 'printeris',
    '⌨' => 'tastatūra',
    '🖱' => 'datorpele',
    '🖲' => 'kursorbumba',
    '💽' => 'minidisks',
    '💾' => 'diskete',
    '💿' => 'optiskais disks',
    '📀' => 'dvd',
    '🧮' => 'skaitīkļi',
    '🎥' => 'kinokamera',
    '🎞' => 'filmas lente',
    '📽' => 'filmu projektors',
    '🎬' => 'klapīte',
    '📺' => 'televizors',
    '📷' => 'fotokamera',
    '📸' => 'fotokamera ar zibspuldzi',
    '📹' => 'videokamera',
    '📼' => 'videokasete',
    '🔍' => 'pa kreisi vērsta lupa',
    '🔎' => 'pa labi vērsta lupa',
    '🕯' => 'svece',
    '💡' => 'spuldze',
    '🔦' => 'kabatas lukturītis',
    '🏮' => 'sarkana papīra laterna',
    '🪔' => 'eļļas lampa',
    '📔' => 'bloknots ar dekoratīvu vāku',
    '📕' => 'aizvērta grāmata',
    '📖' => 'atvērta grāmata',
    '📗' => 'zaļa grāmata',
    '📘' => 'zila grāmata',
    '📙' => 'oranža grāmata',
    '📚' => 'grāmatas',
    '📓' => 'piezīmju grāmata',
    '📒' => 'grāmata ar spirāli',
    '📃' => 'lapa ar atliektu malu',
    '📜' => 'papīra tīstoklis',
    '📄' => 'papīra lapa',
    '📰' => 'avīze',
    '🗞' => 'satīta avīze',
    '📑' => 'līmkarodziņi',
    '🔖' => 'grāmatzīme',
    '🏷' => 'atzīme',
    '🪙' => 'monēta',
    '💰' => 'naudas maiss',
    '🪎' => 'dārgumu lāde',
    '💴' => 'jenas banknote',
    '💵' => 'dolāra banknote',
    '💶' => 'eiro banknote',
    '💷' => 'sterliņu mārciņas banknote',
    '💸' => 'banknote ar spārniem',
    '💳' => 'kredītkarte',
    '🧾' => 'kvīts',
    '💹' => 'augšupejoša diagrammas līkne ar jenas simbolu',
    '✉' => 'aploksne',
    '📧' => 'e-pasts',
    '📨' => 'ienākoša aploksne',
    '📩' => 'aploksne ar bultiņu',
    '📤' => 'izejošo dokumentu paliktnis',
    '📥' => 'ienākošo dokumentu paliktnis',
    '📦' => 'paciņa',
    '📫' => 'aizvērta pastkaste ar paceltu karodziņu',
    '📪' => 'aizvērta pastkaste ar nolaistu karodziņu',
    '📬' => 'atvērta pastkaste ar paceltu karodziņu',
    '📭' => 'atvērta pastkaste ar nolaistu karodziņu',
    '📮' => 'pastkaste',
    '🗳' => 'vēlēšanu urna ar vēlēšanu zīmi',
    '✏' => 'zīmulis',
    '✒' => 'melna rakstāmspalva',
    '🖋' => 'tintes pildspalva',
    '🖊' => 'pildspalva',
    '🖌' => 'ota',
    '🖍' => 'krītiņš',
    '📝' => 'piezīme',
    '💼' => 'portfelis',
    '📁' => 'dokumentu mape',
    '📂' => 'atvērta dokumentu mape',
    '🗂' => 'dokumentu sadalītājs',
    '📅' => 'kalendārs',
    '📆' => 'noplēšamais kalendārs',
    '🗒' => 'bloknots ar spirāli',
    '🗓' => 'kalendārs ar spirāli',
    '📇' => 'kartīšu rādītājs',
    '📈' => 'augšupejoša diagrammas līkne',
    '📉' => 'lejupejoša diagrammas līkne',
    '📊' => 'joslu diagramma',
    '📋' => 'dokumentu paliktnis',
    '📌' => 'piespraude',
    '📍' => 'apaļa spraudīte',
    '📎' => 'papīra saspraude',
    '🖇' => 'savienotas saspraudes',
    '📏' => 'taisns lineāls',
    '📐' => 'trīsstūra lineāls',
    '✂' => 'šķēres',
    '🗃' => 'dokumentu kaste',
    '🗄' => 'dokumentu skapis',
    '🗑' => 'atkritumu grozs',
    '🔒' => 'slēdzene',
    '🔓' => 'atvērta slēdzene',
    '🔏' => 'slēdzene ar rakstāmspalvu',
    '🔐' => 'aizvērta slēdzene ar atslēgu',
    '🔑' => 'atslēga',
    '🗝' => 'veca atslēga',
    '🔨' => 'āmurs',
    '🪓' => 'cirvis',
    '⛏' => 'cirtnis',
    '⚒' => 'āmurs un cirtnis',
    '🛠' => 'āmurs un uzgriežņu atslēga',
    '🗡' => 'duncis',
    '⚔' => 'sakrustoti zobeni',
    '💣' => 'spridzeklis',
    '🪃' => 'bumerangs',
    '🏹' => 'loks un bulta',
    '🛡' => 'vairogs',
    '🪚' => 'vienrokas zāģis',
    '🔧' => 'uzgriežņu atslēga',
    '🪛' => 'skrūvgriezis',
    '🔩' => 'skrūve un uzgrieznis',
    '⚙' => 'zobrats',
    '🗜' => 'skrūvspīles',
    '⚖' => 'svari',
    '🦯' => 'baltais atbalsta spieķis',
    '🔗' => 'ķēdes posms',
    '⛓' => 'ķēdes',
    '🪝' => 'āķis',
    '🧰' => 'darbarīku kaste',
    '🧲' => 'magnēts',
    '🪜' => 'kāpnes',
    '🪏' => 'lāpsta',
    '⚗' => 'destilēšanas aparāts',
    '🧪' => 'mēģene',
    '🧫' => 'Petri trauks',
    '🧬' => 'DNS',
    '🔬' => 'mikroskops',
    '🔭' => 'teleskops',
    '📡' => 'satelīta šķīvis',
    '💉' => 'šļirce',
    '🩸' => 'asins pile',
    '💊' => 'zāļu kapsula',
    '🩹' => 'plāksteris',
    '🩼' => 'kruķis',
    '🩺' => 'stetoskops',
    '🩻' => 'rentgens',
    '🚪' => 'durvis',
    '🛗' => 'lifts',
    '🪞' => 'spogulis',
    '🪟' => 'logs',
    '🛏' => 'gulta',
    '🛋' => 'dīvāns un lampa',
    '🪑' => 'krēsls',
    '🚽' => 'tualetes pods',
    '🪠' => 'vantūzs',
    '🚿' => 'duša',
    '🛁' => 'vanna',
    '🪤' => 'peļu slazds',
    '🪒' => 'bārdas nazis',
    '🧴' => 'losjona pudele',
    '🧷' => 'saspraude',
    '🧹' => 'slota',
    '🧺' => 'grozs',
    '🧻' => 'papīra rullis',
    '🪣' => 'spainis',
    '🧼' => 'ziepes',
    '🫧' => 'burbuļi',
    '🪥' => 'zobu suka',
    '🧽' => 'sūklis',
    '🧯' => 'ugunsdzēsības aparāts',
    '🛒' => 'iepirkumu ratiņi',
    '🚬' => 'aizdegta cigarete',
    '⚰' => 'zārks',
    '🪦' => 'kapakmens',
    '⚱' => 'pelnu urna',
    '🧿' => 'amulets pret ļaunu aci',
    '🪬' => 'hamsa',
    '🗿' => 'Lieldienu salu statuja',
    '🪧' => 'plakāts',
    '🪪' => 'identifikācijas karte',
    '🏧' => 'bankomāta zīme',
    '🚮' => 'atkritumu urnas zīme',
    '🚰' => 'dzeramais ūdens',
    '♿' => 'ratiņkrēsls',
    '🚹' => 'vīriešu tualete',
    '🚺' => 'sieviešu tualete',
    '🚻' => 'tualete',
    '🚼' => 'zīdaiņa simbols',
    '🚾' => 'ateja',
    '🛂' => 'pasu kontrole',
    '🛃' => 'muita',
    '🛄' => 'bagāžas saņemšana',
    '🛅' => 'bagāžas glabātava',
    '⚠' => 'brīdinājums',
    '🚸' => 'bērni šķērso ielu',
    '⛔' => 'iebraukt aizliegts',
    '🚫' => 'aizliegts',
    '🚳' => 'velosipēdiem braukt aizliegts',
    '🚭' => 'smēķēt aizliegts',
    '🚯' => 'atkritumus mest aizliegts',
    '🚱' => 'nav dzeramais ūdens',
    '🚷' => 'gājējiem iet aizliegts',
    '📵' => 'mobilie tālruņi aizliegti',
    '🔞' => 'tikai no 18 gadu vecuma',
    '☢' => 'radioaktīvs',
    '☣' => 'bioloģiskais apdraudējums',
    '⬆' => 'augšupbultiņa',
    '↗' => 'uz augšējo labo stūri vērsta bultiņa',
    '➡' => 'labā bultiņa',
    '↘' => 'uz apakšējo labo stūri vērsta bultiņa',
    '⬇' => 'lejupbultiņa',
    '↙' => 'uz apakšējo kreiso stūri vērsta bultiņa',
    '⬅' => 'kreisā bultiņa',
    '↖' => 'uz augšējo kreiso stūri vērsta bultiņa',
    '↕' => 'augšup un lejup vērsta bultiņa',
    '↔' => 'pa kreisi un pa labi vērsta bultiņa',
    '↩' => 'pa kreisi vērsta izliekta bultiņa',
    '↪' => 'pa labi vērsta izliekta bultiņa',
    '⤴' => 'augšup vērsta izliekta bultiņa',
    '⤵' => 'lejup vērsta izliekta bultiņa',
    '🔃' => 'pulksteņrādītāja virzienā vērstas vertikālas bultiņas',
    '🔄' => 'pretēji pulksteņrādītāja virzienam vērstas bultiņas',
    '🔙' => 'bultiņa ar uzrakstu Back',
    '🔚' => 'bultiņa ar uzrakstu End',
    '🔛' => 'bultiņa ar uzrakstu On!',
    '🔜' => 'bultiņa ar uzrakstu Soon',
    '🔝' => 'bultiņa ar uzrakstu Top',
    '🛐' => 'lūgšanu vieta',
    '⚛' => 'atoma simbols',
    '🕉' => 'om simbols',
    '✡' => 'Dāvida zvaigzne',
    '☸' => 'darmas rats',
    '☯' => 'iņ un jaņ',
    '✝' => 'kristiešu krusts',
    '☦' => 'pareizticīgo krusts',
    '☪' => 'zvaigzne un pusmēness',
    '☮' => 'miera simbols',
    '🕎' => 'menora',
    '🔯' => 'sešstaru zvaigzne ar punktu vidū',
    '🪯' => 'khanda',
    '♈' => 'zodiaka zīme Auns',
    '♉' => 'zodiaka zīme Vērsis',
    '♊' => 'zodiaka zīme Dvīņi',
    '♋' => 'zodiaka zīme Vēzis',
    '♌' => 'zodiaka zīme Lauva',
    '♍' => 'zodiaka zīme Jaunava',
    '♎' => 'zodiaka zīme Svari',
    '♏' => 'zodiaka zīme Skorpions',
    '♐' => 'zodiaka zīme Strēlnieks',
    '♑' => 'zodiaka zīme Mežāzis',
    '♒' => 'zodiaka zīme Ūdensvīrs',
    '♓' => 'zodiaka zīme Zivis',
    '⛎' => 'zodiaka zīme Čūsknesis',
    '🔀' => 'poga Jaukta secība',
    '🔁' => 'poga Atkārtot',
    '🔂' => 'poga Atkārtot vienu dziesmu',
    '▶' => 'poga Atskaņot',
    '⏩' => 'poga Pārtīt uz priekšu',
    '⏭' => 'poga Nākamā dziesma',
    '⏯' => 'poga Atskaņot vai apturēt',
    '◀' => 'poga Atpakaļ',
    '⏪' => 'poga Attīt atpakaļ',
    '⏮' => 'poga Iepriekšējā dziesma',
    '🔼' => 'poga Augšup',
    '⏫' => 'poga Ātri augšup',
    '🔽' => 'poga Lejup',
    '⏬' => 'poga Ātri lejup',
    '⏸' => 'poga Pauze',
    '⏹' => 'poga Pārtraukt',
    '⏺' => 'poga Ierakstīt',
    '⏏' => 'poga Izstumt',
    '🎦' => 'kino',
    '🔅' => 'samazināt spilgtumu',
    '🔆' => 'palielināt spilgtumu',
    '📶' => 'signāla stipruma joslas',
    '🛜' => 'bezvadu internets',
    '📳' => 'vibrozvana režīms',
    '📴' => 'izslēgts mobilais tālrunis',
    '♀' => 'sieviešu simbols',
    '♂' => 'vīriešu simbols',
    '⚧' => 'transdzimuma simbols',
    '✖' => 'reizināt',
    '➕' => 'pluszīme',
    '➖' => 'mīnuss',
    '➗' => 'dalīt',
    '🟰' => 'smagā vienādības zīme',
    '♾' => 'bezgalība',
    '‼' => 'divas izsaukuma zīmes',
    '⁉' => 'izsaukuma un jautājuma zīme',
    '❓' => 'sarkana jautājuma zīme',
    '❔' => 'balta jautājuma zīme',
    '❕' => 'balta izsaukuma zīme',
    '❗' => 'sarkana izsaukuma zīme',
    '〰' => 'viļņota domuzīme',
    '💱' => 'valūtas maiņa',
    '💲' => 'dolāra zīme',
    '⚕' => 'medicīnas simbols',
    '♻' => 'atkritumu pārstrādes simbols',
    '⚜' => 'lilijas simbols',
    '🔱' => 'trijzaris',
    '📛' => 'vārda nozīmīte',
    '🔰' => 'japāņu simbols, kas apzīmē iesācēju',
    '⭕' => 'liels aplis',
    '✅' => 'balta kontrolzīme',
    '☑' => 'atzīmēta izvēles rūtiņa',
    '✔' => 'kontrolzīme',
    '❌' => 'krustiņš',
    '❎' => 'krustiņa poga',
    '➰' => 'cilpiņa',
    '➿' => 'dubulta cilpa',
    '〽' => 'partijas sākuma zīme',
    '✳' => 'astoņstaru zvaigznīte',
    '✴' => 'četrstaru zvaigzne',
    '❇' => 'dzirkstis',
    '™' => 'preču zīme',
    '🫟' => 'šļakatas',
    '🔠' => 'lielie latīņu burti',
    '🔡' => 'mazie latīņu burti',
    '🔢' => 'cipari',
    '🔣' => 'simboli',
    '🔤' => 'latīņu burti',
    '🅰' => 'A poga (asinsgrupa)',
    '🆎' => 'AB poga (asinsgrupa)',
    '🅱' => 'B poga (asinsgrupa)',
    '🆑' => 'poga CL',
    '🆒' => 'uzraksts Cool kvadrātveida ietvarā',
    '🆓' => 'uzraksts Free kvadrātveida ietvarā',
    'ℹ' => 'informācijas simbols',
    '🆔' => 'uzraksts ID kvadrātveida ietvarā',
    'Ⓜ' => 'burts M apļveida ietvarā',
    '🆕' => 'uzraksts New kvadrātveida ietvarā',
    '🆖' => 'uzraksts NG kvadrātveida ietvarā',
    '🅾' => 'O poga (asinsgrupa)',
    '🆗' => 'uzraksts OK kvadrātveida ietvarā',
    '🅿' => 'poga P',
    '🆘' => 'uzraksts SOS kvadrātveida ietvarā',
    '🆙' => 'poga Up!',
    '🆚' => 'uzraksts VS kvadrātveida ietvarā',
    '🈁' => 'uzraksts Šeit katakanā kvadrātveida ietvarā',
    '🈂' => 'uzraksts Pakalpojums katakanā kvadrātveida ietvarā',
    '🈷' => 'ideogramma Mēness kvadrātveida ietvarā',
    '🈶' => 'ideogramma Būt kvadrātveida ietvarā',
    '🈯' => 'ideogramma Norāde kvadrātveida ietvarā',
    '🉐' => 'ideogramma Izdevīgi apļveida ietvarā',
    '🈹' => 'ideogramma Atlaide kvadrātveida ietvarā',
    '🈚' => 'ideogramma Bezmaksas kvadrātveida ietvarā',
    '🈲' => 'ideogramma Aizliegt kvadrātveida ietvarā',
    '🉑' => 'ideogramma Piekrist apļveida ietvarā',
    '🈸' => 'ideogramma Pieprasīt kvadrātveida ietvarā',
    '🈴' => 'ideogramma Sekmīgi kvadrātveida ietvarā',
    '🈳' => 'ideogramma Brīvs kvadrātveida ietvarā',
    '㊗' => 'ideogramma Apsveikums kvadrātveida ietvarā',
    '㊙' => 'ideogramma Slepens kvadrātveida ietvarā',
    '🈺' => 'ideogramma Strādā kvadrātveida ietvarā',
    '🈵' => 'ideogramma Pilns kvadrātveida ietvarā',
    '🔴' => 'sarkans aplis',
    '🟠' => 'oranžs aplis',
    '🟡' => 'dzeltens aplis',
    '🟢' => 'zaļš aplis',
    '🔵' => 'zils aplis',
    '🟣' => 'violets aplis',
    '🟤' => 'brūns aplis',
    '⚫' => 'melns aplis',
    '⚪' => 'balts aplis',
    '🟥' => 'sarkans kvadrāts',
    '🟧' => 'oranžs kvadrāts',
    '🟨' => 'dzeltens kvadrāts',
    '🟩' => 'zaļš kvadrāts',
    '🟦' => 'zils kvadrāts',
    '🟪' => 'violets kvadrāts',
    '🟫' => 'brūns kvadrāts',
    '⬛' => 'liels melns kvadrāts',
    '⬜' => 'liels balts kvadrāts',
    '◼' => 'vidējs melns kvadrāts',
    '◻' => 'vidējs balts kvadrāts',
    '◾' => 'vidēji mazs melns kvadrāts',
    '◽' => 'vidēji mazs balts kvadrāts',
    '▪' => 'mazs melns kvadrāts',
    '▫' => 'mazs balts kvadrāts',
    '🔶' => 'liels oranžs rombs',
    '🔷' => 'liels zils rombs',
    '🔸' => 'mazs oranžs rombs',
    '🔹' => 'mazs zils rombs',
    '🔺' => 'augšupvērsts sarkans trīsstūris',
    '🔻' => 'lejupvērsts sarkans trīsstūris',
    '💠' => 'rombs ar punktu',
    '🔘' => 'radiopoga',
    '🔳' => 'balta kvadrātveida poga',
    '🔲' => 'melna kvadrātveida poga',
    '🏁' => 'finiša karogs',
    '🚩' => 'trīsstūrveida karogs',
    '🎌' => 'sakrustoti karogi',
    '🏴' => 'melns karogs',
    '🏳' => 'balts karogs',
];
