<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'busu: mtu mzima, mtu mzima, ngozi nyeupe na ngozi nyeupe kiasi',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'busu: mtu mzima, mtu mzima, ngozi nyeupe na ngozi ya kahawia',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'busu: mtu mzima, mtu mzima, ngozi nyeupe na ngozi nyeusi kiasi',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'busu: mtu mzima, mtu mzima, ngozi nyeupe na ngozi nyeusi',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'busu: mtu mzima, mtu mzima, ngozi nyeupe kiasi na ngozi nyeupe',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'busu: mtu mzima, mtu mzima, ngozi nyeupe kiasi na ngozi ya kahawia',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'busu: mtu mzima, mtu mzima, ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'busu: mtu mzima, mtu mzima, ngozi nyeupe kiasi na ngozi nyeusi',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'busu: mtu mzima, mtu mzima, ngozi ya kahawia na ngozi nyeupe',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'busu: mtu mzima, mtu mzima, ngozi ya kahawia na ngozi nyeupe kiasi',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'busu: mtu mzima, mtu mzima, ngozi ya kahawia na ngozi nyeusi kiasi',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'busu: mtu mzima, mtu mzima, ngozi ya kahawia na ngozi nyeusi',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'busu: mtu mzima, mtu mzima, ngozi nyeusi kiasi na ngozi nyeupe',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'busu: mtu mzima, mtu mzima, ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'busu: mtu mzima, mtu mzima, ngozi nyeusi kiasi na ngozi ya kahawia',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'busu: mtu mzima, mtu mzima, ngozi nyeusi kiasi na ngozi nyeusi',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'busu: mtu mzima, mtu mzima, ngozi nyeusi na ngozi nyeupe',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'busu: mtu mzima, mtu mzima, ngozi nyeusi na ngozi nyeupe kiasi',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'busu: mtu mzima, mtu mzima, ngozi nyeusi na ngozi ya kahawia',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'busu: mtu mzima, mtu mzima, ngozi nyeusi na ngozi nyeusi kiasi',
    '👨🏻‍❤‍💋‍👨🏻' => 'busu: mwanamume, mwanamume na ngozi nyeupe',
    '👨🏻‍❤‍💋‍👨🏼' => 'busu: mwanamume, mwanamume, ngozi nyeupe na ngozi nyeupe kiasi',
    '👨🏻‍❤‍💋‍👨🏽' => 'busu: mwanamume, mwanamume, ngozi nyeupe na ngozi ya kahawia',
    '👨🏻‍❤‍💋‍👨🏾' => 'busu: mwanamume, mwanamume, ngozi nyeupe na ngozi nyeusi kiasi',
    '👨🏻‍❤‍💋‍👨🏿' => 'busu: mwanamume, mwanamume, ngozi nyeupe na ngozi nyeusi',
    '👨🏼‍❤‍💋‍👨🏻' => 'busu: mwanamume, mwanamume, ngozi nyeupe kiasi na ngozi nyeupe',
    '👨🏼‍❤‍💋‍👨🏼' => 'busu: mwanamume, mwanamume na ngozi nyeupe kiasi',
    '👨🏼‍❤‍💋‍👨🏽' => 'busu: mwanamume, mwanamume, ngozi nyeupe kiasi na ngozi ya kahawia',
    '👨🏼‍❤‍💋‍👨🏾' => 'busu: mwanamume, mwanamume, ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👨🏼‍❤‍💋‍👨🏿' => 'busu: mwanamume, mwanamume, ngozi nyeupe kiasi na ngozi nyeusi',
    '👨🏽‍❤‍💋‍👨🏻' => 'busu: mwanamume, mwanamume, ngozi ya kahawia na ngozi nyeupe',
    '👨🏽‍❤‍💋‍👨🏼' => 'busu: mwanamume, mwanamume, ngozi ya kahawia na ngozi nyeupe kiasi',
    '👨🏽‍❤‍💋‍👨🏽' => 'busu: mwanamume, mwanamume na ngozi ya kahawia',
    '👨🏽‍❤‍💋‍👨🏾' => 'busu: mwanamume, mwanamume, ngozi ya kahawia na ngozi nyeusi kiasi',
    '👨🏽‍❤‍💋‍👨🏿' => 'busu: mwanamume, mwanamume, ngozi ya kahawia na ngozi nyeusi',
    '👨🏾‍❤‍💋‍👨🏻' => 'busu: mwanamume, mwanamume, ngozi nyeusi kiasi na ngozi nyeupe',
    '👨🏾‍❤‍💋‍👨🏼' => 'busu: mwanamume, mwanamume, ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👨🏾‍❤‍💋‍👨🏽' => 'busu: mwanamume, mwanamume, ngozi nyeusi kiasi na ngozi ya kahawia',
    '👨🏾‍❤‍💋‍👨🏾' => 'busu: mwanamume, mwanamume na ngozi nyeusi kiasi',
    '👨🏾‍❤‍💋‍👨🏿' => 'busu: mwanamume, mwanamume, ngozi nyeusi kiasi na ngozi nyeusi',
    '👨🏿‍❤‍💋‍👨🏻' => 'busu: mwanamume, mwanamume, ngozi nyeusi na ngozi nyeupe',
    '👨🏿‍❤‍💋‍👨🏼' => 'busu: mwanamume, mwanamume, ngozi nyeusi na ngozi nyeupe kiasi',
    '👨🏿‍❤‍💋‍👨🏽' => 'busu: mwanamume, mwanamume, ngozi nyeusi na ngozi ya kahawia',
    '👨🏿‍❤‍💋‍👨🏾' => 'busu: mwanamume, mwanamume, ngozi nyeusi na ngozi nyeusi kiasi',
    '👨🏿‍❤‍💋‍👨🏿' => 'busu: mwanamume, mwanamume na ngozi nyeusi',
    '👩🏻‍❤‍💋‍👨🏻' => 'busu: mwanamke, mwanamume na ngozi nyeupe',
    '👩🏻‍❤‍💋‍👨🏼' => 'busu: mwanamke, mwanamume, ngozi nyeupe na ngozi nyeupe kiasi',
    '👩🏻‍❤‍💋‍👨🏽' => 'busu: mwanamke, mwanamume, ngozi nyeupe na ngozi ya kahawia',
    '👩🏻‍❤‍💋‍👨🏾' => 'busu: mwanamke, mwanamume, ngozi nyeupe na ngozi nyeusi kiasi',
    '👩🏻‍❤‍💋‍👨🏿' => 'busu: mwanamke, mwanamume, ngozi nyeupe na ngozi nyeusi',
    '👩🏼‍❤‍💋‍👨🏻' => 'busu: mwanamke, mwanamume, ngozi nyeupe kiasi na ngozi nyeupe',
    '👩🏼‍❤‍💋‍👨🏼' => 'busu: mwanamke, mwanamume na ngozi nyeupe kiasi',
    '👩🏼‍❤‍💋‍👨🏽' => 'busu: mwanamke, mwanamume, ngozi nyeupe kiasi na ngozi ya kahawia',
    '👩🏼‍❤‍💋‍👨🏾' => 'busu: mwanamke, mwanamume, ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👩🏼‍❤‍💋‍👨🏿' => 'busu: mwanamke, mwanamume, ngozi nyeupe kiasi na ngozi nyeusi',
    '👩🏽‍❤‍💋‍👨🏻' => 'busu: mwanamke, mwanamume, ngozi ya kahawia na ngozi nyeupe',
    '👩🏽‍❤‍💋‍👨🏼' => 'busu: mwanamke, mwanamume, ngozi ya kahawia na ngozi nyeupe kiasi',
    '👩🏽‍❤‍💋‍👨🏽' => 'busu: mwanamke, mwanamume na ngozi ya kahawia',
    '👩🏽‍❤‍💋‍👨🏾' => 'busu: mwanamke, mwanamume, ngozi ya kahawia na ngozi nyeusi kiasi',
    '👩🏽‍❤‍💋‍👨🏿' => 'busu: mwanamke, mwanamume, ngozi ya kahawia na ngozi nyeusi',
    '👩🏾‍❤‍💋‍👨🏻' => 'busu: mwanamke, mwanamume, ngozi nyeusi kiasi na ngozi nyeupe',
    '👩🏾‍❤‍💋‍👨🏼' => 'busu: mwanamke, mwanamume, ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👩🏾‍❤‍💋‍👨🏽' => 'busu: mwanamke, mwanamume, ngozi nyeusi kiasi na ngozi ya kahawia',
    '👩🏾‍❤‍💋‍👨🏾' => 'busu: mwanamke, mwanamume na ngozi nyeusi kiasi',
    '👩🏾‍❤‍💋‍👨🏿' => 'busu: mwanamke, mwanamume, ngozi nyeusi kiasi na ngozi nyeusi',
    '👩🏿‍❤‍💋‍👨🏻' => 'busu: mwanamke, mwanamume, ngozi nyeusi na ngozi nyeupe',
    '👩🏿‍❤‍💋‍👨🏼' => 'busu: mwanamke, mwanamume, ngozi nyeusi na ngozi nyeupe kiasi',
    '👩🏿‍❤‍💋‍👨🏽' => 'busu: mwanamke, mwanamume, ngozi nyeusi na ngozi ya kahawia',
    '👩🏿‍❤‍💋‍👨🏾' => 'busu: mwanamke, mwanamume, ngozi nyeusi na ngozi nyeusi kiasi',
    '👩🏿‍❤‍💋‍👨🏿' => 'busu: mwanamke, mwanamume na ngozi nyeusi',
    '👩🏻‍❤‍💋‍👩🏻' => 'busu: mwanamke, mwanamke na ngozi nyeupe',
    '👩🏻‍❤‍💋‍👩🏼' => 'busu: mwanamke, mwanamke, ngozi nyeupe na ngozi nyeupe kiasi',
    '👩🏻‍❤‍💋‍👩🏽' => 'busu: mwanamke, mwanamke, ngozi nyeupe na ngozi ya kahawia',
    '👩🏻‍❤‍💋‍👩🏾' => 'busu: mwanamke, mwanamke, ngozi nyeupe na ngozi nyeusi kiasi',
    '👩🏻‍❤‍💋‍👩🏿' => 'busu: mwanamke, mwanamke, ngozi nyeupe na ngozi nyeusi',
    '👩🏼‍❤‍💋‍👩🏻' => 'busu: mwanamke, mwanamke, ngozi nyeupe kiasi na ngozi nyeupe',
    '👩🏼‍❤‍💋‍👩🏼' => 'busu: mwanamke, mwanamke na ngozi nyeupe kiasi',
    '👩🏼‍❤‍💋‍👩🏽' => 'busu: mwanamke, mwanamke, ngozi nyeupe kiasi na ngozi ya kahawia',
    '👩🏼‍❤‍💋‍👩🏾' => 'busu: mwanamke, mwanamke, ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👩🏼‍❤‍💋‍👩🏿' => 'busu: mwanamke, mwanamke, ngozi nyeupe kiasi na ngozi nyeusi',
    '👩🏽‍❤‍💋‍👩🏻' => 'busu: mwanamke, mwanamke, ngozi ya kahawia na ngozi nyeupe',
    '👩🏽‍❤‍💋‍👩🏼' => 'busu: mwanamke, mwanamke, ngozi ya kahawia na ngozi nyeupe kiasi',
    '👩🏽‍❤‍💋‍👩🏽' => 'busu: mwanamke, mwanamke na ngozi ya kahawia',
    '👩🏽‍❤‍💋‍👩🏾' => 'busu: mwanamke, mwanamke, ngozi ya kahawia na ngozi nyeusi kiasi',
    '👩🏽‍❤‍💋‍👩🏿' => 'busu: mwanamke, mwanamke, ngozi ya kahawia na ngozi nyeusi',
    '👩🏾‍❤‍💋‍👩🏻' => 'busu: mwanamke, mwanamke, ngozi nyeusi kiasi na ngozi nyeupe',
    '👩🏾‍❤‍💋‍👩🏼' => 'busu: mwanamke, mwanamke, ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👩🏾‍❤‍💋‍👩🏽' => 'busu: mwanamke, mwanamke, ngozi nyeusi kiasi na ngozi ya kahawia',
    '👩🏾‍❤‍💋‍👩🏾' => 'busu: mwanamke, mwanamke na ngozi nyeusi kiasi',
    '👩🏾‍❤‍💋‍👩🏿' => 'busu: mwanamke, mwanamke, ngozi nyeusi kiasi na ngozi nyeusi',
    '👩🏿‍❤‍💋‍👩🏻' => 'busu: mwanamke, mwanamke, ngozi nyeusi na ngozi nyeupe',
    '👩🏿‍❤‍💋‍👩🏼' => 'busu: mwanamke, mwanamke, ngozi nyeusi na ngozi nyeupe kiasi',
    '👩🏿‍❤‍💋‍👩🏽' => 'busu: mwanamke, mwanamke, ngozi nyeusi na ngozi ya kahawia',
    '👩🏿‍❤‍💋‍👩🏾' => 'busu: mwanamke, mwanamke, ngozi nyeusi na ngozi nyeusi kiasi',
    '👩🏿‍❤‍💋‍👩🏿' => 'busu: mwanamke, mwanamke na ngozi nyeusi',
    '🧑🏻‍🫯‍🧑🏼' => 'wanandondi: ngozi nyeupe na ngozi nyeupe kiasi',
    '🧑🏻‍🫯‍🧑🏽' => 'wanandondi: ngozi nyeupe na ngozi ya kahawia',
    '🧑🏻‍🫯‍🧑🏾' => 'wanandondi: ngozi nyeupe na ngozi nyeusi kiasi',
    '🧑🏻‍🫯‍🧑🏿' => 'wanandondi: ngozi nyeupe na ngozi nyeusi',
    '🧑🏼‍🫯‍🧑🏻' => 'wanandondi: ngozi nyeupe kiasi na ngozi nyeupe',
    '🧑🏼‍🫯‍🧑🏽' => 'wanandondi: ngozi nyeupe kiasi na ngozi ya kahawia',
    '🧑🏼‍🫯‍🧑🏾' => 'wanandondi: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '🧑🏼‍🫯‍🧑🏿' => 'wanandondi: ngozi nyeupe kiasi na ngozi nyeusi',
    '🧑🏽‍🫯‍🧑🏻' => 'wanandondi: ngozi ya kahawia na ngozi nyeupe',
    '🧑🏽‍🫯‍🧑🏼' => 'wanandondi: ngozi ya kahawia na ngozi nyeupe kiasi',
    '🧑🏽‍🫯‍🧑🏾' => 'wanandondi: ngozi ya kahawia na ngozi nyeusi kiasi',
    '🧑🏽‍🫯‍🧑🏿' => 'wanandondi: ngozi ya kahawia na ngozi nyeusi',
    '🧑🏾‍🫯‍🧑🏻' => 'wanandondi: ngozi nyeusi kiasi na ngozi nyeupe',
    '🧑🏾‍🫯‍🧑🏼' => 'wanandondi: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '🧑🏾‍🫯‍🧑🏽' => 'wanandondi: ngozi nyeusi kiasi na ngozi ya kahawia',
    '🧑🏾‍🫯‍🧑🏿' => 'wanandondi: ngozi nyeusi kiasi na ngozi nyeusi',
    '🧑🏿‍🫯‍🧑🏻' => 'wanandondi: ngozi nyeusi na ngozi nyeupe',
    '🧑🏿‍🫯‍🧑🏼' => 'wanandondi: ngozi nyeusi na ngozi nyeupe kiasi',
    '🧑🏿‍🫯‍🧑🏽' => 'wanandondi: ngozi nyeusi na ngozi ya kahawia',
    '🧑🏿‍🫯‍🧑🏾' => 'wanandondi: ngozi nyeusi na ngozi nyeusi kiasi',
    '🧑🏻‍❤‍🧑🏼' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeupe na ngozi nyeupe kiasi',
    '🧑🏻‍❤‍🧑🏽' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeupe na ngozi ya kahawia',
    '🧑🏻‍❤‍🧑🏾' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeupe na ngozi nyeusi kiasi',
    '🧑🏻‍❤‍🧑🏿' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeupe na ngozi nyeusi',
    '🧑🏼‍❤‍🧑🏻' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeupe kiasi na ngozi nyeupe',
    '🧑🏼‍❤‍🧑🏽' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeupe kiasi na ngozi ya kahawia',
    '🧑🏼‍❤‍🧑🏾' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '🧑🏼‍❤‍🧑🏿' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeupe kiasi na ngozi nyeusi',
    '🧑🏽‍❤‍🧑🏻' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi ya kahawia na ngozi nyeupe',
    '🧑🏽‍❤‍🧑🏼' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi ya kahawia na ngozi nyeupe kiasi',
    '🧑🏽‍❤‍🧑🏾' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi ya kahawia na ngozi nyeusi kiasi',
    '🧑🏽‍❤‍🧑🏿' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi ya kahawia na ngozi nyeusi',
    '🧑🏾‍❤‍🧑🏻' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeusi kiasi na ngozi nyeupe',
    '🧑🏾‍❤‍🧑🏼' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '🧑🏾‍❤‍🧑🏽' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeusi kiasi na ngozi ya kahawia',
    '🧑🏾‍❤‍🧑🏿' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeusi kiasi na ngozi nyeusi',
    '🧑🏿‍❤‍🧑🏻' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeusi na ngozi nyeupe',
    '🧑🏿‍❤‍🧑🏼' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeusi na ngozi nyeupe kiasi',
    '🧑🏿‍❤‍🧑🏽' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeusi na ngozi ya kahawia',
    '🧑🏿‍❤‍🧑🏾' => 'mume na mke na ishara ya moyo: mtu mzima, mtu mzima, ngozi nyeusi na ngozi nyeusi kiasi',
    '🧑🏻‍🐰‍🧑🏼' => 'watu wanaosherehekea: ngozi nyeupe na ngozi nyeupe kiasi',
    '🧑🏻‍🐰‍🧑🏽' => 'watu wanaosherehekea: ngozi nyeupe na ngozi ya kahawia',
    '🧑🏻‍🐰‍🧑🏾' => 'watu wanaosherehekea: ngozi nyeupe na ngozi nyeusi kiasi',
    '🧑🏻‍🐰‍🧑🏿' => 'watu wanaosherehekea: ngozi nyeupe na ngozi nyeusi',
    '🧑🏼‍🐰‍🧑🏻' => 'watu wanaosherehekea: ngozi nyeupe kiasi na ngozi nyeupe',
    '🧑🏼‍🐰‍🧑🏽' => 'watu wanaosherehekea: ngozi nyeupe kiasi na ngozi ya kahawia',
    '🧑🏼‍🐰‍🧑🏾' => 'watu wanaosherehekea: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '🧑🏼‍🐰‍🧑🏿' => 'watu wanaosherehekea: ngozi nyeupe kiasi na ngozi nyeusi',
    '🧑🏽‍🐰‍🧑🏻' => 'watu wanaosherehekea: ngozi ya kahawia na ngozi nyeupe',
    '🧑🏽‍🐰‍🧑🏼' => 'watu wanaosherehekea: ngozi ya kahawia na ngozi nyeupe kiasi',
    '🧑🏽‍🐰‍🧑🏾' => 'watu wanaosherehekea: ngozi ya kahawia na ngozi nyeusi kiasi',
    '🧑🏽‍🐰‍🧑🏿' => 'watu wanaosherehekea: ngozi ya kahawia na ngozi nyeusi',
    '🧑🏾‍🐰‍🧑🏻' => 'watu wanaosherehekea: ngozi nyeusi kiasi na ngozi nyeupe',
    '🧑🏾‍🐰‍🧑🏼' => 'watu wanaosherehekea: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '🧑🏾‍🐰‍🧑🏽' => 'watu wanaosherehekea: ngozi nyeusi kiasi na ngozi ya kahawia',
    '🧑🏾‍🐰‍🧑🏿' => 'watu wanaosherehekea: ngozi nyeusi kiasi na ngozi nyeusi',
    '🧑🏿‍🐰‍🧑🏻' => 'watu wanaosherehekea: ngozi nyeusi na ngozi nyeupe',
    '🧑🏿‍🐰‍🧑🏼' => 'watu wanaosherehekea: ngozi nyeusi na ngozi nyeupe kiasi',
    '🧑🏿‍🐰‍🧑🏽' => 'watu wanaosherehekea: ngozi nyeusi na ngozi ya kahawia',
    '🧑🏿‍🐰‍🧑🏾' => 'watu wanaosherehekea: ngozi nyeusi na ngozi nyeusi kiasi',
    '👨🏻‍🫯‍👨🏼' => 'wanaume wanaomenyana miereka: ngozi nyeupe na ngozi nyeupe kiasi',
    '👨🏻‍🫯‍👨🏽' => 'wanaume wanaomenyana miereka: ngozi nyeupe na ngozi ya kahawia',
    '👨🏻‍🫯‍👨🏾' => 'wanaume wanaomenyana miereka: ngozi nyeupe na ngozi nyeusi kiasi',
    '👨🏻‍🫯‍👨🏿' => 'wanaume wanaomenyana miereka: ngozi nyeupe na ngozi nyeusi',
    '👨🏼‍🫯‍👨🏻' => 'wanaume wanaomenyana miereka: ngozi nyeupe kiasi na ngozi nyeupe',
    '👨🏼‍🫯‍👨🏽' => 'wanaume wanaomenyana miereka: ngozi nyeupe kiasi na ngozi ya kahawia',
    '👨🏼‍🫯‍👨🏾' => 'wanaume wanaomenyana miereka: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👨🏼‍🫯‍👨🏿' => 'wanaume wanaomenyana miereka: ngozi nyeupe kiasi na ngozi nyeusi',
    '👨🏽‍🫯‍👨🏻' => 'wanaume wanaomenyana miereka: ngozi ya kahawia na ngozi nyeupe',
    '👨🏽‍🫯‍👨🏼' => 'wanaume wanaomenyana miereka: ngozi ya kahawia na ngozi nyeupe kiasi',
    '👨🏽‍🫯‍👨🏾' => 'wanaume wanaomenyana miereka: ngozi ya kahawia na ngozi nyeusi kiasi',
    '👨🏽‍🫯‍👨🏿' => 'wanaume wanaomenyana miereka: ngozi ya kahawia na ngozi nyeusi',
    '👨🏾‍🫯‍👨🏻' => 'wanaume wanaomenyana miereka: ngozi nyeusi kiasi na ngozi nyeupe',
    '👨🏾‍🫯‍👨🏼' => 'wanaume wanaomenyana miereka: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👨🏾‍🫯‍👨🏽' => 'wanaume wanaomenyana miereka: ngozi nyeusi kiasi na ngozi ya kahawia',
    '👨🏾‍🫯‍👨🏿' => 'wanaume wanaomenyana miereka: ngozi nyeusi kiasi na ngozi nyeusi',
    '👨🏿‍🫯‍👨🏻' => 'wanaume wanaomenyana miereka: ngozi nyeusi na ngozi nyeupe',
    '👨🏿‍🫯‍👨🏼' => 'wanaume wanaomenyana miereka: ngozi nyeusi na ngozi nyeupe kiasi',
    '👨🏿‍🫯‍👨🏽' => 'wanaume wanaomenyana miereka: ngozi nyeusi na ngozi ya kahawia',
    '👨🏿‍🫯‍👨🏾' => 'wanaume wanaomenyana miereka: ngozi nyeusi na ngozi nyeusi kiasi',
    '👨🏻‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume na ngozi nyeupe',
    '👨🏻‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeupe na ngozi nyeupe kiasi',
    '👨🏻‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeupe na ngozi ya kahawia',
    '👨🏻‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeupe na ngozi nyeusi kiasi',
    '👨🏻‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeupe na ngozi nyeusi',
    '👨🏼‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeupe kiasi na ngozi nyeupe',
    '👨🏼‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume na ngozi nyeupe kiasi',
    '👨🏼‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeupe kiasi na ngozi ya kahawia',
    '👨🏼‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👨🏼‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeupe kiasi na ngozi nyeusi',
    '👨🏽‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi ya kahawia na ngozi nyeupe',
    '👨🏽‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi ya kahawia na ngozi nyeupe kiasi',
    '👨🏽‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume na ngozi ya kahawia',
    '👨🏽‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi ya kahawia na ngozi nyeusi kiasi',
    '👨🏽‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi ya kahawia na ngozi nyeusi',
    '👨🏾‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeusi kiasi na ngozi nyeupe',
    '👨🏾‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👨🏾‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeusi kiasi na ngozi ya kahawia',
    '👨🏾‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume na ngozi nyeusi kiasi',
    '👨🏾‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeusi kiasi na ngozi nyeusi',
    '👨🏿‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeusi na ngozi nyeupe',
    '👨🏿‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeusi na ngozi nyeupe kiasi',
    '👨🏿‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeusi na ngozi ya kahawia',
    '👨🏿‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume, ngozi nyeusi na ngozi nyeusi kiasi',
    '👨🏿‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamume, mwanamume na ngozi nyeusi',
    '👨🏻‍🐰‍👨🏼' => 'wanaume wanaosherehekea: ngozi nyeupe na ngozi nyeupe kiasi',
    '👨🏻‍🐰‍👨🏽' => 'wanaume wanaosherehekea: ngozi nyeupe na ngozi ya kahawia',
    '👨🏻‍🐰‍👨🏾' => 'wanaume wanaosherehekea: ngozi nyeupe na ngozi nyeusi kiasi',
    '👨🏻‍🐰‍👨🏿' => 'wanaume wanaosherehekea: ngozi nyeupe na ngozi nyeusi',
    '👨🏼‍🐰‍👨🏻' => 'wanaume wanaosherehekea: ngozi nyeupe kiasi na ngozi nyeupe',
    '👨🏼‍🐰‍👨🏽' => 'wanaume wanaosherehekea: ngozi nyeupe kiasi na ngozi ya kahawia',
    '👨🏼‍🐰‍👨🏾' => 'wanaume wanaosherehekea: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👨🏼‍🐰‍👨🏿' => 'wanaume wanaosherehekea: ngozi nyeupe kiasi na ngozi nyeusi',
    '👨🏽‍🐰‍👨🏻' => 'wanaume wanaosherehekea: ngozi ya kahawia na ngozi nyeupe',
    '👨🏽‍🐰‍👨🏼' => 'wanaume wanaosherehekea: ngozi ya kahawia na ngozi nyeupe kiasi',
    '👨🏽‍🐰‍👨🏾' => 'wanaume wanaosherehekea: ngozi ya kahawia na ngozi nyeusi kiasi',
    '👨🏽‍🐰‍👨🏿' => 'wanaume wanaosherehekea: ngozi ya kahawia na ngozi nyeusi',
    '👨🏾‍🐰‍👨🏻' => 'wanaume wanaosherehekea: ngozi nyeusi kiasi na ngozi nyeupe',
    '👨🏾‍🐰‍👨🏼' => 'wanaume wanaosherehekea: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👨🏾‍🐰‍👨🏽' => 'wanaume wanaosherehekea: ngozi nyeusi kiasi na ngozi ya kahawia',
    '👨🏾‍🐰‍👨🏿' => 'wanaume wanaosherehekea: ngozi nyeusi kiasi na ngozi nyeusi',
    '👨🏿‍🐰‍👨🏻' => 'wanaume wanaosherehekea: ngozi nyeusi na ngozi nyeupe',
    '👨🏿‍🐰‍👨🏼' => 'wanaume wanaosherehekea: ngozi nyeusi na ngozi nyeupe kiasi',
    '👨🏿‍🐰‍👨🏽' => 'wanaume wanaosherehekea: ngozi nyeusi na ngozi ya kahawia',
    '👨🏿‍🐰‍👨🏾' => 'wanaume wanaosherehekea: ngozi nyeusi na ngozi nyeusi kiasi',
    '👩🏻‍🫯‍👩🏼' => 'wanawake wanaomenyana miereka: ngozi nyeupe na ngozi nyeupe kiasi',
    '👩🏻‍🫯‍👩🏽' => 'wanawake wanaomenyana miereka: ngozi nyeupe na ngozi ya kahawia',
    '👩🏻‍🫯‍👩🏾' => 'wanawake wanaomenyana miereka: ngozi nyeupe na ngozi nyeusi kiasi',
    '👩🏻‍🫯‍👩🏿' => 'wanawake wanaomenyana miereka: ngozi nyeupe na ngozi nyeusi',
    '👩🏼‍🫯‍👩🏻' => 'wanawake wanaomenyana miereka: ngozi nyeupe kiasi na ngozi nyeupe',
    '👩🏼‍🫯‍👩🏽' => 'wanawake wanaomenyana miereka: ngozi nyeupe kiasi na ngozi ya kahawia',
    '👩🏼‍🫯‍👩🏾' => 'wanawake wanaomenyana miereka: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👩🏼‍🫯‍👩🏿' => 'wanawake wanaomenyana miereka: ngozi nyeupe kiasi na ngozi nyeusi',
    '👩🏽‍🫯‍👩🏻' => 'wanawake wanaomenyana miereka: ngozi ya kahawia na ngozi nyeupe',
    '👩🏽‍🫯‍👩🏼' => 'wanawake wanaomenyana miereka: ngozi ya kahawia na ngozi nyeupe kiasi',
    '👩🏽‍🫯‍👩🏾' => 'wanawake wanaomenyana miereka: ngozi ya kahawia na ngozi nyeusi kiasi',
    '👩🏽‍🫯‍👩🏿' => 'wanawake wanaomenyana miereka: ngozi ya kahawia na ngozi nyeusi',
    '👩🏾‍🫯‍👩🏻' => 'wanawake wanaomenyana miereka: ngozi nyeusi kiasi na ngozi nyeupe',
    '👩🏾‍🫯‍👩🏼' => 'wanawake wanaomenyana miereka: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👩🏾‍🫯‍👩🏽' => 'wanawake wanaomenyana miereka: ngozi nyeusi kiasi na ngozi ya kahawia',
    '👩🏾‍🫯‍👩🏿' => 'wanawake wanaomenyana miereka: ngozi nyeusi kiasi na ngozi nyeusi',
    '👩🏿‍🫯‍👩🏻' => 'wanawake wanaomenyana miereka: ngozi nyeusi na ngozi nyeupe',
    '👩🏿‍🫯‍👩🏼' => 'wanawake wanaomenyana miereka: ngozi nyeusi na ngozi nyeupe kiasi',
    '👩🏿‍🫯‍👩🏽' => 'wanawake wanaomenyana miereka: ngozi nyeusi na ngozi ya kahawia',
    '👩🏿‍🫯‍👩🏾' => 'wanawake wanaomenyana miereka: ngozi nyeusi na ngozi nyeusi kiasi',
    '👩🏻‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume na ngozi nyeupe',
    '👩🏻‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeupe na ngozi nyeupe kiasi',
    '👩🏻‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeupe na ngozi ya kahawia',
    '👩🏻‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeupe na ngozi nyeusi kiasi',
    '👩🏻‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeupe na ngozi nyeusi',
    '👩🏼‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeupe kiasi na ngozi nyeupe',
    '👩🏼‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume na ngozi nyeupe kiasi',
    '👩🏼‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeupe kiasi na ngozi ya kahawia',
    '👩🏼‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👩🏼‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeupe kiasi na ngozi nyeusi',
    '👩🏽‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi ya kahawia na ngozi nyeupe',
    '👩🏽‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi ya kahawia na ngozi nyeupe kiasi',
    '👩🏽‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume na ngozi ya kahawia',
    '👩🏽‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi ya kahawia na ngozi nyeusi kiasi',
    '👩🏽‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi ya kahawia na ngozi nyeusi',
    '👩🏾‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeusi kiasi na ngozi nyeupe',
    '👩🏾‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👩🏾‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeusi kiasi na ngozi ya kahawia',
    '👩🏾‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume na ngozi nyeusi kiasi',
    '👩🏾‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeusi kiasi na ngozi nyeusi',
    '👩🏿‍❤‍👨🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeusi na ngozi nyeupe',
    '👩🏿‍❤‍👨🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeusi na ngozi nyeupe kiasi',
    '👩🏿‍❤‍👨🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeusi na ngozi ya kahawia',
    '👩🏿‍❤‍👨🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume, ngozi nyeusi na ngozi nyeusi kiasi',
    '👩🏿‍❤‍👨🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamume na ngozi nyeusi',
    '👩🏻‍❤‍👩🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke na ngozi nyeupe',
    '👩🏻‍❤‍👩🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeupe na ngozi nyeupe kiasi',
    '👩🏻‍❤‍👩🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeupe na ngozi ya kahawia',
    '👩🏻‍❤‍👩🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeupe na ngozi nyeusi kiasi',
    '👩🏻‍❤‍👩🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeupe na ngozi nyeusi',
    '👩🏼‍❤‍👩🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeupe kiasi na ngozi nyeupe',
    '👩🏼‍❤‍👩🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke na ngozi nyeupe kiasi',
    '👩🏼‍❤‍👩🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeupe kiasi na ngozi ya kahawia',
    '👩🏼‍❤‍👩🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👩🏼‍❤‍👩🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeupe kiasi na ngozi nyeusi',
    '👩🏽‍❤‍👩🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi ya kahawia na ngozi nyeupe',
    '👩🏽‍❤‍👩🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi ya kahawia na ngozi nyeupe kiasi',
    '👩🏽‍❤‍👩🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke na ngozi ya kahawia',
    '👩🏽‍❤‍👩🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi ya kahawia na ngozi nyeusi kiasi',
    '👩🏽‍❤‍👩🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi ya kahawia na ngozi nyeusi',
    '👩🏾‍❤‍👩🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeusi kiasi na ngozi nyeupe',
    '👩🏾‍❤‍👩🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👩🏾‍❤‍👩🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeusi kiasi na ngozi ya kahawia',
    '👩🏾‍❤‍👩🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke na ngozi nyeusi kiasi',
    '👩🏾‍❤‍👩🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeusi kiasi na ngozi nyeusi',
    '👩🏿‍❤‍👩🏻' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeusi na ngozi nyeupe',
    '👩🏿‍❤‍👩🏼' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeusi na ngozi nyeupe kiasi',
    '👩🏿‍❤‍👩🏽' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeusi na ngozi ya kahawia',
    '👩🏿‍❤‍👩🏾' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke, ngozi nyeusi na ngozi nyeusi kiasi',
    '👩🏿‍❤‍👩🏿' => 'mume na mke na ishara ya moyo: mwanamke, mwanamke na ngozi nyeusi',
    '👩🏻‍🐰‍👩🏼' => 'wanawake wanaosherehekea: ngozi nyeupe na ngozi nyeupe kiasi',
    '👩🏻‍🐰‍👩🏽' => 'wanawake wanaosherehekea: ngozi nyeupe na ngozi ya kahawia',
    '👩🏻‍🐰‍👩🏾' => 'wanawake wanaosherehekea: ngozi nyeupe na ngozi nyeusi kiasi',
    '👩🏻‍🐰‍👩🏿' => 'wanawake wanaosherehekea: ngozi nyeupe na ngozi nyeusi',
    '👩🏼‍🐰‍👩🏻' => 'wanawake wanaosherehekea: ngozi nyeupe kiasi na ngozi nyeupe',
    '👩🏼‍🐰‍👩🏽' => 'wanawake wanaosherehekea: ngozi nyeupe kiasi na ngozi ya kahawia',
    '👩🏼‍🐰‍👩🏾' => 'wanawake wanaosherehekea: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👩🏼‍🐰‍👩🏿' => 'wanawake wanaosherehekea: ngozi nyeupe kiasi na ngozi nyeusi',
    '👩🏽‍🐰‍👩🏻' => 'wanawake wanaosherehekea: ngozi ya kahawia na ngozi nyeupe',
    '👩🏽‍🐰‍👩🏼' => 'wanawake wanaosherehekea: ngozi ya kahawia na ngozi nyeupe kiasi',
    '👩🏽‍🐰‍👩🏾' => 'wanawake wanaosherehekea: ngozi ya kahawia na ngozi nyeusi kiasi',
    '👩🏽‍🐰‍👩🏿' => 'wanawake wanaosherehekea: ngozi ya kahawia na ngozi nyeusi',
    '👩🏾‍🐰‍👩🏻' => 'wanawake wanaosherehekea: ngozi nyeusi kiasi na ngozi nyeupe',
    '👩🏾‍🐰‍👩🏼' => 'wanawake wanaosherehekea: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👩🏾‍🐰‍👩🏽' => 'wanawake wanaosherehekea: ngozi nyeusi kiasi na ngozi ya kahawia',
    '👩🏾‍🐰‍👩🏿' => 'wanawake wanaosherehekea: ngozi nyeusi kiasi na ngozi nyeusi',
    '👩🏿‍🐰‍👩🏻' => 'wanawake wanaosherehekea: ngozi nyeusi na ngozi nyeupe',
    '👩🏿‍🐰‍👩🏼' => 'wanawake wanaosherehekea: ngozi nyeusi na ngozi nyeupe kiasi',
    '👩🏿‍🐰‍👩🏽' => 'wanawake wanaosherehekea: ngozi nyeusi na ngozi ya kahawia',
    '👩🏿‍🐰‍👩🏾' => 'wanawake wanaosherehekea: ngozi nyeusi na ngozi nyeusi kiasi',
    '🧑🏻‍🤝‍🧑🏻' => 'watu walioshikana mikono: ngozi nyeupe',
    '🧑🏻‍🤝‍🧑🏼' => 'watu walioshikana mikono: ngozi nyeupe na ngozi nyeupe kiasi',
    '🧑🏻‍🤝‍🧑🏽' => 'watu walioshikana mikono: ngozi nyeupe na ngozi ya kahawia',
    '🧑🏻‍🤝‍🧑🏾' => 'watu walioshikana mikono: ngozi nyeupe na ngozi nyeusi kiasi',
    '🧑🏻‍🤝‍🧑🏿' => 'watu walioshikana mikono: ngozi nyeupe na ngozi nyeusi',
    '🧑🏼‍🤝‍🧑🏻' => 'watu walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeupe',
    '🧑🏼‍🤝‍🧑🏼' => 'watu walioshikana mikono: ngozi nyeupe kiasi',
    '🧑🏼‍🤝‍🧑🏽' => 'watu walioshikana mikono: ngozi nyeupe kiasi na ngozi ya kahawia',
    '🧑🏼‍🤝‍🧑🏾' => 'watu walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '🧑🏼‍🤝‍🧑🏿' => 'watu walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeusi',
    '🧑🏽‍🤝‍🧑🏻' => 'watu walioshikana mikono: ngozi ya kahawia na ngozi nyeupe',
    '🧑🏽‍🤝‍🧑🏼' => 'watu walioshikana mikono: ngozi ya kahawia na ngozi nyeupe kiasi',
    '🧑🏽‍🤝‍🧑🏽' => 'watu walioshikana mikono: ngozi ya kahawia',
    '🧑🏽‍🤝‍🧑🏾' => 'watu walioshikana mikono: ngozi ya kahawia na ngozi nyeusi kiasi',
    '🧑🏽‍🤝‍🧑🏿' => 'watu walioshikana mikono: ngozi ya kahawia na ngozi nyeusi',
    '🧑🏾‍🤝‍🧑🏻' => 'watu walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeupe',
    '🧑🏾‍🤝‍🧑🏼' => 'watu walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '🧑🏾‍🤝‍🧑🏽' => 'watu walioshikana mikono: ngozi nyeusi kiasi na ngozi ya kahawia',
    '🧑🏾‍🤝‍🧑🏾' => 'watu walioshikana mikono: ngozi nyeusi kiasi',
    '🧑🏾‍🤝‍🧑🏿' => 'watu walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeusi',
    '🧑🏿‍🤝‍🧑🏻' => 'watu walioshikana mikono: ngozi nyeusi na ngozi nyeupe',
    '🧑🏿‍🤝‍🧑🏼' => 'watu walioshikana mikono: ngozi nyeusi na ngozi nyeupe kiasi',
    '🧑🏿‍🤝‍🧑🏽' => 'watu walioshikana mikono: ngozi nyeusi na ngozi ya kahawia',
    '🧑🏿‍🤝‍🧑🏾' => 'watu walioshikana mikono: ngozi nyeusi na ngozi nyeusi kiasi',
    '🧑🏿‍🤝‍🧑🏿' => 'watu walioshikana mikono: ngozi nyeusi',
    '👩🏻‍🤝‍👩🏼' => 'wanawake walioshikana mikono: ngozi nyeupe na ngozi nyeupe kiasi',
    '👩🏻‍🤝‍👩🏽' => 'wanawake walioshikana mikono: ngozi nyeupe na ngozi ya kahawia',
    '👩🏻‍🤝‍👩🏾' => 'wanawake walioshikana mikono: ngozi nyeupe na ngozi nyeusi kiasi',
    '👩🏻‍🤝‍👩🏿' => 'wanawake walioshikana mikono: ngozi nyeupe na ngozi nyeusi',
    '👩🏼‍🤝‍👩🏻' => 'wanawake walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeupe',
    '👩🏼‍🤝‍👩🏽' => 'wanawake walioshikana mikono: ngozi nyeupe kiasi na ngozi ya kahawia',
    '👩🏼‍🤝‍👩🏾' => 'wanawake walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👩🏼‍🤝‍👩🏿' => 'wanawake walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeusi',
    '👩🏽‍🤝‍👩🏻' => 'wanawake walioshikana mikono: ngozi ya kahawia na ngozi nyeupe',
    '👩🏽‍🤝‍👩🏼' => 'wanawake walioshikana mikono: ngozi ya kahawia na ngozi nyeupe kiasi',
    '👩🏽‍🤝‍👩🏾' => 'wanawake walioshikana mikono: ngozi ya kahawia na ngozi nyeusi kiasi',
    '👩🏽‍🤝‍👩🏿' => 'wanawake walioshikana mikono: ngozi ya kahawia na ngozi nyeusi',
    '👩🏾‍🤝‍👩🏻' => 'wanawake walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeupe',
    '👩🏾‍🤝‍👩🏼' => 'wanawake walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👩🏾‍🤝‍👩🏽' => 'wanawake walioshikana mikono: ngozi nyeusi kiasi na ngozi ya kahawia',
    '👩🏾‍🤝‍👩🏿' => 'wanawake walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeusi',
    '👩🏿‍🤝‍👩🏻' => 'wanawake walioshikana mikono: ngozi nyeusi na ngozi nyeupe',
    '👩🏿‍🤝‍👩🏼' => 'wanawake walioshikana mikono: ngozi nyeusi na ngozi nyeupe kiasi',
    '👩🏿‍🤝‍👩🏽' => 'wanawake walioshikana mikono: ngozi nyeusi na ngozi ya kahawia',
    '👩🏿‍🤝‍👩🏾' => 'wanawake walioshikana mikono: ngozi nyeusi na ngozi nyeusi kiasi',
    '👩🏻‍🤝‍👨🏼' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe na ngozi nyeupe kiasi',
    '👩🏻‍🤝‍👨🏽' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe na ngozi ya kahawia',
    '👩🏻‍🤝‍👨🏾' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe na ngozi nyeusi kiasi',
    '👩🏻‍🤝‍👨🏿' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe na ngozi nyeusi',
    '👩🏼‍🤝‍👨🏻' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeupe',
    '👩🏼‍🤝‍👨🏽' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe kiasi na ngozi ya kahawia',
    '👩🏼‍🤝‍👨🏾' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👩🏼‍🤝‍👨🏿' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeusi',
    '👩🏽‍🤝‍👨🏻' => 'mwanamke na mwanamume walioshikana mikono: ngozi ya kahawia na ngozi nyeupe',
    '👩🏽‍🤝‍👨🏼' => 'mwanamke na mwanamume walioshikana mikono: ngozi ya kahawia na ngozi nyeupe kiasi',
    '👩🏽‍🤝‍👨🏾' => 'mwanamke na mwanamume walioshikana mikono: ngozi ya kahawia na ngozi nyeusi kiasi',
    '👩🏽‍🤝‍👨🏿' => 'mwanamke na mwanamume walioshikana mikono: ngozi ya kahawia na ngozi nyeusi',
    '👩🏾‍🤝‍👨🏻' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeupe',
    '👩🏾‍🤝‍👨🏼' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👩🏾‍🤝‍👨🏽' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi kiasi na ngozi ya kahawia',
    '👩🏾‍🤝‍👨🏿' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeusi',
    '👩🏿‍🤝‍👨🏻' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi na ngozi nyeupe',
    '👩🏿‍🤝‍👨🏼' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi na ngozi nyeupe kiasi',
    '👩🏿‍🤝‍👨🏽' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi na ngozi ya kahawia',
    '👩🏿‍🤝‍👨🏾' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi na ngozi nyeusi kiasi',
    '👨🏻‍🤝‍👨🏼' => 'wanaume walioshikana mikono: ngozi nyeupe na ngozi nyeupe kiasi',
    '👨🏻‍🤝‍👨🏽' => 'wanaume walioshikana mikono: ngozi nyeupe na ngozi ya kahawia',
    '👨🏻‍🤝‍👨🏾' => 'wanaume walioshikana mikono: ngozi nyeupe na ngozi nyeusi kiasi',
    '👨🏻‍🤝‍👨🏿' => 'wanaume walioshikana mikono: ngozi nyeupe na ngozi nyeusi',
    '👨🏼‍🤝‍👨🏻' => 'wanaume walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeupe',
    '👨🏼‍🤝‍👨🏽' => 'wanaume walioshikana mikono: ngozi nyeupe kiasi na ngozi ya kahawia',
    '👨🏼‍🤝‍👨🏾' => 'wanaume walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '👨🏼‍🤝‍👨🏿' => 'wanaume walioshikana mikono: ngozi nyeupe kiasi na ngozi nyeusi',
    '👨🏽‍🤝‍👨🏻' => 'wanaume walioshikana mikono: ngozi ya kahawia na ngozi nyeupe',
    '👨🏽‍🤝‍👨🏼' => 'wanaume walioshikana mikono: ngozi ya kahawia na ngozi nyeupe kiasi',
    '👨🏽‍🤝‍👨🏾' => 'wanaume walioshikana mikono: ngozi ya kahawia na ngozi nyeusi kiasi',
    '👨🏽‍🤝‍👨🏿' => 'wanaume walioshikana mikono: ngozi ya kahawia na ngozi nyeusi',
    '👨🏾‍🤝‍👨🏻' => 'wanaume walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeupe',
    '👨🏾‍🤝‍👨🏼' => 'wanaume walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '👨🏾‍🤝‍👨🏽' => 'wanaume walioshikana mikono: ngozi nyeusi kiasi na ngozi ya kahawia',
    '👨🏾‍🤝‍👨🏿' => 'wanaume walioshikana mikono: ngozi nyeusi kiasi na ngozi nyeusi',
    '👨🏿‍🤝‍👨🏻' => 'wanaume walioshikana mikono: ngozi nyeusi na ngozi nyeupe',
    '👨🏿‍🤝‍👨🏼' => 'wanaume walioshikana mikono: ngozi nyeusi na ngozi nyeupe kiasi',
    '👨🏿‍🤝‍👨🏽' => 'wanaume walioshikana mikono: ngozi nyeusi na ngozi ya kahawia',
    '👨🏿‍🤝‍👨🏾' => 'wanaume walioshikana mikono: ngozi nyeusi na ngozi nyeusi kiasi',
    '👩‍❤‍💋‍👨' => 'busu: mwanamke na mwanamume',
    '👨‍❤‍💋‍👨' => 'busu: mwanamume na mwanamume',
    '👩‍❤‍💋‍👩' => 'busu: mwanamke na mwanamke',
    '👨‍👩‍👧‍👦' => 'familia: mwanamume, mwanamke, msichana na mvulana',
    '👨‍👩‍👦‍👦' => 'familia: mwanamume, mwanamke, mvulana na mvulana',
    '👨‍👩‍👧‍👧' => 'familia: mwanamume, mwanamke, msichana na msichana',
    '👨‍👨‍👧‍👦' => 'familia: mwanamume, mwanamume, msichana na mvulana',
    '👨‍👨‍👦‍👦' => 'familia: mwanamume, mwanamume, mvulana na mvulana',
    '👨‍👨‍👧‍👧' => 'familia: mwanamume, mwanamume, msichana na msichana',
    '👩‍👩‍👧‍👦' => 'familia: mwanamke, mwanamke, msichana na mvulana',
    '👩‍👩‍👦‍👦' => 'familia: mwanamke, mwanamke, mvulana na mvulana',
    '👩‍👩‍👧‍👧' => 'familia: mwanamke, mwanamke, msichana na msichana',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'bendera: Uingereza',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'bendera: Uskoti',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'bendera: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'familia: mtu mzima, mtu mzima, mtoto, mtoto',
    '🚶🏻‍♀‍➡' => 'mwanamke anayetembea: ngozi nyeupe na inayoangalia kulia',
    '🚶🏼‍♀‍➡' => 'mwanamke anayetembea: ngozi nyeupe kiasi na inayoangalia kulia',
    '🚶🏽‍♀‍➡' => 'mwanamke anayetembea: ngozi ya kahawia na inayoangalia kulia',
    '🚶🏾‍♀‍➡' => 'mwanamke anayetembea: ngozi nyeusi kiasi na inayoangalia kulia',
    '🚶🏿‍♀‍➡' => 'mwanamke anayetembea: ngozi nyeusi na inayoangalia kulia',
    '🚶🏻‍♂‍➡' => 'mwanamume anayetembea: ngozi nyeupe na inayoangalia kulia',
    '🚶🏼‍♂‍➡' => 'mwanamume anayetembea: ngozi nyeupe kiasi na inayoangalia kulia',
    '🚶🏽‍♂‍➡' => 'mwanamume anayetembea: ngozi ya kahawia na inayoangalia kulia',
    '🚶🏾‍♂‍➡' => 'mwanamume anayetembea: ngozi nyeusi kiasi na inayoangalia kulia',
    '🚶🏿‍♂‍➡' => 'mwanamume anayetembea: ngozi nyeusi na inayoangalia kulia',
    '🧎🏻‍♀‍➡' => 'mwanamke aliyepiga magoti: ngozi nyeupe na inayoangalia kulia',
    '🧎🏼‍♀‍➡' => 'mwanamke aliyepiga magoti: ngozi nyeupe kiasi na inayoangalia kulia',
    '🧎🏽‍♀‍➡' => 'mwanamke aliyepiga magoti: ngozi ya kahawia na inayoangalia kulia',
    '🧎🏾‍♀‍➡' => 'mwanamke aliyepiga magoti: ngozi nyeusi kiasi na inayoangalia kulia',
    '🧎🏿‍♀‍➡' => 'mwanamke aliyepiga magoti: ngozi nyeusi na inayoangalia kulia',
    '🧎🏻‍♂‍➡' => 'mwanamume aliyepiga magoti: ngozi nyeupe na inayoangalia kulia',
    '🧎🏼‍♂‍➡' => 'mwanamume aliyepiga magoti: ngozi nyeupe kiasi na inayoangalia kulia',
    '🧎🏽‍♂‍➡' => 'mwanamume aliyepiga magoti: ngozi ya kahawia na inayoangalia kulia',
    '🧎🏾‍♂‍➡' => 'mwanamume aliyepiga magoti: ngozi nyeusi kiasi na inayoangalia kulia',
    '🧎🏿‍♂‍➡' => 'mwanamume aliyepiga magoti: ngozi nyeusi na inayoangalia kulia',
    '🧑🏻‍🦯‍➡' => 'mtu anayetembea kwa mkongojo: ngozi nyeupe na inayoangalia kulia',
    '🧑🏼‍🦯‍➡' => 'mtu anayetembea kwa mkongojo: ngozi nyeupe kiasi na inayoangalia kulia',
    '🧑🏽‍🦯‍➡' => 'mtu anayetembea kwa mkongojo: ngozi ya kahawia na inayoangalia kulia',
    '🧑🏾‍🦯‍➡' => 'mtu anayetembea kwa mkongojo: ngozi nyeusi kiasi na inayoangalia kulia',
    '🧑🏿‍🦯‍➡' => 'mtu anayetembea kwa mkongojo: ngozi nyeusi na inayoangalia kulia',
    '👨🏻‍🦯‍➡' => 'mwanamume anayetembea kwa mkongojo: ngozi nyeupe na inayoangalia kulia',
    '👨🏼‍🦯‍➡' => 'mwanamume anayetembea kwa mkongojo: ngozi nyeupe kiasi na inayoangalia kulia',
    '👨🏽‍🦯‍➡' => 'mwanamume anayetembea kwa mkongojo: ngozi ya kahawia na inayoangalia kulia',
    '👨🏾‍🦯‍➡' => 'mwanamume anayetembea kwa mkongojo: ngozi nyeusi kiasi na inayoangalia kulia',
    '👨🏿‍🦯‍➡' => 'mwanamume anayetembea kwa mkongojo: ngozi nyeusi na inayoangalia kulia',
    '👩🏻‍🦯‍➡' => 'mwanamke anayetembea kwa mkongojo: ngozi nyeupe na inayoangalia kulia',
    '👩🏼‍🦯‍➡' => 'mwanamke anayetembea kwa mkongojo: ngozi nyeupe kiasi na inayoangalia kulia',
    '👩🏽‍🦯‍➡' => 'mwanamke anayetembea kwa mkongojo: ngozi ya kahawia na inayoangalia kulia',
    '👩🏾‍🦯‍➡' => 'mwanamke anayetembea kwa mkongojo: ngozi nyeusi kiasi na inayoangalia kulia',
    '👩🏿‍🦯‍➡' => 'mwanamke anayetembea kwa mkongojo: ngozi nyeusi na inayoangalia kulia',
    '🧑🏻‍🦼‍➡' => 'mtu aliyeketia kiti cha magurudumu: ngozi nyeupe na inayoangalia kulia',
    '🧑🏼‍🦼‍➡' => 'mtu aliyeketia kiti cha magurudumu: ngozi nyeupe kiasi na inayoangalia kulia',
    '🧑🏽‍🦼‍➡' => 'mtu aliyeketia kiti cha magurudumu: ngozi ya kahawia na inayoangalia kulia',
    '🧑🏾‍🦼‍➡' => 'mtu aliyeketia kiti cha magurudumu: ngozi nyeusi kiasi na inayoangalia kulia',
    '🧑🏿‍🦼‍➡' => 'mtu aliyeketia kiti cha magurudumu: ngozi nyeusi na inayoangalia kulia',
    '👨🏻‍🦼‍➡' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi nyeupe na inayoangalia kulia',
    '👨🏼‍🦼‍➡' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi nyeupe kiasi na inayoangalia kulia',
    '👨🏽‍🦼‍➡' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi ya kahawia na inayoangalia kulia',
    '👨🏾‍🦼‍➡' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi nyeusi kiasi na inayoangalia kulia',
    '👨🏿‍🦼‍➡' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi nyeusi na inayoangalia kulia',
    '👩🏻‍🦼‍➡' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi nyeupe na inayoangalia kulia',
    '👩🏼‍🦼‍➡' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi nyeupe kiasi na inayoangalia kulia',
    '👩🏽‍🦼‍➡' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi ya kahawia na inayoangalia kulia',
    '👩🏾‍🦼‍➡' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi nyeusi kiasi na inayoangalia kulia',
    '👩🏿‍🦼‍➡' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi nyeusi na inayoangalia kulia',
    '🧑🏻‍🦽‍➡' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe na inayoangalia kulia',
    '🧑🏼‍🦽‍➡' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe kiasi na inayoangalia kulia',
    '🧑🏽‍🦽‍➡' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi ya kahawia na inayoangalia kulia',
    '🧑🏾‍🦽‍➡' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi kiasi na inayoangalia kulia',
    '🧑🏿‍🦽‍➡' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi na inayoangalia kulia',
    '👨🏻‍🦽‍➡' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe na inayoangalia kulia',
    '👨🏼‍🦽‍➡' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe kiasi na inayoangalia kulia',
    '👨🏽‍🦽‍➡' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi ya kahawia na inayoangalia kulia',
    '👨🏾‍🦽‍➡' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi kiasi na inayoangalia kulia',
    '👨🏿‍🦽‍➡' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi na inayoangalia kulia',
    '👩🏻‍🦽‍➡' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe na inayoangalia kulia',
    '👩🏼‍🦽‍➡' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe kiasi na inayoangalia kulia',
    '👩🏽‍🦽‍➡' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi ya kahawia na inayoangalia kulia',
    '👩🏾‍🦽‍➡' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi kiasi na inayoangalia kulia',
    '👩🏿‍🦽‍➡' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi na inayoangalia kulia',
    '🏃🏻‍♀‍➡' => 'mwanamke anayekimbia: ngozi nyeupe na inayoangalia kulia',
    '🏃🏼‍♀‍➡' => 'mwanamke anayekimbia: ngozi nyeupe kiasi na inayoangalia kulia',
    '🏃🏽‍♀‍➡' => 'mwanamke anayekimbia: ngozi ya kahawia na inayoangalia kulia',
    '🏃🏾‍♀‍➡' => 'mwanamke anayekimbia: ngozi nyeusi kiasi na inayoangalia kulia',
    '🏃🏿‍♀‍➡' => 'mwanamke anayekimbia: ngozi nyeusi na inayoangalia kulia',
    '🏃🏻‍♂‍➡' => 'mwanamume anayekimbia: ngozi nyeupe na inayoangalia kulia',
    '🏃🏼‍♂‍➡' => 'mwanamume anayekimbia: ngozi nyeupe kiasi na inayoangalia kulia',
    '🏃🏽‍♂‍➡' => 'mwanamume anayekimbia: ngozi ya kahawia na inayoangalia kulia',
    '🏃🏾‍♂‍➡' => 'mwanamume anayekimbia: ngozi nyeusi kiasi na inayoangalia kulia',
    '🏃🏿‍♂‍➡' => 'mwanamume anayekimbia: ngozi nyeusi na inayoangalia kulia',
    '🫱🏻‍🫲🏼' => 'kusalimiana: ngozi nyeupe na ngozi nyeupe kiasi',
    '🫱🏻‍🫲🏽' => 'kusalimiana: ngozi nyeupe na ngozi ya kahawia',
    '🫱🏻‍🫲🏾' => 'kusalimiana: ngozi nyeupe na ngozi nyeusi kiasi',
    '🫱🏻‍🫲🏿' => 'kusalimiana: ngozi nyeupe na ngozi nyeusi',
    '🫱🏼‍🫲🏻' => 'kusalimiana: ngozi nyeupe kiasi na ngozi nyeupe',
    '🫱🏼‍🫲🏽' => 'kusalimiana: ngozi nyeupe kiasi na ngozi ya kahawia',
    '🫱🏼‍🫲🏾' => 'kusalimiana: ngozi nyeupe kiasi na ngozi nyeusi kiasi',
    '🫱🏼‍🫲🏿' => 'kusalimiana: ngozi nyeupe kiasi na ngozi nyeusi',
    '🫱🏽‍🫲🏻' => 'kusalimiana: ngozi ya kahawia na ngozi nyeupe',
    '🫱🏽‍🫲🏼' => 'kusalimiana: ngozi ya kahawia na ngozi nyeupe kiasi',
    '🫱🏽‍🫲🏾' => 'kusalimiana: ngozi ya kahawia na ngozi nyeusi kiasi',
    '🫱🏽‍🫲🏿' => 'kusalimiana: ngozi ya kahawia na ngozi nyeusi',
    '🫱🏾‍🫲🏻' => 'kusalimiana: ngozi nyeusi kiasi na ngozi nyeupe',
    '🫱🏾‍🫲🏼' => 'kusalimiana: ngozi nyeusi kiasi na ngozi nyeupe kiasi',
    '🫱🏾‍🫲🏽' => 'kusalimiana: ngozi nyeusi kiasi na ngozi ya kahawia',
    '🫱🏾‍🫲🏿' => 'kusalimiana: ngozi nyeusi kiasi na ngozi nyeusi',
    '🫱🏿‍🫲🏻' => 'kusalimiana: ngozi nyeusi na ngozi nyeupe',
    '🫱🏿‍🫲🏼' => 'kusalimiana: ngozi nyeusi na ngozi nyeupe kiasi',
    '🫱🏿‍🫲🏽' => 'kusalimiana: ngozi nyeusi na ngozi ya kahawia',
    '🫱🏿‍🫲🏾' => 'kusalimiana: ngozi nyeusi na ngozi nyeusi kiasi',
    '🚶‍♀‍➡' => 'mwanamke anayetembea: inayoangalia kulia',
    '🚶‍♂‍➡' => 'mwanamume anayetembea: inayoangalia kulia',
    '🧎‍♀‍➡' => 'mwanamke aliyepiga magoti: inayoangalia kulia',
    '🧎‍♂‍➡' => 'mwanamume aliyepiga magoti: inayoangalia kulia',
    '🧑‍🦯‍➡' => 'mtu anayetembea kwa mkongojo: inayoangalia kulia',
    '👨‍🦯‍➡' => 'mwanamume anayetembea kwa mkongojo: inayoangalia kulia',
    '👩‍🦯‍➡' => 'mwanamke anayetembea kwa mkongojo: inayoangalia kulia',
    '🧑‍🦼‍➡' => 'mtu aliyeketia kiti cha magurudumu: inayoangalia kulia',
    '👨‍🦼‍➡' => 'Mtu aliyeketi kwenye kiti cha magurudumu: inayoangalia kulia',
    '👩‍🦼‍➡' => 'mwanamke aliyeketia kiti cha magurudumu: inayoangalia kulia',
    '🧑‍🦽‍➡' => 'mtu anayejiendesha kwa kiti cha magurudumu: inayoangalia kulia',
    '👨‍🦽‍➡' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: inayoangalia kulia',
    '👩‍🦽‍➡' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: inayoangalia kulia',
    '🏃‍♀‍➡' => 'mwanamke anayekimbia: inayoangalia kulia',
    '🏃‍♂‍➡' => 'mwanamume anayekimbia: inayoangalia kulia',
    '👩‍❤‍👨' => 'mume na mke na ishara ya moyo: mwanamke na mwanamume',
    '👨‍❤‍👨' => 'mume na mke na ishara ya moyo: mwanamume na mwanamume',
    '👩‍❤‍👩' => 'mume na mke na ishara ya moyo: mwanamke na mwanamke',
    '👨‍👩‍👦' => 'familia: mwanamume, mwanamke na mvulana',
    '👨‍👩‍👧' => 'familia: mwanamume, mwanamke na msichana',
    '👨‍👨‍👦' => 'familia: mwanamume, mwanamume na mvulana',
    '👨‍👨‍👧' => 'familia: mwanamume, mwanamume na msichana',
    '👩‍👩‍👦' => 'familia: mwanamke, mwanamke na mvulana',
    '👩‍👩‍👧' => 'familia: mwanamke, mwanamke na msichana',
    '👨‍👦‍👦' => 'familia: mwanamume, mvulana na mvulana',
    '👨‍👧‍👦' => 'familia: mwanamume, msichana na mvulana',
    '👨‍👧‍👧' => 'familia: mwanamume, msichana na msichana',
    '👩‍👦‍👦' => 'familia: mwanamke, mvulana na mvulana',
    '👩‍👧‍👦' => 'familia: mwanamke, msichana na mvulana',
    '👩‍👧‍👧' => 'familia: mwanamke, msichana na msichana',
    '🧑‍🤝‍🧑' => 'watu walioshikana mikono',
    '🧑‍🧑‍🧒' => 'familia: mtu mzima, mtu mzima, mtoto',
    '🧑‍🧒‍🧒' => 'familia: mtu mzima, mtoto, mtoto',
    '🧑🏻‍🦰' => 'mtu mzima: ngozi nyeupe na nywele nyekundu',
    '🧑🏼‍🦰' => 'mtu mzima: ngozi nyeupe kiasi na nywele nyekundu',
    '🧑🏽‍🦰' => 'mtu mzima: ngozi ya kahawia na nywele nyekundu',
    '🧑🏾‍🦰' => 'mtu mzima: ngozi nyeusi kiasi na nywele nyekundu',
    '🧑🏿‍🦰' => 'mtu mzima: ngozi nyeusi na nywele nyekundu',
    '🧑🏻‍🦱' => 'mtu mzima: ngozi nyeupe na nywele yenye mawimbi',
    '🧑🏼‍🦱' => 'mtu mzima: ngozi nyeupe kiasi na nywele yenye mawimbi',
    '🧑🏽‍🦱' => 'mtu mzima: ngozi ya kahawia na nywele yenye mawimbi',
    '🧑🏾‍🦱' => 'mtu mzima: ngozi nyeusi kiasi na nywele yenye mawimbi',
    '🧑🏿‍🦱' => 'mtu mzima: ngozi nyeusi na nywele yenye mawimbi',
    '🧑🏻‍🦳' => 'mtu mzima: ngozi nyeupe na nywele nyeupe',
    '🧑🏼‍🦳' => 'mtu mzima: ngozi nyeupe kiasi na nywele nyeupe',
    '🧑🏽‍🦳' => 'mtu mzima: ngozi ya kahawia na nywele nyeupe',
    '🧑🏾‍🦳' => 'mtu mzima: ngozi nyeusi kiasi na nywele nyeupe',
    '🧑🏿‍🦳' => 'mtu mzima: ngozi nyeusi na nywele nyeupe',
    '🧑🏻‍🦲' => 'mtu mzima: ngozi nyeupe na upara',
    '🧑🏼‍🦲' => 'mtu mzima: ngozi nyeupe kiasi na upara',
    '🧑🏽‍🦲' => 'mtu mzima: ngozi ya kahawia na upara',
    '🧑🏾‍🦲' => 'mtu mzima: ngozi nyeusi kiasi na upara',
    '🧑🏿‍🦲' => 'mtu mzima: ngozi nyeusi na upara',
    '🧑🏻‍🩰' => 'mcheza bale: ngozi nyeupe',
    '🧑🏼‍🩰' => 'mcheza bale: ngozi nyeupe kiasi',
    '🧑🏽‍🩰' => 'mcheza bale: ngozi ya kahawia',
    '🧑🏾‍🩰' => 'mcheza bale: ngozi nyeusi kiasi',
    '🧑🏿‍🩰' => 'mcheza bale: ngozi nyeusi',
    '🧔🏻‍♂' => 'mwanamume: ngozi nyeupe na ndevu',
    '🧔🏼‍♂' => 'mwanamume: ngozi nyeupe kiasi na ndevu',
    '🧔🏽‍♂' => 'mwanamume: ngozi ya kahawia na ndevu',
    '🧔🏾‍♂' => 'mwanamume: ngozi nyeusi kiasi na ndevu',
    '🧔🏿‍♂' => 'mwanamume: ngozi nyeusi na ndevu',
    '👱🏻‍♂' => 'mwanamume mwenye nywele ya kimanjano: ngozi nyeupe',
    '👱🏼‍♂' => 'mwanamume mwenye nywele ya kimanjano: ngozi nyeupe kiasi',
    '👱🏽‍♂' => 'mwanamume mwenye nywele ya kimanjano: ngozi ya kahawia',
    '👱🏾‍♂' => 'mwanamume mwenye nywele ya kimanjano: ngozi nyeusi kiasi',
    '👱🏿‍♂' => 'mwanamume mwenye nywele ya kimanjano: ngozi nyeusi',
    '👨🏻‍🦰' => 'mwanamume: ngozi nyeupe na nywele nyekundu',
    '👨🏼‍🦰' => 'mwanamume: ngozi nyeupe kiasi na nywele nyekundu',
    '👨🏽‍🦰' => 'mwanamume: ngozi ya kahawia na nywele nyekundu',
    '👨🏾‍🦰' => 'mwanamume: ngozi nyeusi kiasi na nywele nyekundu',
    '👨🏿‍🦰' => 'mwanamume: ngozi nyeusi na nywele nyekundu',
    '👨🏻‍🦱' => 'mwanamume: ngozi nyeupe na nywele yenye mawimbi',
    '👨🏼‍🦱' => 'mwanamume: ngozi nyeupe kiasi na nywele yenye mawimbi',
    '👨🏽‍🦱' => 'mwanamume: ngozi ya kahawia na nywele yenye mawimbi',
    '👨🏾‍🦱' => 'mwanamume: ngozi nyeusi kiasi na nywele yenye mawimbi',
    '👨🏿‍🦱' => 'mwanamume: ngozi nyeusi na nywele yenye mawimbi',
    '👨🏻‍🦳' => 'mwanamume: ngozi nyeupe na nywele nyeupe',
    '👨🏼‍🦳' => 'mwanamume: ngozi nyeupe kiasi na nywele nyeupe',
    '👨🏽‍🦳' => 'mwanamume: ngozi ya kahawia na nywele nyeupe',
    '👨🏾‍🦳' => 'mwanamume: ngozi nyeusi kiasi na nywele nyeupe',
    '👨🏿‍🦳' => 'mwanamume: ngozi nyeusi na nywele nyeupe',
    '👨🏻‍🦲' => 'mwanamume: ngozi nyeupe na upara',
    '👨🏼‍🦲' => 'mwanamume: ngozi nyeupe kiasi na upara',
    '👨🏽‍🦲' => 'mwanamume: ngozi ya kahawia na upara',
    '👨🏾‍🦲' => 'mwanamume: ngozi nyeusi kiasi na upara',
    '👨🏿‍🦲' => 'mwanamume: ngozi nyeusi na upara',
    '🧔🏻‍♀' => 'mwanamke: ngozi nyeupe na ndevu',
    '🧔🏼‍♀' => 'mwanamke: ngozi nyeupe kiasi na ndevu',
    '🧔🏽‍♀' => 'mwanamke: ngozi ya kahawia na ndevu',
    '🧔🏾‍♀' => 'mwanamke: ngozi nyeusi kiasi na ndevu',
    '🧔🏿‍♀' => 'mwanamke: ngozi nyeusi na ndevu',
    '👱🏻‍♀' => 'mwanamke mwenye nywele ya kimanjano: ngozi nyeupe',
    '👱🏼‍♀' => 'mwanamke mwenye nywele ya kimanjano: ngozi nyeupe kiasi',
    '👱🏽‍♀' => 'mwanamke mwenye nywele ya kimanjano: ngozi ya kahawia',
    '👱🏾‍♀' => 'mwanamke mwenye nywele ya kimanjano: ngozi nyeusi kiasi',
    '👱🏿‍♀' => 'mwanamke mwenye nywele ya kimanjano: ngozi nyeusi',
    '👩🏻‍🦰' => 'mwanamke: ngozi nyeupe na nywele nyekundu',
    '👩🏼‍🦰' => 'mwanamke: ngozi nyeupe kiasi na nywele nyekundu',
    '👩🏽‍🦰' => 'mwanamke: ngozi ya kahawia na nywele nyekundu',
    '👩🏾‍🦰' => 'mwanamke: ngozi nyeusi kiasi na nywele nyekundu',
    '👩🏿‍🦰' => 'mwanamke: ngozi nyeusi na nywele nyekundu',
    '👩🏻‍🦱' => 'mwanamke: ngozi nyeupe na nywele yenye mawimbi',
    '👩🏼‍🦱' => 'mwanamke: ngozi nyeupe kiasi na nywele yenye mawimbi',
    '👩🏽‍🦱' => 'mwanamke: ngozi ya kahawia na nywele yenye mawimbi',
    '👩🏾‍🦱' => 'mwanamke: ngozi nyeusi kiasi na nywele yenye mawimbi',
    '👩🏿‍🦱' => 'mwanamke: ngozi nyeusi na nywele yenye mawimbi',
    '👩🏻‍🦳' => 'mwanamke: ngozi nyeupe na nywele nyeupe',
    '👩🏼‍🦳' => 'mwanamke: ngozi nyeupe kiasi na nywele nyeupe',
    '👩🏽‍🦳' => 'mwanamke: ngozi ya kahawia na nywele nyeupe',
    '👩🏾‍🦳' => 'mwanamke: ngozi nyeusi kiasi na nywele nyeupe',
    '👩🏿‍🦳' => 'mwanamke: ngozi nyeusi na nywele nyeupe',
    '👩🏻‍🦲' => 'mwanamke: ngozi nyeupe na upara',
    '👩🏼‍🦲' => 'mwanamke: ngozi nyeupe kiasi na upara',
    '👩🏽‍🦲' => 'mwanamke: ngozi ya kahawia na upara',
    '👩🏾‍🦲' => 'mwanamke: ngozi nyeusi kiasi na upara',
    '👩🏿‍🦲' => 'mwanamke: ngozi nyeusi na upara',
    '🙍🏻‍♂' => 'mwanamume anayekunja kipaji cha uso: ngozi nyeupe',
    '🙍🏼‍♂' => 'mwanamume anayekunja kipaji cha uso: ngozi nyeupe kiasi',
    '🙍🏽‍♂' => 'mwanamume anayekunja kipaji cha uso: ngozi ya kahawia',
    '🙍🏾‍♂' => 'mwanamume anayekunja kipaji cha uso: ngozi nyeusi kiasi',
    '🙍🏿‍♂' => 'mwanamume anayekunja kipaji cha uso: ngozi nyeusi',
    '🙍🏻‍♀' => 'mwanamke anayekunja kipaji cha uso: ngozi nyeupe',
    '🙍🏼‍♀' => 'mwanamke anayekunja kipaji cha uso: ngozi nyeupe kiasi',
    '🙍🏽‍♀' => 'mwanamke anayekunja kipaji cha uso: ngozi ya kahawia',
    '🙍🏾‍♀' => 'mwanamke anayekunja kipaji cha uso: ngozi nyeusi kiasi',
    '🙍🏿‍♀' => 'mwanamke anayekunja kipaji cha uso: ngozi nyeusi',
    '🙎🏻‍♂' => 'mwanamume anayebibidua midomo: ngozi nyeupe',
    '🙎🏼‍♂' => 'mwanamume anayebibidua midomo: ngozi nyeupe kiasi',
    '🙎🏽‍♂' => 'mwanamume anayebibidua midomo: ngozi ya kahawia',
    '🙎🏾‍♂' => 'mwanamume anayebibidua midomo: ngozi nyeusi kiasi',
    '🙎🏿‍♂' => 'mwanamume anayebibidua midomo: ngozi nyeusi',
    '🙎🏻‍♀' => 'mwanamke anayebibidua midomo: ngozi nyeupe',
    '🙎🏼‍♀' => 'mwanamke anayebibidua midomo: ngozi nyeupe kiasi',
    '🙎🏽‍♀' => 'mwanamke anayebibidua midomo: ngozi ya kahawia',
    '🙎🏾‍♀' => 'mwanamke anayebibidua midomo: ngozi nyeusi kiasi',
    '🙎🏿‍♀' => 'mwanamke anayebibidua midomo: ngozi nyeusi',
    '🙅🏻‍♂' => 'Mtu anayeonyesha ishara ya HAPANA: ngozi nyeupe',
    '🙅🏼‍♂' => 'Mtu anayeonyesha ishara ya HAPANA: ngozi nyeupe kiasi',
    '🙅🏽‍♂' => 'Mtu anayeonyesha ishara ya HAPANA: ngozi ya kahawia',
    '🙅🏾‍♂' => 'Mtu anayeonyesha ishara ya HAPANA: ngozi nyeusi kiasi',
    '🙅🏿‍♂' => 'Mtu anayeonyesha ishara ya HAPANA: ngozi nyeusi',
    '🙅🏻‍♀' => 'mwanamke anayeonyesha ishara ya kukataa: ngozi nyeupe',
    '🙅🏼‍♀' => 'mwanamke anayeonyesha ishara ya kukataa: ngozi nyeupe kiasi',
    '🙅🏽‍♀' => 'mwanamke anayeonyesha ishara ya kukataa: ngozi ya kahawia',
    '🙅🏾‍♀' => 'mwanamke anayeonyesha ishara ya kukataa: ngozi nyeusi kiasi',
    '🙅🏿‍♀' => 'mwanamke anayeonyesha ishara ya kukataa: ngozi nyeusi',
    '🙆🏻‍♂' => 'Mtu anayeonyesha ishara ya NDIO: ngozi nyeupe',
    '🙆🏼‍♂' => 'Mtu anayeonyesha ishara ya NDIO: ngozi nyeupe kiasi',
    '🙆🏽‍♂' => 'Mtu anayeonyesha ishara ya NDIO: ngozi ya kahawia',
    '🙆🏾‍♂' => 'Mtu anayeonyesha ishara ya NDIO: ngozi nyeusi kiasi',
    '🙆🏿‍♂' => 'Mtu anayeonyesha ishara ya NDIO: ngozi nyeusi',
    '🙆🏻‍♀' => 'mwanamke anayeonyesha ishara ya kukubali: ngozi nyeupe',
    '🙆🏼‍♀' => 'mwanamke anayeonyesha ishara ya kukubali: ngozi nyeupe kiasi',
    '🙆🏽‍♀' => 'mwanamke anayeonyesha ishara ya kukubali: ngozi ya kahawia',
    '🙆🏾‍♀' => 'mwanamke anayeonyesha ishara ya kukubali: ngozi nyeusi kiasi',
    '🙆🏿‍♀' => 'mwanamke anayeonyesha ishara ya kukubali: ngozi nyeusi',
    '💁🏻‍♂' => 'mwanamume anayetoa maelezo: ngozi nyeupe',
    '💁🏼‍♂' => 'mwanamume anayetoa maelezo: ngozi nyeupe kiasi',
    '💁🏽‍♂' => 'mwanamume anayetoa maelezo: ngozi ya kahawia',
    '💁🏾‍♂' => 'mwanamume anayetoa maelezo: ngozi nyeusi kiasi',
    '💁🏿‍♂' => 'mwanamume anayetoa maelezo: ngozi nyeusi',
    '💁🏻‍♀' => 'mwanamke anayetoa maelezo: ngozi nyeupe',
    '💁🏼‍♀' => 'mwanamke anayetoa maelezo: ngozi nyeupe kiasi',
    '💁🏽‍♀' => 'mwanamke anayetoa maelezo: ngozi ya kahawia',
    '💁🏾‍♀' => 'mwanamke anayetoa maelezo: ngozi nyeusi kiasi',
    '💁🏿‍♀' => 'mwanamke anayetoa maelezo: ngozi nyeusi',
    '🙋🏻‍♂' => 'mtu aliyeinua mkono: ngozi nyeupe',
    '🙋🏼‍♂' => 'mtu aliyeinua mkono: ngozi nyeupe kiasi',
    '🙋🏽‍♂' => 'mtu aliyeinua mkono: ngozi ya kahawia',
    '🙋🏾‍♂' => 'mtu aliyeinua mkono: ngozi nyeusi kiasi',
    '🙋🏿‍♂' => 'mtu aliyeinua mkono: ngozi nyeusi',
    '🙋🏻‍♀' => 'mwanamke mwenye furaha aliyeinua mnoko: ngozi nyeupe',
    '🙋🏼‍♀' => 'mwanamke mwenye furaha aliyeinua mnoko: ngozi nyeupe kiasi',
    '🙋🏽‍♀' => 'mwanamke mwenye furaha aliyeinua mnoko: ngozi ya kahawia',
    '🙋🏾‍♀' => 'mwanamke mwenye furaha aliyeinua mnoko: ngozi nyeusi kiasi',
    '🙋🏿‍♀' => 'mwanamke mwenye furaha aliyeinua mnoko: ngozi nyeusi',
    '🧏🏻‍♂' => 'mwanamume kiziwi: ngozi nyeupe',
    '🧏🏼‍♂' => 'mwanamume kiziwi: ngozi nyeupe kiasi',
    '🧏🏽‍♂' => 'mwanamume kiziwi: ngozi ya kahawia',
    '🧏🏾‍♂' => 'mwanamume kiziwi: ngozi nyeusi kiasi',
    '🧏🏿‍♂' => 'mwanamume kiziwi: ngozi nyeusi',
    '🧏🏻‍♀' => 'mwanamke kiziwi: ngozi nyeupe',
    '🧏🏼‍♀' => 'mwanamke kiziwi: ngozi nyeupe kiasi',
    '🧏🏽‍♀' => 'mwanamke kiziwi: ngozi ya kahawia',
    '🧏🏾‍♀' => 'mwanamke kiziwi: ngozi nyeusi kiasi',
    '🧏🏿‍♀' => 'mwanamke kiziwi: ngozi nyeusi',
    '🙇🏻‍♂' => 'mwanamume aliyeinama: ngozi nyeupe',
    '🙇🏼‍♂' => 'mwanamume aliyeinama: ngozi nyeupe kiasi',
    '🙇🏽‍♂' => 'mwanamume aliyeinama: ngozi ya kahawia',
    '🙇🏾‍♂' => 'mwanamume aliyeinama: ngozi nyeusi kiasi',
    '🙇🏿‍♂' => 'mwanamume aliyeinama: ngozi nyeusi',
    '🙇🏻‍♀' => 'mwanamke aliyeinama: ngozi nyeupe',
    '🙇🏼‍♀' => 'mwanamke aliyeinama: ngozi nyeupe kiasi',
    '🙇🏽‍♀' => 'mwanamke aliyeinama: ngozi ya kahawia',
    '🙇🏾‍♀' => 'mwanamke aliyeinama: ngozi nyeusi kiasi',
    '🙇🏿‍♀' => 'mwanamke aliyeinama: ngozi nyeusi',
    '🤦🏻‍♂' => 'mwanamume anayeashiria kutoamini: ngozi nyeupe',
    '🤦🏼‍♂' => 'mwanamume anayeashiria kutoamini: ngozi nyeupe kiasi',
    '🤦🏽‍♂' => 'mwanamume anayeashiria kutoamini: ngozi ya kahawia',
    '🤦🏾‍♂' => 'mwanamume anayeashiria kutoamini: ngozi nyeusi kiasi',
    '🤦🏿‍♂' => 'mwanamume anayeashiria kutoamini: ngozi nyeusi',
    '🤦🏻‍♀' => 'mwanamke anayeashiria kutoamini: ngozi nyeupe',
    '🤦🏼‍♀' => 'mwanamke anayeashiria kutoamini: ngozi nyeupe kiasi',
    '🤦🏽‍♀' => 'mwanamke anayeashiria kutoamini: ngozi ya kahawia',
    '🤦🏾‍♀' => 'mwanamke anayeashiria kutoamini: ngozi nyeusi kiasi',
    '🤦🏿‍♀' => 'mwanamke anayeashiria kutoamini: ngozi nyeusi',
    '🤷🏻‍♂' => 'mwanamume anayeashiria kutojali: ngozi nyeupe',
    '🤷🏼‍♂' => 'mwanamume anayeashiria kutojali: ngozi nyeupe kiasi',
    '🤷🏽‍♂' => 'mwanamume anayeashiria kutojali: ngozi ya kahawia',
    '🤷🏾‍♂' => 'mwanamume anayeashiria kutojali: ngozi nyeusi kiasi',
    '🤷🏿‍♂' => 'mwanamume anayeashiria kutojali: ngozi nyeusi',
    '🤷🏻‍♀' => 'mwanamke anayeashiria kutojali: ngozi nyeupe',
    '🤷🏼‍♀' => 'mwanamke anayeashiria kutojali: ngozi nyeupe kiasi',
    '🤷🏽‍♀' => 'mwanamke anayeashiria kutojali: ngozi ya kahawia',
    '🤷🏾‍♀' => 'mwanamke anayeashiria kutojali: ngozi nyeusi kiasi',
    '🤷🏿‍♀' => 'mwanamke anayeashiria kutojali: ngozi nyeusi',
    '🧑🏻‍⚕' => 'mhudumu wa afya: ngozi nyeupe',
    '🧑🏼‍⚕' => 'mhudumu wa afya: ngozi nyeupe kiasi',
    '🧑🏽‍⚕' => 'mhudumu wa afya: ngozi ya kahawia',
    '🧑🏾‍⚕' => 'mhudumu wa afya: ngozi nyeusi kiasi',
    '🧑🏿‍⚕' => 'mhudumu wa afya: ngozi nyeusi',
    '👨🏻‍⚕' => 'mhudumu wa afya wa kiume: ngozi nyeupe',
    '👨🏼‍⚕' => 'mhudumu wa afya wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍⚕' => 'mhudumu wa afya wa kiume: ngozi ya kahawia',
    '👨🏾‍⚕' => 'mhudumu wa afya wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍⚕' => 'mhudumu wa afya wa kiume: ngozi nyeusi',
    '👩🏻‍⚕' => 'mhudumu wa afya wa kike: ngozi nyeupe',
    '👩🏼‍⚕' => 'mhudumu wa afya wa kike: ngozi nyeupe kiasi',
    '👩🏽‍⚕' => 'mhudumu wa afya wa kike: ngozi ya kahawia',
    '👩🏾‍⚕' => 'mhudumu wa afya wa kike: ngozi nyeusi kiasi',
    '👩🏿‍⚕' => 'mhudumu wa afya wa kike: ngozi nyeusi',
    '🧑🏻‍🎓' => 'mwanafunzi: ngozi nyeupe',
    '🧑🏼‍🎓' => 'mwanafunzi: ngozi nyeupe kiasi',
    '🧑🏽‍🎓' => 'mwanafunzi: ngozi ya kahawia',
    '🧑🏾‍🎓' => 'mwanafunzi: ngozi nyeusi kiasi',
    '🧑🏿‍🎓' => 'mwanafunzi: ngozi nyeusi',
    '👨🏻‍🎓' => 'mwanafunzi na kofia ya kufuzu: ngozi nyeupe',
    '👨🏼‍🎓' => 'mwanafunzi na kofia ya kufuzu: ngozi nyeupe kiasi',
    '👨🏽‍🎓' => 'mwanafunzi na kofia ya kufuzu: ngozi ya kahawia',
    '👨🏾‍🎓' => 'mwanafunzi na kofia ya kufuzu: ngozi nyeusi kiasi',
    '👨🏿‍🎓' => 'mwanafunzi na kofia ya kufuzu: ngozi nyeusi',
    '👩🏻‍🎓' => 'mwanafunzi wa kike na kofia ya kufuzu: ngozi nyeupe',
    '👩🏼‍🎓' => 'mwanafunzi wa kike na kofia ya kufuzu: ngozi nyeupe kiasi',
    '👩🏽‍🎓' => 'mwanafunzi wa kike na kofia ya kufuzu: ngozi ya kahawia',
    '👩🏾‍🎓' => 'mwanafunzi wa kike na kofia ya kufuzu: ngozi nyeusi kiasi',
    '👩🏿‍🎓' => 'mwanafunzi wa kike na kofia ya kufuzu: ngozi nyeusi',
    '🧑🏻‍🏫' => 'mwalimu: ngozi nyeupe',
    '🧑🏼‍🏫' => 'mwalimu: ngozi nyeupe kiasi',
    '🧑🏽‍🏫' => 'mwalimu: ngozi ya kahawia',
    '🧑🏾‍🏫' => 'mwalimu: ngozi nyeusi kiasi',
    '🧑🏿‍🏫' => 'mwalimu: ngozi nyeusi',
    '👨🏻‍🏫' => 'mwalimu na ubao: ngozi nyeupe',
    '👨🏼‍🏫' => 'mwalimu na ubao: ngozi nyeupe kiasi',
    '👨🏽‍🏫' => 'mwalimu na ubao: ngozi ya kahawia',
    '👨🏾‍🏫' => 'mwalimu na ubao: ngozi nyeusi kiasi',
    '👨🏿‍🏫' => 'mwalimu na ubao: ngozi nyeusi',
    '👩🏻‍🏫' => 'mwalimu wa kike na ubao: ngozi nyeupe',
    '👩🏼‍🏫' => 'mwalimu wa kike na ubao: ngozi nyeupe kiasi',
    '👩🏽‍🏫' => 'mwalimu wa kike na ubao: ngozi ya kahawia',
    '👩🏾‍🏫' => 'mwalimu wa kike na ubao: ngozi nyeusi kiasi',
    '👩🏿‍🏫' => 'mwalimu wa kike na ubao: ngozi nyeusi',
    '🧑🏻‍⚖' => 'hakimu: ngozi nyeupe',
    '🧑🏼‍⚖' => 'hakimu: ngozi nyeupe kiasi',
    '🧑🏽‍⚖' => 'hakimu: ngozi ya kahawia',
    '🧑🏾‍⚖' => 'hakimu: ngozi nyeusi kiasi',
    '🧑🏿‍⚖' => 'hakimu: ngozi nyeusi',
    '👨🏻‍⚖' => 'jaji wa kiume: ngozi nyeupe',
    '👨🏼‍⚖' => 'jaji wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍⚖' => 'jaji wa kiume: ngozi ya kahawia',
    '👨🏾‍⚖' => 'jaji wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍⚖' => 'jaji wa kiume: ngozi nyeusi',
    '👩🏻‍⚖' => 'jaji wa kike: ngozi nyeupe',
    '👩🏼‍⚖' => 'jaji wa kike: ngozi nyeupe kiasi',
    '👩🏽‍⚖' => 'jaji wa kike: ngozi ya kahawia',
    '👩🏾‍⚖' => 'jaji wa kike: ngozi nyeusi kiasi',
    '👩🏿‍⚖' => 'jaji wa kike: ngozi nyeusi',
    '🧑🏻‍🌾' => 'mkulima: ngozi nyeupe',
    '🧑🏼‍🌾' => 'mkulima: ngozi nyeupe kiasi',
    '🧑🏽‍🌾' => 'mkulima: ngozi ya kahawia',
    '🧑🏾‍🌾' => 'mkulima: ngozi nyeusi kiasi',
    '🧑🏿‍🌾' => 'mkulima: ngozi nyeusi',
    '👨🏻‍🌾' => 'mkulima wa kiume: ngozi nyeupe',
    '👨🏼‍🌾' => 'mkulima wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍🌾' => 'mkulima wa kiume: ngozi ya kahawia',
    '👨🏾‍🌾' => 'mkulima wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍🌾' => 'mkulima wa kiume: ngozi nyeusi',
    '👩🏻‍🌾' => 'mkulima wa kike: ngozi nyeupe',
    '👩🏼‍🌾' => 'mkulima wa kike: ngozi nyeupe kiasi',
    '👩🏽‍🌾' => 'mkulima wa kike: ngozi ya kahawia',
    '👩🏾‍🌾' => 'mkulima wa kike: ngozi nyeusi kiasi',
    '👩🏿‍🌾' => 'mkulima wa kike: ngozi nyeusi',
    '🧑🏻‍🍳' => 'mpishi: ngozi nyeupe',
    '🧑🏼‍🍳' => 'mpishi: ngozi nyeupe kiasi',
    '🧑🏽‍🍳' => 'mpishi: ngozi ya kahawia',
    '🧑🏾‍🍳' => 'mpishi: ngozi nyeusi kiasi',
    '🧑🏿‍🍳' => 'mpishi: ngozi nyeusi',
    '👨🏻‍🍳' => 'mpishi wa kiume: ngozi nyeupe',
    '👨🏼‍🍳' => 'mpishi wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍🍳' => 'mpishi wa kiume: ngozi ya kahawia',
    '👨🏾‍🍳' => 'mpishi wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍🍳' => 'mpishi wa kiume: ngozi nyeusi',
    '👩🏻‍🍳' => 'mpishi wa kike: ngozi nyeupe',
    '👩🏼‍🍳' => 'mpishi wa kike: ngozi nyeupe kiasi',
    '👩🏽‍🍳' => 'mpishi wa kike: ngozi ya kahawia',
    '👩🏾‍🍳' => 'mpishi wa kike: ngozi nyeusi kiasi',
    '👩🏿‍🍳' => 'mpishi wa kike: ngozi nyeusi',
    '🧑🏻‍🔧' => 'makanika: ngozi nyeupe',
    '🧑🏼‍🔧' => 'makanika: ngozi nyeupe kiasi',
    '🧑🏽‍🔧' => 'makanika: ngozi ya kahawia',
    '🧑🏾‍🔧' => 'makanika: ngozi nyeusi kiasi',
    '🧑🏿‍🔧' => 'makanika: ngozi nyeusi',
    '👨🏻‍🔧' => 'fundi mitambo wa kiume: ngozi nyeupe',
    '👨🏼‍🔧' => 'fundi mitambo wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍🔧' => 'fundi mitambo wa kiume: ngozi ya kahawia',
    '👨🏾‍🔧' => 'fundi mitambo wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍🔧' => 'fundi mitambo wa kiume: ngozi nyeusi',
    '👩🏻‍🔧' => 'fundi mitambo wa kike: ngozi nyeupe',
    '👩🏼‍🔧' => 'fundi mitambo wa kike: ngozi nyeupe kiasi',
    '👩🏽‍🔧' => 'fundi mitambo wa kike: ngozi ya kahawia',
    '👩🏾‍🔧' => 'fundi mitambo wa kike: ngozi nyeusi kiasi',
    '👩🏿‍🔧' => 'fundi mitambo wa kike: ngozi nyeusi',
    '🧑🏻‍🏭' => 'mfanyakazi wa kiwanda: ngozi nyeupe',
    '🧑🏼‍🏭' => 'mfanyakazi wa kiwanda: ngozi nyeupe kiasi',
    '🧑🏽‍🏭' => 'mfanyakazi wa kiwanda: ngozi ya kahawia',
    '🧑🏾‍🏭' => 'mfanyakazi wa kiwanda: ngozi nyeusi kiasi',
    '🧑🏿‍🏭' => 'mfanyakazi wa kiwanda: ngozi nyeusi',
    '👨🏻‍🏭' => 'mwanamume na gesi ya kuchoma: ngozi nyeupe',
    '👨🏼‍🏭' => 'mwanamume na gesi ya kuchoma: ngozi nyeupe kiasi',
    '👨🏽‍🏭' => 'mwanamume na gesi ya kuchoma: ngozi ya kahawia',
    '👨🏾‍🏭' => 'mwanamume na gesi ya kuchoma: ngozi nyeusi kiasi',
    '👨🏿‍🏭' => 'mwanamume na gesi ya kuchoma: ngozi nyeusi',
    '👩🏻‍🏭' => 'mwanamke na gesi ya kuchoma: ngozi nyeupe',
    '👩🏼‍🏭' => 'mwanamke na gesi ya kuchoma: ngozi nyeupe kiasi',
    '👩🏽‍🏭' => 'mwanamke na gesi ya kuchoma: ngozi ya kahawia',
    '👩🏾‍🏭' => 'mwanamke na gesi ya kuchoma: ngozi nyeusi kiasi',
    '👩🏿‍🏭' => 'mwanamke na gesi ya kuchoma: ngozi nyeusi',
    '🧑🏻‍💼' => 'mfanyakazi wa ofisi: ngozi nyeupe',
    '🧑🏼‍💼' => 'mfanyakazi wa ofisi: ngozi nyeupe kiasi',
    '🧑🏽‍💼' => 'mfanyakazi wa ofisi: ngozi ya kahawia',
    '🧑🏾‍💼' => 'mfanyakazi wa ofisi: ngozi nyeusi kiasi',
    '🧑🏿‍💼' => 'mfanyakazi wa ofisi: ngozi nyeusi',
    '👨🏻‍💼' => 'mwanamume aliyevaa nadhifu: ngozi nyeupe',
    '👨🏼‍💼' => 'mwanamume aliyevaa nadhifu: ngozi nyeupe kiasi',
    '👨🏽‍💼' => 'mwanamume aliyevaa nadhifu: ngozi ya kahawia',
    '👨🏾‍💼' => 'mwanamume aliyevaa nadhifu: ngozi nyeusi kiasi',
    '👨🏿‍💼' => 'mwanamume aliyevaa nadhifu: ngozi nyeusi',
    '👩🏻‍💼' => 'mwanamke aliyevaa nadhifu: ngozi nyeupe',
    '👩🏼‍💼' => 'mwanamke aliyevaa nadhifu: ngozi nyeupe kiasi',
    '👩🏽‍💼' => 'mwanamke aliyevaa nadhifu: ngozi ya kahawia',
    '👩🏾‍💼' => 'mwanamke aliyevaa nadhifu: ngozi nyeusi kiasi',
    '👩🏿‍💼' => 'mwanamke aliyevaa nadhifu: ngozi nyeusi',
    '🧑🏻‍🔬' => 'mwanasayansi: ngozi nyeupe',
    '🧑🏼‍🔬' => 'mwanasayansi: ngozi nyeupe kiasi',
    '🧑🏽‍🔬' => 'mwanasayansi: ngozi ya kahawia',
    '🧑🏾‍🔬' => 'mwanasayansi: ngozi nyeusi kiasi',
    '🧑🏿‍🔬' => 'mwanasayansi: ngozi nyeusi',
    '👨🏻‍🔬' => 'mwanasayansi wa kiume: ngozi nyeupe',
    '👨🏼‍🔬' => 'mwanasayansi wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍🔬' => 'mwanasayansi wa kiume: ngozi ya kahawia',
    '👨🏾‍🔬' => 'mwanasayansi wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍🔬' => 'mwanasayansi wa kiume: ngozi nyeusi',
    '👩🏻‍🔬' => 'mwanasayansi wa kike: ngozi nyeupe',
    '👩🏼‍🔬' => 'mwanasayansi wa kike: ngozi nyeupe kiasi',
    '👩🏽‍🔬' => 'mwanasayansi wa kike: ngozi ya kahawia',
    '👩🏾‍🔬' => 'mwanasayansi wa kike: ngozi nyeusi kiasi',
    '👩🏿‍🔬' => 'mwanasayansi wa kike: ngozi nyeusi',
    '🧑🏻‍💻' => 'mwanateknolojia: ngozi nyeupe',
    '🧑🏼‍💻' => 'mwanateknolojia: ngozi nyeupe kiasi',
    '🧑🏽‍💻' => 'mwanateknolojia: ngozi ya kahawia',
    '🧑🏾‍💻' => 'mwanateknolojia: ngozi nyeusi kiasi',
    '🧑🏿‍💻' => 'mwanateknolojia: ngozi nyeusi',
    '👨🏻‍💻' => 'mwanateknolojia wa kiume: ngozi nyeupe',
    '👨🏼‍💻' => 'mwanateknolojia wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍💻' => 'mwanateknolojia wa kiume: ngozi ya kahawia',
    '👨🏾‍💻' => 'mwanateknolojia wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍💻' => 'mwanateknolojia wa kiume: ngozi nyeusi',
    '👩🏻‍💻' => 'mwanateknolojia wa kike: ngozi nyeupe',
    '👩🏼‍💻' => 'mwanateknolojia wa kike: ngozi nyeupe kiasi',
    '👩🏽‍💻' => 'mwanateknolojia wa kike: ngozi ya kahawia',
    '👩🏾‍💻' => 'mwanateknolojia wa kike: ngozi nyeusi kiasi',
    '👩🏿‍💻' => 'mwanateknolojia wa kike: ngozi nyeusi',
    '🧑🏻‍🎤' => 'mwimbaji: ngozi nyeupe',
    '🧑🏼‍🎤' => 'mwimbaji: ngozi nyeupe kiasi',
    '🧑🏽‍🎤' => 'mwimbaji: ngozi ya kahawia',
    '🧑🏾‍🎤' => 'mwimbaji: ngozi nyeusi kiasi',
    '🧑🏿‍🎤' => 'mwimbaji: ngozi nyeusi',
    '👨🏻‍🎤' => 'mwimbaji wa kiume: ngozi nyeupe',
    '👨🏼‍🎤' => 'mwimbaji wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍🎤' => 'mwimbaji wa kiume: ngozi ya kahawia',
    '👨🏾‍🎤' => 'mwimbaji wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍🎤' => 'mwimbaji wa kiume: ngozi nyeusi',
    '👩🏻‍🎤' => 'mwimbaji wa kike: ngozi nyeupe',
    '👩🏼‍🎤' => 'mwimbaji wa kike: ngozi nyeupe kiasi',
    '👩🏽‍🎤' => 'mwimbaji wa kike: ngozi ya kahawia',
    '👩🏾‍🎤' => 'mwimbaji wa kike: ngozi nyeusi kiasi',
    '👩🏿‍🎤' => 'mwimbaji wa kike: ngozi nyeusi',
    '🧑🏻‍🎨' => 'mchoraji: ngozi nyeupe',
    '🧑🏼‍🎨' => 'mchoraji: ngozi nyeupe kiasi',
    '🧑🏽‍🎨' => 'mchoraji: ngozi ya kahawia',
    '🧑🏾‍🎨' => 'mchoraji: ngozi nyeusi kiasi',
    '🧑🏿‍🎨' => 'mchoraji: ngozi nyeusi',
    '👨🏻‍🎨' => 'mchoraji wa kiume: ngozi nyeupe',
    '👨🏼‍🎨' => 'mchoraji wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍🎨' => 'mchoraji wa kiume: ngozi ya kahawia',
    '👨🏾‍🎨' => 'mchoraji wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍🎨' => 'mchoraji wa kiume: ngozi nyeusi',
    '👩🏻‍🎨' => 'mchoraji wa kike: ngozi nyeupe',
    '👩🏼‍🎨' => 'mchoraji wa kike: ngozi nyeupe kiasi',
    '👩🏽‍🎨' => 'mchoraji wa kike: ngozi ya kahawia',
    '👩🏾‍🎨' => 'mchoraji wa kike: ngozi nyeusi kiasi',
    '👩🏿‍🎨' => 'mchoraji wa kike: ngozi nyeusi',
    '🧑🏻‍✈' => 'rubani: ngozi nyeupe',
    '🧑🏼‍✈' => 'rubani: ngozi nyeupe kiasi',
    '🧑🏽‍✈' => 'rubani: ngozi ya kahawia',
    '🧑🏾‍✈' => 'rubani: ngozi nyeusi kiasi',
    '🧑🏿‍✈' => 'rubani: ngozi nyeusi',
    '👨🏻‍✈' => 'rubani wa kiume: ngozi nyeupe',
    '👨🏼‍✈' => 'rubani wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍✈' => 'rubani wa kiume: ngozi ya kahawia',
    '👨🏾‍✈' => 'rubani wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍✈' => 'rubani wa kiume: ngozi nyeusi',
    '👩🏻‍✈' => 'rubani wa kike: ngozi nyeupe',
    '👩🏼‍✈' => 'rubani wa kike: ngozi nyeupe kiasi',
    '👩🏽‍✈' => 'rubani wa kike: ngozi ya kahawia',
    '👩🏾‍✈' => 'rubani wa kike: ngozi nyeusi kiasi',
    '👩🏿‍✈' => 'rubani wa kike: ngozi nyeusi',
    '🧑🏻‍🚀' => 'mwanaanga: ngozi nyeupe',
    '🧑🏼‍🚀' => 'mwanaanga: ngozi nyeupe kiasi',
    '🧑🏽‍🚀' => 'mwanaanga: ngozi ya kahawia',
    '🧑🏾‍🚀' => 'mwanaanga: ngozi nyeusi kiasi',
    '🧑🏿‍🚀' => 'mwanaanga: ngozi nyeusi',
    '👨🏻‍🚀' => 'mwanaanga wa kiume: ngozi nyeupe',
    '👨🏼‍🚀' => 'mwanaanga wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍🚀' => 'mwanaanga wa kiume: ngozi ya kahawia',
    '👨🏾‍🚀' => 'mwanaanga wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍🚀' => 'mwanaanga wa kiume: ngozi nyeusi',
    '👩🏻‍🚀' => 'mwanaanga wa kike: ngozi nyeupe',
    '👩🏼‍🚀' => 'mwanaanga wa kike: ngozi nyeupe kiasi',
    '👩🏽‍🚀' => 'mwanaanga wa kike: ngozi ya kahawia',
    '👩🏾‍🚀' => 'mwanaanga wa kike: ngozi nyeusi kiasi',
    '👩🏿‍🚀' => 'mwanaanga wa kike: ngozi nyeusi',
    '🧑🏻‍🚒' => 'mzimamoto: ngozi nyeupe',
    '🧑🏼‍🚒' => 'mzimamoto: ngozi nyeupe kiasi',
    '🧑🏽‍🚒' => 'mzimamoto: ngozi ya kahawia',
    '🧑🏾‍🚒' => 'mzimamoto: ngozi nyeusi kiasi',
    '🧑🏿‍🚒' => 'mzimamoto: ngozi nyeusi',
    '👨🏻‍🚒' => 'mzimamoto wa kiume: ngozi nyeupe',
    '👨🏼‍🚒' => 'mzimamoto wa kiume: ngozi nyeupe kiasi',
    '👨🏽‍🚒' => 'mzimamoto wa kiume: ngozi ya kahawia',
    '👨🏾‍🚒' => 'mzimamoto wa kiume: ngozi nyeusi kiasi',
    '👨🏿‍🚒' => 'mzimamoto wa kiume: ngozi nyeusi',
    '👩🏻‍🚒' => 'mzimamoto wa kike: ngozi nyeupe',
    '👩🏼‍🚒' => 'mzimamoto wa kike: ngozi nyeupe kiasi',
    '👩🏽‍🚒' => 'mzimamoto wa kike: ngozi ya kahawia',
    '👩🏾‍🚒' => 'mzimamoto wa kike: ngozi nyeusi kiasi',
    '👩🏿‍🚒' => 'mzimamoto wa kike: ngozi nyeusi',
    '👮🏻‍♂' => 'polisi wa kiume: ngozi nyeupe',
    '👮🏼‍♂' => 'polisi wa kiume: ngozi nyeupe kiasi',
    '👮🏽‍♂' => 'polisi wa kiume: ngozi ya kahawia',
    '👮🏾‍♂' => 'polisi wa kiume: ngozi nyeusi kiasi',
    '👮🏿‍♂' => 'polisi wa kiume: ngozi nyeusi',
    '👮🏻‍♀' => 'polisi wa kike: ngozi nyeupe',
    '👮🏼‍♀' => 'polisi wa kike: ngozi nyeupe kiasi',
    '👮🏽‍♀' => 'polisi wa kike: ngozi ya kahawia',
    '👮🏾‍♀' => 'polisi wa kike: ngozi nyeusi kiasi',
    '👮🏿‍♀' => 'polisi wa kike: ngozi nyeusi',
    '🕵🏻‍♂' => 'jasusi mwanamume: ngozi nyeupe',
    '🕵🏼‍♂' => 'jasusi mwanamume: ngozi nyeupe kiasi',
    '🕵🏽‍♂' => 'jasusi mwanamume: ngozi ya kahawia',
    '🕵🏾‍♂' => 'jasusi mwanamume: ngozi nyeusi kiasi',
    '🕵🏿‍♂' => 'jasusi mwanamume: ngozi nyeusi',
    '🕵🏻‍♀' => 'jasusi mwanamke: ngozi nyeupe',
    '🕵🏼‍♀' => 'jasusi mwanamke: ngozi nyeupe kiasi',
    '🕵🏽‍♀' => 'jasusi mwanamke: ngozi ya kahawia',
    '🕵🏾‍♀' => 'jasusi mwanamke: ngozi nyeusi kiasi',
    '🕵🏿‍♀' => 'jasusi mwanamke: ngozi nyeusi',
    '💂🏻‍♂' => 'mlinzi mwanamume: ngozi nyeupe',
    '💂🏼‍♂' => 'mlinzi mwanamume: ngozi nyeupe kiasi',
    '💂🏽‍♂' => 'mlinzi mwanamume: ngozi ya kahawia',
    '💂🏾‍♂' => 'mlinzi mwanamume: ngozi nyeusi kiasi',
    '💂🏿‍♂' => 'mlinzi mwanamume: ngozi nyeusi',
    '💂🏻‍♀' => 'mlinzi wa kike: ngozi nyeupe',
    '💂🏼‍♀' => 'mlinzi wa kike: ngozi nyeupe kiasi',
    '💂🏽‍♀' => 'mlinzi wa kike: ngozi ya kahawia',
    '💂🏾‍♀' => 'mlinzi wa kike: ngozi nyeusi kiasi',
    '💂🏿‍♀' => 'mlinzi wa kike: ngozi nyeusi',
    '👷🏻‍♂' => 'mjenzi mwanamume: ngozi nyeupe',
    '👷🏼‍♂' => 'mjenzi mwanamume: ngozi nyeupe kiasi',
    '👷🏽‍♂' => 'mjenzi mwanamume: ngozi ya kahawia',
    '👷🏾‍♂' => 'mjenzi mwanamume: ngozi nyeusi kiasi',
    '👷🏿‍♂' => 'mjenzi mwanamume: ngozi nyeusi',
    '👷🏻‍♀' => 'mjenzi wa kike: ngozi nyeupe',
    '👷🏼‍♀' => 'mjenzi wa kike: ngozi nyeupe kiasi',
    '👷🏽‍♀' => 'mjenzi wa kike: ngozi ya kahawia',
    '👷🏾‍♀' => 'mjenzi wa kike: ngozi nyeusi kiasi',
    '👷🏿‍♀' => 'mjenzi wa kike: ngozi nyeusi',
    '👳🏻‍♂' => 'mwanamume aliyefunga kilemba: ngozi nyeupe',
    '👳🏼‍♂' => 'mwanamume aliyefunga kilemba: ngozi nyeupe kiasi',
    '👳🏽‍♂' => 'mwanamume aliyefunga kilemba: ngozi ya kahawia',
    '👳🏾‍♂' => 'mwanamume aliyefunga kilemba: ngozi nyeusi kiasi',
    '👳🏿‍♂' => 'mwanamume aliyefunga kilemba: ngozi nyeusi',
    '👳🏻‍♀' => 'mwanamke aliyefunga kilemba: ngozi nyeupe',
    '👳🏼‍♀' => 'mwanamke aliyefunga kilemba: ngozi nyeupe kiasi',
    '👳🏽‍♀' => 'mwanamke aliyefunga kilemba: ngozi ya kahawia',
    '👳🏾‍♀' => 'mwanamke aliyefunga kilemba: ngozi nyeusi kiasi',
    '👳🏿‍♀' => 'mwanamke aliyefunga kilemba: ngozi nyeusi',
    '🤵🏻‍♂' => 'mwanamume aliyevalia tuxedo: ngozi nyeupe',
    '🤵🏼‍♂' => 'mwanamume aliyevalia tuxedo: ngozi nyeupe kiasi',
    '🤵🏽‍♂' => 'mwanamume aliyevalia tuxedo: ngozi ya kahawia',
    '🤵🏾‍♂' => 'mwanamume aliyevalia tuxedo: ngozi nyeusi kiasi',
    '🤵🏿‍♂' => 'mwanamume aliyevalia tuxedo: ngozi nyeusi',
    '🤵🏻‍♀' => 'mwanamke aliyevalia tuxedo: ngozi nyeupe',
    '🤵🏼‍♀' => 'mwanamke aliyevalia tuxedo: ngozi nyeupe kiasi',
    '🤵🏽‍♀' => 'mwanamke aliyevalia tuxedo: ngozi ya kahawia',
    '🤵🏾‍♀' => 'mwanamke aliyevalia tuxedo: ngozi nyeusi kiasi',
    '🤵🏿‍♀' => 'mwanamke aliyevalia tuxedo: ngozi nyeusi',
    '👰🏻‍♂' => 'mwanamume aliyevalia shela: ngozi nyeupe',
    '👰🏼‍♂' => 'mwanamume aliyevalia shela: ngozi nyeupe kiasi',
    '👰🏽‍♂' => 'mwanamume aliyevalia shela: ngozi ya kahawia',
    '👰🏾‍♂' => 'mwanamume aliyevalia shela: ngozi nyeusi kiasi',
    '👰🏿‍♂' => 'mwanamume aliyevalia shela: ngozi nyeusi',
    '👰🏻‍♀' => 'mwanamke aliyevalia shela: ngozi nyeupe',
    '👰🏼‍♀' => 'mwanamke aliyevalia shela: ngozi nyeupe kiasi',
    '👰🏽‍♀' => 'mwanamke aliyevalia shela: ngozi ya kahawia',
    '👰🏾‍♀' => 'mwanamke aliyevalia shela: ngozi nyeusi kiasi',
    '👰🏿‍♀' => 'mwanamke aliyevalia shela: ngozi nyeusi',
    '👩🏻‍🍼' => 'mwanamke anayemlisha mtoto: ngozi nyeupe',
    '👩🏼‍🍼' => 'mwanamke anayemlisha mtoto: ngozi nyeupe kiasi',
    '👩🏽‍🍼' => 'mwanamke anayemlisha mtoto: ngozi ya kahawia',
    '👩🏾‍🍼' => 'mwanamke anayemlisha mtoto: ngozi nyeusi kiasi',
    '👩🏿‍🍼' => 'mwanamke anayemlisha mtoto: ngozi nyeusi',
    '👨🏻‍🍼' => 'mwanamume anayemlisha mtoto: ngozi nyeupe',
    '👨🏼‍🍼' => 'mwanamume anayemlisha mtoto: ngozi nyeupe kiasi',
    '👨🏽‍🍼' => 'mwanamume anayemlisha mtoto: ngozi ya kahawia',
    '👨🏾‍🍼' => 'mwanamume anayemlisha mtoto: ngozi nyeusi kiasi',
    '👨🏿‍🍼' => 'mwanamume anayemlisha mtoto: ngozi nyeusi',
    '🧑🏻‍🍼' => 'mtu anamyelisha mtoto: ngozi nyeupe',
    '🧑🏼‍🍼' => 'mtu anamyelisha mtoto: ngozi nyeupe kiasi',
    '🧑🏽‍🍼' => 'mtu anamyelisha mtoto: ngozi ya kahawia',
    '🧑🏾‍🍼' => 'mtu anamyelisha mtoto: ngozi nyeusi kiasi',
    '🧑🏿‍🍼' => 'mtu anamyelisha mtoto: ngozi nyeusi',
    '🧑🏻‍🎄' => 'kichimbakazi yeyote: ngozi nyeupe',
    '🧑🏼‍🎄' => 'kichimbakazi yeyote: ngozi nyeupe kiasi',
    '🧑🏽‍🎄' => 'kichimbakazi yeyote: ngozi ya kahawia',
    '🧑🏾‍🎄' => 'kichimbakazi yeyote: ngozi nyeusi kiasi',
    '🧑🏿‍🎄' => 'kichimbakazi yeyote: ngozi nyeusi',
    '🦸🏻‍♂' => 'shujaa wa kiume: ngozi nyeupe',
    '🦸🏼‍♂' => 'shujaa wa kiume: ngozi nyeupe kiasi',
    '🦸🏽‍♂' => 'shujaa wa kiume: ngozi ya kahawia',
    '🦸🏾‍♂' => 'shujaa wa kiume: ngozi nyeusi kiasi',
    '🦸🏿‍♂' => 'shujaa wa kiume: ngozi nyeusi',
    '🦸🏻‍♀' => 'shujaa wa kike: ngozi nyeupe',
    '🦸🏼‍♀' => 'shujaa wa kike: ngozi nyeupe kiasi',
    '🦸🏽‍♀' => 'shujaa wa kike: ngozi ya kahawia',
    '🦸🏾‍♀' => 'shujaa wa kike: ngozi nyeusi kiasi',
    '🦸🏿‍♀' => 'shujaa wa kike: ngozi nyeusi',
    '🦹🏻‍♂' => 'jambazi wa kiume: ngozi nyeupe',
    '🦹🏼‍♂' => 'jambazi wa kiume: ngozi nyeupe kiasi',
    '🦹🏽‍♂' => 'jambazi wa kiume: ngozi ya kahawia',
    '🦹🏾‍♂' => 'jambazi wa kiume: ngozi nyeusi kiasi',
    '🦹🏿‍♂' => 'jambazi wa kiume: ngozi nyeusi',
    '🦹🏻‍♀' => 'jambazi wa kike: ngozi nyeupe',
    '🦹🏼‍♀' => 'jambazi wa kike: ngozi nyeupe kiasi',
    '🦹🏽‍♀' => 'jambazi wa kike: ngozi ya kahawia',
    '🦹🏾‍♀' => 'jambazi wa kike: ngozi nyeusi kiasi',
    '🦹🏿‍♀' => 'jambazi wa kike: ngozi nyeusi',
    '🧙🏻‍♂' => 'mchawi wa kiume: ngozi nyeupe',
    '🧙🏼‍♂' => 'mchawi wa kiume: ngozi nyeupe kiasi',
    '🧙🏽‍♂' => 'mchawi wa kiume: ngozi ya kahawia',
    '🧙🏾‍♂' => 'mchawi wa kiume: ngozi nyeusi kiasi',
    '🧙🏿‍♂' => 'mchawi wa kiume: ngozi nyeusi',
    '🧙🏻‍♀' => 'mlozi wa kike: ngozi nyeupe',
    '🧙🏼‍♀' => 'mlozi wa kike: ngozi nyeupe kiasi',
    '🧙🏽‍♀' => 'mlozi wa kike: ngozi ya kahawia',
    '🧙🏾‍♀' => 'mlozi wa kike: ngozi nyeusi kiasi',
    '🧙🏿‍♀' => 'mlozi wa kike: ngozi nyeusi',
    '🧚🏻‍♂' => 'kichimbakazi wa kiume: ngozi nyeupe',
    '🧚🏼‍♂' => 'kichimbakazi wa kiume: ngozi nyeupe kiasi',
    '🧚🏽‍♂' => 'kichimbakazi wa kiume: ngozi ya kahawia',
    '🧚🏾‍♂' => 'kichimbakazi wa kiume: ngozi nyeusi kiasi',
    '🧚🏿‍♂' => 'kichimbakazi wa kiume: ngozi nyeusi',
    '🧚🏻‍♀' => 'kichimbakazi wa kike: ngozi nyeupe',
    '🧚🏼‍♀' => 'kichimbakazi wa kike: ngozi nyeupe kiasi',
    '🧚🏽‍♀' => 'kichimbakazi wa kike: ngozi ya kahawia',
    '🧚🏾‍♀' => 'kichimbakazi wa kike: ngozi nyeusi kiasi',
    '🧚🏿‍♀' => 'kichimbakazi wa kike: ngozi nyeusi',
    '🧛🏻‍♂' => 'mnyonya damu wa kiume: ngozi nyeupe',
    '🧛🏼‍♂' => 'mnyonya damu wa kiume: ngozi nyeupe kiasi',
    '🧛🏽‍♂' => 'mnyonya damu wa kiume: ngozi ya kahawia',
    '🧛🏾‍♂' => 'mnyonya damu wa kiume: ngozi nyeusi kiasi',
    '🧛🏿‍♂' => 'mnyonya damu wa kiume: ngozi nyeusi',
    '🧛🏻‍♀' => 'mnyonya damu wa kike: ngozi nyeupe',
    '🧛🏼‍♀' => 'mnyonya damu wa kike: ngozi nyeupe kiasi',
    '🧛🏽‍♀' => 'mnyonya damu wa kike: ngozi ya kahawia',
    '🧛🏾‍♀' => 'mnyonya damu wa kike: ngozi nyeusi kiasi',
    '🧛🏿‍♀' => 'mnyonya damu wa kike: ngozi nyeusi',
    '🧜🏻‍♂' => 'nguva dume: ngozi nyeupe',
    '🧜🏼‍♂' => 'nguva dume: ngozi nyeupe kiasi',
    '🧜🏽‍♂' => 'nguva dume: ngozi ya kahawia',
    '🧜🏾‍♂' => 'nguva dume: ngozi nyeusi kiasi',
    '🧜🏿‍♂' => 'nguva dume: ngozi nyeusi',
    '🧜🏻‍♀' => 'nguva: ngozi nyeupe',
    '🧜🏼‍♀' => 'nguva: ngozi nyeupe kiasi',
    '🧜🏽‍♀' => 'nguva: ngozi ya kahawia',
    '🧜🏾‍♀' => 'nguva: ngozi nyeusi kiasi',
    '🧜🏿‍♀' => 'nguva: ngozi nyeusi',
    '🧝🏻‍♂' => 'kibwengo dume: ngozi nyeupe',
    '🧝🏼‍♂' => 'kibwengo dume: ngozi nyeupe kiasi',
    '🧝🏽‍♂' => 'kibwengo dume: ngozi ya kahawia',
    '🧝🏾‍♂' => 'kibwengo dume: ngozi nyeusi kiasi',
    '🧝🏿‍♂' => 'kibwengo dume: ngozi nyeusi',
    '🧝🏻‍♀' => 'kibwengo cha kike: ngozi nyeupe',
    '🧝🏼‍♀' => 'kibwengo cha kike: ngozi nyeupe kiasi',
    '🧝🏽‍♀' => 'kibwengo cha kike: ngozi ya kahawia',
    '🧝🏾‍♀' => 'kibwengo cha kike: ngozi nyeusi kiasi',
    '🧝🏿‍♀' => 'kibwengo cha kike: ngozi nyeusi',
    '💆🏻‍♂' => 'mwanamume anayekandwa uso: ngozi nyeupe',
    '💆🏼‍♂' => 'mwanamume anayekandwa uso: ngozi nyeupe kiasi',
    '💆🏽‍♂' => 'mwanamume anayekandwa uso: ngozi ya kahawia',
    '💆🏾‍♂' => 'mwanamume anayekandwa uso: ngozi nyeusi kiasi',
    '💆🏿‍♂' => 'mwanamume anayekandwa uso: ngozi nyeusi',
    '💆🏻‍♀' => 'mwanamke anayekandwa uso: ngozi nyeupe',
    '💆🏼‍♀' => 'mwanamke anayekandwa uso: ngozi nyeupe kiasi',
    '💆🏽‍♀' => 'mwanamke anayekandwa uso: ngozi ya kahawia',
    '💆🏾‍♀' => 'mwanamke anayekandwa uso: ngozi nyeusi kiasi',
    '💆🏿‍♀' => 'mwanamke anayekandwa uso: ngozi nyeusi',
    '💇🏻‍♂' => 'mwanamume anayenyolewa nywele: ngozi nyeupe',
    '💇🏼‍♂' => 'mwanamume anayenyolewa nywele: ngozi nyeupe kiasi',
    '💇🏽‍♂' => 'mwanamume anayenyolewa nywele: ngozi ya kahawia',
    '💇🏾‍♂' => 'mwanamume anayenyolewa nywele: ngozi nyeusi kiasi',
    '💇🏿‍♂' => 'mwanamume anayenyolewa nywele: ngozi nyeusi',
    '💇🏻‍♀' => 'mwanamke anayenyolewa nywele: ngozi nyeupe',
    '💇🏼‍♀' => 'mwanamke anayenyolewa nywele: ngozi nyeupe kiasi',
    '💇🏽‍♀' => 'mwanamke anayenyolewa nywele: ngozi ya kahawia',
    '💇🏾‍♀' => 'mwanamke anayenyolewa nywele: ngozi nyeusi kiasi',
    '💇🏿‍♀' => 'mwanamke anayenyolewa nywele: ngozi nyeusi',
    '🚶🏻‍♂' => 'mwanamume anayetembea: ngozi nyeupe',
    '🚶🏼‍♂' => 'mwanamume anayetembea: ngozi nyeupe kiasi',
    '🚶🏽‍♂' => 'mwanamume anayetembea: ngozi ya kahawia',
    '🚶🏾‍♂' => 'mwanamume anayetembea: ngozi nyeusi kiasi',
    '🚶🏿‍♂' => 'mwanamume anayetembea: ngozi nyeusi',
    '🚶🏻‍♀' => 'mwanamke anayetembea: ngozi nyeupe',
    '🚶🏼‍♀' => 'mwanamke anayetembea: ngozi nyeupe kiasi',
    '🚶🏽‍♀' => 'mwanamke anayetembea: ngozi ya kahawia',
    '🚶🏾‍♀' => 'mwanamke anayetembea: ngozi nyeusi kiasi',
    '🚶🏿‍♀' => 'mwanamke anayetembea: ngozi nyeusi',
    '🚶🏻‍➡' => 'mtu anayetembea: ngozi nyeupe na inayoangalia kulia',
    '🚶🏼‍➡' => 'mtu anayetembea: ngozi nyeupe kiasi na inayoangalia kulia',
    '🚶🏽‍➡' => 'mtu anayetembea: ngozi ya kahawia na inayoangalia kulia',
    '🚶🏾‍➡' => 'mtu anayetembea: ngozi nyeusi kiasi na inayoangalia kulia',
    '🚶🏿‍➡' => 'mtu anayetembea: ngozi nyeusi na inayoangalia kulia',
    '🧍🏻‍♂' => 'mwanamume aliyesimama: ngozi nyeupe',
    '🧍🏼‍♂' => 'mwanamume aliyesimama: ngozi nyeupe kiasi',
    '🧍🏽‍♂' => 'mwanamume aliyesimama: ngozi ya kahawia',
    '🧍🏾‍♂' => 'mwanamume aliyesimama: ngozi nyeusi kiasi',
    '🧍🏿‍♂' => 'mwanamume aliyesimama: ngozi nyeusi',
    '🧍🏻‍♀' => 'mwanamke aliyesimama: ngozi nyeupe',
    '🧍🏼‍♀' => 'mwanamke aliyesimama: ngozi nyeupe kiasi',
    '🧍🏽‍♀' => 'mwanamke aliyesimama: ngozi ya kahawia',
    '🧍🏾‍♀' => 'mwanamke aliyesimama: ngozi nyeusi kiasi',
    '🧍🏿‍♀' => 'mwanamke aliyesimama: ngozi nyeusi',
    '🧎🏻‍♂' => 'mwanamume aliyepiga magoti: ngozi nyeupe',
    '🧎🏼‍♂' => 'mwanamume aliyepiga magoti: ngozi nyeupe kiasi',
    '🧎🏽‍♂' => 'mwanamume aliyepiga magoti: ngozi ya kahawia',
    '🧎🏾‍♂' => 'mwanamume aliyepiga magoti: ngozi nyeusi kiasi',
    '🧎🏿‍♂' => 'mwanamume aliyepiga magoti: ngozi nyeusi',
    '🧎🏻‍♀' => 'mwanamke aliyepiga magoti: ngozi nyeupe',
    '🧎🏼‍♀' => 'mwanamke aliyepiga magoti: ngozi nyeupe kiasi',
    '🧎🏽‍♀' => 'mwanamke aliyepiga magoti: ngozi ya kahawia',
    '🧎🏾‍♀' => 'mwanamke aliyepiga magoti: ngozi nyeusi kiasi',
    '🧎🏿‍♀' => 'mwanamke aliyepiga magoti: ngozi nyeusi',
    '🧎🏻‍➡' => 'mtu aliyepiga magoti: ngozi nyeupe na inayoangalia kulia',
    '🧎🏼‍➡' => 'mtu aliyepiga magoti: ngozi nyeupe kiasi na inayoangalia kulia',
    '🧎🏽‍➡' => 'mtu aliyepiga magoti: ngozi ya kahawia na inayoangalia kulia',
    '🧎🏾‍➡' => 'mtu aliyepiga magoti: ngozi nyeusi kiasi na inayoangalia kulia',
    '🧎🏿‍➡' => 'mtu aliyepiga magoti: ngozi nyeusi na inayoangalia kulia',
    '🧑🏻‍🦯' => 'mtu anayetembea kwa mkongojo: ngozi nyeupe',
    '🧑🏼‍🦯' => 'mtu anayetembea kwa mkongojo: ngozi nyeupe kiasi',
    '🧑🏽‍🦯' => 'mtu anayetembea kwa mkongojo: ngozi ya kahawia',
    '🧑🏾‍🦯' => 'mtu anayetembea kwa mkongojo: ngozi nyeusi kiasi',
    '🧑🏿‍🦯' => 'mtu anayetembea kwa mkongojo: ngozi nyeusi',
    '👨🏻‍🦯' => 'mwanamume anayetembea kwa mkongojo: ngozi nyeupe',
    '👨🏼‍🦯' => 'mwanamume anayetembea kwa mkongojo: ngozi nyeupe kiasi',
    '👨🏽‍🦯' => 'mwanamume anayetembea kwa mkongojo: ngozi ya kahawia',
    '👨🏾‍🦯' => 'mwanamume anayetembea kwa mkongojo: ngozi nyeusi kiasi',
    '👨🏿‍🦯' => 'mwanamume anayetembea kwa mkongojo: ngozi nyeusi',
    '👩🏻‍🦯' => 'mwanamke anayetembea kwa mkongojo: ngozi nyeupe',
    '👩🏼‍🦯' => 'mwanamke anayetembea kwa mkongojo: ngozi nyeupe kiasi',
    '👩🏽‍🦯' => 'mwanamke anayetembea kwa mkongojo: ngozi ya kahawia',
    '👩🏾‍🦯' => 'mwanamke anayetembea kwa mkongojo: ngozi nyeusi kiasi',
    '👩🏿‍🦯' => 'mwanamke anayetembea kwa mkongojo: ngozi nyeusi',
    '🧑🏻‍🦼' => 'mtu aliyeketia kiti cha magurudumu: ngozi nyeupe',
    '🧑🏼‍🦼' => 'mtu aliyeketia kiti cha magurudumu: ngozi nyeupe kiasi',
    '🧑🏽‍🦼' => 'mtu aliyeketia kiti cha magurudumu: ngozi ya kahawia',
    '🧑🏾‍🦼' => 'mtu aliyeketia kiti cha magurudumu: ngozi nyeusi kiasi',
    '🧑🏿‍🦼' => 'mtu aliyeketia kiti cha magurudumu: ngozi nyeusi',
    '👨🏻‍🦼' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi nyeupe',
    '👨🏼‍🦼' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi nyeupe kiasi',
    '👨🏽‍🦼' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi ya kahawia',
    '👨🏾‍🦼' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi nyeusi kiasi',
    '👨🏿‍🦼' => 'Mtu aliyeketi kwenye kiti cha magurudumu: ngozi nyeusi',
    '👩🏻‍🦼' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi nyeupe',
    '👩🏼‍🦼' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi nyeupe kiasi',
    '👩🏽‍🦼' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi ya kahawia',
    '👩🏾‍🦼' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi nyeusi kiasi',
    '👩🏿‍🦼' => 'mwanamke aliyeketia kiti cha magurudumu: ngozi nyeusi',
    '🧑🏻‍🦽' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe',
    '🧑🏼‍🦽' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe kiasi',
    '🧑🏽‍🦽' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi ya kahawia',
    '🧑🏾‍🦽' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi kiasi',
    '🧑🏿‍🦽' => 'mtu anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi',
    '👨🏻‍🦽' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe',
    '👨🏼‍🦽' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe kiasi',
    '👨🏽‍🦽' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi ya kahawia',
    '👨🏾‍🦽' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi kiasi',
    '👨🏿‍🦽' => 'mwanamume anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi',
    '👩🏻‍🦽' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe',
    '👩🏼‍🦽' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi nyeupe kiasi',
    '👩🏽‍🦽' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi ya kahawia',
    '👩🏾‍🦽' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi kiasi',
    '👩🏿‍🦽' => 'mwanamke anayejiendesha kwa kiti cha magurudumu: ngozi nyeusi',
    '🏃🏻‍♂' => 'mwanamume anayekimbia: ngozi nyeupe',
    '🏃🏼‍♂' => 'mwanamume anayekimbia: ngozi nyeupe kiasi',
    '🏃🏽‍♂' => 'mwanamume anayekimbia: ngozi ya kahawia',
    '🏃🏾‍♂' => 'mwanamume anayekimbia: ngozi nyeusi kiasi',
    '🏃🏿‍♂' => 'mwanamume anayekimbia: ngozi nyeusi',
    '🏃🏻‍♀' => 'mwanamke anayekimbia: ngozi nyeupe',
    '🏃🏼‍♀' => 'mwanamke anayekimbia: ngozi nyeupe kiasi',
    '🏃🏽‍♀' => 'mwanamke anayekimbia: ngozi ya kahawia',
    '🏃🏾‍♀' => 'mwanamke anayekimbia: ngozi nyeusi kiasi',
    '🏃🏿‍♀' => 'mwanamke anayekimbia: ngozi nyeusi',
    '🏃🏻‍➡' => 'mkimbiaji: ngozi nyeupe na inayoangalia kulia',
    '🏃🏼‍➡' => 'mkimbiaji: ngozi nyeupe kiasi na inayoangalia kulia',
    '🏃🏽‍➡' => 'mkimbiaji: ngozi ya kahawia na inayoangalia kulia',
    '🏃🏾‍➡' => 'mkimbiaji: ngozi nyeusi kiasi na inayoangalia kulia',
    '🏃🏿‍➡' => 'mkimbiaji: ngozi nyeusi na inayoangalia kulia',
    '👯🏻‍♀' => 'wanawake wanaosherehekea: ngozi nyeupe',
    '👯🏼‍♀' => 'wanawake wanaosherehekea: ngozi nyeupe kiasi',
    '👯🏽‍♀' => 'wanawake wanaosherehekea: ngozi ya kahawia',
    '👯🏾‍♀' => 'wanawake wanaosherehekea: ngozi nyeusi kiasi',
    '👯🏿‍♀' => 'wanawake wanaosherehekea: ngozi nyeusi',
    '👯🏻‍♂' => 'wanaume wanaosherehekea: ngozi nyeupe',
    '👯🏼‍♂' => 'wanaume wanaosherehekea: ngozi nyeupe kiasi',
    '👯🏽‍♂' => 'wanaume wanaosherehekea: ngozi ya kahawia',
    '👯🏾‍♂' => 'wanaume wanaosherehekea: ngozi nyeusi kiasi',
    '👯🏿‍♂' => 'wanaume wanaosherehekea: ngozi nyeusi',
    '🧖🏻‍♂' => 'mwanamume katika bafu la mvuke: ngozi nyeupe',
    '🧖🏼‍♂' => 'mwanamume katika bafu la mvuke: ngozi nyeupe kiasi',
    '🧖🏽‍♂' => 'mwanamume katika bafu la mvuke: ngozi ya kahawia',
    '🧖🏾‍♂' => 'mwanamume katika bafu la mvuke: ngozi nyeusi kiasi',
    '🧖🏿‍♂' => 'mwanamume katika bafu la mvuke: ngozi nyeusi',
    '🧖🏻‍♀' => 'mwanamke katika bafu la mvuke: ngozi nyeupe',
    '🧖🏼‍♀' => 'mwanamke katika bafu la mvuke: ngozi nyeupe kiasi',
    '🧖🏽‍♀' => 'mwanamke katika bafu la mvuke: ngozi ya kahawia',
    '🧖🏾‍♀' => 'mwanamke katika bafu la mvuke: ngozi nyeusi kiasi',
    '🧖🏿‍♀' => 'mwanamke katika bafu la mvuke: ngozi nyeusi',
    '🧗🏻‍♂' => 'mwanamume anayekwea: ngozi nyeupe',
    '🧗🏼‍♂' => 'mwanamume anayekwea: ngozi nyeupe kiasi',
    '🧗🏽‍♂' => 'mwanamume anayekwea: ngozi ya kahawia',
    '🧗🏾‍♂' => 'mwanamume anayekwea: ngozi nyeusi kiasi',
    '🧗🏿‍♂' => 'mwanamume anayekwea: ngozi nyeusi',
    '🧗🏻‍♀' => 'mwanamke anayekwea: ngozi nyeupe',
    '🧗🏼‍♀' => 'mwanamke anayekwea: ngozi nyeupe kiasi',
    '🧗🏽‍♀' => 'mwanamke anayekwea: ngozi ya kahawia',
    '🧗🏾‍♀' => 'mwanamke anayekwea: ngozi nyeusi kiasi',
    '🧗🏿‍♀' => 'mwanamke anayekwea: ngozi nyeusi',
    '🏌🏻‍♂' => 'mwanamume anayecheza gofu: ngozi nyeupe',
    '🏌🏼‍♂' => 'mwanamume anayecheza gofu: ngozi nyeupe kiasi',
    '🏌🏽‍♂' => 'mwanamume anayecheza gofu: ngozi ya kahawia',
    '🏌🏾‍♂' => 'mwanamume anayecheza gofu: ngozi nyeusi kiasi',
    '🏌🏿‍♂' => 'mwanamume anayecheza gofu: ngozi nyeusi',
    '🏌🏻‍♀' => 'mwanamke anayecheza gofu: ngozi nyeupe',
    '🏌🏼‍♀' => 'mwanamke anayecheza gofu: ngozi nyeupe kiasi',
    '🏌🏽‍♀' => 'mwanamke anayecheza gofu: ngozi ya kahawia',
    '🏌🏾‍♀' => 'mwanamke anayecheza gofu: ngozi nyeusi kiasi',
    '🏌🏿‍♀' => 'mwanamke anayecheza gofu: ngozi nyeusi',
    '🏄🏻‍♂' => 'mwanamume anayeteleza kwenye mawimbi: ngozi nyeupe',
    '🏄🏼‍♂' => 'mwanamume anayeteleza kwenye mawimbi: ngozi nyeupe kiasi',
    '🏄🏽‍♂' => 'mwanamume anayeteleza kwenye mawimbi: ngozi ya kahawia',
    '🏄🏾‍♂' => 'mwanamume anayeteleza kwenye mawimbi: ngozi nyeusi kiasi',
    '🏄🏿‍♂' => 'mwanamume anayeteleza kwenye mawimbi: ngozi nyeusi',
    '🏄🏻‍♀' => 'mwanamke anayeteleza kwenye mawimbi: ngozi nyeupe',
    '🏄🏼‍♀' => 'mwanamke anayeteleza kwenye mawimbi: ngozi nyeupe kiasi',
    '🏄🏽‍♀' => 'mwanamke anayeteleza kwenye mawimbi: ngozi ya kahawia',
    '🏄🏾‍♀' => 'mwanamke anayeteleza kwenye mawimbi: ngozi nyeusi kiasi',
    '🏄🏿‍♀' => 'mwanamke anayeteleza kwenye mawimbi: ngozi nyeusi',
    '🚣🏻‍♂' => 'mwanamume anayeendesha ngalawa: ngozi nyeupe',
    '🚣🏼‍♂' => 'mwanamume anayeendesha ngalawa: ngozi nyeupe kiasi',
    '🚣🏽‍♂' => 'mwanamume anayeendesha ngalawa: ngozi ya kahawia',
    '🚣🏾‍♂' => 'mwanamume anayeendesha ngalawa: ngozi nyeusi kiasi',
    '🚣🏿‍♂' => 'mwanamume anayeendesha ngalawa: ngozi nyeusi',
    '🚣🏻‍♀' => 'mwanamke anayeendesha ngalawa: ngozi nyeupe',
    '🚣🏼‍♀' => 'mwanamke anayeendesha ngalawa: ngozi nyeupe kiasi',
    '🚣🏽‍♀' => 'mwanamke anayeendesha ngalawa: ngozi ya kahawia',
    '🚣🏾‍♀' => 'mwanamke anayeendesha ngalawa: ngozi nyeusi kiasi',
    '🚣🏿‍♀' => 'mwanamke anayeendesha ngalawa: ngozi nyeusi',
    '🏊🏻‍♂' => 'mwanaume anayeogelea: ngozi nyeupe',
    '🏊🏼‍♂' => 'mwanaume anayeogelea: ngozi nyeupe kiasi',
    '🏊🏽‍♂' => 'mwanaume anayeogelea: ngozi ya kahawia',
    '🏊🏾‍♂' => 'mwanaume anayeogelea: ngozi nyeusi kiasi',
    '🏊🏿‍♂' => 'mwanaume anayeogelea: ngozi nyeusi',
    '🏊🏻‍♀' => 'mwanamke anayeogelea: ngozi nyeupe',
    '🏊🏼‍♀' => 'mwanamke anayeogelea: ngozi nyeupe kiasi',
    '🏊🏽‍♀' => 'mwanamke anayeogelea: ngozi ya kahawia',
    '🏊🏾‍♀' => 'mwanamke anayeogelea: ngozi nyeusi kiasi',
    '🏊🏿‍♀' => 'mwanamke anayeogelea: ngozi nyeusi',
    '⛹🏻‍♂' => 'mwanaume aliye na mpira: ngozi nyeupe',
    '⛹🏼‍♂' => 'mwanaume aliye na mpira: ngozi nyeupe kiasi',
    '⛹🏽‍♂' => 'mwanaume aliye na mpira: ngozi ya kahawia',
    '⛹🏾‍♂' => 'mwanaume aliye na mpira: ngozi nyeusi kiasi',
    '⛹🏿‍♂' => 'mwanaume aliye na mpira: ngozi nyeusi',
    '⛹🏻‍♀' => 'mwanamke aliye na mpira: ngozi nyeupe',
    '⛹🏼‍♀' => 'mwanamke aliye na mpira: ngozi nyeupe kiasi',
    '⛹🏽‍♀' => 'mwanamke aliye na mpira: ngozi ya kahawia',
    '⛹🏾‍♀' => 'mwanamke aliye na mpira: ngozi nyeusi kiasi',
    '⛹🏿‍♀' => 'mwanamke aliye na mpira: ngozi nyeusi',
    '🏋🏻‍♂' => 'mwanamume anayebeba vyuma vizito: ngozi nyeupe',
    '🏋🏼‍♂' => 'mwanamume anayebeba vyuma vizito: ngozi nyeupe kiasi',
    '🏋🏽‍♂' => 'mwanamume anayebeba vyuma vizito: ngozi ya kahawia',
    '🏋🏾‍♂' => 'mwanamume anayebeba vyuma vizito: ngozi nyeusi kiasi',
    '🏋🏿‍♂' => 'mwanamume anayebeba vyuma vizito: ngozi nyeusi',
    '🏋🏻‍♀' => 'mwanamke anayebeba vyuma vizito: ngozi nyeupe',
    '🏋🏼‍♀' => 'mwanamke anayebeba vyuma vizito: ngozi nyeupe kiasi',
    '🏋🏽‍♀' => 'mwanamke anayebeba vyuma vizito: ngozi ya kahawia',
    '🏋🏾‍♀' => 'mwanamke anayebeba vyuma vizito: ngozi nyeusi kiasi',
    '🏋🏿‍♀' => 'mwanamke anayebeba vyuma vizito: ngozi nyeusi',
    '🚴🏻‍♂' => 'mwanaume anayeendesha baisikeli: ngozi nyeupe',
    '🚴🏼‍♂' => 'mwanaume anayeendesha baisikeli: ngozi nyeupe kiasi',
    '🚴🏽‍♂' => 'mwanaume anayeendesha baisikeli: ngozi ya kahawia',
    '🚴🏾‍♂' => 'mwanaume anayeendesha baisikeli: ngozi nyeusi kiasi',
    '🚴🏿‍♂' => 'mwanaume anayeendesha baisikeli: ngozi nyeusi',
    '🚴🏻‍♀' => 'mwanamke anayeendesha baisikeli: ngozi nyeupe',
    '🚴🏼‍♀' => 'mwanamke anayeendesha baisikeli: ngozi nyeupe kiasi',
    '🚴🏽‍♀' => 'mwanamke anayeendesha baisikeli: ngozi ya kahawia',
    '🚴🏾‍♀' => 'mwanamke anayeendesha baisikeli: ngozi nyeusi kiasi',
    '🚴🏿‍♀' => 'mwanamke anayeendesha baisikeli: ngozi nyeusi',
    '🚵🏻‍♂' => 'Mtu anayeendesha baiskeli mlimani: ngozi nyeupe',
    '🚵🏼‍♂' => 'Mtu anayeendesha baiskeli mlimani: ngozi nyeupe kiasi',
    '🚵🏽‍♂' => 'Mtu anayeendesha baiskeli mlimani: ngozi ya kahawia',
    '🚵🏾‍♂' => 'Mtu anayeendesha baiskeli mlimani: ngozi nyeusi kiasi',
    '🚵🏿‍♂' => 'Mtu anayeendesha baiskeli mlimani: ngozi nyeusi',
    '🚵🏻‍♀' => 'mwanamke anayeendesha baiskeli mlimani: ngozi nyeupe',
    '🚵🏼‍♀' => 'mwanamke anayeendesha baiskeli mlimani: ngozi nyeupe kiasi',
    '🚵🏽‍♀' => 'mwanamke anayeendesha baiskeli mlimani: ngozi ya kahawia',
    '🚵🏾‍♀' => 'mwanamke anayeendesha baiskeli mlimani: ngozi nyeusi kiasi',
    '🚵🏿‍♀' => 'mwanamke anayeendesha baiskeli mlimani: ngozi nyeusi',
    '🤸🏻‍♂' => 'mwanamume anayefanya sarakasi: ngozi nyeupe',
    '🤸🏼‍♂' => 'mwanamume anayefanya sarakasi: ngozi nyeupe kiasi',
    '🤸🏽‍♂' => 'mwanamume anayefanya sarakasi: ngozi ya kahawia',
    '🤸🏾‍♂' => 'mwanamume anayefanya sarakasi: ngozi nyeusi kiasi',
    '🤸🏿‍♂' => 'mwanamume anayefanya sarakasi: ngozi nyeusi',
    '🤸🏻‍♀' => 'mwanamke anayefanya sarakasi: ngozi nyeupe',
    '🤸🏼‍♀' => 'mwanamke anayefanya sarakasi: ngozi nyeupe kiasi',
    '🤸🏽‍♀' => 'mwanamke anayefanya sarakasi: ngozi ya kahawia',
    '🤸🏾‍♀' => 'mwanamke anayefanya sarakasi: ngozi nyeusi kiasi',
    '🤸🏿‍♀' => 'mwanamke anayefanya sarakasi: ngozi nyeusi',
    '🤼🏻‍♀' => 'wanawake wanaomenyana miereka: ngozi nyeupe',
    '🤼🏼‍♀' => 'wanawake wanaomenyana miereka: ngozi nyeupe kiasi',
    '🤼🏽‍♀' => 'wanawake wanaomenyana miereka: ngozi ya kahawia',
    '🤼🏾‍♀' => 'wanawake wanaomenyana miereka: ngozi nyeusi kiasi',
    '🤼🏿‍♀' => 'wanawake wanaomenyana miereka: ngozi nyeusi',
    '🤼🏻‍♂' => 'wanaume wanaomenyana miereka: ngozi nyeupe',
    '🤼🏼‍♂' => 'wanaume wanaomenyana miereka: ngozi nyeupe kiasi',
    '🤼🏽‍♂' => 'wanaume wanaomenyana miereka: ngozi ya kahawia',
    '🤼🏾‍♂' => 'wanaume wanaomenyana miereka: ngozi nyeusi kiasi',
    '🤼🏿‍♂' => 'wanaume wanaomenyana miereka: ngozi nyeusi',
    '🤽🏻‍♂' => 'mwanamume anayecheza mpira wa mikono majini: ngozi nyeupe',
    '🤽🏼‍♂' => 'mwanamume anayecheza mpira wa mikono majini: ngozi nyeupe kiasi',
    '🤽🏽‍♂' => 'mwanamume anayecheza mpira wa mikono majini: ngozi ya kahawia',
    '🤽🏾‍♂' => 'mwanamume anayecheza mpira wa mikono majini: ngozi nyeusi kiasi',
    '🤽🏿‍♂' => 'mwanamume anayecheza mpira wa mikono majini: ngozi nyeusi',
    '🤽🏻‍♀' => 'Mtu anayecheza mpira wa mikono majini: ngozi nyeupe',
    '🤽🏼‍♀' => 'Mtu anayecheza mpira wa mikono majini: ngozi nyeupe kiasi',
    '🤽🏽‍♀' => 'Mtu anayecheza mpira wa mikono majini: ngozi ya kahawia',
    '🤽🏾‍♀' => 'Mtu anayecheza mpira wa mikono majini: ngozi nyeusi kiasi',
    '🤽🏿‍♀' => 'Mtu anayecheza mpira wa mikono majini: ngozi nyeusi',
    '🤾🏻‍♂' => 'mwanamume anayecheza mpira wa mikono: ngozi nyeupe',
    '🤾🏼‍♂' => 'mwanamume anayecheza mpira wa mikono: ngozi nyeupe kiasi',
    '🤾🏽‍♂' => 'mwanamume anayecheza mpira wa mikono: ngozi ya kahawia',
    '🤾🏾‍♂' => 'mwanamume anayecheza mpira wa mikono: ngozi nyeusi kiasi',
    '🤾🏿‍♂' => 'mwanamume anayecheza mpira wa mikono: ngozi nyeusi',
    '🤾🏻‍♀' => 'mwanamke anayecheza mpira wa mikono: ngozi nyeupe',
    '🤾🏼‍♀' => 'mwanamke anayecheza mpira wa mikono: ngozi nyeupe kiasi',
    '🤾🏽‍♀' => 'mwanamke anayecheza mpira wa mikono: ngozi ya kahawia',
    '🤾🏾‍♀' => 'mwanamke anayecheza mpira wa mikono: ngozi nyeusi kiasi',
    '🤾🏿‍♀' => 'mwanamke anayecheza mpira wa mikono: ngozi nyeusi',
    '🤹🏻‍♂' => 'Mtu anayecheza mipira mingi mkononi: ngozi nyeupe',
    '🤹🏼‍♂' => 'Mtu anayecheza mipira mingi mkononi: ngozi nyeupe kiasi',
    '🤹🏽‍♂' => 'Mtu anayecheza mipira mingi mkononi: ngozi ya kahawia',
    '🤹🏾‍♂' => 'Mtu anayecheza mipira mingi mkononi: ngozi nyeusi kiasi',
    '🤹🏿‍♂' => 'Mtu anayecheza mipira mingi mkononi: ngozi nyeusi',
    '🤹🏻‍♀' => 'Mtu anayecheza mipira mingi mikononi: ngozi nyeupe',
    '🤹🏼‍♀' => 'Mtu anayecheza mipira mingi mikononi: ngozi nyeupe kiasi',
    '🤹🏽‍♀' => 'Mtu anayecheza mipira mingi mikononi: ngozi ya kahawia',
    '🤹🏾‍♀' => 'Mtu anayecheza mipira mingi mikononi: ngozi nyeusi kiasi',
    '🤹🏿‍♀' => 'Mtu anayecheza mipira mingi mikononi: ngozi nyeusi',
    '🧘🏻‍♂' => 'mwanamume anayetaamali: ngozi nyeupe',
    '🧘🏼‍♂' => 'mwanamume anayetaamali: ngozi nyeupe kiasi',
    '🧘🏽‍♂' => 'mwanamume anayetaamali: ngozi ya kahawia',
    '🧘🏾‍♂' => 'mwanamume anayetaamali: ngozi nyeusi kiasi',
    '🧘🏿‍♂' => 'mwanamume anayetaamali: ngozi nyeusi',
    '🧘🏻‍♀' => 'mwanamke anayetaamali: ngozi nyeupe',
    '🧘🏼‍♀' => 'mwanamke anayetaamali: ngozi nyeupe kiasi',
    '🧘🏽‍♀' => 'mwanamke anayetaamali: ngozi ya kahawia',
    '🧘🏾‍♀' => 'mwanamke anayetaamali: ngozi nyeusi kiasi',
    '🧘🏿‍♀' => 'mwanamke anayetaamali: ngozi nyeusi',
    '🧑‍🦰' => 'mtu mzima: nywele nyekundu',
    '🧑‍🦱' => 'mtu mzima: nywele yenye mawimbi',
    '🧑‍🦳' => 'mtu mzima: nywele nyeupe',
    '🧑‍🦲' => 'mtu mzima: upara',
    '👨‍🦰' => 'mwanamume: nywele nyekundu',
    '👨‍🦱' => 'mwanamume: nywele yenye mawimbi',
    '👨‍🦳' => 'mwanamume: nywele nyeupe',
    '👨‍🦲' => 'mwanamume: upara',
    '👩‍🦰' => 'mwanamke: nywele nyekundu',
    '👩‍🦱' => 'mwanamke: nywele yenye mawimbi',
    '👩‍🦳' => 'mwanamke: nywele nyeupe',
    '👩‍🦲' => 'mwanamke: upara',
    '🚶‍➡' => 'mtu anayetembea: inayoangalia kulia',
    '🧎‍➡' => 'mtu aliyepiga magoti: inayoangalia kulia',
    '🏃‍➡' => 'mkimbiaji: inayoangalia kulia',
    '👨‍👦' => 'familia: mwanamume na mvulana',
    '👨‍👧' => 'familia: mwanamume na msichana',
    '👩‍👦' => 'familia: mwanamke na mvulana',
    '👩‍👧' => 'familia: mwanamke na msichana',
    '😶‍🌫' => 'uso kwenye mawingu',
    '😮‍💨' => 'uso unaopumua',
    '🙂‍↕' => 'kutikisa kichwa juu chini',
    '😵‍💫' => 'uso wenye macho yanayozunguka',
    '❤‍🔥' => 'moyo unaochomeka',
    '❤‍🩹' => 'kurekebisha moyo',
    '👁‍🗨' => 'jicho ndani ya puto la usemi unaoelekea kulia',
    '🧔‍♂' => 'mwanamume: ndevu',
    '👱‍♂' => 'mwanamume mwenye nywele ya kimanjano',
    '🧔‍♀' => 'mwanamke: ndevu',
    '👱‍♀' => 'mwanamke mwenye nywele ya kimanjano',
    '🙍‍♂' => 'mwanamume anayekunja kipaji cha uso',
    '🙍‍♀' => 'mwanamke anayekunja kipaji cha uso',
    '🙎‍♂' => 'mwanamume anayebibidua midomo',
    '🙎‍♀' => 'mwanamke anayebibidua midomo',
    '🙅‍♂' => 'Mtu anayeonyesha ishara ya HAPANA',
    '🙅‍♀' => 'mwanamke anayeonyesha ishara ya kukataa',
    '🙆‍♂' => 'Mtu anayeonyesha ishara ya NDIO',
    '🙆‍♀' => 'mwanamke anayeonyesha ishara ya kukubali',
    '💁‍♂' => 'mwanamume anayetoa maelezo',
    '💁‍♀' => 'mwanamke anayetoa maelezo',
    '🙋‍♂' => 'mtu aliyeinua mkono',
    '🙋‍♀' => 'mwanamke mwenye furaha aliyeinua mnoko',
    '🧏‍♂' => 'mwanamume kiziwi',
    '🧏‍♀' => 'mwanamke kiziwi',
    '🙇‍♂' => 'mwanamume aliyeinama',
    '🙇‍♀' => 'mwanamke aliyeinama',
    '🤦‍♂' => 'mwanamume anayeashiria kutoamini',
    '🤦‍♀' => 'mwanamke anayeashiria kutoamini',
    '🤷‍♂' => 'mwanamume anayeashiria kutojali',
    '🤷‍♀' => 'mwanamke anayeashiria kutojali',
    '🧑‍⚕' => 'mhudumu wa afya',
    '👨‍⚕' => 'mhudumu wa afya wa kiume',
    '👩‍⚕' => 'mhudumu wa afya wa kike',
    '🧑‍🎓' => 'mwanafunzi',
    '👨‍🎓' => 'mwanafunzi na kofia ya kufuzu',
    '👩‍🎓' => 'mwanafunzi wa kike na kofia ya kufuzu',
    '🧑‍🏫' => 'mwalimu',
    '👨‍🏫' => 'mwalimu na ubao',
    '👩‍🏫' => 'mwalimu wa kike na ubao',
    '🧑‍⚖' => 'hakimu',
    '👨‍⚖' => 'jaji wa kiume',
    '👩‍⚖' => 'jaji wa kike',
    '🧑‍🌾' => 'mkulima',
    '👨‍🌾' => 'mkulima wa kiume',
    '👩‍🌾' => 'mkulima wa kike',
    '🧑‍🍳' => 'mpishi',
    '👨‍🍳' => 'mpishi wa kiume',
    '👩‍🍳' => 'mpishi wa kike',
    '🧑‍🔧' => 'makanika',
    '👨‍🔧' => 'fundi mitambo wa kiume',
    '👩‍🔧' => 'fundi mitambo wa kike',
    '🧑‍🏭' => 'mfanyakazi wa kiwanda',
    '👨‍🏭' => 'mwanamume na gesi ya kuchoma',
    '👩‍🏭' => 'mwanamke na gesi ya kuchoma',
    '🧑‍💼' => 'mfanyakazi wa ofisi',
    '👨‍💼' => 'mwanamume aliyevaa nadhifu',
    '👩‍💼' => 'mwanamke aliyevaa nadhifu',
    '🧑‍🔬' => 'mwanasayansi',
    '👨‍🔬' => 'mwanasayansi wa kiume',
    '👩‍🔬' => 'mwanasayansi wa kike',
    '🧑‍💻' => 'mwanateknolojia',
    '👨‍💻' => 'mwanateknolojia wa kiume',
    '👩‍💻' => 'mwanateknolojia wa kike',
    '🧑‍🎤' => 'mwimbaji',
    '👨‍🎤' => 'mwimbaji wa kiume',
    '👩‍🎤' => 'mwimbaji wa kike',
    '🧑‍🎨' => 'mchoraji',
    '👨‍🎨' => 'mchoraji wa kiume',
    '👩‍🎨' => 'mchoraji wa kike',
    '🧑‍✈' => 'rubani',
    '👨‍✈' => 'rubani wa kiume',
    '👩‍✈' => 'rubani wa kike',
    '🧑‍🚀' => 'mwanaanga',
    '👨‍🚀' => 'mwanaanga wa kiume',
    '👩‍🚀' => 'mwanaanga wa kike',
    '🧑‍🚒' => 'mzimamoto',
    '👨‍🚒' => 'mzimamoto wa kiume',
    '👩‍🚒' => 'mzimamoto wa kike',
    '👮‍♂' => 'polisi wa kiume',
    '👮‍♀' => 'polisi wa kike',
    '🕵‍♂' => 'jasusi mwanamume',
    '🕵‍♀' => 'jasusi mwanamke',
    '💂‍♂' => 'mlinzi mwanamume',
    '💂‍♀' => 'mlinzi wa kike',
    '👷‍♂' => 'mjenzi mwanamume',
    '👷‍♀' => 'mjenzi wa kike',
    '👳‍♂' => 'mwanamume aliyefunga kilemba',
    '👳‍♀' => 'mwanamke aliyefunga kilemba',
    '🤵‍♂' => 'mwanamume aliyevalia tuxedo',
    '🤵‍♀' => 'mwanamke aliyevalia tuxedo',
    '👰‍♂' => 'mwanamume aliyevalia shela',
    '👰‍♀' => 'mwanamke aliyevalia shela',
    '👩‍🍼' => 'mwanamke anayemlisha mtoto',
    '👨‍🍼' => 'mwanamume anayemlisha mtoto',
    '🧑‍🍼' => 'mtu anamyelisha mtoto',
    '🧑‍🎄' => 'kichimbakazi yeyote',
    '🦸‍♂' => 'shujaa wa kiume',
    '🦸‍♀' => 'shujaa wa kike',
    '🦹‍♂' => 'jambazi wa kiume',
    '🦹‍♀' => 'jambazi wa kike',
    '🧙‍♂' => 'mchawi wa kiume',
    '🧙‍♀' => 'mlozi wa kike',
    '🧚‍♂' => 'kichimbakazi wa kiume',
    '🧚‍♀' => 'kichimbakazi wa kike',
    '🧛‍♂' => 'mnyonya damu wa kiume',
    '🧛‍♀' => 'mnyonya damu wa kike',
    '🧜‍♂' => 'nguva dume',
    '🧜‍♀' => 'nguva',
    '🧝‍♂' => 'kibwengo dume',
    '🧝‍♀' => 'kibwengo cha kike',
    '🧞‍♂' => 'jini dume',
    '🧞‍♀' => 'jini la kike',
    '🧟‍♂' => 'dubwana dume',
    '🧟‍♀' => 'dubwana jike',
    '💆‍♂' => 'mwanamume anayekandwa uso',
    '💆‍♀' => 'mwanamke anayekandwa uso',
    '💇‍♂' => 'mwanamume anayenyolewa nywele',
    '💇‍♀' => 'mwanamke anayenyolewa nywele',
    '🚶‍♂' => 'mwanamume anayetembea',
    '🚶‍♀' => 'mwanamke anayetembea',
    '🧍‍♂' => 'mwanamume aliyesimama',
    '🧍‍♀' => 'mwanamke aliyesimama',
    '🧎‍♂' => 'mwanamume aliyepiga magoti',
    '🧎‍♀' => 'mwanamke aliyepiga magoti',
    '🧑‍🦯' => 'mtu anayetembea kwa mkongojo',
    '👨‍🦯' => 'mwanamume anayetembea kwa mkongojo',
    '👩‍🦯' => 'mwanamke anayetembea kwa mkongojo',
    '🧑‍🦼' => 'mtu aliyeketia kiti cha magurudumu',
    '👨‍🦼' => 'Mtu aliyeketi kwenye kiti cha magurudumu',
    '👩‍🦼' => 'mwanamke aliyeketia kiti cha magurudumu',
    '🧑‍🦽' => 'mtu anayejiendesha kwa kiti cha magurudumu',
    '👨‍🦽' => 'mwanamume anayejiendesha kwa kiti cha magurudumu',
    '👩‍🦽' => 'mwanamke anayejiendesha kwa kiti cha magurudumu',
    '🏃‍♂' => 'mwanamume anayekimbia',
    '🏃‍♀' => 'mwanamke anayekimbia',
    '🧑‍🩰' => 'mcheza bale',
    '👯‍♂' => 'wanaume wanaosherehekea',
    '👯‍♀' => 'wanawake wanaosherehekea',
    '🧖‍♂' => 'mwanamume katika bafu la mvuke',
    '🧖‍♀' => 'mwanamke katika bafu la mvuke',
    '🧗‍♂' => 'mwanamume anayekwea',
    '🧗‍♀' => 'mwanamke anayekwea',
    '🏌‍♂' => 'mwanamume anayecheza gofu',
    '🏌‍♀' => 'mwanamke anayecheza gofu',
    '🏄‍♂' => 'mwanamume anayeteleza kwenye mawimbi',
    '🏄‍♀' => 'mwanamke anayeteleza kwenye mawimbi',
    '🚣‍♂' => 'mwanamume anayeendesha ngalawa',
    '🚣‍♀' => 'mwanamke anayeendesha ngalawa',
    '🏊‍♂' => 'mwanaume anayeogelea',
    '🏊‍♀' => 'mwanamke anayeogelea',
    '⛹‍♂' => 'mwanaume aliye na mpira',
    '⛹‍♀' => 'mwanamke aliye na mpira',
    '🏋‍♂' => 'mwanamume anayebeba vyuma vizito',
    '🏋‍♀' => 'mwanamke anayebeba vyuma vizito',
    '🚴‍♂' => 'mwanaume anayeendesha baisikeli',
    '🚴‍♀' => 'mwanamke anayeendesha baisikeli',
    '🚵‍♂' => 'Mtu anayeendesha baiskeli mlimani',
    '🚵‍♀' => 'mwanamke anayeendesha baiskeli mlimani',
    '🤸‍♂' => 'mwanamume anayefanya sarakasi',
    '🤸‍♀' => 'mwanamke anayefanya sarakasi',
    '🤼‍♂' => 'wanaume wanaomenyana miereka',
    '🤼‍♀' => 'wanawake wanaomenyana miereka',
    '🤽‍♂' => 'mwanamume anayecheza mpira wa mikono majini',
    '🤽‍♀' => 'Mtu anayecheza mpira wa mikono majini',
    '🤾‍♂' => 'mwanamume anayecheza mpira wa mikono',
    '🤾‍♀' => 'mwanamke anayecheza mpira wa mikono',
    '🤹‍♂' => 'Mtu anayecheza mipira mingi mkononi',
    '🤹‍♀' => 'Mtu anayecheza mipira mingi mikononi',
    '🧘‍♂' => 'mwanamume anayetaamali',
    '🧘‍♀' => 'mwanamke anayetaamali',
    '🧑‍🧒' => 'familia: mtu mzima, mtoto',
    '🐕‍🦺' => 'mbwa msaidizi',
    '🐈‍⬛' => 'paka mweusi',
    '🐻‍❄' => 'dubu barafu',
    '🐦‍⬛' => 'ndege mweusi',
    '🐦‍🔥' => 'finiksi',
    '🍋‍🟩' => 'ndimu',
    '🍄‍🟫' => 'uyoga kahawia',
    '⛓‍💥' => 'myororo uliokatika',
    '🏳‍🌈' => 'bendera ya upinde wa mvua',
    '🏳‍⚧' => 'bendera ya wageuza jinsia',
    '🏴‍☠' => 'bendera ya maharamia',
    '👋🏻' => 'mkono unaopunga: ngozi nyeupe',
    '👋🏼' => 'mkono unaopunga: ngozi nyeupe kiasi',
    '👋🏽' => 'mkono unaopunga: ngozi ya kahawia',
    '👋🏾' => 'mkono unaopunga: ngozi nyeusi kiasi',
    '👋🏿' => 'mkono unaopunga: ngozi nyeusi',
    '🤚🏻' => 'kuinua mkono: ngozi nyeupe',
    '🤚🏼' => 'kuinua mkono: ngozi nyeupe kiasi',
    '🤚🏽' => 'kuinua mkono: ngozi ya kahawia',
    '🤚🏾' => 'kuinua mkono: ngozi nyeusi kiasi',
    '🤚🏿' => 'kuinua mkono: ngozi nyeusi',
    '🖐🏻' => 'mkono ulioinuliwa wenye vidole vilivyotanuliwa: ngozi nyeupe',
    '🖐🏼' => 'mkono ulioinuliwa wenye vidole vilivyotanuliwa: ngozi nyeupe kiasi',
    '🖐🏽' => 'mkono ulioinuliwa wenye vidole vilivyotanuliwa: ngozi ya kahawia',
    '🖐🏾' => 'mkono ulioinuliwa wenye vidole vilivyotanuliwa: ngozi nyeusi kiasi',
    '🖐🏿' => 'mkono ulioinuliwa wenye vidole vilivyotanuliwa: ngozi nyeusi',
    '✋🏻' => 'mkono ulioinuliwa: ngozi nyeupe',
    '✋🏼' => 'mkono ulioinuliwa: ngozi nyeupe kiasi',
    '✋🏽' => 'mkono ulioinuliwa: ngozi ya kahawia',
    '✋🏾' => 'mkono ulioinuliwa: ngozi nyeusi kiasi',
    '✋🏿' => 'mkono ulioinuliwa: ngozi nyeusi',
    '🖖🏻' => 'ishara ya vulkani: ngozi nyeupe',
    '🖖🏼' => 'ishara ya vulkani: ngozi nyeupe kiasi',
    '🖖🏽' => 'ishara ya vulkani: ngozi ya kahawia',
    '🖖🏾' => 'ishara ya vulkani: ngozi nyeusi kiasi',
    '🖖🏿' => 'ishara ya vulkani: ngozi nyeusi',
    '🫱🏻' => 'mkono unaoelekea kulia: ngozi nyeupe',
    '🫱🏼' => 'mkono unaoelekea kulia: ngozi nyeupe kiasi',
    '🫱🏽' => 'mkono unaoelekea kulia: ngozi ya kahawia',
    '🫱🏾' => 'mkono unaoelekea kulia: ngozi nyeusi kiasi',
    '🫱🏿' => 'mkono unaoelekea kulia: ngozi nyeusi',
    '🫲🏻' => 'mkono unaoelekea kushoto: ngozi nyeupe',
    '🫲🏼' => 'mkono unaoelekea kushoto: ngozi nyeupe kiasi',
    '🫲🏽' => 'mkono unaoelekea kushoto: ngozi ya kahawia',
    '🫲🏾' => 'mkono unaoelekea kushoto: ngozi nyeusi kiasi',
    '🫲🏿' => 'mkono unaoelekea kushoto: ngozi nyeusi',
    '🫳🏻' => 'mkono wenye kiganja kinachoelekea chini: ngozi nyeupe',
    '🫳🏼' => 'mkono wenye kiganja kinachoelekea chini: ngozi nyeupe kiasi',
    '🫳🏽' => 'mkono wenye kiganja kinachoelekea chini: ngozi ya kahawia',
    '🫳🏾' => 'mkono wenye kiganja kinachoelekea chini: ngozi nyeusi kiasi',
    '🫳🏿' => 'mkono wenye kiganja kinachoelekea chini: ngozi nyeusi',
    '🫴🏻' => 'mkono wenye kiganja kinachoelekea juu: ngozi nyeupe',
    '🫴🏼' => 'mkono wenye kiganja kinachoelekea juu: ngozi nyeupe kiasi',
    '🫴🏽' => 'mkono wenye kiganja kinachoelekea juu: ngozi ya kahawia',
    '🫴🏾' => 'mkono wenye kiganja kinachoelekea juu: ngozi nyeusi kiasi',
    '🫴🏿' => 'mkono wenye kiganja kinachoelekea juu: ngozi nyeusi',
    '🫷🏻' => 'mkono unaosukuma kushoto: ngozi nyeupe',
    '🫷🏼' => 'mkono unaosukuma kushoto: ngozi nyeupe kiasi',
    '🫷🏽' => 'mkono unaosukuma kushoto: ngozi ya kahawia',
    '🫷🏾' => 'mkono unaosukuma kushoto: ngozi nyeusi kiasi',
    '🫷🏿' => 'mkono unaosukuma kushoto: ngozi nyeusi',
    '🫸🏻' => 'mkono unaosukuma kulia: ngozi nyeupe',
    '🫸🏼' => 'mkono unaosukuma kulia: ngozi nyeupe kiasi',
    '🫸🏽' => 'mkono unaosukuma kulia: ngozi ya kahawia',
    '🫸🏾' => 'mkono unaosukuma kulia: ngozi nyeusi kiasi',
    '🫸🏿' => 'mkono unaosukuma kulia: ngozi nyeusi',
    '👌🏻' => 'mkono wa kuonyesha mambo yako shwari: ngozi nyeupe',
    '👌🏼' => 'mkono wa kuonyesha mambo yako shwari: ngozi nyeupe kiasi',
    '👌🏽' => 'mkono wa kuonyesha mambo yako shwari: ngozi ya kahawia',
    '👌🏾' => 'mkono wa kuonyesha mambo yako shwari: ngozi nyeusi kiasi',
    '👌🏿' => 'mkono wa kuonyesha mambo yako shwari: ngozi nyeusi',
    '🤌🏻' => 'mkono wenye vidole vinavyobana: ngozi nyeupe',
    '🤌🏼' => 'mkono wenye vidole vinavyobana: ngozi nyeupe kiasi',
    '🤌🏽' => 'mkono wenye vidole vinavyobana: ngozi ya kahawia',
    '🤌🏾' => 'mkono wenye vidole vinavyobana: ngozi nyeusi kiasi',
    '🤌🏿' => 'mkono wenye vidole vinavyobana: ngozi nyeusi',
    '🤏🏻' => 'vidole vinavyobana: ngozi nyeupe',
    '🤏🏼' => 'vidole vinavyobana: ngozi nyeupe kiasi',
    '🤏🏽' => 'vidole vinavyobana: ngozi ya kahawia',
    '🤏🏾' => 'vidole vinavyobana: ngozi nyeusi kiasi',
    '🤏🏿' => 'vidole vinavyobana: ngozi nyeusi',
    '✌🏻' => 'mkono wa ushindi: ngozi nyeupe',
    '✌🏼' => 'mkono wa ushindi: ngozi nyeupe kiasi',
    '✌🏽' => 'mkono wa ushindi: ngozi ya kahawia',
    '✌🏾' => 'mkono wa ushindi: ngozi nyeusi kiasi',
    '✌🏿' => 'mkono wa ushindi: ngozi nyeusi',
    '🤞🏻' => 'ishara ya kubahatisha: ngozi nyeupe',
    '🤞🏼' => 'ishara ya kubahatisha: ngozi nyeupe kiasi',
    '🤞🏽' => 'ishara ya kubahatisha: ngozi ya kahawia',
    '🤞🏾' => 'ishara ya kubahatisha: ngozi nyeusi kiasi',
    '🤞🏿' => 'ishara ya kubahatisha: ngozi nyeusi',
    '🫰🏻' => 'vidole vya shahada na gumba vinavyopitana: ngozi nyeupe',
    '🫰🏼' => 'vidole vya shahada na gumba vinavyopitana: ngozi nyeupe kiasi',
    '🫰🏽' => 'vidole vya shahada na gumba vinavyopitana: ngozi ya kahawia',
    '🫰🏾' => 'vidole vya shahada na gumba vinavyopitana: ngozi nyeusi kiasi',
    '🫰🏿' => 'vidole vya shahada na gumba vinavyopitana: ngozi nyeusi',
    '🤟🏻' => 'ishara ya "nakupenda": ngozi nyeupe',
    '🤟🏼' => 'ishara ya "nakupenda": ngozi nyeupe kiasi',
    '🤟🏽' => 'ishara ya "nakupenda": ngozi ya kahawia',
    '🤟🏾' => 'ishara ya "nakupenda": ngozi nyeusi kiasi',
    '🤟🏿' => 'ishara ya "nakupenda": ngozi nyeusi',
    '🤘🏻' => 'ishara ya pembe: ngozi nyeupe',
    '🤘🏼' => 'ishara ya pembe: ngozi nyeupe kiasi',
    '🤘🏽' => 'ishara ya pembe: ngozi ya kahawia',
    '🤘🏾' => 'ishara ya pembe: ngozi nyeusi kiasi',
    '🤘🏿' => 'ishara ya pembe: ngozi nyeusi',
    '🤙🏻' => 'ishara ya “nipigie simu”: ngozi nyeupe',
    '🤙🏼' => 'ishara ya “nipigie simu”: ngozi nyeupe kiasi',
    '🤙🏽' => 'ishara ya “nipigie simu”: ngozi ya kahawia',
    '🤙🏾' => 'ishara ya “nipigie simu”: ngozi nyeusi kiasi',
    '🤙🏿' => 'ishara ya “nipigie simu”: ngozi nyeusi',
    '👈🏻' => 'kidole cha shahada kinachoelekeza kushoto: ngozi nyeupe',
    '👈🏼' => 'kidole cha shahada kinachoelekeza kushoto: ngozi nyeupe kiasi',
    '👈🏽' => 'kidole cha shahada kinachoelekeza kushoto: ngozi ya kahawia',
    '👈🏾' => 'kidole cha shahada kinachoelekeza kushoto: ngozi nyeusi kiasi',
    '👈🏿' => 'kidole cha shahada kinachoelekeza kushoto: ngozi nyeusi',
    '👉🏻' => 'kidole cha shahada kinachoelekeza kulia: ngozi nyeupe',
    '👉🏼' => 'kidole cha shahada kinachoelekeza kulia: ngozi nyeupe kiasi',
    '👉🏽' => 'kidole cha shahada kinachoelekeza kulia: ngozi ya kahawia',
    '👉🏾' => 'kidole cha shahada kinachoelekeza kulia: ngozi nyeusi kiasi',
    '👉🏿' => 'kidole cha shahada kinachoelekeza kulia: ngozi nyeusi',
    '👆🏻' => 'kidole cha kwanza kinachoelekeza juu kwa nyuma: ngozi nyeupe',
    '👆🏼' => 'kidole cha kwanza kinachoelekeza juu kwa nyuma: ngozi nyeupe kiasi',
    '👆🏽' => 'kidole cha kwanza kinachoelekeza juu kwa nyuma: ngozi ya kahawia',
    '👆🏾' => 'kidole cha kwanza kinachoelekeza juu kwa nyuma: ngozi nyeusi kiasi',
    '👆🏿' => 'kidole cha kwanza kinachoelekeza juu kwa nyuma: ngozi nyeusi',
    '🖕🏻' => 'kidole cha kati: ngozi nyeupe',
    '🖕🏼' => 'kidole cha kati: ngozi nyeupe kiasi',
    '🖕🏽' => 'kidole cha kati: ngozi ya kahawia',
    '🖕🏾' => 'kidole cha kati: ngozi nyeusi kiasi',
    '🖕🏿' => 'kidole cha kati: ngozi nyeusi',
    '👇🏻' => 'kidole cha kwanza kinachoelekeza chini kwa nyuma: ngozi nyeupe',
    '👇🏼' => 'kidole cha kwanza kinachoelekeza chini kwa nyuma: ngozi nyeupe kiasi',
    '👇🏽' => 'kidole cha kwanza kinachoelekeza chini kwa nyuma: ngozi ya kahawia',
    '👇🏾' => 'kidole cha kwanza kinachoelekeza chini kwa nyuma: ngozi nyeusi kiasi',
    '👇🏿' => 'kidole cha kwanza kinachoelekeza chini kwa nyuma: ngozi nyeusi',
    '☝🏻' => 'kidole cha shahada kinachoelekeza juu: ngozi nyeupe',
    '☝🏼' => 'kidole cha shahada kinachoelekeza juu: ngozi nyeupe kiasi',
    '☝🏽' => 'kidole cha shahada kinachoelekeza juu: ngozi ya kahawia',
    '☝🏾' => 'kidole cha shahada kinachoelekeza juu: ngozi nyeusi kiasi',
    '☝🏿' => 'kidole cha shahada kinachoelekeza juu: ngozi nyeusi',
    '🫵🏻' => 'kidole cha shahada kinachomwelekea mtazamaji: ngozi nyeupe',
    '🫵🏼' => 'kidole cha shahada kinachomwelekea mtazamaji: ngozi nyeupe kiasi',
    '🫵🏽' => 'kidole cha shahada kinachomwelekea mtazamaji: ngozi ya kahawia',
    '🫵🏾' => 'kidole cha shahada kinachomwelekea mtazamaji: ngozi nyeusi kiasi',
    '🫵🏿' => 'kidole cha shahada kinachomwelekea mtazamaji: ngozi nyeusi',
    '👍🏻' => 'dole gumba juu: ngozi nyeupe',
    '👍🏼' => 'dole gumba juu: ngozi nyeupe kiasi',
    '👍🏽' => 'dole gumba juu: ngozi ya kahawia',
    '👍🏾' => 'dole gumba juu: ngozi nyeusi kiasi',
    '👍🏿' => 'dole gumba juu: ngozi nyeusi',
    '👎🏻' => 'dole gumba chini: ngozi nyeupe',
    '👎🏼' => 'dole gumba chini: ngozi nyeupe kiasi',
    '👎🏽' => 'dole gumba chini: ngozi ya kahawia',
    '👎🏾' => 'dole gumba chini: ngozi nyeusi kiasi',
    '👎🏿' => 'dole gumba chini: ngozi nyeusi',
    '✊🏻' => 'ngumi iliyoinuliwa: ngozi nyeupe',
    '✊🏼' => 'ngumi iliyoinuliwa: ngozi nyeupe kiasi',
    '✊🏽' => 'ngumi iliyoinuliwa: ngozi ya kahawia',
    '✊🏾' => 'ngumi iliyoinuliwa: ngozi nyeusi kiasi',
    '✊🏿' => 'ngumi iliyoinuliwa: ngozi nyeusi',
    '👊🏻' => 'ngumi iliyonyooshewa: ngozi nyeupe',
    '👊🏼' => 'ngumi iliyonyooshewa: ngozi nyeupe kiasi',
    '👊🏽' => 'ngumi iliyonyooshewa: ngozi ya kahawia',
    '👊🏾' => 'ngumi iliyonyooshewa: ngozi nyeusi kiasi',
    '👊🏿' => 'ngumi iliyonyooshewa: ngozi nyeusi',
    '🤛🏻' => 'ngumi ya kulia: ngozi nyeupe',
    '🤛🏼' => 'ngumi ya kulia: ngozi nyeupe kiasi',
    '🤛🏽' => 'ngumi ya kulia: ngozi ya kahawia',
    '🤛🏾' => 'ngumi ya kulia: ngozi nyeusi kiasi',
    '🤛🏿' => 'ngumi ya kulia: ngozi nyeusi',
    '🤜🏻' => 'ngumi ya kushoto: ngozi nyeupe',
    '🤜🏼' => 'ngumi ya kushoto: ngozi nyeupe kiasi',
    '🤜🏽' => 'ngumi ya kushoto: ngozi ya kahawia',
    '🤜🏾' => 'ngumi ya kushoto: ngozi nyeusi kiasi',
    '🤜🏿' => 'ngumi ya kushoto: ngozi nyeusi',
    '👏🏻' => 'mikono inayopiga makofi: ngozi nyeupe',
    '👏🏼' => 'mikono inayopiga makofi: ngozi nyeupe kiasi',
    '👏🏽' => 'mikono inayopiga makofi: ngozi ya kahawia',
    '👏🏾' => 'mikono inayopiga makofi: ngozi nyeusi kiasi',
    '👏🏿' => 'mikono inayopiga makofi: ngozi nyeusi',
    '🙌🏻' => 'mikono iliyoinuliwa: ngozi nyeupe',
    '🙌🏼' => 'mikono iliyoinuliwa: ngozi nyeupe kiasi',
    '🙌🏽' => 'mikono iliyoinuliwa: ngozi ya kahawia',
    '🙌🏾' => 'mikono iliyoinuliwa: ngozi nyeusi kiasi',
    '🙌🏿' => 'mikono iliyoinuliwa: ngozi nyeusi',
    '🫶🏻' => 'mikono inayoonyesha ishara ya moyo: ngozi nyeupe',
    '🫶🏼' => 'mikono inayoonyesha ishara ya moyo: ngozi nyeupe kiasi',
    '🫶🏽' => 'mikono inayoonyesha ishara ya moyo: ngozi ya kahawia',
    '🫶🏾' => 'mikono inayoonyesha ishara ya moyo: ngozi nyeusi kiasi',
    '🫶🏿' => 'mikono inayoonyesha ishara ya moyo: ngozi nyeusi',
    '👐🏻' => 'mikono iliyowazi: ngozi nyeupe',
    '👐🏼' => 'mikono iliyowazi: ngozi nyeupe kiasi',
    '👐🏽' => 'mikono iliyowazi: ngozi ya kahawia',
    '👐🏾' => 'mikono iliyowazi: ngozi nyeusi kiasi',
    '👐🏿' => 'mikono iliyowazi: ngozi nyeusi',
    '🤲🏻' => 'viganja vilivyoshikana: ngozi nyeupe',
    '🤲🏼' => 'viganja vilivyoshikana: ngozi nyeupe kiasi',
    '🤲🏽' => 'viganja vilivyoshikana: ngozi ya kahawia',
    '🤲🏾' => 'viganja vilivyoshikana: ngozi nyeusi kiasi',
    '🤲🏿' => 'viganja vilivyoshikana: ngozi nyeusi',
    '🤝🏻' => 'kusalimiana: ngozi nyeupe',
    '🤝🏼' => 'kusalimiana: ngozi nyeupe kiasi',
    '🤝🏽' => 'kusalimiana: ngozi ya kahawia',
    '🤝🏾' => 'kusalimiana: ngozi nyeusi kiasi',
    '🤝🏿' => 'kusalimiana: ngozi nyeusi',
    '🙏🏻' => 'mikono iliyokunjwa: ngozi nyeupe',
    '🙏🏼' => 'mikono iliyokunjwa: ngozi nyeupe kiasi',
    '🙏🏽' => 'mikono iliyokunjwa: ngozi ya kahawia',
    '🙏🏾' => 'mikono iliyokunjwa: ngozi nyeusi kiasi',
    '🙏🏿' => 'mikono iliyokunjwa: ngozi nyeusi',
    '✍🏻' => 'mkono unaoandika: ngozi nyeupe',
    '✍🏼' => 'mkono unaoandika: ngozi nyeupe kiasi',
    '✍🏽' => 'mkono unaoandika: ngozi ya kahawia',
    '✍🏾' => 'mkono unaoandika: ngozi nyeusi kiasi',
    '✍🏿' => 'mkono unaoandika: ngozi nyeusi',
    '💅🏻' => 'rangi ya kupaka kwenye kucha: ngozi nyeupe',
    '💅🏼' => 'rangi ya kupaka kwenye kucha: ngozi nyeupe kiasi',
    '💅🏽' => 'rangi ya kupaka kwenye kucha: ngozi ya kahawia',
    '💅🏾' => 'rangi ya kupaka kwenye kucha: ngozi nyeusi kiasi',
    '💅🏿' => 'rangi ya kupaka kwenye kucha: ngozi nyeusi',
    '🤳🏻' => 'selfi: ngozi nyeupe',
    '🤳🏼' => 'selfi: ngozi nyeupe kiasi',
    '🤳🏽' => 'selfi: ngozi ya kahawia',
    '🤳🏾' => 'selfi: ngozi nyeusi kiasi',
    '🤳🏿' => 'selfi: ngozi nyeusi',
    '💪🏻' => 'misuli iliyotunishwa: ngozi nyeupe',
    '💪🏼' => 'misuli iliyotunishwa: ngozi nyeupe kiasi',
    '💪🏽' => 'misuli iliyotunishwa: ngozi ya kahawia',
    '💪🏾' => 'misuli iliyotunishwa: ngozi nyeusi kiasi',
    '💪🏿' => 'misuli iliyotunishwa: ngozi nyeusi',
    '🦵🏻' => 'mguu: ngozi nyeupe',
    '🦵🏼' => 'mguu: ngozi nyeupe kiasi',
    '🦵🏽' => 'mguu: ngozi ya kahawia',
    '🦵🏾' => 'mguu: ngozi nyeusi kiasi',
    '🦵🏿' => 'mguu: ngozi nyeusi',
    '🦶🏻' => 'wayo: ngozi nyeupe',
    '🦶🏼' => 'wayo: ngozi nyeupe kiasi',
    '🦶🏽' => 'wayo: ngozi ya kahawia',
    '🦶🏾' => 'wayo: ngozi nyeusi kiasi',
    '🦶🏿' => 'wayo: ngozi nyeusi',
    '👂🏻' => 'sikio: ngozi nyeupe',
    '👂🏼' => 'sikio: ngozi nyeupe kiasi',
    '👂🏽' => 'sikio: ngozi ya kahawia',
    '👂🏾' => 'sikio: ngozi nyeusi kiasi',
    '👂🏿' => 'sikio: ngozi nyeusi',
    '🦻🏻' => 'sikio lenye kifaa cha kusikia: ngozi nyeupe',
    '🦻🏼' => 'sikio lenye kifaa cha kusikia: ngozi nyeupe kiasi',
    '🦻🏽' => 'sikio lenye kifaa cha kusikia: ngozi ya kahawia',
    '🦻🏾' => 'sikio lenye kifaa cha kusikia: ngozi nyeusi kiasi',
    '🦻🏿' => 'sikio lenye kifaa cha kusikia: ngozi nyeusi',
    '👃🏻' => 'pua: ngozi nyeupe',
    '👃🏼' => 'pua: ngozi nyeupe kiasi',
    '👃🏽' => 'pua: ngozi ya kahawia',
    '👃🏾' => 'pua: ngozi nyeusi kiasi',
    '👃🏿' => 'pua: ngozi nyeusi',
    '👶🏻' => 'mtoto: ngozi nyeupe',
    '👶🏼' => 'mtoto: ngozi nyeupe kiasi',
    '👶🏽' => 'mtoto: ngozi ya kahawia',
    '👶🏾' => 'mtoto: ngozi nyeusi kiasi',
    '👶🏿' => 'mtoto: ngozi nyeusi',
    '🧒🏻' => 'kijana: ngozi nyeupe',
    '🧒🏼' => 'kijana: ngozi nyeupe kiasi',
    '🧒🏽' => 'kijana: ngozi ya kahawia',
    '🧒🏾' => 'kijana: ngozi nyeusi kiasi',
    '🧒🏿' => 'kijana: ngozi nyeusi',
    '👦🏻' => 'mvulana: ngozi nyeupe',
    '👦🏼' => 'mvulana: ngozi nyeupe kiasi',
    '👦🏽' => 'mvulana: ngozi ya kahawia',
    '👦🏾' => 'mvulana: ngozi nyeusi kiasi',
    '👦🏿' => 'mvulana: ngozi nyeusi',
    '👧🏻' => 'msichana: ngozi nyeupe',
    '👧🏼' => 'msichana: ngozi nyeupe kiasi',
    '👧🏽' => 'msichana: ngozi ya kahawia',
    '👧🏾' => 'msichana: ngozi nyeusi kiasi',
    '👧🏿' => 'msichana: ngozi nyeusi',
    '🧑🏻' => 'mtu mzima: ngozi nyeupe',
    '🧑🏼' => 'mtu mzima: ngozi nyeupe kiasi',
    '🧑🏽' => 'mtu mzima: ngozi ya kahawia',
    '🧑🏾' => 'mtu mzima: ngozi nyeusi kiasi',
    '🧑🏿' => 'mtu mzima: ngozi nyeusi',
    '👱🏻' => 'mtu mwenye nywele za shaba: ngozi nyeupe',
    '👱🏼' => 'mtu mwenye nywele za shaba: ngozi nyeupe kiasi',
    '👱🏽' => 'mtu mwenye nywele za shaba: ngozi ya kahawia',
    '👱🏾' => 'mtu mwenye nywele za shaba: ngozi nyeusi kiasi',
    '👱🏿' => 'mtu mwenye nywele za shaba: ngozi nyeusi',
    '👨🏻' => 'mwanamume: ngozi nyeupe',
    '👨🏼' => 'mwanamume: ngozi nyeupe kiasi',
    '👨🏽' => 'mwanamume: ngozi ya kahawia',
    '👨🏾' => 'mwanamume: ngozi nyeusi kiasi',
    '👨🏿' => 'mwanamume: ngozi nyeusi',
    '🧔🏻' => 'mtu mwenye ndevu: ngozi nyeupe',
    '🧔🏼' => 'mtu mwenye ndevu: ngozi nyeupe kiasi',
    '🧔🏽' => 'mtu mwenye ndevu: ngozi ya kahawia',
    '🧔🏾' => 'mtu mwenye ndevu: ngozi nyeusi kiasi',
    '🧔🏿' => 'mtu mwenye ndevu: ngozi nyeusi',
    '👩🏻' => 'mwanamke: ngozi nyeupe',
    '👩🏼' => 'mwanamke: ngozi nyeupe kiasi',
    '👩🏽' => 'mwanamke: ngozi ya kahawia',
    '👩🏾' => 'mwanamke: ngozi nyeusi kiasi',
    '👩🏿' => 'mwanamke: ngozi nyeusi',
    '🧓🏻' => 'mzee: ngozi nyeupe',
    '🧓🏼' => 'mzee: ngozi nyeupe kiasi',
    '🧓🏽' => 'mzee: ngozi ya kahawia',
    '🧓🏾' => 'mzee: ngozi nyeusi kiasi',
    '🧓🏿' => 'mzee: ngozi nyeusi',
    '👴🏻' => 'babu: ngozi nyeupe',
    '👴🏼' => 'babu: ngozi nyeupe kiasi',
    '👴🏽' => 'babu: ngozi ya kahawia',
    '👴🏾' => 'babu: ngozi nyeusi kiasi',
    '👴🏿' => 'babu: ngozi nyeusi',
    '👵🏻' => 'bibi: ngozi nyeupe',
    '👵🏼' => 'bibi: ngozi nyeupe kiasi',
    '👵🏽' => 'bibi: ngozi ya kahawia',
    '👵🏾' => 'bibi: ngozi nyeusi kiasi',
    '👵🏿' => 'bibi: ngozi nyeusi',
    '🙍🏻' => 'mtu anayekunja kipaji cha uso: ngozi nyeupe',
    '🙍🏼' => 'mtu anayekunja kipaji cha uso: ngozi nyeupe kiasi',
    '🙍🏽' => 'mtu anayekunja kipaji cha uso: ngozi ya kahawia',
    '🙍🏾' => 'mtu anayekunja kipaji cha uso: ngozi nyeusi kiasi',
    '🙍🏿' => 'mtu anayekunja kipaji cha uso: ngozi nyeusi',
    '🙎🏻' => 'mtu aliyebibidua midomo: ngozi nyeupe',
    '🙎🏼' => 'mtu aliyebibidua midomo: ngozi nyeupe kiasi',
    '🙎🏽' => 'mtu aliyebibidua midomo: ngozi ya kahawia',
    '🙎🏾' => 'mtu aliyebibidua midomo: ngozi nyeusi kiasi',
    '🙎🏿' => 'mtu aliyebibidua midomo: ngozi nyeusi',
    '🙅🏻' => 'mtu anayeonyesha ishara ya kukataa: ngozi nyeupe',
    '🙅🏼' => 'mtu anayeonyesha ishara ya kukataa: ngozi nyeupe kiasi',
    '🙅🏽' => 'mtu anayeonyesha ishara ya kukataa: ngozi ya kahawia',
    '🙅🏾' => 'mtu anayeonyesha ishara ya kukataa: ngozi nyeusi kiasi',
    '🙅🏿' => 'mtu anayeonyesha ishara ya kukataa: ngozi nyeusi',
    '🙆🏻' => 'mtu anayeonyesha ishara ya kukubali: ngozi nyeupe',
    '🙆🏼' => 'mtu anayeonyesha ishara ya kukubali: ngozi nyeupe kiasi',
    '🙆🏽' => 'mtu anayeonyesha ishara ya kukubali: ngozi ya kahawia',
    '🙆🏾' => 'mtu anayeonyesha ishara ya kukubali: ngozi nyeusi kiasi',
    '🙆🏿' => 'mtu anayeonyesha ishara ya kukubali: ngozi nyeusi',
    '💁🏻' => 'mhudumu anayetoa maelezo: ngozi nyeupe',
    '💁🏼' => 'mhudumu anayetoa maelezo: ngozi nyeupe kiasi',
    '💁🏽' => 'mhudumu anayetoa maelezo: ngozi ya kahawia',
    '💁🏾' => 'mhudumu anayetoa maelezo: ngozi nyeusi kiasi',
    '💁🏿' => 'mhudumu anayetoa maelezo: ngozi nyeusi',
    '🙋🏻' => 'mtu mwenye furaha aliyeinua mkono: ngozi nyeupe',
    '🙋🏼' => 'mtu mwenye furaha aliyeinua mkono: ngozi nyeupe kiasi',
    '🙋🏽' => 'mtu mwenye furaha aliyeinua mkono: ngozi ya kahawia',
    '🙋🏾' => 'mtu mwenye furaha aliyeinua mkono: ngozi nyeusi kiasi',
    '🙋🏿' => 'mtu mwenye furaha aliyeinua mkono: ngozi nyeusi',
    '🧏🏻' => 'kiziwi: ngozi nyeupe',
    '🧏🏼' => 'kiziwi: ngozi nyeupe kiasi',
    '🧏🏽' => 'kiziwi: ngozi ya kahawia',
    '🧏🏾' => 'kiziwi: ngozi nyeusi kiasi',
    '🧏🏿' => 'kiziwi: ngozi nyeusi',
    '🙇🏻' => 'mtu aliyeinama: ngozi nyeupe',
    '🙇🏼' => 'mtu aliyeinama: ngozi nyeupe kiasi',
    '🙇🏽' => 'mtu aliyeinama: ngozi ya kahawia',
    '🙇🏾' => 'mtu aliyeinama: ngozi nyeusi kiasi',
    '🙇🏿' => 'mtu aliyeinama: ngozi nyeusi',
    '🤦🏻' => 'ishara ya kutoamini: ngozi nyeupe',
    '🤦🏼' => 'ishara ya kutoamini: ngozi nyeupe kiasi',
    '🤦🏽' => 'ishara ya kutoamini: ngozi ya kahawia',
    '🤦🏾' => 'ishara ya kutoamini: ngozi nyeusi kiasi',
    '🤦🏿' => 'ishara ya kutoamini: ngozi nyeusi',
    '🤷🏻' => 'ishara ya kutojali: ngozi nyeupe',
    '🤷🏼' => 'ishara ya kutojali: ngozi nyeupe kiasi',
    '🤷🏽' => 'ishara ya kutojali: ngozi ya kahawia',
    '🤷🏾' => 'ishara ya kutojali: ngozi nyeusi kiasi',
    '🤷🏿' => 'ishara ya kutojali: ngozi nyeusi',
    '👮🏻' => 'afisa wa polisi: ngozi nyeupe',
    '👮🏼' => 'afisa wa polisi: ngozi nyeupe kiasi',
    '👮🏽' => 'afisa wa polisi: ngozi ya kahawia',
    '👮🏾' => 'afisa wa polisi: ngozi nyeusi kiasi',
    '👮🏿' => 'afisa wa polisi: ngozi nyeusi',
    '🕵🏻' => 'mpelelezi: ngozi nyeupe',
    '🕵🏼' => 'mpelelezi: ngozi nyeupe kiasi',
    '🕵🏽' => 'mpelelezi: ngozi ya kahawia',
    '🕵🏾' => 'mpelelezi: ngozi nyeusi kiasi',
    '🕵🏿' => 'mpelelezi: ngozi nyeusi',
    '💂🏻' => 'mlinzi: ngozi nyeupe',
    '💂🏼' => 'mlinzi: ngozi nyeupe kiasi',
    '💂🏽' => 'mlinzi: ngozi ya kahawia',
    '💂🏾' => 'mlinzi: ngozi nyeusi kiasi',
    '💂🏿' => 'mlinzi: ngozi nyeusi',
    '🥷🏻' => 'ninja: ngozi nyeupe',
    '🥷🏼' => 'ninja: ngozi nyeupe kiasi',
    '🥷🏽' => 'ninja: ngozi ya kahawia',
    '🥷🏾' => 'ninja: ngozi nyeusi kiasi',
    '🥷🏿' => 'ninja: ngozi nyeusi',
    '👷🏻' => 'mfanyakazi wa ujenzi: ngozi nyeupe',
    '👷🏼' => 'mfanyakazi wa ujenzi: ngozi nyeupe kiasi',
    '👷🏽' => 'mfanyakazi wa ujenzi: ngozi ya kahawia',
    '👷🏾' => 'mfanyakazi wa ujenzi: ngozi nyeusi kiasi',
    '👷🏿' => 'mfanyakazi wa ujenzi: ngozi nyeusi',
    '🫅🏻' => 'kichwa chenye taji: ngozi nyeupe',
    '🫅🏼' => 'kichwa chenye taji: ngozi nyeupe kiasi',
    '🫅🏽' => 'kichwa chenye taji: ngozi ya kahawia',
    '🫅🏾' => 'kichwa chenye taji: ngozi nyeusi kiasi',
    '🫅🏿' => 'kichwa chenye taji: ngozi nyeusi',
    '🤴🏻' => 'mwana wa mfalme: ngozi nyeupe',
    '🤴🏼' => 'mwana wa mfalme: ngozi nyeupe kiasi',
    '🤴🏽' => 'mwana wa mfalme: ngozi ya kahawia',
    '🤴🏾' => 'mwana wa mfalme: ngozi nyeusi kiasi',
    '🤴🏿' => 'mwana wa mfalme: ngozi nyeusi',
    '👸🏻' => 'binti mfalme: ngozi nyeupe',
    '👸🏼' => 'binti mfalme: ngozi nyeupe kiasi',
    '👸🏽' => 'binti mfalme: ngozi ya kahawia',
    '👸🏾' => 'binti mfalme: ngozi nyeusi kiasi',
    '👸🏿' => 'binti mfalme: ngozi nyeusi',
    '👳🏻' => 'mwanaume aliyefunga kilemba: ngozi nyeupe',
    '👳🏼' => 'mwanaume aliyefunga kilemba: ngozi nyeupe kiasi',
    '👳🏽' => 'mwanaume aliyefunga kilemba: ngozi ya kahawia',
    '👳🏾' => 'mwanaume aliyefunga kilemba: ngozi nyeusi kiasi',
    '👳🏿' => 'mwanaume aliyefunga kilemba: ngozi nyeusi',
    '👲🏻' => 'mwanamume aliyevaa kofia ya kichina: ngozi nyeupe',
    '👲🏼' => 'mwanamume aliyevaa kofia ya kichina: ngozi nyeupe kiasi',
    '👲🏽' => 'mwanamume aliyevaa kofia ya kichina: ngozi ya kahawia',
    '👲🏾' => 'mwanamume aliyevaa kofia ya kichina: ngozi nyeusi kiasi',
    '👲🏿' => 'mwanamume aliyevaa kofia ya kichina: ngozi nyeusi',
    '🧕🏻' => 'mwanamke aliyejifunga kitambaa kichwani: ngozi nyeupe',
    '🧕🏼' => 'mwanamke aliyejifunga kitambaa kichwani: ngozi nyeupe kiasi',
    '🧕🏽' => 'mwanamke aliyejifunga kitambaa kichwani: ngozi ya kahawia',
    '🧕🏾' => 'mwanamke aliyejifunga kitambaa kichwani: ngozi nyeusi kiasi',
    '🧕🏿' => 'mwanamke aliyejifunga kitambaa kichwani: ngozi nyeusi',
    '🤵🏻' => 'mtu aliyevaa tuxedo: ngozi nyeupe',
    '🤵🏼' => 'mtu aliyevaa tuxedo: ngozi nyeupe kiasi',
    '🤵🏽' => 'mtu aliyevaa tuxedo: ngozi ya kahawia',
    '🤵🏾' => 'mtu aliyevaa tuxedo: ngozi nyeusi kiasi',
    '🤵🏿' => 'mtu aliyevaa tuxedo: ngozi nyeusi',
    '👰🏻' => 'mtu aliyevaa shela: ngozi nyeupe',
    '👰🏼' => 'mtu aliyevaa shela: ngozi nyeupe kiasi',
    '👰🏽' => 'mtu aliyevaa shela: ngozi ya kahawia',
    '👰🏾' => 'mtu aliyevaa shela: ngozi nyeusi kiasi',
    '👰🏿' => 'mtu aliyevaa shela: ngozi nyeusi',
    '🤰🏻' => 'mwanamke mjamzito: ngozi nyeupe',
    '🤰🏼' => 'mwanamke mjamzito: ngozi nyeupe kiasi',
    '🤰🏽' => 'mwanamke mjamzito: ngozi ya kahawia',
    '🤰🏾' => 'mwanamke mjamzito: ngozi nyeusi kiasi',
    '🤰🏿' => 'mwanamke mjamzito: ngozi nyeusi',
    '🫃🏻' => 'mwanamume mwenye kitambi: ngozi nyeupe',
    '🫃🏼' => 'mwanamume mwenye kitambi: ngozi nyeupe kiasi',
    '🫃🏽' => 'mwanamume mwenye kitambi: ngozi ya kahawia',
    '🫃🏾' => 'mwanamume mwenye kitambi: ngozi nyeusi kiasi',
    '🫃🏿' => 'mwanamume mwenye kitambi: ngozi nyeusi',
    '🫄🏻' => 'mtu mwenye mimba: ngozi nyeupe',
    '🫄🏼' => 'mtu mwenye mimba: ngozi nyeupe kiasi',
    '🫄🏽' => 'mtu mwenye mimba: ngozi ya kahawia',
    '🫄🏾' => 'mtu mwenye mimba: ngozi nyeusi kiasi',
    '🫄🏿' => 'mtu mwenye mimba: ngozi nyeusi',
    '🤱🏻' => 'kunyonyesha mtoto: ngozi nyeupe',
    '🤱🏼' => 'kunyonyesha mtoto: ngozi nyeupe kiasi',
    '🤱🏽' => 'kunyonyesha mtoto: ngozi ya kahawia',
    '🤱🏾' => 'kunyonyesha mtoto: ngozi nyeusi kiasi',
    '🤱🏿' => 'kunyonyesha mtoto: ngozi nyeusi',
    '👼🏻' => 'mtoto malaika: ngozi nyeupe',
    '👼🏼' => 'mtoto malaika: ngozi nyeupe kiasi',
    '👼🏽' => 'mtoto malaika: ngozi ya kahawia',
    '👼🏾' => 'mtoto malaika: ngozi nyeusi kiasi',
    '👼🏿' => 'mtoto malaika: ngozi nyeusi',
    '🎅🏻' => 'baba krismasi: ngozi nyeupe',
    '🎅🏼' => 'baba krismasi: ngozi nyeupe kiasi',
    '🎅🏽' => 'baba krismasi: ngozi ya kahawia',
    '🎅🏾' => 'baba krismasi: ngozi nyeusi kiasi',
    '🎅🏿' => 'baba krismasi: ngozi nyeusi',
    '🤶🏻' => 'mkongwe: ngozi nyeupe',
    '🤶🏼' => 'mkongwe: ngozi nyeupe kiasi',
    '🤶🏽' => 'mkongwe: ngozi ya kahawia',
    '🤶🏾' => 'mkongwe: ngozi nyeusi kiasi',
    '🤶🏿' => 'mkongwe: ngozi nyeusi',
    '🦸🏻' => 'shujaa: ngozi nyeupe',
    '🦸🏼' => 'shujaa: ngozi nyeupe kiasi',
    '🦸🏽' => 'shujaa: ngozi ya kahawia',
    '🦸🏾' => 'shujaa: ngozi nyeusi kiasi',
    '🦸🏿' => 'shujaa: ngozi nyeusi',
    '🦹🏻' => 'jambazi sugu: ngozi nyeupe',
    '🦹🏼' => 'jambazi sugu: ngozi nyeupe kiasi',
    '🦹🏽' => 'jambazi sugu: ngozi ya kahawia',
    '🦹🏾' => 'jambazi sugu: ngozi nyeusi kiasi',
    '🦹🏿' => 'jambazi sugu: ngozi nyeusi',
    '🧙🏻' => 'mlozi: ngozi nyeupe',
    '🧙🏼' => 'mlozi: ngozi nyeupe kiasi',
    '🧙🏽' => 'mlozi: ngozi ya kahawia',
    '🧙🏾' => 'mlozi: ngozi nyeusi kiasi',
    '🧙🏿' => 'mlozi: ngozi nyeusi',
    '🧚🏻' => 'kichimbakazi: ngozi nyeupe',
    '🧚🏼' => 'kichimbakazi: ngozi nyeupe kiasi',
    '🧚🏽' => 'kichimbakazi: ngozi ya kahawia',
    '🧚🏾' => 'kichimbakazi: ngozi nyeusi kiasi',
    '🧚🏿' => 'kichimbakazi: ngozi nyeusi',
    '🧛🏻' => 'mnyonya damu: ngozi nyeupe',
    '🧛🏼' => 'mnyonya damu: ngozi nyeupe kiasi',
    '🧛🏽' => 'mnyonya damu: ngozi ya kahawia',
    '🧛🏾' => 'mnyonya damu: ngozi nyeusi kiasi',
    '🧛🏿' => 'mnyonya damu: ngozi nyeusi',
    '🧜🏻' => 'nguva mtu: ngozi nyeupe',
    '🧜🏼' => 'nguva mtu: ngozi nyeupe kiasi',
    '🧜🏽' => 'nguva mtu: ngozi ya kahawia',
    '🧜🏾' => 'nguva mtu: ngozi nyeusi kiasi',
    '🧜🏿' => 'nguva mtu: ngozi nyeusi',
    '🧝🏻' => 'kibwengo: ngozi nyeupe',
    '🧝🏼' => 'kibwengo: ngozi nyeupe kiasi',
    '🧝🏽' => 'kibwengo: ngozi ya kahawia',
    '🧝🏾' => 'kibwengo: ngozi nyeusi kiasi',
    '🧝🏿' => 'kibwengo: ngozi nyeusi',
    '💆🏻' => 'kukanda uso: ngozi nyeupe',
    '💆🏼' => 'kukanda uso: ngozi nyeupe kiasi',
    '💆🏽' => 'kukanda uso: ngozi ya kahawia',
    '💆🏾' => 'kukanda uso: ngozi nyeusi kiasi',
    '💆🏿' => 'kukanda uso: ngozi nyeusi',
    '💇🏻' => 'kukata nywele: ngozi nyeupe',
    '💇🏼' => 'kukata nywele: ngozi nyeupe kiasi',
    '💇🏽' => 'kukata nywele: ngozi ya kahawia',
    '💇🏾' => 'kukata nywele: ngozi nyeusi kiasi',
    '💇🏿' => 'kukata nywele: ngozi nyeusi',
    '🚶🏻' => 'mtu anayetembea: ngozi nyeupe',
    '🚶🏼' => 'mtu anayetembea: ngozi nyeupe kiasi',
    '🚶🏽' => 'mtu anayetembea: ngozi ya kahawia',
    '🚶🏾' => 'mtu anayetembea: ngozi nyeusi kiasi',
    '🚶🏿' => 'mtu anayetembea: ngozi nyeusi',
    '🧍🏻' => 'mtu aliyesimama: ngozi nyeupe',
    '🧍🏼' => 'mtu aliyesimama: ngozi nyeupe kiasi',
    '🧍🏽' => 'mtu aliyesimama: ngozi ya kahawia',
    '🧍🏾' => 'mtu aliyesimama: ngozi nyeusi kiasi',
    '🧍🏿' => 'mtu aliyesimama: ngozi nyeusi',
    '🧎🏻' => 'mtu aliyepiga magoti: ngozi nyeupe',
    '🧎🏼' => 'mtu aliyepiga magoti: ngozi nyeupe kiasi',
    '🧎🏽' => 'mtu aliyepiga magoti: ngozi ya kahawia',
    '🧎🏾' => 'mtu aliyepiga magoti: ngozi nyeusi kiasi',
    '🧎🏿' => 'mtu aliyepiga magoti: ngozi nyeusi',
    '🏃🏻' => 'mkimbiaji: ngozi nyeupe',
    '🏃🏼' => 'mkimbiaji: ngozi nyeupe kiasi',
    '🏃🏽' => 'mkimbiaji: ngozi ya kahawia',
    '🏃🏾' => 'mkimbiaji: ngozi nyeusi kiasi',
    '🏃🏿' => 'mkimbiaji: ngozi nyeusi',
    '💃🏻' => 'mwanamke anayecheza: ngozi nyeupe',
    '💃🏼' => 'mwanamke anayecheza: ngozi nyeupe kiasi',
    '💃🏽' => 'mwanamke anayecheza: ngozi ya kahawia',
    '💃🏾' => 'mwanamke anayecheza: ngozi nyeusi kiasi',
    '💃🏿' => 'mwanamke anayecheza: ngozi nyeusi',
    '🕺🏻' => 'kusakata rumba: ngozi nyeupe',
    '🕺🏼' => 'kusakata rumba: ngozi nyeupe kiasi',
    '🕺🏽' => 'kusakata rumba: ngozi ya kahawia',
    '🕺🏾' => 'kusakata rumba: ngozi nyeusi kiasi',
    '🕺🏿' => 'kusakata rumba: ngozi nyeusi',
    '🕴🏻' => 'mwanaume aliyevaa suti anayeelea hewani: ngozi nyeupe',
    '🕴🏼' => 'mwanaume aliyevaa suti anayeelea hewani: ngozi nyeupe kiasi',
    '🕴🏽' => 'mwanaume aliyevaa suti anayeelea hewani: ngozi ya kahawia',
    '🕴🏾' => 'mwanaume aliyevaa suti anayeelea hewani: ngozi nyeusi kiasi',
    '🕴🏿' => 'mwanaume aliyevaa suti anayeelea hewani: ngozi nyeusi',
    '👯🏻' => 'watu wanaosherehekea: ngozi nyeupe',
    '👯🏼' => 'watu wanaosherehekea: ngozi nyeupe kiasi',
    '👯🏽' => 'watu wanaosherehekea: ngozi ya kahawia',
    '👯🏾' => 'watu wanaosherehekea: ngozi nyeusi kiasi',
    '👯🏿' => 'watu wanaosherehekea: ngozi nyeusi',
    '🧖🏻' => 'mtu katika bafu la mvuke: ngozi nyeupe',
    '🧖🏼' => 'mtu katika bafu la mvuke: ngozi nyeupe kiasi',
    '🧖🏽' => 'mtu katika bafu la mvuke: ngozi ya kahawia',
    '🧖🏾' => 'mtu katika bafu la mvuke: ngozi nyeusi kiasi',
    '🧖🏿' => 'mtu katika bafu la mvuke: ngozi nyeusi',
    '🧗🏻' => 'mtu anayekwea: ngozi nyeupe',
    '🧗🏼' => 'mtu anayekwea: ngozi nyeupe kiasi',
    '🧗🏽' => 'mtu anayekwea: ngozi ya kahawia',
    '🧗🏾' => 'mtu anayekwea: ngozi nyeusi kiasi',
    '🧗🏿' => 'mtu anayekwea: ngozi nyeusi',
    '🏇🏻' => 'mbio za farasi: ngozi nyeupe',
    '🏇🏼' => 'mbio za farasi: ngozi nyeupe kiasi',
    '🏇🏽' => 'mbio za farasi: ngozi ya kahawia',
    '🏇🏾' => 'mbio za farasi: ngozi nyeusi kiasi',
    '🏇🏿' => 'mbio za farasi: ngozi nyeusi',
    '🏂🏻' => 'mtu anayeteleza kwenye theluji: ngozi nyeupe',
    '🏂🏼' => 'mtu anayeteleza kwenye theluji: ngozi nyeupe kiasi',
    '🏂🏽' => 'mtu anayeteleza kwenye theluji: ngozi ya kahawia',
    '🏂🏾' => 'mtu anayeteleza kwenye theluji: ngozi nyeusi kiasi',
    '🏂🏿' => 'mtu anayeteleza kwenye theluji: ngozi nyeusi',
    '🏌🏻' => 'mcheza gofu: ngozi nyeupe',
    '🏌🏼' => 'mcheza gofu: ngozi nyeupe kiasi',
    '🏌🏽' => 'mcheza gofu: ngozi ya kahawia',
    '🏌🏾' => 'mcheza gofu: ngozi nyeusi kiasi',
    '🏌🏿' => 'mcheza gofu: ngozi nyeusi',
    '🏄🏻' => 'mtu anayeteleza kwenye mawimbi: ngozi nyeupe',
    '🏄🏼' => 'mtu anayeteleza kwenye mawimbi: ngozi nyeupe kiasi',
    '🏄🏽' => 'mtu anayeteleza kwenye mawimbi: ngozi ya kahawia',
    '🏄🏾' => 'mtu anayeteleza kwenye mawimbi: ngozi nyeusi kiasi',
    '🏄🏿' => 'mtu anayeteleza kwenye mawimbi: ngozi nyeusi',
    '🚣🏻' => 'ngalawa: ngozi nyeupe',
    '🚣🏼' => 'ngalawa: ngozi nyeupe kiasi',
    '🚣🏽' => 'ngalawa: ngozi ya kahawia',
    '🚣🏾' => 'ngalawa: ngozi nyeusi kiasi',
    '🚣🏿' => 'ngalawa: ngozi nyeusi',
    '🏊🏻' => 'mwogeleaji: ngozi nyeupe',
    '🏊🏼' => 'mwogeleaji: ngozi nyeupe kiasi',
    '🏊🏽' => 'mwogeleaji: ngozi ya kahawia',
    '🏊🏾' => 'mwogeleaji: ngozi nyeusi kiasi',
    '🏊🏿' => 'mwogeleaji: ngozi nyeusi',
    '⛹🏻' => 'mtu na mpira: ngozi nyeupe',
    '⛹🏼' => 'mtu na mpira: ngozi nyeupe kiasi',
    '⛹🏽' => 'mtu na mpira: ngozi ya kahawia',
    '⛹🏾' => 'mtu na mpira: ngozi nyeusi kiasi',
    '⛹🏿' => 'mtu na mpira: ngozi nyeusi',
    '🏋🏻' => 'mbeba vyuma vizito: ngozi nyeupe',
    '🏋🏼' => 'mbeba vyuma vizito: ngozi nyeupe kiasi',
    '🏋🏽' => 'mbeba vyuma vizito: ngozi ya kahawia',
    '🏋🏾' => 'mbeba vyuma vizito: ngozi nyeusi kiasi',
    '🏋🏿' => 'mbeba vyuma vizito: ngozi nyeusi',
    '🚴🏻' => 'mwendesha baisikeli: ngozi nyeupe',
    '🚴🏼' => 'mwendesha baisikeli: ngozi nyeupe kiasi',
    '🚴🏽' => 'mwendesha baisikeli: ngozi ya kahawia',
    '🚴🏾' => 'mwendesha baisikeli: ngozi nyeusi kiasi',
    '🚴🏿' => 'mwendesha baisikeli: ngozi nyeusi',
    '🚵🏻' => 'mtu anayeendesha baisikeli mlimani: ngozi nyeupe',
    '🚵🏼' => 'mtu anayeendesha baisikeli mlimani: ngozi nyeupe kiasi',
    '🚵🏽' => 'mtu anayeendesha baisikeli mlimani: ngozi ya kahawia',
    '🚵🏾' => 'mtu anayeendesha baisikeli mlimani: ngozi nyeusi kiasi',
    '🚵🏿' => 'mtu anayeendesha baisikeli mlimani: ngozi nyeusi',
    '🤸🏻' => 'sarakasi: ngozi nyeupe',
    '🤸🏼' => 'sarakasi: ngozi nyeupe kiasi',
    '🤸🏽' => 'sarakasi: ngozi ya kahawia',
    '🤸🏾' => 'sarakasi: ngozi nyeusi kiasi',
    '🤸🏿' => 'sarakasi: ngozi nyeusi',
    '🤼🏻' => 'wanandondi: ngozi nyeupe',
    '🤼🏼' => 'wanandondi: ngozi nyeupe kiasi',
    '🤼🏽' => 'wanandondi: ngozi ya kahawia',
    '🤼🏾' => 'wanandondi: ngozi nyeusi kiasi',
    '🤼🏿' => 'wanandondi: ngozi nyeusi',
    '🤽🏻' => 'michezo kwenye bwawa la kuogelea: ngozi nyeupe',
    '🤽🏼' => 'michezo kwenye bwawa la kuogelea: ngozi nyeupe kiasi',
    '🤽🏽' => 'michezo kwenye bwawa la kuogelea: ngozi ya kahawia',
    '🤽🏾' => 'michezo kwenye bwawa la kuogelea: ngozi nyeusi kiasi',
    '🤽🏿' => 'michezo kwenye bwawa la kuogelea: ngozi nyeusi',
    '🤾🏻' => 'mpira wa mikono: ngozi nyeupe',
    '🤾🏼' => 'mpira wa mikono: ngozi nyeupe kiasi',
    '🤾🏽' => 'mpira wa mikono: ngozi ya kahawia',
    '🤾🏾' => 'mpira wa mikono: ngozi nyeusi kiasi',
    '🤾🏿' => 'mpira wa mikono: ngozi nyeusi',
    '🤹🏻' => 'mtu anayecheza mipira mingi: ngozi nyeupe',
    '🤹🏼' => 'mtu anayecheza mipira mingi: ngozi nyeupe kiasi',
    '🤹🏽' => 'mtu anayecheza mipira mingi: ngozi ya kahawia',
    '🤹🏾' => 'mtu anayecheza mipira mingi: ngozi nyeusi kiasi',
    '🤹🏿' => 'mtu anayecheza mipira mingi: ngozi nyeusi',
    '🧘🏻' => 'mtu anayetaamali: ngozi nyeupe',
    '🧘🏼' => 'mtu anayetaamali: ngozi nyeupe kiasi',
    '🧘🏽' => 'mtu anayetaamali: ngozi ya kahawia',
    '🧘🏾' => 'mtu anayetaamali: ngozi nyeusi kiasi',
    '🧘🏿' => 'mtu anayetaamali: ngozi nyeusi',
    '🛀🏻' => 'mtu anayeoga: ngozi nyeupe',
    '🛀🏼' => 'mtu anayeoga: ngozi nyeupe kiasi',
    '🛀🏽' => 'mtu anayeoga: ngozi ya kahawia',
    '🛀🏾' => 'mtu anayeoga: ngozi nyeusi kiasi',
    '🛀🏿' => 'mtu anayeoga: ngozi nyeusi',
    '🛌🏻' => 'mtu aliyelala kitandani: ngozi nyeupe',
    '🛌🏼' => 'mtu aliyelala kitandani: ngozi nyeupe kiasi',
    '🛌🏽' => 'mtu aliyelala kitandani: ngozi ya kahawia',
    '🛌🏾' => 'mtu aliyelala kitandani: ngozi nyeusi kiasi',
    '🛌🏿' => 'mtu aliyelala kitandani: ngozi nyeusi',
    '👭🏻' => 'wanawake walioshikana mikono: ngozi nyeupe',
    '👭🏼' => 'wanawake walioshikana mikono: ngozi nyeupe kiasi',
    '👭🏽' => 'wanawake walioshikana mikono: ngozi ya kahawia',
    '👭🏾' => 'wanawake walioshikana mikono: ngozi nyeusi kiasi',
    '👭🏿' => 'wanawake walioshikana mikono: ngozi nyeusi',
    '👫🏻' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe',
    '👫🏼' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeupe kiasi',
    '👫🏽' => 'mwanamke na mwanamume walioshikana mikono: ngozi ya kahawia',
    '👫🏾' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi kiasi',
    '👫🏿' => 'mwanamke na mwanamume walioshikana mikono: ngozi nyeusi',
    '👬🏻' => 'wanaume walioshikana mikono: ngozi nyeupe',
    '👬🏼' => 'wanaume walioshikana mikono: ngozi nyeupe kiasi',
    '👬🏽' => 'wanaume walioshikana mikono: ngozi ya kahawia',
    '👬🏾' => 'wanaume walioshikana mikono: ngozi nyeusi kiasi',
    '👬🏿' => 'wanaume walioshikana mikono: ngozi nyeusi',
    '💏🏻' => 'busu: ngozi nyeupe',
    '💏🏼' => 'busu: ngozi nyeupe kiasi',
    '💏🏽' => 'busu: ngozi ya kahawia',
    '💏🏾' => 'busu: ngozi nyeusi kiasi',
    '💏🏿' => 'busu: ngozi nyeusi',
    '💑🏻' => 'mume na mke na ishara ya moyo: ngozi nyeupe',
    '💑🏼' => 'mume na mke na ishara ya moyo: ngozi nyeupe kiasi',
    '💑🏽' => 'mume na mke na ishara ya moyo: ngozi ya kahawia',
    '💑🏾' => 'mume na mke na ishara ya moyo: ngozi nyeusi kiasi',
    '💑🏿' => 'mume na mke na ishara ya moyo: ngozi nyeusi',
    '🇦🇨' => 'bendera: Kisiwa cha Ascension',
    '🇦🇩' => 'bendera: Andorra',
    '🇦🇪' => 'bendera: Falme za Kiarabu',
    '🇦🇫' => 'bendera: Afghanistani',
    '🇦🇬' => 'bendera: Antigua na Babuda',
    '🇦🇮' => 'bendera: Anguila',
    '🇦🇱' => 'bendera: Albania',
    '🇦🇲' => 'bendera: Armenia',
    '🇦🇴' => 'bendera: Angola',
    '🇦🇶' => 'bendera: Antaktika',
    '🇦🇷' => 'bendera: Ajentina',
    '🇦🇸' => 'bendera: Samoa ya Marekani',
    '🇦🇹' => 'bendera: Austria',
    '🇦🇺' => 'bendera: Australia',
    '🇦🇼' => 'bendera: Aruba',
    '🇦🇽' => 'bendera: Visiwa vya Aland',
    '🇦🇿' => 'bendera: Azabajani',
    '🇧🇦' => 'bendera: Bosnia na Hezegovina',
    '🇧🇧' => 'bendera: Babados',
    '🇧🇩' => 'bendera: Bangladeshi',
    '🇧🇪' => 'bendera: Ubelgiji',
    '🇧🇫' => 'bendera: Bukinafaso',
    '🇧🇬' => 'bendera: Bulgaria',
    '🇧🇭' => 'bendera: Bahareni',
    '🇧🇮' => 'bendera: Burundi',
    '🇧🇯' => 'bendera: Benini',
    '🇧🇱' => 'bendera: St. Barthelemy',
    '🇧🇲' => 'bendera: Bermuda',
    '🇧🇳' => 'bendera: Brunei',
    '🇧🇴' => 'bendera: Bolivia',
    '🇧🇶' => 'bendera: Uholanzi ya Karibiani',
    '🇧🇷' => 'bendera: Brazil',
    '🇧🇸' => 'bendera: Bahamas',
    '🇧🇹' => 'bendera: Bhutani',
    '🇧🇻' => 'bendera: Kisiwa cha Bouvet',
    '🇧🇼' => 'bendera: Botswana',
    '🇧🇾' => 'bendera: Belarusi',
    '🇧🇿' => 'bendera: Belize',
    '🇨🇦' => 'bendera: Kanada',
    '🇨🇨' => 'bendera: Visiwa vya Kokos (Keeling)',
    '🇨🇩' => 'bendera: Kongo - Kinshasa',
    '🇨🇫' => 'bendera: Jamhuri ya Afrika ya Kati',
    '🇨🇬' => 'bendera: Kongo - Brazzaville',
    '🇨🇭' => 'bendera: Uswisi',
    '🇨🇮' => 'bendera: Cote d’Ivoire',
    '🇨🇰' => 'bendera: Visiwa vya Cook',
    '🇨🇱' => 'bendera: Chile',
    '🇨🇲' => 'bendera: Kameruni',
    '🇨🇳' => 'bendera: Uchina',
    '🇨🇴' => 'bendera: Kolombia',
    '🇨🇵' => 'bendera: Kisiwa cha Clipperton',
    '🇨🇶' => 'bendera: Sark',
    '🇨🇷' => 'bendera: Kostarika',
    '🇨🇺' => 'bendera: Kuba',
    '🇨🇻' => 'bendera: Kepuvede',
    '🇨🇼' => 'bendera: Kurakao',
    '🇨🇽' => 'bendera: Kisiwa cha Krismasi',
    '🇨🇾' => 'bendera: Saiprasi',
    '🇨🇿' => 'bendera: Chechia',
    '🇩🇪' => 'bendera: Ujerumani',
    '🇩🇬' => 'bendera: Diego Garcia',
    '🇩🇯' => 'bendera: Jibuti',
    '🇩🇰' => 'bendera: Denmaki',
    '🇩🇲' => 'bendera: Dominika',
    '🇩🇴' => 'bendera: Jamhuri ya Dominika',
    '🇩🇿' => 'bendera: Aljeria',
    '🇪🇦' => 'bendera: Keuta na Melilla',
    '🇪🇨' => 'bendera: Ekwado',
    '🇪🇪' => 'bendera: Estonia',
    '🇪🇬' => 'bendera: Misri',
    '🇪🇭' => 'bendera: Sahara Magharibi',
    '🇪🇷' => 'bendera: Eritrea',
    '🇪🇸' => 'bendera: Uhispania',
    '🇪🇹' => 'bendera: Ethiopia',
    '🇪🇺' => 'bendera: Umoja wa Ulaya',
    '🇫🇮' => 'bendera: Ufini',
    '🇫🇯' => 'bendera: Fiji',
    '🇫🇰' => 'bendera: Visiwa vya Falkland',
    '🇫🇲' => 'bendera: Mikronesia',
    '🇫🇴' => 'bendera: Visiwa vya Faroe',
    '🇫🇷' => 'bendera: Ufaransa',
    '🇬🇦' => 'bendera: Gaboni',
    '🇬🇧' => 'bendera: Ufalme wa Muungano',
    '🇬🇩' => 'bendera: Grenada',
    '🇬🇪' => 'bendera: Jojia',
    '🇬🇫' => 'bendera: Guiana ya Ufaransa',
    '🇬🇬' => 'bendera: Guernsey',
    '🇬🇭' => 'bendera: Ghana',
    '🇬🇮' => 'bendera: Gibraltar',
    '🇬🇱' => 'bendera: Greenland',
    '🇬🇲' => 'bendera: Gambia',
    '🇬🇳' => 'bendera: Gine',
    '🇬🇵' => 'bendera: Gwadelupe',
    '🇬🇶' => 'bendera: Guinea ya Ikweta',
    '🇬🇷' => 'bendera: Ugiriki',
    '🇬🇸' => 'bendera: Visiwa vya Jojia Kusini na Sandwich Kusini',
    '🇬🇹' => 'bendera: Gwatemala',
    '🇬🇺' => 'bendera: Guami',
    '🇬🇼' => 'bendera: Ginebisau',
    '🇬🇾' => 'bendera: Guyana',
    '🇭🇰' => 'bendera: Hong Kong SAR China',
    '🇭🇲' => 'bendera: Kisiwa cha Heard na Visiwa vya McDonald',
    '🇭🇳' => 'bendera: Honduras',
    '🇭🇷' => 'bendera: Kroashia',
    '🇭🇹' => 'bendera: Haiti',
    '🇭🇺' => 'bendera: Hungaria',
    '🇮🇨' => 'bendera: Visiwa vya Kanari',
    '🇮🇩' => 'bendera: Indonesia',
    '🇮🇪' => 'bendera: Ayalandi',
    '🇮🇱' => 'bendera: Israeli',
    '🇮🇲' => 'bendera: Kisiwa cha Man',
    '🇮🇳' => 'bendera: India',
    '🇮🇴' => 'bendera: Eneo la Uingereza katika Bahari Hindi',
    '🇮🇶' => 'bendera: Iraki',
    '🇮🇷' => 'bendera: Iran',
    '🇮🇸' => 'bendera: Aisilandi',
    '🇮🇹' => 'bendera: Italia',
    '🇯🇪' => 'bendera: Jersey',
    '🇯🇲' => 'bendera: Jamaika',
    '🇯🇴' => 'bendera: Yordani',
    '🇯🇵' => 'bendera: Japani',
    '🇰🇪' => 'bendera: Kenya',
    '🇰🇬' => 'bendera: Kirigizistani',
    '🇰🇭' => 'bendera: Kambodia',
    '🇰🇮' => 'bendera: Kiribati',
    '🇰🇲' => 'bendera: Komoro',
    '🇰🇳' => 'bendera: St. Kitts na Nevis',
    '🇰🇵' => 'bendera: Korea Kaskazini',
    '🇰🇷' => 'bendera: Korea Kusini',
    '🇰🇼' => 'bendera: Kuwait',
    '🇰🇾' => 'bendera: Visiwa vya Cayman',
    '🇰🇿' => 'bendera: Kazakistani',
    '🇱🇦' => 'bendera: Laosi',
    '🇱🇧' => 'bendera: Lebanoni',
    '🇱🇨' => 'bendera: St. Lucia',
    '🇱🇮' => 'bendera: Lishenteni',
    '🇱🇰' => 'bendera: Sri Lanka',
    '🇱🇷' => 'bendera: Liberia',
    '🇱🇸' => 'bendera: Lesotho',
    '🇱🇹' => 'bendera: Lithuania',
    '🇱🇺' => 'bendera: Lasembagi',
    '🇱🇻' => 'bendera: Lativia',
    '🇱🇾' => 'bendera: Libya',
    '🇲🇦' => 'bendera: Moroko',
    '🇲🇨' => 'bendera: Monako',
    '🇲🇩' => 'bendera: Moldova',
    '🇲🇪' => 'bendera: Montenegro',
    '🇲🇫' => 'bendera: St. Martin',
    '🇲🇬' => 'bendera: Madagaska',
    '🇲🇭' => 'bendera: Visiwa vya Marshall',
    '🇲🇰' => 'bendera: Masedonia',
    '🇲🇱' => 'bendera: Mali',
    '🇲🇲' => 'bendera: Myama (Burma)',
    '🇲🇳' => 'bendera: Mongolia',
    '🇲🇴' => 'bendera: Makau SAR China',
    '🇲🇵' => 'bendera: Visiwa vya Mariana vya Kaskazini',
    '🇲🇶' => 'bendera: Martinique',
    '🇲🇷' => 'bendera: Moritania',
    '🇲🇸' => 'bendera: Montserati',
    '🇲🇹' => 'bendera: Malta',
    '🇲🇺' => 'bendera: Morisi',
    '🇲🇻' => 'bendera: Maldivi',
    '🇲🇼' => 'bendera: Malawi',
    '🇲🇽' => 'bendera: Meksiko',
    '🇲🇾' => 'bendera: Malesia',
    '🇲🇿' => 'bendera: Msumbiji',
    '🇳🇦' => 'bendera: Namibia',
    '🇳🇨' => 'bendera: Nyukaledonia',
    '🇳🇪' => 'bendera: Nijeri',
    '🇳🇫' => 'bendera: Kisiwa cha Norfolk',
    '🇳🇬' => 'bendera: Nigeria',
    '🇳🇮' => 'bendera: Nikaragwa',
    '🇳🇱' => 'bendera: Uholanzi',
    '🇳🇴' => 'bendera: Norwe',
    '🇳🇵' => 'bendera: Nepali',
    '🇳🇷' => 'bendera: Nauru',
    '🇳🇺' => 'bendera: Niue',
    '🇳🇿' => 'bendera: Nyuzilandi',
    '🇴🇲' => 'bendera: Omani',
    '🇵🇦' => 'bendera: Panama',
    '🇵🇪' => 'bendera: Peru',
    '🇵🇫' => 'bendera: Polinesia ya Ufaransa',
    '🇵🇬' => 'bendera: Papua Guinea Mpya',
    '🇵🇭' => 'bendera: Ufilipino',
    '🇵🇰' => 'bendera: Pakistani',
    '🇵🇱' => 'bendera: Polandi',
    '🇵🇲' => 'bendera: St. Pierre na Miquelon',
    '🇵🇳' => 'bendera: Visiwa vya Pitcairn',
    '🇵🇷' => 'bendera: Pwetoriko',
    '🇵🇸' => 'bendera: Himaya za Palestina',
    '🇵🇹' => 'bendera: Ureno',
    '🇵🇼' => 'bendera: Palau',
    '🇵🇾' => 'bendera: Paragwai',
    '🇶🇦' => 'bendera: Katari',
    '🇷🇪' => 'bendera: Reunion',
    '🇷🇴' => 'bendera: Romania',
    '🇷🇸' => 'bendera: Serbia',
    '🇷🇺' => 'bendera: Urusi',
    '🇷🇼' => 'bendera: Rwanda',
    '🇸🇦' => 'bendera: Saudia',
    '🇸🇧' => 'bendera: Visiwa vya Solomon',
    '🇸🇨' => 'bendera: Ushelisheli',
    '🇸🇩' => 'bendera: Sudan',
    '🇸🇪' => 'bendera: Uswidi',
    '🇸🇬' => 'bendera: Singapuri',
    '🇸🇭' => 'bendera: St. Helena',
    '🇸🇮' => 'bendera: Slovenia',
    '🇸🇯' => 'bendera: Svalbard na Jan Mayen',
    '🇸🇰' => 'bendera: Slovakia',
    '🇸🇱' => 'bendera: Siera Leoni',
    '🇸🇲' => 'bendera: San Marino',
    '🇸🇳' => 'bendera: Senegali',
    '🇸🇴' => 'bendera: Somalia',
    '🇸🇷' => 'bendera: Suriname',
    '🇸🇸' => 'bendera: Sudan Kusini',
    '🇸🇹' => 'bendera: Sao Tome na Prinsipe',
    '🇸🇻' => 'bendera: Elsalvado',
    '🇸🇽' => 'bendera: Sint Maarten',
    '🇸🇾' => 'bendera: Shamu',
    '🇸🇿' => 'bendera: Eswatini',
    '🇹🇦' => 'bendera: Tristan da Cunha',
    '🇹🇨' => 'bendera: Visiwa vya Turks na Caicos',
    '🇹🇩' => 'bendera: Chadi',
    '🇹🇫' => 'bendera: Himaya za Kusini za Kifaranza',
    '🇹🇬' => 'bendera: Togo',
    '🇹🇭' => 'bendera: Thailandi',
    '🇹🇯' => 'bendera: Tajikistani',
    '🇹🇰' => 'bendera: Tokelau',
    '🇹🇱' => 'bendera: Timor-Leste',
    '🇹🇲' => 'bendera: Turukimenstani',
    '🇹🇳' => 'bendera: Tunisia',
    '🇹🇴' => 'bendera: Tonga',
    '🇹🇷' => 'bendera: Uturuki',
    '🇹🇹' => 'bendera: Trinidad na Tobago',
    '🇹🇻' => 'bendera: Tuvalu',
    '🇹🇼' => 'bendera: Taiwani',
    '🇹🇿' => 'bendera: Tanzania',
    '🇺🇦' => 'bendera: Ukreni',
    '🇺🇬' => 'bendera: Uganda',
    '🇺🇲' => 'bendera: Visiwa Vidogo vya Nje vya Marekani',
    '🇺🇳' => 'bendera: Umoja wa Mataifa',
    '🇺🇸' => 'bendera: Marekani',
    '🇺🇾' => 'bendera: Urugwai',
    '🇺🇿' => 'bendera: Uzibekistani',
    '🇻🇦' => 'bendera: Mji wa Vatikani',
    '🇻🇨' => 'bendera: St. Vincent na Grenadines',
    '🇻🇪' => 'bendera: Venezuela',
    '🇻🇬' => 'bendera: Visiwa vya Virgin vya Uingereza',
    '🇻🇮' => 'bendera: Visiwa vya Virgin vya Marekani',
    '🇻🇳' => 'bendera: Vietnamu',
    '🇻🇺' => 'bendera: Vanuatu',
    '🇼🇫' => 'bendera: Wallis na Futuna',
    '🇼🇸' => 'bendera: Samoa',
    '🇽🇰' => 'bendera: Kosovo',
    '🇾🇪' => 'bendera: Yemeni',
    '🇾🇹' => 'bendera: Mayote',
    '🇿🇦' => 'bendera: Afrika Kusini',
    '🇿🇲' => 'bendera: Zambia',
    '🇿🇼' => 'bendera: Zimbabwe',
    '🔟' => 'kitufe: 10',
    '🏻' => 'ngozi nyeupe',
    '🏼' => 'ngozi nyeupe kiasi',
    '🏽' => 'ngozi ya kahawia',
    '🏾' => 'ngozi nyeusi kiasi',
    '🏿' => 'ngozi nyeusi',
    '😀' => 'uso unaokenua',
    '😃' => 'uso unaotabasamu wenye macho makubwa',
    '😄' => 'uso unaotabasamu wenye macho ya tabasamu',
    '😁' => 'uso uliokenua na macho yanayotabasamu',
    '😆' => 'uso unaotabasamu wenye mdomo wazi na macho yaliyofungwa',
    '😅' => 'uso unaotabasamu wenye tone la jasho',
    '🤣' => 'angua kicheko',
    '😂' => 'uso wenye machozi ya furaha',
    '🙂' => 'uso unaotabasamu kwa mbali',
    '🙃' => 'uso uliogeuzwa juu chini',
    '🫠' => 'uso unaoyeyuka',
    '😉' => 'uso unaokonyeza',
    '😊' => 'uso unaotabasamu na macho yanayotabasamu',
    '😇' => 'uso unaotabasamu ulio na mduara wa mwangaza juu yake',
    '🥰' => 'uso wenye tabasamu na maumbo ya moyo',
    '😍' => 'uso unaotabasamu wenye macho ya umbo la moyo',
    '🤩' => 'uso wenye macho ya nyota',
    '😘' => 'uso unaotoa busu',
    '😗' => 'uso unaobusu',
    '☺' => 'uso unaotabasamu',
    '😚' => 'uso unaobusu na macho yaliyofungwa',
    '😙' => 'uso unaobusu na macho yanayotabasamu',
    '🥲' => 'uso unaotabasamu na wenye chozi',
    '😋' => 'uso unaofurahia chakula kitamu',
    '😛' => 'uso wenye ulimi nje',
    '😜' => 'uso unaotoa ulimi nje na kukonyeza jicho',
    '🤪' => 'uso wa kutania',
    '😝' => 'uso wenye makengeza na ulimi unaochomoza',
    '🤑' => 'uso unaoonyesha pesa ya noti mdomoni',
    '🤗' => 'uso unaokumbatia',
    '🤭' => 'uso uliofunika mdomo kwa mkono',
    '🫢' => 'uso wenye macho wazi na mkono kwenye mdomo',
    '🫣' => 'uso wenye macho yanayochungulia',
    '🤫' => 'uso unaonyamazisha',
    '🤔' => 'uso unaotafakari',
    '🫡' => 'uso unaopiga saluti',
    '🤐' => 'uso uliofungwa mdomo kwa zipu',
    '🤨' => 'uso wenye nyusi zilizoinuka',
    '😐' => 'uso uliotulia',
    '😑' => 'uso uliojikausha',
    '😶' => 'uso bila mdomo',
    '🫥' => 'uso uliochorwa kwa vitone',
    '😏' => 'uso unaobeza',
    '😒' => 'uso usio na furaha',
    '🙄' => 'usio wenye macho yanayorembua',
    '😬' => 'uso uliokunjwa',
    '🤥' => 'uso unaodanganya',
    '🫨' => 'uso unaotikisika',
    '😌' => 'uso uliofarijika',
    '😔' => 'uso uliozama katika mawazo',
    '😪' => 'uso unaosinzia',
    '🤤' => 'kutema mate',
    '😴' => 'uso unaoonyesha usingizi',
    '🫩' => 'uso wenye macho yaliyovimba',
    '😷' => 'uso uliovaa barakoa ya matibabu',
    '🤒' => 'uso wenye kipimajoto mdomoni',
    '🤕' => 'uso uliofungwa bandeji kichwani',
    '🤢' => 'kichefuchefu',
    '🤮' => 'uso unaotapika',
    '🤧' => 'kupiga chafya',
    '🥵' => 'uso wenye joto',
    '🥶' => 'uso wenye baridi',
    '🥴' => 'uso uliolewa',
    '😵' => 'uso unaoonyesha kuwa na kizunguzungu',
    '🤯' => 'kichwa kinacholipuka',
    '🤠' => 'uso wenye kofia',
    '🥳' => 'uso wenye kofia ya karamu',
    '🥸' => 'uso uliogeuzwa ili kuficha',
    '😎' => 'uso unaotabasamu uliovaa miwani',
    '🤓' => 'uso wa mjuaji',
    '🧐' => 'uso wenye miwani kwenye jicho moja',
    '😕' => 'uso uliochanganyikiwa',
    '🫤' => 'uso wenye mdomo uliopinda',
    '😟' => 'uso ulio na wasiwasi',
    '🙁' => 'uso ulionuna kiasi',
    '☹' => 'uso ulionuna',
    '😮' => 'uso wenye mdomo ulio wazi',
    '😯' => 'uso ulionyamaa',
    '😲' => 'uso uliostaajabu',
    '😳' => 'uso uliojawa msisimko',
    '🫪' => 'uso ulioumbuka',
    '🥺' => 'uso unaosihi',
    '🥹' => 'uso unaolengwalengwa na machozi',
    '😦' => 'uso ulionuna wenye mdomo uliofunguliwa',
    '😧' => 'uso unaoonyesha uchungu',
    '😨' => 'uso unaoogopa',
    '😰' => 'uso wenye wasiwasi unaotokwa na jasho',
    '😥' => 'Uso wenye huzuni lakini unaoonyesha kufarijika',
    '😢' => 'uso unaolia',
    '😭' => 'uso unaolia kwa sauti',
    '😱' => 'uso unaopiga mayowe ya hofu',
    '😖' => 'uso ulioshangazwa',
    '😣' => 'uso unaovumilia',
    '😞' => 'uso uliosikitika',
    '😓' => 'uso wenye huzuni na jasho jembamba',
    '😩' => 'uso unaoonyesha uchovu',
    '😫' => 'uso uliochoka',
    '🥱' => 'uso unaopiga miayo',
    '😤' => 'uso wenye mvuke unaotoka puani',
    '😡' => 'uso uliobibidua midomo',
    '😠' => 'uso uliojaa hasira',
    '🤬' => 'uso wenye ishara mdomoni',
    '😈' => 'uso unaotabasamu wenye pembe',
    '👿' => 'kishetani',
    '💀' => 'fuvu',
    '☠' => 'fuvu na mifupa',
    '💩' => 'kinyesi',
    '🤡' => 'katuni',
    '👹' => 'zimwi',
    '👺' => 'afriti',
    '👻' => 'pepo',
    '👽' => 'jitu geni',
    '👾' => 'dubwana geni',
    '🤖' => 'roboti',
    '😺' => 'uso wa paka mwenye tabasamu',
    '😸' => 'uso wa paka mwenye tabasamu wenye macho ya tabasamu',
    '😹' => 'paka mwenye machozi ya furaha',
    '😻' => 'uso wa paka unaotabasamu wenye macho yenye umbo la moyo',
    '😼' => 'uso wa paka wenye tabasamu la kulazimisha',
    '😽' => 'uso wa paka anayebusu',
    '🙀' => 'uso wa paka uliochoka',
    '😿' => 'uso wa paka unaolia',
    '😾' => 'uso wa paka uliobibidua midomo',
    '🙈' => 'nyani aliyefumba macho kwa mikono',
    '🙉' => 'nyani aliyefunika masikio kwa mikono',
    '🙊' => 'nyani aliyefunika mdomo kwa mikono',
    '💌' => 'barua ya mapenzi',
    '💘' => 'moyo uliopenyezwa mshale',
    '💝' => 'moyo uliofungwa kwa utepe',
    '💖' => 'moyo unaong’aa',
    '💗' => 'moyo unaokua',
    '💓' => 'moyo unaodunda',
    '💞' => 'mioyo inayozunguka',
    '💕' => 'mioyo miwili',
    '💟' => 'mapambo ya moyo',
    '❣' => 'umbo la moyo lenye alama ya mshangao',
    '💔' => 'moyo uliovunjika',
    '❤' => 'moyo mwekundu',
    '🩷' => 'moyo wa waridi',
    '🧡' => 'moyo wa rangi ya chungwa',
    '💛' => 'moyo wa manjano',
    '💚' => 'moyo wa kijani',
    '💙' => 'moyo ya samawati',
    '🩵' => 'moyo wa buluu hafifu',
    '💜' => 'moyo wa zambarau',
    '🤎' => 'moyo wa hudhurungi',
    '🖤' => 'umbo nyeusi la moyo',
    '🩶' => 'moyo wa kijivu',
    '🤍' => 'moyo mweupe',
    '💋' => 'alama ya busu',
    '💯' => 'pointi mia moja',
    '💢' => 'alama ya hasira',
    '🫯' => 'wingu la vita',
    '💥' => 'mgongano',
    '💫' => 'kizunguzungu',
    '💦' => 'matone ya jasho',
    '💨' => 'kuharakisha',
    '🕳' => 'shimo',
    '💬' => 'kitufe cha usemi',
    '🗨' => 'kitufe cha usemi cha kushoto',
    '🗯' => 'kitufe cha usemi wa hasira cha kulia',
    '💭' => 'kitufe cha mawazo',
    '💤' => 'usingizi',
    '👋' => 'mkono unaopunga',
    '🤚' => 'kuinua mkono',
    '🖐' => 'mkono ulioinuliwa wenye vidole vilivyotanuliwa',
    '✋' => 'mkono ulioinuliwa',
    '🖖' => 'ishara ya vulkani',
    '🫱' => 'mkono unaoelekea kulia',
    '🫲' => 'mkono unaoelekea kushoto',
    '🫳' => 'mkono wenye kiganja kinachoelekea chini',
    '🫴' => 'mkono wenye kiganja kinachoelekea juu',
    '🫷' => 'mkono unaosukuma kushoto',
    '🫸' => 'mkono unaosukuma kulia',
    '👌' => 'mkono wa kuonyesha mambo yako shwari',
    '🤌' => 'mkono wenye vidole vinavyobana',
    '🤏' => 'vidole vinavyobana',
    '✌' => 'mkono wa ushindi',
    '🤞' => 'ishara ya kubahatisha',
    '🫰' => 'vidole vya shahada na gumba vinavyopitana',
    '🤟' => 'ishara ya "nakupenda"',
    '🤘' => 'ishara ya pembe',
    '🤙' => 'ishara ya “nipigie simu”',
    '👈' => 'kidole cha shahada kinachoelekeza kushoto',
    '👉' => 'kidole cha shahada kinachoelekeza kulia',
    '👆' => 'kidole cha kwanza kinachoelekeza juu kwa nyuma',
    '🖕' => 'kidole cha kati',
    '👇' => 'kidole cha kwanza kinachoelekeza chini kwa nyuma',
    '☝' => 'kidole cha shahada kinachoelekeza juu',
    '🫵' => 'kidole cha shahada kinachomwelekea mtazamaji',
    '👍' => 'dole gumba juu',
    '👎' => 'dole gumba chini',
    '✊' => 'ngumi iliyoinuliwa',
    '👊' => 'ngumi iliyonyooshewa',
    '🤛' => 'ngumi ya kulia',
    '🤜' => 'ngumi ya kushoto',
    '👏' => 'mikono inayopiga makofi',
    '🙌' => 'mikono iliyoinuliwa',
    '🫶' => 'mikono inayoonyesha ishara ya moyo',
    '👐' => 'mikono iliyowazi',
    '🤲' => 'viganja vilivyoshikana',
    '🤝' => 'kusalimiana',
    '🙏' => 'mikono iliyokunjwa',
    '✍' => 'mkono unaoandika',
    '💅' => 'rangi ya kupaka kwenye kucha',
    '🤳' => 'selfi',
    '💪' => 'misuli iliyotunishwa',
    '🦾' => 'mkono bandia',
    '🦿' => 'mguu bandia',
    '🦵' => 'mguu',
    '🦶' => 'wayo',
    '👂' => 'sikio',
    '🦻' => 'sikio lenye kifaa cha kusikia',
    '👃' => 'pua',
    '🧠' => 'ubongo',
    '🫀' => 'moyo',
    '🫁' => 'mapafu',
    '🦷' => 'jino',
    '🦴' => 'mfupa',
    '👀' => 'macho',
    '👁' => 'jicho',
    '👅' => 'ulimi',
    '👄' => 'mdomo',
    '🫦' => 'kuuma mdomo',
    '👶' => 'mtoto',
    '🧒' => 'kijana',
    '👦' => 'mvulana',
    '👧' => 'msichana',
    '🧑' => 'mtu mzima',
    '👱' => 'mtu mwenye nywele za shaba',
    '👨' => 'mwanamume',
    '🧔' => 'mtu mwenye ndevu',
    '👩' => 'mwanamke',
    '🧓' => 'mzee',
    '👴' => 'babu',
    '👵' => 'bibi',
    '🙍' => 'mtu anayekunja kipaji cha uso',
    '🙎' => 'mtu aliyebibidua midomo',
    '🙅' => 'mtu anayeonyesha ishara ya kukataa',
    '🙆' => 'mtu anayeonyesha ishara ya kukubali',
    '💁' => 'mhudumu anayetoa maelezo',
    '🙋' => 'mtu mwenye furaha aliyeinua mkono',
    '🧏' => 'kiziwi',
    '🙇' => 'mtu aliyeinama',
    '🤦' => 'ishara ya kutoamini',
    '🤷' => 'ishara ya kutojali',
    '👮' => 'afisa wa polisi',
    '🕵' => 'mpelelezi',
    '💂' => 'mlinzi',
    '🥷' => 'ninja',
    '👷' => 'mfanyakazi wa ujenzi',
    '🫅' => 'kichwa chenye taji',
    '🤴' => 'mwana wa mfalme',
    '👸' => 'binti mfalme',
    '👳' => 'mwanaume aliyefunga kilemba',
    '👲' => 'mwanamume aliyevaa kofia ya kichina',
    '🧕' => 'mwanamke aliyejifunga kitambaa kichwani',
    '🤵' => 'mtu aliyevaa tuxedo',
    '👰' => 'mtu aliyevaa shela',
    '🤰' => 'mwanamke mjamzito',
    '🫃' => 'mwanamume mwenye kitambi',
    '🫄' => 'mtu mwenye mimba',
    '🤱' => 'kunyonyesha mtoto',
    '👼' => 'mtoto malaika',
    '🎅' => 'baba krismasi',
    '🤶' => 'mkongwe',
    '🦸' => 'shujaa',
    '🦹' => 'jambazi sugu',
    '🧙' => 'mlozi',
    '🧚' => 'kichimbakazi',
    '🧛' => 'mnyonya damu',
    '🧜' => 'nguva mtu',
    '🧝' => 'kibwengo',
    '🧞' => 'jini',
    '🧟' => 'dubwana',
    '🧌' => 'jitu',
    '💆' => 'kukanda uso',
    '💇' => 'kukata nywele',
    '🚶' => 'mtu anayetembea',
    '🧍' => 'mtu aliyesimama',
    '🧎' => 'mtu aliyepiga magoti',
    '🏃' => 'mkimbiaji',
    '💃' => 'mwanamke anayecheza',
    '🕺' => 'kusakata rumba',
    '🕴' => 'mwanaume aliyevaa suti anayeelea hewani',
    '👯' => 'watu wanaosherehekea',
    '🧖' => 'mtu katika bafu la mvuke',
    '🧗' => 'mtu anayekwea',
    '🤺' => 'mtu aliyeshika upanga',
    '🏇' => 'mbio za farasi',
    '⛷' => 'mtu anayecheza mchezo wa kuskii',
    '🏂' => 'mtu anayeteleza kwenye theluji',
    '🏌' => 'mcheza gofu',
    '🏄' => 'mtu anayeteleza kwenye mawimbi',
    '🚣' => 'ngalawa',
    '🏊' => 'mwogeleaji',
    '⛹' => 'mtu na mpira',
    '🏋' => 'mbeba vyuma vizito',
    '🚴' => 'mwendesha baisikeli',
    '🚵' => 'mtu anayeendesha baisikeli mlimani',
    '🤸' => 'sarakasi',
    '🤼' => 'wanandondi',
    '🤽' => 'michezo kwenye bwawa la kuogelea',
    '🤾' => 'mpira wa mikono',
    '🤹' => 'mtu anayecheza mipira mingi',
    '🧘' => 'mtu anayetaamali',
    '🛀' => 'mtu anayeoga',
    '🛌' => 'mtu aliyelala kitandani',
    '👭' => 'wanawake walioshikana mikono',
    '👫' => 'mwanamke na mwanamume walioshikana mikono',
    '👬' => 'wanaume walioshikana mikono',
    '💏' => 'busu',
    '💑' => 'mume na mke na ishara ya moyo',
    '🗣' => 'kichwa kinachozungumza',
    '👤' => 'kivuli cha kichwa na mabega ya mtu',
    '👥' => 'vivuli vya vichwa na mabega ya watu',
    '🫂' => 'watu wanaokumbatiana',
    '👪' => 'familia',
    '👣' => 'nyayo',
    '🫆' => 'alama ya kidole',
    '🦰' => 'nywele nyekundu',
    '🦱' => 'nywele yenye mawimbi',
    '🦳' => 'nywele nyeupe',
    '🦲' => 'upara',
    '🐵' => 'uso wa tumbili',
    '🐒' => 'tumbili',
    '🦍' => 'sokwe',
    '🦧' => 'orangutanu (sokwe)',
    '🐶' => 'uso wa mbwa',
    '🐕' => 'mbwa',
    '🦮' => 'mbwa wa kuongoza',
    '🐩' => 'kijibwa',
    '🐺' => 'mbwa mwitu',
    '🦊' => 'mbweha',
    '🦝' => 'rakuni',
    '🐱' => 'uso wa paka',
    '🐈' => 'paka',
    '🦁' => 'simba',
    '🐯' => 'uso wa chui milia',
    '🐅' => 'chui mkubwa mwenye milia',
    '🐆' => 'chui',
    '🐴' => 'uso wa farasi',
    '🫎' => 'kongoni',
    '🫏' => 'punda',
    '🐎' => 'farasi',
    '🦄' => 'uso wa farasi mwenye pembe moja',
    '🦓' => 'punda milia',
    '🦌' => 'kulungu',
    '🦬' => 'baisani',
    '🐮' => 'uso wa ng’ombe',
    '🐂' => 'maksai',
    '🐃' => 'nyati',
    '🐄' => 'ng’ombe',
    '🐷' => 'uso wa nguruwe',
    '🐖' => 'nguruwe',
    '🐗' => 'uso wa nguruwe dume',
    '🐽' => 'pua la nguruwe',
    '🐏' => 'kondoo dume',
    '🐑' => 'kondoo',
    '🐐' => 'mbuzi',
    '🐪' => 'ngamia',
    '🐫' => 'ngamia mwenye nundu mbili',
    '🦙' => 'lama',
    '🦒' => 'twiga',
    '🐘' => 'ndovu',
    '🦣' => 'tembo wa kale',
    '🦏' => 'kifaru',
    '🦛' => 'kiboko',
    '🐭' => 'uso wa panya',
    '🐁' => 'kipanya',
    '🐀' => 'panya',
    '🐹' => 'uso wa buku',
    '🐰' => 'uso wa sungura',
    '🐇' => 'sungura',
    '🐿' => 'kindimilia',
    '🦫' => 'buku',
    '🦔' => 'nungunungu',
    '🦇' => 'popo',
    '🐻' => 'dubu',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'slothi',
    '🦦' => 'fisi-maji',
    '🦨' => 'kicheche',
    '🦘' => 'kangaruu',
    '🦡' => 'melesi',
    '🐾' => 'nyayo za mnyama',
    '🦃' => 'bata mzinga',
    '🐔' => 'kuku',
    '🐓' => 'jogoo',
    '🐣' => 'kifaranga kinachoanguliwa',
    '🐤' => 'kifaranga',
    '🐥' => 'kifaranga kinachotazama mbele',
    '🐦' => 'ndege',
    '🐧' => 'pengwini',
    '🕊' => 'njiwa',
    '🦅' => 'tai (ndege)',
    '🦆' => 'bata',
    '🦢' => 'bata maji',
    '🦉' => 'bundi',
    '🦤' => 'dodo',
    '🪶' => 'unyoya',
    '🦩' => 'Flamingo',
    '🦚' => 'tausi',
    '🦜' => 'kasuku',
    '🪽' => 'bawa',
    '🪿' => 'bata bukini',
    '🐸' => 'uso wa chura',
    '🐊' => 'mamba',
    '🐢' => 'mzee kobe',
    '🦎' => 'mjusi',
    '🐍' => 'nyoka',
    '🐲' => 'uso wa dragoni',
    '🐉' => 'dragoni',
    '🦕' => 'sauropodi',
    '🦖' => 'T-Rex',
    '🐳' => 'nyangumi anayerusha maji',
    '🐋' => 'nyangumi',
    '🐬' => 'pomboo',
    '🦭' => 'sili',
    '🐟' => 'samaki',
    '🐠' => 'samaki wa tropiki',
    '🐡' => 'aina ya samaki',
    '🦈' => 'papa',
    '🐙' => 'pweza',
    '🐚' => 'kombe la mzunguko',
    '🪸' => 'matumbawe',
    '🪼' => 'kiwavi wa baharini',
    '🦀' => 'kaa',
    '🦞' => 'kambamti',
    '🦐' => 'uduvi',
    '🦑' => 'ngisi',
    '🦪' => 'chaza',
    '🐌' => 'konokono',
    '🦋' => 'kipepeo',
    '🐛' => 'mdudu',
    '🐜' => 'siafu',
    '🐝' => 'nyuki',
    '🪲' => 'mende',
    '🐞' => 'kombamwiko mwenye madoa',
    '🦗' => 'nyenje',
    '🪳' => 'kombamwiko',
    '🕷' => 'buibui',
    '🕸' => 'tandabui',
    '🦂' => 'ng’e',
    '🦟' => 'mbu',
    '🪰' => 'nzi',
    '🪱' => 'mnyoo',
    '🦠' => 'bakteria',
    '💐' => 'shada la maua',
    '🌸' => 'ua la mcheri',
    '💮' => 'ua jeupe',
    '🪷' => 'yungiyungi',
    '🏵' => 'waridi',
    '🌹' => 'ua la waridi',
    '🥀' => 'ua lililonyauka',
    '🌺' => 'haibiskasi',
    '🌻' => 'alizeti',
    '🌼' => 'maua mengi',
    '🌷' => 'tulipu',
    '🪻' => 'hyacinthi',
    '🌱' => 'mche',
    '🪴' => 'mmea ndani ya mkebe',
    '🌲' => 'mmea wenye majani mwaka mzima',
    '🌳' => 'mti unaopukutika majani yake',
    '🌴' => 'mnazi',
    '🌵' => 'dungusi kakati',
    '🌾' => 'shada la mchele',
    '🌿' => 'mimea ya msimu',
    '☘' => 'shamroki',
    '🍀' => 'klova yenye majani manne',
    '🍁' => 'jani la mshira',
    '🍂' => 'jani lililoanguka',
    '🍃' => 'jani linalopepea kwenye upepo',
    '🪹' => 'kiota tupu',
    '🪺' => 'kiota chenye mayai',
    '🍄' => 'uyoga',
    '🪾' => 'mti bila majani',
    '🍇' => 'zabibu',
    '🍈' => 'tikiti',
    '🍉' => 'tikitimaji',
    '🍊' => 'chenza',
    '🍋' => 'limau',
    '🍌' => 'ndizi',
    '🍍' => 'nanasi',
    '🥭' => 'embe',
    '🍎' => 'tufaha jekundu',
    '🍏' => 'tufaha la kijani',
    '🍐' => 'pea',
    '🍑' => 'pichi',
    '🍒' => 'cheri',
    '🍓' => 'stroberi',
    '🫐' => 'forosadi',
    '🥝' => 'tunda la kiwi',
    '🍅' => 'nyanya',
    '🫒' => 'zeituni',
    '🥥' => 'nazi',
    '🥑' => 'parachichi',
    '🍆' => 'biringanya',
    '🥔' => 'viazi',
    '🥕' => 'karoti',
    '🌽' => 'mahindi',
    '🌶' => 'pilipili kali',
    '🫑' => 'pilipili boga',
    '🥒' => 'tango',
    '🥬' => 'sukumawiki',
    '🥦' => 'brokoli',
    '🧄' => 'kitunguu saumu',
    '🧅' => 'kitunguu',
    '🥜' => 'njugu',
    '🫘' => 'maharagwe',
    '🌰' => 'aina ya njugu',
    '🫚' => 'tangawizi',
    '🫛' => 'ganda la njegere',
    '🫜' => 'mzizi mboga',
    '🍞' => 'mkate',
    '🥐' => 'mahamri',
    '🥖' => 'mkate wa kifaransa',
    '🫓' => 'chapati ya maji',
    '🥨' => 'pretzel',
    '🥯' => 'mkate wa kuoka',
    '🥞' => 'chapati',
    '🧇' => 'mkate wa sega la nyuki',
    '🧀' => 'kipande cha jibini',
    '🍖' => 'nyama kwenye mfupa',
    '🍗' => 'paja la kuku',
    '🥩' => 'kipande cha nyama',
    '🥓' => 'nyama',
    '🍔' => 'hambaga',
    '🍟' => 'chipsi',
    '🍕' => 'piza',
    '🌭' => 'soseji katika mkate',
    '🥪' => 'sandwichi',
    '🌮' => 'chapati iliyojazwa vyakula mbalimbali',
    '🌯' => 'mkate wa kimeksiko uliowekwa nyama au maharage ndani',
    '🫔' => 'tamale',
    '🥙' => 'shawarma',
    '🧆' => 'felafeli',
    '🥚' => 'yai',
    '🍳' => 'kupika',
    '🥘' => 'kikaango',
    '🍲' => 'chungu cha chakula',
    '🫕' => 'jibini iliyoyeyushwa',
    '🥣' => 'bakuli lenye kijiko',
    '🥗' => 'kachumbari',
    '🍿' => 'bisi',
    '🧈' => 'siagi',
    '🧂' => 'chumvi',
    '🥫' => 'chakula kilicho koponi',
    '🍱' => 'boksi ya kuweka chakula',
    '🍘' => 'biskuti za mchele',
    '🍙' => 'mchele uliotengenezwa kwa mtindo wa tufe',
    '🍚' => 'wali',
    '🍛' => 'wali ulio na mchuzi wa viungo',
    '🍜' => 'bakuli lenye tambi',
    '🍝' => 'tambi',
    '🍠' => 'kiazi kitamu kilichochomwa',
    '🍢' => 'odeni',
    '🍣' => 'sushi',
    '🍤' => 'uduvi iliyokaangwa',
    '🍥' => 'keki ya samaki iliyozingwa',
    '🥮' => 'mkate wa sinia',
    '🍡' => 'dango',
    '🥟' => 'pudini ya kinyunya',
    '🥠' => 'biskuti ya bahati',
    '🥡' => 'kisanduku cha chakula',
    '🍦' => 'aisikrimu laini',
    '🍧' => 'barafu iliyochongwa',
    '🍨' => 'aisikrimu',
    '🍩' => 'kitumbua',
    '🍪' => 'biskuti',
    '🎂' => 'keki ya kusherehekea siku ya kuzaliwa',
    '🍰' => 'keki',
    '🧁' => 'keki ndogo',
    '🥧' => 'pai',
    '🍫' => 'chokoleti',
    '🍬' => 'peremende',
    '🍭' => 'pipi',
    '🍮' => 'faluda',
    '🍯' => 'chungu cha asali',
    '🍼' => 'chupa ya maziwa ya mtoto',
    '🥛' => 'glasi yenye maziwa',
    '☕' => 'kinywaji moto',
    '🫖' => 'birika la chai',
    '🍵' => 'kikombe kisicho na kishikio',
    '🍶' => 'mvinyo wa kijapani unaotokana na mchele',
    '🍾' => 'chupa yenye kifuniko kilichofunguliwa',
    '🍷' => 'glasi ya divai',
    '🍸' => 'glasi ya kokteli',
    '🍹' => 'kinywaji cha tropiki',
    '🍺' => 'kikombe cha bia',
    '🍻' => 'vikombe vya bia vinavyogonganishwa',
    '🥂' => 'kugonga glasi',
    '🥃' => 'glasi',
    '🫗' => 'kinywaji kinachomiminika',
    '🥤' => 'kikombe chenye mrija',
    '🧋' => 'chai ya maziwa ya boba',
    '🧃' => 'chupa ya kinywaji',
    '🧉' => 'kinywaji cha mate',
    '🧊' => 'kidonge cha barafu',
    '🥢' => 'vijiti vya kutumia kula',
    '🍽' => 'uma na kisu na sahani',
    '🍴' => 'uma na kisu',
    '🥄' => 'kijiko',
    '🔪' => 'kisu kinachotumika jikoni',
    '🫙' => 'chupa kubwa',
    '🏺' => 'jungu',
    '🌍' => 'tufe linaloonyesha ulaya-afrika',
    '🌎' => 'tufe linaloonyesha amerika',
    '🌏' => 'tufe linaloonyesha asia-australia',
    '🌐' => 'tufe lenye meridiani',
    '🗺' => 'ramani ya dunia',
    '🗾' => 'ramani ya japani',
    '🧭' => 'dira',
    '🏔' => 'mlima wenye theluji',
    '⛰' => 'mlima',
    '🛘' => 'maporomoko ya ardhi',
    '🌋' => 'volkano',
    '🗻' => 'mlima fuji',
    '🏕' => 'kupiga kambi',
    '🏖' => 'ufuo na mwavuli',
    '🏜' => 'jangwa',
    '🏝' => 'kisiwa cha jangwa',
    '🏞' => 'mbuga ya taifa ya wanyama',
    '🏟' => 'uwanja wa michezo',
    '🏛' => 'jengo la zamani',
    '🏗' => 'ujenzi wa jengo',
    '🧱' => 'tofali',
    '🪨' => 'mwamba',
    '🪵' => 'kuni',
    '🛖' => 'kibanda cha mviringo',
    '🏘' => 'majengo ya nyumba',
    '🏚' => 'jengo la nyumba lililochakaa',
    '🏠' => 'jengo la nyumba',
    '🏡' => 'nyumba yenye ua',
    '🏢' => 'jengo la ofisi',
    '🏣' => 'posta ya japani',
    '🏤' => 'posta',
    '🏥' => 'hospitali',
    '🏦' => 'benki',
    '🏨' => 'hoteli',
    '🏩' => 'hoteli ya mapenzi',
    '🏪' => 'duka la karibu',
    '🏫' => 'shule',
    '🏬' => 'duka kuu',
    '🏭' => 'kiwanda',
    '🏯' => 'kasri la kijapani',
    '🏰' => 'kasri',
    '💒' => 'harusi',
    '🗼' => 'mnara wa tokyo',
    '🗽' => 'sanamu ya uhuru',
    '⛪' => 'kanisa',
    '🕌' => 'msikiti',
    '🛕' => 'hekalu la kihindi',
    '🕍' => 'hekalu la kiyahudi',
    '⛩' => 'madhabahu ya shinto',
    '🕋' => 'kaaba',
    '⛲' => 'mlizamu',
    '⛺' => 'hema',
    '🌁' => 'mandhari yenye ukungu',
    '🌃' => 'usiku wenye nyota',
    '🏙' => 'mwonekano wa jiji',
    '🌄' => 'macheo kwenye milima',
    '🌅' => 'macheo',
    '🌆' => 'mwonekano wa jiji usiku',
    '🌇' => 'machweo',
    '🌉' => 'daraja usiku',
    '♨' => 'chemichemi za maji ya moto',
    '🎠' => 'farasi inayozunguka',
    '🛝' => 'mtelezo wa watoto',
    '🎡' => 'gurudumu linalozunguka',
    '🎢' => 'rola kosta',
    '💈' => 'nguzo ya kinyozi',
    '🎪' => 'hema ya sarakasi',
    '🚂' => 'garimoshi',
    '🚃' => 'gari la moshi',
    '🚄' => 'treni yenye kasi',
    '🚅' => 'treni yenye kasi yenye umbo la risasi',
    '🚆' => 'treni',
    '🚇' => 'metro',
    '🚈' => 'reli nyepesi',
    '🚉' => 'kituo',
    '🚊' => 'tramu',
    '🚝' => 'reli moja',
    '🚞' => 'reli ya milimani',
    '🚋' => 'gari la tramu',
    '🚌' => 'basi',
    '🚍' => 'basi linalokuja',
    '🚎' => 'kiberenge',
    '🚐' => 'basi dogo',
    '🚑' => 'ambulansi',
    '🚒' => 'gari la zimamoto',
    '🚓' => 'gari la polisi',
    '🚔' => 'gari la polisi linalokuja',
    '🚕' => 'teksi',
    '🚖' => 'teksi inayokuja',
    '🚗' => 'gari',
    '🚘' => 'gari linalokuja',
    '🚙' => 'gari la burudani',
    '🛻' => 'gari la mizigo',
    '🚚' => 'gari la kusafirisha mizigo',
    '🚛' => 'lori linalobeba mizigo',
    '🚜' => 'trekta',
    '🏎' => 'gari la mashindano',
    '🏍' => 'pikipiki',
    '🛵' => 'pikipiki (skuta)',
    '🦽' => 'kiti cha magurudumu kisicho na mota',
    '🦼' => 'kiti cha magurudumu chenye mota',
    '🛺' => 'riksho',
    '🚲' => 'baisikeli',
    '🛴' => 'skuta',
    '🛹' => 'ubao mtelezo',
    '🛼' => 'rolasketi',
    '🚏' => 'kituo cha basi',
    '🛣' => 'barabara kuu',
    '🛤' => 'njia ya reli',
    '🛢' => 'pipa la mafuta',
    '⛽' => 'pampu ya mafuta',
    '🛞' => 'gurudumu',
    '🚨' => 'taa ya gari la polisi',
    '🚥' => 'taa mlalo ya trafiki',
    '🚦' => 'taa wima ya trafiki',
    '🛑' => 'taa ya kusimama',
    '🚧' => 'ujenzi',
    '⚓' => 'nanga',
    '🛟' => 'boya okozi',
    '⛵' => 'mashua',
    '🛶' => 'mtumbwi',
    '🚤' => 'mashua ya kasi',
    '🛳' => 'meli ya abiria',
    '⛴' => 'feri',
    '🛥' => 'motaboti',
    '🚢' => 'meli',
    '✈' => 'eropleni',
    '🛩' => 'ndege ndogo',
    '🛫' => 'ndege inayoondoka',
    '🛬' => 'ndege inayowasili',
    '🪂' => 'parachuti',
    '💺' => 'kikalio',
    '🚁' => 'helikopta',
    '🚟' => 'reli inayoelea angani',
    '🚠' => 'gari linalosafiri milimani kwa kamba',
    '🚡' => 'tramu inayosafiri angani kwa kamba',
    '🛰' => 'setilaiti',
    '🚀' => 'roketi',
    '🛸' => 'kisahani kinachopaa',
    '🛎' => 'kengele ya mwandazi',
    '🧳' => 'mzigo',
    '⌛' => 'shisha',
    '⏳' => 'shisha inayotiririsha mchanga',
    '⌚' => 'saa',
    '⏰' => 'kipima muda',
    '⏱' => 'saa ya michezo',
    '⏲' => 'saa ya kupima muda',
    '🕰' => 'saa ya mezani',
    '🕛' => 'saa sita',
    '🕧' => 'saa sita na nusu',
    '🕐' => 'saa saba',
    '🕜' => 'saa saba na nusu',
    '🕑' => 'saa nane',
    '🕝' => 'saa nane na nusu',
    '🕒' => 'saa tisa',
    '🕞' => 'saa tisa na nusu',
    '🕓' => 'saa kumi',
    '🕟' => 'saa kumi na nusu',
    '🕔' => 'saa kumi na moja',
    '🕠' => 'saa kumi na moja na nusu',
    '🕕' => 'saa kumi na mbili',
    '🕡' => 'sa kumi na mbili na nusu',
    '🕖' => 'saa moja',
    '🕢' => 'saa moja na nusu',
    '🕗' => 'saa mbili',
    '🕣' => 'saa mbili na nusu',
    '🕘' => 'saa tatu',
    '🕤' => 'saa tatu na nusu',
    '🕙' => 'saa nne',
    '🕥' => 'saa nne na nusu',
    '🕚' => 'saa tano',
    '🕦' => 'saa tano na nusu',
    '🌑' => 'mwezi mpya',
    '🌒' => 'mwezi mwandamo',
    '🌓' => 'mwezi wa robo ya kwanza',
    '🌔' => 'mwezi ulioangazwa zaidi ya nusu unaopevuka',
    '🌕' => 'mwezi kamili',
    '🌖' => 'mwezi ulioangazwa zaidi ya nusu unaofifia',
    '🌗' => 'mwezi wa robo ya mwisho',
    '🌘' => 'mwezi kongo',
    '🌙' => 'mwezi unaoandama mwezi mpya',
    '🌚' => 'uso wa mwezi mpya',
    '🌛' => 'mwezi wa robo ya kwanza wenye uso',
    '🌜' => 'mwezi wa robo ya mwisho wenye uso',
    '🌡' => 'pima joto',
    '☀' => 'jua',
    '🌝' => 'uso unaokaa mwezi',
    '🌞' => 'uso unaokaa jua',
    '🪐' => 'sayari yenye duara',
    '⭐' => 'nyota nyeupe ya wastani',
    '🌟' => 'nyota inayong’aa',
    '🌠' => 'kimwondo',
    '🌌' => 'kilimia',
    '☁' => 'wingu',
    '⛅' => 'jua nyuma ya wingu',
    '⛈' => 'wingu pamoja na radi na mvua',
    '🌤' => 'jua nyuma ya wingu dogo',
    '🌥' => 'jua nyuma ya wingu kubwa',
    '🌦' => 'jua nyuma ya wingu lenye mvua',
    '🌧' => 'wingu lenye mvua',
    '🌨' => 'wingu lenye theluji',
    '🌩' => 'wingu lenye radi',
    '🌪' => 'kimbunga',
    '🌫' => 'ukungu',
    '🌬' => 'uso unaopuliza upepo',
    '🌀' => 'tufani',
    '🌈' => 'upinde wa mvua',
    '🌂' => 'mwavuli uliokunjwa',
    '☂' => 'mwavuli',
    '☔' => 'mwavuli na matone ya mvua',
    '⛱' => 'mwavuli ulio kwenye ardhi',
    '⚡' => 'volteji ya juu',
    '❄' => 'chembe ya theluji',
    '☃' => 'sanamu ya mtu ya theluji',
    '⛄' => 'sanamu ya mtu ya theluji bila theluji',
    '☄' => 'kimondo',
    '🔥' => 'moto',
    '💧' => 'tone',
    '🌊' => 'wimbi la maji',
    '🎃' => 'taa ya malenge yenye umbo la uso wa mtu',
    '🎄' => 'mti wa krismasi',
    '🎆' => 'fataki',
    '🎇' => 'kimetameta',
    '🧨' => 'fataki ya kuchezea',
    '✨' => 'nyota',
    '🎈' => 'puto',
    '🎉' => 'mapambo ya sherehe',
    '🎊' => 'mpira wa mapambo',
    '🎋' => 'mti wa tanabata',
    '🎍' => 'mapambo ya msonobari',
    '🎎' => 'wanaserere wa kijapani',
    '🎏' => 'bendera ya kambare mamba',
    '🎐' => 'kengele ya upepo',
    '🎑' => 'sherehe ya mwezi',
    '🧧' => 'bahasha nyekundu',
    '🎀' => 'utepe',
    '🎁' => 'zawadi iliyofungwa',
    '🎗' => 'utepe wa ukumbusho',
    '🎟' => 'tiketi za kuingia',
    '🎫' => 'tiketi',
    '🎖' => 'tuzo ya kijeshi',
    '🏆' => 'kikombe',
    '🏅' => 'medali ya michezo',
    '🥇' => 'nishani ya dhababu',
    '🥈' => 'nishani ya fedha',
    '🥉' => 'nishani ya shaba',
    '⚽' => 'mpira wa miguu',
    '⚾' => 'mpira wa besibali',
    '🥎' => 'besibali',
    '🏀' => 'mpira wa kikapu',
    '🏐' => 'mpira wa wavu',
    '🏈' => 'mpira wa marekani',
    '🏉' => 'mpira wa raga',
    '🎾' => 'mpira wa tenisi',
    '🥏' => 'kurusha kisahani',
    '🎳' => 'mchezo wa kuvingirisha matufe chini',
    '🏏' => 'kriketi',
    '🏑' => 'mpira wa magongo',
    '🏒' => 'kigoe cha hoki ya barafuni',
    '🥍' => 'mchezo wa lakrosi',
    '🏓' => 'tenisi ya mezani',
    '🏸' => 'mpira wa vinyoya',
    '🥊' => 'glavu za ndondi',
    '🥋' => 'vazi la karate',
    '🥅' => 'wavu',
    '⛳' => 'bendera katika shimo',
    '⛸' => 'viatu vya kuteleza kwenye theluji',
    '🎣' => 'ndoano ya uvuvi',
    '🤿' => 'barakoa ya kupiga mbizi',
    '🎽' => 'shati la kukimbia',
    '🎿' => 'skii',
    '🛷' => 'sleji',
    '🥌' => 'mpira wa kutelezesha',
    '🎯' => 'kulenga shabaha',
    '🪀' => 'kigurudumu cha uzi',
    '🪁' => 'kishada',
    '🔫' => 'bastola ya maji',
    '🎱' => 'biliadi',
    '🔮' => 'tufe la kioo',
    '🪄' => 'kifimbo cha miujiza',
    '🎮' => 'mchezo wa video',
    '🕹' => 'usukani',
    '🎰' => 'mashine ya kamari',
    '🎲' => 'dadu',
    '🧩' => 'kipande cha mchezo wa mafumbo',
    '🧸' => 'mwanaserere wa dubu',
    '🪅' => 'pinata',
    '🪩' => 'tufe la vioo',
    '🪆' => 'mwanaserere wa kirusi',
    '♠' => 'shupaza',
    '♥' => 'kopa',
    '♦' => 'kisu',
    '♣' => 'maua',
    '♟' => 'kipande cha saratanji',
    '🃏' => 'jokari',
    '🀄' => 'dragoni jekundu la mahjong',
    '🎴' => 'kadi za karata za maua',
    '🎭' => 'sanaa',
    '🖼' => 'fremu yenye picha',
    '🎨' => 'paleti ya msanii',
    '🧵' => 'uzi',
    '🪡' => 'sindano ya kushona',
    '🧶' => 'uzi uliosokotwa',
    '🪢' => 'fundo',
    '👓' => 'miwani',
    '🕶' => 'miwani ya jua',
    '🥽' => 'miwani ya kuogelea',
    '🥼' => 'koti jeupe',
    '🦺' => 'jaketi la usalama',
    '👔' => 'tai',
    '👕' => 'fulana',
    '👖' => 'suruali ya jinzi',
    '🧣' => 'shali',
    '🧤' => 'glavu',
    '🧥' => 'koti',
    '🧦' => 'soksi',
    '👗' => 'nguo',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'nguo ya kuogelea',
    '🩲' => 'chupi',
    '🩳' => 'kaptura',
    '👙' => 'bikini',
    '👚' => 'nguo za wanawake',
    '🪭' => 'feni ya kujipepeta',
    '👛' => 'kibeti',
    '👜' => 'mfuko',
    '👝' => 'kipochi',
    '🛍' => 'mifuko ya kubebea bidhaa',
    '🎒' => 'mfuko wa shuleni',
    '🩴' => 'ndara',
    '👞' => 'kiatu cha wanaume',
    '👟' => 'kiatu cha kukimbia',
    '🥾' => 'kiatu cha kutembea mbali',
    '🥿' => 'kiatu kisicho na kisigino',
    '👠' => 'kiatu chenye kisigino kirefu',
    '👡' => 'ndara ya mwanamke',
    '🩰' => 'viatu vya bale',
    '👢' => 'buti la mwanamke',
    '🪮' => 'kitana',
    '👑' => 'taji',
    '👒' => 'kofia ya mwanamke',
    '🎩' => 'kofia ya mwanamume',
    '🎓' => 'kofia ya mahafali',
    '🧢' => 'chepeo',
    '🪖' => 'kofia ya wanajeshi',
    '⛑' => 'helmeti iliyo na msalaba mweupe',
    '📿' => 'shanga za maombi',
    '💄' => 'rangi ya midomo',
    '💍' => 'pete',
    '💎' => 'kito',
    '🔇' => 'spika imezimwa',
    '🔈' => 'sauti ya chini ya spika',
    '🔉' => 'spika imewashwa',
    '🔊' => 'spika yenye sauti ya juu',
    '📢' => 'kipaza sauti',
    '📣' => 'megafoni',
    '📯' => 'honi ya posta',
    '🔔' => 'kengele',
    '🔕' => 'kengele yenye alama ya mkato',
    '🎼' => 'karatasi ya muziki',
    '🎵' => 'noti ya muziki',
    '🎶' => 'manoti ya muziki',
    '🎙' => 'maikrofoni ya studio',
    '🎚' => 'kitelezi cha kurekebisha sauti',
    '🎛' => 'vitufe vya kudhibiti',
    '🎤' => 'maikrofoni',
    '🎧' => 'spika za masikioni',
    '📻' => 'redio',
    '🎷' => 'saksafoni',
    '🎺' => 'tarumbeta',
    '🪊' => 'tromboni',
    '🪗' => 'kodiani',
    '🎸' => 'gita',
    '🎹' => 'kinanda',
    '🎻' => 'fidla',
    '🪕' => 'gambusi',
    '🥁' => 'ngoma',
    '🪘' => 'ngoma refu',
    '🪇' => 'maraka',
    '🪈' => 'zumari',
    '🪉' => 'kinubi',
    '📱' => 'simu ya mkononi',
    '📲' => 'simu ya mkononi yenye kishale',
    '☎' => 'simu',
    '📞' => 'mkono wa simu',
    '📟' => 'peja',
    '📠' => 'mashine ya faksi',
    '🔋' => 'betri',
    '🪫' => 'betri iliyopungua chaji',
    '🔌' => 'plagi ya umeme',
    '💻' => 'kompyuta ndogo',
    '🖥' => 'kompyuta ya mezani',
    '🖨' => 'printa',
    '⌨' => 'kibodi',
    '🖱' => 'kipanya cha kompyuta',
    '🖲' => 'kitufe cha kompyuta kinachoendesha kishale',
    '💽' => 'diski ndogo',
    '💾' => 'diski laini',
    '💿' => 'diski ya kutumia mwangaza',
    '📀' => 'diski dijitali',
    '🧮' => 'abaki',
    '🎥' => 'kamera ya kurekodi filamu',
    '🎞' => 'fremu za utepe wa filamu',
    '📽' => 'projekta ya filamu',
    '🎬' => 'ubao wa kuanzisha matukio wakati wa kutengeneza filamu',
    '📺' => 'runinga',
    '📷' => 'kamera',
    '📸' => 'kamera yenye mmweko',
    '📹' => 'kamera ya kurekodi video',
    '📼' => 'kaseti ya video',
    '🔍' => 'kioo cha ukuzaji kinachoelekeza kushoto',
    '🔎' => 'kioo cha ukuzaji kinachoelekeza kulia',
    '🕯' => 'mshumaa',
    '💡' => 'taa',
    '🔦' => 'kurunzi',
    '🏮' => 'taa nyekundu ya karatasi',
    '🪔' => 'taa ya diya',
    '📔' => 'daftari lenye jalada lililopambwa',
    '📕' => 'kitabu kilichofungwa',
    '📖' => 'kitabu kilichofunguliwa',
    '📗' => 'kitabu cha kijani',
    '📘' => 'kitabu cha samawati',
    '📙' => 'kitabu cha njano',
    '📚' => 'vitabu',
    '📓' => 'daftari',
    '📒' => 'leja',
    '📃' => 'ukurasa uliokunjwa',
    '📜' => 'hati ya kukunja kwa kuviringisha',
    '📄' => 'ukurasa unaotazama juu',
    '📰' => 'gazeti',
    '🗞' => 'gazeti lililokunjwa',
    '📑' => 'vichupo vya alamisho',
    '🔖' => 'alamisho',
    '🏷' => 'lebo',
    '🪙' => 'sarafu',
    '💰' => 'mfuko wa pesa',
    '🪎' => 'kasha',
    '💴' => 'noti ya yeni',
    '💵' => 'noti ya dola',
    '💶' => 'noti ya yuro',
    '💷' => 'noti ya pauni',
    '💸' => 'pesa za noti zenye mabawa',
    '💳' => 'kadi ya mkopo',
    '🧾' => 'risiti',
    '💹' => 'chati inayopanda yenye yeni',
    '✉' => 'bahasha',
    '📧' => 'barua pepe',
    '📨' => 'bahasha inayoingia',
    '📩' => 'bahasha na kishale',
    '📤' => 'trei ya majalada ya kutoka',
    '📥' => 'trei ya majalada ya kuingia',
    '📦' => 'kifurushi',
    '📫' => 'sanduku la barua lililofungwa lenye bendera iliyoinuliwa',
    '📪' => 'sanduku la barua lililofungwa lenye bendera iliyoshushwa',
    '📬' => 'sanduku la barua lililofunguliwa lenye bendera iliyoinuliwa',
    '📭' => 'sanduku la barua lililofunguliwa lenye bendera iliyoshushwa',
    '📮' => 'sanduku la barua',
    '🗳' => 'sanduku la kupiga kura na kura',
    '✏' => 'penseli',
    '✒' => 'nibu nyeusi',
    '🖋' => 'kalamu ya wino',
    '🖊' => 'kalamu',
    '🖌' => 'brashi ya kupaka rangi',
    '🖍' => 'penseli laini',
    '📝' => 'hati',
    '💼' => 'mkoba',
    '📁' => 'folda ya faili',
    '📂' => 'folda ya faili iliyofunguliwa',
    '🗂' => 'vigawanishi vya kadi',
    '📅' => 'kalenda',
    '📆' => 'kalenda unayoweza kuchana kurasa',
    '🗒' => 'daftari lililobanwa kwa waya wa mzunguko',
    '🗓' => 'kalenda iliyofungwa kwa waya wa mzunguko',
    '📇' => 'kadi',
    '📈' => 'chati inayopanda',
    '📉' => 'chati inayoshuka',
    '📊' => 'chati ya miraba',
    '📋' => 'ubao wa kunakili',
    '📌' => 'pini',
    '📍' => 'pini yenye kichwa cha mduara',
    '📎' => 'kishikizo',
    '🖇' => 'klipu za karatasi zilizounganishwa',
    '📏' => 'rula',
    '📐' => 'rula ya pembe',
    '✂' => 'makasi',
    '🗃' => 'sanduku la faili',
    '🗄' => 'kabati la hati',
    '🗑' => 'ndoo la taka',
    '🔒' => 'kufuli',
    '🔓' => 'kufuli iliyofunguliwa',
    '🔏' => 'kufuli na kalamu',
    '🔐' => 'kufuli iliyofungwa na ufunguo',
    '🔑' => 'ufunguo',
    '🗝' => 'ufunguo wa zamani',
    '🔨' => 'nyundo',
    '🪓' => 'shoka',
    '⛏' => 'sululu',
    '⚒' => 'nyundo na sululu',
    '🛠' => 'nyundo na spana malaya',
    '🗡' => 'sime',
    '⚔' => 'panga zilizopishanishwa',
    '💣' => 'bomu',
    '🪃' => 'bumerangi',
    '🏹' => 'upinde na mshale',
    '🛡' => 'ngao',
    '🪚' => 'msumeno',
    '🔧' => 'spana malaya',
    '🪛' => 'bisibisi',
    '🔩' => 'nati na bolti',
    '⚙' => 'gia',
    '🗜' => 'kubana',
    '⚖' => 'mzani',
    '🦯' => 'mkongojo wa vipofu',
    '🔗' => 'pete ya mnyororo',
    '⛓' => 'minyororo',
    '🪝' => 'ndoano',
    '🧰' => 'kisanduku cha vifaa',
    '🧲' => 'sumaku',
    '🪜' => 'ngazi',
    '🪏' => 'sepetu',
    '⚗' => 'alembiki',
    '🧪' => 'neli ya majaribio',
    '🧫' => 'chombo cha kupondea',
    '🧬' => 'dna',
    '🔬' => 'hadubini',
    '🔭' => 'darubini',
    '📡' => 'antena ya setilaiti',
    '💉' => 'bomba la sindano',
    '🩸' => 'tone la damu',
    '💊' => 'kidonge',
    '🩹' => 'bendeji inayonata',
    '🩼' => 'gongo',
    '🩺' => 'stetoskopu',
    '🩻' => 'eksirei',
    '🚪' => 'mlango',
    '🛗' => 'kambarau',
    '🪞' => 'kioo',
    '🪟' => 'dirisha',
    '🛏' => 'kitanda',
    '🛋' => 'kochi na taa',
    '🪑' => 'kiti',
    '🚽' => 'choo',
    '🪠' => 'kizibuo',
    '🚿' => 'bafu ya manyunyu',
    '🛁' => 'bafu',
    '🪤' => 'mtego wa panya',
    '🪒' => 'wembe',
    '🧴' => 'chupa ya losheni',
    '🧷' => 'kikwasi',
    '🧹' => 'ufagio',
    '🧺' => 'kikapu',
    '🧻' => 'karatasi',
    '🪣' => 'ndoo',
    '🧼' => 'sabuni',
    '🫧' => 'viputo',
    '🪥' => 'mswaki',
    '🧽' => 'sifongo',
    '🧯' => 'kizima moto',
    '🛒' => 'kigari cha kununulia bidhaa',
    '🚬' => 'sigara iliyowashwa',
    '⚰' => 'jeneza',
    '🪦' => 'jiwe la kaburi',
    '⚱' => 'chombo cha kutia majivu ya maiti aliyechomwa',
    '🧿' => 'hirizi',
    '🪬' => 'ishara ya hamsa',
    '🗿' => 'kinyago',
    '🪧' => 'bango',
    '🪪' => 'kitambulisho',
    '🏧' => 'alama ya ATM',
    '🚮' => 'weka taka kwenye pipa',
    '🚰' => 'maji safi ya kunywa',
    '♿' => 'kiti cha magurudumu',
    '🚹' => 'maliwato ya wanaume',
    '🚺' => 'maliwato ya wanawake',
    '🚻' => 'maliwato',
    '🚼' => 'alama ya mtoto',
    '🚾' => 'msala',
    '🛂' => 'udhibiti wa pasipoti',
    '🛃' => 'forodha',
    '🛄' => 'madai ya mzigo',
    '🛅' => 'mahali pa kuhifadhi mizigo',
    '⚠' => 'onyo',
    '🚸' => 'watoto wanavuka barabara',
    '⛔' => 'hakuna kuingia',
    '🚫' => 'imepigwa marufuku',
    '🚳' => 'baisikeli haziruhusiwi',
    '🚭' => 'hakuna kuvuta sigara',
    '🚯' => 'hakuna kutupa taka',
    '🚱' => 'maji hayafai kwa matumizi ya kunywa',
    '🚷' => 'watembea kwa miguu hawaruhusiwi',
    '📵' => 'simu za mkononi haziruhusiwi',
    '🔞' => 'walio chini ya miaka kumi na nane hawaruhusiwi',
    '☢' => 'mnururisho',
    '☣' => 'tahadhari ya kibilojia',
    '⬆' => 'mshale unaoelekeza juu',
    '↗' => 'mshale unaoelekeza juu kulia',
    '➡' => 'mshale unaoelekeza kulia',
    '↘' => 'mshale unaoelekeza chini kulia',
    '⬇' => 'mshale unaoangalia chini',
    '↙' => 'mshale unaoelekeza chini kushoto',
    '⬅' => 'mshale unaoelekeza kushoto',
    '↖' => 'mshale unaoelekeza juu kushoto',
    '↕' => 'mshale unaoelekeza chini na juu',
    '↔' => 'mshale unaoeleza kushoto na kulia',
    '↩' => 'mshale wa kulia unaopinda kushoto',
    '↪' => 'mshale wa kushoto unaopinda kulia',
    '⤴' => 'mshale wa kulia unaopinda juu',
    '⤵' => 'mshale wa kulia unaopinda chini',
    '🔃' => 'mishale wima inayoelekeza kwa mzunguko wa akrabu',
    '🔄' => 'kitufe cha mishale ya kinyume saa',
    '🔙' => 'mshale wa nyuma',
    '🔚' => 'mshale wa mwisho',
    '🔛' => 'mshale wa hewani!',
    '🔜' => 'mshale unaoashiria hivi karibuni',
    '🔝' => 'mshale unaoangalia juu',
    '🛐' => 'mahali pa kuabudu',
    '⚛' => 'alama ya atomu',
    '🕉' => 'omu',
    '✡' => 'nyota ya daudi',
    '☸' => 'gurudumu la dharma',
    '☯' => 'yin yang',
    '✝' => 'msalaba wa kilatini',
    '☦' => 'msalaba',
    '☪' => 'nyota na mwezi mwandamo',
    '☮' => 'alama ya amani',
    '🕎' => 'menorah',
    '🔯' => 'nyota yenye pembe sita na kitone katikati',
    '🪯' => 'khanda',
    '♈' => 'nyota ya kondoo',
    '♉' => 'fahali',
    '♊' => 'mapacha',
    '♋' => 'nyota ya kaa',
    '♌' => 'nyota ya simba',
    '♍' => 'mashuke',
    '♎' => 'mizani',
    '♏' => 'nyota ya nge',
    '♐' => 'mshale',
    '♑' => 'nyota ya mbuzi',
    '♒' => 'nyota ya ndoo',
    '♓' => 'nyota ya samaki',
    '⛎' => 'opichasi',
    '🔀' => 'kitufe cha kuchanganya',
    '🔁' => 'kitufe cha kurudia',
    '🔂' => 'kitufe cha kurudia wimbo mmoja',
    '▶' => 'kitufe cha kucheza',
    '⏩' => 'kitufe cha kupeleka mbele kwa kasi',
    '⏭' => 'kitufe cha kwenda kwenye wimbo unaofuata',
    '⏯' => 'kitufe cha kucheza au kusitisha',
    '◀' => 'kitufe cha kurudisha nyuma',
    '⏪' => 'kitufe cha kurudisha nyuma kwa kasi',
    '⏮' => 'kitufe cha kurudia wimbo uliopita',
    '🔼' => 'kitufe cha juu',
    '⏫' => 'kitufe cha juu kwa kasi',
    '🔽' => 'kitufe cha chini',
    '⏬' => 'kitufe cha chini kwa kasi',
    '⏸' => 'kitufe cha kusitisha',
    '⏹' => 'kitufe cha kusimamisha',
    '⏺' => 'kitufe cha kurekodi',
    '⏏' => 'kitufe cha kutoa',
    '🎦' => 'filamu',
    '🔅' => 'kitufe cha kufifisha mwanga',
    '🔆' => 'kitufe cha kuongeza mwanga',
    '📶' => 'pau za antena',
    '🛜' => 'pasiwaya',
    '📳' => 'hali ya mtetemo',
    '📴' => 'zima simu za mkononi',
    '♀' => 'ishara ya jinsia ya kike',
    '♂' => 'ishara ya jinsia ya kiume',
    '⚧' => 'ishara ya wabadili jinsia',
    '✖' => 'zidisha',
    '➕' => 'kuongeza',
    '➖' => 'kutoa',
    '➗' => 'gawanya',
    '🟰' => 'ishara ya usawa',
    '♾' => 'milele',
    '‼' => 'alama mbili za mshangao',
    '⁉' => 'alama ya mshangao na kuuliza',
    '❓' => 'alama nyekundu ya kuuliza',
    '❔' => 'alama nyeupe ya kuuliza',
    '❕' => 'alama nyeupe ya mshangao',
    '❗' => 'alama nyekundu ya mshangao',
    '〰' => 'dashi iliyopinda',
    '💱' => 'ubadilishanaji wa sarafu',
    '💲' => 'alama nzito ya dola',
    '⚕' => 'ishara ya taaluma ya matibabu',
    '♻' => 'alama ya kutumia tena',
    '⚜' => 'ua la yungi',
    '🔱' => 'nembo ya ncha tatu',
    '📛' => 'beji ya jina',
    '🔰' => 'alama ya kijapani ya anayeanza',
    '⭕' => 'mduara mwekundu wenye shimo',
    '✅' => 'alama nyeupe ya tiki',
    '☑' => 'sanduku la kuteua lenye tiki',
    '✔' => 'alama ya tiki',
    '❌' => 'alama ya X',
    '❎' => 'kitufe cha alama ya kuzidisha',
    '➰' => 'kitanzi kilichopinda',
    '➿' => 'kitanzi kilichopinda mara mbili',
    '〽' => 'alama ya mbadala ya sehemu',
    '✳' => 'kinyota chenye ncha nane',
    '✴' => 'nyota yenye ncha nane',
    '❇' => 'metameta',
    '™' => 'chapa ya biashara',
    '🫟' => 'mtawanyiko',
    '🔠' => 'weka herufi kubwa za kilatini',
    '🔡' => 'weka hefuri ndogo za kilatini',
    '🔢' => 'weka nambari',
    '🔣' => 'weka alama',
    '🔤' => 'weka herufi za kilatini',
    '🅰' => 'kitufe chenye herufi A',
    '🆎' => 'kitufe chenye herufi AB',
    '🅱' => 'kitufe chenye herufi B',
    '🆑' => 'kitufe chenye herufi CL',
    '🆒' => 'kitufe chenye neno ‘COOL’',
    '🆓' => 'kitufe cheney neno ‘FREE’',
    'ℹ' => 'kitufe cha maelezo',
    '🆔' => 'herufi ID kwenye mraba',
    'Ⓜ' => 'herufi M kwenye mduara',
    '🆕' => 'kitufe chenye neno ‘NEW’',
    '🆖' => 'kitufe chenye herufi NG',
    '🅾' => 'kitufe cha O',
    '🆗' => 'kitufe chenye neno ‘OK’',
    '🅿' => 'kitufe cha P',
    '🆘' => 'kitufe chenye neno ‘SOS’',
    '🆙' => 'kitufe cha UP!',
    '🆚' => 'kitufe cha VS',
    '🈁' => 'katakana koko kwenye mraba',
    '🈂' => 'katakana sa kwenye mraba',
    '🈷' => 'idiografu ya mwezi kwenye mraba',
    '🈶' => 'idiografu ya kuwepo kwenye mraba',
    '🈯' => 'idiografu ya kidole kwenye mraba',
    '🉐' => 'idiografu ya manufaa kwenye mduara',
    '🈹' => 'idiografu ya kugawanya kwenye mraba',
    '🈚' => 'idiografu ya kutoa kwenye mraba',
    '🈲' => 'idiografu ya marufuku kwenye mraba',
    '🉑' => 'idiografu ya kukubali kwenye mduara',
    '🈸' => 'idiografu ya kutumia kwenye mraba',
    '🈴' => 'idiografu ya pamoja kwenye mraba',
    '🈳' => 'idiografu tupu kwenye mraba',
    '㊗' => 'idiografu ya pongezi kwenye mduara',
    '㊙' => 'idiografu ya siri kwenye mduara',
    '🈺' => 'idiografu ya kuendesha kwenye mraba',
    '🈵' => 'idiografu ya kujaa kwenye mraba',
    '🔴' => 'mduara mwekundu',
    '🟠' => 'mduara wa chungwa',
    '🟡' => 'mduara wa manjano',
    '🟢' => 'mduara wa kijani',
    '🔵' => 'mduara wa samawati',
    '🟣' => 'mduara wa zambarau',
    '🟤' => 'mduara wa hudhurungi',
    '⚫' => 'mduara mweusi',
    '⚪' => 'mduara mweupe',
    '🟥' => 'mraba mwekundu',
    '🟧' => 'mraba wa chungwa',
    '🟨' => 'mraba wa manjano',
    '🟩' => 'mraba wa kijani',
    '🟦' => 'mraba wa samawati',
    '🟪' => 'mraba wa zambarau',
    '🟫' => 'mraba wa hudhurungi',
    '⬛' => 'mraba mkubwa mweusi',
    '⬜' => 'mraba mkubwa mweupe',
    '◼' => 'mraba wa wastani mweusi',
    '◻' => 'mraba wa wastani mweupe',
    '◾' => 'mraba wastani mdogo mweusi',
    '◽' => 'mraba wastani mdogo mweupe',
    '▪' => 'mraba mdogo mweusi',
    '▫' => 'mraba mdogo mweupe',
    '🔶' => 'almasi kubwa ya njano',
    '🔷' => 'almasi kubwa ya samawati',
    '🔸' => 'almasi ndogo ya njano',
    '🔹' => 'almasi ndogo ya samawati',
    '🔺' => 'pembetatu inayoelekeza juu',
    '🔻' => 'pembetatu inayoelekeza chini',
    '💠' => 'almasi yenye kitone',
    '🔘' => 'kitufe',
    '🔳' => 'kitufe cheupe cha mraba',
    '🔲' => 'kitufe cheusi cha mraba',
    '🏁' => 'bendera yenye mirabaraba',
    '🚩' => 'bendera yenye pembe',
    '🎌' => 'bendera mbili zilizopishana',
    '🏴' => 'kupeperusha bendera nyeusi',
    '🏳' => 'kupeperusha bendera nyeupe',
];
