<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'ʻuma: kakai lalahi, kakai lalahi, kili hinehina mo e kili kelokelo',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'ʻuma: kakai lalahi, kakai lalahi, kili hinehina mo e kili melomelo',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'ʻuma: kakai lalahi, kakai lalahi, kili hinehina mo e kili melomelo-ʻuliʻuli',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'ʻuma: kakai lalahi, kakai lalahi, kili hinehina mo e kili ʻuliʻuli',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'ʻuma: kakai lalahi, kakai lalahi, kili kelokelo mo e kili hinehina',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'ʻuma: kakai lalahi, kakai lalahi, kili kelokelo mo e kili melomelo',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'ʻuma: kakai lalahi, kakai lalahi, kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'ʻuma: kakai lalahi, kakai lalahi, kili kelokelo mo e kili ʻuliʻuli',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'ʻuma: kakai lalahi, kakai lalahi, kili melomelo mo e kili hinehina',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'ʻuma: kakai lalahi, kakai lalahi, kili melomelo mo e kili kelokelo',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'ʻuma: kakai lalahi, kakai lalahi, kili melomelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'ʻuma: kakai lalahi, kakai lalahi, kili melomelo mo e kili ʻuliʻuli',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'ʻuma: kakai lalahi, kakai lalahi, kili melomelo-ʻuliʻuli mo e kili hinehina',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'ʻuma: kakai lalahi, kakai lalahi, kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'ʻuma: kakai lalahi, kakai lalahi, kili melomelo-ʻuliʻuli mo e kili melomelo',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'ʻuma: kakai lalahi, kakai lalahi, kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'ʻuma: kakai lalahi, kakai lalahi, kili ʻuliʻuli mo e kili hinehina',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'ʻuma: kakai lalahi, kakai lalahi, kili ʻuliʻuli mo e kili kelokelo',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'ʻuma: kakai lalahi, kakai lalahi, kili ʻuliʻuli mo e kili melomelo',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'ʻuma: kakai lalahi, kakai lalahi, kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👨🏻‍❤‍💋‍👨🏻' => 'ʻuma: tangata, tangata mo e kili hinehina',
    '👨🏻‍❤‍💋‍👨🏼' => 'ʻuma: tangata, tangata, kili hinehina mo e kili kelokelo',
    '👨🏻‍❤‍💋‍👨🏽' => 'ʻuma: tangata, tangata, kili hinehina mo e kili melomelo',
    '👨🏻‍❤‍💋‍👨🏾' => 'ʻuma: tangata, tangata, kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👨🏻‍❤‍💋‍👨🏿' => 'ʻuma: tangata, tangata, kili hinehina mo e kili ʻuliʻuli',
    '👨🏼‍❤‍💋‍👨🏻' => 'ʻuma: tangata, tangata, kili kelokelo mo e kili hinehina',
    '👨🏼‍❤‍💋‍👨🏼' => 'ʻuma: tangata, tangata mo e kili kelokelo',
    '👨🏼‍❤‍💋‍👨🏽' => 'ʻuma: tangata, tangata, kili kelokelo mo e kili melomelo',
    '👨🏼‍❤‍💋‍👨🏾' => 'ʻuma: tangata, tangata, kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👨🏼‍❤‍💋‍👨🏿' => 'ʻuma: tangata, tangata, kili kelokelo mo e kili ʻuliʻuli',
    '👨🏽‍❤‍💋‍👨🏻' => 'ʻuma: tangata, tangata, kili melomelo mo e kili hinehina',
    '👨🏽‍❤‍💋‍👨🏼' => 'ʻuma: tangata, tangata, kili melomelo mo e kili kelokelo',
    '👨🏽‍❤‍💋‍👨🏽' => 'ʻuma: tangata, tangata mo e kili melomelo',
    '👨🏽‍❤‍💋‍👨🏾' => 'ʻuma: tangata, tangata, kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👨🏽‍❤‍💋‍👨🏿' => 'ʻuma: tangata, tangata, kili melomelo mo e kili ʻuliʻuli',
    '👨🏾‍❤‍💋‍👨🏻' => 'ʻuma: tangata, tangata, kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👨🏾‍❤‍💋‍👨🏼' => 'ʻuma: tangata, tangata, kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👨🏾‍❤‍💋‍👨🏽' => 'ʻuma: tangata, tangata, kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👨🏾‍❤‍💋‍👨🏾' => 'ʻuma: tangata, tangata mo e kili melomelo-ʻuliʻuli',
    '👨🏾‍❤‍💋‍👨🏿' => 'ʻuma: tangata, tangata, kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👨🏿‍❤‍💋‍👨🏻' => 'ʻuma: tangata, tangata, kili ʻuliʻuli mo e kili hinehina',
    '👨🏿‍❤‍💋‍👨🏼' => 'ʻuma: tangata, tangata, kili ʻuliʻuli mo e kili kelokelo',
    '👨🏿‍❤‍💋‍👨🏽' => 'ʻuma: tangata, tangata, kili ʻuliʻuli mo e kili melomelo',
    '👨🏿‍❤‍💋‍👨🏾' => 'ʻuma: tangata, tangata, kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👨🏿‍❤‍💋‍👨🏿' => 'ʻuma: tangata, tangata mo e kili ʻuliʻuli',
    '👩🏻‍❤‍💋‍👨🏻' => 'ʻuma: fefine, tangata mo e kili hinehina',
    '👩🏻‍❤‍💋‍👨🏼' => 'ʻuma: fefine, tangata, kili hinehina mo e kili kelokelo',
    '👩🏻‍❤‍💋‍👨🏽' => 'ʻuma: fefine, tangata, kili hinehina mo e kili melomelo',
    '👩🏻‍❤‍💋‍👨🏾' => 'ʻuma: fefine, tangata, kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍❤‍💋‍👨🏿' => 'ʻuma: fefine, tangata, kili hinehina mo e kili ʻuliʻuli',
    '👩🏼‍❤‍💋‍👨🏻' => 'ʻuma: fefine, tangata, kili kelokelo mo e kili hinehina',
    '👩🏼‍❤‍💋‍👨🏼' => 'ʻuma: fefine, tangata mo e kili kelokelo',
    '👩🏼‍❤‍💋‍👨🏽' => 'ʻuma: fefine, tangata, kili kelokelo mo e kili melomelo',
    '👩🏼‍❤‍💋‍👨🏾' => 'ʻuma: fefine, tangata, kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👩🏼‍❤‍💋‍👨🏿' => 'ʻuma: fefine, tangata, kili kelokelo mo e kili ʻuliʻuli',
    '👩🏽‍❤‍💋‍👨🏻' => 'ʻuma: fefine, tangata, kili melomelo mo e kili hinehina',
    '👩🏽‍❤‍💋‍👨🏼' => 'ʻuma: fefine, tangata, kili melomelo mo e kili kelokelo',
    '👩🏽‍❤‍💋‍👨🏽' => 'ʻuma: fefine, tangata mo e kili melomelo',
    '👩🏽‍❤‍💋‍👨🏾' => 'ʻuma: fefine, tangata, kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👩🏽‍❤‍💋‍👨🏿' => 'ʻuma: fefine, tangata, kili melomelo mo e kili ʻuliʻuli',
    '👩🏾‍❤‍💋‍👨🏻' => 'ʻuma: fefine, tangata, kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👩🏾‍❤‍💋‍👨🏼' => 'ʻuma: fefine, tangata, kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👩🏾‍❤‍💋‍👨🏽' => 'ʻuma: fefine, tangata, kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👩🏾‍❤‍💋‍👨🏾' => 'ʻuma: fefine, tangata mo e kili melomelo-ʻuliʻuli',
    '👩🏾‍❤‍💋‍👨🏿' => 'ʻuma: fefine, tangata, kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👩🏿‍❤‍💋‍👨🏻' => 'ʻuma: fefine, tangata, kili ʻuliʻuli mo e kili hinehina',
    '👩🏿‍❤‍💋‍👨🏼' => 'ʻuma: fefine, tangata, kili ʻuliʻuli mo e kili kelokelo',
    '👩🏿‍❤‍💋‍👨🏽' => 'ʻuma: fefine, tangata, kili ʻuliʻuli mo e kili melomelo',
    '👩🏿‍❤‍💋‍👨🏾' => 'ʻuma: fefine, tangata, kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👩🏿‍❤‍💋‍👨🏿' => 'ʻuma: fefine, tangata mo e kili ʻuliʻuli',
    '👩🏻‍❤‍💋‍👩🏻' => 'ʻuma: fefine, fefine mo e kili hinehina',
    '👩🏻‍❤‍💋‍👩🏼' => 'ʻuma: fefine, fefine, kili hinehina mo e kili kelokelo',
    '👩🏻‍❤‍💋‍👩🏽' => 'ʻuma: fefine, fefine, kili hinehina mo e kili melomelo',
    '👩🏻‍❤‍💋‍👩🏾' => 'ʻuma: fefine, fefine, kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍❤‍💋‍👩🏿' => 'ʻuma: fefine, fefine, kili hinehina mo e kili ʻuliʻuli',
    '👩🏼‍❤‍💋‍👩🏻' => 'ʻuma: fefine, fefine, kili kelokelo mo e kili hinehina',
    '👩🏼‍❤‍💋‍👩🏼' => 'ʻuma: fefine, fefine mo e kili kelokelo',
    '👩🏼‍❤‍💋‍👩🏽' => 'ʻuma: fefine, fefine, kili kelokelo mo e kili melomelo',
    '👩🏼‍❤‍💋‍👩🏾' => 'ʻuma: fefine, fefine, kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👩🏼‍❤‍💋‍👩🏿' => 'ʻuma: fefine, fefine, kili kelokelo mo e kili ʻuliʻuli',
    '👩🏽‍❤‍💋‍👩🏻' => 'ʻuma: fefine, fefine, kili melomelo mo e kili hinehina',
    '👩🏽‍❤‍💋‍👩🏼' => 'ʻuma: fefine, fefine, kili melomelo mo e kili kelokelo',
    '👩🏽‍❤‍💋‍👩🏽' => 'ʻuma: fefine, fefine mo e kili melomelo',
    '👩🏽‍❤‍💋‍👩🏾' => 'ʻuma: fefine, fefine, kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👩🏽‍❤‍💋‍👩🏿' => 'ʻuma: fefine, fefine, kili melomelo mo e kili ʻuliʻuli',
    '👩🏾‍❤‍💋‍👩🏻' => 'ʻuma: fefine, fefine, kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👩🏾‍❤‍💋‍👩🏼' => 'ʻuma: fefine, fefine, kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👩🏾‍❤‍💋‍👩🏽' => 'ʻuma: fefine, fefine, kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👩🏾‍❤‍💋‍👩🏾' => 'ʻuma: fefine, fefine mo e kili melomelo-ʻuliʻuli',
    '👩🏾‍❤‍💋‍👩🏿' => 'ʻuma: fefine, fefine, kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👩🏿‍❤‍💋‍👩🏻' => 'ʻuma: fefine, fefine, kili ʻuliʻuli mo e kili hinehina',
    '👩🏿‍❤‍💋‍👩🏼' => 'ʻuma: fefine, fefine, kili ʻuliʻuli mo e kili kelokelo',
    '👩🏿‍❤‍💋‍👩🏽' => 'ʻuma: fefine, fefine, kili ʻuliʻuli mo e kili melomelo',
    '👩🏿‍❤‍💋‍👩🏾' => 'ʻuma: fefine, fefine, kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👩🏿‍❤‍💋‍👩🏿' => 'ʻuma: fefine, fefine mo e kili ʻuliʻuli',
    '🧑🏻‍🫯‍🧑🏼' => 'kakai fangatua: kili hinehina mo e kili kelokelo',
    '🧑🏻‍🫯‍🧑🏽' => 'kakai fangatua: kili hinehina mo e kili melomelo',
    '🧑🏻‍🫯‍🧑🏾' => 'kakai fangatua: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '🧑🏻‍🫯‍🧑🏿' => 'kakai fangatua: kili hinehina mo e kili ʻuliʻuli',
    '🧑🏼‍🫯‍🧑🏻' => 'kakai fangatua: kili kelokelo mo e kili hinehina',
    '🧑🏼‍🫯‍🧑🏽' => 'kakai fangatua: kili kelokelo mo e kili melomelo',
    '🧑🏼‍🫯‍🧑🏾' => 'kakai fangatua: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏼‍🫯‍🧑🏿' => 'kakai fangatua: kili kelokelo mo e kili ʻuliʻuli',
    '🧑🏽‍🫯‍🧑🏻' => 'kakai fangatua: kili melomelo mo e kili hinehina',
    '🧑🏽‍🫯‍🧑🏼' => 'kakai fangatua: kili melomelo mo e kili kelokelo',
    '🧑🏽‍🫯‍🧑🏾' => 'kakai fangatua: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏽‍🫯‍🧑🏿' => 'kakai fangatua: kili melomelo mo e kili ʻuliʻuli',
    '🧑🏾‍🫯‍🧑🏻' => 'kakai fangatua: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '🧑🏾‍🫯‍🧑🏼' => 'kakai fangatua: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '🧑🏾‍🫯‍🧑🏽' => 'kakai fangatua: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '🧑🏾‍🫯‍🧑🏿' => 'kakai fangatua: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '🧑🏿‍🫯‍🧑🏻' => 'kakai fangatua: kili ʻuliʻuli mo e kili hinehina',
    '🧑🏿‍🫯‍🧑🏼' => 'kakai fangatua: kili ʻuliʻuli mo e kili kelokelo',
    '🧑🏿‍🫯‍🧑🏽' => 'kakai fangatua: kili ʻuliʻuli mo e kili melomelo',
    '🧑🏿‍🫯‍🧑🏾' => 'kakai fangatua: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '🧑🏻‍❤‍🧑🏼' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili hinehina mo e kili kelokelo',
    '🧑🏻‍❤‍🧑🏽' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili hinehina mo e kili melomelo',
    '🧑🏻‍❤‍🧑🏾' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili hinehina mo e kili melomelo-ʻuliʻuli',
    '🧑🏻‍❤‍🧑🏿' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili hinehina mo e kili ʻuliʻuli',
    '🧑🏼‍❤‍🧑🏻' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili kelokelo mo e kili hinehina',
    '🧑🏼‍❤‍🧑🏽' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili kelokelo mo e kili melomelo',
    '🧑🏼‍❤‍🧑🏾' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏼‍❤‍🧑🏿' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili kelokelo mo e kili ʻuliʻuli',
    '🧑🏽‍❤‍🧑🏻' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili melomelo mo e kili hinehina',
    '🧑🏽‍❤‍🧑🏼' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili melomelo mo e kili kelokelo',
    '🧑🏽‍❤‍🧑🏾' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili melomelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏽‍❤‍🧑🏿' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili melomelo mo e kili ʻuliʻuli',
    '🧑🏾‍❤‍🧑🏻' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili melomelo-ʻuliʻuli mo e kili hinehina',
    '🧑🏾‍❤‍🧑🏼' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '🧑🏾‍❤‍🧑🏽' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili melomelo-ʻuliʻuli mo e kili melomelo',
    '🧑🏾‍❤‍🧑🏿' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '🧑🏿‍❤‍🧑🏻' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili ʻuliʻuli mo e kili hinehina',
    '🧑🏿‍❤‍🧑🏼' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili ʻuliʻuli mo e kili kelokelo',
    '🧑🏿‍❤‍🧑🏽' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili ʻuliʻuli mo e kili melomelo',
    '🧑🏿‍❤‍🧑🏾' => 'ongo tokoua moe mafu: kakai lalahi, kakai lalahi, kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '🧑🏻‍🐰‍🧑🏼' => 'tokoua telinga-lāpisi: kili hinehina mo e kili kelokelo',
    '🧑🏻‍🐰‍🧑🏽' => 'tokoua telinga-lāpisi: kili hinehina mo e kili melomelo',
    '🧑🏻‍🐰‍🧑🏾' => 'tokoua telinga-lāpisi: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '🧑🏻‍🐰‍🧑🏿' => 'tokoua telinga-lāpisi: kili hinehina mo e kili ʻuliʻuli',
    '🧑🏼‍🐰‍🧑🏻' => 'tokoua telinga-lāpisi: kili kelokelo mo e kili hinehina',
    '🧑🏼‍🐰‍🧑🏽' => 'tokoua telinga-lāpisi: kili kelokelo mo e kili melomelo',
    '🧑🏼‍🐰‍🧑🏾' => 'tokoua telinga-lāpisi: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏼‍🐰‍🧑🏿' => 'tokoua telinga-lāpisi: kili kelokelo mo e kili ʻuliʻuli',
    '🧑🏽‍🐰‍🧑🏻' => 'tokoua telinga-lāpisi: kili melomelo mo e kili hinehina',
    '🧑🏽‍🐰‍🧑🏼' => 'tokoua telinga-lāpisi: kili melomelo mo e kili kelokelo',
    '🧑🏽‍🐰‍🧑🏾' => 'tokoua telinga-lāpisi: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏽‍🐰‍🧑🏿' => 'tokoua telinga-lāpisi: kili melomelo mo e kili ʻuliʻuli',
    '🧑🏾‍🐰‍🧑🏻' => 'tokoua telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '🧑🏾‍🐰‍🧑🏼' => 'tokoua telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '🧑🏾‍🐰‍🧑🏽' => 'tokoua telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '🧑🏾‍🐰‍🧑🏿' => 'tokoua telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '🧑🏿‍🐰‍🧑🏻' => 'tokoua telinga-lāpisi: kili ʻuliʻuli mo e kili hinehina',
    '🧑🏿‍🐰‍🧑🏼' => 'tokoua telinga-lāpisi: kili ʻuliʻuli mo e kili kelokelo',
    '🧑🏿‍🐰‍🧑🏽' => 'tokoua telinga-lāpisi: kili ʻuliʻuli mo e kili melomelo',
    '🧑🏿‍🐰‍🧑🏾' => 'tokoua telinga-lāpisi: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👨🏻‍🫯‍👨🏼' => 'ongo tangata fangatua: kili hinehina mo e kili kelokelo',
    '👨🏻‍🫯‍👨🏽' => 'ongo tangata fangatua: kili hinehina mo e kili melomelo',
    '👨🏻‍🫯‍👨🏾' => 'ongo tangata fangatua: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👨🏻‍🫯‍👨🏿' => 'ongo tangata fangatua: kili hinehina mo e kili ʻuliʻuli',
    '👨🏼‍🫯‍👨🏻' => 'ongo tangata fangatua: kili kelokelo mo e kili hinehina',
    '👨🏼‍🫯‍👨🏽' => 'ongo tangata fangatua: kili kelokelo mo e kili melomelo',
    '👨🏼‍🫯‍👨🏾' => 'ongo tangata fangatua: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👨🏼‍🫯‍👨🏿' => 'ongo tangata fangatua: kili kelokelo mo e kili ʻuliʻuli',
    '👨🏽‍🫯‍👨🏻' => 'ongo tangata fangatua: kili melomelo mo e kili hinehina',
    '👨🏽‍🫯‍👨🏼' => 'ongo tangata fangatua: kili melomelo mo e kili kelokelo',
    '👨🏽‍🫯‍👨🏾' => 'ongo tangata fangatua: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👨🏽‍🫯‍👨🏿' => 'ongo tangata fangatua: kili melomelo mo e kili ʻuliʻuli',
    '👨🏾‍🫯‍👨🏻' => 'ongo tangata fangatua: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👨🏾‍🫯‍👨🏼' => 'ongo tangata fangatua: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👨🏾‍🫯‍👨🏽' => 'ongo tangata fangatua: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👨🏾‍🫯‍👨🏿' => 'ongo tangata fangatua: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👨🏿‍🫯‍👨🏻' => 'ongo tangata fangatua: kili ʻuliʻuli mo e kili hinehina',
    '👨🏿‍🫯‍👨🏼' => 'ongo tangata fangatua: kili ʻuliʻuli mo e kili kelokelo',
    '👨🏿‍🫯‍👨🏽' => 'ongo tangata fangatua: kili ʻuliʻuli mo e kili melomelo',
    '👨🏿‍🫯‍👨🏾' => 'ongo tangata fangatua: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👨🏻‍❤‍👨🏻' => 'ongo tokoua moe mafu: tangata, tangata mo e kili hinehina',
    '👨🏻‍❤‍👨🏼' => 'ongo tokoua moe mafu: tangata, tangata, kili hinehina mo e kili kelokelo',
    '👨🏻‍❤‍👨🏽' => 'ongo tokoua moe mafu: tangata, tangata, kili hinehina mo e kili melomelo',
    '👨🏻‍❤‍👨🏾' => 'ongo tokoua moe mafu: tangata, tangata, kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👨🏻‍❤‍👨🏿' => 'ongo tokoua moe mafu: tangata, tangata, kili hinehina mo e kili ʻuliʻuli',
    '👨🏼‍❤‍👨🏻' => 'ongo tokoua moe mafu: tangata, tangata, kili kelokelo mo e kili hinehina',
    '👨🏼‍❤‍👨🏼' => 'ongo tokoua moe mafu: tangata, tangata mo e kili kelokelo',
    '👨🏼‍❤‍👨🏽' => 'ongo tokoua moe mafu: tangata, tangata, kili kelokelo mo e kili melomelo',
    '👨🏼‍❤‍👨🏾' => 'ongo tokoua moe mafu: tangata, tangata, kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👨🏼‍❤‍👨🏿' => 'ongo tokoua moe mafu: tangata, tangata, kili kelokelo mo e kili ʻuliʻuli',
    '👨🏽‍❤‍👨🏻' => 'ongo tokoua moe mafu: tangata, tangata, kili melomelo mo e kili hinehina',
    '👨🏽‍❤‍👨🏼' => 'ongo tokoua moe mafu: tangata, tangata, kili melomelo mo e kili kelokelo',
    '👨🏽‍❤‍👨🏽' => 'ongo tokoua moe mafu: tangata, tangata mo e kili melomelo',
    '👨🏽‍❤‍👨🏾' => 'ongo tokoua moe mafu: tangata, tangata, kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👨🏽‍❤‍👨🏿' => 'ongo tokoua moe mafu: tangata, tangata, kili melomelo mo e kili ʻuliʻuli',
    '👨🏾‍❤‍👨🏻' => 'ongo tokoua moe mafu: tangata, tangata, kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👨🏾‍❤‍👨🏼' => 'ongo tokoua moe mafu: tangata, tangata, kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👨🏾‍❤‍👨🏽' => 'ongo tokoua moe mafu: tangata, tangata, kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👨🏾‍❤‍👨🏾' => 'ongo tokoua moe mafu: tangata, tangata mo e kili melomelo-ʻuliʻuli',
    '👨🏾‍❤‍👨🏿' => 'ongo tokoua moe mafu: tangata, tangata, kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👨🏿‍❤‍👨🏻' => 'ongo tokoua moe mafu: tangata, tangata, kili ʻuliʻuli mo e kili hinehina',
    '👨🏿‍❤‍👨🏼' => 'ongo tokoua moe mafu: tangata, tangata, kili ʻuliʻuli mo e kili kelokelo',
    '👨🏿‍❤‍👨🏽' => 'ongo tokoua moe mafu: tangata, tangata, kili ʻuliʻuli mo e kili melomelo',
    '👨🏿‍❤‍👨🏾' => 'ongo tokoua moe mafu: tangata, tangata, kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👨🏿‍❤‍👨🏿' => 'ongo tokoua moe mafu: tangata, tangata mo e kili ʻuliʻuli',
    '👨🏻‍🐰‍👨🏼' => 'ongo tangata telinga-lāpisi: kili hinehina mo e kili kelokelo',
    '👨🏻‍🐰‍👨🏽' => 'ongo tangata telinga-lāpisi: kili hinehina mo e kili melomelo',
    '👨🏻‍🐰‍👨🏾' => 'ongo tangata telinga-lāpisi: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👨🏻‍🐰‍👨🏿' => 'ongo tangata telinga-lāpisi: kili hinehina mo e kili ʻuliʻuli',
    '👨🏼‍🐰‍👨🏻' => 'ongo tangata telinga-lāpisi: kili kelokelo mo e kili hinehina',
    '👨🏼‍🐰‍👨🏽' => 'ongo tangata telinga-lāpisi: kili kelokelo mo e kili melomelo',
    '👨🏼‍🐰‍👨🏾' => 'ongo tangata telinga-lāpisi: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👨🏼‍🐰‍👨🏿' => 'ongo tangata telinga-lāpisi: kili kelokelo mo e kili ʻuliʻuli',
    '👨🏽‍🐰‍👨🏻' => 'ongo tangata telinga-lāpisi: kili melomelo mo e kili hinehina',
    '👨🏽‍🐰‍👨🏼' => 'ongo tangata telinga-lāpisi: kili melomelo mo e kili kelokelo',
    '👨🏽‍🐰‍👨🏾' => 'ongo tangata telinga-lāpisi: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👨🏽‍🐰‍👨🏿' => 'ongo tangata telinga-lāpisi: kili melomelo mo e kili ʻuliʻuli',
    '👨🏾‍🐰‍👨🏻' => 'ongo tangata telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👨🏾‍🐰‍👨🏼' => 'ongo tangata telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👨🏾‍🐰‍👨🏽' => 'ongo tangata telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👨🏾‍🐰‍👨🏿' => 'ongo tangata telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👨🏿‍🐰‍👨🏻' => 'ongo tangata telinga-lāpisi: kili ʻuliʻuli mo e kili hinehina',
    '👨🏿‍🐰‍👨🏼' => 'ongo tangata telinga-lāpisi: kili ʻuliʻuli mo e kili kelokelo',
    '👨🏿‍🐰‍👨🏽' => 'ongo tangata telinga-lāpisi: kili ʻuliʻuli mo e kili melomelo',
    '👨🏿‍🐰‍👨🏾' => 'ongo tangata telinga-lāpisi: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍🫯‍👩🏼' => 'fafine fangatua: kili hinehina mo e kili kelokelo',
    '👩🏻‍🫯‍👩🏽' => 'fafine fangatua: kili hinehina mo e kili melomelo',
    '👩🏻‍🫯‍👩🏾' => 'fafine fangatua: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍🫯‍👩🏿' => 'fafine fangatua: kili hinehina mo e kili ʻuliʻuli',
    '👩🏼‍🫯‍👩🏻' => 'fafine fangatua: kili kelokelo mo e kili hinehina',
    '👩🏼‍🫯‍👩🏽' => 'fafine fangatua: kili kelokelo mo e kili melomelo',
    '👩🏼‍🫯‍👩🏾' => 'fafine fangatua: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👩🏼‍🫯‍👩🏿' => 'fafine fangatua: kili kelokelo mo e kili ʻuliʻuli',
    '👩🏽‍🫯‍👩🏻' => 'fafine fangatua: kili melomelo mo e kili hinehina',
    '👩🏽‍🫯‍👩🏼' => 'fafine fangatua: kili melomelo mo e kili kelokelo',
    '👩🏽‍🫯‍👩🏾' => 'fafine fangatua: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👩🏽‍🫯‍👩🏿' => 'fafine fangatua: kili melomelo mo e kili ʻuliʻuli',
    '👩🏾‍🫯‍👩🏻' => 'fafine fangatua: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👩🏾‍🫯‍👩🏼' => 'fafine fangatua: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👩🏾‍🫯‍👩🏽' => 'fafine fangatua: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👩🏾‍🫯‍👩🏿' => 'fafine fangatua: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👩🏿‍🫯‍👩🏻' => 'fafine fangatua: kili ʻuliʻuli mo e kili hinehina',
    '👩🏿‍🫯‍👩🏼' => 'fafine fangatua: kili ʻuliʻuli mo e kili kelokelo',
    '👩🏿‍🫯‍👩🏽' => 'fafine fangatua: kili ʻuliʻuli mo e kili melomelo',
    '👩🏿‍🫯‍👩🏾' => 'fafine fangatua: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍❤‍👨🏻' => 'ongo tokoua moe mafu: fefine, tangata mo e kili hinehina',
    '👩🏻‍❤‍👨🏼' => 'ongo tokoua moe mafu: fefine, tangata, kili hinehina mo e kili kelokelo',
    '👩🏻‍❤‍👨🏽' => 'ongo tokoua moe mafu: fefine, tangata, kili hinehina mo e kili melomelo',
    '👩🏻‍❤‍👨🏾' => 'ongo tokoua moe mafu: fefine, tangata, kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍❤‍👨🏿' => 'ongo tokoua moe mafu: fefine, tangata, kili hinehina mo e kili ʻuliʻuli',
    '👩🏼‍❤‍👨🏻' => 'ongo tokoua moe mafu: fefine, tangata, kili kelokelo mo e kili hinehina',
    '👩🏼‍❤‍👨🏼' => 'ongo tokoua moe mafu: fefine, tangata mo e kili kelokelo',
    '👩🏼‍❤‍👨🏽' => 'ongo tokoua moe mafu: fefine, tangata, kili kelokelo mo e kili melomelo',
    '👩🏼‍❤‍👨🏾' => 'ongo tokoua moe mafu: fefine, tangata, kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👩🏼‍❤‍👨🏿' => 'ongo tokoua moe mafu: fefine, tangata, kili kelokelo mo e kili ʻuliʻuli',
    '👩🏽‍❤‍👨🏻' => 'ongo tokoua moe mafu: fefine, tangata, kili melomelo mo e kili hinehina',
    '👩🏽‍❤‍👨🏼' => 'ongo tokoua moe mafu: fefine, tangata, kili melomelo mo e kili kelokelo',
    '👩🏽‍❤‍👨🏽' => 'ongo tokoua moe mafu: fefine, tangata mo e kili melomelo',
    '👩🏽‍❤‍👨🏾' => 'ongo tokoua moe mafu: fefine, tangata, kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👩🏽‍❤‍👨🏿' => 'ongo tokoua moe mafu: fefine, tangata, kili melomelo mo e kili ʻuliʻuli',
    '👩🏾‍❤‍👨🏻' => 'ongo tokoua moe mafu: fefine, tangata, kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👩🏾‍❤‍👨🏼' => 'ongo tokoua moe mafu: fefine, tangata, kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👩🏾‍❤‍👨🏽' => 'ongo tokoua moe mafu: fefine, tangata, kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👩🏾‍❤‍👨🏾' => 'ongo tokoua moe mafu: fefine, tangata mo e kili melomelo-ʻuliʻuli',
    '👩🏾‍❤‍👨🏿' => 'ongo tokoua moe mafu: fefine, tangata, kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👩🏿‍❤‍👨🏻' => 'ongo tokoua moe mafu: fefine, tangata, kili ʻuliʻuli mo e kili hinehina',
    '👩🏿‍❤‍👨🏼' => 'ongo tokoua moe mafu: fefine, tangata, kili ʻuliʻuli mo e kili kelokelo',
    '👩🏿‍❤‍👨🏽' => 'ongo tokoua moe mafu: fefine, tangata, kili ʻuliʻuli mo e kili melomelo',
    '👩🏿‍❤‍👨🏾' => 'ongo tokoua moe mafu: fefine, tangata, kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👩🏿‍❤‍👨🏿' => 'ongo tokoua moe mafu: fefine, tangata mo e kili ʻuliʻuli',
    '👩🏻‍❤‍👩🏻' => 'ongo tokoua moe mafu: fefine, fefine mo e kili hinehina',
    '👩🏻‍❤‍👩🏼' => 'ongo tokoua moe mafu: fefine, fefine, kili hinehina mo e kili kelokelo',
    '👩🏻‍❤‍👩🏽' => 'ongo tokoua moe mafu: fefine, fefine, kili hinehina mo e kili melomelo',
    '👩🏻‍❤‍👩🏾' => 'ongo tokoua moe mafu: fefine, fefine, kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍❤‍👩🏿' => 'ongo tokoua moe mafu: fefine, fefine, kili hinehina mo e kili ʻuliʻuli',
    '👩🏼‍❤‍👩🏻' => 'ongo tokoua moe mafu: fefine, fefine, kili kelokelo mo e kili hinehina',
    '👩🏼‍❤‍👩🏼' => 'ongo tokoua moe mafu: fefine, fefine mo e kili kelokelo',
    '👩🏼‍❤‍👩🏽' => 'ongo tokoua moe mafu: fefine, fefine, kili kelokelo mo e kili melomelo',
    '👩🏼‍❤‍👩🏾' => 'ongo tokoua moe mafu: fefine, fefine, kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👩🏼‍❤‍👩🏿' => 'ongo tokoua moe mafu: fefine, fefine, kili kelokelo mo e kili ʻuliʻuli',
    '👩🏽‍❤‍👩🏻' => 'ongo tokoua moe mafu: fefine, fefine, kili melomelo mo e kili hinehina',
    '👩🏽‍❤‍👩🏼' => 'ongo tokoua moe mafu: fefine, fefine, kili melomelo mo e kili kelokelo',
    '👩🏽‍❤‍👩🏽' => 'ongo tokoua moe mafu: fefine, fefine mo e kili melomelo',
    '👩🏽‍❤‍👩🏾' => 'ongo tokoua moe mafu: fefine, fefine, kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👩🏽‍❤‍👩🏿' => 'ongo tokoua moe mafu: fefine, fefine, kili melomelo mo e kili ʻuliʻuli',
    '👩🏾‍❤‍👩🏻' => 'ongo tokoua moe mafu: fefine, fefine, kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👩🏾‍❤‍👩🏼' => 'ongo tokoua moe mafu: fefine, fefine, kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👩🏾‍❤‍👩🏽' => 'ongo tokoua moe mafu: fefine, fefine, kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👩🏾‍❤‍👩🏾' => 'ongo tokoua moe mafu: fefine, fefine mo e kili melomelo-ʻuliʻuli',
    '👩🏾‍❤‍👩🏿' => 'ongo tokoua moe mafu: fefine, fefine, kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👩🏿‍❤‍👩🏻' => 'ongo tokoua moe mafu: fefine, fefine, kili ʻuliʻuli mo e kili hinehina',
    '👩🏿‍❤‍👩🏼' => 'ongo tokoua moe mafu: fefine, fefine, kili ʻuliʻuli mo e kili kelokelo',
    '👩🏿‍❤‍👩🏽' => 'ongo tokoua moe mafu: fefine, fefine, kili ʻuliʻuli mo e kili melomelo',
    '👩🏿‍❤‍👩🏾' => 'ongo tokoua moe mafu: fefine, fefine, kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👩🏿‍❤‍👩🏿' => 'ongo tokoua moe mafu: fefine, fefine mo e kili ʻuliʻuli',
    '👩🏻‍🐰‍👩🏼' => 'fafine telinga-lāpisi: kili hinehina mo e kili kelokelo',
    '👩🏻‍🐰‍👩🏽' => 'fafine telinga-lāpisi: kili hinehina mo e kili melomelo',
    '👩🏻‍🐰‍👩🏾' => 'fafine telinga-lāpisi: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍🐰‍👩🏿' => 'fafine telinga-lāpisi: kili hinehina mo e kili ʻuliʻuli',
    '👩🏼‍🐰‍👩🏻' => 'fafine telinga-lāpisi: kili kelokelo mo e kili hinehina',
    '👩🏼‍🐰‍👩🏽' => 'fafine telinga-lāpisi: kili kelokelo mo e kili melomelo',
    '👩🏼‍🐰‍👩🏾' => 'fafine telinga-lāpisi: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👩🏼‍🐰‍👩🏿' => 'fafine telinga-lāpisi: kili kelokelo mo e kili ʻuliʻuli',
    '👩🏽‍🐰‍👩🏻' => 'fafine telinga-lāpisi: kili melomelo mo e kili hinehina',
    '👩🏽‍🐰‍👩🏼' => 'fafine telinga-lāpisi: kili melomelo mo e kili kelokelo',
    '👩🏽‍🐰‍👩🏾' => 'fafine telinga-lāpisi: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👩🏽‍🐰‍👩🏿' => 'fafine telinga-lāpisi: kili melomelo mo e kili ʻuliʻuli',
    '👩🏾‍🐰‍👩🏻' => 'fafine telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👩🏾‍🐰‍👩🏼' => 'fafine telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👩🏾‍🐰‍👩🏽' => 'fafine telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👩🏾‍🐰‍👩🏿' => 'fafine telinga-lāpisi: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👩🏿‍🐰‍👩🏻' => 'fafine telinga-lāpisi: kili ʻuliʻuli mo e kili hinehina',
    '👩🏿‍🐰‍👩🏼' => 'fafine telinga-lāpisi: kili ʻuliʻuli mo e kili kelokelo',
    '👩🏿‍🐰‍👩🏽' => 'fafine telinga-lāpisi: kili ʻuliʻuli mo e kili melomelo',
    '👩🏿‍🐰‍👩🏾' => 'fafine telinga-lāpisi: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '🧑🏻‍🤝‍🧑🏻' => 'kakai fetakinima: kili hinehina',
    '🧑🏻‍🤝‍🧑🏼' => 'kakai fetakinima: kili hinehina mo e kili kelokelo',
    '🧑🏻‍🤝‍🧑🏽' => 'kakai fetakinima: kili hinehina mo e kili melomelo',
    '🧑🏻‍🤝‍🧑🏾' => 'kakai fetakinima: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '🧑🏻‍🤝‍🧑🏿' => 'kakai fetakinima: kili hinehina mo e kili ʻuliʻuli',
    '🧑🏼‍🤝‍🧑🏻' => 'kakai fetakinima: kili kelokelo mo e kili hinehina',
    '🧑🏼‍🤝‍🧑🏼' => 'kakai fetakinima: kili kelokelo',
    '🧑🏼‍🤝‍🧑🏽' => 'kakai fetakinima: kili kelokelo mo e kili melomelo',
    '🧑🏼‍🤝‍🧑🏾' => 'kakai fetakinima: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏼‍🤝‍🧑🏿' => 'kakai fetakinima: kili kelokelo mo e kili ʻuliʻuli',
    '🧑🏽‍🤝‍🧑🏻' => 'kakai fetakinima: kili melomelo mo e kili hinehina',
    '🧑🏽‍🤝‍🧑🏼' => 'kakai fetakinima: kili melomelo mo e kili kelokelo',
    '🧑🏽‍🤝‍🧑🏽' => 'kakai fetakinima: kili melomelo',
    '🧑🏽‍🤝‍🧑🏾' => 'kakai fetakinima: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '🧑🏽‍🤝‍🧑🏿' => 'kakai fetakinima: kili melomelo mo e kili ʻuliʻuli',
    '🧑🏾‍🤝‍🧑🏻' => 'kakai fetakinima: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '🧑🏾‍🤝‍🧑🏼' => 'kakai fetakinima: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '🧑🏾‍🤝‍🧑🏽' => 'kakai fetakinima: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '🧑🏾‍🤝‍🧑🏾' => 'kakai fetakinima: kili melomelo-ʻuliʻuli',
    '🧑🏾‍🤝‍🧑🏿' => 'kakai fetakinima: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '🧑🏿‍🤝‍🧑🏻' => 'kakai fetakinima: kili ʻuliʻuli mo e kili hinehina',
    '🧑🏿‍🤝‍🧑🏼' => 'kakai fetakinima: kili ʻuliʻuli mo e kili kelokelo',
    '🧑🏿‍🤝‍🧑🏽' => 'kakai fetakinima: kili ʻuliʻuli mo e kili melomelo',
    '🧑🏿‍🤝‍🧑🏾' => 'kakai fetakinima: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '🧑🏿‍🤝‍🧑🏿' => 'kakai fetakinima: kili ʻuliʻuli',
    '👩🏻‍🤝‍👩🏼' => 'fafine fetakinima: kili hinehina mo e kili kelokelo',
    '👩🏻‍🤝‍👩🏽' => 'fafine fetakinima: kili hinehina mo e kili melomelo',
    '👩🏻‍🤝‍👩🏾' => 'fafine fetakinima: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍🤝‍👩🏿' => 'fafine fetakinima: kili hinehina mo e kili ʻuliʻuli',
    '👩🏼‍🤝‍👩🏻' => 'fafine fetakinima: kili kelokelo mo e kili hinehina',
    '👩🏼‍🤝‍👩🏽' => 'fafine fetakinima: kili kelokelo mo e kili melomelo',
    '👩🏼‍🤝‍👩🏾' => 'fafine fetakinima: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👩🏼‍🤝‍👩🏿' => 'fafine fetakinima: kili kelokelo mo e kili ʻuliʻuli',
    '👩🏽‍🤝‍👩🏻' => 'fafine fetakinima: kili melomelo mo e kili hinehina',
    '👩🏽‍🤝‍👩🏼' => 'fafine fetakinima: kili melomelo mo e kili kelokelo',
    '👩🏽‍🤝‍👩🏾' => 'fafine fetakinima: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👩🏽‍🤝‍👩🏿' => 'fafine fetakinima: kili melomelo mo e kili ʻuliʻuli',
    '👩🏾‍🤝‍👩🏻' => 'fafine fetakinima: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👩🏾‍🤝‍👩🏼' => 'fafine fetakinima: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👩🏾‍🤝‍👩🏽' => 'fafine fetakinima: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👩🏾‍🤝‍👩🏿' => 'fafine fetakinima: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👩🏿‍🤝‍👩🏻' => 'fafine fetakinima: kili ʻuliʻuli mo e kili hinehina',
    '👩🏿‍🤝‍👩🏼' => 'fafine fetakinima: kili ʻuliʻuli mo e kili kelokelo',
    '👩🏿‍🤝‍👩🏽' => 'fafine fetakinima: kili ʻuliʻuli mo e kili melomelo',
    '👩🏿‍🤝‍👩🏾' => 'fafine fetakinima: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍🤝‍👨🏼' => 'tangata mo fefine fetakinima: kili hinehina mo e kili kelokelo',
    '👩🏻‍🤝‍👨🏽' => 'tangata mo fefine fetakinima: kili hinehina mo e kili melomelo',
    '👩🏻‍🤝‍👨🏾' => 'tangata mo fefine fetakinima: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👩🏻‍🤝‍👨🏿' => 'tangata mo fefine fetakinima: kili hinehina mo e kili ʻuliʻuli',
    '👩🏼‍🤝‍👨🏻' => 'tangata mo fefine fetakinima: kili kelokelo mo e kili hinehina',
    '👩🏼‍🤝‍👨🏽' => 'tangata mo fefine fetakinima: kili kelokelo mo e kili melomelo',
    '👩🏼‍🤝‍👨🏾' => 'tangata mo fefine fetakinima: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👩🏼‍🤝‍👨🏿' => 'tangata mo fefine fetakinima: kili kelokelo mo e kili ʻuliʻuli',
    '👩🏽‍🤝‍👨🏻' => 'tangata mo fefine fetakinima: kili melomelo mo e kili hinehina',
    '👩🏽‍🤝‍👨🏼' => 'tangata mo fefine fetakinima: kili melomelo mo e kili kelokelo',
    '👩🏽‍🤝‍👨🏾' => 'tangata mo fefine fetakinima: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👩🏽‍🤝‍👨🏿' => 'tangata mo fefine fetakinima: kili melomelo mo e kili ʻuliʻuli',
    '👩🏾‍🤝‍👨🏻' => 'tangata mo fefine fetakinima: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👩🏾‍🤝‍👨🏼' => 'tangata mo fefine fetakinima: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👩🏾‍🤝‍👨🏽' => 'tangata mo fefine fetakinima: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👩🏾‍🤝‍👨🏿' => 'tangata mo fefine fetakinima: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👩🏿‍🤝‍👨🏻' => 'tangata mo fefine fetakinima: kili ʻuliʻuli mo e kili hinehina',
    '👩🏿‍🤝‍👨🏼' => 'tangata mo fefine fetakinima: kili ʻuliʻuli mo e kili kelokelo',
    '👩🏿‍🤝‍👨🏽' => 'tangata mo fefine fetakinima: kili ʻuliʻuli mo e kili melomelo',
    '👩🏿‍🤝‍👨🏾' => 'tangata mo fefine fetakinima: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👨🏻‍🤝‍👨🏼' => 'ongo tangata fetakinima: kili hinehina mo e kili kelokelo',
    '👨🏻‍🤝‍👨🏽' => 'ongo tangata fetakinima: kili hinehina mo e kili melomelo',
    '👨🏻‍🤝‍👨🏾' => 'ongo tangata fetakinima: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '👨🏻‍🤝‍👨🏿' => 'ongo tangata fetakinima: kili hinehina mo e kili ʻuliʻuli',
    '👨🏼‍🤝‍👨🏻' => 'ongo tangata fetakinima: kili kelokelo mo e kili hinehina',
    '👨🏼‍🤝‍👨🏽' => 'ongo tangata fetakinima: kili kelokelo mo e kili melomelo',
    '👨🏼‍🤝‍👨🏾' => 'ongo tangata fetakinima: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '👨🏼‍🤝‍👨🏿' => 'ongo tangata fetakinima: kili kelokelo mo e kili ʻuliʻuli',
    '👨🏽‍🤝‍👨🏻' => 'ongo tangata fetakinima: kili melomelo mo e kili hinehina',
    '👨🏽‍🤝‍👨🏼' => 'ongo tangata fetakinima: kili melomelo mo e kili kelokelo',
    '👨🏽‍🤝‍👨🏾' => 'ongo tangata fetakinima: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '👨🏽‍🤝‍👨🏿' => 'ongo tangata fetakinima: kili melomelo mo e kili ʻuliʻuli',
    '👨🏾‍🤝‍👨🏻' => 'ongo tangata fetakinima: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '👨🏾‍🤝‍👨🏼' => 'ongo tangata fetakinima: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '👨🏾‍🤝‍👨🏽' => 'ongo tangata fetakinima: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '👨🏾‍🤝‍👨🏿' => 'ongo tangata fetakinima: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '👨🏿‍🤝‍👨🏻' => 'ongo tangata fetakinima: kili ʻuliʻuli mo e kili hinehina',
    '👨🏿‍🤝‍👨🏼' => 'ongo tangata fetakinima: kili ʻuliʻuli mo e kili kelokelo',
    '👨🏿‍🤝‍👨🏽' => 'ongo tangata fetakinima: kili ʻuliʻuli mo e kili melomelo',
    '👨🏿‍🤝‍👨🏾' => 'ongo tangata fetakinima: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '👩‍❤‍💋‍👨' => 'ʻuma: fefine mo e tangata',
    '👨‍❤‍💋‍👨' => 'ʻuma: tangata mo e tangata',
    '👩‍❤‍💋‍👩' => 'ʻuma: fefine mo e fefine',
    '👨‍👩‍👧‍👦' => 'fāmili: tangata, fefine, taʻahine mo e tamasiʻi',
    '👨‍👩‍👦‍👦' => 'fāmili: tangata, fefine, tamasiʻi mo e tamasiʻi',
    '👨‍👩‍👧‍👧' => 'fāmili: tangata, fefine, taʻahine mo e taʻahine',
    '👨‍👨‍👧‍👦' => 'fāmili: tangata, tangata, taʻahine mo e tamasiʻi',
    '👨‍👨‍👦‍👦' => 'fāmili: tangata, tangata, tamasiʻi mo e tamasiʻi',
    '👨‍👨‍👧‍👧' => 'fāmili: tangata, tangata, taʻahine mo e taʻahine',
    '👩‍👩‍👧‍👦' => 'fāmili: fefine, fefine, taʻahine mo e tamasiʻi',
    '👩‍👩‍👦‍👦' => 'fāmili: fefine, fefine, tamasiʻi mo e tamasiʻi',
    '👩‍👩‍👧‍👧' => 'fāmili: fefine, fefine, taʻahine mo e taʻahine',
    '🧑‍🧑‍🧒‍🧒' => 'fāmili: ongo motuʻa, ongo fānau',
    '🚶🏻‍♀‍➡' => 'fefine lue: kili hinehina mo e hangamataʻu',
    '🚶🏼‍♀‍➡' => 'fefine lue: kili kelokelo mo e hangamataʻu',
    '🚶🏽‍♀‍➡' => 'fefine lue: kili melomelo mo e hangamataʻu',
    '🚶🏾‍♀‍➡' => 'fefine lue: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🚶🏿‍♀‍➡' => 'fefine lue: kili ʻuliʻuli mo e hangamataʻu',
    '🚶🏻‍♂‍➡' => 'tangata lue: kili hinehina mo e hangamataʻu',
    '🚶🏼‍♂‍➡' => 'tangata lue: kili kelokelo mo e hangamataʻu',
    '🚶🏽‍♂‍➡' => 'tangata lue: kili melomelo mo e hangamataʻu',
    '🚶🏾‍♂‍➡' => 'tangata lue: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🚶🏿‍♂‍➡' => 'tangata lue: kili ʻuliʻuli mo e hangamataʻu',
    '🧎🏻‍♀‍➡' => 'fefine tūʻulutui: kili hinehina mo e hangamataʻu',
    '🧎🏼‍♀‍➡' => 'fefine tūʻulutui: kili kelokelo mo e hangamataʻu',
    '🧎🏽‍♀‍➡' => 'fefine tūʻulutui: kili melomelo mo e hangamataʻu',
    '🧎🏾‍♀‍➡' => 'fefine tūʻulutui: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🧎🏿‍♀‍➡' => 'fefine tūʻulutui: kili ʻuliʻuli mo e hangamataʻu',
    '🧎🏻‍♂‍➡' => 'tangata tūʻulutui: kili hinehina mo e hangamataʻu',
    '🧎🏼‍♂‍➡' => 'tangata tūʻulutui: kili kelokelo mo e hangamataʻu',
    '🧎🏽‍♂‍➡' => 'tangata tūʻulutui: kili melomelo mo e hangamataʻu',
    '🧎🏾‍♂‍➡' => 'tangata tūʻulutui: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🧎🏿‍♂‍➡' => 'tangata tūʻulutui: kili ʻuliʻuli mo e hangamataʻu',
    '🧑🏻‍🦯‍➡' => 'tokotaha moe tokotokokui: kili hinehina mo e hangamataʻu',
    '🧑🏼‍🦯‍➡' => 'tokotaha moe tokotokokui: kili kelokelo mo e hangamataʻu',
    '🧑🏽‍🦯‍➡' => 'tokotaha moe tokotokokui: kili melomelo mo e hangamataʻu',
    '🧑🏾‍🦯‍➡' => 'tokotaha moe tokotokokui: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🧑🏿‍🦯‍➡' => 'tokotaha moe tokotokokui: kili ʻuliʻuli mo e hangamataʻu',
    '👨🏻‍🦯‍➡' => 'tangata moe tokotokokui: kili hinehina mo e hangamataʻu',
    '👨🏼‍🦯‍➡' => 'tangata moe tokotokokui: kili kelokelo mo e hangamataʻu',
    '👨🏽‍🦯‍➡' => 'tangata moe tokotokokui: kili melomelo mo e hangamataʻu',
    '👨🏾‍🦯‍➡' => 'tangata moe tokotokokui: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '👨🏿‍🦯‍➡' => 'tangata moe tokotokokui: kili ʻuliʻuli mo e hangamataʻu',
    '👩🏻‍🦯‍➡' => 'fefine moe tokotokokui: kili hinehina mo e hangamataʻu',
    '👩🏼‍🦯‍➡' => 'fefine moe tokotokokui: kili kelokelo mo e hangamataʻu',
    '👩🏽‍🦯‍➡' => 'fefine moe tokotokokui: kili melomelo mo e hangamataʻu',
    '👩🏾‍🦯‍➡' => 'fefine moe tokotokokui: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '👩🏿‍🦯‍➡' => 'fefine moe tokotokokui: kili ʻuliʻuli mo e hangamataʻu',
    '🧑🏻‍🦼‍➡' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili hinehina mo e hangamataʻu',
    '🧑🏼‍🦼‍➡' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili kelokelo mo e hangamataʻu',
    '🧑🏽‍🦼‍➡' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili melomelo mo e hangamataʻu',
    '🧑🏾‍🦼‍➡' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🧑🏿‍🦼‍➡' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili ʻuliʻuli mo e hangamataʻu',
    '👨🏻‍🦼‍➡' => 'tangata ʻihe sāliote falemahaki mīsini: kili hinehina mo e hangamataʻu',
    '👨🏼‍🦼‍➡' => 'tangata ʻihe sāliote falemahaki mīsini: kili kelokelo mo e hangamataʻu',
    '👨🏽‍🦼‍➡' => 'tangata ʻihe sāliote falemahaki mīsini: kili melomelo mo e hangamataʻu',
    '👨🏾‍🦼‍➡' => 'tangata ʻihe sāliote falemahaki mīsini: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '👨🏿‍🦼‍➡' => 'tangata ʻihe sāliote falemahaki mīsini: kili ʻuliʻuli mo e hangamataʻu',
    '👩🏻‍🦼‍➡' => 'fefine ʻihe sāliote falemahaki mīsini: kili hinehina mo e hangamataʻu',
    '👩🏼‍🦼‍➡' => 'fefine ʻihe sāliote falemahaki mīsini: kili kelokelo mo e hangamataʻu',
    '👩🏽‍🦼‍➡' => 'fefine ʻihe sāliote falemahaki mīsini: kili melomelo mo e hangamataʻu',
    '👩🏾‍🦼‍➡' => 'fefine ʻihe sāliote falemahaki mīsini: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '👩🏿‍🦼‍➡' => 'fefine ʻihe sāliote falemahaki mīsini: kili ʻuliʻuli mo e hangamataʻu',
    '🧑🏻‍🦽‍➡' => 'tokotaha ʻihe sāliote falemahaki: kili hinehina mo e hangamataʻu',
    '🧑🏼‍🦽‍➡' => 'tokotaha ʻihe sāliote falemahaki: kili kelokelo mo e hangamataʻu',
    '🧑🏽‍🦽‍➡' => 'tokotaha ʻihe sāliote falemahaki: kili melomelo mo e hangamataʻu',
    '🧑🏾‍🦽‍➡' => 'tokotaha ʻihe sāliote falemahaki: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🧑🏿‍🦽‍➡' => 'tokotaha ʻihe sāliote falemahaki: kili ʻuliʻuli mo e hangamataʻu',
    '👨🏻‍🦽‍➡' => 'tangata ʻihe sāliote falemahaki: kili hinehina mo e hangamataʻu',
    '👨🏼‍🦽‍➡' => 'tangata ʻihe sāliote falemahaki: kili kelokelo mo e hangamataʻu',
    '👨🏽‍🦽‍➡' => 'tangata ʻihe sāliote falemahaki: kili melomelo mo e hangamataʻu',
    '👨🏾‍🦽‍➡' => 'tangata ʻihe sāliote falemahaki: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '👨🏿‍🦽‍➡' => 'tangata ʻihe sāliote falemahaki: kili ʻuliʻuli mo e hangamataʻu',
    '👩🏻‍🦽‍➡' => 'fefine ʻihe sāliote falemahaki: kili hinehina mo e hangamataʻu',
    '👩🏼‍🦽‍➡' => 'fefine ʻihe sāliote falemahaki: kili kelokelo mo e hangamataʻu',
    '👩🏽‍🦽‍➡' => 'fefine ʻihe sāliote falemahaki: kili melomelo mo e hangamataʻu',
    '👩🏾‍🦽‍➡' => 'fefine ʻihe sāliote falemahaki: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '👩🏿‍🦽‍➡' => 'fefine ʻihe sāliote falemahaki: kili ʻuliʻuli mo e hangamataʻu',
    '🏃🏻‍♀‍➡' => 'fefine lele: kili hinehina mo e hangamataʻu',
    '🏃🏼‍♀‍➡' => 'fefine lele: kili kelokelo mo e hangamataʻu',
    '🏃🏽‍♀‍➡' => 'fefine lele: kili melomelo mo e hangamataʻu',
    '🏃🏾‍♀‍➡' => 'fefine lele: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🏃🏿‍♀‍➡' => 'fefine lele: kili ʻuliʻuli mo e hangamataʻu',
    '🏃🏻‍♂‍➡' => 'tangata lele: kili hinehina mo e hangamataʻu',
    '🏃🏼‍♂‍➡' => 'tangata lele: kili kelokelo mo e hangamataʻu',
    '🏃🏽‍♂‍➡' => 'tangata lele: kili melomelo mo e hangamataʻu',
    '🏃🏾‍♂‍➡' => 'tangata lele: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🏃🏿‍♂‍➡' => 'tangata lele: kili ʻuliʻuli mo e hangamataʻu',
    '🫱🏻‍🫲🏼' => 'lulululu: kili hinehina mo e kili kelokelo',
    '🫱🏻‍🫲🏽' => 'lulululu: kili hinehina mo e kili melomelo',
    '🫱🏻‍🫲🏾' => 'lulululu: kili hinehina mo e kili melomelo-ʻuliʻuli',
    '🫱🏻‍🫲🏿' => 'lulululu: kili hinehina mo e kili ʻuliʻuli',
    '🫱🏼‍🫲🏻' => 'lulululu: kili kelokelo mo e kili hinehina',
    '🫱🏼‍🫲🏽' => 'lulululu: kili kelokelo mo e kili melomelo',
    '🫱🏼‍🫲🏾' => 'lulululu: kili kelokelo mo e kili melomelo-ʻuliʻuli',
    '🫱🏼‍🫲🏿' => 'lulululu: kili kelokelo mo e kili ʻuliʻuli',
    '🫱🏽‍🫲🏻' => 'lulululu: kili melomelo mo e kili hinehina',
    '🫱🏽‍🫲🏼' => 'lulululu: kili melomelo mo e kili kelokelo',
    '🫱🏽‍🫲🏾' => 'lulululu: kili melomelo mo e kili melomelo-ʻuliʻuli',
    '🫱🏽‍🫲🏿' => 'lulululu: kili melomelo mo e kili ʻuliʻuli',
    '🫱🏾‍🫲🏻' => 'lulululu: kili melomelo-ʻuliʻuli mo e kili hinehina',
    '🫱🏾‍🫲🏼' => 'lulululu: kili melomelo-ʻuliʻuli mo e kili kelokelo',
    '🫱🏾‍🫲🏽' => 'lulululu: kili melomelo-ʻuliʻuli mo e kili melomelo',
    '🫱🏾‍🫲🏿' => 'lulululu: kili melomelo-ʻuliʻuli mo e kili ʻuliʻuli',
    '🫱🏿‍🫲🏻' => 'lulululu: kili ʻuliʻuli mo e kili hinehina',
    '🫱🏿‍🫲🏼' => 'lulululu: kili ʻuliʻuli mo e kili kelokelo',
    '🫱🏿‍🫲🏽' => 'lulululu: kili ʻuliʻuli mo e kili melomelo',
    '🫱🏿‍🫲🏾' => 'lulululu: kili ʻuliʻuli mo e kili melomelo-ʻuliʻuli',
    '🚶‍♀‍➡' => 'fefine lue: hangamataʻu',
    '🚶‍♂‍➡' => 'tangata lue: hangamataʻu',
    '🧎‍♀‍➡' => 'fefine tūʻulutui: hangamataʻu',
    '🧎‍♂‍➡' => 'tangata tūʻulutui: hangamataʻu',
    '🧑‍🦯‍➡' => 'tokotaha moe tokotokokui: hangamataʻu',
    '👨‍🦯‍➡' => 'tangata moe tokotokokui: hangamataʻu',
    '👩‍🦯‍➡' => 'fefine moe tokotokokui: hangamataʻu',
    '🧑‍🦼‍➡' => 'tokotaha ʻihe sāliote falemahaki mīsini: hangamataʻu',
    '👨‍🦼‍➡' => 'tangata ʻihe sāliote falemahaki mīsini: hangamataʻu',
    '👩‍🦼‍➡' => 'fefine ʻihe sāliote falemahaki mīsini: hangamataʻu',
    '🧑‍🦽‍➡' => 'tokotaha ʻihe sāliote falemahaki: hangamataʻu',
    '👨‍🦽‍➡' => 'tangata ʻihe sāliote falemahaki: hangamataʻu',
    '👩‍🦽‍➡' => 'fefine ʻihe sāliote falemahaki: hangamataʻu',
    '🏃‍♀‍➡' => 'fefine lele: hangamataʻu',
    '🏃‍♂‍➡' => 'tangata lele: hangamataʻu',
    '👩‍❤‍👨' => 'ongo tokoua moe mafu: fefine mo e tangata',
    '👨‍❤‍👨' => 'ongo tokoua moe mafu: tangata mo e tangata',
    '👩‍❤‍👩' => 'ongo tokoua moe mafu: fefine mo e fefine',
    '👨‍👩‍👦' => 'fāmili: tangata, fefine mo e tamasiʻi',
    '👨‍👩‍👧' => 'fāmili: tangata, fefine mo e taʻahine',
    '👨‍👨‍👦' => 'fāmili: tangata, tangata mo e tamasiʻi',
    '👨‍👨‍👧' => 'fāmili: tangata, tangata mo e taʻahine',
    '👩‍👩‍👦' => 'fāmili: fefine, fefine mo e tamasiʻi',
    '👩‍👩‍👧' => 'fāmili: fefine, fefine mo e taʻahine',
    '👨‍👦‍👦' => 'fāmili: tangata, tamasiʻi mo e tamasiʻi',
    '👨‍👧‍👦' => 'fāmili: tangata, taʻahine mo e tamasiʻi',
    '👨‍👧‍👧' => 'fāmili: tangata, taʻahine mo e taʻahine',
    '👩‍👦‍👦' => 'fāmili: fefine, tamasiʻi mo e tamasiʻi',
    '👩‍👧‍👦' => 'fāmili: fefine, taʻahine mo e tamasiʻi',
    '👩‍👧‍👧' => 'fāmili: fefine, taʻahine mo e taʻahine',
    '🧑‍🤝‍🧑' => 'kakai fetakinima',
    '🧑‍🧑‍🧒' => 'fāmili: ongo motuʻa, fānau',
    '🧑‍🧒‍🧒' => 'fāmili: motuʻa, ongo fānau',
    '🧑🏻‍🦰' => 'kakai lalahi: kili hinehina mo e ʻulu kulokula',
    '🧑🏼‍🦰' => 'kakai lalahi: kili kelokelo mo e ʻulu kulokula',
    '🧑🏽‍🦰' => 'kakai lalahi: kili melomelo mo e ʻulu kulokula',
    '🧑🏾‍🦰' => 'kakai lalahi: kili melomelo-ʻuliʻuli mo e ʻulu kulokula',
    '🧑🏿‍🦰' => 'kakai lalahi: kili ʻuliʻuli mo e ʻulu kulokula',
    '🧑🏻‍🦱' => 'kakai lalahi: kili hinehina mo e ʻulu mingimingi',
    '🧑🏼‍🦱' => 'kakai lalahi: kili kelokelo mo e ʻulu mingimingi',
    '🧑🏽‍🦱' => 'kakai lalahi: kili melomelo mo e ʻulu mingimingi',
    '🧑🏾‍🦱' => 'kakai lalahi: kili melomelo-ʻuliʻuli mo e ʻulu mingimingi',
    '🧑🏿‍🦱' => 'kakai lalahi: kili ʻuliʻuli mo e ʻulu mingimingi',
    '🧑🏻‍🦳' => 'kakai lalahi: kili hinehina mo e ʻulu hinā',
    '🧑🏼‍🦳' => 'kakai lalahi: kili kelokelo mo e ʻulu hinā',
    '🧑🏽‍🦳' => 'kakai lalahi: kili melomelo mo e ʻulu hinā',
    '🧑🏾‍🦳' => 'kakai lalahi: kili melomelo-ʻuliʻuli mo e ʻulu hinā',
    '🧑🏿‍🦳' => 'kakai lalahi: kili ʻuliʻuli mo e ʻulu hinā',
    '🧑🏻‍🦲' => 'kakai lalahi: kili hinehina mo e ʻulu tula',
    '🧑🏼‍🦲' => 'kakai lalahi: kili kelokelo mo e ʻulu tula',
    '🧑🏽‍🦲' => 'kakai lalahi: kili melomelo mo e ʻulu tula',
    '🧑🏾‍🦲' => 'kakai lalahi: kili melomelo-ʻuliʻuli mo e ʻulu tula',
    '🧑🏿‍🦲' => 'kakai lalahi: kili ʻuliʻuli mo e ʻulu tula',
    '🧑🏻‍🩰' => 'tokotaha fakahulohula: kili hinehina',
    '🧑🏼‍🩰' => 'tokotaha fakahulohula: kili kelokelo',
    '🧑🏽‍🩰' => 'tokotaha fakahulohula: kili melomelo',
    '🧑🏾‍🩰' => 'tokotaha fakahulohula: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🩰' => 'tokotaha fakahulohula: kili ʻuliʻuli',
    '🧔🏻‍♂' => 'tangata kava: kili hinehina',
    '🧔🏼‍♂' => 'tangata kava: kili kelokelo',
    '🧔🏽‍♂' => 'tangata kava: kili melomelo',
    '🧔🏾‍♂' => 'tangata kava: kili melomelo-ʻuliʻuli',
    '🧔🏿‍♂' => 'tangata kava: kili ʻuliʻuli',
    '👱🏻‍♂' => 'tangata ʻulu kelo: kili hinehina',
    '👱🏼‍♂' => 'tangata ʻulu kelo: kili kelokelo',
    '👱🏽‍♂' => 'tangata ʻulu kelo: kili melomelo',
    '👱🏾‍♂' => 'tangata ʻulu kelo: kili melomelo-ʻuliʻuli',
    '👱🏿‍♂' => 'tangata ʻulu kelo: kili ʻuliʻuli',
    '👨🏻‍🦰' => 'tangata: kili hinehina mo e ʻulu kulokula',
    '👨🏼‍🦰' => 'tangata: kili kelokelo mo e ʻulu kulokula',
    '👨🏽‍🦰' => 'tangata: kili melomelo mo e ʻulu kulokula',
    '👨🏾‍🦰' => 'tangata: kili melomelo-ʻuliʻuli mo e ʻulu kulokula',
    '👨🏿‍🦰' => 'tangata: kili ʻuliʻuli mo e ʻulu kulokula',
    '👨🏻‍🦱' => 'tangata: kili hinehina mo e ʻulu mingimingi',
    '👨🏼‍🦱' => 'tangata: kili kelokelo mo e ʻulu mingimingi',
    '👨🏽‍🦱' => 'tangata: kili melomelo mo e ʻulu mingimingi',
    '👨🏾‍🦱' => 'tangata: kili melomelo-ʻuliʻuli mo e ʻulu mingimingi',
    '👨🏿‍🦱' => 'tangata: kili ʻuliʻuli mo e ʻulu mingimingi',
    '👨🏻‍🦳' => 'tangata: kili hinehina mo e ʻulu hinā',
    '👨🏼‍🦳' => 'tangata: kili kelokelo mo e ʻulu hinā',
    '👨🏽‍🦳' => 'tangata: kili melomelo mo e ʻulu hinā',
    '👨🏾‍🦳' => 'tangata: kili melomelo-ʻuliʻuli mo e ʻulu hinā',
    '👨🏿‍🦳' => 'tangata: kili ʻuliʻuli mo e ʻulu hinā',
    '👨🏻‍🦲' => 'tangata: kili hinehina mo e ʻulu tula',
    '👨🏼‍🦲' => 'tangata: kili kelokelo mo e ʻulu tula',
    '👨🏽‍🦲' => 'tangata: kili melomelo mo e ʻulu tula',
    '👨🏾‍🦲' => 'tangata: kili melomelo-ʻuliʻuli mo e ʻulu tula',
    '👨🏿‍🦲' => 'tangata: kili ʻuliʻuli mo e ʻulu tula',
    '🧔🏻‍♀' => 'fefine kava: kili hinehina',
    '🧔🏼‍♀' => 'fefine kava: kili kelokelo',
    '🧔🏽‍♀' => 'fefine kava: kili melomelo',
    '🧔🏾‍♀' => 'fefine kava: kili melomelo-ʻuliʻuli',
    '🧔🏿‍♀' => 'fefine kava: kili ʻuliʻuli',
    '👱🏻‍♀' => 'fefine ʻulu kelo: kili hinehina',
    '👱🏼‍♀' => 'fefine ʻulu kelo: kili kelokelo',
    '👱🏽‍♀' => 'fefine ʻulu kelo: kili melomelo',
    '👱🏾‍♀' => 'fefine ʻulu kelo: kili melomelo-ʻuliʻuli',
    '👱🏿‍♀' => 'fefine ʻulu kelo: kili ʻuliʻuli',
    '👩🏻‍🦰' => 'fefine: kili hinehina mo e ʻulu kulokula',
    '👩🏼‍🦰' => 'fefine: kili kelokelo mo e ʻulu kulokula',
    '👩🏽‍🦰' => 'fefine: kili melomelo mo e ʻulu kulokula',
    '👩🏾‍🦰' => 'fefine: kili melomelo-ʻuliʻuli mo e ʻulu kulokula',
    '👩🏿‍🦰' => 'fefine: kili ʻuliʻuli mo e ʻulu kulokula',
    '👩🏻‍🦱' => 'fefine: kili hinehina mo e ʻulu mingimingi',
    '👩🏼‍🦱' => 'fefine: kili kelokelo mo e ʻulu mingimingi',
    '👩🏽‍🦱' => 'fefine: kili melomelo mo e ʻulu mingimingi',
    '👩🏾‍🦱' => 'fefine: kili melomelo-ʻuliʻuli mo e ʻulu mingimingi',
    '👩🏿‍🦱' => 'fefine: kili ʻuliʻuli mo e ʻulu mingimingi',
    '👩🏻‍🦳' => 'fefine: kili hinehina mo e ʻulu hinā',
    '👩🏼‍🦳' => 'fefine: kili kelokelo mo e ʻulu hinā',
    '👩🏽‍🦳' => 'fefine: kili melomelo mo e ʻulu hinā',
    '👩🏾‍🦳' => 'fefine: kili melomelo-ʻuliʻuli mo e ʻulu hinā',
    '👩🏿‍🦳' => 'fefine: kili ʻuliʻuli mo e ʻulu hinā',
    '👩🏻‍🦲' => 'fefine: kili hinehina mo e ʻulu tula',
    '👩🏼‍🦲' => 'fefine: kili kelokelo mo e ʻulu tula',
    '👩🏽‍🦲' => 'fefine: kili melomelo mo e ʻulu tula',
    '👩🏾‍🦲' => 'fefine: kili melomelo-ʻuliʻuli mo e ʻulu tula',
    '👩🏿‍🦲' => 'fefine: kili ʻuliʻuli mo e ʻulu tula',
    '🙍🏻‍♂' => 'tangata matamamahi: kili hinehina',
    '🙍🏼‍♂' => 'tangata matamamahi: kili kelokelo',
    '🙍🏽‍♂' => 'tangata matamamahi: kili melomelo',
    '🙍🏾‍♂' => 'tangata matamamahi: kili melomelo-ʻuliʻuli',
    '🙍🏿‍♂' => 'tangata matamamahi: kili ʻuliʻuli',
    '🙍🏻‍♀' => 'fefine matamamahi: kili hinehina',
    '🙍🏼‍♀' => 'fefine matamamahi: kili kelokelo',
    '🙍🏽‍♀' => 'fefine matamamahi: kili melomelo',
    '🙍🏾‍♀' => 'fefine matamamahi: kili melomelo-ʻuliʻuli',
    '🙍🏿‍♀' => 'fefine matamamahi: kili ʻuliʻuli',
    '🙎🏻‍♂' => 'tangata mataʻita: kili hinehina',
    '🙎🏼‍♂' => 'tangata mataʻita: kili kelokelo',
    '🙎🏽‍♂' => 'tangata mataʻita: kili melomelo',
    '🙎🏾‍♂' => 'tangata mataʻita: kili melomelo-ʻuliʻuli',
    '🙎🏿‍♂' => 'tangata mataʻita: kili ʻuliʻuli',
    '🙎🏻‍♀' => 'fefine mataʻita: kili hinehina',
    '🙎🏼‍♀' => 'fefine mataʻita: kili kelokelo',
    '🙎🏽‍♀' => 'fefine mataʻita: kili melomelo',
    '🙎🏾‍♀' => 'fefine mataʻita: kili melomelo-ʻuliʻuli',
    '🙎🏿‍♀' => 'fefine mataʻita: kili ʻuliʻuli',
    '🙅🏻‍♂' => 'tangata kaunima fetuiaki: kili hinehina',
    '🙅🏼‍♂' => 'tangata kaunima fetuiaki: kili kelokelo',
    '🙅🏽‍♂' => 'tangata kaunima fetuiaki: kili melomelo',
    '🙅🏾‍♂' => 'tangata kaunima fetuiaki: kili melomelo-ʻuliʻuli',
    '🙅🏿‍♂' => 'tangata kaunima fetuiaki: kili ʻuliʻuli',
    '🙅🏻‍♀' => 'fefine kaunima fetuiaki: kili hinehina',
    '🙅🏼‍♀' => 'fefine kaunima fetuiaki: kili kelokelo',
    '🙅🏽‍♀' => 'fefine kaunima fetuiaki: kili melomelo',
    '🙅🏾‍♀' => 'fefine kaunima fetuiaki: kili melomelo-ʻuliʻuli',
    '🙅🏿‍♀' => 'fefine kaunima fetuiaki: kili ʻuliʻuli',
    '🙆🏻‍♂' => 'tangata kaunima fetuiaki ʻolunga: kili hinehina',
    '🙆🏼‍♂' => 'tangata kaunima fetuiaki ʻolunga: kili kelokelo',
    '🙆🏽‍♂' => 'tangata kaunima fetuiaki ʻolunga: kili melomelo',
    '🙆🏾‍♂' => 'tangata kaunima fetuiaki ʻolunga: kili melomelo-ʻuliʻuli',
    '🙆🏿‍♂' => 'tangata kaunima fetuiaki ʻolunga: kili ʻuliʻuli',
    '🙆🏻‍♀' => 'fefine kaunima fetuiaki ʻolunga: kili hinehina',
    '🙆🏼‍♀' => 'fefine kaunima fetuiaki ʻolunga: kili kelokelo',
    '🙆🏽‍♀' => 'fefine kaunima fetuiaki ʻolunga: kili melomelo',
    '🙆🏾‍♀' => 'fefine kaunima fetuiaki ʻolunga: kili melomelo-ʻuliʻuli',
    '🙆🏿‍♀' => 'fefine kaunima fetuiaki ʻolunga: kili ʻuliʻuli',
    '💁🏻‍♂' => 'tangata nima mafola: kili hinehina',
    '💁🏼‍♂' => 'tangata nima mafola: kili kelokelo',
    '💁🏽‍♂' => 'tangata nima mafola: kili melomelo',
    '💁🏾‍♂' => 'tangata nima mafola: kili melomelo-ʻuliʻuli',
    '💁🏿‍♂' => 'tangata nima mafola: kili ʻuliʻuli',
    '💁🏻‍♀' => 'fefine nima mafola: kili hinehina',
    '💁🏼‍♀' => 'fefine nima mafola: kili kelokelo',
    '💁🏽‍♀' => 'fefine nima mafola: kili melomelo',
    '💁🏾‍♀' => 'fefine nima mafola: kili melomelo-ʻuliʻuli',
    '💁🏿‍♀' => 'fefine nima mafola: kili ʻuliʻuli',
    '🙋🏻‍♂' => 'tangata nima ʻi ʻolunga: kili hinehina',
    '🙋🏼‍♂' => 'tangata nima ʻi ʻolunga: kili kelokelo',
    '🙋🏽‍♂' => 'tangata nima ʻi ʻolunga: kili melomelo',
    '🙋🏾‍♂' => 'tangata nima ʻi ʻolunga: kili melomelo-ʻuliʻuli',
    '🙋🏿‍♂' => 'tangata nima ʻi ʻolunga: kili ʻuliʻuli',
    '🙋🏻‍♀' => 'fefine nima ʻi ʻolunga: kili hinehina',
    '🙋🏼‍♀' => 'fefine nima ʻi ʻolunga: kili kelokelo',
    '🙋🏽‍♀' => 'fefine nima ʻi ʻolunga: kili melomelo',
    '🙋🏾‍♀' => 'fefine nima ʻi ʻolunga: kili melomelo-ʻuliʻuli',
    '🙋🏿‍♀' => 'fefine nima ʻi ʻolunga: kili ʻuliʻuli',
    '🧏🏻‍♂' => 'tangata tuli: kili hinehina',
    '🧏🏼‍♂' => 'tangata tuli: kili kelokelo',
    '🧏🏽‍♂' => 'tangata tuli: kili melomelo',
    '🧏🏾‍♂' => 'tangata tuli: kili melomelo-ʻuliʻuli',
    '🧏🏿‍♂' => 'tangata tuli: kili ʻuliʻuli',
    '🧏🏻‍♀' => 'fefine tuli: kili hinehina',
    '🧏🏼‍♀' => 'fefine tuli: kili kelokelo',
    '🧏🏽‍♀' => 'fefine tuli: kili melomelo',
    '🧏🏾‍♀' => 'fefine tuli: kili melomelo-ʻuliʻuli',
    '🧏🏿‍♀' => 'fefine tuli: kili ʻuliʻuli',
    '🙇🏻‍♂' => 'tangata punou: kili hinehina',
    '🙇🏼‍♂' => 'tangata punou: kili kelokelo',
    '🙇🏽‍♂' => 'tangata punou: kili melomelo',
    '🙇🏾‍♂' => 'tangata punou: kili melomelo-ʻuliʻuli',
    '🙇🏿‍♂' => 'tangata punou: kili ʻuliʻuli',
    '🙇🏻‍♀' => 'fefine punou: kili hinehina',
    '🙇🏼‍♀' => 'fefine punou: kili kelokelo',
    '🙇🏽‍♀' => 'fefine punou: kili melomelo',
    '🙇🏾‍♀' => 'fefine punou: kili melomelo-ʻuliʻuli',
    '🙇🏿‍♀' => 'fefine punou: kili ʻuliʻuli',
    '🤦🏻‍♂' => 'tangata nima ʻihe mata: kili hinehina',
    '🤦🏼‍♂' => 'tangata nima ʻihe mata: kili kelokelo',
    '🤦🏽‍♂' => 'tangata nima ʻihe mata: kili melomelo',
    '🤦🏾‍♂' => 'tangata nima ʻihe mata: kili melomelo-ʻuliʻuli',
    '🤦🏿‍♂' => 'tangata nima ʻihe mata: kili ʻuliʻuli',
    '🤦🏻‍♀' => 'fefine nima ʻihe mata: kili hinehina',
    '🤦🏼‍♀' => 'fefine nima ʻihe mata: kili kelokelo',
    '🤦🏽‍♀' => 'fefine nima ʻihe mata: kili melomelo',
    '🤦🏾‍♀' => 'fefine nima ʻihe mata: kili melomelo-ʻuliʻuli',
    '🤦🏿‍♀' => 'fefine nima ʻihe mata: kili ʻuliʻuli',
    '🤷🏻‍♂' => 'tangata fakamahiki: kili hinehina',
    '🤷🏼‍♂' => 'tangata fakamahiki: kili kelokelo',
    '🤷🏽‍♂' => 'tangata fakamahiki: kili melomelo',
    '🤷🏾‍♂' => 'tangata fakamahiki: kili melomelo-ʻuliʻuli',
    '🤷🏿‍♂' => 'tangata fakamahiki: kili ʻuliʻuli',
    '🤷🏻‍♀' => 'fefine fakamahiki: kili hinehina',
    '🤷🏼‍♀' => 'fefine fakamahiki: kili kelokelo',
    '🤷🏽‍♀' => 'fefine fakamahiki: kili melomelo',
    '🤷🏾‍♀' => 'fefine fakamahiki: kili melomelo-ʻuliʻuli',
    '🤷🏿‍♀' => 'fefine fakamahiki: kili ʻuliʻuli',
    '🧑🏻‍⚕' => 'neesi: kili hinehina',
    '🧑🏼‍⚕' => 'neesi: kili kelokelo',
    '🧑🏽‍⚕' => 'neesi: kili melomelo',
    '🧑🏾‍⚕' => 'neesi: kili melomelo-ʻuliʻuli',
    '🧑🏿‍⚕' => 'neesi: kili ʻuliʻuli',
    '👨🏻‍⚕' => 'neesi tangata: kili hinehina',
    '👨🏼‍⚕' => 'neesi tangata: kili kelokelo',
    '👨🏽‍⚕' => 'neesi tangata: kili melomelo',
    '👨🏾‍⚕' => 'neesi tangata: kili melomelo-ʻuliʻuli',
    '👨🏿‍⚕' => 'neesi tangata: kili ʻuliʻuli',
    '👩🏻‍⚕' => 'neesi fefine: kili hinehina',
    '👩🏼‍⚕' => 'neesi fefine: kili kelokelo',
    '👩🏽‍⚕' => 'neesi fefine: kili melomelo',
    '👩🏾‍⚕' => 'neesi fefine: kili melomelo-ʻuliʻuli',
    '👩🏿‍⚕' => 'neesi fefine: kili ʻuliʻuli',
    '🧑🏻‍🎓' => 'tokotaha ako: kili hinehina',
    '🧑🏼‍🎓' => 'tokotaha ako: kili kelokelo',
    '🧑🏽‍🎓' => 'tokotaha ako: kili melomelo',
    '🧑🏾‍🎓' => 'tokotaha ako: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🎓' => 'tokotaha ako: kili ʻuliʻuli',
    '👨🏻‍🎓' => 'tamasiʻi ako: kili hinehina',
    '👨🏼‍🎓' => 'tamasiʻi ako: kili kelokelo',
    '👨🏽‍🎓' => 'tamasiʻi ako: kili melomelo',
    '👨🏾‍🎓' => 'tamasiʻi ako: kili melomelo-ʻuliʻuli',
    '👨🏿‍🎓' => 'tamasiʻi ako: kili ʻuliʻuli',
    '👩🏻‍🎓' => 'taʻahine ako: kili hinehina',
    '👩🏼‍🎓' => 'taʻahine ako: kili kelokelo',
    '👩🏽‍🎓' => 'taʻahine ako: kili melomelo',
    '👩🏾‍🎓' => 'taʻahine ako: kili melomelo-ʻuliʻuli',
    '👩🏿‍🎓' => 'taʻahine ako: kili ʻuliʻuli',
    '🧑🏻‍🏫' => 'faiako: kili hinehina',
    '🧑🏼‍🏫' => 'faiako: kili kelokelo',
    '🧑🏽‍🏫' => 'faiako: kili melomelo',
    '🧑🏾‍🏫' => 'faiako: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🏫' => 'faiako: kili ʻuliʻuli',
    '👨🏻‍🏫' => 'faiako tangata: kili hinehina',
    '👨🏼‍🏫' => 'faiako tangata: kili kelokelo',
    '👨🏽‍🏫' => 'faiako tangata: kili melomelo',
    '👨🏾‍🏫' => 'faiako tangata: kili melomelo-ʻuliʻuli',
    '👨🏿‍🏫' => 'faiako tangata: kili ʻuliʻuli',
    '👩🏻‍🏫' => 'faiako fefine: kili hinehina',
    '👩🏼‍🏫' => 'faiako fefine: kili kelokelo',
    '👩🏽‍🏫' => 'faiako fefine: kili melomelo',
    '👩🏾‍🏫' => 'faiako fefine: kili melomelo-ʻuliʻuli',
    '👩🏿‍🏫' => 'faiako fefine: kili ʻuliʻuli',
    '🧑🏻‍⚖' => 'fakamaau: kili hinehina',
    '🧑🏼‍⚖' => 'fakamaau: kili kelokelo',
    '🧑🏽‍⚖' => 'fakamaau: kili melomelo',
    '🧑🏾‍⚖' => 'fakamaau: kili melomelo-ʻuliʻuli',
    '🧑🏿‍⚖' => 'fakamaau: kili ʻuliʻuli',
    '👨🏻‍⚖' => 'fakamaau tangata: kili hinehina',
    '👨🏼‍⚖' => 'fakamaau tangata: kili kelokelo',
    '👨🏽‍⚖' => 'fakamaau tangata: kili melomelo',
    '👨🏾‍⚖' => 'fakamaau tangata: kili melomelo-ʻuliʻuli',
    '👨🏿‍⚖' => 'fakamaau tangata: kili ʻuliʻuli',
    '👩🏻‍⚖' => 'fakamaau fefine: kili hinehina',
    '👩🏼‍⚖' => 'fakamaau fefine: kili kelokelo',
    '👩🏽‍⚖' => 'fakamaau fefine: kili melomelo',
    '👩🏾‍⚖' => 'fakamaau fefine: kili melomelo-ʻuliʻuli',
    '👩🏿‍⚖' => 'fakamaau fefine: kili ʻuliʻuli',
    '🧑🏻‍🌾' => 'tokotaha ngoue: kili hinehina',
    '🧑🏼‍🌾' => 'tokotaha ngoue: kili kelokelo',
    '🧑🏽‍🌾' => 'tokotaha ngoue: kili melomelo',
    '🧑🏾‍🌾' => 'tokotaha ngoue: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🌾' => 'tokotaha ngoue: kili ʻuliʻuli',
    '👨🏻‍🌾' => 'tangata ngoue: kili hinehina',
    '👨🏼‍🌾' => 'tangata ngoue: kili kelokelo',
    '👨🏽‍🌾' => 'tangata ngoue: kili melomelo',
    '👨🏾‍🌾' => 'tangata ngoue: kili melomelo-ʻuliʻuli',
    '👨🏿‍🌾' => 'tangata ngoue: kili ʻuliʻuli',
    '👩🏻‍🌾' => 'fefine ngoue: kili hinehina',
    '👩🏼‍🌾' => 'fefine ngoue: kili kelokelo',
    '👩🏽‍🌾' => 'fefine ngoue: kili melomelo',
    '👩🏾‍🌾' => 'fefine ngoue: kili melomelo-ʻuliʻuli',
    '👩🏿‍🌾' => 'fefine ngoue: kili ʻuliʻuli',
    '🧑🏻‍🍳' => 'tokotaha ngaohikai: kili hinehina',
    '🧑🏼‍🍳' => 'tokotaha ngaohikai: kili kelokelo',
    '🧑🏽‍🍳' => 'tokotaha ngaohikai: kili melomelo',
    '🧑🏾‍🍳' => 'tokotaha ngaohikai: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🍳' => 'tokotaha ngaohikai: kili ʻuliʻuli',
    '👨🏻‍🍳' => 'tangata ngaohikai: kili hinehina',
    '👨🏼‍🍳' => 'tangata ngaohikai: kili kelokelo',
    '👨🏽‍🍳' => 'tangata ngaohikai: kili melomelo',
    '👨🏾‍🍳' => 'tangata ngaohikai: kili melomelo-ʻuliʻuli',
    '👨🏿‍🍳' => 'tangata ngaohikai: kili ʻuliʻuli',
    '👩🏻‍🍳' => 'fefine ngaohikai: kili hinehina',
    '👩🏼‍🍳' => 'fefine ngaohikai: kili kelokelo',
    '👩🏽‍🍳' => 'fefine ngaohikai: kili melomelo',
    '👩🏾‍🍳' => 'fefine ngaohikai: kili melomelo-ʻuliʻuli',
    '👩🏿‍🍳' => 'fefine ngaohikai: kili ʻuliʻuli',
    '🧑🏻‍🔧' => 'ʻenisia: kili hinehina',
    '🧑🏼‍🔧' => 'ʻenisia: kili kelokelo',
    '🧑🏽‍🔧' => 'ʻenisia: kili melomelo',
    '🧑🏾‍🔧' => 'ʻenisia: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🔧' => 'ʻenisia: kili ʻuliʻuli',
    '👨🏻‍🔧' => 'ʻenisinia tangata: kili hinehina',
    '👨🏼‍🔧' => 'ʻenisinia tangata: kili kelokelo',
    '👨🏽‍🔧' => 'ʻenisinia tangata: kili melomelo',
    '👨🏾‍🔧' => 'ʻenisinia tangata: kili melomelo-ʻuliʻuli',
    '👨🏿‍🔧' => 'ʻenisinia tangata: kili ʻuliʻuli',
    '👩🏻‍🔧' => 'ʻenisinia fefine: kili hinehina',
    '👩🏼‍🔧' => 'ʻenisinia fefine: kili kelokelo',
    '👩🏽‍🔧' => 'ʻenisinia fefine: kili melomelo',
    '👩🏾‍🔧' => 'ʻenisinia fefine: kili melomelo-ʻuliʻuli',
    '👩🏿‍🔧' => 'ʻenisinia fefine: kili ʻuliʻuli',
    '🧑🏻‍🏭' => 'tokotaha ngāue fale faʻuʻanga: kili hinehina',
    '🧑🏼‍🏭' => 'tokotaha ngāue fale faʻuʻanga: kili kelokelo',
    '🧑🏽‍🏭' => 'tokotaha ngāue fale faʻuʻanga: kili melomelo',
    '🧑🏾‍🏭' => 'tokotaha ngāue fale faʻuʻanga: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🏭' => 'tokotaha ngāue fale faʻuʻanga: kili ʻuliʻuli',
    '👨🏻‍🏭' => 'tangata ngāue fale faʻuʻanga: kili hinehina',
    '👨🏼‍🏭' => 'tangata ngāue fale faʻuʻanga: kili kelokelo',
    '👨🏽‍🏭' => 'tangata ngāue fale faʻuʻanga: kili melomelo',
    '👨🏾‍🏭' => 'tangata ngāue fale faʻuʻanga: kili melomelo-ʻuliʻuli',
    '👨🏿‍🏭' => 'tangata ngāue fale faʻuʻanga: kili ʻuliʻuli',
    '👩🏻‍🏭' => 'fefine ngāue fale faʻuʻanga: kili hinehina',
    '👩🏼‍🏭' => 'fefine ngāue fale faʻuʻanga: kili kelokelo',
    '👩🏽‍🏭' => 'fefine ngāue fale faʻuʻanga: kili melomelo',
    '👩🏾‍🏭' => 'fefine ngāue fale faʻuʻanga: kili melomelo-ʻuliʻuli',
    '👩🏿‍🏭' => 'fefine ngāue fale faʻuʻanga: kili ʻuliʻuli',
    '🧑🏻‍💼' => 'tokotaha ngāue ʻōfisi: kili hinehina',
    '🧑🏼‍💼' => 'tokotaha ngāue ʻōfisi: kili kelokelo',
    '🧑🏽‍💼' => 'tokotaha ngāue ʻōfisi: kili melomelo',
    '🧑🏾‍💼' => 'tokotaha ngāue ʻōfisi: kili melomelo-ʻuliʻuli',
    '🧑🏿‍💼' => 'tokotaha ngāue ʻōfisi: kili ʻuliʻuli',
    '👨🏻‍💼' => 'tangata ngāue ʻōfisi: kili hinehina',
    '👨🏼‍💼' => 'tangata ngāue ʻōfisi: kili kelokelo',
    '👨🏽‍💼' => 'tangata ngāue ʻōfisi: kili melomelo',
    '👨🏾‍💼' => 'tangata ngāue ʻōfisi: kili melomelo-ʻuliʻuli',
    '👨🏿‍💼' => 'tangata ngāue ʻōfisi: kili ʻuliʻuli',
    '👩🏻‍💼' => 'fefine ngāue ʻōfisi: kili hinehina',
    '👩🏼‍💼' => 'fefine ngāue ʻōfisi: kili kelokelo',
    '👩🏽‍💼' => 'fefine ngāue ʻōfisi: kili melomelo',
    '👩🏾‍💼' => 'fefine ngāue ʻōfisi: kili melomelo-ʻuliʻuli',
    '👩🏿‍💼' => 'fefine ngāue ʻōfisi: kili ʻuliʻuli',
    '🧑🏻‍🔬' => 'tokotaha faisaienisi: kili hinehina',
    '🧑🏼‍🔬' => 'tokotaha faisaienisi: kili kelokelo',
    '🧑🏽‍🔬' => 'tokotaha faisaienisi: kili melomelo',
    '🧑🏾‍🔬' => 'tokotaha faisaienisi: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🔬' => 'tokotaha faisaienisi: kili ʻuliʻuli',
    '👨🏻‍🔬' => 'tangata faisaienisi: kili hinehina',
    '👨🏼‍🔬' => 'tangata faisaienisi: kili kelokelo',
    '👨🏽‍🔬' => 'tangata faisaienisi: kili melomelo',
    '👨🏾‍🔬' => 'tangata faisaienisi: kili melomelo-ʻuliʻuli',
    '👨🏿‍🔬' => 'tangata faisaienisi: kili ʻuliʻuli',
    '👩🏻‍🔬' => 'fefine faisaienisi: kili hinehina',
    '👩🏼‍🔬' => 'fefine faisaienisi: kili kelokelo',
    '👩🏽‍🔬' => 'fefine faisaienisi: kili melomelo',
    '👩🏾‍🔬' => 'fefine faisaienisi: kili melomelo-ʻuliʻuli',
    '👩🏿‍🔬' => 'fefine faisaienisi: kili ʻuliʻuli',
    '🧑🏻‍💻' => 'tokotaha fakatekinolosia: kili hinehina',
    '🧑🏼‍💻' => 'tokotaha fakatekinolosia: kili kelokelo',
    '🧑🏽‍💻' => 'tokotaha fakatekinolosia: kili melomelo',
    '🧑🏾‍💻' => 'tokotaha fakatekinolosia: kili melomelo-ʻuliʻuli',
    '🧑🏿‍💻' => 'tokotaha fakatekinolosia: kili ʻuliʻuli',
    '👨🏻‍💻' => 'tangata fakatekinolosia: kili hinehina',
    '👨🏼‍💻' => 'tangata fakatekinolosia: kili kelokelo',
    '👨🏽‍💻' => 'tangata fakatekinolosia: kili melomelo',
    '👨🏾‍💻' => 'tangata fakatekinolosia: kili melomelo-ʻuliʻuli',
    '👨🏿‍💻' => 'tangata fakatekinolosia: kili ʻuliʻuli',
    '👩🏻‍💻' => 'fefine fakatekinolosia: kili hinehina',
    '👩🏼‍💻' => 'fefine fakatekinolosia: kili kelokelo',
    '👩🏽‍💻' => 'fefine fakatekinolosia: kili melomelo',
    '👩🏾‍💻' => 'fefine fakatekinolosia: kili melomelo-ʻuliʻuli',
    '👩🏿‍💻' => 'fefine fakatekinolosia: kili ʻuliʻuli',
    '🧑🏻‍🎤' => 'tokotaha hiva: kili hinehina',
    '🧑🏼‍🎤' => 'tokotaha hiva: kili kelokelo',
    '🧑🏽‍🎤' => 'tokotaha hiva: kili melomelo',
    '🧑🏾‍🎤' => 'tokotaha hiva: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🎤' => 'tokotaha hiva: kili ʻuliʻuli',
    '👨🏻‍🎤' => 'tangata hiva: kili hinehina',
    '👨🏼‍🎤' => 'tangata hiva: kili kelokelo',
    '👨🏽‍🎤' => 'tangata hiva: kili melomelo',
    '👨🏾‍🎤' => 'tangata hiva: kili melomelo-ʻuliʻuli',
    '👨🏿‍🎤' => 'tangata hiva: kili ʻuliʻuli',
    '👩🏻‍🎤' => 'fefine hiva: kili hinehina',
    '👩🏼‍🎤' => 'fefine hiva: kili kelokelo',
    '👩🏽‍🎤' => 'fefine hiva: kili melomelo',
    '👩🏾‍🎤' => 'fefine hiva: kili melomelo-ʻuliʻuli',
    '👩🏿‍🎤' => 'fefine hiva: kili ʻuliʻuli',
    '🧑🏻‍🎨' => 'tokotaha tā-fakatātā: kili hinehina',
    '🧑🏼‍🎨' => 'tokotaha tā-fakatātā: kili kelokelo',
    '🧑🏽‍🎨' => 'tokotaha tā-fakatātā: kili melomelo',
    '🧑🏾‍🎨' => 'tokotaha tā-fakatātā: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🎨' => 'tokotaha tā-fakatātā: kili ʻuliʻuli',
    '👨🏻‍🎨' => 'tangata tā-fakatātā: kili hinehina',
    '👨🏼‍🎨' => 'tangata tā-fakatātā: kili kelokelo',
    '👨🏽‍🎨' => 'tangata tā-fakatātā: kili melomelo',
    '👨🏾‍🎨' => 'tangata tā-fakatātā: kili melomelo-ʻuliʻuli',
    '👨🏿‍🎨' => 'tangata tā-fakatātā: kili ʻuliʻuli',
    '👩🏻‍🎨' => 'fefine tā-fakatātā: kili hinehina',
    '👩🏼‍🎨' => 'fefine tā-fakatātā: kili kelokelo',
    '👩🏽‍🎨' => 'fefine tā-fakatātā: kili melomelo',
    '👩🏾‍🎨' => 'fefine tā-fakatātā: kili melomelo-ʻuliʻuli',
    '👩🏿‍🎨' => 'fefine tā-fakatātā: kili ʻuliʻuli',
    '🧑🏻‍✈' => 'pailate: kili hinehina',
    '🧑🏼‍✈' => 'pailate: kili kelokelo',
    '🧑🏽‍✈' => 'pailate: kili melomelo',
    '🧑🏾‍✈' => 'pailate: kili melomelo-ʻuliʻuli',
    '🧑🏿‍✈' => 'pailate: kili ʻuliʻuli',
    '👨🏻‍✈' => 'pailate tangata: kili hinehina',
    '👨🏼‍✈' => 'pailate tangata: kili kelokelo',
    '👨🏽‍✈' => 'pailate tangata: kili melomelo',
    '👨🏾‍✈' => 'pailate tangata: kili melomelo-ʻuliʻuli',
    '👨🏿‍✈' => 'pailate tangata: kili ʻuliʻuli',
    '👩🏻‍✈' => 'pailate fefine: kili hinehina',
    '👩🏼‍✈' => 'pailate fefine: kili kelokelo',
    '👩🏽‍✈' => 'pailate fefine: kili melomelo',
    '👩🏾‍✈' => 'pailate fefine: kili melomelo-ʻuliʻuli',
    '👩🏿‍✈' => 'pailate fefine: kili ʻuliʻuli',
    '🧑🏻‍🚀' => 'tokotaha folaufetuʻu: kili hinehina',
    '🧑🏼‍🚀' => 'tokotaha folaufetuʻu: kili kelokelo',
    '🧑🏽‍🚀' => 'tokotaha folaufetuʻu: kili melomelo',
    '🧑🏾‍🚀' => 'tokotaha folaufetuʻu: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🚀' => 'tokotaha folaufetuʻu: kili ʻuliʻuli',
    '👨🏻‍🚀' => 'tama folaufetuʻu: kili hinehina',
    '👨🏼‍🚀' => 'tama folaufetuʻu: kili kelokelo',
    '👨🏽‍🚀' => 'tama folaufetuʻu: kili melomelo',
    '👨🏾‍🚀' => 'tama folaufetuʻu: kili melomelo-ʻuliʻuli',
    '👨🏿‍🚀' => 'tama folaufetuʻu: kili ʻuliʻuli',
    '👩🏻‍🚀' => 'fefine folaufetuʻu: kili hinehina',
    '👩🏼‍🚀' => 'fefine folaufetuʻu: kili kelokelo',
    '👩🏽‍🚀' => 'fefine folaufetuʻu: kili melomelo',
    '👩🏾‍🚀' => 'fefine folaufetuʻu: kili melomelo-ʻuliʻuli',
    '👩🏿‍🚀' => 'fefine folaufetuʻu: kili ʻuliʻuli',
    '🧑🏻‍🚒' => 'tokotaha tāmate-afi: kili hinehina',
    '🧑🏼‍🚒' => 'tokotaha tāmate-afi: kili kelokelo',
    '🧑🏽‍🚒' => 'tokotaha tāmate-afi: kili melomelo',
    '🧑🏾‍🚒' => 'tokotaha tāmate-afi: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🚒' => 'tokotaha tāmate-afi: kili ʻuliʻuli',
    '👨🏻‍🚒' => 'tangata tāmate-afi: kili hinehina',
    '👨🏼‍🚒' => 'tangata tāmate-afi: kili kelokelo',
    '👨🏽‍🚒' => 'tangata tāmate-afi: kili melomelo',
    '👨🏾‍🚒' => 'tangata tāmate-afi: kili melomelo-ʻuliʻuli',
    '👨🏿‍🚒' => 'tangata tāmate-afi: kili ʻuliʻuli',
    '👩🏻‍🚒' => 'fefine tāmate-afi: kili hinehina',
    '👩🏼‍🚒' => 'fefine tāmate-afi: kili kelokelo',
    '👩🏽‍🚒' => 'fefine tāmate-afi: kili melomelo',
    '👩🏾‍🚒' => 'fefine tāmate-afi: kili melomelo-ʻuliʻuli',
    '👩🏿‍🚒' => 'fefine tāmate-afi: kili ʻuliʻuli',
    '👮🏻‍♂' => 'ʻofisa polisi tangata: kili hinehina',
    '👮🏼‍♂' => 'ʻofisa polisi tangata: kili kelokelo',
    '👮🏽‍♂' => 'ʻofisa polisi tangata: kili melomelo',
    '👮🏾‍♂' => 'ʻofisa polisi tangata: kili melomelo-ʻuliʻuli',
    '👮🏿‍♂' => 'ʻofisa polisi tangata: kili ʻuliʻuli',
    '👮🏻‍♀' => 'ʻofisa polisi fefine: kili hinehina',
    '👮🏼‍♀' => 'ʻofisa polisi fefine: kili kelokelo',
    '👮🏽‍♀' => 'ʻofisa polisi fefine: kili melomelo',
    '👮🏾‍♀' => 'ʻofisa polisi fefine: kili melomelo-ʻuliʻuli',
    '👮🏿‍♀' => 'ʻofisa polisi fefine: kili ʻuliʻuli',
    '🕵🏻‍♂' => 'tangata fakatotolo: kili hinehina',
    '🕵🏼‍♂' => 'tangata fakatotolo: kili kelokelo',
    '🕵🏽‍♂' => 'tangata fakatotolo: kili melomelo',
    '🕵🏾‍♂' => 'tangata fakatotolo: kili melomelo-ʻuliʻuli',
    '🕵🏿‍♂' => 'tangata fakatotolo: kili ʻuliʻuli',
    '🕵🏻‍♀' => 'fefine fakatotolo: kili hinehina',
    '🕵🏼‍♀' => 'fefine fakatotolo: kili kelokelo',
    '🕵🏽‍♀' => 'fefine fakatotolo: kili melomelo',
    '🕵🏾‍♀' => 'fefine fakatotolo: kili melomelo-ʻuliʻuli',
    '🕵🏿‍♀' => 'fefine fakatotolo: kili ʻuliʻuli',
    '💂🏻‍♂' => 'leʻo tangata: kili hinehina',
    '💂🏼‍♂' => 'leʻo tangata: kili kelokelo',
    '💂🏽‍♂' => 'leʻo tangata: kili melomelo',
    '💂🏾‍♂' => 'leʻo tangata: kili melomelo-ʻuliʻuli',
    '💂🏿‍♂' => 'leʻo tangata: kili ʻuliʻuli',
    '💂🏻‍♀' => 'leʻo fefine: kili hinehina',
    '💂🏼‍♀' => 'leʻo fefine: kili kelokelo',
    '💂🏽‍♀' => 'leʻo fefine: kili melomelo',
    '💂🏾‍♀' => 'leʻo fefine: kili melomelo-ʻuliʻuli',
    '💂🏿‍♀' => 'leʻo fefine: kili ʻuliʻuli',
    '👷🏻‍♂' => 'tangata ngāue langa: kili hinehina',
    '👷🏼‍♂' => 'tangata ngāue langa: kili kelokelo',
    '👷🏽‍♂' => 'tangata ngāue langa: kili melomelo',
    '👷🏾‍♂' => 'tangata ngāue langa: kili melomelo-ʻuliʻuli',
    '👷🏿‍♂' => 'tangata ngāue langa: kili ʻuliʻuli',
    '👷🏻‍♀' => 'fefine ngāue langa: kili hinehina',
    '👷🏼‍♀' => 'fefine ngāue langa: kili kelokelo',
    '👷🏽‍♀' => 'fefine ngāue langa: kili melomelo',
    '👷🏾‍♀' => 'fefine ngāue langa: kili melomelo-ʻuliʻuli',
    '👷🏿‍♀' => 'fefine ngāue langa: kili ʻuliʻuli',
    '👳🏻‍♂' => 'tangata tui faʻu: kili hinehina',
    '👳🏼‍♂' => 'tangata tui faʻu: kili kelokelo',
    '👳🏽‍♂' => 'tangata tui faʻu: kili melomelo',
    '👳🏾‍♂' => 'tangata tui faʻu: kili melomelo-ʻuliʻuli',
    '👳🏿‍♂' => 'tangata tui faʻu: kili ʻuliʻuli',
    '👳🏻‍♀' => 'fefine tui faʻu: kili hinehina',
    '👳🏼‍♀' => 'fefine tui faʻu: kili kelokelo',
    '👳🏽‍♀' => 'fefine tui faʻu: kili melomelo',
    '👳🏾‍♀' => 'fefine tui faʻu: kili melomelo-ʻuliʻuli',
    '👳🏿‍♀' => 'fefine tui faʻu: kili ʻuliʻuli',
    '🤵🏻‍♂' => 'tangata vala kakato: kili hinehina',
    '🤵🏼‍♂' => 'tangata vala kakato: kili kelokelo',
    '🤵🏽‍♂' => 'tangata vala kakato: kili melomelo',
    '🤵🏾‍♂' => 'tangata vala kakato: kili melomelo-ʻuliʻuli',
    '🤵🏿‍♂' => 'tangata vala kakato: kili ʻuliʻuli',
    '🤵🏻‍♀' => 'fefine vala kakato: kili hinehina',
    '🤵🏼‍♀' => 'fefine vala kakato: kili kelokelo',
    '🤵🏽‍♀' => 'fefine vala kakato: kili melomelo',
    '🤵🏾‍♀' => 'fefine vala kakato: kili melomelo-ʻuliʻuli',
    '🤵🏿‍♀' => 'fefine vala kakato: kili ʻuliʻuli',
    '👰🏻‍♂' => 'tangata tui veili: kili hinehina',
    '👰🏼‍♂' => 'tangata tui veili: kili kelokelo',
    '👰🏽‍♂' => 'tangata tui veili: kili melomelo',
    '👰🏾‍♂' => 'tangata tui veili: kili melomelo-ʻuliʻuli',
    '👰🏿‍♂' => 'tangata tui veili: kili ʻuliʻuli',
    '👰🏻‍♀' => 'fefine tui veili: kili hinehina',
    '👰🏼‍♀' => 'fefine tui veili: kili kelokelo',
    '👰🏽‍♀' => 'fefine tui veili: kili melomelo',
    '👰🏾‍♀' => 'fefine tui veili: kili melomelo-ʻuliʻuli',
    '👰🏿‍♀' => 'fefine tui veili: kili ʻuliʻuli',
    '👩🏻‍🍼' => 'fefine fakahuhu: kili hinehina',
    '👩🏼‍🍼' => 'fefine fakahuhu: kili kelokelo',
    '👩🏽‍🍼' => 'fefine fakahuhu: kili melomelo',
    '👩🏾‍🍼' => 'fefine fakahuhu: kili melomelo-ʻuliʻuli',
    '👩🏿‍🍼' => 'fefine fakahuhu: kili ʻuliʻuli',
    '👨🏻‍🍼' => 'tangata fakahuhu: kili hinehina',
    '👨🏼‍🍼' => 'tangata fakahuhu: kili kelokelo',
    '👨🏽‍🍼' => 'tangata fakahuhu: kili melomelo',
    '👨🏾‍🍼' => 'tangata fakahuhu: kili melomelo-ʻuliʻuli',
    '👨🏿‍🍼' => 'tangata fakahuhu: kili ʻuliʻuli',
    '🧑🏻‍🍼' => 'tokotaha fakahuhu: kili hinehina',
    '🧑🏼‍🍼' => 'tokotaha fakahuhu: kili kelokelo',
    '🧑🏽‍🍼' => 'tokotaha fakahuhu: kili melomelo',
    '🧑🏾‍🍼' => 'tokotaha fakahuhu: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🍼' => 'tokotaha fakahuhu: kili ʻuliʻuli',
    '🧑🏻‍🎄' => 'Sānita Kalausi tokotaha: kili hinehina',
    '🧑🏼‍🎄' => 'Sānita Kalausi tokotaha: kili kelokelo',
    '🧑🏽‍🎄' => 'Sānita Kalausi tokotaha: kili melomelo',
    '🧑🏾‍🎄' => 'Sānita Kalausi tokotaha: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🎄' => 'Sānita Kalausi tokotaha: kili ʻuliʻuli',
    '🦸🏻‍♂' => 'tangata ivimālohi: kili hinehina',
    '🦸🏼‍♂' => 'tangata ivimālohi: kili kelokelo',
    '🦸🏽‍♂' => 'tangata ivimālohi: kili melomelo',
    '🦸🏾‍♂' => 'tangata ivimālohi: kili melomelo-ʻuliʻuli',
    '🦸🏿‍♂' => 'tangata ivimālohi: kili ʻuliʻuli',
    '🦸🏻‍♀' => 'fefine ivimālohi: kili hinehina',
    '🦸🏼‍♀' => 'fefine ivimālohi: kili kelokelo',
    '🦸🏽‍♀' => 'fefine ivimālohi: kili melomelo',
    '🦸🏾‍♀' => 'fefine ivimālohi: kili melomelo-ʻuliʻuli',
    '🦸🏿‍♀' => 'fefine ivimālohi: kili ʻuliʻuli',
    '🦹🏻‍♂' => 'tangata kākā: kili hinehina',
    '🦹🏼‍♂' => 'tangata kākā: kili kelokelo',
    '🦹🏽‍♂' => 'tangata kākā: kili melomelo',
    '🦹🏾‍♂' => 'tangata kākā: kili melomelo-ʻuliʻuli',
    '🦹🏿‍♂' => 'tangata kākā: kili ʻuliʻuli',
    '🦹🏻‍♀' => 'fefine kākā: kili hinehina',
    '🦹🏼‍♀' => 'fefine kākā: kili kelokelo',
    '🦹🏽‍♀' => 'fefine kākā: kili melomelo',
    '🦹🏾‍♀' => 'fefine kākā: kili melomelo-ʻuliʻuli',
    '🦹🏿‍♀' => 'fefine kākā: kili ʻuliʻuli',
    '🧙🏻‍♂' => 'tangata taula-faʻahikehe: kili hinehina',
    '🧙🏼‍♂' => 'tangata taula-faʻahikehe: kili kelokelo',
    '🧙🏽‍♂' => 'tangata taula-faʻahikehe: kili melomelo',
    '🧙🏾‍♂' => 'tangata taula-faʻahikehe: kili melomelo-ʻuliʻuli',
    '🧙🏿‍♂' => 'tangata taula-faʻahikehe: kili ʻuliʻuli',
    '🧙🏻‍♀' => 'fefine taula-faʻahikehe: kili hinehina',
    '🧙🏼‍♀' => 'fefine taula-faʻahikehe: kili kelokelo',
    '🧙🏽‍♀' => 'fefine taula-faʻahikehe: kili melomelo',
    '🧙🏾‍♀' => 'fefine taula-faʻahikehe: kili melomelo-ʻuliʻuli',
    '🧙🏿‍♀' => 'fefine taula-faʻahikehe: kili ʻuliʻuli',
    '🧚🏻‍♂' => 'feeli tangata: kili hinehina',
    '🧚🏼‍♂' => 'feeli tangata: kili kelokelo',
    '🧚🏽‍♂' => 'feeli tangata: kili melomelo',
    '🧚🏾‍♂' => 'feeli tangata: kili melomelo-ʻuliʻuli',
    '🧚🏿‍♂' => 'feeli tangata: kili ʻuliʻuli',
    '🧚🏻‍♀' => 'feeli fefine: kili hinehina',
    '🧚🏼‍♀' => 'feeli fefine: kili kelokelo',
    '🧚🏽‍♀' => 'feeli fefine: kili melomelo',
    '🧚🏾‍♀' => 'feeli fefine: kili melomelo-ʻuliʻuli',
    '🧚🏿‍♀' => 'feeli fefine: kili ʻuliʻuli',
    '🧛🏻‍♂' => 'tangata misi toto: kili hinehina',
    '🧛🏼‍♂' => 'tangata misi toto: kili kelokelo',
    '🧛🏽‍♂' => 'tangata misi toto: kili melomelo',
    '🧛🏾‍♂' => 'tangata misi toto: kili melomelo-ʻuliʻuli',
    '🧛🏿‍♂' => 'tangata misi toto: kili ʻuliʻuli',
    '🧛🏻‍♀' => 'fefine misi toto: kili hinehina',
    '🧛🏼‍♀' => 'fefine misi toto: kili kelokelo',
    '🧛🏽‍♀' => 'fefine misi toto: kili melomelo',
    '🧛🏾‍♀' => 'fefine misi toto: kili melomelo-ʻuliʻuli',
    '🧛🏿‍♀' => 'fefine misi toto: kili ʻuliʻuli',
    '🧜🏻‍♂' => 'tangata meimeite: kili hinehina',
    '🧜🏼‍♂' => 'tangata meimeite: kili kelokelo',
    '🧜🏽‍♂' => 'tangata meimeite: kili melomelo',
    '🧜🏾‍♂' => 'tangata meimeite: kili melomelo-ʻuliʻuli',
    '🧜🏿‍♂' => 'tangata meimeite: kili ʻuliʻuli',
    '🧜🏻‍♀' => 'fefine meimeite: kili hinehina',
    '🧜🏼‍♀' => 'fefine meimeite: kili kelokelo',
    '🧜🏽‍♀' => 'fefine meimeite: kili melomelo',
    '🧜🏾‍♀' => 'fefine meimeite: kili melomelo-ʻuliʻuli',
    '🧜🏿‍♀' => 'fefine meimeite: kili ʻuliʻuli',
    '🧝🏻‍♂' => 'kiʻi feeli tangata: kili hinehina',
    '🧝🏼‍♂' => 'kiʻi feeli tangata: kili kelokelo',
    '🧝🏽‍♂' => 'kiʻi feeli tangata: kili melomelo',
    '🧝🏾‍♂' => 'kiʻi feeli tangata: kili melomelo-ʻuliʻuli',
    '🧝🏿‍♂' => 'kiʻi feeli tangata: kili ʻuliʻuli',
    '🧝🏻‍♀' => 'kiʻi feeli fefine: kili hinehina',
    '🧝🏼‍♀' => 'kiʻi feeli fefine: kili kelokelo',
    '🧝🏽‍♀' => 'kiʻi feeli fefine: kili melomelo',
    '🧝🏾‍♀' => 'kiʻi feeli fefine: kili melomelo-ʻuliʻuli',
    '🧝🏿‍♀' => 'kiʻi feeli fefine: kili ʻuliʻuli',
    '💆🏻‍♂' => 'tangata fotofotaʻi: kili hinehina',
    '💆🏼‍♂' => 'tangata fotofotaʻi: kili kelokelo',
    '💆🏽‍♂' => 'tangata fotofotaʻi: kili melomelo',
    '💆🏾‍♂' => 'tangata fotofotaʻi: kili melomelo-ʻuliʻuli',
    '💆🏿‍♂' => 'tangata fotofotaʻi: kili ʻuliʻuli',
    '💆🏻‍♀' => 'fefine fotofotaʻi: kili hinehina',
    '💆🏼‍♀' => 'fefine fotofotaʻi: kili kelokelo',
    '💆🏽‍♀' => 'fefine fotofotaʻi: kili melomelo',
    '💆🏾‍♀' => 'fefine fotofotaʻi: kili melomelo-ʻuliʻuli',
    '💆🏿‍♀' => 'fefine fotofotaʻi: kili ʻuliʻuli',
    '💇🏻‍♂' => 'tangata ʻulu kosi: kili hinehina',
    '💇🏼‍♂' => 'tangata ʻulu kosi: kili kelokelo',
    '💇🏽‍♂' => 'tangata ʻulu kosi: kili melomelo',
    '💇🏾‍♂' => 'tangata ʻulu kosi: kili melomelo-ʻuliʻuli',
    '💇🏿‍♂' => 'tangata ʻulu kosi: kili ʻuliʻuli',
    '💇🏻‍♀' => 'fefine ʻulu kosi: kili hinehina',
    '💇🏼‍♀' => 'fefine ʻulu kosi: kili kelokelo',
    '💇🏽‍♀' => 'fefine ʻulu kosi: kili melomelo',
    '💇🏾‍♀' => 'fefine ʻulu kosi: kili melomelo-ʻuliʻuli',
    '💇🏿‍♀' => 'fefine ʻulu kosi: kili ʻuliʻuli',
    '🚶🏻‍♂' => 'tangata lue: kili hinehina',
    '🚶🏼‍♂' => 'tangata lue: kili kelokelo',
    '🚶🏽‍♂' => 'tangata lue: kili melomelo',
    '🚶🏾‍♂' => 'tangata lue: kili melomelo-ʻuliʻuli',
    '🚶🏿‍♂' => 'tangata lue: kili ʻuliʻuli',
    '🚶🏻‍♀' => 'fefine lue: kili hinehina',
    '🚶🏼‍♀' => 'fefine lue: kili kelokelo',
    '🚶🏽‍♀' => 'fefine lue: kili melomelo',
    '🚶🏾‍♀' => 'fefine lue: kili melomelo-ʻuliʻuli',
    '🚶🏿‍♀' => 'fefine lue: kili ʻuliʻuli',
    '🚶🏻‍➡' => 'tokotaha lue: kili hinehina mo e hangamataʻu',
    '🚶🏼‍➡' => 'tokotaha lue: kili kelokelo mo e hangamataʻu',
    '🚶🏽‍➡' => 'tokotaha lue: kili melomelo mo e hangamataʻu',
    '🚶🏾‍➡' => 'tokotaha lue: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🚶🏿‍➡' => 'tokotaha lue: kili ʻuliʻuli mo e hangamataʻu',
    '🧍🏻‍♂' => 'tangata tuʻu: kili hinehina',
    '🧍🏼‍♂' => 'tangata tuʻu: kili kelokelo',
    '🧍🏽‍♂' => 'tangata tuʻu: kili melomelo',
    '🧍🏾‍♂' => 'tangata tuʻu: kili melomelo-ʻuliʻuli',
    '🧍🏿‍♂' => 'tangata tuʻu: kili ʻuliʻuli',
    '🧍🏻‍♀' => 'fefine tuʻu: kili hinehina',
    '🧍🏼‍♀' => 'fefine tuʻu: kili kelokelo',
    '🧍🏽‍♀' => 'fefine tuʻu: kili melomelo',
    '🧍🏾‍♀' => 'fefine tuʻu: kili melomelo-ʻuliʻuli',
    '🧍🏿‍♀' => 'fefine tuʻu: kili ʻuliʻuli',
    '🧎🏻‍♂' => 'tangata tūʻulutui: kili hinehina',
    '🧎🏼‍♂' => 'tangata tūʻulutui: kili kelokelo',
    '🧎🏽‍♂' => 'tangata tūʻulutui: kili melomelo',
    '🧎🏾‍♂' => 'tangata tūʻulutui: kili melomelo-ʻuliʻuli',
    '🧎🏿‍♂' => 'tangata tūʻulutui: kili ʻuliʻuli',
    '🧎🏻‍♀' => 'fefine tūʻulutui: kili hinehina',
    '🧎🏼‍♀' => 'fefine tūʻulutui: kili kelokelo',
    '🧎🏽‍♀' => 'fefine tūʻulutui: kili melomelo',
    '🧎🏾‍♀' => 'fefine tūʻulutui: kili melomelo-ʻuliʻuli',
    '🧎🏿‍♀' => 'fefine tūʻulutui: kili ʻuliʻuli',
    '🧎🏻‍➡' => 'tokotaha tūʻulutui: kili hinehina mo e hangamataʻu',
    '🧎🏼‍➡' => 'tokotaha tūʻulutui: kili kelokelo mo e hangamataʻu',
    '🧎🏽‍➡' => 'tokotaha tūʻulutui: kili melomelo mo e hangamataʻu',
    '🧎🏾‍➡' => 'tokotaha tūʻulutui: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🧎🏿‍➡' => 'tokotaha tūʻulutui: kili ʻuliʻuli mo e hangamataʻu',
    '🧑🏻‍🦯' => 'tokotaha moe tokotokokui: kili hinehina',
    '🧑🏼‍🦯' => 'tokotaha moe tokotokokui: kili kelokelo',
    '🧑🏽‍🦯' => 'tokotaha moe tokotokokui: kili melomelo',
    '🧑🏾‍🦯' => 'tokotaha moe tokotokokui: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🦯' => 'tokotaha moe tokotokokui: kili ʻuliʻuli',
    '👨🏻‍🦯' => 'tangata moe tokotokokui: kili hinehina',
    '👨🏼‍🦯' => 'tangata moe tokotokokui: kili kelokelo',
    '👨🏽‍🦯' => 'tangata moe tokotokokui: kili melomelo',
    '👨🏾‍🦯' => 'tangata moe tokotokokui: kili melomelo-ʻuliʻuli',
    '👨🏿‍🦯' => 'tangata moe tokotokokui: kili ʻuliʻuli',
    '👩🏻‍🦯' => 'fefine moe tokotokokui: kili hinehina',
    '👩🏼‍🦯' => 'fefine moe tokotokokui: kili kelokelo',
    '👩🏽‍🦯' => 'fefine moe tokotokokui: kili melomelo',
    '👩🏾‍🦯' => 'fefine moe tokotokokui: kili melomelo-ʻuliʻuli',
    '👩🏿‍🦯' => 'fefine moe tokotokokui: kili ʻuliʻuli',
    '🧑🏻‍🦼' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili hinehina',
    '🧑🏼‍🦼' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili kelokelo',
    '🧑🏽‍🦼' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili melomelo',
    '🧑🏾‍🦼' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🦼' => 'tokotaha ʻihe sāliote falemahaki mīsini: kili ʻuliʻuli',
    '👨🏻‍🦼' => 'tangata ʻihe sāliote falemahaki mīsini: kili hinehina',
    '👨🏼‍🦼' => 'tangata ʻihe sāliote falemahaki mīsini: kili kelokelo',
    '👨🏽‍🦼' => 'tangata ʻihe sāliote falemahaki mīsini: kili melomelo',
    '👨🏾‍🦼' => 'tangata ʻihe sāliote falemahaki mīsini: kili melomelo-ʻuliʻuli',
    '👨🏿‍🦼' => 'tangata ʻihe sāliote falemahaki mīsini: kili ʻuliʻuli',
    '👩🏻‍🦼' => 'fefine ʻihe sāliote falemahaki mīsini: kili hinehina',
    '👩🏼‍🦼' => 'fefine ʻihe sāliote falemahaki mīsini: kili kelokelo',
    '👩🏽‍🦼' => 'fefine ʻihe sāliote falemahaki mīsini: kili melomelo',
    '👩🏾‍🦼' => 'fefine ʻihe sāliote falemahaki mīsini: kili melomelo-ʻuliʻuli',
    '👩🏿‍🦼' => 'fefine ʻihe sāliote falemahaki mīsini: kili ʻuliʻuli',
    '🧑🏻‍🦽' => 'tokotaha ʻihe sāliote falemahaki: kili hinehina',
    '🧑🏼‍🦽' => 'tokotaha ʻihe sāliote falemahaki: kili kelokelo',
    '🧑🏽‍🦽' => 'tokotaha ʻihe sāliote falemahaki: kili melomelo',
    '🧑🏾‍🦽' => 'tokotaha ʻihe sāliote falemahaki: kili melomelo-ʻuliʻuli',
    '🧑🏿‍🦽' => 'tokotaha ʻihe sāliote falemahaki: kili ʻuliʻuli',
    '👨🏻‍🦽' => 'tangata ʻihe sāliote falemahaki: kili hinehina',
    '👨🏼‍🦽' => 'tangata ʻihe sāliote falemahaki: kili kelokelo',
    '👨🏽‍🦽' => 'tangata ʻihe sāliote falemahaki: kili melomelo',
    '👨🏾‍🦽' => 'tangata ʻihe sāliote falemahaki: kili melomelo-ʻuliʻuli',
    '👨🏿‍🦽' => 'tangata ʻihe sāliote falemahaki: kili ʻuliʻuli',
    '👩🏻‍🦽' => 'fefine ʻihe sāliote falemahaki: kili hinehina',
    '👩🏼‍🦽' => 'fefine ʻihe sāliote falemahaki: kili kelokelo',
    '👩🏽‍🦽' => 'fefine ʻihe sāliote falemahaki: kili melomelo',
    '👩🏾‍🦽' => 'fefine ʻihe sāliote falemahaki: kili melomelo-ʻuliʻuli',
    '👩🏿‍🦽' => 'fefine ʻihe sāliote falemahaki: kili ʻuliʻuli',
    '🏃🏻‍♂' => 'tangata lele: kili hinehina',
    '🏃🏼‍♂' => 'tangata lele: kili kelokelo',
    '🏃🏽‍♂' => 'tangata lele: kili melomelo',
    '🏃🏾‍♂' => 'tangata lele: kili melomelo-ʻuliʻuli',
    '🏃🏿‍♂' => 'tangata lele: kili ʻuliʻuli',
    '🏃🏻‍♀' => 'fefine lele: kili hinehina',
    '🏃🏼‍♀' => 'fefine lele: kili kelokelo',
    '🏃🏽‍♀' => 'fefine lele: kili melomelo',
    '🏃🏾‍♀' => 'fefine lele: kili melomelo-ʻuliʻuli',
    '🏃🏿‍♀' => 'fefine lele: kili ʻuliʻuli',
    '🏃🏻‍➡' => 'tokotaha lele: kili hinehina mo e hangamataʻu',
    '🏃🏼‍➡' => 'tokotaha lele: kili kelokelo mo e hangamataʻu',
    '🏃🏽‍➡' => 'tokotaha lele: kili melomelo mo e hangamataʻu',
    '🏃🏾‍➡' => 'tokotaha lele: kili melomelo-ʻuliʻuli mo e hangamataʻu',
    '🏃🏿‍➡' => 'tokotaha lele: kili ʻuliʻuli mo e hangamataʻu',
    '👯🏻‍♀' => 'fafine telinga-lāpisi: kili hinehina',
    '👯🏼‍♀' => 'fafine telinga-lāpisi: kili kelokelo',
    '👯🏽‍♀' => 'fafine telinga-lāpisi: kili melomelo',
    '👯🏾‍♀' => 'fafine telinga-lāpisi: kili melomelo-ʻuliʻuli',
    '👯🏿‍♀' => 'fafine telinga-lāpisi: kili ʻuliʻuli',
    '👯🏻‍♂' => 'ongo tangata telinga-lāpisi: kili hinehina',
    '👯🏼‍♂' => 'ongo tangata telinga-lāpisi: kili kelokelo',
    '👯🏽‍♂' => 'ongo tangata telinga-lāpisi: kili melomelo',
    '👯🏾‍♂' => 'ongo tangata telinga-lāpisi: kili melomelo-ʻuliʻuli',
    '👯🏿‍♂' => 'ongo tangata telinga-lāpisi: kili ʻuliʻuli',
    '🧖🏻‍♂' => 'tangata ʻi loki mao: kili hinehina',
    '🧖🏼‍♂' => 'tangata ʻi loki mao: kili kelokelo',
    '🧖🏽‍♂' => 'tangata ʻi loki mao: kili melomelo',
    '🧖🏾‍♂' => 'tangata ʻi loki mao: kili melomelo-ʻuliʻuli',
    '🧖🏿‍♂' => 'tangata ʻi loki mao: kili ʻuliʻuli',
    '🧖🏻‍♀' => 'fefine ʻi loki mao: kili hinehina',
    '🧖🏼‍♀' => 'fefine ʻi loki mao: kili kelokelo',
    '🧖🏽‍♀' => 'fefine ʻi loki mao: kili melomelo',
    '🧖🏾‍♀' => 'fefine ʻi loki mao: kili melomelo-ʻuliʻuli',
    '🧖🏿‍♀' => 'fefine ʻi loki mao: kili ʻuliʻuli',
    '🧗🏻‍♂' => 'tangata kaka: kili hinehina',
    '🧗🏼‍♂' => 'tangata kaka: kili kelokelo',
    '🧗🏽‍♂' => 'tangata kaka: kili melomelo',
    '🧗🏾‍♂' => 'tangata kaka: kili melomelo-ʻuliʻuli',
    '🧗🏿‍♂' => 'tangata kaka: kili ʻuliʻuli',
    '🧗🏻‍♀' => 'fefine kaka: kili hinehina',
    '🧗🏼‍♀' => 'fefine kaka: kili kelokelo',
    '🧗🏽‍♀' => 'fefine kaka: kili melomelo',
    '🧗🏾‍♀' => 'fefine kaka: kili melomelo-ʻuliʻuli',
    '🧗🏿‍♀' => 'fefine kaka: kili ʻuliʻuli',
    '🏌🏻‍♂' => 'tangata tāpulu: kili hinehina',
    '🏌🏼‍♂' => 'tangata tāpulu: kili kelokelo',
    '🏌🏽‍♂' => 'tangata tāpulu: kili melomelo',
    '🏌🏾‍♂' => 'tangata tāpulu: kili melomelo-ʻuliʻuli',
    '🏌🏿‍♂' => 'tangata tāpulu: kili ʻuliʻuli',
    '🏌🏻‍♀' => 'fefine tāpulu: kili hinehina',
    '🏌🏼‍♀' => 'fefine tāpulu: kili kelokelo',
    '🏌🏽‍♀' => 'fefine tāpulu: kili melomelo',
    '🏌🏾‍♀' => 'fefine tāpulu: kili melomelo-ʻuliʻuli',
    '🏌🏿‍♀' => 'fefine tāpulu: kili ʻuliʻuli',
    '🏄🏻‍♂' => 'tangata fānifo: kili hinehina',
    '🏄🏼‍♂' => 'tangata fānifo: kili kelokelo',
    '🏄🏽‍♂' => 'tangata fānifo: kili melomelo',
    '🏄🏾‍♂' => 'tangata fānifo: kili melomelo-ʻuliʻuli',
    '🏄🏿‍♂' => 'tangata fānifo: kili ʻuliʻuli',
    '🏄🏻‍♀' => 'fefine fānifo: kili hinehina',
    '🏄🏼‍♀' => 'fefine fānifo: kili kelokelo',
    '🏄🏽‍♀' => 'fefine fānifo: kili melomelo',
    '🏄🏾‍♀' => 'fefine fānifo: kili melomelo-ʻuliʻuli',
    '🏄🏿‍♀' => 'fefine fānifo: kili ʻuliʻuli',
    '🚣🏻‍♂' => 'tangata ʻaʻalo: kili hinehina',
    '🚣🏼‍♂' => 'tangata ʻaʻalo: kili kelokelo',
    '🚣🏽‍♂' => 'tangata ʻaʻalo: kili melomelo',
    '🚣🏾‍♂' => 'tangata ʻaʻalo: kili melomelo-ʻuliʻuli',
    '🚣🏿‍♂' => 'tangata ʻaʻalo: kili ʻuliʻuli',
    '🚣🏻‍♀' => 'fefine ʻaʻalo: kili hinehina',
    '🚣🏼‍♀' => 'fefine ʻaʻalo: kili kelokelo',
    '🚣🏽‍♀' => 'fefine ʻaʻalo: kili melomelo',
    '🚣🏾‍♀' => 'fefine ʻaʻalo: kili melomelo-ʻuliʻuli',
    '🚣🏿‍♀' => 'fefine ʻaʻalo: kili ʻuliʻuli',
    '🏊🏻‍♂' => 'tangata kakau: kili hinehina',
    '🏊🏼‍♂' => 'tangata kakau: kili kelokelo',
    '🏊🏽‍♂' => 'tangata kakau: kili melomelo',
    '🏊🏾‍♂' => 'tangata kakau: kili melomelo-ʻuliʻuli',
    '🏊🏿‍♂' => 'tangata kakau: kili ʻuliʻuli',
    '🏊🏻‍♀' => 'fefine kakau: kili hinehina',
    '🏊🏼‍♀' => 'fefine kakau: kili kelokelo',
    '🏊🏽‍♀' => 'fefine kakau: kili melomelo',
    '🏊🏾‍♀' => 'fefine kakau: kili melomelo-ʻuliʻuli',
    '🏊🏿‍♀' => 'fefine kakau: kili ʻuliʻuli',
    '⛹🏻‍♂' => 'tangata tōpuna pulu: kili hinehina',
    '⛹🏼‍♂' => 'tangata tōpuna pulu: kili kelokelo',
    '⛹🏽‍♂' => 'tangata tōpuna pulu: kili melomelo',
    '⛹🏾‍♂' => 'tangata tōpuna pulu: kili melomelo-ʻuliʻuli',
    '⛹🏿‍♂' => 'tangata tōpuna pulu: kili ʻuliʻuli',
    '⛹🏻‍♀' => 'fefine tōpuna pulu: kili hinehina',
    '⛹🏼‍♀' => 'fefine tōpuna pulu: kili kelokelo',
    '⛹🏽‍♀' => 'fefine tōpuna pulu: kili melomelo',
    '⛹🏾‍♀' => 'fefine tōpuna pulu: kili melomelo-ʻuliʻuli',
    '⛹🏿‍♀' => 'fefine tōpuna pulu: kili ʻuliʻuli',
    '🏋🏻‍♂' => 'tangata hiki meʻamamafa: kili hinehina',
    '🏋🏼‍♂' => 'tangata hiki meʻamamafa: kili kelokelo',
    '🏋🏽‍♂' => 'tangata hiki meʻamamafa: kili melomelo',
    '🏋🏾‍♂' => 'tangata hiki meʻamamafa: kili melomelo-ʻuliʻuli',
    '🏋🏿‍♂' => 'tangata hiki meʻamamafa: kili ʻuliʻuli',
    '🏋🏻‍♀' => 'fefine hiki meʻamamafa: kili hinehina',
    '🏋🏼‍♀' => 'fefine hiki meʻamamafa: kili kelokelo',
    '🏋🏽‍♀' => 'fefine hiki meʻamamafa: kili melomelo',
    '🏋🏾‍♀' => 'fefine hiki meʻamamafa: kili melomelo-ʻuliʻuli',
    '🏋🏿‍♀' => 'fefine hiki meʻamamafa: kili ʻuliʻuli',
    '🚴🏻‍♂' => 'tangata heka pasikala: kili hinehina',
    '🚴🏼‍♂' => 'tangata heka pasikala: kili kelokelo',
    '🚴🏽‍♂' => 'tangata heka pasikala: kili melomelo',
    '🚴🏾‍♂' => 'tangata heka pasikala: kili melomelo-ʻuliʻuli',
    '🚴🏿‍♂' => 'tangata heka pasikala: kili ʻuliʻuli',
    '🚴🏻‍♀' => 'fefine heka pasikala: kili hinehina',
    '🚴🏼‍♀' => 'fefine heka pasikala: kili kelokelo',
    '🚴🏽‍♀' => 'fefine heka pasikala: kili melomelo',
    '🚴🏾‍♀' => 'fefine heka pasikala: kili melomelo-ʻuliʻuli',
    '🚴🏿‍♀' => 'fefine heka pasikala: kili ʻuliʻuli',
    '🚵🏻‍♂' => 'tangata heka pasikala moʻunga: kili hinehina',
    '🚵🏼‍♂' => 'tangata heka pasikala moʻunga: kili kelokelo',
    '🚵🏽‍♂' => 'tangata heka pasikala moʻunga: kili melomelo',
    '🚵🏾‍♂' => 'tangata heka pasikala moʻunga: kili melomelo-ʻuliʻuli',
    '🚵🏿‍♂' => 'tangata heka pasikala moʻunga: kili ʻuliʻuli',
    '🚵🏻‍♀' => 'fefine heka pasikala moʻunga: kili hinehina',
    '🚵🏼‍♀' => 'fefine heka pasikala moʻunga: kili kelokelo',
    '🚵🏽‍♀' => 'fefine heka pasikala moʻunga: kili melomelo',
    '🚵🏾‍♀' => 'fefine heka pasikala moʻunga: kili melomelo-ʻuliʻuli',
    '🚵🏿‍♀' => 'fefine heka pasikala moʻunga: kili ʻuliʻuli',
    '🤸🏻‍♂' => 'tangata tākisi: kili hinehina',
    '🤸🏼‍♂' => 'tangata tākisi: kili kelokelo',
    '🤸🏽‍♂' => 'tangata tākisi: kili melomelo',
    '🤸🏾‍♂' => 'tangata tākisi: kili melomelo-ʻuliʻuli',
    '🤸🏿‍♂' => 'tangata tākisi: kili ʻuliʻuli',
    '🤸🏻‍♀' => 'fefine tākisi: kili hinehina',
    '🤸🏼‍♀' => 'fefine tākisi: kili kelokelo',
    '🤸🏽‍♀' => 'fefine tākisi: kili melomelo',
    '🤸🏾‍♀' => 'fefine tākisi: kili melomelo-ʻuliʻuli',
    '🤸🏿‍♀' => 'fefine tākisi: kili ʻuliʻuli',
    '🤼🏻‍♀' => 'fafine fangatua: kili hinehina',
    '🤼🏼‍♀' => 'fafine fangatua: kili kelokelo',
    '🤼🏽‍♀' => 'fafine fangatua: kili melomelo',
    '🤼🏾‍♀' => 'fafine fangatua: kili melomelo-ʻuliʻuli',
    '🤼🏿‍♀' => 'fafine fangatua: kili ʻuliʻuli',
    '🤼🏻‍♂' => 'ongo tangata fangatua: kili hinehina',
    '🤼🏼‍♂' => 'ongo tangata fangatua: kili kelokelo',
    '🤼🏽‍♂' => 'ongo tangata fangatua: kili melomelo',
    '🤼🏾‍♂' => 'ongo tangata fangatua: kili melomelo-ʻuliʻuli',
    '🤼🏿‍♂' => 'ongo tangata fangatua: kili ʻuliʻuli',
    '🤽🏻‍♂' => 'tangata polovai: kili hinehina',
    '🤽🏼‍♂' => 'tangata polovai: kili kelokelo',
    '🤽🏽‍♂' => 'tangata polovai: kili melomelo',
    '🤽🏾‍♂' => 'tangata polovai: kili melomelo-ʻuliʻuli',
    '🤽🏿‍♂' => 'tangata polovai: kili ʻuliʻuli',
    '🤽🏻‍♀' => 'fefine polovai: kili hinehina',
    '🤽🏼‍♀' => 'fefine polovai: kili kelokelo',
    '🤽🏽‍♀' => 'fefine polovai: kili melomelo',
    '🤽🏾‍♀' => 'fefine polovai: kili melomelo-ʻuliʻuli',
    '🤽🏿‍♀' => 'fefine polovai: kili ʻuliʻuli',
    '🤾🏻‍♂' => 'tangata netipolo: kili hinehina',
    '🤾🏼‍♂' => 'tangata netipolo: kili kelokelo',
    '🤾🏽‍♂' => 'tangata netipolo: kili melomelo',
    '🤾🏾‍♂' => 'tangata netipolo: kili melomelo-ʻuliʻuli',
    '🤾🏿‍♂' => 'tangata netipolo: kili ʻuliʻuli',
    '🤾🏻‍♀' => 'fefine netipolo: kili hinehina',
    '🤾🏼‍♀' => 'fefine netipolo: kili kelokelo',
    '🤾🏽‍♀' => 'fefine netipolo: kili melomelo',
    '🤾🏾‍♀' => 'fefine netipolo: kili melomelo-ʻuliʻuli',
    '🤾🏿‍♀' => 'fefine netipolo: kili ʻuliʻuli',
    '🤹🏻‍♂' => 'tangata hiko: kili hinehina',
    '🤹🏼‍♂' => 'tangata hiko: kili kelokelo',
    '🤹🏽‍♂' => 'tangata hiko: kili melomelo',
    '🤹🏾‍♂' => 'tangata hiko: kili melomelo-ʻuliʻuli',
    '🤹🏿‍♂' => 'tangata hiko: kili ʻuliʻuli',
    '🤹🏻‍♀' => 'fefine hiko: kili hinehina',
    '🤹🏼‍♀' => 'fefine hiko: kili kelokelo',
    '🤹🏽‍♀' => 'fefine hiko: kili melomelo',
    '🤹🏾‍♀' => 'fefine hiko: kili melomelo-ʻuliʻuli',
    '🤹🏿‍♀' => 'fefine hiko: kili ʻuliʻuli',
    '🧘🏻‍♂' => 'tangata tangutu fehauaki: kili hinehina',
    '🧘🏼‍♂' => 'tangata tangutu fehauaki: kili kelokelo',
    '🧘🏽‍♂' => 'tangata tangutu fehauaki: kili melomelo',
    '🧘🏾‍♂' => 'tangata tangutu fehauaki: kili melomelo-ʻuliʻuli',
    '🧘🏿‍♂' => 'tangata tangutu fehauaki: kili ʻuliʻuli',
    '🧘🏻‍♀' => 'fefine tangutu fehauaki: kili hinehina',
    '🧘🏼‍♀' => 'fefine tangutu fehauaki: kili kelokelo',
    '🧘🏽‍♀' => 'fefine tangutu fehauaki: kili melomelo',
    '🧘🏾‍♀' => 'fefine tangutu fehauaki: kili melomelo-ʻuliʻuli',
    '🧘🏿‍♀' => 'fefine tangutu fehauaki: kili ʻuliʻuli',
    '🧑‍🦰' => 'kakai lalahi: ʻulu kulokula',
    '🧑‍🦱' => 'kakai lalahi: ʻulu mingimingi',
    '🧑‍🦳' => 'kakai lalahi: ʻulu hinā',
    '🧑‍🦲' => 'kakai lalahi: ʻulu tula',
    '👨‍🦰' => 'tangata: ʻulu kulokula',
    '👨‍🦱' => 'tangata: ʻulu mingimingi',
    '👨‍🦳' => 'tangata: ʻulu hinā',
    '👨‍🦲' => 'tangata: ʻulu tula',
    '👩‍🦰' => 'fefine: ʻulu kulokula',
    '👩‍🦱' => 'fefine: ʻulu mingimingi',
    '👩‍🦳' => 'fefine: ʻulu hinā',
    '👩‍🦲' => 'fefine: ʻulu tula',
    '🚶‍➡' => 'tokotaha lue: hangamataʻu',
    '🧎‍➡' => 'tokotaha tūʻulutui: hangamataʻu',
    '🏃‍➡' => 'tokotaha lele: hangamataʻu',
    '👨‍👦' => 'fāmili: tangata mo e tamasiʻi',
    '👨‍👧' => 'fāmili: tangata mo e taʻahine',
    '👩‍👦' => 'fāmili: fefine mo e tamasiʻi',
    '👩‍👧' => 'fāmili: fefine mo e taʻahine',
    '😶‍🌫' => 'mata ʻihe ʻao',
    '😮‍💨' => 'mata hō',
    '🙂‍↕' => 'mata kamokamo',
    '😵‍💫' => 'mata takatakai',
    '❤‍🔥' => 'mafu afi',
    '❤‍🩹' => 'mafu monomono',
    '👁‍🗨' => 'kanoʻimata ʻi ha pulalea',
    '🧔‍♂' => 'tangata kava',
    '👱‍♂' => 'tangata ʻulu kelo',
    '🧔‍♀' => 'fefine kava',
    '👱‍♀' => 'fefine ʻulu kelo',
    '🙍‍♂' => 'tangata matamamahi',
    '🙍‍♀' => 'fefine matamamahi',
    '🙎‍♂' => 'tangata mataʻita',
    '🙎‍♀' => 'fefine mataʻita',
    '🙅‍♂' => 'tangata kaunima fetuiaki',
    '🙅‍♀' => 'fefine kaunima fetuiaki',
    '🙆‍♂' => 'tangata kaunima fetuiaki ʻolunga',
    '🙆‍♀' => 'fefine kaunima fetuiaki ʻolunga',
    '💁‍♂' => 'tangata nima mafola',
    '💁‍♀' => 'fefine nima mafola',
    '🙋‍♂' => 'tangata nima ʻi ʻolunga',
    '🙋‍♀' => 'fefine nima ʻi ʻolunga',
    '🧏‍♂' => 'tangata tuli',
    '🧏‍♀' => 'fefine tuli',
    '🙇‍♂' => 'tangata punou',
    '🙇‍♀' => 'fefine punou',
    '🤦‍♂' => 'tangata nima ʻihe mata',
    '🤦‍♀' => 'fefine nima ʻihe mata',
    '🤷‍♂' => 'tangata fakamahiki',
    '🤷‍♀' => 'fefine fakamahiki',
    '🧑‍⚕' => 'neesi',
    '👨‍⚕' => 'neesi tangata',
    '👩‍⚕' => 'neesi fefine',
    '🧑‍🎓' => 'tokotaha ako',
    '👨‍🎓' => 'tamasiʻi ako',
    '👩‍🎓' => 'taʻahine ako',
    '🧑‍🏫' => 'faiako',
    '👨‍🏫' => 'faiako tangata',
    '👩‍🏫' => 'faiako fefine',
    '🧑‍⚖' => 'fakamaau',
    '👨‍⚖' => 'fakamaau tangata',
    '👩‍⚖' => 'fakamaau fefine',
    '🧑‍🌾' => 'tokotaha ngoue',
    '👨‍🌾' => 'tangata ngoue',
    '👩‍🌾' => 'fefine ngoue',
    '🧑‍🍳' => 'tokotaha ngaohikai',
    '👨‍🍳' => 'tangata ngaohikai',
    '👩‍🍳' => 'fefine ngaohikai',
    '🧑‍🔧' => 'ʻenisia',
    '👨‍🔧' => 'ʻenisinia tangata',
    '👩‍🔧' => 'ʻenisinia fefine',
    '🧑‍🏭' => 'tokotaha ngāue fale faʻuʻanga',
    '👨‍🏭' => 'tangata ngāue fale faʻuʻanga',
    '👩‍🏭' => 'fefine ngāue fale faʻuʻanga',
    '🧑‍💼' => 'tokotaha ngāue ʻōfisi',
    '👨‍💼' => 'tangata ngāue ʻōfisi',
    '👩‍💼' => 'fefine ngāue ʻōfisi',
    '🧑‍🔬' => 'tokotaha faisaienisi',
    '👨‍🔬' => 'tangata faisaienisi',
    '👩‍🔬' => 'fefine faisaienisi',
    '🧑‍💻' => 'tokotaha fakatekinolosia',
    '👨‍💻' => 'tangata fakatekinolosia',
    '👩‍💻' => 'fefine fakatekinolosia',
    '🧑‍🎤' => 'tokotaha hiva',
    '👨‍🎤' => 'tangata hiva',
    '👩‍🎤' => 'fefine hiva',
    '🧑‍🎨' => 'tokotaha tā-fakatātā',
    '👨‍🎨' => 'tangata tā-fakatātā',
    '👩‍🎨' => 'fefine tā-fakatātā',
    '🧑‍✈' => 'pailate',
    '👨‍✈' => 'pailate tangata',
    '👩‍✈' => 'pailate fefine',
    '🧑‍🚀' => 'tokotaha folaufetuʻu',
    '👨‍🚀' => 'tama folaufetuʻu',
    '👩‍🚀' => 'fefine folaufetuʻu',
    '🧑‍🚒' => 'tokotaha tāmate-afi',
    '👨‍🚒' => 'tangata tāmate-afi',
    '👩‍🚒' => 'fefine tāmate-afi',
    '👮‍♂' => 'ʻofisa polisi tangata',
    '👮‍♀' => 'ʻofisa polisi fefine',
    '🕵‍♂' => 'tangata fakatotolo',
    '🕵‍♀' => 'fefine fakatotolo',
    '💂‍♂' => 'leʻo tangata',
    '💂‍♀' => 'leʻo fefine',
    '👷‍♂' => 'tangata ngāue langa',
    '👷‍♀' => 'fefine ngāue langa',
    '👳‍♂' => 'tangata tui faʻu',
    '👳‍♀' => 'fefine tui faʻu',
    '🤵‍♂' => 'tangata vala kakato',
    '🤵‍♀' => 'fefine vala kakato',
    '👰‍♂' => 'tangata tui veili',
    '👰‍♀' => 'fefine tui veili',
    '👩‍🍼' => 'fefine fakahuhu',
    '👨‍🍼' => 'tangata fakahuhu',
    '🧑‍🍼' => 'tokotaha fakahuhu',
    '🧑‍🎄' => 'Sānita Kalausi tokotaha',
    '🦸‍♂' => 'tangata ivimālohi',
    '🦸‍♀' => 'fefine ivimālohi',
    '🦹‍♂' => 'tangata kākā',
    '🦹‍♀' => 'fefine kākā',
    '🧙‍♂' => 'tangata taula-faʻahikehe',
    '🧙‍♀' => 'fefine taula-faʻahikehe',
    '🧚‍♂' => 'feeli tangata',
    '🧚‍♀' => 'feeli fefine',
    '🧛‍♂' => 'tangata misi toto',
    '🧛‍♀' => 'fefine misi toto',
    '🧜‍♂' => 'tangata meimeite',
    '🧜‍♀' => 'fefine meimeite',
    '🧝‍♂' => 'kiʻi feeli tangata',
    '🧝‍♀' => 'kiʻi feeli fefine',
    '🧞‍♂' => 'faʻahikehe tangata',
    '🧞‍♀' => 'faʻahikehe fefine',
    '🧟‍♂' => 'tēvolo tangata',
    '🧟‍♀' => 'tēvolo fefine',
    '💆‍♂' => 'tangata fotofotaʻi',
    '💆‍♀' => 'fefine fotofotaʻi',
    '💇‍♂' => 'tangata ʻulu kosi',
    '💇‍♀' => 'fefine ʻulu kosi',
    '🚶‍♂' => 'tangata lue',
    '🚶‍♀' => 'fefine lue',
    '🧍‍♂' => 'tangata tuʻu',
    '🧍‍♀' => 'fefine tuʻu',
    '🧎‍♂' => 'tangata tūʻulutui',
    '🧎‍♀' => 'fefine tūʻulutui',
    '🧑‍🦯' => 'tokotaha moe tokotokokui',
    '👨‍🦯' => 'tangata moe tokotokokui',
    '👩‍🦯' => 'fefine moe tokotokokui',
    '🧑‍🦼' => 'tokotaha ʻihe sāliote falemahaki mīsini',
    '👨‍🦼' => 'tangata ʻihe sāliote falemahaki mīsini',
    '👩‍🦼' => 'fefine ʻihe sāliote falemahaki mīsini',
    '🧑‍🦽' => 'tokotaha ʻihe sāliote falemahaki',
    '👨‍🦽' => 'tangata ʻihe sāliote falemahaki',
    '👩‍🦽' => 'fefine ʻihe sāliote falemahaki',
    '🏃‍♂' => 'tangata lele',
    '🏃‍♀' => 'fefine lele',
    '🧑‍🩰' => 'tokotaha fakahulohula',
    '👯‍♂' => 'ongo tangata telinga-lāpisi',
    '👯‍♀' => 'fafine telinga-lāpisi',
    '🧖‍♂' => 'tangata ʻi loki mao',
    '🧖‍♀' => 'fefine ʻi loki mao',
    '🧗‍♂' => 'tangata kaka',
    '🧗‍♀' => 'fefine kaka',
    '🏌‍♂' => 'tangata tāpulu',
    '🏌‍♀' => 'fefine tāpulu',
    '🏄‍♂' => 'tangata fānifo',
    '🏄‍♀' => 'fefine fānifo',
    '🚣‍♂' => 'tangata ʻaʻalo',
    '🚣‍♀' => 'fefine ʻaʻalo',
    '🏊‍♂' => 'tangata kakau',
    '🏊‍♀' => 'fefine kakau',
    '⛹‍♂' => 'tangata tōpuna pulu',
    '⛹‍♀' => 'fefine tōpuna pulu',
    '🏋‍♂' => 'tangata hiki meʻamamafa',
    '🏋‍♀' => 'fefine hiki meʻamamafa',
    '🚴‍♂' => 'tangata heka pasikala',
    '🚴‍♀' => 'fefine heka pasikala',
    '🚵‍♂' => 'tangata heka pasikala moʻunga',
    '🚵‍♀' => 'fefine heka pasikala moʻunga',
    '🤸‍♂' => 'tangata tākisi',
    '🤸‍♀' => 'fefine tākisi',
    '🤼‍♂' => 'ongo tangata fangatua',
    '🤼‍♀' => 'fafine fangatua',
    '🤽‍♂' => 'tangata polovai',
    '🤽‍♀' => 'fefine polovai',
    '🤾‍♂' => 'tangata netipolo',
    '🤾‍♀' => 'fefine netipolo',
    '🤹‍♂' => 'tangata hiko',
    '🤹‍♀' => 'fefine hiko',
    '🧘‍♂' => 'tangata tangutu fehauaki',
    '🧘‍♀' => 'fefine tangutu fehauaki',
    '🧑‍🧒' => 'fāmili: motuʻa, fānau',
    '🐕‍🦺' => 'kulī tokoni',
    '🐈‍⬛' => 'pusi ʻuliʻuli',
    '🐻‍❄' => 'pea hinehina',
    '🐦‍⬛' => 'manupuna lanuʻuliʻuli',
    '🐦‍🔥' => 'feniki',
    '🍋‍🟩' => 'laime',
    '🍄‍🟫' => 'fakamalu-ʻa-tēvolo kula',
    '⛓‍💥' => 'sēini motu',
    '🏳‍🌈' => 'fuka ʻūmata',
    '🏳‍⚧' => 'fuka pulū-pingikē-hinehina',
    '🏴‍☠' => 'fuka kaihaʻatahi',
    '👋🏻' => 'nima taʻataʻalo: kili hinehina',
    '👋🏼' => 'nima taʻataʻalo: kili kelokelo',
    '👋🏽' => 'nima taʻataʻalo: kili melomelo',
    '👋🏾' => 'nima taʻataʻalo: kili melomelo-ʻuliʻuli',
    '👋🏿' => 'nima taʻataʻalo: kili ʻuliʻuli',
    '🤚🏻' => 'tuʻanima hiki ki ʻolunga: kili hinehina',
    '🤚🏼' => 'tuʻanima hiki ki ʻolunga: kili kelokelo',
    '🤚🏽' => 'tuʻanima hiki ki ʻolunga: kili melomelo',
    '🤚🏾' => 'tuʻanima hiki ki ʻolunga: kili melomelo-ʻuliʻuli',
    '🤚🏿' => 'tuʻanima hiki ki ʻolunga: kili ʻuliʻuli',
    '🖐🏻' => 'nima fālalahi: kili hinehina',
    '🖐🏼' => 'nima fālalahi: kili kelokelo',
    '🖐🏽' => 'nima fālalahi: kili melomelo',
    '🖐🏾' => 'nima fālalahi: kili melomelo-ʻuliʻuli',
    '🖐🏿' => 'nima fālalahi: kili ʻuliʻuli',
    '✋🏻' => 'nima hiki ki ʻolunga: kili hinehina',
    '✋🏼' => 'nima hiki ki ʻolunga: kili kelokelo',
    '✋🏽' => 'nima hiki ki ʻolunga: kili melomelo',
    '✋🏾' => 'nima hiki ki ʻolunga: kili melomelo-ʻuliʻuli',
    '✋🏿' => 'nima hiki ki ʻolunga: kili ʻuliʻuli',
    '🖖🏻' => 'nima mavaeua: kili hinehina',
    '🖖🏼' => 'nima mavaeua: kili kelokelo',
    '🖖🏽' => 'nima mavaeua: kili melomelo',
    '🖖🏾' => 'nima mavaeua: kili melomelo-ʻuliʻuli',
    '🖖🏿' => 'nima mavaeua: kili ʻuliʻuli',
    '🫱🏻' => 'nima ki mataʻu: kili hinehina',
    '🫱🏼' => 'nima ki mataʻu: kili kelokelo',
    '🫱🏽' => 'nima ki mataʻu: kili melomelo',
    '🫱🏾' => 'nima ki mataʻu: kili melomelo-ʻuliʻuli',
    '🫱🏿' => 'nima ki mataʻu: kili ʻuliʻuli',
    '🫲🏻' => 'ninma ki hema: kili hinehina',
    '🫲🏼' => 'ninma ki hema: kili kelokelo',
    '🫲🏽' => 'ninma ki hema: kili melomelo',
    '🫲🏾' => 'ninma ki hema: kili melomelo-ʻuliʻuli',
    '🫲🏿' => 'ninma ki hema: kili ʻuliʻuli',
    '🫳🏻' => 'nima ʻohifo: kili hinehina',
    '🫳🏼' => 'nima ʻohifo: kili kelokelo',
    '🫳🏽' => 'nima ʻohifo: kili melomelo',
    '🫳🏾' => 'nima ʻohifo: kili melomelo-ʻuliʻuli',
    '🫳🏿' => 'nima ʻohifo: kili ʻuliʻuli',
    '🫴🏻' => 'nima ʻohake: kili hinehina',
    '🫴🏼' => 'nima ʻohake: kili kelokelo',
    '🫴🏽' => 'nima ʻohake: kili melomelo',
    '🫴🏾' => 'nima ʻohake: kili melomelo-ʻuliʻuli',
    '🫴🏿' => 'nima ʻohake: kili ʻuliʻuli',
    '🫷🏻' => 'nima teke ki hema: kili hinehina',
    '🫷🏼' => 'nima teke ki hema: kili kelokelo',
    '🫷🏽' => 'nima teke ki hema: kili melomelo',
    '🫷🏾' => 'nima teke ki hema: kili melomelo-ʻuliʻuli',
    '🫷🏿' => 'nima teke ki hema: kili ʻuliʻuli',
    '🫸🏻' => 'nima teke ki mataʻu: kili hinehina',
    '🫸🏼' => 'nima teke ki mataʻu: kili kelokelo',
    '🫸🏽' => 'nima teke ki mataʻu: kili melomelo',
    '🫸🏾' => 'nima teke ki mataʻu: kili melomelo-ʻuliʻuli',
    '🫸🏿' => 'nima teke ki mataʻu: kili ʻuliʻuli',
    '👌🏻' => 'nima fakaʻilonga sai: kili hinehina',
    '👌🏼' => 'nima fakaʻilonga sai: kili kelokelo',
    '👌🏽' => 'nima fakaʻilonga sai: kili melomelo',
    '👌🏾' => 'nima fakaʻilonga sai: kili melomelo-ʻuliʻuli',
    '👌🏿' => 'nima fakaʻilonga sai: kili ʻuliʻuli',
    '🤌🏻' => 'louhiʻinima fakamaʻopoʻopo: kili hinehina',
    '🤌🏼' => 'louhiʻinima fakamaʻopoʻopo: kili kelokelo',
    '🤌🏽' => 'louhiʻinima fakamaʻopoʻopo: kili melomelo',
    '🤌🏾' => 'louhiʻinima fakamaʻopoʻopo: kili melomelo-ʻuliʻuli',
    '🤌🏿' => 'louhiʻinima fakamaʻopoʻopo: kili ʻuliʻuli',
    '🤏🏻' => 'nima fakamaʻopoʻopo: kili hinehina',
    '🤏🏼' => 'nima fakamaʻopoʻopo: kili kelokelo',
    '🤏🏽' => 'nima fakamaʻopoʻopo: kili melomelo',
    '🤏🏾' => 'nima fakamaʻopoʻopo: kili melomelo-ʻuliʻuli',
    '🤏🏿' => 'nima fakamaʻopoʻopo: kili ʻuliʻuli',
    '✌🏻' => 'nima ikuna: kili hinehina',
    '✌🏼' => 'nima ikuna: kili kelokelo',
    '✌🏽' => 'nima ikuna: kili melomelo',
    '✌🏾' => 'nima ikuna: kili melomelo-ʻuliʻuli',
    '✌🏿' => 'nima ikuna: kili ʻuliʻuli',
    '🤞🏻' => 'louhiʻinima fehauaki: kili hinehina',
    '🤞🏼' => 'louhiʻinima fehauaki: kili kelokelo',
    '🤞🏽' => 'louhiʻinima fehauaki: kili melomelo',
    '🤞🏾' => 'louhiʻinima fehauaki: kili melomelo-ʻuliʻuli',
    '🤞🏿' => 'louhiʻinima fehauaki: kili ʻuliʻuli',
    '🫰🏻' => 'louhiʻinima moe motuʻatuhu fehauaki: kili hinehina',
    '🫰🏼' => 'louhiʻinima moe motuʻatuhu fehauaki: kili kelokelo',
    '🫰🏽' => 'louhiʻinima moe motuʻatuhu fehauaki: kili melomelo',
    '🫰🏾' => 'louhiʻinima moe motuʻatuhu fehauaki: kili melomelo-ʻuliʻuli',
    '🫰🏿' => 'louhiʻinima moe motuʻatuhu fehauaki: kili ʻuliʻuli',
    '🤟🏻' => 'nima fakaʻilonga mafu: kili hinehina',
    '🤟🏼' => 'nima fakaʻilonga mafu: kili kelokelo',
    '🤟🏽' => 'nima fakaʻilonga mafu: kili melomelo',
    '🤟🏾' => 'nima fakaʻilonga mafu: kili melomelo-ʻuliʻuli',
    '🤟🏿' => 'nima fakaʻilonga mafu: kili ʻuliʻuli',
    '🤘🏻' => 'nima fakaʻilonga fakatēvolo: kili hinehina',
    '🤘🏼' => 'nima fakaʻilonga fakatēvolo: kili kelokelo',
    '🤘🏽' => 'nima fakaʻilonga fakatēvolo: kili melomelo',
    '🤘🏾' => 'nima fakaʻilonga fakatēvolo: kili melomelo-ʻuliʻuli',
    '🤘🏿' => 'nima fakaʻilonga fakatēvolo: kili ʻuliʻuli',
    '🤙🏻' => 'nima fakaʻilonga tā mai: kili hinehina',
    '🤙🏼' => 'nima fakaʻilonga tā mai: kili kelokelo',
    '🤙🏽' => 'nima fakaʻilonga tā mai: kili melomelo',
    '🤙🏾' => 'nima fakaʻilonga tā mai: kili melomelo-ʻuliʻuli',
    '🤙🏿' => 'nima fakaʻilonga tā mai: kili ʻuliʻuli',
    '👈🏻' => 'tuhu tuʻanima tonu ki hema: kili hinehina',
    '👈🏼' => 'tuhu tuʻanima tonu ki hema: kili kelokelo',
    '👈🏽' => 'tuhu tuʻanima tonu ki hema: kili melomelo',
    '👈🏾' => 'tuhu tuʻanima tonu ki hema: kili melomelo-ʻuliʻuli',
    '👈🏿' => 'tuhu tuʻanima tonu ki hema: kili ʻuliʻuli',
    '👉🏻' => 'tuhu tuʻanima tonu ki mataʻu: kili hinehina',
    '👉🏼' => 'tuhu tuʻanima tonu ki mataʻu: kili kelokelo',
    '👉🏽' => 'tuhu tuʻanima tonu ki mataʻu: kili melomelo',
    '👉🏾' => 'tuhu tuʻanima tonu ki mataʻu: kili melomelo-ʻuliʻuli',
    '👉🏿' => 'tuhu tuʻanima tonu ki mataʻu: kili ʻuliʻuli',
    '👆🏻' => 'tuhu tuʻanima tonu ki ʻolunga: kili hinehina',
    '👆🏼' => 'tuhu tuʻanima tonu ki ʻolunga: kili kelokelo',
    '👆🏽' => 'tuhu tuʻanima tonu ki ʻolunga: kili melomelo',
    '👆🏾' => 'tuhu tuʻanima tonu ki ʻolunga: kili melomelo-ʻuliʻuli',
    '👆🏿' => 'tuhu tuʻanima tonu ki ʻolunga: kili ʻuliʻuli',
    '🖕🏻' => 'tuhu ʻi loto: kili hinehina',
    '🖕🏼' => 'tuhu ʻi loto: kili kelokelo',
    '🖕🏽' => 'tuhu ʻi loto: kili melomelo',
    '🖕🏾' => 'tuhu ʻi loto: kili melomelo-ʻuliʻuli',
    '🖕🏿' => 'tuhu ʻi loto: kili ʻuliʻuli',
    '👇🏻' => 'tuhu tuʻanima tonu ki lalo: kili hinehina',
    '👇🏼' => 'tuhu tuʻanima tonu ki lalo: kili kelokelo',
    '👇🏽' => 'tuhu tuʻanima tonu ki lalo: kili melomelo',
    '👇🏾' => 'tuhu tuʻanima tonu ki lalo: kili melomelo-ʻuliʻuli',
    '👇🏿' => 'tuhu tuʻanima tonu ki lalo: kili ʻuliʻuli',
    '☝🏻' => 'tuhu tonu ki ʻolunga: kili hinehina',
    '☝🏼' => 'tuhu tonu ki ʻolunga: kili kelokelo',
    '☝🏽' => 'tuhu tonu ki ʻolunga: kili melomelo',
    '☝🏾' => 'tuhu tonu ki ʻolunga: kili melomelo-ʻuliʻuli',
    '☝🏿' => 'tuhu tonu ki ʻolunga: kili ʻuliʻuli',
    '🫵🏻' => 'tuhu tonu ki muʻa: kili hinehina',
    '🫵🏼' => 'tuhu tonu ki muʻa: kili kelokelo',
    '🫵🏽' => 'tuhu tonu ki muʻa: kili melomelo',
    '🫵🏾' => 'tuhu tonu ki muʻa: kili melomelo-ʻuliʻuli',
    '🫵🏿' => 'tuhu tonu ki muʻa: kili ʻuliʻuli',
    '👍🏻' => 'motuʻatuhu ki ʻolunga: kili hinehina',
    '👍🏼' => 'motuʻatuhu ki ʻolunga: kili kelokelo',
    '👍🏽' => 'motuʻatuhu ki ʻolunga: kili melomelo',
    '👍🏾' => 'motuʻatuhu ki ʻolunga: kili melomelo-ʻuliʻuli',
    '👍🏿' => 'motuʻatuhu ki ʻolunga: kili ʻuliʻuli',
    '👎🏻' => 'motuʻatuhu ki lalo: kili hinehina',
    '👎🏼' => 'motuʻatuhu ki lalo: kili kelokelo',
    '👎🏽' => 'motuʻatuhu ki lalo: kili melomelo',
    '👎🏾' => 'motuʻatuhu ki lalo: kili melomelo-ʻuliʻuli',
    '👎🏿' => 'motuʻatuhu ki lalo: kili ʻuliʻuli',
    '✊🏻' => 'tuke hiki ki ʻolunga: kili hinehina',
    '✊🏼' => 'tuke hiki ki ʻolunga: kili kelokelo',
    '✊🏽' => 'tuke hiki ki ʻolunga: kili melomelo',
    '✊🏾' => 'tuke hiki ki ʻolunga: kili melomelo-ʻuliʻuli',
    '✊🏿' => 'tuke hiki ki ʻolunga: kili ʻuliʻuli',
    '👊🏻' => 'tuke ki muʻa: kili hinehina',
    '👊🏼' => 'tuke ki muʻa: kili kelokelo',
    '👊🏽' => 'tuke ki muʻa: kili melomelo',
    '👊🏾' => 'tuke ki muʻa: kili melomelo-ʻuliʻuli',
    '👊🏿' => 'tuke ki muʻa: kili ʻuliʻuli',
    '🤛🏻' => 'tuke ki hema: kili hinehina',
    '🤛🏼' => 'tuke ki hema: kili kelokelo',
    '🤛🏽' => 'tuke ki hema: kili melomelo',
    '🤛🏾' => 'tuke ki hema: kili melomelo-ʻuliʻuli',
    '🤛🏿' => 'tuke ki hema: kili ʻuliʻuli',
    '🤜🏻' => 'tuke ki mataʻu: kili hinehina',
    '🤜🏼' => 'tuke ki mataʻu: kili kelokelo',
    '🤜🏽' => 'tuke ki mataʻu: kili melomelo',
    '🤜🏾' => 'tuke ki mataʻu: kili melomelo-ʻuliʻuli',
    '🤜🏿' => 'tuke ki mataʻu: kili ʻuliʻuli',
    '👏🏻' => 'nima pasipasi: kili hinehina',
    '👏🏼' => 'nima pasipasi: kili kelokelo',
    '👏🏽' => 'nima pasipasi: kili melomelo',
    '👏🏾' => 'nima pasipasi: kili melomelo-ʻuliʻuli',
    '👏🏿' => 'nima pasipasi: kili ʻuliʻuli',
    '🙌🏻' => 'ongo nima hiki ki ʻolunga: kili hinehina',
    '🙌🏼' => 'ongo nima hiki ki ʻolunga: kili kelokelo',
    '🙌🏽' => 'ongo nima hiki ki ʻolunga: kili melomelo',
    '🙌🏾' => 'ongo nima hiki ki ʻolunga: kili melomelo-ʻuliʻuli',
    '🙌🏿' => 'ongo nima hiki ki ʻolunga: kili ʻuliʻuli',
    '🫶🏻' => 'ongo nima fakamafu: kili hinehina',
    '🫶🏼' => 'ongo nima fakamafu: kili kelokelo',
    '🫶🏽' => 'ongo nima fakamafu: kili melomelo',
    '🫶🏾' => 'ongo nima fakamafu: kili melomelo-ʻuliʻuli',
    '🫶🏿' => 'ongo nima fakamafu: kili ʻuliʻuli',
    '👐🏻' => 'nima homo: kili hinehina',
    '👐🏼' => 'nima homo: kili kelokelo',
    '👐🏽' => 'nima homo: kili melomelo',
    '👐🏾' => 'nima homo: kili melomelo-ʻuliʻuli',
    '👐🏿' => 'nima homo: kili ʻuliʻuli',
    '🤲🏻' => 'ongo aofinima hiki ki ʻolunga: kili hinehina',
    '🤲🏼' => 'ongo aofinima hiki ki ʻolunga: kili kelokelo',
    '🤲🏽' => 'ongo aofinima hiki ki ʻolunga: kili melomelo',
    '🤲🏾' => 'ongo aofinima hiki ki ʻolunga: kili melomelo-ʻuliʻuli',
    '🤲🏿' => 'ongo aofinima hiki ki ʻolunga: kili ʻuliʻuli',
    '🤝🏻' => 'lulululu: kili hinehina',
    '🤝🏼' => 'lulululu: kili kelokelo',
    '🤝🏽' => 'lulululu: kili melomelo',
    '🤝🏾' => 'lulululu: kili melomelo-ʻuliʻuli',
    '🤝🏿' => 'lulululu: kili ʻuliʻuli',
    '🙏🏻' => 'ongo nima tataʻo: kili hinehina',
    '🙏🏼' => 'ongo nima tataʻo: kili kelokelo',
    '🙏🏽' => 'ongo nima tataʻo: kili melomelo',
    '🙏🏾' => 'ongo nima tataʻo: kili melomelo-ʻuliʻuli',
    '🙏🏿' => 'ongo nima tataʻo: kili ʻuliʻuli',
    '✍🏻' => 'nima ʻoku tohi: kili hinehina',
    '✍🏼' => 'nima ʻoku tohi: kili kelokelo',
    '✍🏽' => 'nima ʻoku tohi: kili melomelo',
    '✍🏾' => 'nima ʻoku tohi: kili melomelo-ʻuliʻuli',
    '✍🏿' => 'nima ʻoku tohi: kili ʻuliʻuli',
    '💅🏻' => 'valivali ngeʻesinima: kili hinehina',
    '💅🏼' => 'valivali ngeʻesinima: kili kelokelo',
    '💅🏽' => 'valivali ngeʻesinima: kili melomelo',
    '💅🏾' => 'valivali ngeʻesinima: kili melomelo-ʻuliʻuli',
    '💅🏿' => 'valivali ngeʻesinima: kili ʻuliʻuli',
    '🤳🏻' => 'faitaaʻi pē kita: kili hinehina',
    '🤳🏼' => 'faitaaʻi pē kita: kili kelokelo',
    '🤳🏽' => 'faitaaʻi pē kita: kili melomelo',
    '🤳🏾' => 'faitaaʻi pē kita: kili melomelo-ʻuliʻuli',
    '🤳🏿' => 'faitaaʻi pē kita: kili ʻuliʻuli',
    '💪🏻' => 'pāpela ʻoku pelu: kili hinehina',
    '💪🏼' => 'pāpela ʻoku pelu: kili kelokelo',
    '💪🏽' => 'pāpela ʻoku pelu: kili melomelo',
    '💪🏾' => 'pāpela ʻoku pelu: kili melomelo-ʻuliʻuli',
    '💪🏿' => 'pāpela ʻoku pelu: kili ʻuliʻuli',
    '🦵🏻' => 'vaʻe: kili hinehina',
    '🦵🏼' => 'vaʻe: kili kelokelo',
    '🦵🏽' => 'vaʻe: kili melomelo',
    '🦵🏾' => 'vaʻe: kili melomelo-ʻuliʻuli',
    '🦵🏿' => 'vaʻe: kili ʻuliʻuli',
    '🦶🏻' => 'lauʻivaʻe: kili hinehina',
    '🦶🏼' => 'lauʻivaʻe: kili kelokelo',
    '🦶🏽' => 'lauʻivaʻe: kili melomelo',
    '🦶🏾' => 'lauʻivaʻe: kili melomelo-ʻuliʻuli',
    '🦶🏿' => 'lauʻivaʻe: kili ʻuliʻuli',
    '👂🏻' => 'telinga: kili hinehina',
    '👂🏼' => 'telinga: kili kelokelo',
    '👂🏽' => 'telinga: kili melomelo',
    '👂🏾' => 'telinga: kili melomelo-ʻuliʻuli',
    '👂🏿' => 'telinga: kili ʻuliʻuli',
    '🦻🏻' => 'telinga moe meʻa fakafanongo: kili hinehina',
    '🦻🏼' => 'telinga moe meʻa fakafanongo: kili kelokelo',
    '🦻🏽' => 'telinga moe meʻa fakafanongo: kili melomelo',
    '🦻🏾' => 'telinga moe meʻa fakafanongo: kili melomelo-ʻuliʻuli',
    '🦻🏿' => 'telinga moe meʻa fakafanongo: kili ʻuliʻuli',
    '👃🏻' => 'ihu: kili hinehina',
    '👃🏼' => 'ihu: kili kelokelo',
    '👃🏽' => 'ihu: kili melomelo',
    '👃🏾' => 'ihu: kili melomelo-ʻuliʻuli',
    '👃🏿' => 'ihu: kili ʻuliʻuli',
    '👶🏻' => 'valevale: kili hinehina',
    '👶🏼' => 'valevale: kili kelokelo',
    '👶🏽' => 'valevale: kili melomelo',
    '👶🏾' => 'valevale: kili melomelo-ʻuliʻuli',
    '👶🏿' => 'valevale: kili ʻuliʻuli',
    '🧒🏻' => 'fānau: kili hinehina',
    '🧒🏼' => 'fānau: kili kelokelo',
    '🧒🏽' => 'fānau: kili melomelo',
    '🧒🏾' => 'fānau: kili melomelo-ʻuliʻuli',
    '🧒🏿' => 'fānau: kili ʻuliʻuli',
    '👦🏻' => 'tamasiʻi: kili hinehina',
    '👦🏼' => 'tamasiʻi: kili kelokelo',
    '👦🏽' => 'tamasiʻi: kili melomelo',
    '👦🏾' => 'tamasiʻi: kili melomelo-ʻuliʻuli',
    '👦🏿' => 'tamasiʻi: kili ʻuliʻuli',
    '👧🏻' => 'taʻahine: kili hinehina',
    '👧🏼' => 'taʻahine: kili kelokelo',
    '👧🏽' => 'taʻahine: kili melomelo',
    '👧🏾' => 'taʻahine: kili melomelo-ʻuliʻuli',
    '👧🏿' => 'taʻahine: kili ʻuliʻuli',
    '🧑🏻' => 'kakai lalahi: kili hinehina',
    '🧑🏼' => 'kakai lalahi: kili kelokelo',
    '🧑🏽' => 'kakai lalahi: kili melomelo',
    '🧑🏾' => 'kakai lalahi: kili melomelo-ʻuliʻuli',
    '🧑🏿' => 'kakai lalahi: kili ʻuliʻuli',
    '👱🏻' => 'tokotaha ʻulu kelo: kili hinehina',
    '👱🏼' => 'tokotaha ʻulu kelo: kili kelokelo',
    '👱🏽' => 'tokotaha ʻulu kelo: kili melomelo',
    '👱🏾' => 'tokotaha ʻulu kelo: kili melomelo-ʻuliʻuli',
    '👱🏿' => 'tokotaha ʻulu kelo: kili ʻuliʻuli',
    '👨🏻' => 'tangata: kili hinehina',
    '👨🏼' => 'tangata: kili kelokelo',
    '👨🏽' => 'tangata: kili melomelo',
    '👨🏾' => 'tangata: kili melomelo-ʻuliʻuli',
    '👨🏿' => 'tangata: kili ʻuliʻuli',
    '🧔🏻' => 'tokotaha kava: kili hinehina',
    '🧔🏼' => 'tokotaha kava: kili kelokelo',
    '🧔🏽' => 'tokotaha kava: kili melomelo',
    '🧔🏾' => 'tokotaha kava: kili melomelo-ʻuliʻuli',
    '🧔🏿' => 'tokotaha kava: kili ʻuliʻuli',
    '👩🏻' => 'fefine: kili hinehina',
    '👩🏼' => 'fefine: kili kelokelo',
    '👩🏽' => 'fefine: kili melomelo',
    '👩🏾' => 'fefine: kili melomelo-ʻuliʻuli',
    '👩🏿' => 'fefine: kili ʻuliʻuli',
    '🧓🏻' => 'tokotaha motuʻa: kili hinehina',
    '🧓🏼' => 'tokotaha motuʻa: kili kelokelo',
    '🧓🏽' => 'tokotaha motuʻa: kili melomelo',
    '🧓🏾' => 'tokotaha motuʻa: kili melomelo-ʻuliʻuli',
    '🧓🏿' => 'tokotaha motuʻa: kili ʻuliʻuli',
    '👴🏻' => 'motuʻa: kili hinehina',
    '👴🏼' => 'motuʻa: kili kelokelo',
    '👴🏽' => 'motuʻa: kili melomelo',
    '👴🏾' => 'motuʻa: kili melomelo-ʻuliʻuli',
    '👴🏿' => 'motuʻa: kili ʻuliʻuli',
    '👵🏻' => 'finemotuʻa: kili hinehina',
    '👵🏼' => 'finemotuʻa: kili kelokelo',
    '👵🏽' => 'finemotuʻa: kili melomelo',
    '👵🏾' => 'finemotuʻa: kili melomelo-ʻuliʻuli',
    '👵🏿' => 'finemotuʻa: kili ʻuliʻuli',
    '🙍🏻' => 'tokotaha matamamahi: kili hinehina',
    '🙍🏼' => 'tokotaha matamamahi: kili kelokelo',
    '🙍🏽' => 'tokotaha matamamahi: kili melomelo',
    '🙍🏾' => 'tokotaha matamamahi: kili melomelo-ʻuliʻuli',
    '🙍🏿' => 'tokotaha matamamahi: kili ʻuliʻuli',
    '🙎🏻' => 'tokotaha mataʻita: kili hinehina',
    '🙎🏼' => 'tokotaha mataʻita: kili kelokelo',
    '🙎🏽' => 'tokotaha mataʻita: kili melomelo',
    '🙎🏾' => 'tokotaha mataʻita: kili melomelo-ʻuliʻuli',
    '🙎🏿' => 'tokotaha mataʻita: kili ʻuliʻuli',
    '🙅🏻' => 'tokotaha kaunima fetuiaki: kili hinehina',
    '🙅🏼' => 'tokotaha kaunima fetuiaki: kili kelokelo',
    '🙅🏽' => 'tokotaha kaunima fetuiaki: kili melomelo',
    '🙅🏾' => 'tokotaha kaunima fetuiaki: kili melomelo-ʻuliʻuli',
    '🙅🏿' => 'tokotaha kaunima fetuiaki: kili ʻuliʻuli',
    '🙆🏻' => 'tokotaha kaunima fetuiaki ʻolunga: kili hinehina',
    '🙆🏼' => 'tokotaha kaunima fetuiaki ʻolunga: kili kelokelo',
    '🙆🏽' => 'tokotaha kaunima fetuiaki ʻolunga: kili melomelo',
    '🙆🏾' => 'tokotaha kaunima fetuiaki ʻolunga: kili melomelo-ʻuliʻuli',
    '🙆🏿' => 'tokotaha kaunima fetuiaki ʻolunga: kili ʻuliʻuli',
    '💁🏻' => 'tokotaha nima mafola: kili hinehina',
    '💁🏼' => 'tokotaha nima mafola: kili kelokelo',
    '💁🏽' => 'tokotaha nima mafola: kili melomelo',
    '💁🏾' => 'tokotaha nima mafola: kili melomelo-ʻuliʻuli',
    '💁🏿' => 'tokotaha nima mafola: kili ʻuliʻuli',
    '🙋🏻' => 'tokotaha nima ʻi ʻolunga: kili hinehina',
    '🙋🏼' => 'tokotaha nima ʻi ʻolunga: kili kelokelo',
    '🙋🏽' => 'tokotaha nima ʻi ʻolunga: kili melomelo',
    '🙋🏾' => 'tokotaha nima ʻi ʻolunga: kili melomelo-ʻuliʻuli',
    '🙋🏿' => 'tokotaha nima ʻi ʻolunga: kili ʻuliʻuli',
    '🧏🏻' => 'tokotaha tuli: kili hinehina',
    '🧏🏼' => 'tokotaha tuli: kili kelokelo',
    '🧏🏽' => 'tokotaha tuli: kili melomelo',
    '🧏🏾' => 'tokotaha tuli: kili melomelo-ʻuliʻuli',
    '🧏🏿' => 'tokotaha tuli: kili ʻuliʻuli',
    '🙇🏻' => 'tokotaha punou: kili hinehina',
    '🙇🏼' => 'tokotaha punou: kili kelokelo',
    '🙇🏽' => 'tokotaha punou: kili melomelo',
    '🙇🏾' => 'tokotaha punou: kili melomelo-ʻuliʻuli',
    '🙇🏿' => 'tokotaha punou: kili ʻuliʻuli',
    '🤦🏻' => 'tokotaha nima ʻihe mata: kili hinehina',
    '🤦🏼' => 'tokotaha nima ʻihe mata: kili kelokelo',
    '🤦🏽' => 'tokotaha nima ʻihe mata: kili melomelo',
    '🤦🏾' => 'tokotaha nima ʻihe mata: kili melomelo-ʻuliʻuli',
    '🤦🏿' => 'tokotaha nima ʻihe mata: kili ʻuliʻuli',
    '🤷🏻' => 'tokotaha fakamahiki: kili hinehina',
    '🤷🏼' => 'tokotaha fakamahiki: kili kelokelo',
    '🤷🏽' => 'tokotaha fakamahiki: kili melomelo',
    '🤷🏾' => 'tokotaha fakamahiki: kili melomelo-ʻuliʻuli',
    '🤷🏿' => 'tokotaha fakamahiki: kili ʻuliʻuli',
    '👮🏻' => 'ʻofisa polisi: kili hinehina',
    '👮🏼' => 'ʻofisa polisi: kili kelokelo',
    '👮🏽' => 'ʻofisa polisi: kili melomelo',
    '👮🏾' => 'ʻofisa polisi: kili melomelo-ʻuliʻuli',
    '👮🏿' => 'ʻofisa polisi: kili ʻuliʻuli',
    '🕵🏻' => 'tokotaha fakatotolo: kili hinehina',
    '🕵🏼' => 'tokotaha fakatotolo: kili kelokelo',
    '🕵🏽' => 'tokotaha fakatotolo: kili melomelo',
    '🕵🏾' => 'tokotaha fakatotolo: kili melomelo-ʻuliʻuli',
    '🕵🏿' => 'tokotaha fakatotolo: kili ʻuliʻuli',
    '💂🏻' => 'leʻo: kili hinehina',
    '💂🏼' => 'leʻo: kili kelokelo',
    '💂🏽' => 'leʻo: kili melomelo',
    '💂🏾' => 'leʻo: kili melomelo-ʻuliʻuli',
    '💂🏿' => 'leʻo: kili ʻuliʻuli',
    '🥷🏻' => 'mata ninisā: kili hinehina',
    '🥷🏼' => 'mata ninisā: kili kelokelo',
    '🥷🏽' => 'mata ninisā: kili melomelo',
    '🥷🏾' => 'mata ninisā: kili melomelo-ʻuliʻuli',
    '🥷🏿' => 'mata ninisā: kili ʻuliʻuli',
    '👷🏻' => 'tokotaha ngāue langa: kili hinehina',
    '👷🏼' => 'tokotaha ngāue langa: kili kelokelo',
    '👷🏽' => 'tokotaha ngāue langa: kili melomelo',
    '👷🏾' => 'tokotaha ngāue langa: kili melomelo-ʻuliʻuli',
    '👷🏿' => 'tokotaha ngāue langa: kili ʻuliʻuli',
    '🫅🏻' => 'tokotaha ʻai kalauni: kili hinehina',
    '🫅🏼' => 'tokotaha ʻai kalauni: kili kelokelo',
    '🫅🏽' => 'tokotaha ʻai kalauni: kili melomelo',
    '🫅🏾' => 'tokotaha ʻai kalauni: kili melomelo-ʻuliʻuli',
    '🫅🏿' => 'tokotaha ʻai kalauni: kili ʻuliʻuli',
    '🤴🏻' => 'ʻalo tangata: kili hinehina',
    '🤴🏼' => 'ʻalo tangata: kili kelokelo',
    '🤴🏽' => 'ʻalo tangata: kili melomelo',
    '🤴🏾' => 'ʻalo tangata: kili melomelo-ʻuliʻuli',
    '🤴🏿' => 'ʻalo tangata: kili ʻuliʻuli',
    '👸🏻' => 'ʻalo fefine: kili hinehina',
    '👸🏼' => 'ʻalo fefine: kili kelokelo',
    '👸🏽' => 'ʻalo fefine: kili melomelo',
    '👸🏾' => 'ʻalo fefine: kili melomelo-ʻuliʻuli',
    '👸🏿' => 'ʻalo fefine: kili ʻuliʻuli',
    '👳🏻' => 'tokotaha tui faʻu: kili hinehina',
    '👳🏼' => 'tokotaha tui faʻu: kili kelokelo',
    '👳🏽' => 'tokotaha tui faʻu: kili melomelo',
    '👳🏾' => 'tokotaha tui faʻu: kili melomelo-ʻuliʻuli',
    '👳🏿' => 'tokotaha tui faʻu: kili ʻuliʻuli',
    '👲🏻' => 'tangata tui tatā fakasiaina: kili hinehina',
    '👲🏼' => 'tangata tui tatā fakasiaina: kili kelokelo',
    '👲🏽' => 'tangata tui tatā fakasiaina: kili melomelo',
    '👲🏾' => 'tangata tui tatā fakasiaina: kili melomelo-ʻuliʻuli',
    '👲🏿' => 'tangata tui tatā fakasiaina: kili ʻuliʻuli',
    '🧕🏻' => 'fefine tui sikaafi: kili hinehina',
    '🧕🏼' => 'fefine tui sikaafi: kili kelokelo',
    '🧕🏽' => 'fefine tui sikaafi: kili melomelo',
    '🧕🏾' => 'fefine tui sikaafi: kili melomelo-ʻuliʻuli',
    '🧕🏿' => 'fefine tui sikaafi: kili ʻuliʻuli',
    '🤵🏻' => 'tokotaha vala kakato: kili hinehina',
    '🤵🏼' => 'tokotaha vala kakato: kili kelokelo',
    '🤵🏽' => 'tokotaha vala kakato: kili melomelo',
    '🤵🏾' => 'tokotaha vala kakato: kili melomelo-ʻuliʻuli',
    '🤵🏿' => 'tokotaha vala kakato: kili ʻuliʻuli',
    '👰🏻' => 'tokotaha tui veili: kili hinehina',
    '👰🏼' => 'tokotaha tui veili: kili kelokelo',
    '👰🏽' => 'tokotaha tui veili: kili melomelo',
    '👰🏾' => 'tokotaha tui veili: kili melomelo-ʻuliʻuli',
    '👰🏿' => 'tokotaha tui veili: kili ʻuliʻuli',
    '🤰🏻' => 'fefine feitama: kili hinehina',
    '🤰🏼' => 'fefine feitama: kili kelokelo',
    '🤰🏽' => 'fefine feitama: kili melomelo',
    '🤰🏾' => 'fefine feitama: kili melomelo-ʻuliʻuli',
    '🤰🏿' => 'fefine feitama: kili ʻuliʻuli',
    '🫃🏻' => 'tangata feitama: kili hinehina',
    '🫃🏼' => 'tangata feitama: kili kelokelo',
    '🫃🏽' => 'tangata feitama: kili melomelo',
    '🫃🏾' => 'tangata feitama: kili melomelo-ʻuliʻuli',
    '🫃🏿' => 'tangata feitama: kili ʻuliʻuli',
    '🫄🏻' => 'tokotaha feitama: kili hinehina',
    '🫄🏼' => 'tokotaha feitama: kili kelokelo',
    '🫄🏽' => 'tokotaha feitama: kili melomelo',
    '🫄🏾' => 'tokotaha feitama: kili melomelo-ʻuliʻuli',
    '🫄🏿' => 'tokotaha feitama: kili ʻuliʻuli',
    '🤱🏻' => 'fakahuhu: kili hinehina',
    '🤱🏼' => 'fakahuhu: kili kelokelo',
    '🤱🏽' => 'fakahuhu: kili melomelo',
    '🤱🏾' => 'fakahuhu: kili melomelo-ʻuliʻuli',
    '🤱🏿' => 'fakahuhu: kili ʻuliʻuli',
    '👼🏻' => 'ʻangelo valevale: kili hinehina',
    '👼🏼' => 'ʻangelo valevale: kili kelokelo',
    '👼🏽' => 'ʻangelo valevale: kili melomelo',
    '👼🏾' => 'ʻangelo valevale: kili melomelo-ʻuliʻuli',
    '👼🏿' => 'ʻangelo valevale: kili ʻuliʻuli',
    '🎅🏻' => 'Sānita Kalausi: kili hinehina',
    '🎅🏼' => 'Sānita Kalausi: kili kelokelo',
    '🎅🏽' => 'Sānita Kalausi: kili melomelo',
    '🎅🏾' => 'Sānita Kalausi: kili melomelo-ʻuliʻuli',
    '🎅🏿' => 'Sānita Kalausi: kili ʻuliʻuli',
    '🤶🏻' => 'Sānita Kalausi fefine: kili hinehina',
    '🤶🏼' => 'Sānita Kalausi fefine: kili kelokelo',
    '🤶🏽' => 'Sānita Kalausi fefine: kili melomelo',
    '🤶🏾' => 'Sānita Kalausi fefine: kili melomelo-ʻuliʻuli',
    '🤶🏿' => 'Sānita Kalausi fefine: kili ʻuliʻuli',
    '🦸🏻' => 'tokotaha ivimālohi: kili hinehina',
    '🦸🏼' => 'tokotaha ivimālohi: kili kelokelo',
    '🦸🏽' => 'tokotaha ivimālohi: kili melomelo',
    '🦸🏾' => 'tokotaha ivimālohi: kili melomelo-ʻuliʻuli',
    '🦸🏿' => 'tokotaha ivimālohi: kili ʻuliʻuli',
    '🦹🏻' => 'tokotaha kākā: kili hinehina',
    '🦹🏼' => 'tokotaha kākā: kili kelokelo',
    '🦹🏽' => 'tokotaha kākā: kili melomelo',
    '🦹🏾' => 'tokotaha kākā: kili melomelo-ʻuliʻuli',
    '🦹🏿' => 'tokotaha kākā: kili ʻuliʻuli',
    '🧙🏻' => 'tokotaha taula-faʻahikehe: kili hinehina',
    '🧙🏼' => 'tokotaha taula-faʻahikehe: kili kelokelo',
    '🧙🏽' => 'tokotaha taula-faʻahikehe: kili melomelo',
    '🧙🏾' => 'tokotaha taula-faʻahikehe: kili melomelo-ʻuliʻuli',
    '🧙🏿' => 'tokotaha taula-faʻahikehe: kili ʻuliʻuli',
    '🧚🏻' => 'feeli: kili hinehina',
    '🧚🏼' => 'feeli: kili kelokelo',
    '🧚🏽' => 'feeli: kili melomelo',
    '🧚🏾' => 'feeli: kili melomelo-ʻuliʻuli',
    '🧚🏿' => 'feeli: kili ʻuliʻuli',
    '🧛🏻' => 'tokotaha misi toto: kili hinehina',
    '🧛🏼' => 'tokotaha misi toto: kili kelokelo',
    '🧛🏽' => 'tokotaha misi toto: kili melomelo',
    '🧛🏾' => 'tokotaha misi toto: kili melomelo-ʻuliʻuli',
    '🧛🏿' => 'tokotaha misi toto: kili ʻuliʻuli',
    '🧜🏻' => 'tokotaha meimeite: kili hinehina',
    '🧜🏼' => 'tokotaha meimeite: kili kelokelo',
    '🧜🏽' => 'tokotaha meimeite: kili melomelo',
    '🧜🏾' => 'tokotaha meimeite: kili melomelo-ʻuliʻuli',
    '🧜🏿' => 'tokotaha meimeite: kili ʻuliʻuli',
    '🧝🏻' => 'kiʻi feeli: kili hinehina',
    '🧝🏼' => 'kiʻi feeli: kili kelokelo',
    '🧝🏽' => 'kiʻi feeli: kili melomelo',
    '🧝🏾' => 'kiʻi feeli: kili melomelo-ʻuliʻuli',
    '🧝🏿' => 'kiʻi feeli: kili ʻuliʻuli',
    '💆🏻' => 'tokotaha fotofotaʻi: kili hinehina',
    '💆🏼' => 'tokotaha fotofotaʻi: kili kelokelo',
    '💆🏽' => 'tokotaha fotofotaʻi: kili melomelo',
    '💆🏾' => 'tokotaha fotofotaʻi: kili melomelo-ʻuliʻuli',
    '💆🏿' => 'tokotaha fotofotaʻi: kili ʻuliʻuli',
    '💇🏻' => 'tokotaha ʻulu kosi: kili hinehina',
    '💇🏼' => 'tokotaha ʻulu kosi: kili kelokelo',
    '💇🏽' => 'tokotaha ʻulu kosi: kili melomelo',
    '💇🏾' => 'tokotaha ʻulu kosi: kili melomelo-ʻuliʻuli',
    '💇🏿' => 'tokotaha ʻulu kosi: kili ʻuliʻuli',
    '🚶🏻' => 'tokotaha lue: kili hinehina',
    '🚶🏼' => 'tokotaha lue: kili kelokelo',
    '🚶🏽' => 'tokotaha lue: kili melomelo',
    '🚶🏾' => 'tokotaha lue: kili melomelo-ʻuliʻuli',
    '🚶🏿' => 'tokotaha lue: kili ʻuliʻuli',
    '🧍🏻' => 'tokotaha tuʻu: kili hinehina',
    '🧍🏼' => 'tokotaha tuʻu: kili kelokelo',
    '🧍🏽' => 'tokotaha tuʻu: kili melomelo',
    '🧍🏾' => 'tokotaha tuʻu: kili melomelo-ʻuliʻuli',
    '🧍🏿' => 'tokotaha tuʻu: kili ʻuliʻuli',
    '🧎🏻' => 'tokotaha tūʻulutui: kili hinehina',
    '🧎🏼' => 'tokotaha tūʻulutui: kili kelokelo',
    '🧎🏽' => 'tokotaha tūʻulutui: kili melomelo',
    '🧎🏾' => 'tokotaha tūʻulutui: kili melomelo-ʻuliʻuli',
    '🧎🏿' => 'tokotaha tūʻulutui: kili ʻuliʻuli',
    '🏃🏻' => 'tokotaha lele: kili hinehina',
    '🏃🏼' => 'tokotaha lele: kili kelokelo',
    '🏃🏽' => 'tokotaha lele: kili melomelo',
    '🏃🏾' => 'tokotaha lele: kili melomelo-ʻuliʻuli',
    '🏃🏿' => 'tokotaha lele: kili ʻuliʻuli',
    '💃🏻' => 'fefine meʻe: kili hinehina',
    '💃🏼' => 'fefine meʻe: kili kelokelo',
    '💃🏽' => 'fefine meʻe: kili melomelo',
    '💃🏾' => 'fefine meʻe: kili melomelo-ʻuliʻuli',
    '💃🏿' => 'fefine meʻe: kili ʻuliʻuli',
    '🕺🏻' => 'tangata meʻe: kili hinehina',
    '🕺🏼' => 'tangata meʻe: kili kelokelo',
    '🕺🏽' => 'tangata meʻe: kili melomelo',
    '🕺🏾' => 'tangata meʻe: kili melomelo-ʻuliʻuli',
    '🕺🏿' => 'tangata meʻe: kili ʻuliʻuli',
    '🕴🏻' => 'tangata ʻi vala tangata kakato ʻoku maʻanu: kili hinehina',
    '🕴🏼' => 'tangata ʻi vala tangata kakato ʻoku maʻanu: kili kelokelo',
    '🕴🏽' => 'tangata ʻi vala tangata kakato ʻoku maʻanu: kili melomelo',
    '🕴🏾' => 'tangata ʻi vala tangata kakato ʻoku maʻanu: kili melomelo-ʻuliʻuli',
    '🕴🏿' => 'tangata ʻi vala tangata kakato ʻoku maʻanu: kili ʻuliʻuli',
    '👯🏻' => 'tokoua telinga-lāpisi: kili hinehina',
    '👯🏼' => 'tokoua telinga-lāpisi: kili kelokelo',
    '👯🏽' => 'tokoua telinga-lāpisi: kili melomelo',
    '👯🏾' => 'tokoua telinga-lāpisi: kili melomelo-ʻuliʻuli',
    '👯🏿' => 'tokoua telinga-lāpisi: kili ʻuliʻuli',
    '🧖🏻' => 'tokotaha ʻi loki mao: kili hinehina',
    '🧖🏼' => 'tokotaha ʻi loki mao: kili kelokelo',
    '🧖🏽' => 'tokotaha ʻi loki mao: kili melomelo',
    '🧖🏾' => 'tokotaha ʻi loki mao: kili melomelo-ʻuliʻuli',
    '🧖🏿' => 'tokotaha ʻi loki mao: kili ʻuliʻuli',
    '🧗🏻' => 'tokotaha kaka: kili hinehina',
    '🧗🏼' => 'tokotaha kaka: kili kelokelo',
    '🧗🏽' => 'tokotaha kaka: kili melomelo',
    '🧗🏾' => 'tokotaha kaka: kili melomelo-ʻuliʻuli',
    '🧗🏿' => 'tokotaha kaka: kili ʻuliʻuli',
    '🏇🏻' => 'lova hoosi: kili hinehina',
    '🏇🏼' => 'lova hoosi: kili kelokelo',
    '🏇🏽' => 'lova hoosi: kili melomelo',
    '🏇🏾' => 'lova hoosi: kili melomelo-ʻuliʻuli',
    '🏇🏿' => 'lova hoosi: kili ʻuliʻuli',
    '🏂🏻' => 'tokotaha heke laupapa sinou: kili hinehina',
    '🏂🏼' => 'tokotaha heke laupapa sinou: kili kelokelo',
    '🏂🏽' => 'tokotaha heke laupapa sinou: kili melomelo',
    '🏂🏾' => 'tokotaha heke laupapa sinou: kili melomelo-ʻuliʻuli',
    '🏂🏿' => 'tokotaha heke laupapa sinou: kili ʻuliʻuli',
    '🏌🏻' => 'tokotaha tāpulu: kili hinehina',
    '🏌🏼' => 'tokotaha tāpulu: kili kelokelo',
    '🏌🏽' => 'tokotaha tāpulu: kili melomelo',
    '🏌🏾' => 'tokotaha tāpulu: kili melomelo-ʻuliʻuli',
    '🏌🏿' => 'tokotaha tāpulu: kili ʻuliʻuli',
    '🏄🏻' => 'tokotaha fānifo: kili hinehina',
    '🏄🏼' => 'tokotaha fānifo: kili kelokelo',
    '🏄🏽' => 'tokotaha fānifo: kili melomelo',
    '🏄🏾' => 'tokotaha fānifo: kili melomelo-ʻuliʻuli',
    '🏄🏿' => 'tokotaha fānifo: kili ʻuliʻuli',
    '🚣🏻' => 'tokotaha ʻaʻalo: kili hinehina',
    '🚣🏼' => 'tokotaha ʻaʻalo: kili kelokelo',
    '🚣🏽' => 'tokotaha ʻaʻalo: kili melomelo',
    '🚣🏾' => 'tokotaha ʻaʻalo: kili melomelo-ʻuliʻuli',
    '🚣🏿' => 'tokotaha ʻaʻalo: kili ʻuliʻuli',
    '🏊🏻' => 'tokotaha kakau: kili hinehina',
    '🏊🏼' => 'tokotaha kakau: kili kelokelo',
    '🏊🏽' => 'tokotaha kakau: kili melomelo',
    '🏊🏾' => 'tokotaha kakau: kili melomelo-ʻuliʻuli',
    '🏊🏿' => 'tokotaha kakau: kili ʻuliʻuli',
    '⛹🏻' => 'tokotaha tōpuna pulu: kili hinehina',
    '⛹🏼' => 'tokotaha tōpuna pulu: kili kelokelo',
    '⛹🏽' => 'tokotaha tōpuna pulu: kili melomelo',
    '⛹🏾' => 'tokotaha tōpuna pulu: kili melomelo-ʻuliʻuli',
    '⛹🏿' => 'tokotaha tōpuna pulu: kili ʻuliʻuli',
    '🏋🏻' => 'tokotaha hiki meʻamamafa: kili hinehina',
    '🏋🏼' => 'tokotaha hiki meʻamamafa: kili kelokelo',
    '🏋🏽' => 'tokotaha hiki meʻamamafa: kili melomelo',
    '🏋🏾' => 'tokotaha hiki meʻamamafa: kili melomelo-ʻuliʻuli',
    '🏋🏿' => 'tokotaha hiki meʻamamafa: kili ʻuliʻuli',
    '🚴🏻' => 'tokotaha heka pasikala: kili hinehina',
    '🚴🏼' => 'tokotaha heka pasikala: kili kelokelo',
    '🚴🏽' => 'tokotaha heka pasikala: kili melomelo',
    '🚴🏾' => 'tokotaha heka pasikala: kili melomelo-ʻuliʻuli',
    '🚴🏿' => 'tokotaha heka pasikala: kili ʻuliʻuli',
    '🚵🏻' => 'tokotaha heka pasikala moʻunga: kili hinehina',
    '🚵🏼' => 'tokotaha heka pasikala moʻunga: kili kelokelo',
    '🚵🏽' => 'tokotaha heka pasikala moʻunga: kili melomelo',
    '🚵🏾' => 'tokotaha heka pasikala moʻunga: kili melomelo-ʻuliʻuli',
    '🚵🏿' => 'tokotaha heka pasikala moʻunga: kili ʻuliʻuli',
    '🤸🏻' => 'tokotaha tākisi: kili hinehina',
    '🤸🏼' => 'tokotaha tākisi: kili kelokelo',
    '🤸🏽' => 'tokotaha tākisi: kili melomelo',
    '🤸🏾' => 'tokotaha tākisi: kili melomelo-ʻuliʻuli',
    '🤸🏿' => 'tokotaha tākisi: kili ʻuliʻuli',
    '🤼🏻' => 'kakai fangatua: kili hinehina',
    '🤼🏼' => 'kakai fangatua: kili kelokelo',
    '🤼🏽' => 'kakai fangatua: kili melomelo',
    '🤼🏾' => 'kakai fangatua: kili melomelo-ʻuliʻuli',
    '🤼🏿' => 'kakai fangatua: kili ʻuliʻuli',
    '🤽🏻' => 'tokotaha polovai: kili hinehina',
    '🤽🏼' => 'tokotaha polovai: kili kelokelo',
    '🤽🏽' => 'tokotaha polovai: kili melomelo',
    '🤽🏾' => 'tokotaha polovai: kili melomelo-ʻuliʻuli',
    '🤽🏿' => 'tokotaha polovai: kili ʻuliʻuli',
    '🤾🏻' => 'tokotaha netipolo: kili hinehina',
    '🤾🏼' => 'tokotaha netipolo: kili kelokelo',
    '🤾🏽' => 'tokotaha netipolo: kili melomelo',
    '🤾🏾' => 'tokotaha netipolo: kili melomelo-ʻuliʻuli',
    '🤾🏿' => 'tokotaha netipolo: kili ʻuliʻuli',
    '🤹🏻' => 'tokotaha hiko: kili hinehina',
    '🤹🏼' => 'tokotaha hiko: kili kelokelo',
    '🤹🏽' => 'tokotaha hiko: kili melomelo',
    '🤹🏾' => 'tokotaha hiko: kili melomelo-ʻuliʻuli',
    '🤹🏿' => 'tokotaha hiko: kili ʻuliʻuli',
    '🧘🏻' => 'tokotaha tangutu fehauaki: kili hinehina',
    '🧘🏼' => 'tokotaha tangutu fehauaki: kili kelokelo',
    '🧘🏽' => 'tokotaha tangutu fehauaki: kili melomelo',
    '🧘🏾' => 'tokotaha tangutu fehauaki: kili melomelo-ʻuliʻuli',
    '🧘🏿' => 'tokotaha tangutu fehauaki: kili ʻuliʻuli',
    '🛀🏻' => 'tokotaha kaukau: kili hinehina',
    '🛀🏼' => 'tokotaha kaukau: kili kelokelo',
    '🛀🏽' => 'tokotaha kaukau: kili melomelo',
    '🛀🏾' => 'tokotaha kaukau: kili melomelo-ʻuliʻuli',
    '🛀🏿' => 'tokotaha kaukau: kili ʻuliʻuli',
    '🛌🏻' => 'tokotaha ʻi mohenga: kili hinehina',
    '🛌🏼' => 'tokotaha ʻi mohenga: kili kelokelo',
    '🛌🏽' => 'tokotaha ʻi mohenga: kili melomelo',
    '🛌🏾' => 'tokotaha ʻi mohenga: kili melomelo-ʻuliʻuli',
    '🛌🏿' => 'tokotaha ʻi mohenga: kili ʻuliʻuli',
    '👭🏻' => 'fafine fetakinima: kili hinehina',
    '👭🏼' => 'fafine fetakinima: kili kelokelo',
    '👭🏽' => 'fafine fetakinima: kili melomelo',
    '👭🏾' => 'fafine fetakinima: kili melomelo-ʻuliʻuli',
    '👭🏿' => 'fafine fetakinima: kili ʻuliʻuli',
    '👫🏻' => 'tangata mo fefine fetakinima: kili hinehina',
    '👫🏼' => 'tangata mo fefine fetakinima: kili kelokelo',
    '👫🏽' => 'tangata mo fefine fetakinima: kili melomelo',
    '👫🏾' => 'tangata mo fefine fetakinima: kili melomelo-ʻuliʻuli',
    '👫🏿' => 'tangata mo fefine fetakinima: kili ʻuliʻuli',
    '👬🏻' => 'ongo tangata fetakinima: kili hinehina',
    '👬🏼' => 'ongo tangata fetakinima: kili kelokelo',
    '👬🏽' => 'ongo tangata fetakinima: kili melomelo',
    '👬🏾' => 'ongo tangata fetakinima: kili melomelo-ʻuliʻuli',
    '👬🏿' => 'ongo tangata fetakinima: kili ʻuliʻuli',
    '💏🏻' => 'ʻuma: kili hinehina',
    '💏🏼' => 'ʻuma: kili kelokelo',
    '💏🏽' => 'ʻuma: kili melomelo',
    '💏🏾' => 'ʻuma: kili melomelo-ʻuliʻuli',
    '💏🏿' => 'ʻuma: kili ʻuliʻuli',
    '💑🏻' => 'ongo tokoua moe mafu: kili hinehina',
    '💑🏼' => 'ongo tokoua moe mafu: kili kelokelo',
    '💑🏽' => 'ongo tokoua moe mafu: kili melomelo',
    '💑🏾' => 'ongo tokoua moe mafu: kili melomelo-ʻuliʻuli',
    '💑🏿' => 'ongo tokoua moe mafu: kili ʻuliʻuli',
    '🇦🇨' => 'fuka: Motu ʻAsenisini',
    '🇦🇩' => 'fuka: ʻAnitola',
    '🇦🇪' => 'fuka: ʻAlepea Fakatahataha',
    '🇦🇫' => 'fuka: ʻAfikānisitani',
    '🇦🇬' => 'fuka: Anitikua mo Palaputa',
    '🇦🇮' => 'fuka: Anikuila',
    '🇦🇱' => 'fuka: ʻAlipania',
    '🇦🇲' => 'fuka: ʻĀmenia',
    '🇦🇴' => 'fuka: ʻAngikola',
    '🇦🇶' => 'fuka: ʻAnitātika',
    '🇦🇷' => 'fuka: ʻAsenitina',
    '🇦🇸' => 'fuka: Haʻamoa ʻAmelika',
    '🇦🇹' => 'fuka: ʻAositulia',
    '🇦🇺' => 'fuka: ʻAositelēlia',
    '🇦🇼' => 'fuka: ʻAlupa',
    '🇦🇽' => 'fuka: ʻOtumotu ʻAlani',
    '🇦🇿' => 'fuka: ʻAsapaisani',
    '🇧🇦' => 'fuka: Posinia mo Hesikōvina',
    '🇧🇧' => 'fuka: Pāpeitosi',
    '🇧🇩' => 'fuka: Pengilātesi',
    '🇧🇪' => 'fuka: Pelesiume',
    '🇧🇫' => 'fuka: Pekano Faso',
    '🇧🇬' => 'fuka: Pulukalia',
    '🇧🇭' => 'fuka: Paleini',
    '🇧🇮' => 'fuka: Puluniti',
    '🇧🇯' => 'fuka: Penini',
    '🇧🇱' => 'fuka: Sā Patēlemi',
    '🇧🇲' => 'fuka: Pēmuta',
    '🇧🇳' => 'fuka: Pulunei',
    '🇧🇴' => 'fuka: Polīvia',
    '🇧🇶' => 'fuka: Kalipiane fakahōlani',
    '🇧🇷' => 'fuka: Palāsili',
    '🇧🇸' => 'fuka: Pahama',
    '🇧🇹' => 'fuka: Pūtani',
    '🇧🇻' => 'fuka: Motu Puveti',
    '🇧🇼' => 'fuka: Potisiuana',
    '🇧🇾' => 'fuka: Pelalusi',
    '🇧🇿' => 'fuka: Pelise',
    '🇨🇦' => 'fuka: Kānata',
    '🇨🇨' => 'fuka: ʻOtumotu Koko',
    '🇨🇩' => 'fuka: Kongo - Kinisasa',
    '🇨🇫' => 'fuka: Lepupelika ʻAfilika Lotoloto',
    '🇨🇬' => 'fuka: Kongo - Palasavila',
    '🇨🇭' => 'fuka: Suisilani',
    '🇨🇮' => 'fuka: Matafonua ʻAivolī',
    '🇨🇰' => 'fuka: ʻOtumotu Kuki',
    '🇨🇱' => 'fuka: Sili',
    '🇨🇲' => 'fuka: Kameluni',
    '🇨🇳' => 'fuka: Siaina',
    '🇨🇴' => 'fuka: Kolomipia',
    '🇨🇵' => 'fuka: Motu Kilipatoni',
    '🇨🇶' => 'fuka: Saaki',
    '🇨🇷' => 'fuka: Kosita Lika',
    '🇨🇺' => 'fuka: Kiupa',
    '🇨🇻' => 'fuka: Muiʻi Vēte',
    '🇨🇼' => 'fuka: Kulasao',
    '🇨🇽' => 'fuka: Motu Kilisimasi',
    '🇨🇾' => 'fuka: Saipalesi',
    '🇨🇿' => 'fuka: Sēkia',
    '🇩🇪' => 'fuka: Siamane',
    '🇩🇬' => 'fuka: Tieko Kāsia',
    '🇩🇯' => 'fuka: Siputi',
    '🇩🇰' => 'fuka: Tenimaʻake',
    '🇩🇲' => 'fuka: Tominika',
    '🇩🇴' => 'fuka: Lepupelika Tominika',
    '🇩🇿' => 'fuka: ʻAlisilia',
    '🇪🇦' => 'fuka: Siuta mo Melila',
    '🇪🇨' => 'fuka: ʻEkuetoa',
    '🇪🇪' => 'fuka: ʻEsitōnia',
    '🇪🇬' => 'fuka: ʻIsipite',
    '🇪🇭' => 'fuka: Sahala fakahihifo',
    '🇪🇷' => 'fuka: ʻElitulia',
    '🇪🇸' => 'fuka: Sipeini',
    '🇪🇹' => 'fuka: ʻĪtiōpia',
    '🇪🇺' => 'fuka: ʻEulope fakatahataha',
    '🇫🇮' => 'fuka: Finilani',
    '🇫🇯' => 'fuka: Fisi',
    '🇫🇰' => 'fuka: ʻOtumotu Fokulani',
    '🇫🇲' => 'fuka: Mikolonīsia',
    '🇫🇴' => 'fuka: ʻOtumotu Faloe',
    '🇫🇷' => 'fuka: Falanisē',
    '🇬🇦' => 'fuka: Kaponi',
    '🇬🇧' => 'fuka: Pilitānia',
    '🇬🇩' => 'fuka: Kelenatā',
    '🇬🇪' => 'fuka: Seōsia',
    '🇬🇫' => 'fuka: Kuiana fakafalanisē',
    '🇬🇬' => 'fuka: Kuenisī',
    '🇬🇭' => 'fuka: Kana',
    '🇬🇮' => 'fuka: Sipalālitā',
    '🇬🇱' => 'fuka: Kulinilani',
    '🇬🇲' => 'fuka: Kamipia',
    '🇬🇳' => 'fuka: Kini',
    '🇬🇵' => 'fuka: Kuatalupe',
    '🇬🇶' => 'fuka: ʻEkueta Kini',
    '🇬🇷' => 'fuka: Kalisi',
    '🇬🇸' => 'fuka: ʻOtumotu Seōsia-tonga mo Saniuisi-tonga',
    '🇬🇹' => 'fuka: Kuatamala',
    '🇬🇺' => 'fuka: Kuamu',
    '🇬🇼' => 'fuka: Kini-Pisau',
    '🇬🇾' => 'fuka: Kuiana',
    '🇭🇰' => 'fuka: Hongi Kongi SAR Siaina',
    '🇭🇲' => 'fuka: ʻOtumotu Heati mo Makitonali',
    '🇭🇳' => 'fuka: Honitulasi',
    '🇭🇷' => 'fuka: Kuloisia',
    '🇭🇹' => 'fuka: Haiti',
    '🇭🇺' => 'fuka: Hungakalia',
    '🇮🇨' => 'fuka: ʻOtumotu Kaneli',
    '🇮🇩' => 'fuka: ʻInitonēsia',
    '🇮🇪' => 'fuka: ʻAealani',
    '🇮🇱' => 'fuka: ʻIsileli',
    '🇮🇲' => 'fuka: Motu Mani',
    '🇮🇳' => 'fuka: ʻInitia',
    '🇮🇴' => 'fuka: Potu fonua moana ʻInitia fakapilitānia',
    '🇮🇶' => 'fuka: ʻIlaaki',
    '🇮🇷' => 'fuka: ʻIlaani',
    '🇮🇸' => 'fuka: ʻAisilani',
    '🇮🇹' => 'fuka: ʻĪtali',
    '🇯🇪' => 'fuka: Selusī',
    '🇯🇲' => 'fuka: Samaika',
    '🇯🇴' => 'fuka: Soatane',
    '🇯🇵' => 'fuka: Siapani',
    '🇰🇪' => 'fuka: Keniā',
    '🇰🇬' => 'fuka: Kīkisitani',
    '🇰🇭' => 'fuka: Kamipōtia',
    '🇰🇮' => 'fuka: Kilipasi',
    '🇰🇲' => 'fuka: Komolosi',
    '🇰🇳' => 'fuka: Sā Kitisi mo Nevisi',
    '🇰🇵' => 'fuka: Kōlea tokelau',
    '🇰🇷' => 'fuka: Kōlea tonga',
    '🇰🇼' => 'fuka: Kueiti',
    '🇰🇾' => 'fuka: ʻOtumotu Keimeni',
    '🇰🇿' => 'fuka: Kasakitani',
    '🇱🇦' => 'fuka: Lau',
    '🇱🇧' => 'fuka: Lepanoni',
    '🇱🇨' => 'fuka: Sā Lūsia',
    '🇱🇮' => 'fuka: Likitenisiteini',
    '🇱🇰' => 'fuka: Sīlangikā',
    '🇱🇷' => 'fuka: Laipelia',
    '🇱🇸' => 'fuka: Lesoto',
    '🇱🇹' => 'fuka: Lituania',
    '🇱🇺' => 'fuka: Lakisimipeki',
    '🇱🇻' => 'fuka: Lativia',
    '🇱🇾' => 'fuka: Līpia',
    '🇲🇦' => 'fuka: Moloko',
    '🇲🇨' => 'fuka: Monako',
    '🇲🇩' => 'fuka: Molotova',
    '🇲🇪' => 'fuka: Monitenikalo',
    '🇲🇫' => 'fuka: Sā Mātini (fakafalanisē)',
    '🇲🇬' => 'fuka: Matakasika',
    '🇲🇭' => 'fuka: ʻOtumotu Māsolo',
    '🇲🇰' => 'fuka: Masetōnia fakatokelau',
    '🇲🇱' => 'fuka: Māli',
    '🇲🇲' => 'fuka: Mianimā (Pema)',
    '🇲🇳' => 'fuka: Mongokōlia',
    '🇲🇴' => 'fuka: Makau SAR Siaina',
    '🇲🇵' => 'fuka: ʻOtumotu Maliana tokelau',
    '🇲🇶' => 'fuka: Mātiniki',
    '🇲🇷' => 'fuka: Maulitenia',
    '🇲🇸' => 'fuka: Moʻungaselati',
    '🇲🇹' => 'fuka: Malita',
    '🇲🇺' => 'fuka: Maulitiusi',
    '🇲🇻' => 'fuka: Malativisi',
    '🇲🇼' => 'fuka: Malaui',
    '🇲🇽' => 'fuka: Mekisikou',
    '🇲🇾' => 'fuka: Malēsia',
    '🇲🇿' => 'fuka: Mosēmipiki',
    '🇳🇦' => 'fuka: Namipia',
    '🇳🇨' => 'fuka: Niu Kaletōnia',
    '🇳🇪' => 'fuka: Nisia',
    '🇳🇫' => 'fuka: Motu Nōfoliki',
    '🇳🇬' => 'fuka: Naisilia',
    '🇳🇮' => 'fuka: Nikalakua',
    '🇳🇱' => 'fuka: Hōlani',
    '🇳🇴' => 'fuka: Noauē',
    '🇳🇵' => 'fuka: Nepali',
    '🇳🇷' => 'fuka: Naulu',
    '🇳🇺' => 'fuka: Niuē',
    '🇳🇿' => 'fuka: Nuʻusila',
    '🇴🇲' => 'fuka: ʻOmani',
    '🇵🇦' => 'fuka: Panamā',
    '🇵🇪' => 'fuka: Pelū',
    '🇵🇫' => 'fuka: Polinisia fakafalanisē',
    '🇵🇬' => 'fuka: Papuaniukini',
    '🇵🇭' => 'fuka: Filipaini',
    '🇵🇰' => 'fuka: Pākisitani',
    '🇵🇱' => 'fuka: Polani',
    '🇵🇲' => 'fuka: Sā Piea mo Mikeloni',
    '🇵🇳' => 'fuka: ʻOtumotu Pitikeni',
    '🇵🇷' => 'fuka: Puēto Liko',
    '🇵🇸' => 'fuka: Potu Palesitaine',
    '🇵🇹' => 'fuka: Potukali',
    '🇵🇼' => 'fuka: Palau',
    '🇵🇾' => 'fuka: Palakuai',
    '🇶🇦' => 'fuka: Katā',
    '🇷🇪' => 'fuka: Lēunioni',
    '🇷🇴' => 'fuka: Lomēnia',
    '🇷🇸' => 'fuka: Sēpia',
    '🇷🇺' => 'fuka: Lūsia',
    '🇷🇼' => 'fuka: Luanitā',
    '🇸🇦' => 'fuka: Saute ʻAlepea',
    '🇸🇧' => 'fuka: ʻOtumotu Solomone',
    '🇸🇨' => 'fuka: ʻOtumotu Seiseli',
    '🇸🇩' => 'fuka: Sūteni',
    '🇸🇪' => 'fuka: Suēteni',
    '🇸🇬' => 'fuka: Singapoa',
    '🇸🇭' => 'fuka: Sā Helena',
    '🇸🇮' => 'fuka: Silōvenia',
    '🇸🇯' => 'fuka: Sivolopāti mo Sani Maieni',
    '🇸🇰' => 'fuka: Silōvakia',
    '🇸🇱' => 'fuka: Siela Leone',
    '🇸🇲' => 'fuka: Sā Malino',
    '🇸🇳' => 'fuka: Senekalo',
    '🇸🇴' => 'fuka: Sōmalia',
    '🇸🇷' => 'fuka: Suliname',
    '🇸🇸' => 'fuka: Sūtani fakatonga',
    '🇸🇹' => 'fuka: Sao Tomē mo Pilinisipe',
    '🇸🇻' => 'fuka: ʻEle Salavatoa',
    '🇸🇽' => 'fuka: Sā Mātini (fakahōlani)',
    '🇸🇾' => 'fuka: Sīlia',
    '🇸🇿' => 'fuka: ʻEsuatini',
    '🇹🇦' => 'fuka: Tulisitani ta Kunuha',
    '🇹🇨' => 'fuka: ʻOtumotu Tuki mo Kaikosi',
    '🇹🇩' => 'fuka: Sāti',
    '🇹🇫' => 'fuka: Potu fonua tonga fakafalanisē',
    '🇹🇬' => 'fuka: Toko',
    '🇹🇭' => 'fuka: Tailani',
    '🇹🇯' => 'fuka: Tasikitani',
    '🇹🇰' => 'fuka: Tokelau',
    '🇹🇱' => 'fuka: Timoa fakahahake',
    '🇹🇲' => 'fuka: Tūkimenisitani',
    '🇹🇳' => 'fuka: Tunīsia',
    '🇹🇴' => 'fuka: Tonga',
    '🇹🇷' => 'fuka: Toake',
    '🇹🇹' => 'fuka: Tilinitati mo Topako',
    '🇹🇻' => 'fuka: Tūvalu',
    '🇹🇼' => 'fuka: Taiuani',
    '🇹🇿' => 'fuka: Tenisānia',
    '🇺🇦' => 'fuka: ʻŪkalaʻine',
    '🇺🇬' => 'fuka: ʻIukanitā',
    '🇺🇲' => 'fuka: ʻOtumotu siʻi ʻo ʻAmelika',
    '🇺🇳' => 'fuka: ʻŪ fonua fakatahataha',
    '🇺🇸' => 'fuka: Puleʻanga fakatahataha ʻAmelika',
    '🇺🇾' => 'fuka: ʻUlukuai',
    '🇺🇿' => 'fuka: ʻUsipekitani',
    '🇻🇦' => 'fuka: Kolo Vatikani',
    '🇻🇨' => 'fuka: Sā Viniseni mo Kulenatini',
    '🇻🇪' => 'fuka: Venesuela',
    '🇻🇬' => 'fuka: ʻOtumotu Vilikini fakapilitānia',
    '🇻🇮' => 'fuka: ʻOtumotu Vilikini fakaʻamelika',
    '🇻🇳' => 'fuka: Vietinami',
    '🇻🇺' => 'fuka: Vanuatu',
    '🇼🇫' => 'fuka: ʻUvea mo Futuna',
    '🇼🇸' => 'fuka: Haʻamoa',
    '🇽🇰' => 'fuka: Kōsovo',
    '🇾🇪' => 'fuka: Iemeni',
    '🇾🇹' => 'fuka: Maiote',
    '🇿🇦' => 'fuka: ʻAfilika tonga',
    '🇿🇲' => 'fuka: Semipia',
    '🇿🇼' => 'fuka: Simipapuei',
    '🔟' => 'tatā foʻi kī: 10',
    '🏻' => 'kili hinehina',
    '🏼' => 'kili kelokelo',
    '🏽' => 'kili melomelo',
    '🏾' => 'kili melomelo-ʻuliʻuli',
    '🏿' => 'kili ʻuliʻuli',
    '😀' => 'mata fiefia',
    '😃' => 'mata fiefia moe kanoʻimata lalahi',
    '😄' => 'mata fiefia moe kanoʻimata malimali',
    '😁' => 'mata ina moe kanoʻimata malimali',
    '😆' => 'mata fiefia moe tetepa',
    '😅' => 'mata fiefia moe tautaʻa',
    '🤣' => 'mata kata moe teka faliki',
    '😂' => 'mata moe loʻimata fiefia',
    '🙂' => 'mata kiʻi malimali',
    '🙃' => 'mata fulihi',
    '🫠' => 'mata vaia',
    '😉' => 'mata fakakuitaha',
    '😊' => 'mata malimali moe kanoʻimata malimali',
    '😇' => 'mata malimali moe takaniko',
    '🥰' => 'mata malimali moe mafu ʻe 3',
    '😍' => 'mata malimali moe kanoʻimata mafu',
    '🤩' => 'mata fetuʻu',
    '😘' => 'mata ʻoku puhi ʻae ʻuma',
    '😗' => 'mata ʻuma',
    '☺' => 'mata malimali',
    '😚' => 'mata ʻuma moe kanoʻimata kuikui',
    '😙' => 'mata ʻuma moe kanoʻimata malimali',
    '🥲' => 'mata malimali moe loʻimata',
    '😋' => 'mataʻi ʻuakai',
    '😛' => 'mata moe ʻelelo',
    '😜' => 'mata kuitaha moe ʻelelo',
    '🤪' => 'mata masoli',
    '😝' => 'mata tetepa moe ʻelelo',
    '🤑' => 'mata ngutu-paʻanga',
    '🤗' => 'mata fāʻufua moe nima-homo',
    '🤭' => 'mata moe nima ʻi muʻa ʻoe ngutu',
    '🫢' => 'mata matalahi moe nima ʻi muʻa ʻoe ngutu',
    '🫣' => 'mata moe foʻimata tauasi',
    '🤫' => 'mata fiemaʻu fakalongolongo',
    '🤔' => 'mataʻi fakakaukau',
    '🫡' => 'mata fetapa',
    '🤐' => 'mata moe ngutu meʻa-fakamaʻu-fusi',
    '🤨' => 'mata moe kemo mahiki',
    '😐' => 'mata noa pē',
    '😑' => 'mata matanoa',
    '😶' => 'mata taʻengutu',
    '🫥' => 'mata fakalaine toti',
    '😏' => 'mata katakata manuki',
    '😒' => 'mata taʻefiefia',
    '🙄' => 'mata kilokilo',
    '😬' => 'mata mioʻi',
    '🤥' => 'mata moe ihu lōloa',
    '🫨' => 'mata tete',
    '😌' => 'mata fakanongononga',
    '😔' => 'mata fakalaulauloto',
    '😪' => 'mata fiemohea',
    '🤤' => 'mata ngutu hafu fāvai',
    '😴' => 'mata mohe',
    '🫩' => 'mata kōkō',
    '😷' => 'mata moe pūloa fakafaitoʻo',
    '🤒' => 'mata moe meʻafuamafana',
    '🤕' => 'mata moe haʻi lavea',
    '🤢' => 'mata kavahia',
    '🤮' => 'mata lua',
    '🤧' => 'mata mafatua',
    '🥵' => 'mata vevela',
    '🥶' => 'mata momoko',
    '🥴' => 'mata konā',
    '😵' => 'mata ninimo',
    '🤯' => 'mata pahū',
    '🤠' => 'mata moe tatā fakakaupoe',
    '🥳' => 'mata paati',
    '🥸' => 'mata fakapuli',
    '😎' => 'mata malimali moe matasioʻatalaʻā',
    '🤓' => 'mata moe matasioʻata lahi',
    '🧐' => 'mata moe matasioʻata tafaʻaki taha',
    '😕' => 'mata puputuʻu',
    '🫤' => 'mata ngutu fakahihifi',
    '😟' => 'mata lotohohaʻa',
    '🙁' => 'mata kiʻi fingo',
    '☹' => 'mata fingo',
    '😮' => 'mata moe ngutu fakamanga',
    '😯' => 'mata longo',
    '😲' => 'mata ʻohovale',
    '😳' => 'mata pahapaha',
    '🥺' => 'mata kole',
    '🥹' => 'mata loʻimata maʻu',
    '😦' => 'mata fingo moe ngutu fakamanga',
    '😧' => 'mata lotomamahi',
    '😨' => 'mata fakamanavahē',
    '😰' => 'mata lotomoʻua moe tautaʻa',
    '😥' => 'mata lotomamahi kā fakanongononga',
    '😢' => 'mata loʻimata',
    '😭' => 'mata loʻimata lahi',
    '😱' => 'mata ʻoku kekekeke he manavahē',
    '😖' => 'mata fakapuputuʻu',
    '😣' => 'mata lotokītaki',
    '😞' => 'mata fakalotomamahi',
    '😓' => 'mata lototaʻotaʻomia moe tautaʻa',
    '😩' => 'mata ongosia',
    '😫' => 'mata helaʻia',
    '🥱' => 'mata mamao',
    '😤' => 'mata moe mao meihe ihu',
    '😡' => 'mata ʻita lahi',
    '😠' => 'mata ʻita',
    '🤬' => 'mata kapekape',
    '😈' => 'mata malimali moe meʻatui',
    '👿' => 'mata ʻita moe meʻatui',
    '💀' => 'ʻulupoko',
    '☠' => 'ʻulupoko moe ongo hui fehauaki',
    '💩' => 'tuʻunga meʻakovi',
    '🤡' => 'mata tokotaha-fieoli',
    '👹' => 'nifoloa',
    '👺' => 'pīnōnō',
    '👻' => 'fakapūloa',
    '👽' => 'meʻamoʻuikehe',
    '👾' => 'meʻamoʻuikehe fakamanavahē',
    '🤖' => 'mata tangata-ukamea',
    '😺' => 'mataʻipusi fiefia',
    '😸' => 'mataʻipusi fiefia moe kanoʻimata malimali',
    '😹' => 'mataʻipusi moe loʻimata fiefia',
    '😻' => 'mataʻipusi malimali moe kanoʻimata mafu',
    '😼' => 'mataʻipusi moe malimali feʻu',
    '😽' => 'mataʻipusi ʻuma',
    '🙀' => 'mataʻipusi ongosia',
    '😿' => 'mataʻipusi loʻimata',
    '😾' => 'mataʻipusi taʻefiemālie',
    '🙈' => 'ngeli ʻikai sio kovi',
    '🙉' => 'ngeli ʻikai fanongo kovi',
    '🙊' => 'ngeli ʻikai lea kovi',
    '💌' => 'tohi ʻofa',
    '💘' => 'mafu moe ngahau',
    '💝' => 'mafu moe lipine',
    '💖' => 'mafu ngingila',
    '💗' => 'mafu tupu',
    '💓' => 'mafu ʻoku tā',
    '💞' => 'ongo mafu takai',
    '💕' => 'ongo mafu',
    '💟' => 'mafu teuteuʻi',
    '❣' => 'mafu fakaʻilonga kalanga',
    '💔' => 'loto lavea',
    '❤' => 'mafu kulokula',
    '🩷' => 'mafu lanupingikī',
    '🧡' => 'mafu lanumoli',
    '💛' => 'mafu engeenga',
    '💚' => 'mafu lanumata',
    '💙' => 'mafu lanupulū',
    '🩵' => 'mafu lanupulū maama',
    '💜' => 'mafu lanufesiʻifekika',
    '🤎' => 'mafu melomelo',
    '🖤' => 'mafu ʻuliʻuli',
    '🩶' => 'mafu lanulavilavi',
    '🤍' => 'mafu hinehina',
    '💋' => 'ʻilonga loungutu',
    '💯' => 'poini ʻe teau',
    '💢' => 'fakaʻilonga ʻita',
    '🫯' => 'ʻao uatau',
    '💥' => 'fepaki',
    '💫' => 'ninimo',
    '💦' => 'tautaʻa tulutā',
    '💨' => 'ʻoho atu',
    '🕳' => 'ava',
    '💬' => 'pulalea',
    '🗨' => 'pulalea ʻi hema',
    '🗯' => 'pulalea ʻita',
    '💭' => 'pulalea fakakaukau',
    '💤' => 'mohe',
    '👋' => 'nima taʻataʻalo',
    '🤚' => 'tuʻanima hiki ki ʻolunga',
    '🖐' => 'nima fālalahi',
    '✋' => 'nima hiki ki ʻolunga',
    '🖖' => 'nima mavaeua',
    '🫱' => 'nima ki mataʻu',
    '🫲' => 'ninma ki hema',
    '🫳' => 'nima ʻohifo',
    '🫴' => 'nima ʻohake',
    '🫷' => 'nima teke ki hema',
    '🫸' => 'nima teke ki mataʻu',
    '👌' => 'nima fakaʻilonga sai',
    '🤌' => 'louhiʻinima fakamaʻopoʻopo',
    '🤏' => 'nima fakamaʻopoʻopo',
    '✌' => 'nima ikuna',
    '🤞' => 'louhiʻinima fehauaki',
    '🫰' => 'louhiʻinima moe motuʻatuhu fehauaki',
    '🤟' => 'nima fakaʻilonga mafu',
    '🤘' => 'nima fakaʻilonga fakatēvolo',
    '🤙' => 'nima fakaʻilonga tā mai',
    '👈' => 'tuhu tuʻanima tonu ki hema',
    '👉' => 'tuhu tuʻanima tonu ki mataʻu',
    '👆' => 'tuhu tuʻanima tonu ki ʻolunga',
    '🖕' => 'tuhu ʻi loto',
    '👇' => 'tuhu tuʻanima tonu ki lalo',
    '☝' => 'tuhu tonu ki ʻolunga',
    '🫵' => 'tuhu tonu ki muʻa',
    '👍' => 'motuʻatuhu ki ʻolunga',
    '👎' => 'motuʻatuhu ki lalo',
    '✊' => 'tuke hiki ki ʻolunga',
    '👊' => 'tuke ki muʻa',
    '🤛' => 'tuke ki hema',
    '🤜' => 'tuke ki mataʻu',
    '👏' => 'nima pasipasi',
    '🙌' => 'ongo nima hiki ki ʻolunga',
    '🫶' => 'ongo nima fakamafu',
    '👐' => 'nima homo',
    '🤲' => 'ongo aofinima hiki ki ʻolunga',
    '🤝' => 'lulululu',
    '🙏' => 'ongo nima tataʻo',
    '✍' => 'nima ʻoku tohi',
    '💅' => 'valivali ngeʻesinima',
    '🤳' => 'faitaaʻi pē kita',
    '💪' => 'pāpela ʻoku pelu',
    '🦾' => 'nima ukamea',
    '🦿' => 'vaʻe ukamea',
    '🦵' => 'vaʻe',
    '🦶' => 'lauʻivaʻe',
    '👂' => 'telinga',
    '🦻' => 'telinga moe meʻa fakafanongo',
    '👃' => 'ihu',
    '🧠' => 'ʻuto',
    '🫀' => 'mafu',
    '🫁' => 'maʻamaʻa',
    '🦷' => 'nifo',
    '🦴' => 'hui',
    '👀' => 'ongo kanoʻimata',
    '👁' => 'kanoʻimata',
    '👅' => 'ʻelelo',
    '👄' => 'ngutu',
    '🫦' => 'uʻu loungutu',
    '👶' => 'valevale',
    '🧒' => 'fānau',
    '👦' => 'tamasiʻi',
    '👧' => 'taʻahine',
    '🧑' => 'kakai lalahi',
    '👱' => 'tokotaha ʻulu kelo',
    '👨' => 'tangata',
    '🧔' => 'tokotaha kava',
    '👩' => 'fefine',
    '🧓' => 'tokotaha motuʻa',
    '👴' => 'motuʻa',
    '👵' => 'finemotuʻa',
    '🙍' => 'tokotaha matamamahi',
    '🙎' => 'tokotaha mataʻita',
    '🙅' => 'tokotaha kaunima fetuiaki',
    '🙆' => 'tokotaha kaunima fetuiaki ʻolunga',
    '💁' => 'tokotaha nima mafola',
    '🙋' => 'tokotaha nima ʻi ʻolunga',
    '🧏' => 'tokotaha tuli',
    '🙇' => 'tokotaha punou',
    '🤦' => 'tokotaha nima ʻihe mata',
    '🤷' => 'tokotaha fakamahiki',
    '👮' => 'ʻofisa polisi',
    '🕵' => 'tokotaha fakatotolo',
    '💂' => 'leʻo',
    '🥷' => 'mata ninisā',
    '👷' => 'tokotaha ngāue langa',
    '🫅' => 'tokotaha ʻai kalauni',
    '🤴' => 'ʻalo tangata',
    '👸' => 'ʻalo fefine',
    '👳' => 'tokotaha tui faʻu',
    '👲' => 'tangata tui tatā fakasiaina',
    '🧕' => 'fefine tui sikaafi',
    '🤵' => 'tokotaha vala kakato',
    '👰' => 'tokotaha tui veili',
    '🤰' => 'fefine feitama',
    '🫃' => 'tangata feitama',
    '🫄' => 'tokotaha feitama',
    '🤱' => 'fakahuhu',
    '👼' => 'ʻangelo valevale',
    '🎅' => 'Sānita Kalausi',
    '🤶' => 'Sānita Kalausi fefine',
    '🦸' => 'tokotaha ivimālohi',
    '🦹' => 'tokotaha kākā',
    '🧙' => 'tokotaha taula-faʻahikehe',
    '🧚' => 'feeli',
    '🧛' => 'tokotaha misi toto',
    '🧜' => 'tokotaha meimeite',
    '🧝' => 'kiʻi feeli',
    '🧞' => 'faʻahikehe',
    '🧟' => 'tēvolo',
    '🧌' => 'fakatele',
    '🫈' => 'tokotaha fulufula',
    '💆' => 'tokotaha fotofotaʻi',
    '💇' => 'tokotaha ʻulu kosi',
    '🚶' => 'tokotaha lue',
    '🧍' => 'tokotaha tuʻu',
    '🧎' => 'tokotaha tūʻulutui',
    '🏃' => 'tokotaha lele',
    '💃' => 'fefine meʻe',
    '🕺' => 'tangata meʻe',
    '🕴' => 'tangata ʻi vala tangata kakato ʻoku maʻanu',
    '👯' => 'tokoua telinga-lāpisi',
    '🧖' => 'tokotaha ʻi loki mao',
    '🧗' => 'tokotaha kaka',
    '🤺' => 'tokotaha tau heletā',
    '🏇' => 'lova hoosi',
    '⛷' => 'tokotaha heke sinou',
    '🏂' => 'tokotaha heke laupapa sinou',
    '🏌' => 'tokotaha tāpulu',
    '🏄' => 'tokotaha fānifo',
    '🚣' => 'tokotaha ʻaʻalo',
    '🏊' => 'tokotaha kakau',
    '⛹' => 'tokotaha tōpuna pulu',
    '🏋' => 'tokotaha hiki meʻamamafa',
    '🚴' => 'tokotaha heka pasikala',
    '🚵' => 'tokotaha heka pasikala moʻunga',
    '🤸' => 'tokotaha tākisi',
    '🤼' => 'kakai fangatua',
    '🤽' => 'tokotaha polovai',
    '🤾' => 'tokotaha netipolo',
    '🤹' => 'tokotaha hiko',
    '🧘' => 'tokotaha tangutu fehauaki',
    '🛀' => 'tokotaha kaukau',
    '🛌' => 'tokotaha ʻi mohenga',
    '👭' => 'fafine fetakinima',
    '👫' => 'tangata mo fefine fetakinima',
    '👬' => 'ongo tangata fetakinima',
    '💏' => 'ʻuma',
    '💑' => 'ongo tokoua moe mafu',
    '🗣' => 'mata talanoa',
    '👤' => 'ʻata ʻoe sino',
    '👥' => 'ongo ʻata ʻoe sino',
    '🫂' => 'kakai fāʻufua',
    '👪' => 'fāmili',
    '👣' => 'topuvaʻe',
    '🫆' => 'fakaʻilonganima',
    '🦰' => 'ʻulu kulokula',
    '🦱' => 'ʻulu mingimingi',
    '🦳' => 'ʻulu hinā',
    '🦲' => 'ʻulu tula',
    '🐵' => 'mataʻi-ngeli',
    '🐒' => 'ngeli',
    '🦍' => 'kolila',
    '🦧' => 'ngeli-nofoʻuta',
    '🐶' => 'mataʻi-kulī',
    '🐕' => 'kulī',
    '🦮' => 'kulī tokonikui',
    '🐩' => 'kulī pūteli',
    '🐺' => 'mataʻi-ulofi',
    '🦊' => 'mataʻi-fokisi',
    '🦝' => 'lakūni',
    '🐱' => 'mataʻi-pusi',
    '🐈' => 'pusi',
    '🦁' => 'mataʻi-laione',
    '🐯' => 'mataʻi-taika',
    '🐅' => 'taika',
    '🐆' => 'lēpati',
    '🐴' => 'mataʻi-hoosi',
    '🫎' => 'tialahi',
    '🫏' => 'ʻasi',
    '🐎' => 'hoosi',
    '🦄' => 'mataʻi-meʻatuitaha',
    '🦓' => 'sepelā',
    '🦌' => 'tia',
    '🦬' => 'pisoni',
    '🐮' => 'mataʻi-pulu',
    '🐂' => 'pulu pokaʻi',
    '🐃' => 'pafalō',
    '🐄' => 'pulu',
    '🐷' => 'mataʻi-puaka',
    '🐖' => 'puaka',
    '🐗' => 'puaka fekai',
    '🐽' => 'ihuʻi-puaka',
    '🐏' => 'sipi tau',
    '🐑' => 'sipi fefine',
    '🐐' => 'kosi',
    '🐪' => 'kāmeli tuʻahulataha',
    '🐫' => 'kāmeli tuʻahulaua',
    '🦙' => 'lama',
    '🦒' => 'silafi',
    '🐘' => 'ʻelefānite',
    '🦣' => 'mamota',
    '🦏' => 'lainosolosi',
    '🦛' => 'hipopotama',
    '🐭' => 'mataʻi-kumāsiʻi',
    '🐁' => 'kumāsiʻi',
    '🐀' => 'kumā',
    '🐹' => 'kumā-feti',
    '🐰' => 'mataʻi-lāpisi',
    '🐇' => 'lāpisi',
    '🐿' => 'sikueli',
    '🦫' => 'kumā fai-tāpuni-vai',
    '🦔' => 'puakatalatala',
    '🦇' => 'peka',
    '🐻' => 'mataʻi-pea',
    '🐨' => 'koala',
    '🐼' => 'mataʻi-pea-ʻuliʻuli-moe-hinehina',
    '🦥' => 'pea-fakapikopiko',
    '🦦' => 'ʻotē',
    '🦨' => 'manu fainamukū',
    '🦘' => 'kangikalū',
    '🦡' => 'patisē',
    '🐾' => 'topuvaʻe manu',
    '🦃' => 'pīpī',
    '🐔' => 'moa',
    '🐓' => 'moataʻane',
    '🐣' => 'fōfoaʻimoa',
    '🐤' => 'ʻuhikiʻimoa',
    '🐥' => 'ʻuhikiʻimoa hanga mai',
    '🐦' => 'manupuna',
    '🐧' => 'penikuini',
    '🕊' => 'lupe',
    '🦅' => 'ʻikale',
    '🦆' => 'pato',
    '🦢' => 'patolahi',
    '🦉' => 'lulu',
    '🦤' => 'toto',
    '🪶' => 'fulufulu',
    '🦩' => 'falamingo',
    '🦚' => 'pīkoka',
    '🦜' => 'kakā',
    '🪽' => 'kapakau',
    '🪿' => 'kuusi',
    '🐸' => 'mataʻi-poto',
    '🐊' => 'kalokataile',
    '🐢' => 'fonu',
    '🦎' => 'moko',
    '🐍' => 'ngata',
    '🐲' => 'mataʻi-talākoni',
    '🐉' => 'talākoni',
    '🦕' => 'saulopoti',
    '🦖' => 'tainosauli nifo māsila',
    '🐳' => 'tofuaʻa puhi',
    '🐋' => 'tofuaʻa',
    '🐬' => 'pungopunga',
    '🫍' => 'tofuaʻa tāmateʻi',
    '🦭' => 'kulītahi',
    '🐟' => 'ika',
    '🐠' => 'ika he hakau',
    '🐡' => 'sokisoki',
    '🦈' => 'ʻanga',
    '🐙' => 'feke',
    '🐚' => 'keleʻa',
    '🪸' => 'feo',
    '🪼' => 'kolokalu',
    '🦀' => 'paka',
    '🦞' => 'ʻuo',
    '🦐' => 'ʻuosiʻisiʻi',
    '🦑' => 'ngūfeke',
    '🦪' => 'tofe',
    '🐌' => 'ʻelili',
    '🦋' => 'pepe',
    '🐛' => 'kutu',
    '🐜' => 'lō',
    '🐝' => 'hone',
    '🪲' => 'mongomonga iiki',
    '🐞' => 'mongomonga-fineʻeiki',
    '🦗' => 'kālihi',
    '🪳' => 'mongomonga',
    '🕷' => 'hina',
    '🕸' => 'matamatakupenga',
    '🦂' => 'sikipio',
    '🦟' => 'namu',
    '🪰' => 'lango',
    '🪱' => 'kelemutu',
    '🦠' => 'siemu',
    '💐' => 'haʻinga matalaʻiʻakau',
    '🌸' => 'matalaʻi-seli',
    '💮' => 'matalaʻiʻakau hinehina',
    '🪷' => 'hainitevai',
    '🏵' => 'potupotutatau',
    '🌹' => 'lose',
    '🥀' => 'mae',
    '🌺' => 'kaute',
    '🌻' => 'siolaʻā',
    '🌼' => 'matalaʻiʻakau',
    '🌷' => 'tiulipe',
    '🪻' => 'hainite',
    '🌱' => 'pulopula',
    '🪴' => 'ʻakau ʻihe kulo',
    '🌲' => 'ʻakau lanumata maʻu pē',
    '🌳' => 'ʻakau fakatōlau',
    '🌴' => 'fuʻu niu',
    '🌵' => 'kakatisi',
    '🌾' => 'haʻinga laise',
    '🌿' => 'ʻakau faitoʻo',
    '☘' => 'sameloki',
    '🍀' => 'kihikihipālangi lau ʻe fā',
    '🍁' => 'lauʻi-mapele',
    '🍂' => 'lau kuo tō',
    '🍃' => 'lau ngaungaue matangi',
    '🪹' => 'ngeʻesi pununga',
    '🪺' => 'pununga moe foʻimanu',
    '🍄' => 'fakamalu-ʻa-tēvolo',
    '🪾' => 'ʻakau taʻelau',
    '🍇' => 'kālepi',
    '🍈' => 'meleni-pālangi',
    '🍉' => 'meleni',
    '🍊' => 'moli',
    '🍋' => 'lemani',
    '🍌' => 'siaine',
    '🍍' => 'fainā',
    '🥭' => 'mango',
    '🍎' => 'ʻāpele kula',
    '🍏' => 'ʻāpele mata',
    '🍐' => 'pea',
    '🍑' => 'piisi',
    '🍒' => 'seli',
    '🍓' => 'sitolōpeli',
    '🫐' => 'pelilanupulū',
    '🥝' => 'kiui',
    '🍅' => 'temata',
    '🫒' => 'ʻolive kai',
    '🥥' => 'foʻi niu',
    '🥑' => 'ʻāvoka',
    '🍆' => 'paingani',
    '🥔' => 'pateta',
    '🥕' => 'kāloti',
    '🌽' => 'foʻi koane',
    '🌶' => 'polo fifisi',
    '🫑' => 'polo',
    '🥒' => 'kiukamipa',
    '🥬' => 'lētisi',
    '🥦' => 'kāpisi',
    '🧄' => 'kaliki',
    '🧅' => 'ʻonioni',
    '🥜' => 'pīnati',
    '🫘' => 'piini',
    '🌰' => 'ifi',
    '🫚' => 'sinisā',
    '🫛' => 'ngeʻesi piini',
    '🫜' => 'meʻakai foha',
    '🍞' => 'mā',
    '🥐' => 'mā kalipa',
    '🥖' => 'mā lōloa',
    '🫓' => 'mā lafalafa',
    '🥨' => 'pani mamio',
    '🥯' => 'pani mama',
    '🥞' => 'pani',
    '🧇' => 'pani manifi',
    '🧀' => 'siisi',
    '🍖' => 'kanomate moe hui',
    '🍗' => 'vaʻeʻi-moa',
    '🥩' => 'kanomate fahi',
    '🥓' => 'pēkani',
    '🍔' => 'hamipaka',
    '🍟' => 'pateta fakapaku',
    '🍕' => 'pisa',
    '🌭' => 'sōsisi kulī vela',
    '🥪' => 'sanuisi',
    '🌮' => 'mā pelupelu',
    '🌯' => 'polito',
    '🫔' => 'mā pulupulu',
    '🥙' => 'mā falati',
    '🧆' => 'falafeli',
    '🥚' => 'fuaʻimoa',
    '🍳' => 'fakapaku',
    '🥘' => 'fakapaku meʻakai',
    '🍲' => 'kulo meʻakai',
    '🫕' => 'siisi māfana',
    '🥣' => 'poulu moe sepuni',
    '🥗' => 'salati',
    '🍿' => 'koane fakapaku',
    '🧈' => 'pata',
    '🧂' => 'masima',
    '🥫' => 'meʻakai kapa',
    '🍱' => 'puha meʻakai fakasiapani',
    '🍘' => 'pisikete laise',
    '🍙' => 'puluʻi laise',
    '🍚' => 'laise moho',
    '🍛' => 'laise kale',
    '🍜' => 'kulo mao',
    '🍝' => 'sipeketi',
    '🍠' => 'kumala tunu',
    '🍢' => 'ʻoteni',
    '🍣' => 'susi',
    '🍤' => 'ʻuosiʻisiʻi fakapaku',
    '🍥' => 'keke ika',
    '🥮' => 'keke māhina',
    '🍡' => 'faikakai fakasiapani',
    '🥟' => 'tōpai',
    '🥠' => 'pisikete talamonū',
    '🥡' => 'kato meʻakai',
    '🍦' => 'ʻaisikilimi molū',
    '🍧' => 'ʻaisitele',
    '🍨' => 'ʻaisikilimi',
    '🍩' => 'keke fakapaku',
    '🍪' => 'pisikete',
    '🎂' => 'keke ʻaho fāʻeleʻi',
    '🍰' => 'keke',
    '🧁' => 'ipukeke',
    '🥧' => 'pai',
    '🍫' => 'lole sokaleti',
    '🍬' => 'lole',
    '🍭' => 'lolepopi',
    '🍮' => 'kasitati',
    '🍯' => 'kulo hone',
    '🍼' => 'hinahuhu',
    '🥛' => 'ipu huʻakau',
    '☕' => 'inu māfana',
    '🫖' => 'tīpota',
    '🍵' => 'ipu tī',
    '🍶' => 'uaine-laise',
    '🍾' => 'hina moe ʻumosi',
    '🍷' => 'ipu sioʻata uaine',
    '🍸' => 'ipu sioʻata paati',
    '🍹' => 'ʻotai',
    '🍺' => 'moki pia',
    '🍻' => 'moki fakapaaki',
    '🥂' => 'ipu sioʻata fakapaaki',
    '🥃' => 'ipu sioʻata',
    '🫗' => 'lilingi vai',
    '🥤' => 'ipu moe vaʻakauinu',
    '🧋' => 'tī maʻupu',
    '🧃' => 'puha inu',
    '🧉' => 'kofi fakaʻamelika-tonga',
    '🧊' => 'puloka ʻaisi',
    '🥢' => 'vaʻakau kai',
    '🍽' => 'huhukai moe helekai moe peleti',
    '🍴' => 'huhukai moe helekai',
    '🥄' => 'sēpuni',
    '🔪' => 'hele paipa',
    '🫙' => 'siā',
    '🏺' => 'tukuʻanga uaine',
    '🌍' => 'kolope ʻasi mai ʻEulope-ʻAfilika',
    '🌎' => 'kolope ʻasi mai ongo ʻAmelika',
    '🌏' => 'kolope ʻasi mai ʻĒsia-ʻAositelēlia',
    '🌐' => 'kolope moe ngaahi melitiane',
    '🗺' => 'mape ʻo māmani',
    '🗾' => 'mape ʻoe Siapani',
    '🧭' => 'kāpasa',
    '🏔' => 'moʻunga ʻufiʻufiʻaki he sinou',
    '⛰' => 'moʻunga',
    '🛘' => 'fonua kuo holo',
    '🌋' => 'moʻungaafi',
    '🗻' => 'moʻunga ko Fusi',
    '🏕' => 'fakateniti',
    '🏖' => 'matātahi moe fakamalu',
    '🏜' => 'toafa',
    '🏝' => 'motu liʻekina',
    '🏞' => 'paʻake fakafonua',
    '🏟' => 'fale sipoti',
    '🏛' => 'fale fakakalisi/loma',
    '🏗' => 'langa fale',
    '🧱' => 'piliki',
    '🪨' => 'maka',
    '🪵' => 'ʻakau',
    '🛖' => 'fale ʻuta',
    '🏘' => 'ngaahi fale',
    '🏚' => 'lusaʻanga',
    '🏠' => 'fale',
    '🏡' => 'fale moe ngoue',
    '🏢' => 'fale ʻōfisi',
    '🏣' => 'ʻōfisi lītohi fakasiapani',
    '🏤' => 'ʻōfisi lītohi',
    '🏥' => 'falemahaki',
    '🏦' => 'pangikē',
    '🏨' => 'fale tali-fononga',
    '🏩' => 'fale paʻumutu',
    '🏪' => 'falekoloa',
    '🏫' => 'faleako',
    '🏬' => 'falekoloa lahi',
    '🏭' => 'fale ngāueʻanga',
    '🏯' => 'pālasi fakasiapani',
    '🏰' => 'pālasi',
    '💒' => 'mali',
    '🗼' => 'taua Tokiō',
    '🗽' => 'maka fakamanatu tauʻatāina',
    '⛪' => 'falelotu',
    '🕌' => 'falelotu fakaʻisilami',
    '🛕' => 'falelotu fakahinitū',
    '🕍' => 'falelotu fakasiu',
    '⛩' => 'falelotu fakasiapani',
    '🕋' => 'fale māʻoniʻoni fakaʻisilami',
    '⛲' => 'fauniteni',
    '⛺' => 'teniti',
    '🌁' => 'fuʻukakapu',
    '🌃' => 'pō fetuʻuʻia',
    '🏙' => 'fale lalahi lotokolo',
    '🌄' => 'hopo ʻae laʻā he funga moʻunga',
    '🌅' => 'hopo ʻae laʻā',
    '🌆' => 'fale lalahi lotokolo mamalu efiafi',
    '🌇' => 'tō ʻae laʻā',
    '🌉' => 'hala kavakava poʻuli',
    '♨' => 'vaipuna mao',
    '🎠' => 'hoosi vaʻinga',
    '🛝' => 'malaʻe vaʻinga',
    '🎡' => 'veʻeteka vaʻinga',
    '🎢' => 'lola vaʻinga',
    '💈' => 'pou kosiʻulu',
    '🎪' => 'teniti sākisi',
    '🚂' => 'mīsini lēlue',
    '🚃' => 'sāliote lēlue',
    '🚄' => 'lēlue oma',
    '🚅' => 'lēlue oma fakasiapani',
    '🚆' => 'lēlue',
    '🚇' => 'lēlue lalofonua',
    '🚈' => 'kiʻi lēlue',
    '🚉' => 'tauʻanga lēlue',
    '🚊' => 'talamu',
    '🚝' => 'lēlue poutaha',
    '🚞' => 'hala lēlue moʻunga',
    '🚋' => 'sāliote talamu',
    '🚌' => 'pasi',
    '🚍' => 'pasi lele mai',
    '🚎' => 'pasi ʻuhila',
    '🚐' => 'pasi iiki',
    '🚑' => 'meʻalele falemahaki',
    '🚒' => 'meʻalele tāmateafi',
    '🚓' => 'meʻalele polisi',
    '🚔' => 'meʻalele polisi lele mai',
    '🚕' => 'meʻalele utakakai',
    '🚖' => 'meʻalele utakakai lele mai',
    '🚗' => 'meʻalele',
    '🚘' => 'meʻalele lele mai',
    '🚙' => 'meʻalele sipoti',
    '🛻' => 'lolo tapolokepi',
    '🚚' => 'loli tiliva',
    '🚛' => 'loli uta lalahi',
    '🚜' => 'mīsini taulani',
    '🏎' => 'meʻalele lova',
    '🏍' => 'motopaiki',
    '🛵' => 'paiki sikuta',
    '🦽' => 'sāliote falemahaki',
    '🦼' => 'sāliote falemahaki mīsini',
    '🛺' => 'loli siʻisiʻi',
    '🚲' => 'pasikala',
    '🛴' => 'sikuta kauleka',
    '🛹' => 'papasikeiti',
    '🛼' => 'sū sikeiti',
    '🚏' => 'tauʻanga pasi',
    '🛣' => 'hala lahi',
    '🛤' => 'hala lēlue',
    '🛢' => 'talamulolo',
    '⛽' => 'pausa',
    '🛞' => 'veʻelapa',
    '🚨' => 'maama meʻalele polisi',
    '🚥' => 'maama hala fakalava',
    '🚦' => 'maama hala tuʻutonu',
    '🛑' => 'fakaʻilonga tuʻu',
    '🚧' => 'fakaʻilonga ngāue langa',
    '⚓' => 'taula',
    '🛟' => 'poe',
    '⛵' => 'vakalā',
    '🛶' => 'pōpao',
    '🚤' => 'vaka oma',
    '🛳' => 'vaka meili',
    '⛴' => 'vaka uta pāsese',
    '🛥' => 'vaka mīsini',
    '🚢' => 'vakalahi',
    '✈' => 'vakapuna',
    '🛩' => 'vakapuna iiki',
    '🛫' => 'vakapuna puna hake',
    '🛬' => 'vakapuna puna hifo',
    '🪂' => 'fakamalu fakatō',
    '💺' => 'sea vakapuna',
    '🚁' => 'helikopeta',
    '🚟' => 'lēlue tāupe lahi',
    '🚠' => 'lēlue tāupe moʻunga',
    '🚡' => 'lēlue tāupe iiki',
    '🛰' => 'satelaite',
    '🚀' => 'loketi',
    '🛸' => 'peleti puna',
    '🛎' => 'fafangu hotele',
    '🧳' => 'katoleta',
    '⌛' => 'sioʻata fuataimi ʻosi',
    '⏳' => 'sioʻata fuataimi teʻeki ʻosi',
    '⌚' => 'uasi',
    '⏰' => 'uasi fafangu',
    '⏱' => 'uasi sipoti',
    '⏲' => 'uasi talataimi',
    '🕰' => 'uasi tuʻulotofale',
    '🕛' => 'hoko ʻae tahaua',
    '🕧' => 'haafe taha',
    '🕐' => 'hoko ʻae taha',
    '🕜' => 'haafe ua',
    '🕑' => 'hoko ʻae ua',
    '🕝' => 'haafe tolu',
    '🕒' => 'hoko ʻae tolu',
    '🕞' => 'haafe fā',
    '🕓' => 'hoko ʻae fā',
    '🕟' => 'haafe nima',
    '🕔' => 'hoko ʻae nima',
    '🕠' => 'haafe ono',
    '🕕' => 'hoko ʻae ono',
    '🕡' => 'haafe fitu',
    '🕖' => 'hoko ʻae fitu',
    '🕢' => 'haafe valu',
    '🕗' => 'hoko ʻae valu',
    '🕣' => 'haafe hiva',
    '🕘' => 'hoko ʻae hiva',
    '🕤' => 'haafe hongofulu',
    '🕙' => 'hoko ʻae hongofulu',
    '🕥' => 'haafe tahataha',
    '🕚' => 'hoko ʻae tahataha',
    '🕦' => 'haafe tahaua',
    '🌑' => 'mate ʻae māhina',
    '🌒' => 'māhina ʻilo ʻehe maama',
    '🌓' => 'māhina tuʻu efiafi',
    '🌔' => 'māhina matofi',
    '🌕' => 'māhina kātoa',
    '🌖' => 'māhina lekeleka',
    '🌗' => 'māhina tuʻu hengihengi',
    '🌘' => 'māhina silipō',
    '🌙' => 'māhina kalipa',
    '🌚' => 'mata mate ʻae māhina',
    '🌛' => 'mata māhina tuʻu efiafi',
    '🌜' => 'mata māhina tuʻu hengihengi',
    '🌡' => 'fuamāfana',
    '☀' => 'laʻā',
    '🌝' => 'mata māhina kātoa',
    '🌞' => 'mata e laʻā',
    '🪐' => 'palanite mama',
    '⭐' => 'fetuʻu',
    '🌟' => 'fetuʻu ngingila',
    '🌠' => 'fetuʻu ʻesiafi',
    '🌌' => 'kaniva',
    '☁' => 'ʻao',
    '⛅' => 'laʻā ʻaoʻaofia',
    '⛈' => 'ʻao moe ʻuha moe ʻuhila',
    '🌤' => 'ʻaoʻaofia siʻi',
    '🌥' => 'ʻaoʻaofia lahi',
    '🌦' => 'ʻaoʻaofia ʻuha',
    '🌧' => 'ʻuha ʻaoʻaofia',
    '🌨' => 'sinou ʻaoʻaofia',
    '🌩' => 'ʻuhila ʻaoʻaofia',
    '🌪' => 'ʻahiohio',
    '🌫' => 'kakapu',
    '🌬' => 'mataʻi matangi',
    '🌀' => 'saikolone',
    '🌈' => 'ʻūmata',
    '🌂' => 'tukuhifo fakamalu',
    '☂' => 'teke fakamalu',
    '☔' => 'fakamalu ʻihe ʻuha',
    '⛱' => 'fakamalu tuʻu',
    '⚡' => 'volita māʻolunga',
    '❄' => 'foʻi sinou',
    '☃' => 'tangata sinou ʻihe ʻea sinou',
    '⛄' => 'tangata sinou',
    '☄' => 'fetuʻu fuka',
    '🔥' => 'afi',
    '💧' => 'tulutā vai',
    '🌊' => 'peau',
    '🎃' => 'matahina',
    '🎄' => 'ʻakau kilisimasi',
    '🎆' => 'fanaʻone',
    '🎇' => 'fanaʻone fetapatapaki',
    '🧨' => 'ʻone',
    '✨' => 'fetapatapaki',
    '🎈' => 'foʻi pula',
    '🎉' => 'paatipuna',
    '🎊' => 'pulu konifeti',
    '🎋' => 'ʻakau kātoanga fakasiapani',
    '🎍' => 'ongo matapā-paini',
    '🎎' => 'tamapua fakasiapani',
    '🎏' => 'ika fakamanumanu',
    '🎐' => 'fafangu-matangi',
    '🎑' => 'vakai-māhina',
    '🧧' => 'sila kulokula',
    '🎀' => 'lipine',
    '🎁' => 'lipine puha',
    '🎗' => 'lipine fakamanatu',
    '🎟' => 'tikite fakahū',
    '🎫' => 'tikite',
    '🎖' => 'mētali fakakautau',
    '🏆' => 'fakapale',
    '🏅' => 'mētali fakasipoti',
    '🥇' => 'mētali fika ʻuluaki',
    '🥈' => 'mētali fika ua',
    '🥉' => 'mētali fika tolu',
    '⚽' => 'soka',
    '⚾' => 'peisipolo',
    '🥎' => 'pulutenisi',
    '🏀' => 'pasiketipolo',
    '🏐' => 'volipolo',
    '🏈' => 'ʻakapulu fakaʻamelika',
    '🏉' => 'ʻakapulu',
    '🎾' => 'tenisi',
    '🥏' => 'tisi puna',
    '🎳' => 'tekapulu',
    '🏏' => 'kilikiti',
    '🏑' => 'hoki',
    '🏒' => 'hokiʻaisi',
    '🥍' => 'hokiʻinitiakula',
    '🏓' => 'pingipongo',
    '🏸' => 'patiminitoni',
    '🥊' => 'letafuhu',
    '🥋' => 'teuteu fangatua',
    '🥅' => 'kupenga kolo',
    '⛳' => 'fuka ʻihe luo',
    '⛸' => 'sū sikeiti ʻaisi',
    '🎣' => 'ʻakau-taumātaʻu',
    '🤿' => 'sioʻata uku',
    '🎽' => 'falani sipoti',
    '🎿' => 'heke sinou',
    '🛷' => 'hekeʻanga',
    '🥌' => 'maka tolo',
    '🎯' => 'lotomālie ʻoe tāketi',
    '🪀' => 'ioio',
    '🪁' => 'lofa',
    '🔫' => 'pekenene vai',
    '🎱' => 'pulu fika 8',
    '🔮' => 'pulu kalisitala',
    '🪄' => 'vaʻakau fakamēsiki',
    '🎮' => 'vaʻinga vitiō',
    '🕹' => 'ʻakau vaʻinga',
    '🎰' => 'mīsini tā paʻanga',
    '🎲' => 'taisi',
    '🧩' => 'laʻilekileki',
    '🧸' => 'pea tamapua',
    '🪅' => 'tamapua lole',
    '🪩' => 'pula-hulohula',
    '🪆' => 'tamapua fakaʻotu',
    '♠' => 'sipeiti',
    '♥' => 'haati',
    '♦' => 'taimani',
    '♣' => 'kalapa',
    '♟' => 'pate veimau',
    '🃏' => 'sioka',
    '🀄' => 'talakoni kulokula',
    '🎴' => 'sioka matalaʻiʻakau',
    '🎭' => 'faiva aati',
    '🖼' => 'ʻesiaʻi tā',
    '🎨' => 'tāvalivali',
    '🧵' => 'filo',
    '🪡' => 'huituitui',
    '🧶' => 'filo lalanga',
    '🪢' => 'fakapona',
    '👓' => 'matasioʻata',
    '🕶' => 'matasioʻatalaʻā',
    '🥽' => 'sioʻata malu',
    '🥼' => 'kote kemi',
    '🦺' => 'vesi',
    '👔' => 'hēkesi',
    '👕' => 'falani',
    '👖' => 'talausese',
    '🧣' => 'sikaafi',
    '🧤' => 'kofunima',
    '🧥' => 'kote',
    '🧦' => 'sitōkeni',
    '👗' => 'kofu',
    '👘' => 'kimono',
    '🥻' => 'sali',
    '🩱' => 'vala matātahi kongataha',
    '🩲' => 'talausese loto',
    '🩳' => 'talausese mutu',
    '👙' => 'vala matātahi kongaua',
    '👚' => 'vala fefine',
    '🪭' => 'ī-pelupelu',
    '👛' => 'kato paʻanga',
    '👜' => 'kato',
    '👝' => 'peesi teuteu',
    '🛍' => 'kato faʻoʻanga fakatau',
    '🎒' => 'kato ako',
    '🩴' => 'saniteli',
    '👞' => 'sū fakatangata',
    '👟' => 'sū lele',
    '🥾' => 'sū puti ʻeva lalo',
    '🥿' => 'sū fakafefine',
    '👠' => 'sū ʻete',
    '👡' => 'saniteli fakafefine',
    '🩰' => 'sū faiva pālangi',
    '👢' => 'sū puti fakafefine',
    '🪮' => 'helu',
    '👑' => 'kalauni',
    '👒' => 'tatā fakafefine',
    '🎩' => 'tatā māʻolunga',
    '🎓' => 'tatā maʻu mataʻitohi',
    '🧢' => 'kepi peisipolo',
    '🪖' => 'helemeti',
    '⛑' => 'tatā fefeka',
    '📿' => 'kulalotu',
    '💄' => 'lipisitiki',
    '💍' => 'mama',
    '💎' => 'maka koloa',
    '🔇' => 'leʻo matafa',
    '🔈' => 'leʻo siʻi',
    '🔉' => 'leʻo loto',
    '🔊' => 'leʻo lahi',
    '📢' => 'sipikā',
    '📣' => 'meʻa fakaleʻolahi',
    '📯' => 'meʻa fakakōkō',
    '🔔' => 'fafangu',
    '🔕' => 'fafangu matafa',
    '🎼' => 'pepa hiva',
    '🎵' => 'nota',
    '🎶' => 'ngaahi nota',
    '🎙' => 'maikalofone fakamafolalea',
    '🎚' => 'meʻatoʻo tohoʻi',
    '🎛' => 'meʻatoʻo puleʻi',
    '🎤' => 'maikalofone',
    '🎧' => 'sipika ʻulu',
    '📻' => 'letiō',
    '🎷' => 'sakisefoni',
    '🎺' => 'meʻaifi',
    '🪊' => 'talamapone',
    '🪗' => 'puhaleotoho',
    '🎸' => 'kitā',
    '🎹' => 'ʻū kī',
    '🎻' => 'vaiolini',
    '🪕' => 'penisiō',
    '🥁' => 'nafa talamu',
    '🪘' => 'nafa',
    '🪇' => 'malaka',
    '🪈' => 'fuluta',
    '🪉' => 'haʻape',
    '📱' => 'foni toʻotoʻo',
    '📲' => 'foni toʻotoʻo moe ngahau',
    '☎' => 'telefoni',
    '📞' => 'meʻa fakaongo telefoni',
    '📟' => 'foni kikī',
    '📠' => 'foni tohi',
    '🔋' => 'maka fakaʻuhila',
    '🪫' => 'maka vaivai',
    '🔌' => 'ʻumosi ʻuhila',
    '💻' => 'komipiuta fungasino',
    '🖥' => 'komipiuta',
    '🖨' => 'mīsini paaki',
    '⌨' => 'ngaahi foʻi kī',
    '🖱' => 'kumā fakakomipiuta',
    '🖲' => 'polo toho',
    '💽' => 'tisi fefeka',
    '💾' => 'tisi molū',
    '💿' => 'tisi mamata',
    '📀' => 'tisi faiva',
    '🧮' => 'solopani',
    '🎥' => 'faitā heleʻuhila',
    '🎞' => 'ʻata heleʻuhila',
    '📽' => 'mīsini heleʻuhila',
    '🎬' => 'papapasi',
    '📺' => 'televīsone',
    '📷' => 'faitā',
    '📸' => 'faitā moe kasa',
    '📹' => 'faitā vitiō',
    '📼' => 'kasete vitiō',
    '🔍' => 'sioʻata ʻesiafi falala ki hema',
    '🔎' => 'sioʻata ʻesiafi falala ki mataʻu',
    '🕯' => 'teʻelango',
    '💡' => 'foʻi ʻuhila',
    '🔦' => 'kasa',
    '🏮' => 'maama matangi kulokula',
    '🪔' => 'maama tia',
    '📔' => 'pepa tohi teuʻi',
    '📕' => 'tohi mapuni',
    '📖' => 'tohi fakaava',
    '📗' => 'tohi lanumata',
    '📘' => 'tohi lanupulū',
    '📙' => 'tohi lanumoli',
    '📚' => 'ʻū tohi',
    '📓' => 'pepa tohi',
    '📒' => 'lētisa',
    '📃' => 'pepa fafatu',
    '📜' => 'takainga tohi',
    '📄' => 'pepa hanga hake',
    '📰' => 'nusipepa',
    '🗞' => 'nusipepa takainga',
    '📑' => 'vahevahe tohi',
    '🔖' => 'fakaʻilonga tohi',
    '🏷' => 'fakaʻilonga',
    '🪙' => 'paʻanga maka',
    '💰' => 'tangai paʻanga',
    '🪎' => 'puha koloa',
    '💴' => 'laʻi paʻanga fakasiapani',
    '💵' => 'laʻi paʻanga fakaʻamelika',
    '💶' => 'laʻi paʻanga fakaʻeulope',
    '💷' => 'laʻi paʻanga fakapilitania',
    '💸' => 'paʻanga moe kapakau',
    '💳' => 'kaati pangikē',
    '🧾' => 'lisiti',
    '💹' => 'siate tupulaki, paʻanga fakasiapani',
    '✉' => 'sila',
    '📧' => 'tohila',
    '📨' => 'sila hūmai',
    '📩' => 'sila moe ngahau',
    '📤' => 'laulau hū atu',
    '📥' => 'laulau hū mai',
    '📦' => 'kofukofu',
    '📫' => 'puha meili mapuni moe fuka ki ʻolunga',
    '📪' => 'puha meili mapuni moe fuka ki lalo',
    '📬' => 'puha meili ava moe fuka ki ʻolunga',
    '📭' => 'puha meili ava moe fuka ki lalo',
    '📮' => 'puha lītohi',
    '🗳' => 'puha fili moe pepa fili',
    '✏' => 'peni',
    '✒' => 'mataʻipeni',
    '🖋' => 'peniʻutu',
    '🖊' => 'polopeni',
    '🖌' => 'polosi vali',
    '🖍' => 'sioka tāvalivali',
    '📝' => 'pepa fakamanatu',
    '💼' => 'kato leta toʻotoʻo',
    '📁' => 'takafi faile',
    '📂' => 'takafi faile ava',
    '🗂' => 'vahevahe takafi faile',
    '📅' => 'tohimāhina',
    '📆' => 'tohimāhina fakaʻaho',
    '🗒' => 'pepa fakamaʻu vilovilo',
    '🗓' => 'tohimāhina fakamaʻu vilovilo',
    '📇' => 'tohi fakahinohino fakamaʻu vilovilo',
    '📈' => 'siate tupulaki',
    '📉' => 'siate maholo',
    '📊' => 'siate pā',
    '📋' => 'papa fakamaʻu pepa',
    '📌' => 'pine',
    '📍' => 'pine fuopotopoto',
    '📎' => 'fakamaʻu pepa',
    '🖇' => 'fakamaʻu pepa sēini',
    '📏' => 'lula hangatonu',
    '📐' => 'lula tapatolu',
    '✂' => 'helekosi',
    '🗃' => 'puha takafi faile',
    '🗄' => 'toloa takafi faile',
    '🗑' => 'kapa veve',
    '🔒' => 'loka',
    '🔓' => 'taʻeloka',
    '🔏' => 'loka moe peni',
    '🔐' => 'loka moe kī',
    '🔑' => 'kī',
    '🗝' => 'kī motuʻa',
    '🔨' => 'hamala',
    '🪓' => 'toki',
    '⛏' => 'toki tākelekele',
    '⚒' => 'hamala moe toki tākelekele',
    '🛠' => 'hamala moe sipana',
    '🗡' => 'heletā',
    '⚔' => 'heletā fehauaki',
    '💣' => 'pulukōkō',
    '🪃' => 'pūmalengi',
    '🏹' => 'kaufana moe ngahau',
    '🛡' => 'pā',
    '🪚' => 'kili',
    '🔧' => 'sipana',
    '🪛' => 'vetesikalu',
    '🔩' => 'nati moe polota',
    '⚙' => 'veʻeteka',
    '🗜' => 'fakauʻu',
    '⚖' => 'meʻa fuamamafa',
    '🦯' => 'tokotoko fakaʻeke',
    '🔗' => 'kupuʻi sēini',
    '⛓' => 'sēini',
    '🪝' => 'mātaʻu',
    '🧰' => 'puha meʻangāue',
    '🧲' => 'makinito',
    '🪜' => 'tuʻunga',
    '🪏' => 'huo tata',
    '⚗' => 'hina hakaʻanga',
    '🧪' => 'tiupi kemi',
    '🧫' => 'tisi kemi',
    '🧬' => 'TNA',
    '🔬' => 'meʻa fakaʻataefu',
    '🔭' => 'meʻa fakaʻatafetuʻu',
    '📡' => 'tisi satelaite',
    '💉' => 'meʻafana faitoʻo',
    '🩸' => 'tulutā toto',
    '💊' => 'foʻiʻakau',
    '🩹' => 'haʻihaʻi fakapipiki',
    '🩼' => 'kalatisi',
    '🩺' => 'meʻa fakaongo',
    '🩻' => 'huelo fakaʻēkesi',
    '🚪' => 'matapā',
    '🛗' => 'lifi',
    '🪞' => 'sioʻata',
    '🪟' => 'matapā-sioʻata',
    '🛏' => 'mohenga',
    '🛋' => 'sea mālōlōʻanga moe maama',
    '🪑' => 'sea',
    '🚽' => 'po toileti',
    '🪠' => 'meʻapamu toileti',
    '🚿' => 'meʻa fakapihi kaukau',
    '🛁' => 'topu kaukau',
    '🪤' => 'tauhele kumā',
    '🪒' => 'telekava',
    '🧴' => 'hina kilimi milimili',
    '🧷' => 'pine nāpikeni',
    '🧹' => 'taufale',
    '🧺' => 'kato lālanga',
    '🧻' => 'takainga pepa',
    '🪣' => 'kane',
    '🧼' => 'koa',
    '🫧' => 'maʻupu',
    '🪥' => 'fulufulunifo',
    '🧽' => 'oma',
    '🧯' => 'meʻa tāmateʻi afi',
    '🛒' => 'saliote tanakiʻanga fakatau',
    '🚬' => 'sikaleti',
    '⚰' => 'puha tanu',
    '🪦' => 'maka fakamanatu',
    '⚱' => 'hina fakamomofi',
    '🧿' => 'mana nasā',
    '🪬' => 'mataʻinima',
    '🗿' => 'moai',
    '🪧' => 'fakaʻilonga sikinali',
    '🪪' => 'kaati id',
    '🏧' => 'mīsini toho paʻanga',
    '🚮' => 'ʻilonga kapa veve',
    '🚰' => 'vai inu',
    '♿' => 'sea poliō',
    '🚹' => 'fale mālōlō tangata',
    '🚺' => 'fale mālōlō fefine',
    '🚻' => 'fale mālōlō',
    '🚼' => 'ʻilonga valevale',
    '🚾' => 'toileti',
    '🛂' => 'ʻofisa tohifolau',
    '🛃' => 'tute',
    '🛄' => 'maʻuʻanga katoleta',
    '🛅' => 'toloa katoleta',
    '⚠' => 'fakatokanga',
    '🚸' => 'fānau kolosiʻanga',
    '⛔' => 'tapu hū',
    '🚫' => 'tapu',
    '🚳' => 'tapu pasikala',
    '🚭' => 'tapu ifi tapaka',
    '🚯' => 'tapu fakaveve',
    '🚱' => 'vai taʻe inu',
    '🚷' => 'tapu lue',
    '📵' => 'tapu telefoni',
    '🔞' => 'tapu taʻu 18 hifo',
    '☢' => 'mofi ʻātomi',
    '☣' => 'fakatuʻutāmaki moʻui',
    '⬆' => 'ngahau ki ʻolunga',
    '↗' => 'ngahau ki ʻolunga toʻomataʻu',
    '➡' => 'ngahau ki toʻomataʻu',
    '↘' => 'ngahau ki lalo toʻomataʻu',
    '⬇' => 'ngahau ki lalo',
    '↙' => 'ngahau ki lalo toʻohema',
    '⬅' => 'ngahau ki toʻohema',
    '↖' => 'ngahau ki ʻolunga toʻohema',
    '↕' => 'ngahau ki ʻolunga mo lalo',
    '↔' => 'ngahau ki toʻohema mo toʻomataʻu',
    '↩' => 'ngahau afe ki toʻohema',
    '↪' => 'ngahau afe ki toʻomataʻu',
    '⤴' => 'ngahau afe ki ʻolunga',
    '⤵' => 'ngahau afe ki lalo',
    '🔃' => 'ngahau vilovilo toʻomataʻu',
    '🔄' => 'ngahau vilovilo toʻohema',
    '🔙' => 'ngahau FOKI',
    '🔚' => 'ngahau NGATA',
    '🔛' => 'ngahau FUNGA',
    '🔜' => 'ngahau OFI',
    '🔝' => 'ngahau TUMUTUMU',
    '🛐' => 'feituʻu faiʻanga lotu',
    '⚛' => 'ʻātomi',
    '🕉' => 'omikala',
    '✡' => 'fetuʻu ʻo Tēvita',
    '☸' => 'veʻeteka ʻo Tāma',
    '☯' => 'ingi-iangi',
    '✝' => 'kolosi fakalatina',
    '☦' => 'kolosi fakakalisi',
    '☪' => 'fetuʻu moe kalipa',
    '☮' => 'ʻilonga fakamelino',
    '🕎' => 'menola',
    '🔯' => 'fetuʻu tapaono moe ʻila',
    '🪯' => 'ʻilonga fakasiki',
    '♈' => 'Sipi tangata (pupunga)',
    '♉' => 'Pulu tau (pupunga)',
    '♊' => 'Māhanga taʻane (pupunga)',
    '♋' => 'ʻUo (pupunga)',
    '♌' => 'Laione (pupunga)',
    '♍' => 'Taupoʻou (pupunga)',
    '♎' => 'Fuatautau (pupunga)',
    '♏' => 'Sikipio (pupunga)',
    '♐' => 'Tangata fana (pupunga)',
    '♑' => 'Kositahi (pupunga)',
    '♒' => 'Fineʻutuvai (pupunga)',
    '♓' => 'Ongo ika (pupunga)',
    '⛎' => 'Tangata toʻo ngata (pupunga)',
    '🔀' => 'meʻalolomi tuifio',
    '🔁' => 'meʻalolomi toutou',
    '🔂' => 'meʻalolomi toe tuʻotaha',
    '▶' => 'meʻalolomi tā',
    '⏩' => 'meʻalolomi fakalaka vave',
    '⏭' => 'meʻalolomi fasi hoko',
    '⏯' => 'meʻalolomi tā pe tatali',
    '◀' => 'meʻalolomi foki',
    '⏪' => 'meʻalolomi foki vave',
    '⏮' => 'meʻalolomi fasi kimuʻa',
    '🔼' => 'meʻalolomi hake',
    '⏫' => 'meʻalolomi hake vave',
    '🔽' => 'meʻalolomi hifo',
    '⏬' => 'meʻalolomi hifo vave',
    '⏸' => 'meʻalolomi tatali',
    '⏹' => 'meʻalolomi taʻofi',
    '⏺' => 'meʻalolomi hiki',
    '⏏' => 'meʻalolomi toʻo',
    '🎦' => 'fale heleʻuhila',
    '🔅' => 'meʻalolomi fakapōpōʻuli',
    '🔆' => 'meʻalolomi fakamaama',
    '📶' => 'pā lave',
    '🛜' => 'mākoni',
    '📳' => 'foni tetetete',
    '📴' => 'foni toʻotoʻo tāmateʻi',
    '♀' => 'ʻilonga fakafefine',
    '♂' => 'ʻilonga fakatangata',
    '⚧' => 'ʻilonga fakaleiti moe tomupoi',
    '✖' => 'liunga mamafa',
    '➕' => 'tānaki mamafa',
    '➖' => 'kole mamafa',
    '➗' => 'vahevahe mamafa',
    '🟰' => 'tatau mamafa',
    '♾' => 'taʻengata mamafa',
    '‼' => 'kalanga lōua',
    '⁉' => 'kalanga-fehuʻi',
    '❓' => 'fehuʻi kulokula',
    '❔' => 'fehuʻi hinehina',
    '❕' => 'kalanga hinehina',
    '❗' => 'kalanga kulokula',
    '〰' => 'kohi fafasi',
    '💱' => 'paʻanga fakafetongi',
    '💲' => 'paʻanga mamafa',
    '⚕' => 'ʻilonga tōketā',
    '♻' => 'ʻilonga ngāueʻaki foʻou',
    '⚜' => 'ʻilonga lile',
    '🔱' => 'tao matatolu',
    '📛' => 'kaati hingoa',
    '🔰' => 'tokotaha langalangafoʻou fakasiapani',
    '⭕' => 'fuopotopoto mamafa',
    '✅' => 'meʻalolomi sivi',
    '☑' => 'puha fili moe sivi',
    '✔' => 'sivi mamafa',
    '❌' => 'kolosi',
    '❎' => 'meʻalolomi kolosi',
    '➰' => 'laine fakasākisi',
    '➿' => 'laine fakasākisi lōua',
    '〽' => 'liliu faʻahi',
    '✳' => 'fetuʻu huelovalu',
    '✴' => 'fetuʻu tapavalu',
    '❇' => 'fetapaki',
    '™' => 'fefakatauʻaki',
    '🫟' => 'afuhia',
    '🔠' => 'hū mataʻitohi lahi pē',
    '🔡' => 'hū mataʻitohi siʻi pē',
    '🔢' => 'hū mataʻifika pē',
    '🔣' => 'hū fakaʻilonga pē',
    '🔤' => 'hū mataʻitohi fakalatina',
    '🅰' => 'meʻalolomi faʻahinga toto A',
    '🆎' => 'meʻalolomi faʻahinga toto AB',
    '🅱' => 'meʻalolomi faʻahinga toto B',
    '🆑' => 'meʻalolomi CL',
    '🆒' => 'meʻalolomi COOL',
    '🆓' => 'meʻalolomi FREE',
    'ℹ' => 'fakaʻilonga fakamatala',
    '🆔' => 'meʻalolomi ID',
    'Ⓜ' => 'fakaʻilonga M fuopotopoto',
    '🆕' => 'meʻalolomi NEW',
    '🆖' => 'meʻalolomi NG',
    '🅾' => 'meʻalolomi faʻahinga toto O',
    '🆗' => 'meʻalolomi OK',
    '🅿' => 'meʻalolomi P',
    '🆘' => 'meʻalolomi SOS',
    '🆙' => 'meʻalolomi UP!',
    '🆚' => 'meʻalolomi VS',
    '🈁' => 'meʻalolomi «ʻi heni» (fakasiapani)',
    '🈂' => 'meʻalolomi «totongi faifatongia» (fakasiapani)',
    '🈷' => 'meʻalolomi «moʻua fakamāhina» (fakasiapani)',
    '🈶' => 'meʻalolomi «totongi» (fakasiapani)',
    '🈯' => 'meʻalolomi «taʻofi» (fakasiapani)',
    '🉐' => 'meʻalolomi «maʻamaʻa» (fakasiapani)',
    '🈹' => 'meʻalolomi «fakamaʻamaʻa» (fakasiapani)',
    '🈚' => 'meʻalolomi «taʻetotongi» (fakasiapani)',
    '🈲' => 'meʻalolomi «tapu» (fakasiapani)',
    '🉑' => 'meʻalolomi «ala tali» (fakasiapani)',
    '🈸' => 'meʻalolomi «ʻai heni» (fakasiapani)',
    '🈴' => 'meʻalolomi «fika lava» (fakasiapani)',
    '🈳' => 'meʻalolomi «loki ʻatā» (fakasiapani)',
    '㊗' => 'meʻalolomi «fakamālō» (fakasiapani)',
    '㊙' => 'meʻalolomi «lilolilo» (fakasiapani)',
    '🈺' => 'meʻalolomi «ava he ngāue» (fakasiapani)',
    '🈵' => 'meʻalolomi «hala loki ʻatā» (fakasiapani)',
    '🔴' => 'fuopotopoto kulokula',
    '🟠' => 'fuopotopoto lanumoli',
    '🟡' => 'fuopotopoto engeenga',
    '🟢' => 'fuopotopoto lanumata',
    '🔵' => 'fuopotopoto lanupulū',
    '🟣' => 'fuopotopoto lanuvaioleti',
    '🟤' => 'fuopotopoto melomelo',
    '⚫' => 'fuopotopoto ʻuluʻuli',
    '⚪' => 'fuopotopoto hinehina',
    '🟥' => 'tapafā kulokula',
    '🟧' => 'tapafā lanumoli',
    '🟨' => 'tapafā engeenga',
    '🟩' => 'tapafā lanumata',
    '🟦' => 'tapafā lanupulū',
    '🟪' => 'tapafā lanuvaioleti',
    '🟫' => 'tapafā melomelo',
    '⬛' => 'tapafā lahi mo ʻuliʻuli',
    '⬜' => 'tapafā lahi mo hinehina',
    '◼' => 'tapafā tauloto mo ʻuliʻuli',
    '◻' => 'tapafā tauloto mo hinehina',
    '◾' => 'tapafā siʻi mo ʻuliʻuli',
    '◽' => 'tapafā siʻi mo hinehina',
    '▪' => 'tapafā siʻisiʻi mo ʻuliʻuli',
    '▫' => 'tapafā siʻisiʻi mo hinehina',
    '🔶' => 'taiamoni lahi mo lanumoli',
    '🔷' => 'taiamoni lahi mo lanupulū',
    '🔸' => 'taiamoni siʻi mo lanumoli',
    '🔹' => 'taiamoni siʻi mo lanupulū',
    '🔺' => 'tapatolu ki ʻolunga kulokula',
    '🔻' => 'tapatolu kulokula ki lalo',
    '💠' => 'taiamoni moe ʻila',
    '🔘' => 'meʻalolomi lētio',
    '🔳' => 'meʻalolomi tapafā hinehina',
    '🔲' => 'meʻalolomi tapafā ʻuliʻuli',
    '🏁' => 'fuka lova',
    '🚩' => 'fuka tapatolu',
    '🎌' => 'fuka fehauaki',
    '🏴' => 'fuka ʻuliʻuli',
    '🏳' => 'fuka hinehina',
];
