<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'sich küssendes Paar: Person, Person, helle Hautfarbe und mittelhelle Hautfarbe',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'sich küssendes Paar: Person, Person, helle Hautfarbe und mittlere Hautfarbe',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'sich küssendes Paar: Person, Person, helle Hautfarbe und mitteldunkle Hautfarbe',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'sich küssendes Paar: Person, Person, helle Hautfarbe und dunkle Hautfarbe',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'sich küssendes Paar: Person, Person, mittelhelle Hautfarbe und helle Hautfarbe',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'sich küssendes Paar: Person, Person, mittelhelle Hautfarbe und mittlere Hautfarbe',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'sich küssendes Paar: Person, Person, mittelhelle Hautfarbe und mitteldunkle Hautfarbe',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'sich küssendes Paar: Person, Person, mittelhelle Hautfarbe und dunkle Hautfarbe',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'sich küssendes Paar: Person, Person, mittlere Hautfarbe und helle Hautfarbe',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'sich küssendes Paar: Person, Person, mittlere Hautfarbe und mittelhelle Hautfarbe',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'sich küssendes Paar: Person, Person, mittlere Hautfarbe und mitteldunkle Hautfarbe',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'sich küssendes Paar: Person, Person, mittlere Hautfarbe und dunkle Hautfarbe',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'sich küssendes Paar: Person, Person, mitteldunkle Hautfarbe und helle Hautfarbe',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'sich küssendes Paar: Person, Person, mitteldunkle Hautfarbe und mittelhelle Hautfarbe',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'sich küssendes Paar: Person, Person, mitteldunkle Hautfarbe und mittlere Hautfarbe',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'sich küssendes Paar: Person, Person, mitteldunkle Hautfarbe und dunkle Hautfarbe',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'sich küssendes Paar: Person, Person, dunkle Hautfarbe und helle Hautfarbe',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'sich küssendes Paar: Person, Person, dunkle Hautfarbe und mittelhelle Hautfarbe',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'sich küssendes Paar: Person, Person, dunkle Hautfarbe und mittlere Hautfarbe',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'sich küssendes Paar: Person, Person, dunkle Hautfarbe und mitteldunkle Hautfarbe',
    '👨🏻‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Mann, Mann und helle Hautfarbe',
    '👨🏻‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Mann, Mann, helle Hautfarbe und mittelhelle Hautfarbe',
    '👨🏻‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Mann, Mann, helle Hautfarbe und mittlere Hautfarbe',
    '👨🏻‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Mann, Mann, helle Hautfarbe und mitteldunkle Hautfarbe',
    '👨🏻‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Mann, Mann, helle Hautfarbe und dunkle Hautfarbe',
    '👨🏼‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Mann, Mann, mittelhelle Hautfarbe und helle Hautfarbe',
    '👨🏼‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Mann, Mann und mittelhelle Hautfarbe',
    '👨🏼‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Mann, Mann, mittelhelle Hautfarbe und mittlere Hautfarbe',
    '👨🏼‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Mann, Mann, mittelhelle Hautfarbe und mitteldunkle Hautfarbe',
    '👨🏼‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Mann, Mann, mittelhelle Hautfarbe und dunkle Hautfarbe',
    '👨🏽‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Mann, Mann, mittlere Hautfarbe und helle Hautfarbe',
    '👨🏽‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Mann, Mann, mittlere Hautfarbe und mittelhelle Hautfarbe',
    '👨🏽‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Mann, Mann und mittlere Hautfarbe',
    '👨🏽‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Mann, Mann, mittlere Hautfarbe und mitteldunkle Hautfarbe',
    '👨🏽‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Mann, Mann, mittlere Hautfarbe und dunkle Hautfarbe',
    '👨🏾‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Mann, Mann, mitteldunkle Hautfarbe und helle Hautfarbe',
    '👨🏾‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Mann, Mann, mitteldunkle Hautfarbe und mittelhelle Hautfarbe',
    '👨🏾‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Mann, Mann, mitteldunkle Hautfarbe und mittlere Hautfarbe',
    '👨🏾‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Mann, Mann und mitteldunkle Hautfarbe',
    '👨🏾‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Mann, Mann, mitteldunkle Hautfarbe und dunkle Hautfarbe',
    '👨🏿‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Mann, Mann, dunkle Hautfarbe und helle Hautfarbe',
    '👨🏿‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Mann, Mann, dunkle Hautfarbe und mittelhelle Hautfarbe',
    '👨🏿‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Mann, Mann, dunkle Hautfarbe und mittlere Hautfarbe',
    '👨🏿‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Mann, Mann, dunkle Hautfarbe und mitteldunkle Hautfarbe',
    '👨🏿‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Mann, Mann und dunkle Hautfarbe',
    '👩🏻‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Frau, Mann und helle Hautfarbe',
    '👩🏻‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Frau, Mann, helle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏻‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Frau, Mann, helle Hautfarbe und mittlere Hautfarbe',
    '👩🏻‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Frau, Mann, helle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏻‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Frau, Mann, helle Hautfarbe und dunkle Hautfarbe',
    '👩🏼‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Frau, Mann, mittelhelle Hautfarbe und helle Hautfarbe',
    '👩🏼‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Frau, Mann und mittelhelle Hautfarbe',
    '👩🏼‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Frau, Mann, mittelhelle Hautfarbe und mittlere Hautfarbe',
    '👩🏼‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Frau, Mann, mittelhelle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏼‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Frau, Mann, mittelhelle Hautfarbe und dunkle Hautfarbe',
    '👩🏽‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Frau, Mann, mittlere Hautfarbe und helle Hautfarbe',
    '👩🏽‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Frau, Mann, mittlere Hautfarbe und mittelhelle Hautfarbe',
    '👩🏽‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Frau, Mann und mittlere Hautfarbe',
    '👩🏽‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Frau, Mann, mittlere Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏽‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Frau, Mann, mittlere Hautfarbe und dunkle Hautfarbe',
    '👩🏾‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Frau, Mann, mitteldunkle Hautfarbe und helle Hautfarbe',
    '👩🏾‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Frau, Mann, mitteldunkle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏾‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Frau, Mann, mitteldunkle Hautfarbe und mittlere Hautfarbe',
    '👩🏾‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Frau, Mann und mitteldunkle Hautfarbe',
    '👩🏾‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Frau, Mann, mitteldunkle Hautfarbe und dunkle Hautfarbe',
    '👩🏿‍❤‍💋‍👨🏻' => 'sich küssendes Paar: Frau, Mann, dunkle Hautfarbe und helle Hautfarbe',
    '👩🏿‍❤‍💋‍👨🏼' => 'sich küssendes Paar: Frau, Mann, dunkle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏿‍❤‍💋‍👨🏽' => 'sich küssendes Paar: Frau, Mann, dunkle Hautfarbe und mittlere Hautfarbe',
    '👩🏿‍❤‍💋‍👨🏾' => 'sich küssendes Paar: Frau, Mann, dunkle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏿‍❤‍💋‍👨🏿' => 'sich küssendes Paar: Frau, Mann und dunkle Hautfarbe',
    '👩🏻‍❤‍💋‍👩🏻' => 'sich küssendes Paar: Frau, Frau und helle Hautfarbe',
    '👩🏻‍❤‍💋‍👩🏼' => 'sich küssendes Paar: Frau, Frau, helle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏻‍❤‍💋‍👩🏽' => 'sich küssendes Paar: Frau, Frau, helle Hautfarbe und mittlere Hautfarbe',
    '👩🏻‍❤‍💋‍👩🏾' => 'sich küssendes Paar: Frau, Frau, helle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏻‍❤‍💋‍👩🏿' => 'sich küssendes Paar: Frau, Frau, helle Hautfarbe und dunkle Hautfarbe',
    '👩🏼‍❤‍💋‍👩🏻' => 'sich küssendes Paar: Frau, Frau, mittelhelle Hautfarbe und helle Hautfarbe',
    '👩🏼‍❤‍💋‍👩🏼' => 'sich küssendes Paar: Frau, Frau und mittelhelle Hautfarbe',
    '👩🏼‍❤‍💋‍👩🏽' => 'sich küssendes Paar: Frau, Frau, mittelhelle Hautfarbe und mittlere Hautfarbe',
    '👩🏼‍❤‍💋‍👩🏾' => 'sich küssendes Paar: Frau, Frau, mittelhelle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏼‍❤‍💋‍👩🏿' => 'sich küssendes Paar: Frau, Frau, mittelhelle Hautfarbe und dunkle Hautfarbe',
    '👩🏽‍❤‍💋‍👩🏻' => 'sich küssendes Paar: Frau, Frau, mittlere Hautfarbe und helle Hautfarbe',
    '👩🏽‍❤‍💋‍👩🏼' => 'sich küssendes Paar: Frau, Frau, mittlere Hautfarbe und mittelhelle Hautfarbe',
    '👩🏽‍❤‍💋‍👩🏽' => 'sich küssendes Paar: Frau, Frau und mittlere Hautfarbe',
    '👩🏽‍❤‍💋‍👩🏾' => 'sich küssendes Paar: Frau, Frau, mittlere Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏽‍❤‍💋‍👩🏿' => 'sich küssendes Paar: Frau, Frau, mittlere Hautfarbe und dunkle Hautfarbe',
    '👩🏾‍❤‍💋‍👩🏻' => 'sich küssendes Paar: Frau, Frau, mitteldunkle Hautfarbe und helle Hautfarbe',
    '👩🏾‍❤‍💋‍👩🏼' => 'sich küssendes Paar: Frau, Frau, mitteldunkle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏾‍❤‍💋‍👩🏽' => 'sich küssendes Paar: Frau, Frau, mitteldunkle Hautfarbe und mittlere Hautfarbe',
    '👩🏾‍❤‍💋‍👩🏾' => 'sich küssendes Paar: Frau, Frau und mitteldunkle Hautfarbe',
    '👩🏾‍❤‍💋‍👩🏿' => 'sich küssendes Paar: Frau, Frau, mitteldunkle Hautfarbe und dunkle Hautfarbe',
    '👩🏿‍❤‍💋‍👩🏻' => 'sich küssendes Paar: Frau, Frau, dunkle Hautfarbe und helle Hautfarbe',
    '👩🏿‍❤‍💋‍👩🏼' => 'sich küssendes Paar: Frau, Frau, dunkle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏿‍❤‍💋‍👩🏽' => 'sich küssendes Paar: Frau, Frau, dunkle Hautfarbe und mittlere Hautfarbe',
    '👩🏿‍❤‍💋‍👩🏾' => 'sich küssendes Paar: Frau, Frau, dunkle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏿‍❤‍💋‍👩🏿' => 'sich küssendes Paar: Frau, Frau und dunkle Hautfarbe',
    '🧑🏻‍🫯‍🧑🏼' => 'Ringer(in): helle Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏻‍🫯‍🧑🏽' => 'Ringer(in): helle Hautfarbe, mittlere Hautfarbe',
    '🧑🏻‍🫯‍🧑🏾' => 'Ringer(in): helle Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏻‍🫯‍🧑🏿' => 'Ringer(in): helle Hautfarbe, dunkle Hautfarbe',
    '🧑🏼‍🫯‍🧑🏻' => 'Ringer(in): mittelhelle Hautfarbe, helle Hautfarbe',
    '🧑🏼‍🫯‍🧑🏽' => 'Ringer(in): mittelhelle Hautfarbe, mittlere Hautfarbe',
    '🧑🏼‍🫯‍🧑🏾' => 'Ringer(in): mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏼‍🫯‍🧑🏿' => 'Ringer(in): mittelhelle Hautfarbe, dunkle Hautfarbe',
    '🧑🏽‍🫯‍🧑🏻' => 'Ringer(in): mittlere Hautfarbe, helle Hautfarbe',
    '🧑🏽‍🫯‍🧑🏼' => 'Ringer(in): mittlere Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏽‍🫯‍🧑🏾' => 'Ringer(in): mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏽‍🫯‍🧑🏿' => 'Ringer(in): mittlere Hautfarbe, dunkle Hautfarbe',
    '🧑🏾‍🫯‍🧑🏻' => 'Ringer(in): mitteldunkle Hautfarbe, helle Hautfarbe',
    '🧑🏾‍🫯‍🧑🏼' => 'Ringer(in): mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏾‍🫯‍🧑🏽' => 'Ringer(in): mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '🧑🏾‍🫯‍🧑🏿' => 'Ringer(in): mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '🧑🏿‍🫯‍🧑🏻' => 'Ringer(in): dunkle Hautfarbe, helle Hautfarbe',
    '🧑🏿‍🫯‍🧑🏼' => 'Ringer(in): dunkle Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏿‍🫯‍🧑🏽' => 'Ringer(in): dunkle Hautfarbe, mittlere Hautfarbe',
    '🧑🏿‍🫯‍🧑🏾' => 'Ringer(in): dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏻‍❤‍🧑🏼' => 'Liebespaar: Person, Person, helle Hautfarbe und mittelhelle Hautfarbe',
    '🧑🏻‍❤‍🧑🏽' => 'Liebespaar: Person, Person, helle Hautfarbe und mittlere Hautfarbe',
    '🧑🏻‍❤‍🧑🏾' => 'Liebespaar: Person, Person, helle Hautfarbe und mitteldunkle Hautfarbe',
    '🧑🏻‍❤‍🧑🏿' => 'Liebespaar: Person, Person, helle Hautfarbe und dunkle Hautfarbe',
    '🧑🏼‍❤‍🧑🏻' => 'Liebespaar: Person, Person, mittelhelle Hautfarbe und helle Hautfarbe',
    '🧑🏼‍❤‍🧑🏽' => 'Liebespaar: Person, Person, mittelhelle Hautfarbe und mittlere Hautfarbe',
    '🧑🏼‍❤‍🧑🏾' => 'Liebespaar: Person, Person, mittelhelle Hautfarbe und mitteldunkle Hautfarbe',
    '🧑🏼‍❤‍🧑🏿' => 'Liebespaar: Person, Person, mittelhelle Hautfarbe und dunkle Hautfarbe',
    '🧑🏽‍❤‍🧑🏻' => 'Liebespaar: Person, Person, mittlere Hautfarbe und helle Hautfarbe',
    '🧑🏽‍❤‍🧑🏼' => 'Liebespaar: Person, Person, mittlere Hautfarbe und mittelhelle Hautfarbe',
    '🧑🏽‍❤‍🧑🏾' => 'Liebespaar: Person, Person, mittlere Hautfarbe und mitteldunkle Hautfarbe',
    '🧑🏽‍❤‍🧑🏿' => 'Liebespaar: Person, Person, mittlere Hautfarbe und dunkle Hautfarbe',
    '🧑🏾‍❤‍🧑🏻' => 'Liebespaar: Person, Person, mitteldunkle Hautfarbe und helle Hautfarbe',
    '🧑🏾‍❤‍🧑🏼' => 'Liebespaar: Person, Person, mitteldunkle Hautfarbe und mittelhelle Hautfarbe',
    '🧑🏾‍❤‍🧑🏽' => 'Liebespaar: Person, Person, mitteldunkle Hautfarbe und mittlere Hautfarbe',
    '🧑🏾‍❤‍🧑🏿' => 'Liebespaar: Person, Person, mitteldunkle Hautfarbe und dunkle Hautfarbe',
    '🧑🏿‍❤‍🧑🏻' => 'Liebespaar: Person, Person, dunkle Hautfarbe und helle Hautfarbe',
    '🧑🏿‍❤‍🧑🏼' => 'Liebespaar: Person, Person, dunkle Hautfarbe und mittelhelle Hautfarbe',
    '🧑🏿‍❤‍🧑🏽' => 'Liebespaar: Person, Person, dunkle Hautfarbe und mittlere Hautfarbe',
    '🧑🏿‍❤‍🧑🏾' => 'Liebespaar: Person, Person, dunkle Hautfarbe und mitteldunkle Hautfarbe',
    '🧑🏻‍🐰‍🧑🏼' => 'Personen mit Hasenohren: helle Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏻‍🐰‍🧑🏽' => 'Personen mit Hasenohren: helle Hautfarbe, mittlere Hautfarbe',
    '🧑🏻‍🐰‍🧑🏾' => 'Personen mit Hasenohren: helle Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏻‍🐰‍🧑🏿' => 'Personen mit Hasenohren: helle Hautfarbe, dunkle Hautfarbe',
    '🧑🏼‍🐰‍🧑🏻' => 'Personen mit Hasenohren: mittelhelle Hautfarbe, helle Hautfarbe',
    '🧑🏼‍🐰‍🧑🏽' => 'Personen mit Hasenohren: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '🧑🏼‍🐰‍🧑🏾' => 'Personen mit Hasenohren: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏼‍🐰‍🧑🏿' => 'Personen mit Hasenohren: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '🧑🏽‍🐰‍🧑🏻' => 'Personen mit Hasenohren: mittlere Hautfarbe, helle Hautfarbe',
    '🧑🏽‍🐰‍🧑🏼' => 'Personen mit Hasenohren: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏽‍🐰‍🧑🏾' => 'Personen mit Hasenohren: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏽‍🐰‍🧑🏿' => 'Personen mit Hasenohren: mittlere Hautfarbe, dunkle Hautfarbe',
    '🧑🏾‍🐰‍🧑🏻' => 'Personen mit Hasenohren: mitteldunkle Hautfarbe, helle Hautfarbe',
    '🧑🏾‍🐰‍🧑🏼' => 'Personen mit Hasenohren: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏾‍🐰‍🧑🏽' => 'Personen mit Hasenohren: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '🧑🏾‍🐰‍🧑🏿' => 'Personen mit Hasenohren: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '🧑🏿‍🐰‍🧑🏻' => 'Personen mit Hasenohren: dunkle Hautfarbe, helle Hautfarbe',
    '🧑🏿‍🐰‍🧑🏼' => 'Personen mit Hasenohren: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏿‍🐰‍🧑🏽' => 'Personen mit Hasenohren: dunkle Hautfarbe, mittlere Hautfarbe',
    '🧑🏿‍🐰‍🧑🏾' => 'Personen mit Hasenohren: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏻‍🫯‍👨🏼' => 'ringende Männer: helle Hautfarbe, mittelhelle Hautfarbe',
    '👨🏻‍🫯‍👨🏽' => 'ringende Männer: helle Hautfarbe, mittlere Hautfarbe',
    '👨🏻‍🫯‍👨🏾' => 'ringende Männer: helle Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏻‍🫯‍👨🏿' => 'ringende Männer: helle Hautfarbe, dunkle Hautfarbe',
    '👨🏼‍🫯‍👨🏻' => 'ringende Männer: mittelhelle Hautfarbe, helle Hautfarbe',
    '👨🏼‍🫯‍👨🏽' => 'ringende Männer: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '👨🏼‍🫯‍👨🏾' => 'ringende Männer: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏼‍🫯‍👨🏿' => 'ringende Männer: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '👨🏽‍🫯‍👨🏻' => 'ringende Männer: mittlere Hautfarbe, helle Hautfarbe',
    '👨🏽‍🫯‍👨🏼' => 'ringende Männer: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '👨🏽‍🫯‍👨🏾' => 'ringende Männer: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏽‍🫯‍👨🏿' => 'ringende Männer: mittlere Hautfarbe, dunkle Hautfarbe',
    '👨🏾‍🫯‍👨🏻' => 'ringende Männer: mitteldunkle Hautfarbe, helle Hautfarbe',
    '👨🏾‍🫯‍👨🏼' => 'ringende Männer: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '👨🏾‍🫯‍👨🏽' => 'ringende Männer: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '👨🏾‍🫯‍👨🏿' => 'ringende Männer: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '👨🏿‍🫯‍👨🏻' => 'ringende Männer: dunkle Hautfarbe, helle Hautfarbe',
    '👨🏿‍🫯‍👨🏼' => 'ringende Männer: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '👨🏿‍🫯‍👨🏽' => 'ringende Männer: dunkle Hautfarbe, mittlere Hautfarbe',
    '👨🏿‍🫯‍👨🏾' => 'ringende Männer: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏻‍❤‍👨🏻' => 'Liebespaar: Mann, Mann und helle Hautfarbe',
    '👨🏻‍❤‍👨🏼' => 'Liebespaar: Mann, Mann, helle Hautfarbe und mittelhelle Hautfarbe',
    '👨🏻‍❤‍👨🏽' => 'Liebespaar: Mann, Mann, helle Hautfarbe und mittlere Hautfarbe',
    '👨🏻‍❤‍👨🏾' => 'Liebespaar: Mann, Mann, helle Hautfarbe und mitteldunkle Hautfarbe',
    '👨🏻‍❤‍👨🏿' => 'Liebespaar: Mann, Mann, helle Hautfarbe und dunkle Hautfarbe',
    '👨🏼‍❤‍👨🏻' => 'Liebespaar: Mann, Mann, mittelhelle Hautfarbe und helle Hautfarbe',
    '👨🏼‍❤‍👨🏼' => 'Liebespaar: Mann, Mann und mittelhelle Hautfarbe',
    '👨🏼‍❤‍👨🏽' => 'Liebespaar: Mann, Mann, mittelhelle Hautfarbe und mittlere Hautfarbe',
    '👨🏼‍❤‍👨🏾' => 'Liebespaar: Mann, Mann, mittelhelle Hautfarbe und mitteldunkle Hautfarbe',
    '👨🏼‍❤‍👨🏿' => 'Liebespaar: Mann, Mann, mittelhelle Hautfarbe und dunkle Hautfarbe',
    '👨🏽‍❤‍👨🏻' => 'Liebespaar: Mann, Mann, mittlere Hautfarbe und helle Hautfarbe',
    '👨🏽‍❤‍👨🏼' => 'Liebespaar: Mann, Mann, mittlere Hautfarbe und mittelhelle Hautfarbe',
    '👨🏽‍❤‍👨🏽' => 'Liebespaar: Mann, Mann und mittlere Hautfarbe',
    '👨🏽‍❤‍👨🏾' => 'Liebespaar: Mann, Mann, mittlere Hautfarbe und mitteldunkle Hautfarbe',
    '👨🏽‍❤‍👨🏿' => 'Liebespaar: Mann, Mann, mittlere Hautfarbe und dunkle Hautfarbe',
    '👨🏾‍❤‍👨🏻' => 'Liebespaar: Mann, Mann, mitteldunkle Hautfarbe und helle Hautfarbe',
    '👨🏾‍❤‍👨🏼' => 'Liebespaar: Mann, Mann, mitteldunkle Hautfarbe und mittelhelle Hautfarbe',
    '👨🏾‍❤‍👨🏽' => 'Liebespaar: Mann, Mann, mitteldunkle Hautfarbe und mittlere Hautfarbe',
    '👨🏾‍❤‍👨🏾' => 'Liebespaar: Mann, Mann und mitteldunkle Hautfarbe',
    '👨🏾‍❤‍👨🏿' => 'Liebespaar: Mann, Mann, mitteldunkle Hautfarbe und dunkle Hautfarbe',
    '👨🏿‍❤‍👨🏻' => 'Liebespaar: Mann, Mann, dunkle Hautfarbe und helle Hautfarbe',
    '👨🏿‍❤‍👨🏼' => 'Liebespaar: Mann, Mann, dunkle Hautfarbe und mittelhelle Hautfarbe',
    '👨🏿‍❤‍👨🏽' => 'Liebespaar: Mann, Mann, dunkle Hautfarbe und mittlere Hautfarbe',
    '👨🏿‍❤‍👨🏾' => 'Liebespaar: Mann, Mann, dunkle Hautfarbe und mitteldunkle Hautfarbe',
    '👨🏿‍❤‍👨🏿' => 'Liebespaar: Mann, Mann und dunkle Hautfarbe',
    '👨🏻‍🐰‍👨🏼' => 'Männer mit Hasenohren: helle Hautfarbe, mittelhelle Hautfarbe',
    '👨🏻‍🐰‍👨🏽' => 'Männer mit Hasenohren: helle Hautfarbe, mittlere Hautfarbe',
    '👨🏻‍🐰‍👨🏾' => 'Männer mit Hasenohren: helle Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏻‍🐰‍👨🏿' => 'Männer mit Hasenohren: helle Hautfarbe, dunkle Hautfarbe',
    '👨🏼‍🐰‍👨🏻' => 'Männer mit Hasenohren: mittelhelle Hautfarbe, helle Hautfarbe',
    '👨🏼‍🐰‍👨🏽' => 'Männer mit Hasenohren: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '👨🏼‍🐰‍👨🏾' => 'Männer mit Hasenohren: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏼‍🐰‍👨🏿' => 'Männer mit Hasenohren: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '👨🏽‍🐰‍👨🏻' => 'Männer mit Hasenohren: mittlere Hautfarbe, helle Hautfarbe',
    '👨🏽‍🐰‍👨🏼' => 'Männer mit Hasenohren: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '👨🏽‍🐰‍👨🏾' => 'Männer mit Hasenohren: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏽‍🐰‍👨🏿' => 'Männer mit Hasenohren: mittlere Hautfarbe, dunkle Hautfarbe',
    '👨🏾‍🐰‍👨🏻' => 'Männer mit Hasenohren: mitteldunkle Hautfarbe, helle Hautfarbe',
    '👨🏾‍🐰‍👨🏼' => 'Männer mit Hasenohren: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '👨🏾‍🐰‍👨🏽' => 'Männer mit Hasenohren: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '👨🏾‍🐰‍👨🏿' => 'Männer mit Hasenohren: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '👨🏿‍🐰‍👨🏻' => 'Männer mit Hasenohren: dunkle Hautfarbe, helle Hautfarbe',
    '👨🏿‍🐰‍👨🏼' => 'Männer mit Hasenohren: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '👨🏿‍🐰‍👨🏽' => 'Männer mit Hasenohren: dunkle Hautfarbe, mittlere Hautfarbe',
    '👨🏿‍🐰‍👨🏾' => 'Männer mit Hasenohren: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏻‍🫯‍👩🏼' => 'ringende Frauen: helle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏻‍🫯‍👩🏽' => 'ringende Frauen: helle Hautfarbe, mittlere Hautfarbe',
    '👩🏻‍🫯‍👩🏾' => 'ringende Frauen: helle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏻‍🫯‍👩🏿' => 'ringende Frauen: helle Hautfarbe, dunkle Hautfarbe',
    '👩🏼‍🫯‍👩🏻' => 'ringende Frauen: mittelhelle Hautfarbe, helle Hautfarbe',
    '👩🏼‍🫯‍👩🏽' => 'ringende Frauen: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '👩🏼‍🫯‍👩🏾' => 'ringende Frauen: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏼‍🫯‍👩🏿' => 'ringende Frauen: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '👩🏽‍🫯‍👩🏻' => 'ringende Frauen: mittlere Hautfarbe, helle Hautfarbe',
    '👩🏽‍🫯‍👩🏼' => 'ringende Frauen: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '👩🏽‍🫯‍👩🏾' => 'ringende Frauen: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏽‍🫯‍👩🏿' => 'ringende Frauen: mittlere Hautfarbe, dunkle Hautfarbe',
    '👩🏾‍🫯‍👩🏻' => 'ringende Frauen: mitteldunkle Hautfarbe, helle Hautfarbe',
    '👩🏾‍🫯‍👩🏼' => 'ringende Frauen: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏾‍🫯‍👩🏽' => 'ringende Frauen: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '👩🏾‍🫯‍👩🏿' => 'ringende Frauen: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '👩🏿‍🫯‍👩🏻' => 'ringende Frauen: dunkle Hautfarbe, helle Hautfarbe',
    '👩🏿‍🫯‍👩🏼' => 'ringende Frauen: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏿‍🫯‍👩🏽' => 'ringende Frauen: dunkle Hautfarbe, mittlere Hautfarbe',
    '👩🏿‍🫯‍👩🏾' => 'ringende Frauen: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏻‍❤‍👨🏻' => 'Liebespaar: Frau, Mann und helle Hautfarbe',
    '👩🏻‍❤‍👨🏼' => 'Liebespaar: Frau, Mann, helle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏻‍❤‍👨🏽' => 'Liebespaar: Frau, Mann, helle Hautfarbe und mittlere Hautfarbe',
    '👩🏻‍❤‍👨🏾' => 'Liebespaar: Frau, Mann, helle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏻‍❤‍👨🏿' => 'Liebespaar: Frau, Mann, helle Hautfarbe und dunkle Hautfarbe',
    '👩🏼‍❤‍👨🏻' => 'Liebespaar: Frau, Mann, mittelhelle Hautfarbe und helle Hautfarbe',
    '👩🏼‍❤‍👨🏼' => 'Liebespaar: Frau, Mann und mittelhelle Hautfarbe',
    '👩🏼‍❤‍👨🏽' => 'Liebespaar: Frau, Mann, mittelhelle Hautfarbe und mittlere Hautfarbe',
    '👩🏼‍❤‍👨🏾' => 'Liebespaar: Frau, Mann, mittelhelle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏼‍❤‍👨🏿' => 'Liebespaar: Frau, Mann, mittelhelle Hautfarbe und dunkle Hautfarbe',
    '👩🏽‍❤‍👨🏻' => 'Liebespaar: Frau, Mann, mittlere Hautfarbe und helle Hautfarbe',
    '👩🏽‍❤‍👨🏼' => 'Liebespaar: Frau, Mann, mittlere Hautfarbe und mittelhelle Hautfarbe',
    '👩🏽‍❤‍👨🏽' => 'Liebespaar: Frau, Mann und mittlere Hautfarbe',
    '👩🏽‍❤‍👨🏾' => 'Liebespaar: Frau, Mann, mittlere Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏽‍❤‍👨🏿' => 'Liebespaar: Frau, Mann, mittlere Hautfarbe und dunkle Hautfarbe',
    '👩🏾‍❤‍👨🏻' => 'Liebespaar: Frau, Mann, mitteldunkle Hautfarbe und helle Hautfarbe',
    '👩🏾‍❤‍👨🏼' => 'Liebespaar: Frau, Mann, mitteldunkle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏾‍❤‍👨🏽' => 'Liebespaar: Frau, Mann, mitteldunkle Hautfarbe und mittlere Hautfarbe',
    '👩🏾‍❤‍👨🏾' => 'Liebespaar: Frau, Mann und mitteldunkle Hautfarbe',
    '👩🏾‍❤‍👨🏿' => 'Liebespaar: Frau, Mann, mitteldunkle Hautfarbe und dunkle Hautfarbe',
    '👩🏿‍❤‍👨🏻' => 'Liebespaar: Frau, Mann, dunkle Hautfarbe und helle Hautfarbe',
    '👩🏿‍❤‍👨🏼' => 'Liebespaar: Frau, Mann, dunkle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏿‍❤‍👨🏽' => 'Liebespaar: Frau, Mann, dunkle Hautfarbe und mittlere Hautfarbe',
    '👩🏿‍❤‍👨🏾' => 'Liebespaar: Frau, Mann, dunkle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏿‍❤‍👨🏿' => 'Liebespaar: Frau, Mann und dunkle Hautfarbe',
    '👩🏻‍❤‍👩🏻' => 'Liebespaar: Frau, Frau und helle Hautfarbe',
    '👩🏻‍❤‍👩🏼' => 'Liebespaar: Frau, Frau, helle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏻‍❤‍👩🏽' => 'Liebespaar: Frau, Frau, helle Hautfarbe und mittlere Hautfarbe',
    '👩🏻‍❤‍👩🏾' => 'Liebespaar: Frau, Frau, helle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏻‍❤‍👩🏿' => 'Liebespaar: Frau, Frau, helle Hautfarbe und dunkle Hautfarbe',
    '👩🏼‍❤‍👩🏻' => 'Liebespaar: Frau, Frau, mittelhelle Hautfarbe und helle Hautfarbe',
    '👩🏼‍❤‍👩🏼' => 'Liebespaar: Frau, Frau und mittelhelle Hautfarbe',
    '👩🏼‍❤‍👩🏽' => 'Liebespaar: Frau, Frau, mittelhelle Hautfarbe und mittlere Hautfarbe',
    '👩🏼‍❤‍👩🏾' => 'Liebespaar: Frau, Frau, mittelhelle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏼‍❤‍👩🏿' => 'Liebespaar: Frau, Frau, mittelhelle Hautfarbe und dunkle Hautfarbe',
    '👩🏽‍❤‍👩🏻' => 'Liebespaar: Frau, Frau, mittlere Hautfarbe und helle Hautfarbe',
    '👩🏽‍❤‍👩🏼' => 'Liebespaar: Frau, Frau, mittlere Hautfarbe und mittelhelle Hautfarbe',
    '👩🏽‍❤‍👩🏽' => 'Liebespaar: Frau, Frau und mittlere Hautfarbe',
    '👩🏽‍❤‍👩🏾' => 'Liebespaar: Frau, Frau, mittlere Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏽‍❤‍👩🏿' => 'Liebespaar: Frau, Frau, mittlere Hautfarbe und dunkle Hautfarbe',
    '👩🏾‍❤‍👩🏻' => 'Liebespaar: Frau, Frau, mitteldunkle Hautfarbe und helle Hautfarbe',
    '👩🏾‍❤‍👩🏼' => 'Liebespaar: Frau, Frau, mitteldunkle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏾‍❤‍👩🏽' => 'Liebespaar: Frau, Frau, mitteldunkle Hautfarbe und mittlere Hautfarbe',
    '👩🏾‍❤‍👩🏾' => 'Liebespaar: Frau, Frau und mitteldunkle Hautfarbe',
    '👩🏾‍❤‍👩🏿' => 'Liebespaar: Frau, Frau, mitteldunkle Hautfarbe und dunkle Hautfarbe',
    '👩🏿‍❤‍👩🏻' => 'Liebespaar: Frau, Frau, dunkle Hautfarbe und helle Hautfarbe',
    '👩🏿‍❤‍👩🏼' => 'Liebespaar: Frau, Frau, dunkle Hautfarbe und mittelhelle Hautfarbe',
    '👩🏿‍❤‍👩🏽' => 'Liebespaar: Frau, Frau, dunkle Hautfarbe und mittlere Hautfarbe',
    '👩🏿‍❤‍👩🏾' => 'Liebespaar: Frau, Frau, dunkle Hautfarbe und mitteldunkle Hautfarbe',
    '👩🏿‍❤‍👩🏿' => 'Liebespaar: Frau, Frau und dunkle Hautfarbe',
    '👩🏻‍🐰‍👩🏼' => 'Frauen mit Hasenohren: helle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏻‍🐰‍👩🏽' => 'Frauen mit Hasenohren: helle Hautfarbe, mittlere Hautfarbe',
    '👩🏻‍🐰‍👩🏾' => 'Frauen mit Hasenohren: helle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏻‍🐰‍👩🏿' => 'Frauen mit Hasenohren: helle Hautfarbe, dunkle Hautfarbe',
    '👩🏼‍🐰‍👩🏻' => 'Frauen mit Hasenohren: mittelhelle Hautfarbe, helle Hautfarbe',
    '👩🏼‍🐰‍👩🏽' => 'Frauen mit Hasenohren: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '👩🏼‍🐰‍👩🏾' => 'Frauen mit Hasenohren: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏼‍🐰‍👩🏿' => 'Frauen mit Hasenohren: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '👩🏽‍🐰‍👩🏻' => 'Frauen mit Hasenohren: mittlere Hautfarbe, helle Hautfarbe',
    '👩🏽‍🐰‍👩🏼' => 'Frauen mit Hasenohren: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '👩🏽‍🐰‍👩🏾' => 'Frauen mit Hasenohren: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏽‍🐰‍👩🏿' => 'Frauen mit Hasenohren: mittlere Hautfarbe, dunkle Hautfarbe',
    '👩🏾‍🐰‍👩🏻' => 'Frauen mit Hasenohren: mitteldunkle Hautfarbe, helle Hautfarbe',
    '👩🏾‍🐰‍👩🏼' => 'Frauen mit Hasenohren: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏾‍🐰‍👩🏽' => 'Frauen mit Hasenohren: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '👩🏾‍🐰‍👩🏿' => 'Frauen mit Hasenohren: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '👩🏿‍🐰‍👩🏻' => 'Frauen mit Hasenohren: dunkle Hautfarbe, helle Hautfarbe',
    '👩🏿‍🐰‍👩🏼' => 'Frauen mit Hasenohren: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏿‍🐰‍👩🏽' => 'Frauen mit Hasenohren: dunkle Hautfarbe, mittlere Hautfarbe',
    '👩🏿‍🐰‍👩🏾' => 'Frauen mit Hasenohren: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏻‍🤝‍🧑🏻' => 'sich an den Händen haltende Personen: helle Hautfarbe',
    '🧑🏻‍🤝‍🧑🏼' => 'sich an den Händen haltende Personen: helle Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏻‍🤝‍🧑🏽' => 'sich an den Händen haltende Personen: helle Hautfarbe, mittlere Hautfarbe',
    '🧑🏻‍🤝‍🧑🏾' => 'sich an den Händen haltende Personen: helle Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏻‍🤝‍🧑🏿' => 'sich an den Händen haltende Personen: helle Hautfarbe, dunkle Hautfarbe',
    '🧑🏼‍🤝‍🧑🏻' => 'sich an den Händen haltende Personen: mittelhelle Hautfarbe, helle Hautfarbe',
    '🧑🏼‍🤝‍🧑🏼' => 'sich an den Händen haltende Personen: mittelhelle Hautfarbe',
    '🧑🏼‍🤝‍🧑🏽' => 'sich an den Händen haltende Personen: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '🧑🏼‍🤝‍🧑🏾' => 'sich an den Händen haltende Personen: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏼‍🤝‍🧑🏿' => 'sich an den Händen haltende Personen: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '🧑🏽‍🤝‍🧑🏻' => 'sich an den Händen haltende Personen: mittlere Hautfarbe, helle Hautfarbe',
    '🧑🏽‍🤝‍🧑🏼' => 'sich an den Händen haltende Personen: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏽‍🤝‍🧑🏽' => 'sich an den Händen haltende Personen: mittlere Hautfarbe',
    '🧑🏽‍🤝‍🧑🏾' => 'sich an den Händen haltende Personen: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏽‍🤝‍🧑🏿' => 'sich an den Händen haltende Personen: mittlere Hautfarbe, dunkle Hautfarbe',
    '🧑🏾‍🤝‍🧑🏻' => 'sich an den Händen haltende Personen: mitteldunkle Hautfarbe, helle Hautfarbe',
    '🧑🏾‍🤝‍🧑🏼' => 'sich an den Händen haltende Personen: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏾‍🤝‍🧑🏽' => 'sich an den Händen haltende Personen: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '🧑🏾‍🤝‍🧑🏾' => 'sich an den Händen haltende Personen: mitteldunkle Hautfarbe',
    '🧑🏾‍🤝‍🧑🏿' => 'sich an den Händen haltende Personen: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '🧑🏿‍🤝‍🧑🏻' => 'sich an den Händen haltende Personen: dunkle Hautfarbe, helle Hautfarbe',
    '🧑🏿‍🤝‍🧑🏼' => 'sich an den Händen haltende Personen: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '🧑🏿‍🤝‍🧑🏽' => 'sich an den Händen haltende Personen: dunkle Hautfarbe, mittlere Hautfarbe',
    '🧑🏿‍🤝‍🧑🏾' => 'sich an den Händen haltende Personen: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '🧑🏿‍🤝‍🧑🏿' => 'sich an den Händen haltende Personen: dunkle Hautfarbe',
    '👩🏻‍🤝‍👩🏼' => 'Händchen haltende Frauen: helle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏻‍🤝‍👩🏽' => 'Händchen haltende Frauen: helle Hautfarbe, mittlere Hautfarbe',
    '👩🏻‍🤝‍👩🏾' => 'Händchen haltende Frauen: helle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏻‍🤝‍👩🏿' => 'Händchen haltende Frauen: helle Hautfarbe, dunkle Hautfarbe',
    '👩🏼‍🤝‍👩🏻' => 'Händchen haltende Frauen: mittelhelle Hautfarbe, helle Hautfarbe',
    '👩🏼‍🤝‍👩🏽' => 'Händchen haltende Frauen: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '👩🏼‍🤝‍👩🏾' => 'Händchen haltende Frauen: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏼‍🤝‍👩🏿' => 'Händchen haltende Frauen: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '👩🏽‍🤝‍👩🏻' => 'Händchen haltende Frauen: mittlere Hautfarbe, helle Hautfarbe',
    '👩🏽‍🤝‍👩🏼' => 'Händchen haltende Frauen: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '👩🏽‍🤝‍👩🏾' => 'Händchen haltende Frauen: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏽‍🤝‍👩🏿' => 'Händchen haltende Frauen: mittlere Hautfarbe, dunkle Hautfarbe',
    '👩🏾‍🤝‍👩🏻' => 'Händchen haltende Frauen: mitteldunkle Hautfarbe, helle Hautfarbe',
    '👩🏾‍🤝‍👩🏼' => 'Händchen haltende Frauen: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏾‍🤝‍👩🏽' => 'Händchen haltende Frauen: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '👩🏾‍🤝‍👩🏿' => 'Händchen haltende Frauen: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '👩🏿‍🤝‍👩🏻' => 'Händchen haltende Frauen: dunkle Hautfarbe, helle Hautfarbe',
    '👩🏿‍🤝‍👩🏼' => 'Händchen haltende Frauen: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏿‍🤝‍👩🏽' => 'Händchen haltende Frauen: dunkle Hautfarbe, mittlere Hautfarbe',
    '👩🏿‍🤝‍👩🏾' => 'Händchen haltende Frauen: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏻‍🤝‍👨🏼' => 'Mann und Frau halten Hände: helle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏻‍🤝‍👨🏽' => 'Mann und Frau halten Hände: helle Hautfarbe, mittlere Hautfarbe',
    '👩🏻‍🤝‍👨🏾' => 'Mann und Frau halten Hände: helle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏻‍🤝‍👨🏿' => 'Mann und Frau halten Hände: helle Hautfarbe, dunkle Hautfarbe',
    '👩🏼‍🤝‍👨🏻' => 'Mann und Frau halten Hände: mittelhelle Hautfarbe, helle Hautfarbe',
    '👩🏼‍🤝‍👨🏽' => 'Mann und Frau halten Hände: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '👩🏼‍🤝‍👨🏾' => 'Mann und Frau halten Hände: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏼‍🤝‍👨🏿' => 'Mann und Frau halten Hände: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '👩🏽‍🤝‍👨🏻' => 'Mann und Frau halten Hände: mittlere Hautfarbe, helle Hautfarbe',
    '👩🏽‍🤝‍👨🏼' => 'Mann und Frau halten Hände: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '👩🏽‍🤝‍👨🏾' => 'Mann und Frau halten Hände: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '👩🏽‍🤝‍👨🏿' => 'Mann und Frau halten Hände: mittlere Hautfarbe, dunkle Hautfarbe',
    '👩🏾‍🤝‍👨🏻' => 'Mann und Frau halten Hände: mitteldunkle Hautfarbe, helle Hautfarbe',
    '👩🏾‍🤝‍👨🏼' => 'Mann und Frau halten Hände: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏾‍🤝‍👨🏽' => 'Mann und Frau halten Hände: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '👩🏾‍🤝‍👨🏿' => 'Mann und Frau halten Hände: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '👩🏿‍🤝‍👨🏻' => 'Mann und Frau halten Hände: dunkle Hautfarbe, helle Hautfarbe',
    '👩🏿‍🤝‍👨🏼' => 'Mann und Frau halten Hände: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '👩🏿‍🤝‍👨🏽' => 'Mann und Frau halten Hände: dunkle Hautfarbe, mittlere Hautfarbe',
    '👩🏿‍🤝‍👨🏾' => 'Mann und Frau halten Hände: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏻‍🤝‍👨🏼' => 'Händchen haltende Männer: helle Hautfarbe, mittelhelle Hautfarbe',
    '👨🏻‍🤝‍👨🏽' => 'Händchen haltende Männer: helle Hautfarbe, mittlere Hautfarbe',
    '👨🏻‍🤝‍👨🏾' => 'Händchen haltende Männer: helle Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏻‍🤝‍👨🏿' => 'Händchen haltende Männer: helle Hautfarbe, dunkle Hautfarbe',
    '👨🏼‍🤝‍👨🏻' => 'Händchen haltende Männer: mittelhelle Hautfarbe, helle Hautfarbe',
    '👨🏼‍🤝‍👨🏽' => 'Händchen haltende Männer: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '👨🏼‍🤝‍👨🏾' => 'Händchen haltende Männer: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏼‍🤝‍👨🏿' => 'Händchen haltende Männer: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '👨🏽‍🤝‍👨🏻' => 'Händchen haltende Männer: mittlere Hautfarbe, helle Hautfarbe',
    '👨🏽‍🤝‍👨🏼' => 'Händchen haltende Männer: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '👨🏽‍🤝‍👨🏾' => 'Händchen haltende Männer: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '👨🏽‍🤝‍👨🏿' => 'Händchen haltende Männer: mittlere Hautfarbe, dunkle Hautfarbe',
    '👨🏾‍🤝‍👨🏻' => 'Händchen haltende Männer: mitteldunkle Hautfarbe, helle Hautfarbe',
    '👨🏾‍🤝‍👨🏼' => 'Händchen haltende Männer: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '👨🏾‍🤝‍👨🏽' => 'Händchen haltende Männer: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '👨🏾‍🤝‍👨🏿' => 'Händchen haltende Männer: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '👨🏿‍🤝‍👨🏻' => 'Händchen haltende Männer: dunkle Hautfarbe, helle Hautfarbe',
    '👨🏿‍🤝‍👨🏼' => 'Händchen haltende Männer: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '👨🏿‍🤝‍👨🏽' => 'Händchen haltende Männer: dunkle Hautfarbe, mittlere Hautfarbe',
    '👨🏿‍🤝‍👨🏾' => 'Händchen haltende Männer: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '👩‍❤‍💋‍👨' => 'sich küssendes Paar: Frau, Mann',
    '👨‍❤‍💋‍👨' => 'sich küssendes Paar: Mann, Mann',
    '👩‍❤‍💋‍👩' => 'sich küssendes Paar: Frau, Frau',
    '👨‍👩‍👧‍👦' => 'Familie: Mann, Frau, Mädchen und Junge',
    '👨‍👩‍👦‍👦' => 'Familie: Mann, Frau, Junge und Junge',
    '👨‍👩‍👧‍👧' => 'Familie: Mann, Frau, Mädchen und Mädchen',
    '👨‍👨‍👧‍👦' => 'Familie: Mann, Mann, Mädchen und Junge',
    '👨‍👨‍👦‍👦' => 'Familie: Mann, Mann, Junge und Junge',
    '👨‍👨‍👧‍👧' => 'Familie: Mann, Mann, Mädchen und Mädchen',
    '👩‍👩‍👧‍👦' => 'Familie: Frau, Frau, Mädchen und Junge',
    '👩‍👩‍👦‍👦' => 'Familie: Frau, Frau, Junge und Junge',
    '👩‍👩‍👧‍👧' => 'Familie: Frau, Frau, Mädchen und Mädchen',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'Flagge: England',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'Flagge: Schottland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'Flagge: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'Familie: 2 Erwachsene, 2 Kinder',
    '🚶🏻‍♀‍➡' => 'Fussgängerin: helle Hautfarbe, nach rechts',
    '🚶🏼‍♀‍➡' => 'Fussgängerin: mittelhelle Hautfarbe, nach rechts',
    '🚶🏽‍♀‍➡' => 'Fussgängerin: mittlere Hautfarbe, nach rechts',
    '🚶🏾‍♀‍➡' => 'Fussgängerin: mitteldunkle Hautfarbe, nach rechts',
    '🚶🏿‍♀‍➡' => 'Fussgängerin: dunkle Hautfarbe, nach rechts',
    '🚶🏻‍♂‍➡' => 'Fussgänger: helle Hautfarbe, nach rechts',
    '🚶🏼‍♂‍➡' => 'Fussgänger: mittelhelle Hautfarbe, nach rechts',
    '🚶🏽‍♂‍➡' => 'Fussgänger: mittlere Hautfarbe, nach rechts',
    '🚶🏾‍♂‍➡' => 'Fussgänger: mitteldunkle Hautfarbe, nach rechts',
    '🚶🏿‍♂‍➡' => 'Fussgänger: dunkle Hautfarbe, nach rechts',
    '🧎🏻‍♀‍➡' => 'kniende Frau: helle Hautfarbe, nach rechts',
    '🧎🏼‍♀‍➡' => 'kniende Frau: mittelhelle Hautfarbe, nach rechts',
    '🧎🏽‍♀‍➡' => 'kniende Frau: mittlere Hautfarbe, nach rechts',
    '🧎🏾‍♀‍➡' => 'kniende Frau: mitteldunkle Hautfarbe, nach rechts',
    '🧎🏿‍♀‍➡' => 'kniende Frau: dunkle Hautfarbe, nach rechts',
    '🧎🏻‍♂‍➡' => 'kniender Mann: helle Hautfarbe, nach rechts',
    '🧎🏼‍♂‍➡' => 'kniender Mann: mittelhelle Hautfarbe, nach rechts',
    '🧎🏽‍♂‍➡' => 'kniender Mann: mittlere Hautfarbe, nach rechts',
    '🧎🏾‍♂‍➡' => 'kniender Mann: mitteldunkle Hautfarbe, nach rechts',
    '🧎🏿‍♂‍➡' => 'kniender Mann: dunkle Hautfarbe, nach rechts',
    '🧑🏻‍🦯‍➡' => 'Person mit Langstock: helle Hautfarbe, nach rechts',
    '🧑🏼‍🦯‍➡' => 'Person mit Langstock: mittelhelle Hautfarbe, nach rechts',
    '🧑🏽‍🦯‍➡' => 'Person mit Langstock: mittlere Hautfarbe, nach rechts',
    '🧑🏾‍🦯‍➡' => 'Person mit Langstock: mitteldunkle Hautfarbe, nach rechts',
    '🧑🏿‍🦯‍➡' => 'Person mit Langstock: dunkle Hautfarbe, nach rechts',
    '👨🏻‍🦯‍➡' => 'Mann mit Langstock: helle Hautfarbe, nach rechts',
    '👨🏼‍🦯‍➡' => 'Mann mit Langstock: mittelhelle Hautfarbe, nach rechts',
    '👨🏽‍🦯‍➡' => 'Mann mit Langstock: mittlere Hautfarbe, nach rechts',
    '👨🏾‍🦯‍➡' => 'Mann mit Langstock: mitteldunkle Hautfarbe, nach rechts',
    '👨🏿‍🦯‍➡' => 'Mann mit Langstock: dunkle Hautfarbe, nach rechts',
    '👩🏻‍🦯‍➡' => 'Frau mit Langstock: helle Hautfarbe, nach rechts',
    '👩🏼‍🦯‍➡' => 'Frau mit Langstock: mittelhelle Hautfarbe, nach rechts',
    '👩🏽‍🦯‍➡' => 'Frau mit Langstock: mittlere Hautfarbe, nach rechts',
    '👩🏾‍🦯‍➡' => 'Frau mit Langstock: mitteldunkle Hautfarbe, nach rechts',
    '👩🏿‍🦯‍➡' => 'Frau mit Langstock: dunkle Hautfarbe, nach rechts',
    '🧑🏻‍🦼‍➡' => 'Person in elektrischem Rollstuhl: helle Hautfarbe, nach rechts',
    '🧑🏼‍🦼‍➡' => 'Person in elektrischem Rollstuhl: mittelhelle Hautfarbe, nach rechts',
    '🧑🏽‍🦼‍➡' => 'Person in elektrischem Rollstuhl: mittlere Hautfarbe, nach rechts',
    '🧑🏾‍🦼‍➡' => 'Person in elektrischem Rollstuhl: mitteldunkle Hautfarbe, nach rechts',
    '🧑🏿‍🦼‍➡' => 'Person in elektrischem Rollstuhl: dunkle Hautfarbe, nach rechts',
    '👨🏻‍🦼‍➡' => 'Mann in elektrischem Rollstuhl: helle Hautfarbe, nach rechts',
    '👨🏼‍🦼‍➡' => 'Mann in elektrischem Rollstuhl: mittelhelle Hautfarbe, nach rechts',
    '👨🏽‍🦼‍➡' => 'Mann in elektrischem Rollstuhl: mittlere Hautfarbe, nach rechts',
    '👨🏾‍🦼‍➡' => 'Mann in elektrischem Rollstuhl: mitteldunkle Hautfarbe, nach rechts',
    '👨🏿‍🦼‍➡' => 'Mann in elektrischem Rollstuhl: dunkle Hautfarbe, nach rechts',
    '👩🏻‍🦼‍➡' => 'Frau in elektrischem Rollstuhl: helle Hautfarbe, nach rechts',
    '👩🏼‍🦼‍➡' => 'Frau in elektrischem Rollstuhl: mittelhelle Hautfarbe, nach rechts',
    '👩🏽‍🦼‍➡' => 'Frau in elektrischem Rollstuhl: mittlere Hautfarbe, nach rechts',
    '👩🏾‍🦼‍➡' => 'Frau in elektrischem Rollstuhl: mitteldunkle Hautfarbe, nach rechts',
    '👩🏿‍🦼‍➡' => 'Frau in elektrischem Rollstuhl: dunkle Hautfarbe, nach rechts',
    '🧑🏻‍🦽‍➡' => 'Person in manuellem Rollstuhl: helle Hautfarbe, nach rechts',
    '🧑🏼‍🦽‍➡' => 'Person in manuellem Rollstuhl: mittelhelle Hautfarbe, nach rechts',
    '🧑🏽‍🦽‍➡' => 'Person in manuellem Rollstuhl: mittlere Hautfarbe, nach rechts',
    '🧑🏾‍🦽‍➡' => 'Person in manuellem Rollstuhl: mitteldunkle Hautfarbe, nach rechts',
    '🧑🏿‍🦽‍➡' => 'Person in manuellem Rollstuhl: dunkle Hautfarbe, nach rechts',
    '👨🏻‍🦽‍➡' => 'Mann in manuellem Rollstuhl: helle Hautfarbe, nach rechts',
    '👨🏼‍🦽‍➡' => 'Mann in manuellem Rollstuhl: mittelhelle Hautfarbe, nach rechts',
    '👨🏽‍🦽‍➡' => 'Mann in manuellem Rollstuhl: mittlere Hautfarbe, nach rechts',
    '👨🏾‍🦽‍➡' => 'Mann in manuellem Rollstuhl: mitteldunkle Hautfarbe, nach rechts',
    '👨🏿‍🦽‍➡' => 'Mann in manuellem Rollstuhl: dunkle Hautfarbe, nach rechts',
    '👩🏻‍🦽‍➡' => 'Frau in manuellem Rollstuhl: helle Hautfarbe, nach rechts',
    '👩🏼‍🦽‍➡' => 'Frau in manuellem Rollstuhl: mittelhelle Hautfarbe, nach rechts',
    '👩🏽‍🦽‍➡' => 'Frau in manuellem Rollstuhl: mittlere Hautfarbe, nach rechts',
    '👩🏾‍🦽‍➡' => 'Frau in manuellem Rollstuhl: mitteldunkle Hautfarbe, nach rechts',
    '👩🏿‍🦽‍➡' => 'Frau in manuellem Rollstuhl: dunkle Hautfarbe, nach rechts',
    '🏃🏻‍♀‍➡' => 'laufende Frau: helle Hautfarbe, nach rechts',
    '🏃🏼‍♀‍➡' => 'laufende Frau: mittelhelle Hautfarbe, nach rechts',
    '🏃🏽‍♀‍➡' => 'laufende Frau: mittlere Hautfarbe, nach rechts',
    '🏃🏾‍♀‍➡' => 'laufende Frau: mitteldunkle Hautfarbe, nach rechts',
    '🏃🏿‍♀‍➡' => 'laufende Frau: dunkle Hautfarbe, nach rechts',
    '🏃🏻‍♂‍➡' => 'laufender Mann: helle Hautfarbe, nach rechts',
    '🏃🏼‍♂‍➡' => 'laufender Mann: mittelhelle Hautfarbe, nach rechts',
    '🏃🏽‍♂‍➡' => 'laufender Mann: mittlere Hautfarbe, nach rechts',
    '🏃🏾‍♂‍➡' => 'laufender Mann: mitteldunkle Hautfarbe, nach rechts',
    '🏃🏿‍♂‍➡' => 'laufender Mann: dunkle Hautfarbe, nach rechts',
    '🫱🏻‍🫲🏼' => 'Handschlag: helle Hautfarbe, mittelhelle Hautfarbe',
    '🫱🏻‍🫲🏽' => 'Handschlag: helle Hautfarbe, mittlere Hautfarbe',
    '🫱🏻‍🫲🏾' => 'Handschlag: helle Hautfarbe, mitteldunkle Hautfarbe',
    '🫱🏻‍🫲🏿' => 'Handschlag: helle Hautfarbe, dunkle Hautfarbe',
    '🫱🏼‍🫲🏻' => 'Handschlag: mittelhelle Hautfarbe, helle Hautfarbe',
    '🫱🏼‍🫲🏽' => 'Handschlag: mittelhelle Hautfarbe, mittlere Hautfarbe',
    '🫱🏼‍🫲🏾' => 'Handschlag: mittelhelle Hautfarbe, mitteldunkle Hautfarbe',
    '🫱🏼‍🫲🏿' => 'Handschlag: mittelhelle Hautfarbe, dunkle Hautfarbe',
    '🫱🏽‍🫲🏻' => 'Handschlag: mittlere Hautfarbe, helle Hautfarbe',
    '🫱🏽‍🫲🏼' => 'Handschlag: mittlere Hautfarbe, mittelhelle Hautfarbe',
    '🫱🏽‍🫲🏾' => 'Handschlag: mittlere Hautfarbe, mitteldunkle Hautfarbe',
    '🫱🏽‍🫲🏿' => 'Handschlag: mittlere Hautfarbe, dunkle Hautfarbe',
    '🫱🏾‍🫲🏻' => 'Handschlag: mitteldunkle Hautfarbe, helle Hautfarbe',
    '🫱🏾‍🫲🏼' => 'Handschlag: mitteldunkle Hautfarbe, mittelhelle Hautfarbe',
    '🫱🏾‍🫲🏽' => 'Handschlag: mitteldunkle Hautfarbe, mittlere Hautfarbe',
    '🫱🏾‍🫲🏿' => 'Handschlag: mitteldunkle Hautfarbe, dunkle Hautfarbe',
    '🫱🏿‍🫲🏻' => 'Handschlag: dunkle Hautfarbe, helle Hautfarbe',
    '🫱🏿‍🫲🏼' => 'Handschlag: dunkle Hautfarbe, mittelhelle Hautfarbe',
    '🫱🏿‍🫲🏽' => 'Handschlag: dunkle Hautfarbe, mittlere Hautfarbe',
    '🫱🏿‍🫲🏾' => 'Handschlag: dunkle Hautfarbe, mitteldunkle Hautfarbe',
    '🚶‍♀‍➡' => 'Fussgängerin: nach rechts',
    '🚶‍♂‍➡' => 'Fussgänger: nach rechts',
    '🧎‍♀‍➡' => 'kniende Frau: nach rechts',
    '🧎‍♂‍➡' => 'kniender Mann: nach rechts',
    '🧑‍🦯‍➡' => 'Person mit Langstock: nach rechts',
    '👨‍🦯‍➡' => 'Mann mit Langstock: nach rechts',
    '👩‍🦯‍➡' => 'Frau mit Langstock: nach rechts',
    '🧑‍🦼‍➡' => 'Person in elektrischem Rollstuhl: nach rechts',
    '👨‍🦼‍➡' => 'Mann in elektrischem Rollstuhl: nach rechts',
    '👩‍🦼‍➡' => 'Frau in elektrischem Rollstuhl: nach rechts',
    '🧑‍🦽‍➡' => 'Person in manuellem Rollstuhl: nach rechts',
    '👨‍🦽‍➡' => 'Mann in manuellem Rollstuhl: nach rechts',
    '👩‍🦽‍➡' => 'Frau in manuellem Rollstuhl: nach rechts',
    '🏃‍♀‍➡' => 'laufende Frau: nach rechts',
    '🏃‍♂‍➡' => 'laufender Mann: nach rechts',
    '👩‍❤‍👨' => 'Liebespaar: Frau, Mann',
    '👨‍❤‍👨' => 'Liebespaar: Mann, Mann',
    '👩‍❤‍👩' => 'Liebespaar: Frau, Frau',
    '👨‍👩‍👦' => 'Familie: Mann, Frau und Junge',
    '👨‍👩‍👧' => 'Familie: Mann, Frau und Mädchen',
    '👨‍👨‍👦' => 'Familie: Mann, Mann und Junge',
    '👨‍👨‍👧' => 'Familie: Mann, Mann und Mädchen',
    '👩‍👩‍👦' => 'Familie: Frau, Frau und Junge',
    '👩‍👩‍👧' => 'Familie: Frau, Frau und Mädchen',
    '👨‍👦‍👦' => 'Familie: Mann, Junge und Junge',
    '👨‍👧‍👦' => 'Familie: Mann, Mädchen und Junge',
    '👨‍👧‍👧' => 'Familie: Mann, Mädchen und Mädchen',
    '👩‍👦‍👦' => 'Familie: Frau, Junge und Junge',
    '👩‍👧‍👦' => 'Familie: Frau, Mädchen und Junge',
    '👩‍👧‍👧' => 'Familie: Frau, Mädchen und Mädchen',
    '🧑‍🤝‍🧑' => 'sich an den Händen haltende Personen',
    '🧑‍🧑‍🧒' => 'Familie: 2 Erwachsene, 1 Kind',
    '🧑‍🧒‍🧒' => 'Familie: 1 Erwachsene(r), 2 Kinder',
    '🧑🏻‍🦰' => 'Person: helle Hautfarbe, rotes Haar',
    '🧑🏼‍🦰' => 'Person: mittelhelle Hautfarbe, rotes Haar',
    '🧑🏽‍🦰' => 'Person: mittlere Hautfarbe, rotes Haar',
    '🧑🏾‍🦰' => 'Person: mitteldunkle Hautfarbe, rotes Haar',
    '🧑🏿‍🦰' => 'Person: dunkle Hautfarbe, rotes Haar',
    '🧑🏻‍🦱' => 'Person: helle Hautfarbe, lockiges Haar',
    '🧑🏼‍🦱' => 'Person: mittelhelle Hautfarbe, lockiges Haar',
    '🧑🏽‍🦱' => 'Person: mittlere Hautfarbe, lockiges Haar',
    '🧑🏾‍🦱' => 'Person: mitteldunkle Hautfarbe, lockiges Haar',
    '🧑🏿‍🦱' => 'Person: dunkle Hautfarbe, lockiges Haar',
    '🧑🏻‍🦳' => 'Person: helle Hautfarbe, weisses Haar',
    '🧑🏼‍🦳' => 'Person: mittelhelle Hautfarbe, weisses Haar',
    '🧑🏽‍🦳' => 'Person: mittlere Hautfarbe, weisses Haar',
    '🧑🏾‍🦳' => 'Person: mitteldunkle Hautfarbe, weisses Haar',
    '🧑🏿‍🦳' => 'Person: dunkle Hautfarbe, weisses Haar',
    '🧑🏻‍🦲' => 'Person: helle Hautfarbe, Glatze',
    '🧑🏼‍🦲' => 'Person: mittelhelle Hautfarbe, Glatze',
    '🧑🏽‍🦲' => 'Person: mittlere Hautfarbe, Glatze',
    '🧑🏾‍🦲' => 'Person: mitteldunkle Hautfarbe, Glatze',
    '🧑🏿‍🦲' => 'Person: dunkle Hautfarbe, Glatze',
    '🧑🏻‍🩰' => 'Balletttänzerin: helle Hautfarbe',
    '🧑🏼‍🩰' => 'Balletttänzerin: mittelhelle Hautfarbe',
    '🧑🏽‍🩰' => 'Balletttänzerin: mittlere Hautfarbe',
    '🧑🏾‍🩰' => 'Balletttänzerin: mitteldunkle Hautfarbe',
    '🧑🏿‍🩰' => 'Balletttänzerin: dunkle Hautfarbe',
    '🧔🏻‍♂' => 'Mann: helle Hautfarbe, Bart',
    '🧔🏼‍♂' => 'Mann: mittelhelle Hautfarbe, Bart',
    '🧔🏽‍♂' => 'Mann: mittlere Hautfarbe, Bart',
    '🧔🏾‍♂' => 'Mann: mitteldunkle Hautfarbe, Bart',
    '🧔🏿‍♂' => 'Mann: dunkle Hautfarbe, Bart',
    '👱🏻‍♂' => 'Mann: helle Hautfarbe, blond',
    '👱🏼‍♂' => 'Mann: mittelhelle Hautfarbe, blond',
    '👱🏽‍♂' => 'Mann: mittlere Hautfarbe, blond',
    '👱🏾‍♂' => 'Mann: mitteldunkle Hautfarbe, blond',
    '👱🏿‍♂' => 'Mann: dunkle Hautfarbe, blond',
    '👨🏻‍🦰' => 'Mann: helle Hautfarbe, rotes Haar',
    '👨🏼‍🦰' => 'Mann: mittelhelle Hautfarbe, rotes Haar',
    '👨🏽‍🦰' => 'Mann: mittlere Hautfarbe, rotes Haar',
    '👨🏾‍🦰' => 'Mann: mitteldunkle Hautfarbe, rotes Haar',
    '👨🏿‍🦰' => 'Mann: dunkle Hautfarbe, rotes Haar',
    '👨🏻‍🦱' => 'Mann: helle Hautfarbe, lockiges Haar',
    '👨🏼‍🦱' => 'Mann: mittelhelle Hautfarbe, lockiges Haar',
    '👨🏽‍🦱' => 'Mann: mittlere Hautfarbe, lockiges Haar',
    '👨🏾‍🦱' => 'Mann: mitteldunkle Hautfarbe, lockiges Haar',
    '👨🏿‍🦱' => 'Mann: dunkle Hautfarbe, lockiges Haar',
    '👨🏻‍🦳' => 'Mann: helle Hautfarbe, weisses Haar',
    '👨🏼‍🦳' => 'Mann: mittelhelle Hautfarbe, weisses Haar',
    '👨🏽‍🦳' => 'Mann: mittlere Hautfarbe, weisses Haar',
    '👨🏾‍🦳' => 'Mann: mitteldunkle Hautfarbe, weisses Haar',
    '👨🏿‍🦳' => 'Mann: dunkle Hautfarbe, weisses Haar',
    '👨🏻‍🦲' => 'Mann: helle Hautfarbe, Glatze',
    '👨🏼‍🦲' => 'Mann: mittelhelle Hautfarbe, Glatze',
    '👨🏽‍🦲' => 'Mann: mittlere Hautfarbe, Glatze',
    '👨🏾‍🦲' => 'Mann: mitteldunkle Hautfarbe, Glatze',
    '👨🏿‍🦲' => 'Mann: dunkle Hautfarbe, Glatze',
    '🧔🏻‍♀' => 'Frau: helle Hautfarbe, Bart',
    '🧔🏼‍♀' => 'Frau: mittelhelle Hautfarbe, Bart',
    '🧔🏽‍♀' => 'Frau: mittlere Hautfarbe, Bart',
    '🧔🏾‍♀' => 'Frau: mitteldunkle Hautfarbe, Bart',
    '🧔🏿‍♀' => 'Frau: dunkle Hautfarbe, Bart',
    '👱🏻‍♀' => 'Frau: helle Hautfarbe, blond',
    '👱🏼‍♀' => 'Frau: mittelhelle Hautfarbe, blond',
    '👱🏽‍♀' => 'Frau: mittlere Hautfarbe, blond',
    '👱🏾‍♀' => 'Frau: mitteldunkle Hautfarbe, blond',
    '👱🏿‍♀' => 'Frau: dunkle Hautfarbe, blond',
    '👩🏻‍🦰' => 'Frau: helle Hautfarbe, rotes Haar',
    '👩🏼‍🦰' => 'Frau: mittelhelle Hautfarbe, rotes Haar',
    '👩🏽‍🦰' => 'Frau: mittlere Hautfarbe, rotes Haar',
    '👩🏾‍🦰' => 'Frau: mitteldunkle Hautfarbe, rotes Haar',
    '👩🏿‍🦰' => 'Frau: dunkle Hautfarbe, rotes Haar',
    '👩🏻‍🦱' => 'Frau: helle Hautfarbe, lockiges Haar',
    '👩🏼‍🦱' => 'Frau: mittelhelle Hautfarbe, lockiges Haar',
    '👩🏽‍🦱' => 'Frau: mittlere Hautfarbe, lockiges Haar',
    '👩🏾‍🦱' => 'Frau: mitteldunkle Hautfarbe, lockiges Haar',
    '👩🏿‍🦱' => 'Frau: dunkle Hautfarbe, lockiges Haar',
    '👩🏻‍🦳' => 'Frau: helle Hautfarbe, weisses Haar',
    '👩🏼‍🦳' => 'Frau: mittelhelle Hautfarbe, weisses Haar',
    '👩🏽‍🦳' => 'Frau: mittlere Hautfarbe, weisses Haar',
    '👩🏾‍🦳' => 'Frau: mitteldunkle Hautfarbe, weisses Haar',
    '👩🏿‍🦳' => 'Frau: dunkle Hautfarbe, weisses Haar',
    '👩🏻‍🦲' => 'Frau: helle Hautfarbe, Glatze',
    '👩🏼‍🦲' => 'Frau: mittelhelle Hautfarbe, Glatze',
    '👩🏽‍🦲' => 'Frau: mittlere Hautfarbe, Glatze',
    '👩🏾‍🦲' => 'Frau: mitteldunkle Hautfarbe, Glatze',
    '👩🏿‍🦲' => 'Frau: dunkle Hautfarbe, Glatze',
    '🙍🏻‍♂' => 'missmutiger Mann: helle Hautfarbe',
    '🙍🏼‍♂' => 'missmutiger Mann: mittelhelle Hautfarbe',
    '🙍🏽‍♂' => 'missmutiger Mann: mittlere Hautfarbe',
    '🙍🏾‍♂' => 'missmutiger Mann: mitteldunkle Hautfarbe',
    '🙍🏿‍♂' => 'missmutiger Mann: dunkle Hautfarbe',
    '🙍🏻‍♀' => 'missmutige Frau: helle Hautfarbe',
    '🙍🏼‍♀' => 'missmutige Frau: mittelhelle Hautfarbe',
    '🙍🏽‍♀' => 'missmutige Frau: mittlere Hautfarbe',
    '🙍🏾‍♀' => 'missmutige Frau: mitteldunkle Hautfarbe',
    '🙍🏿‍♀' => 'missmutige Frau: dunkle Hautfarbe',
    '🙎🏻‍♂' => 'schmollender Mann: helle Hautfarbe',
    '🙎🏼‍♂' => 'schmollender Mann: mittelhelle Hautfarbe',
    '🙎🏽‍♂' => 'schmollender Mann: mittlere Hautfarbe',
    '🙎🏾‍♂' => 'schmollender Mann: mitteldunkle Hautfarbe',
    '🙎🏿‍♂' => 'schmollender Mann: dunkle Hautfarbe',
    '🙎🏻‍♀' => 'schmollende Frau: helle Hautfarbe',
    '🙎🏼‍♀' => 'schmollende Frau: mittelhelle Hautfarbe',
    '🙎🏽‍♀' => 'schmollende Frau: mittlere Hautfarbe',
    '🙎🏾‍♀' => 'schmollende Frau: mitteldunkle Hautfarbe',
    '🙎🏿‍♀' => 'schmollende Frau: dunkle Hautfarbe',
    '🙅🏻‍♂' => 'Mann mit überkreuzten Armen: helle Hautfarbe',
    '🙅🏼‍♂' => 'Mann mit überkreuzten Armen: mittelhelle Hautfarbe',
    '🙅🏽‍♂' => 'Mann mit überkreuzten Armen: mittlere Hautfarbe',
    '🙅🏾‍♂' => 'Mann mit überkreuzten Armen: mitteldunkle Hautfarbe',
    '🙅🏿‍♂' => 'Mann mit überkreuzten Armen: dunkle Hautfarbe',
    '🙅🏻‍♀' => 'Frau mit überkreuzten Armen: helle Hautfarbe',
    '🙅🏼‍♀' => 'Frau mit überkreuzten Armen: mittelhelle Hautfarbe',
    '🙅🏽‍♀' => 'Frau mit überkreuzten Armen: mittlere Hautfarbe',
    '🙅🏾‍♀' => 'Frau mit überkreuzten Armen: mitteldunkle Hautfarbe',
    '🙅🏿‍♀' => 'Frau mit überkreuzten Armen: dunkle Hautfarbe',
    '🙆🏻‍♂' => 'Mann mit Händen auf dem Kopf: helle Hautfarbe',
    '🙆🏼‍♂' => 'Mann mit Händen auf dem Kopf: mittelhelle Hautfarbe',
    '🙆🏽‍♂' => 'Mann mit Händen auf dem Kopf: mittlere Hautfarbe',
    '🙆🏾‍♂' => 'Mann mit Händen auf dem Kopf: mitteldunkle Hautfarbe',
    '🙆🏿‍♂' => 'Mann mit Händen auf dem Kopf: dunkle Hautfarbe',
    '🙆🏻‍♀' => 'Frau mit Händen auf dem Kopf: helle Hautfarbe',
    '🙆🏼‍♀' => 'Frau mit Händen auf dem Kopf: mittelhelle Hautfarbe',
    '🙆🏽‍♀' => 'Frau mit Händen auf dem Kopf: mittlere Hautfarbe',
    '🙆🏾‍♀' => 'Frau mit Händen auf dem Kopf: mitteldunkle Hautfarbe',
    '🙆🏿‍♀' => 'Frau mit Händen auf dem Kopf: dunkle Hautfarbe',
    '💁🏻‍♂' => 'Infoschalter-Mitarbeiter: helle Hautfarbe',
    '💁🏼‍♂' => 'Infoschalter-Mitarbeiter: mittelhelle Hautfarbe',
    '💁🏽‍♂' => 'Infoschalter-Mitarbeiter: mittlere Hautfarbe',
    '💁🏾‍♂' => 'Infoschalter-Mitarbeiter: mitteldunkle Hautfarbe',
    '💁🏿‍♂' => 'Infoschalter-Mitarbeiter: dunkle Hautfarbe',
    '💁🏻‍♀' => 'Infoschalter-Mitarbeiterin: helle Hautfarbe',
    '💁🏼‍♀' => 'Infoschalter-Mitarbeiterin: mittelhelle Hautfarbe',
    '💁🏽‍♀' => 'Infoschalter-Mitarbeiterin: mittlere Hautfarbe',
    '💁🏾‍♀' => 'Infoschalter-Mitarbeiterin: mitteldunkle Hautfarbe',
    '💁🏿‍♀' => 'Infoschalter-Mitarbeiterin: dunkle Hautfarbe',
    '🙋🏻‍♂' => 'Mann mit erhobenem Arm: helle Hautfarbe',
    '🙋🏼‍♂' => 'Mann mit erhobenem Arm: mittelhelle Hautfarbe',
    '🙋🏽‍♂' => 'Mann mit erhobenem Arm: mittlere Hautfarbe',
    '🙋🏾‍♂' => 'Mann mit erhobenem Arm: mitteldunkle Hautfarbe',
    '🙋🏿‍♂' => 'Mann mit erhobenem Arm: dunkle Hautfarbe',
    '🙋🏻‍♀' => 'Frau mit erhobenem Arm: helle Hautfarbe',
    '🙋🏼‍♀' => 'Frau mit erhobenem Arm: mittelhelle Hautfarbe',
    '🙋🏽‍♀' => 'Frau mit erhobenem Arm: mittlere Hautfarbe',
    '🙋🏾‍♀' => 'Frau mit erhobenem Arm: mitteldunkle Hautfarbe',
    '🙋🏿‍♀' => 'Frau mit erhobenem Arm: dunkle Hautfarbe',
    '🧏🏻‍♂' => 'gehörloser Mann: helle Hautfarbe',
    '🧏🏼‍♂' => 'gehörloser Mann: mittelhelle Hautfarbe',
    '🧏🏽‍♂' => 'gehörloser Mann: mittlere Hautfarbe',
    '🧏🏾‍♂' => 'gehörloser Mann: mitteldunkle Hautfarbe',
    '🧏🏿‍♂' => 'gehörloser Mann: dunkle Hautfarbe',
    '🧏🏻‍♀' => 'gehörlose Frau: helle Hautfarbe',
    '🧏🏼‍♀' => 'gehörlose Frau: mittelhelle Hautfarbe',
    '🧏🏽‍♀' => 'gehörlose Frau: mittlere Hautfarbe',
    '🧏🏾‍♀' => 'gehörlose Frau: mitteldunkle Hautfarbe',
    '🧏🏿‍♀' => 'gehörlose Frau: dunkle Hautfarbe',
    '🙇🏻‍♂' => 'sich verbeugender Mann: helle Hautfarbe',
    '🙇🏼‍♂' => 'sich verbeugender Mann: mittelhelle Hautfarbe',
    '🙇🏽‍♂' => 'sich verbeugender Mann: mittlere Hautfarbe',
    '🙇🏾‍♂' => 'sich verbeugender Mann: mitteldunkle Hautfarbe',
    '🙇🏿‍♂' => 'sich verbeugender Mann: dunkle Hautfarbe',
    '🙇🏻‍♀' => 'sich verbeugende Frau: helle Hautfarbe',
    '🙇🏼‍♀' => 'sich verbeugende Frau: mittelhelle Hautfarbe',
    '🙇🏽‍♀' => 'sich verbeugende Frau: mittlere Hautfarbe',
    '🙇🏾‍♀' => 'sich verbeugende Frau: mitteldunkle Hautfarbe',
    '🙇🏿‍♀' => 'sich verbeugende Frau: dunkle Hautfarbe',
    '🤦🏻‍♂' => 'sich an den Kopf fassender Mann: helle Hautfarbe',
    '🤦🏼‍♂' => 'sich an den Kopf fassender Mann: mittelhelle Hautfarbe',
    '🤦🏽‍♂' => 'sich an den Kopf fassender Mann: mittlere Hautfarbe',
    '🤦🏾‍♂' => 'sich an den Kopf fassender Mann: mitteldunkle Hautfarbe',
    '🤦🏿‍♂' => 'sich an den Kopf fassender Mann: dunkle Hautfarbe',
    '🤦🏻‍♀' => 'sich an den Kopf fassende Frau: helle Hautfarbe',
    '🤦🏼‍♀' => 'sich an den Kopf fassende Frau: mittelhelle Hautfarbe',
    '🤦🏽‍♀' => 'sich an den Kopf fassende Frau: mittlere Hautfarbe',
    '🤦🏾‍♀' => 'sich an den Kopf fassende Frau: mitteldunkle Hautfarbe',
    '🤦🏿‍♀' => 'sich an den Kopf fassende Frau: dunkle Hautfarbe',
    '🤷🏻‍♂' => 'schulterzuckender Mann: helle Hautfarbe',
    '🤷🏼‍♂' => 'schulterzuckender Mann: mittelhelle Hautfarbe',
    '🤷🏽‍♂' => 'schulterzuckender Mann: mittlere Hautfarbe',
    '🤷🏾‍♂' => 'schulterzuckender Mann: mitteldunkle Hautfarbe',
    '🤷🏿‍♂' => 'schulterzuckender Mann: dunkle Hautfarbe',
    '🤷🏻‍♀' => 'schulterzuckende Frau: helle Hautfarbe',
    '🤷🏼‍♀' => 'schulterzuckende Frau: mittelhelle Hautfarbe',
    '🤷🏽‍♀' => 'schulterzuckende Frau: mittlere Hautfarbe',
    '🤷🏾‍♀' => 'schulterzuckende Frau: mitteldunkle Hautfarbe',
    '🤷🏿‍♀' => 'schulterzuckende Frau: dunkle Hautfarbe',
    '🧑🏻‍⚕' => 'Arzt/Ärztin: helle Hautfarbe',
    '🧑🏼‍⚕' => 'Arzt/Ärztin: mittelhelle Hautfarbe',
    '🧑🏽‍⚕' => 'Arzt/Ärztin: mittlere Hautfarbe',
    '🧑🏾‍⚕' => 'Arzt/Ärztin: mitteldunkle Hautfarbe',
    '🧑🏿‍⚕' => 'Arzt/Ärztin: dunkle Hautfarbe',
    '👨🏻‍⚕' => 'Arzt: helle Hautfarbe',
    '👨🏼‍⚕' => 'Arzt: mittelhelle Hautfarbe',
    '👨🏽‍⚕' => 'Arzt: mittlere Hautfarbe',
    '👨🏾‍⚕' => 'Arzt: mitteldunkle Hautfarbe',
    '👨🏿‍⚕' => 'Arzt: dunkle Hautfarbe',
    '👩🏻‍⚕' => 'Ärztin: helle Hautfarbe',
    '👩🏼‍⚕' => 'Ärztin: mittelhelle Hautfarbe',
    '👩🏽‍⚕' => 'Ärztin: mittlere Hautfarbe',
    '👩🏾‍⚕' => 'Ärztin: mitteldunkle Hautfarbe',
    '👩🏿‍⚕' => 'Ärztin: dunkle Hautfarbe',
    '🧑🏻‍🎓' => 'Student(in): helle Hautfarbe',
    '🧑🏼‍🎓' => 'Student(in): mittelhelle Hautfarbe',
    '🧑🏽‍🎓' => 'Student(in): mittlere Hautfarbe',
    '🧑🏾‍🎓' => 'Student(in): mitteldunkle Hautfarbe',
    '🧑🏿‍🎓' => 'Student(in): dunkle Hautfarbe',
    '👨🏻‍🎓' => 'Student: helle Hautfarbe',
    '👨🏼‍🎓' => 'Student: mittelhelle Hautfarbe',
    '👨🏽‍🎓' => 'Student: mittlere Hautfarbe',
    '👨🏾‍🎓' => 'Student: mitteldunkle Hautfarbe',
    '👨🏿‍🎓' => 'Student: dunkle Hautfarbe',
    '👩🏻‍🎓' => 'Studentin: helle Hautfarbe',
    '👩🏼‍🎓' => 'Studentin: mittelhelle Hautfarbe',
    '👩🏽‍🎓' => 'Studentin: mittlere Hautfarbe',
    '👩🏾‍🎓' => 'Studentin: mitteldunkle Hautfarbe',
    '👩🏿‍🎓' => 'Studentin: dunkle Hautfarbe',
    '🧑🏻‍🏫' => 'Lehrer(in): helle Hautfarbe',
    '🧑🏼‍🏫' => 'Lehrer(in): mittelhelle Hautfarbe',
    '🧑🏽‍🏫' => 'Lehrer(in): mittlere Hautfarbe',
    '🧑🏾‍🏫' => 'Lehrer(in): mitteldunkle Hautfarbe',
    '🧑🏿‍🏫' => 'Lehrer(in): dunkle Hautfarbe',
    '👨🏻‍🏫' => 'Lehrer: helle Hautfarbe',
    '👨🏼‍🏫' => 'Lehrer: mittelhelle Hautfarbe',
    '👨🏽‍🏫' => 'Lehrer: mittlere Hautfarbe',
    '👨🏾‍🏫' => 'Lehrer: mitteldunkle Hautfarbe',
    '👨🏿‍🏫' => 'Lehrer: dunkle Hautfarbe',
    '👩🏻‍🏫' => 'Lehrerin: helle Hautfarbe',
    '👩🏼‍🏫' => 'Lehrerin: mittelhelle Hautfarbe',
    '👩🏽‍🏫' => 'Lehrerin: mittlere Hautfarbe',
    '👩🏾‍🏫' => 'Lehrerin: mitteldunkle Hautfarbe',
    '👩🏿‍🏫' => 'Lehrerin: dunkle Hautfarbe',
    '🧑🏻‍⚖' => 'Richter(in): helle Hautfarbe',
    '🧑🏼‍⚖' => 'Richter(in): mittelhelle Hautfarbe',
    '🧑🏽‍⚖' => 'Richter(in): mittlere Hautfarbe',
    '🧑🏾‍⚖' => 'Richter(in): mitteldunkle Hautfarbe',
    '🧑🏿‍⚖' => 'Richter(in): dunkle Hautfarbe',
    '👨🏻‍⚖' => 'Richter: helle Hautfarbe',
    '👨🏼‍⚖' => 'Richter: mittelhelle Hautfarbe',
    '👨🏽‍⚖' => 'Richter: mittlere Hautfarbe',
    '👨🏾‍⚖' => 'Richter: mitteldunkle Hautfarbe',
    '👨🏿‍⚖' => 'Richter: dunkle Hautfarbe',
    '👩🏻‍⚖' => 'Richterin: helle Hautfarbe',
    '👩🏼‍⚖' => 'Richterin: mittelhelle Hautfarbe',
    '👩🏽‍⚖' => 'Richterin: mittlere Hautfarbe',
    '👩🏾‍⚖' => 'Richterin: mitteldunkle Hautfarbe',
    '👩🏿‍⚖' => 'Richterin: dunkle Hautfarbe',
    '🧑🏻‍🌾' => 'Bauer/Bäuerin: helle Hautfarbe',
    '🧑🏼‍🌾' => 'Bauer/Bäuerin: mittelhelle Hautfarbe',
    '🧑🏽‍🌾' => 'Bauer/Bäuerin: mittlere Hautfarbe',
    '🧑🏾‍🌾' => 'Bauer/Bäuerin: mitteldunkle Hautfarbe',
    '🧑🏿‍🌾' => 'Bauer/Bäuerin: dunkle Hautfarbe',
    '👨🏻‍🌾' => 'Bauer: helle Hautfarbe',
    '👨🏼‍🌾' => 'Bauer: mittelhelle Hautfarbe',
    '👨🏽‍🌾' => 'Bauer: mittlere Hautfarbe',
    '👨🏾‍🌾' => 'Bauer: mitteldunkle Hautfarbe',
    '👨🏿‍🌾' => 'Bauer: dunkle Hautfarbe',
    '👩🏻‍🌾' => 'Bäuerin: helle Hautfarbe',
    '👩🏼‍🌾' => 'Bäuerin: mittelhelle Hautfarbe',
    '👩🏽‍🌾' => 'Bäuerin: mittlere Hautfarbe',
    '👩🏾‍🌾' => 'Bäuerin: mitteldunkle Hautfarbe',
    '👩🏿‍🌾' => 'Bäuerin: dunkle Hautfarbe',
    '🧑🏻‍🍳' => 'Koch/Köchin: helle Hautfarbe',
    '🧑🏼‍🍳' => 'Koch/Köchin: mittelhelle Hautfarbe',
    '🧑🏽‍🍳' => 'Koch/Köchin: mittlere Hautfarbe',
    '🧑🏾‍🍳' => 'Koch/Köchin: mitteldunkle Hautfarbe',
    '🧑🏿‍🍳' => 'Koch/Köchin: dunkle Hautfarbe',
    '👨🏻‍🍳' => 'Koch: helle Hautfarbe',
    '👨🏼‍🍳' => 'Koch: mittelhelle Hautfarbe',
    '👨🏽‍🍳' => 'Koch: mittlere Hautfarbe',
    '👨🏾‍🍳' => 'Koch: mitteldunkle Hautfarbe',
    '👨🏿‍🍳' => 'Koch: dunkle Hautfarbe',
    '👩🏻‍🍳' => 'Köchin: helle Hautfarbe',
    '👩🏼‍🍳' => 'Köchin: mittelhelle Hautfarbe',
    '👩🏽‍🍳' => 'Köchin: mittlere Hautfarbe',
    '👩🏾‍🍳' => 'Köchin: mitteldunkle Hautfarbe',
    '👩🏿‍🍳' => 'Köchin: dunkle Hautfarbe',
    '🧑🏻‍🔧' => 'Mechaniker(in): helle Hautfarbe',
    '🧑🏼‍🔧' => 'Mechaniker(in): mittelhelle Hautfarbe',
    '🧑🏽‍🔧' => 'Mechaniker(in): mittlere Hautfarbe',
    '🧑🏾‍🔧' => 'Mechaniker(in): mitteldunkle Hautfarbe',
    '🧑🏿‍🔧' => 'Mechaniker(in): dunkle Hautfarbe',
    '👨🏻‍🔧' => 'Mechaniker: helle Hautfarbe',
    '👨🏼‍🔧' => 'Mechaniker: mittelhelle Hautfarbe',
    '👨🏽‍🔧' => 'Mechaniker: mittlere Hautfarbe',
    '👨🏾‍🔧' => 'Mechaniker: mitteldunkle Hautfarbe',
    '👨🏿‍🔧' => 'Mechaniker: dunkle Hautfarbe',
    '👩🏻‍🔧' => 'Mechanikerin: helle Hautfarbe',
    '👩🏼‍🔧' => 'Mechanikerin: mittelhelle Hautfarbe',
    '👩🏽‍🔧' => 'Mechanikerin: mittlere Hautfarbe',
    '👩🏾‍🔧' => 'Mechanikerin: mitteldunkle Hautfarbe',
    '👩🏿‍🔧' => 'Mechanikerin: dunkle Hautfarbe',
    '🧑🏻‍🏭' => 'Fabrikarbeiter(in): helle Hautfarbe',
    '🧑🏼‍🏭' => 'Fabrikarbeiter(in): mittelhelle Hautfarbe',
    '🧑🏽‍🏭' => 'Fabrikarbeiter(in): mittlere Hautfarbe',
    '🧑🏾‍🏭' => 'Fabrikarbeiter(in): mitteldunkle Hautfarbe',
    '🧑🏿‍🏭' => 'Fabrikarbeiter(in): dunkle Hautfarbe',
    '👨🏻‍🏭' => 'Fabrikarbeiter: helle Hautfarbe',
    '👨🏼‍🏭' => 'Fabrikarbeiter: mittelhelle Hautfarbe',
    '👨🏽‍🏭' => 'Fabrikarbeiter: mittlere Hautfarbe',
    '👨🏾‍🏭' => 'Fabrikarbeiter: mitteldunkle Hautfarbe',
    '👨🏿‍🏭' => 'Fabrikarbeiter: dunkle Hautfarbe',
    '👩🏻‍🏭' => 'Fabrikarbeiterin: helle Hautfarbe',
    '👩🏼‍🏭' => 'Fabrikarbeiterin: mittelhelle Hautfarbe',
    '👩🏽‍🏭' => 'Fabrikarbeiterin: mittlere Hautfarbe',
    '👩🏾‍🏭' => 'Fabrikarbeiterin: mitteldunkle Hautfarbe',
    '👩🏿‍🏭' => 'Fabrikarbeiterin: dunkle Hautfarbe',
    '🧑🏻‍💼' => 'Büroangestellte(r): helle Hautfarbe',
    '🧑🏼‍💼' => 'Büroangestellte(r): mittelhelle Hautfarbe',
    '🧑🏽‍💼' => 'Büroangestellte(r): mittlere Hautfarbe',
    '🧑🏾‍💼' => 'Büroangestellte(r): mitteldunkle Hautfarbe',
    '🧑🏿‍💼' => 'Büroangestellte(r): dunkle Hautfarbe',
    '👨🏻‍💼' => 'Büroangestellter: helle Hautfarbe',
    '👨🏼‍💼' => 'Büroangestellter: mittelhelle Hautfarbe',
    '👨🏽‍💼' => 'Büroangestellter: mittlere Hautfarbe',
    '👨🏾‍💼' => 'Büroangestellter: mitteldunkle Hautfarbe',
    '👨🏿‍💼' => 'Büroangestellter: dunkle Hautfarbe',
    '👩🏻‍💼' => 'Büroangestellte: helle Hautfarbe',
    '👩🏼‍💼' => 'Büroangestellte: mittelhelle Hautfarbe',
    '👩🏽‍💼' => 'Büroangestellte: mittlere Hautfarbe',
    '👩🏾‍💼' => 'Büroangestellte: mitteldunkle Hautfarbe',
    '👩🏿‍💼' => 'Büroangestellte: dunkle Hautfarbe',
    '🧑🏻‍🔬' => 'Wissenschaftler(in): helle Hautfarbe',
    '🧑🏼‍🔬' => 'Wissenschaftler(in): mittelhelle Hautfarbe',
    '🧑🏽‍🔬' => 'Wissenschaftler(in): mittlere Hautfarbe',
    '🧑🏾‍🔬' => 'Wissenschaftler(in): mitteldunkle Hautfarbe',
    '🧑🏿‍🔬' => 'Wissenschaftler(in): dunkle Hautfarbe',
    '👨🏻‍🔬' => 'Wissenschaftler: helle Hautfarbe',
    '👨🏼‍🔬' => 'Wissenschaftler: mittelhelle Hautfarbe',
    '👨🏽‍🔬' => 'Wissenschaftler: mittlere Hautfarbe',
    '👨🏾‍🔬' => 'Wissenschaftler: mitteldunkle Hautfarbe',
    '👨🏿‍🔬' => 'Wissenschaftler: dunkle Hautfarbe',
    '👩🏻‍🔬' => 'Wissenschaftlerin: helle Hautfarbe',
    '👩🏼‍🔬' => 'Wissenschaftlerin: mittelhelle Hautfarbe',
    '👩🏽‍🔬' => 'Wissenschaftlerin: mittlere Hautfarbe',
    '👩🏾‍🔬' => 'Wissenschaftlerin: mitteldunkle Hautfarbe',
    '👩🏿‍🔬' => 'Wissenschaftlerin: dunkle Hautfarbe',
    '🧑🏻‍💻' => 'IT-Experte/IT-Expertin: helle Hautfarbe',
    '🧑🏼‍💻' => 'IT-Experte/IT-Expertin: mittelhelle Hautfarbe',
    '🧑🏽‍💻' => 'IT-Experte/IT-Expertin: mittlere Hautfarbe',
    '🧑🏾‍💻' => 'IT-Experte/IT-Expertin: mitteldunkle Hautfarbe',
    '🧑🏿‍💻' => 'IT-Experte/IT-Expertin: dunkle Hautfarbe',
    '👨🏻‍💻' => 'IT-Experte: helle Hautfarbe',
    '👨🏼‍💻' => 'IT-Experte: mittelhelle Hautfarbe',
    '👨🏽‍💻' => 'IT-Experte: mittlere Hautfarbe',
    '👨🏾‍💻' => 'IT-Experte: mitteldunkle Hautfarbe',
    '👨🏿‍💻' => 'IT-Experte: dunkle Hautfarbe',
    '👩🏻‍💻' => 'IT-Expertin: helle Hautfarbe',
    '👩🏼‍💻' => 'IT-Expertin: mittelhelle Hautfarbe',
    '👩🏽‍💻' => 'IT-Expertin: mittlere Hautfarbe',
    '👩🏾‍💻' => 'IT-Expertin: mitteldunkle Hautfarbe',
    '👩🏿‍💻' => 'IT-Expertin: dunkle Hautfarbe',
    '🧑🏻‍🎤' => 'Sänger(in): helle Hautfarbe',
    '🧑🏼‍🎤' => 'Sänger(in): mittelhelle Hautfarbe',
    '🧑🏽‍🎤' => 'Sänger(in): mittlere Hautfarbe',
    '🧑🏾‍🎤' => 'Sänger(in): mitteldunkle Hautfarbe',
    '🧑🏿‍🎤' => 'Sänger(in): dunkle Hautfarbe',
    '👨🏻‍🎤' => 'Sänger: helle Hautfarbe',
    '👨🏼‍🎤' => 'Sänger: mittelhelle Hautfarbe',
    '👨🏽‍🎤' => 'Sänger: mittlere Hautfarbe',
    '👨🏾‍🎤' => 'Sänger: mitteldunkle Hautfarbe',
    '👨🏿‍🎤' => 'Sänger: dunkle Hautfarbe',
    '👩🏻‍🎤' => 'Sängerin: helle Hautfarbe',
    '👩🏼‍🎤' => 'Sängerin: mittelhelle Hautfarbe',
    '👩🏽‍🎤' => 'Sängerin: mittlere Hautfarbe',
    '👩🏾‍🎤' => 'Sängerin: mitteldunkle Hautfarbe',
    '👩🏿‍🎤' => 'Sängerin: dunkle Hautfarbe',
    '🧑🏻‍🎨' => 'Künstler(in): helle Hautfarbe',
    '🧑🏼‍🎨' => 'Künstler(in): mittelhelle Hautfarbe',
    '🧑🏽‍🎨' => 'Künstler(in): mittlere Hautfarbe',
    '🧑🏾‍🎨' => 'Künstler(in): mitteldunkle Hautfarbe',
    '🧑🏿‍🎨' => 'Künstler(in): dunkle Hautfarbe',
    '👨🏻‍🎨' => 'Künstler: helle Hautfarbe',
    '👨🏼‍🎨' => 'Künstler: mittelhelle Hautfarbe',
    '👨🏽‍🎨' => 'Künstler: mittlere Hautfarbe',
    '👨🏾‍🎨' => 'Künstler: mitteldunkle Hautfarbe',
    '👨🏿‍🎨' => 'Künstler: dunkle Hautfarbe',
    '👩🏻‍🎨' => 'Künstlerin: helle Hautfarbe',
    '👩🏼‍🎨' => 'Künstlerin: mittelhelle Hautfarbe',
    '👩🏽‍🎨' => 'Künstlerin: mittlere Hautfarbe',
    '👩🏾‍🎨' => 'Künstlerin: mitteldunkle Hautfarbe',
    '👩🏿‍🎨' => 'Künstlerin: dunkle Hautfarbe',
    '🧑🏻‍✈' => 'Pilot(in): helle Hautfarbe',
    '🧑🏼‍✈' => 'Pilot(in): mittelhelle Hautfarbe',
    '🧑🏽‍✈' => 'Pilot(in): mittlere Hautfarbe',
    '🧑🏾‍✈' => 'Pilot(in): mitteldunkle Hautfarbe',
    '🧑🏿‍✈' => 'Pilot(in): dunkle Hautfarbe',
    '👨🏻‍✈' => 'Pilot: helle Hautfarbe',
    '👨🏼‍✈' => 'Pilot: mittelhelle Hautfarbe',
    '👨🏽‍✈' => 'Pilot: mittlere Hautfarbe',
    '👨🏾‍✈' => 'Pilot: mitteldunkle Hautfarbe',
    '👨🏿‍✈' => 'Pilot: dunkle Hautfarbe',
    '👩🏻‍✈' => 'Pilotin: helle Hautfarbe',
    '👩🏼‍✈' => 'Pilotin: mittelhelle Hautfarbe',
    '👩🏽‍✈' => 'Pilotin: mittlere Hautfarbe',
    '👩🏾‍✈' => 'Pilotin: mitteldunkle Hautfarbe',
    '👩🏿‍✈' => 'Pilotin: dunkle Hautfarbe',
    '🧑🏻‍🚀' => 'Astronaut(in): helle Hautfarbe',
    '🧑🏼‍🚀' => 'Astronaut(in): mittelhelle Hautfarbe',
    '🧑🏽‍🚀' => 'Astronaut(in): mittlere Hautfarbe',
    '🧑🏾‍🚀' => 'Astronaut(in): mitteldunkle Hautfarbe',
    '🧑🏿‍🚀' => 'Astronaut(in): dunkle Hautfarbe',
    '👨🏻‍🚀' => 'Astronaut: helle Hautfarbe',
    '👨🏼‍🚀' => 'Astronaut: mittelhelle Hautfarbe',
    '👨🏽‍🚀' => 'Astronaut: mittlere Hautfarbe',
    '👨🏾‍🚀' => 'Astronaut: mitteldunkle Hautfarbe',
    '👨🏿‍🚀' => 'Astronaut: dunkle Hautfarbe',
    '👩🏻‍🚀' => 'Astronautin: helle Hautfarbe',
    '👩🏼‍🚀' => 'Astronautin: mittelhelle Hautfarbe',
    '👩🏽‍🚀' => 'Astronautin: mittlere Hautfarbe',
    '👩🏾‍🚀' => 'Astronautin: mitteldunkle Hautfarbe',
    '👩🏿‍🚀' => 'Astronautin: dunkle Hautfarbe',
    '🧑🏻‍🚒' => 'Feuerwehrmann/-frau: helle Hautfarbe',
    '🧑🏼‍🚒' => 'Feuerwehrmann/-frau: mittelhelle Hautfarbe',
    '🧑🏽‍🚒' => 'Feuerwehrmann/-frau: mittlere Hautfarbe',
    '🧑🏾‍🚒' => 'Feuerwehrmann/-frau: mitteldunkle Hautfarbe',
    '🧑🏿‍🚒' => 'Feuerwehrmann/-frau: dunkle Hautfarbe',
    '👨🏻‍🚒' => 'Feuerwehrmann: helle Hautfarbe',
    '👨🏼‍🚒' => 'Feuerwehrmann: mittelhelle Hautfarbe',
    '👨🏽‍🚒' => 'Feuerwehrmann: mittlere Hautfarbe',
    '👨🏾‍🚒' => 'Feuerwehrmann: mitteldunkle Hautfarbe',
    '👨🏿‍🚒' => 'Feuerwehrmann: dunkle Hautfarbe',
    '👩🏻‍🚒' => 'Feuerwehrfrau: helle Hautfarbe',
    '👩🏼‍🚒' => 'Feuerwehrfrau: mittelhelle Hautfarbe',
    '👩🏽‍🚒' => 'Feuerwehrfrau: mittlere Hautfarbe',
    '👩🏾‍🚒' => 'Feuerwehrfrau: mitteldunkle Hautfarbe',
    '👩🏿‍🚒' => 'Feuerwehrfrau: dunkle Hautfarbe',
    '👮🏻‍♂' => 'Polizist: helle Hautfarbe',
    '👮🏼‍♂' => 'Polizist: mittelhelle Hautfarbe',
    '👮🏽‍♂' => 'Polizist: mittlere Hautfarbe',
    '👮🏾‍♂' => 'Polizist: mitteldunkle Hautfarbe',
    '👮🏿‍♂' => 'Polizist: dunkle Hautfarbe',
    '👮🏻‍♀' => 'Polizistin: helle Hautfarbe',
    '👮🏼‍♀' => 'Polizistin: mittelhelle Hautfarbe',
    '👮🏽‍♀' => 'Polizistin: mittlere Hautfarbe',
    '👮🏾‍♀' => 'Polizistin: mitteldunkle Hautfarbe',
    '👮🏿‍♀' => 'Polizistin: dunkle Hautfarbe',
    '🕵🏻‍♂' => 'Detektiv: helle Hautfarbe',
    '🕵🏼‍♂' => 'Detektiv: mittelhelle Hautfarbe',
    '🕵🏽‍♂' => 'Detektiv: mittlere Hautfarbe',
    '🕵🏾‍♂' => 'Detektiv: mitteldunkle Hautfarbe',
    '🕵🏿‍♂' => 'Detektiv: dunkle Hautfarbe',
    '🕵🏻‍♀' => 'Detektivin: helle Hautfarbe',
    '🕵🏼‍♀' => 'Detektivin: mittelhelle Hautfarbe',
    '🕵🏽‍♀' => 'Detektivin: mittlere Hautfarbe',
    '🕵🏾‍♀' => 'Detektivin: mitteldunkle Hautfarbe',
    '🕵🏿‍♀' => 'Detektivin: dunkle Hautfarbe',
    '💂🏻‍♂' => 'Wachsoldat: helle Hautfarbe',
    '💂🏼‍♂' => 'Wachsoldat: mittelhelle Hautfarbe',
    '💂🏽‍♂' => 'Wachsoldat: mittlere Hautfarbe',
    '💂🏾‍♂' => 'Wachsoldat: mitteldunkle Hautfarbe',
    '💂🏿‍♂' => 'Wachsoldat: dunkle Hautfarbe',
    '💂🏻‍♀' => 'Wachsoldatin: helle Hautfarbe',
    '💂🏼‍♀' => 'Wachsoldatin: mittelhelle Hautfarbe',
    '💂🏽‍♀' => 'Wachsoldatin: mittlere Hautfarbe',
    '💂🏾‍♀' => 'Wachsoldatin: mitteldunkle Hautfarbe',
    '💂🏿‍♀' => 'Wachsoldatin: dunkle Hautfarbe',
    '👷🏻‍♂' => 'Bauarbeiter: helle Hautfarbe',
    '👷🏼‍♂' => 'Bauarbeiter: mittelhelle Hautfarbe',
    '👷🏽‍♂' => 'Bauarbeiter: mittlere Hautfarbe',
    '👷🏾‍♂' => 'Bauarbeiter: mitteldunkle Hautfarbe',
    '👷🏿‍♂' => 'Bauarbeiter: dunkle Hautfarbe',
    '👷🏻‍♀' => 'Bauarbeiterin: helle Hautfarbe',
    '👷🏼‍♀' => 'Bauarbeiterin: mittelhelle Hautfarbe',
    '👷🏽‍♀' => 'Bauarbeiterin: mittlere Hautfarbe',
    '👷🏾‍♀' => 'Bauarbeiterin: mitteldunkle Hautfarbe',
    '👷🏿‍♀' => 'Bauarbeiterin: dunkle Hautfarbe',
    '👳🏻‍♂' => 'Mann mit Turban: helle Hautfarbe',
    '👳🏼‍♂' => 'Mann mit Turban: mittelhelle Hautfarbe',
    '👳🏽‍♂' => 'Mann mit Turban: mittlere Hautfarbe',
    '👳🏾‍♂' => 'Mann mit Turban: mitteldunkle Hautfarbe',
    '👳🏿‍♂' => 'Mann mit Turban: dunkle Hautfarbe',
    '👳🏻‍♀' => 'Frau mit Turban: helle Hautfarbe',
    '👳🏼‍♀' => 'Frau mit Turban: mittelhelle Hautfarbe',
    '👳🏽‍♀' => 'Frau mit Turban: mittlere Hautfarbe',
    '👳🏾‍♀' => 'Frau mit Turban: mitteldunkle Hautfarbe',
    '👳🏿‍♀' => 'Frau mit Turban: dunkle Hautfarbe',
    '🤵🏻‍♂' => 'Mann im Smoking: helle Hautfarbe',
    '🤵🏼‍♂' => 'Mann im Smoking: mittelhelle Hautfarbe',
    '🤵🏽‍♂' => 'Mann im Smoking: mittlere Hautfarbe',
    '🤵🏾‍♂' => 'Mann im Smoking: mitteldunkle Hautfarbe',
    '🤵🏿‍♂' => 'Mann im Smoking: dunkle Hautfarbe',
    '🤵🏻‍♀' => 'Frau im Smoking: helle Hautfarbe',
    '🤵🏼‍♀' => 'Frau im Smoking: mittelhelle Hautfarbe',
    '🤵🏽‍♀' => 'Frau im Smoking: mittlere Hautfarbe',
    '🤵🏾‍♀' => 'Frau im Smoking: mitteldunkle Hautfarbe',
    '🤵🏿‍♀' => 'Frau im Smoking: dunkle Hautfarbe',
    '👰🏻‍♂' => 'Mann mit Schleier: helle Hautfarbe',
    '👰🏼‍♂' => 'Mann mit Schleier: mittelhelle Hautfarbe',
    '👰🏽‍♂' => 'Mann mit Schleier: mittlere Hautfarbe',
    '👰🏾‍♂' => 'Mann mit Schleier: mitteldunkle Hautfarbe',
    '👰🏿‍♂' => 'Mann mit Schleier: dunkle Hautfarbe',
    '👰🏻‍♀' => 'Frau mit Schleier: helle Hautfarbe',
    '👰🏼‍♀' => 'Frau mit Schleier: mittelhelle Hautfarbe',
    '👰🏽‍♀' => 'Frau mit Schleier: mittlere Hautfarbe',
    '👰🏾‍♀' => 'Frau mit Schleier: mitteldunkle Hautfarbe',
    '👰🏿‍♀' => 'Frau mit Schleier: dunkle Hautfarbe',
    '👩🏻‍🍼' => 'Frau, die Baby die Flasche gibt: helle Hautfarbe',
    '👩🏼‍🍼' => 'Frau, die Baby die Flasche gibt: mittelhelle Hautfarbe',
    '👩🏽‍🍼' => 'Frau, die Baby die Flasche gibt: mittlere Hautfarbe',
    '👩🏾‍🍼' => 'Frau, die Baby die Flasche gibt: mitteldunkle Hautfarbe',
    '👩🏿‍🍼' => 'Frau, die Baby die Flasche gibt: dunkle Hautfarbe',
    '👨🏻‍🍼' => 'Mann, der Baby die Flasche gibt: helle Hautfarbe',
    '👨🏼‍🍼' => 'Mann, der Baby die Flasche gibt: mittelhelle Hautfarbe',
    '👨🏽‍🍼' => 'Mann, der Baby die Flasche gibt: mittlere Hautfarbe',
    '👨🏾‍🍼' => 'Mann, der Baby die Flasche gibt: mitteldunkle Hautfarbe',
    '👨🏿‍🍼' => 'Mann, der Baby die Flasche gibt: dunkle Hautfarbe',
    '🧑🏻‍🍼' => 'Person, die Baby die Flasche gibt: helle Hautfarbe',
    '🧑🏼‍🍼' => 'Person, die Baby die Flasche gibt: mittelhelle Hautfarbe',
    '🧑🏽‍🍼' => 'Person, die Baby die Flasche gibt: mittlere Hautfarbe',
    '🧑🏾‍🍼' => 'Person, die Baby die Flasche gibt: mitteldunkle Hautfarbe',
    '🧑🏿‍🍼' => 'Person, die Baby die Flasche gibt: dunkle Hautfarbe',
    '🧑🏻‍🎄' => 'Weihnachtsperson: helle Hautfarbe',
    '🧑🏼‍🎄' => 'Weihnachtsperson: mittelhelle Hautfarbe',
    '🧑🏽‍🎄' => 'Weihnachtsperson: mittlere Hautfarbe',
    '🧑🏾‍🎄' => 'Weihnachtsperson: mitteldunkle Hautfarbe',
    '🧑🏿‍🎄' => 'Weihnachtsperson: dunkle Hautfarbe',
    '🦸🏻‍♂' => 'Superheld: helle Hautfarbe',
    '🦸🏼‍♂' => 'Superheld: mittelhelle Hautfarbe',
    '🦸🏽‍♂' => 'Superheld: mittlere Hautfarbe',
    '🦸🏾‍♂' => 'Superheld: mitteldunkle Hautfarbe',
    '🦸🏿‍♂' => 'Superheld: dunkle Hautfarbe',
    '🦸🏻‍♀' => 'Heldin: helle Hautfarbe',
    '🦸🏼‍♀' => 'Heldin: mittelhelle Hautfarbe',
    '🦸🏽‍♀' => 'Heldin: mittlere Hautfarbe',
    '🦸🏾‍♀' => 'Heldin: mitteldunkle Hautfarbe',
    '🦸🏿‍♀' => 'Heldin: dunkle Hautfarbe',
    '🦹🏻‍♂' => 'männlicher Bösewicht: helle Hautfarbe',
    '🦹🏼‍♂' => 'männlicher Bösewicht: mittelhelle Hautfarbe',
    '🦹🏽‍♂' => 'männlicher Bösewicht: mittlere Hautfarbe',
    '🦹🏾‍♂' => 'männlicher Bösewicht: mitteldunkle Hautfarbe',
    '🦹🏿‍♂' => 'männlicher Bösewicht: dunkle Hautfarbe',
    '🦹🏻‍♀' => 'weiblicher Bösewicht: helle Hautfarbe',
    '🦹🏼‍♀' => 'weiblicher Bösewicht: mittelhelle Hautfarbe',
    '🦹🏽‍♀' => 'weiblicher Bösewicht: mittlere Hautfarbe',
    '🦹🏾‍♀' => 'weiblicher Bösewicht: mitteldunkle Hautfarbe',
    '🦹🏿‍♀' => 'weiblicher Bösewicht: dunkle Hautfarbe',
    '🧙🏻‍♂' => 'Magier: helle Hautfarbe',
    '🧙🏼‍♂' => 'Magier: mittelhelle Hautfarbe',
    '🧙🏽‍♂' => 'Magier: mittlere Hautfarbe',
    '🧙🏾‍♂' => 'Magier: mitteldunkle Hautfarbe',
    '🧙🏿‍♂' => 'Magier: dunkle Hautfarbe',
    '🧙🏻‍♀' => 'Magierin: helle Hautfarbe',
    '🧙🏼‍♀' => 'Magierin: mittelhelle Hautfarbe',
    '🧙🏽‍♀' => 'Magierin: mittlere Hautfarbe',
    '🧙🏾‍♀' => 'Magierin: mitteldunkle Hautfarbe',
    '🧙🏿‍♀' => 'Magierin: dunkle Hautfarbe',
    '🧚🏻‍♂' => 'männliche Fee: helle Hautfarbe',
    '🧚🏼‍♂' => 'männliche Fee: mittelhelle Hautfarbe',
    '🧚🏽‍♂' => 'männliche Fee: mittlere Hautfarbe',
    '🧚🏾‍♂' => 'männliche Fee: mitteldunkle Hautfarbe',
    '🧚🏿‍♂' => 'männliche Fee: dunkle Hautfarbe',
    '🧚🏻‍♀' => 'Fee: helle Hautfarbe',
    '🧚🏼‍♀' => 'Fee: mittelhelle Hautfarbe',
    '🧚🏽‍♀' => 'Fee: mittlere Hautfarbe',
    '🧚🏾‍♀' => 'Fee: mitteldunkle Hautfarbe',
    '🧚🏿‍♀' => 'Fee: dunkle Hautfarbe',
    '🧛🏻‍♂' => 'männlicher Vampir: helle Hautfarbe',
    '🧛🏼‍♂' => 'männlicher Vampir: mittelhelle Hautfarbe',
    '🧛🏽‍♂' => 'männlicher Vampir: mittlere Hautfarbe',
    '🧛🏾‍♂' => 'männlicher Vampir: mitteldunkle Hautfarbe',
    '🧛🏿‍♂' => 'männlicher Vampir: dunkle Hautfarbe',
    '🧛🏻‍♀' => 'weiblicher Vampir: helle Hautfarbe',
    '🧛🏼‍♀' => 'weiblicher Vampir: mittelhelle Hautfarbe',
    '🧛🏽‍♀' => 'weiblicher Vampir: mittlere Hautfarbe',
    '🧛🏾‍♀' => 'weiblicher Vampir: mitteldunkle Hautfarbe',
    '🧛🏿‍♀' => 'weiblicher Vampir: dunkle Hautfarbe',
    '🧜🏻‍♂' => 'Wassermann: helle Hautfarbe',
    '🧜🏼‍♂' => 'Wassermann: mittelhelle Hautfarbe',
    '🧜🏽‍♂' => 'Wassermann: mittlere Hautfarbe',
    '🧜🏾‍♂' => 'Wassermann: mitteldunkle Hautfarbe',
    '🧜🏿‍♂' => 'Wassermann: dunkle Hautfarbe',
    '🧜🏻‍♀' => 'Meerjungfrau: helle Hautfarbe',
    '🧜🏼‍♀' => 'Meerjungfrau: mittelhelle Hautfarbe',
    '🧜🏽‍♀' => 'Meerjungfrau: mittlere Hautfarbe',
    '🧜🏾‍♀' => 'Meerjungfrau: mitteldunkle Hautfarbe',
    '🧜🏿‍♀' => 'Meerjungfrau: dunkle Hautfarbe',
    '🧝🏻‍♂' => 'Elf: helle Hautfarbe',
    '🧝🏼‍♂' => 'Elf: mittelhelle Hautfarbe',
    '🧝🏽‍♂' => 'Elf: mittlere Hautfarbe',
    '🧝🏾‍♂' => 'Elf: mitteldunkle Hautfarbe',
    '🧝🏿‍♂' => 'Elf: dunkle Hautfarbe',
    '🧝🏻‍♀' => 'Elfe: helle Hautfarbe',
    '🧝🏼‍♀' => 'Elfe: mittelhelle Hautfarbe',
    '🧝🏽‍♀' => 'Elfe: mittlere Hautfarbe',
    '🧝🏾‍♀' => 'Elfe: mitteldunkle Hautfarbe',
    '🧝🏿‍♀' => 'Elfe: dunkle Hautfarbe',
    '💆🏻‍♂' => 'Mann, der eine Kopfmassage bekommt: helle Hautfarbe',
    '💆🏼‍♂' => 'Mann, der eine Kopfmassage bekommt: mittelhelle Hautfarbe',
    '💆🏽‍♂' => 'Mann, der eine Kopfmassage bekommt: mittlere Hautfarbe',
    '💆🏾‍♂' => 'Mann, der eine Kopfmassage bekommt: mitteldunkle Hautfarbe',
    '💆🏿‍♂' => 'Mann, der eine Kopfmassage bekommt: dunkle Hautfarbe',
    '💆🏻‍♀' => 'Frau, die eine Kopfmassage bekommt: helle Hautfarbe',
    '💆🏼‍♀' => 'Frau, die eine Kopfmassage bekommt: mittelhelle Hautfarbe',
    '💆🏽‍♀' => 'Frau, die eine Kopfmassage bekommt: mittlere Hautfarbe',
    '💆🏾‍♀' => 'Frau, die eine Kopfmassage bekommt: mitteldunkle Hautfarbe',
    '💆🏿‍♀' => 'Frau, die eine Kopfmassage bekommt: dunkle Hautfarbe',
    '💇🏻‍♂' => 'Mann beim Haareschneiden: helle Hautfarbe',
    '💇🏼‍♂' => 'Mann beim Haareschneiden: mittelhelle Hautfarbe',
    '💇🏽‍♂' => 'Mann beim Haareschneiden: mittlere Hautfarbe',
    '💇🏾‍♂' => 'Mann beim Haareschneiden: mitteldunkle Hautfarbe',
    '💇🏿‍♂' => 'Mann beim Haareschneiden: dunkle Hautfarbe',
    '💇🏻‍♀' => 'Frau beim Haareschneiden: helle Hautfarbe',
    '💇🏼‍♀' => 'Frau beim Haareschneiden: mittelhelle Hautfarbe',
    '💇🏽‍♀' => 'Frau beim Haareschneiden: mittlere Hautfarbe',
    '💇🏾‍♀' => 'Frau beim Haareschneiden: mitteldunkle Hautfarbe',
    '💇🏿‍♀' => 'Frau beim Haareschneiden: dunkle Hautfarbe',
    '🚶🏻‍♂' => 'Fussgänger: helle Hautfarbe',
    '🚶🏼‍♂' => 'Fussgänger: mittelhelle Hautfarbe',
    '🚶🏽‍♂' => 'Fussgänger: mittlere Hautfarbe',
    '🚶🏾‍♂' => 'Fussgänger: mitteldunkle Hautfarbe',
    '🚶🏿‍♂' => 'Fussgänger: dunkle Hautfarbe',
    '🚶🏻‍♀' => 'Fussgängerin: helle Hautfarbe',
    '🚶🏼‍♀' => 'Fussgängerin: mittelhelle Hautfarbe',
    '🚶🏽‍♀' => 'Fussgängerin: mittlere Hautfarbe',
    '🚶🏾‍♀' => 'Fussgängerin: mitteldunkle Hautfarbe',
    '🚶🏿‍♀' => 'Fussgängerin: dunkle Hautfarbe',
    '🚶🏻‍➡' => 'Fussgänger(in): helle Hautfarbe, nach rechts',
    '🚶🏼‍➡' => 'Fussgänger(in): mittelhelle Hautfarbe, nach rechts',
    '🚶🏽‍➡' => 'Fussgänger(in): mittlere Hautfarbe, nach rechts',
    '🚶🏾‍➡' => 'Fussgänger(in): mitteldunkle Hautfarbe, nach rechts',
    '🚶🏿‍➡' => 'Fussgänger(in): dunkle Hautfarbe, nach rechts',
    '🧍🏻‍♂' => 'stehender Mann: helle Hautfarbe',
    '🧍🏼‍♂' => 'stehender Mann: mittelhelle Hautfarbe',
    '🧍🏽‍♂' => 'stehender Mann: mittlere Hautfarbe',
    '🧍🏾‍♂' => 'stehender Mann: mitteldunkle Hautfarbe',
    '🧍🏿‍♂' => 'stehender Mann: dunkle Hautfarbe',
    '🧍🏻‍♀' => 'stehende Frau: helle Hautfarbe',
    '🧍🏼‍♀' => 'stehende Frau: mittelhelle Hautfarbe',
    '🧍🏽‍♀' => 'stehende Frau: mittlere Hautfarbe',
    '🧍🏾‍♀' => 'stehende Frau: mitteldunkle Hautfarbe',
    '🧍🏿‍♀' => 'stehende Frau: dunkle Hautfarbe',
    '🧎🏻‍♂' => 'kniender Mann: helle Hautfarbe',
    '🧎🏼‍♂' => 'kniender Mann: mittelhelle Hautfarbe',
    '🧎🏽‍♂' => 'kniender Mann: mittlere Hautfarbe',
    '🧎🏾‍♂' => 'kniender Mann: mitteldunkle Hautfarbe',
    '🧎🏿‍♂' => 'kniender Mann: dunkle Hautfarbe',
    '🧎🏻‍♀' => 'kniende Frau: helle Hautfarbe',
    '🧎🏼‍♀' => 'kniende Frau: mittelhelle Hautfarbe',
    '🧎🏽‍♀' => 'kniende Frau: mittlere Hautfarbe',
    '🧎🏾‍♀' => 'kniende Frau: mitteldunkle Hautfarbe',
    '🧎🏿‍♀' => 'kniende Frau: dunkle Hautfarbe',
    '🧎🏻‍➡' => 'kniende Person: helle Hautfarbe, nach rechts',
    '🧎🏼‍➡' => 'kniende Person: mittelhelle Hautfarbe, nach rechts',
    '🧎🏽‍➡' => 'kniende Person: mittlere Hautfarbe, nach rechts',
    '🧎🏾‍➡' => 'kniende Person: mitteldunkle Hautfarbe, nach rechts',
    '🧎🏿‍➡' => 'kniende Person: dunkle Hautfarbe, nach rechts',
    '🧑🏻‍🦯' => 'Person mit Langstock: helle Hautfarbe',
    '🧑🏼‍🦯' => 'Person mit Langstock: mittelhelle Hautfarbe',
    '🧑🏽‍🦯' => 'Person mit Langstock: mittlere Hautfarbe',
    '🧑🏾‍🦯' => 'Person mit Langstock: mitteldunkle Hautfarbe',
    '🧑🏿‍🦯' => 'Person mit Langstock: dunkle Hautfarbe',
    '👨🏻‍🦯' => 'Mann mit Langstock: helle Hautfarbe',
    '👨🏼‍🦯' => 'Mann mit Langstock: mittelhelle Hautfarbe',
    '👨🏽‍🦯' => 'Mann mit Langstock: mittlere Hautfarbe',
    '👨🏾‍🦯' => 'Mann mit Langstock: mitteldunkle Hautfarbe',
    '👨🏿‍🦯' => 'Mann mit Langstock: dunkle Hautfarbe',
    '👩🏻‍🦯' => 'Frau mit Langstock: helle Hautfarbe',
    '👩🏼‍🦯' => 'Frau mit Langstock: mittelhelle Hautfarbe',
    '👩🏽‍🦯' => 'Frau mit Langstock: mittlere Hautfarbe',
    '👩🏾‍🦯' => 'Frau mit Langstock: mitteldunkle Hautfarbe',
    '👩🏿‍🦯' => 'Frau mit Langstock: dunkle Hautfarbe',
    '🧑🏻‍🦼' => 'Person in elektrischem Rollstuhl: helle Hautfarbe',
    '🧑🏼‍🦼' => 'Person in elektrischem Rollstuhl: mittelhelle Hautfarbe',
    '🧑🏽‍🦼' => 'Person in elektrischem Rollstuhl: mittlere Hautfarbe',
    '🧑🏾‍🦼' => 'Person in elektrischem Rollstuhl: mitteldunkle Hautfarbe',
    '🧑🏿‍🦼' => 'Person in elektrischem Rollstuhl: dunkle Hautfarbe',
    '👨🏻‍🦼' => 'Mann in elektrischem Rollstuhl: helle Hautfarbe',
    '👨🏼‍🦼' => 'Mann in elektrischem Rollstuhl: mittelhelle Hautfarbe',
    '👨🏽‍🦼' => 'Mann in elektrischem Rollstuhl: mittlere Hautfarbe',
    '👨🏾‍🦼' => 'Mann in elektrischem Rollstuhl: mitteldunkle Hautfarbe',
    '👨🏿‍🦼' => 'Mann in elektrischem Rollstuhl: dunkle Hautfarbe',
    '👩🏻‍🦼' => 'Frau in elektrischem Rollstuhl: helle Hautfarbe',
    '👩🏼‍🦼' => 'Frau in elektrischem Rollstuhl: mittelhelle Hautfarbe',
    '👩🏽‍🦼' => 'Frau in elektrischem Rollstuhl: mittlere Hautfarbe',
    '👩🏾‍🦼' => 'Frau in elektrischem Rollstuhl: mitteldunkle Hautfarbe',
    '👩🏿‍🦼' => 'Frau in elektrischem Rollstuhl: dunkle Hautfarbe',
    '🧑🏻‍🦽' => 'Person in manuellem Rollstuhl: helle Hautfarbe',
    '🧑🏼‍🦽' => 'Person in manuellem Rollstuhl: mittelhelle Hautfarbe',
    '🧑🏽‍🦽' => 'Person in manuellem Rollstuhl: mittlere Hautfarbe',
    '🧑🏾‍🦽' => 'Person in manuellem Rollstuhl: mitteldunkle Hautfarbe',
    '🧑🏿‍🦽' => 'Person in manuellem Rollstuhl: dunkle Hautfarbe',
    '👨🏻‍🦽' => 'Mann in manuellem Rollstuhl: helle Hautfarbe',
    '👨🏼‍🦽' => 'Mann in manuellem Rollstuhl: mittelhelle Hautfarbe',
    '👨🏽‍🦽' => 'Mann in manuellem Rollstuhl: mittlere Hautfarbe',
    '👨🏾‍🦽' => 'Mann in manuellem Rollstuhl: mitteldunkle Hautfarbe',
    '👨🏿‍🦽' => 'Mann in manuellem Rollstuhl: dunkle Hautfarbe',
    '👩🏻‍🦽' => 'Frau in manuellem Rollstuhl: helle Hautfarbe',
    '👩🏼‍🦽' => 'Frau in manuellem Rollstuhl: mittelhelle Hautfarbe',
    '👩🏽‍🦽' => 'Frau in manuellem Rollstuhl: mittlere Hautfarbe',
    '👩🏾‍🦽' => 'Frau in manuellem Rollstuhl: mitteldunkle Hautfarbe',
    '👩🏿‍🦽' => 'Frau in manuellem Rollstuhl: dunkle Hautfarbe',
    '🏃🏻‍♂' => 'laufender Mann: helle Hautfarbe',
    '🏃🏼‍♂' => 'laufender Mann: mittelhelle Hautfarbe',
    '🏃🏽‍♂' => 'laufender Mann: mittlere Hautfarbe',
    '🏃🏾‍♂' => 'laufender Mann: mitteldunkle Hautfarbe',
    '🏃🏿‍♂' => 'laufender Mann: dunkle Hautfarbe',
    '🏃🏻‍♀' => 'laufende Frau: helle Hautfarbe',
    '🏃🏼‍♀' => 'laufende Frau: mittelhelle Hautfarbe',
    '🏃🏽‍♀' => 'laufende Frau: mittlere Hautfarbe',
    '🏃🏾‍♀' => 'laufende Frau: mitteldunkle Hautfarbe',
    '🏃🏿‍♀' => 'laufende Frau: dunkle Hautfarbe',
    '🏃🏻‍➡' => 'laufende Person: helle Hautfarbe, nach rechts',
    '🏃🏼‍➡' => 'laufende Person: mittelhelle Hautfarbe, nach rechts',
    '🏃🏽‍➡' => 'laufende Person: mittlere Hautfarbe, nach rechts',
    '🏃🏾‍➡' => 'laufende Person: mitteldunkle Hautfarbe, nach rechts',
    '🏃🏿‍➡' => 'laufende Person: dunkle Hautfarbe, nach rechts',
    '👯🏻‍♀' => 'Frauen mit Hasenohren: helle Hautfarbe',
    '👯🏼‍♀' => 'Frauen mit Hasenohren: mittelhelle Hautfarbe',
    '👯🏽‍♀' => 'Frauen mit Hasenohren: mittlere Hautfarbe',
    '👯🏾‍♀' => 'Frauen mit Hasenohren: mitteldunkle Hautfarbe',
    '👯🏿‍♀' => 'Frauen mit Hasenohren: dunkle Hautfarbe',
    '👯🏻‍♂' => 'Männer mit Hasenohren: helle Hautfarbe',
    '👯🏼‍♂' => 'Männer mit Hasenohren: mittelhelle Hautfarbe',
    '👯🏽‍♂' => 'Männer mit Hasenohren: mittlere Hautfarbe',
    '👯🏾‍♂' => 'Männer mit Hasenohren: mitteldunkle Hautfarbe',
    '👯🏿‍♂' => 'Männer mit Hasenohren: dunkle Hautfarbe',
    '🧖🏻‍♂' => 'Mann in Dampfsauna: helle Hautfarbe',
    '🧖🏼‍♂' => 'Mann in Dampfsauna: mittelhelle Hautfarbe',
    '🧖🏽‍♂' => 'Mann in Dampfsauna: mittlere Hautfarbe',
    '🧖🏾‍♂' => 'Mann in Dampfsauna: mitteldunkle Hautfarbe',
    '🧖🏿‍♂' => 'Mann in Dampfsauna: dunkle Hautfarbe',
    '🧖🏻‍♀' => 'Frau in Dampfsauna: helle Hautfarbe',
    '🧖🏼‍♀' => 'Frau in Dampfsauna: mittelhelle Hautfarbe',
    '🧖🏽‍♀' => 'Frau in Dampfsauna: mittlere Hautfarbe',
    '🧖🏾‍♀' => 'Frau in Dampfsauna: mitteldunkle Hautfarbe',
    '🧖🏿‍♀' => 'Frau in Dampfsauna: dunkle Hautfarbe',
    '🧗🏻‍♂' => 'Bergsteiger: helle Hautfarbe',
    '🧗🏼‍♂' => 'Bergsteiger: mittelhelle Hautfarbe',
    '🧗🏽‍♂' => 'Bergsteiger: mittlere Hautfarbe',
    '🧗🏾‍♂' => 'Bergsteiger: mitteldunkle Hautfarbe',
    '🧗🏿‍♂' => 'Bergsteiger: dunkle Hautfarbe',
    '🧗🏻‍♀' => 'Bergsteigerin: helle Hautfarbe',
    '🧗🏼‍♀' => 'Bergsteigerin: mittelhelle Hautfarbe',
    '🧗🏽‍♀' => 'Bergsteigerin: mittlere Hautfarbe',
    '🧗🏾‍♀' => 'Bergsteigerin: mitteldunkle Hautfarbe',
    '🧗🏿‍♀' => 'Bergsteigerin: dunkle Hautfarbe',
    '🏌🏻‍♂' => 'Golfer: helle Hautfarbe',
    '🏌🏼‍♂' => 'Golfer: mittelhelle Hautfarbe',
    '🏌🏽‍♂' => 'Golfer: mittlere Hautfarbe',
    '🏌🏾‍♂' => 'Golfer: mitteldunkle Hautfarbe',
    '🏌🏿‍♂' => 'Golfer: dunkle Hautfarbe',
    '🏌🏻‍♀' => 'Golferin: helle Hautfarbe',
    '🏌🏼‍♀' => 'Golferin: mittelhelle Hautfarbe',
    '🏌🏽‍♀' => 'Golferin: mittlere Hautfarbe',
    '🏌🏾‍♀' => 'Golferin: mitteldunkle Hautfarbe',
    '🏌🏿‍♀' => 'Golferin: dunkle Hautfarbe',
    '🏄🏻‍♂' => 'Surfer: helle Hautfarbe',
    '🏄🏼‍♂' => 'Surfer: mittelhelle Hautfarbe',
    '🏄🏽‍♂' => 'Surfer: mittlere Hautfarbe',
    '🏄🏾‍♂' => 'Surfer: mitteldunkle Hautfarbe',
    '🏄🏿‍♂' => 'Surfer: dunkle Hautfarbe',
    '🏄🏻‍♀' => 'Surferin: helle Hautfarbe',
    '🏄🏼‍♀' => 'Surferin: mittelhelle Hautfarbe',
    '🏄🏽‍♀' => 'Surferin: mittlere Hautfarbe',
    '🏄🏾‍♀' => 'Surferin: mitteldunkle Hautfarbe',
    '🏄🏿‍♀' => 'Surferin: dunkle Hautfarbe',
    '🚣🏻‍♂' => 'Mann im Ruderboot: helle Hautfarbe',
    '🚣🏼‍♂' => 'Mann im Ruderboot: mittelhelle Hautfarbe',
    '🚣🏽‍♂' => 'Mann im Ruderboot: mittlere Hautfarbe',
    '🚣🏾‍♂' => 'Mann im Ruderboot: mitteldunkle Hautfarbe',
    '🚣🏿‍♂' => 'Mann im Ruderboot: dunkle Hautfarbe',
    '🚣🏻‍♀' => 'Frau im Ruderboot: helle Hautfarbe',
    '🚣🏼‍♀' => 'Frau im Ruderboot: mittelhelle Hautfarbe',
    '🚣🏽‍♀' => 'Frau im Ruderboot: mittlere Hautfarbe',
    '🚣🏾‍♀' => 'Frau im Ruderboot: mitteldunkle Hautfarbe',
    '🚣🏿‍♀' => 'Frau im Ruderboot: dunkle Hautfarbe',
    '🏊🏻‍♂' => 'Schwimmer: helle Hautfarbe',
    '🏊🏼‍♂' => 'Schwimmer: mittelhelle Hautfarbe',
    '🏊🏽‍♂' => 'Schwimmer: mittlere Hautfarbe',
    '🏊🏾‍♂' => 'Schwimmer: mitteldunkle Hautfarbe',
    '🏊🏿‍♂' => 'Schwimmer: dunkle Hautfarbe',
    '🏊🏻‍♀' => 'Schwimmerin: helle Hautfarbe',
    '🏊🏼‍♀' => 'Schwimmerin: mittelhelle Hautfarbe',
    '🏊🏽‍♀' => 'Schwimmerin: mittlere Hautfarbe',
    '🏊🏾‍♀' => 'Schwimmerin: mitteldunkle Hautfarbe',
    '🏊🏿‍♀' => 'Schwimmerin: dunkle Hautfarbe',
    '⛹🏻‍♂' => 'Mann mit Ball: helle Hautfarbe',
    '⛹🏼‍♂' => 'Mann mit Ball: mittelhelle Hautfarbe',
    '⛹🏽‍♂' => 'Mann mit Ball: mittlere Hautfarbe',
    '⛹🏾‍♂' => 'Mann mit Ball: mitteldunkle Hautfarbe',
    '⛹🏿‍♂' => 'Mann mit Ball: dunkle Hautfarbe',
    '⛹🏻‍♀' => 'Frau mit Ball: helle Hautfarbe',
    '⛹🏼‍♀' => 'Frau mit Ball: mittelhelle Hautfarbe',
    '⛹🏽‍♀' => 'Frau mit Ball: mittlere Hautfarbe',
    '⛹🏾‍♀' => 'Frau mit Ball: mitteldunkle Hautfarbe',
    '⛹🏿‍♀' => 'Frau mit Ball: dunkle Hautfarbe',
    '🏋🏻‍♂' => 'Gewichtheber: helle Hautfarbe',
    '🏋🏼‍♂' => 'Gewichtheber: mittelhelle Hautfarbe',
    '🏋🏽‍♂' => 'Gewichtheber: mittlere Hautfarbe',
    '🏋🏾‍♂' => 'Gewichtheber: mitteldunkle Hautfarbe',
    '🏋🏿‍♂' => 'Gewichtheber: dunkle Hautfarbe',
    '🏋🏻‍♀' => 'Gewichtheberin: helle Hautfarbe',
    '🏋🏼‍♀' => 'Gewichtheberin: mittelhelle Hautfarbe',
    '🏋🏽‍♀' => 'Gewichtheberin: mittlere Hautfarbe',
    '🏋🏾‍♀' => 'Gewichtheberin: mitteldunkle Hautfarbe',
    '🏋🏿‍♀' => 'Gewichtheberin: dunkle Hautfarbe',
    '🚴🏻‍♂' => 'Radfahrer: helle Hautfarbe',
    '🚴🏼‍♂' => 'Radfahrer: mittelhelle Hautfarbe',
    '🚴🏽‍♂' => 'Radfahrer: mittlere Hautfarbe',
    '🚴🏾‍♂' => 'Radfahrer: mitteldunkle Hautfarbe',
    '🚴🏿‍♂' => 'Radfahrer: dunkle Hautfarbe',
    '🚴🏻‍♀' => 'Radfahrerin: helle Hautfarbe',
    '🚴🏼‍♀' => 'Radfahrerin: mittelhelle Hautfarbe',
    '🚴🏽‍♀' => 'Radfahrerin: mittlere Hautfarbe',
    '🚴🏾‍♀' => 'Radfahrerin: mitteldunkle Hautfarbe',
    '🚴🏿‍♀' => 'Radfahrerin: dunkle Hautfarbe',
    '🚵🏻‍♂' => 'Mountainbiker: helle Hautfarbe',
    '🚵🏼‍♂' => 'Mountainbiker: mittelhelle Hautfarbe',
    '🚵🏽‍♂' => 'Mountainbiker: mittlere Hautfarbe',
    '🚵🏾‍♂' => 'Mountainbiker: mitteldunkle Hautfarbe',
    '🚵🏿‍♂' => 'Mountainbiker: dunkle Hautfarbe',
    '🚵🏻‍♀' => 'Mountainbikerin: helle Hautfarbe',
    '🚵🏼‍♀' => 'Mountainbikerin: mittelhelle Hautfarbe',
    '🚵🏽‍♀' => 'Mountainbikerin: mittlere Hautfarbe',
    '🚵🏾‍♀' => 'Mountainbikerin: mitteldunkle Hautfarbe',
    '🚵🏿‍♀' => 'Mountainbikerin: dunkle Hautfarbe',
    '🤸🏻‍♂' => 'Rad schlagender Mann: helle Hautfarbe',
    '🤸🏼‍♂' => 'Rad schlagender Mann: mittelhelle Hautfarbe',
    '🤸🏽‍♂' => 'Rad schlagender Mann: mittlere Hautfarbe',
    '🤸🏾‍♂' => 'Rad schlagender Mann: mitteldunkle Hautfarbe',
    '🤸🏿‍♂' => 'Rad schlagender Mann: dunkle Hautfarbe',
    '🤸🏻‍♀' => 'Rad schlagende Frau: helle Hautfarbe',
    '🤸🏼‍♀' => 'Rad schlagende Frau: mittelhelle Hautfarbe',
    '🤸🏽‍♀' => 'Rad schlagende Frau: mittlere Hautfarbe',
    '🤸🏾‍♀' => 'Rad schlagende Frau: mitteldunkle Hautfarbe',
    '🤸🏿‍♀' => 'Rad schlagende Frau: dunkle Hautfarbe',
    '🤼🏻‍♀' => 'ringende Frauen: helle Hautfarbe',
    '🤼🏼‍♀' => 'ringende Frauen: mittelhelle Hautfarbe',
    '🤼🏽‍♀' => 'ringende Frauen: mittlere Hautfarbe',
    '🤼🏾‍♀' => 'ringende Frauen: mitteldunkle Hautfarbe',
    '🤼🏿‍♀' => 'ringende Frauen: dunkle Hautfarbe',
    '🤼🏻‍♂' => 'ringende Männer: helle Hautfarbe',
    '🤼🏼‍♂' => 'ringende Männer: mittelhelle Hautfarbe',
    '🤼🏽‍♂' => 'ringende Männer: mittlere Hautfarbe',
    '🤼🏾‍♂' => 'ringende Männer: mitteldunkle Hautfarbe',
    '🤼🏿‍♂' => 'ringende Männer: dunkle Hautfarbe',
    '🤽🏻‍♂' => 'Wasserballspieler: helle Hautfarbe',
    '🤽🏼‍♂' => 'Wasserballspieler: mittelhelle Hautfarbe',
    '🤽🏽‍♂' => 'Wasserballspieler: mittlere Hautfarbe',
    '🤽🏾‍♂' => 'Wasserballspieler: mitteldunkle Hautfarbe',
    '🤽🏿‍♂' => 'Wasserballspieler: dunkle Hautfarbe',
    '🤽🏻‍♀' => 'Wasserballspielerin: helle Hautfarbe',
    '🤽🏼‍♀' => 'Wasserballspielerin: mittelhelle Hautfarbe',
    '🤽🏽‍♀' => 'Wasserballspielerin: mittlere Hautfarbe',
    '🤽🏾‍♀' => 'Wasserballspielerin: mitteldunkle Hautfarbe',
    '🤽🏿‍♀' => 'Wasserballspielerin: dunkle Hautfarbe',
    '🤾🏻‍♂' => 'Handballspieler: helle Hautfarbe',
    '🤾🏼‍♂' => 'Handballspieler: mittelhelle Hautfarbe',
    '🤾🏽‍♂' => 'Handballspieler: mittlere Hautfarbe',
    '🤾🏾‍♂' => 'Handballspieler: mitteldunkle Hautfarbe',
    '🤾🏿‍♂' => 'Handballspieler: dunkle Hautfarbe',
    '🤾🏻‍♀' => 'Handballspielerin: helle Hautfarbe',
    '🤾🏼‍♀' => 'Handballspielerin: mittelhelle Hautfarbe',
    '🤾🏽‍♀' => 'Handballspielerin: mittlere Hautfarbe',
    '🤾🏾‍♀' => 'Handballspielerin: mitteldunkle Hautfarbe',
    '🤾🏿‍♀' => 'Handballspielerin: dunkle Hautfarbe',
    '🤹🏻‍♂' => 'Jongleur: helle Hautfarbe',
    '🤹🏼‍♂' => 'Jongleur: mittelhelle Hautfarbe',
    '🤹🏽‍♂' => 'Jongleur: mittlere Hautfarbe',
    '🤹🏾‍♂' => 'Jongleur: mitteldunkle Hautfarbe',
    '🤹🏿‍♂' => 'Jongleur: dunkle Hautfarbe',
    '🤹🏻‍♀' => 'Jongleurin: helle Hautfarbe',
    '🤹🏼‍♀' => 'Jongleurin: mittelhelle Hautfarbe',
    '🤹🏽‍♀' => 'Jongleurin: mittlere Hautfarbe',
    '🤹🏾‍♀' => 'Jongleurin: mitteldunkle Hautfarbe',
    '🤹🏿‍♀' => 'Jongleurin: dunkle Hautfarbe',
    '🧘🏻‍♂' => 'Mann im Lotossitz: helle Hautfarbe',
    '🧘🏼‍♂' => 'Mann im Lotossitz: mittelhelle Hautfarbe',
    '🧘🏽‍♂' => 'Mann im Lotossitz: mittlere Hautfarbe',
    '🧘🏾‍♂' => 'Mann im Lotossitz: mitteldunkle Hautfarbe',
    '🧘🏿‍♂' => 'Mann im Lotossitz: dunkle Hautfarbe',
    '🧘🏻‍♀' => 'Frau im Lotossitz: helle Hautfarbe',
    '🧘🏼‍♀' => 'Frau im Lotossitz: mittelhelle Hautfarbe',
    '🧘🏽‍♀' => 'Frau im Lotossitz: mittlere Hautfarbe',
    '🧘🏾‍♀' => 'Frau im Lotossitz: mitteldunkle Hautfarbe',
    '🧘🏿‍♀' => 'Frau im Lotossitz: dunkle Hautfarbe',
    '🧑‍🦰' => 'Person: rotes Haar',
    '🧑‍🦱' => 'Person: lockiges Haar',
    '🧑‍🦳' => 'Person: weisses Haar',
    '🧑‍🦲' => 'Person: Glatze',
    '👨‍🦰' => 'Mann: rotes Haar',
    '👨‍🦱' => 'Mann: lockiges Haar',
    '👨‍🦳' => 'Mann: weisses Haar',
    '👨‍🦲' => 'Mann: Glatze',
    '👩‍🦰' => 'Frau: rotes Haar',
    '👩‍🦱' => 'Frau: lockiges Haar',
    '👩‍🦳' => 'Frau: weisses Haar',
    '👩‍🦲' => 'Frau: Glatze',
    '🚶‍➡' => 'Fussgänger(in): nach rechts',
    '🧎‍➡' => 'kniende Person: nach rechts',
    '🏃‍➡' => 'laufende Person: nach rechts',
    '👨‍👦' => 'Familie: Mann, Junge',
    '👨‍👧' => 'Familie: Mann, Mädchen',
    '👩‍👦' => 'Familie: Frau, Junge',
    '👩‍👧' => 'Familie: Frau, Mädchen',
    '😶‍🌫' => 'Gesicht in Wolken',
    '😮‍💨' => 'Gesicht, das ausatmet',
    '🙂‍↕' => 'Kopfnicken',
    '😵‍💫' => 'Gesicht mit Spiralen als Augen',
    '❤‍🔥' => 'Herz in Flammen',
    '❤‍🩹' => 'Herz mit Verband',
    '👁‍🗨' => 'Auge in Sprechblase',
    '🧔‍♂' => 'Mann: Bart',
    '👱‍♂' => 'Mann: blond',
    '🧔‍♀' => 'Frau: Bart',
    '👱‍♀' => 'Frau: blond',
    '🙍‍♂' => 'missmutiger Mann',
    '🙍‍♀' => 'missmutige Frau',
    '🙎‍♂' => 'schmollender Mann',
    '🙎‍♀' => 'schmollende Frau',
    '🙅‍♂' => 'Mann mit überkreuzten Armen',
    '🙅‍♀' => 'Frau mit überkreuzten Armen',
    '🙆‍♂' => 'Mann mit Händen auf dem Kopf',
    '🙆‍♀' => 'Frau mit Händen auf dem Kopf',
    '💁‍♂' => 'Infoschalter-Mitarbeiter',
    '💁‍♀' => 'Infoschalter-Mitarbeiterin',
    '🙋‍♂' => 'Mann mit erhobenem Arm',
    '🙋‍♀' => 'Frau mit erhobenem Arm',
    '🧏‍♂' => 'gehörloser Mann',
    '🧏‍♀' => 'gehörlose Frau',
    '🙇‍♂' => 'sich verbeugender Mann',
    '🙇‍♀' => 'sich verbeugende Frau',
    '🤦‍♂' => 'sich an den Kopf fassender Mann',
    '🤦‍♀' => 'sich an den Kopf fassende Frau',
    '🤷‍♂' => 'schulterzuckender Mann',
    '🤷‍♀' => 'schulterzuckende Frau',
    '🧑‍⚕' => 'Arzt/Ärztin',
    '👨‍⚕' => 'Arzt',
    '👩‍⚕' => 'Ärztin',
    '🧑‍🎓' => 'Student(in)',
    '👨‍🎓' => 'Student',
    '👩‍🎓' => 'Studentin',
    '🧑‍🏫' => 'Lehrer(in)',
    '👨‍🏫' => 'Lehrer',
    '👩‍🏫' => 'Lehrerin',
    '🧑‍⚖' => 'Richter(in)',
    '👨‍⚖' => 'Richter',
    '👩‍⚖' => 'Richterin',
    '🧑‍🌾' => 'Bauer/Bäuerin',
    '👨‍🌾' => 'Bauer',
    '👩‍🌾' => 'Bäuerin',
    '🧑‍🍳' => 'Koch/Köchin',
    '👨‍🍳' => 'Koch',
    '👩‍🍳' => 'Köchin',
    '🧑‍🔧' => 'Mechaniker(in)',
    '👨‍🔧' => 'Mechaniker',
    '👩‍🔧' => 'Mechanikerin',
    '🧑‍🏭' => 'Fabrikarbeiter(in)',
    '👨‍🏭' => 'Fabrikarbeiter',
    '👩‍🏭' => 'Fabrikarbeiterin',
    '🧑‍💼' => 'Büroangestellte(r)',
    '👨‍💼' => 'Büroangestellter',
    '👩‍💼' => 'Büroangestellte',
    '🧑‍🔬' => 'Wissenschaftler(in)',
    '👨‍🔬' => 'Wissenschaftler',
    '👩‍🔬' => 'Wissenschaftlerin',
    '🧑‍💻' => 'IT-Experte/IT-Expertin',
    '👨‍💻' => 'IT-Experte',
    '👩‍💻' => 'IT-Expertin',
    '🧑‍🎤' => 'Sänger(in)',
    '👨‍🎤' => 'Sänger',
    '👩‍🎤' => 'Sängerin',
    '🧑‍🎨' => 'Künstler(in)',
    '👨‍🎨' => 'Künstler',
    '👩‍🎨' => 'Künstlerin',
    '🧑‍✈' => 'Pilot(in)',
    '👨‍✈' => 'Pilot',
    '👩‍✈' => 'Pilotin',
    '🧑‍🚀' => 'Astronaut(in)',
    '👨‍🚀' => 'Astronaut',
    '👩‍🚀' => 'Astronautin',
    '🧑‍🚒' => 'Feuerwehrmann/-frau',
    '👨‍🚒' => 'Feuerwehrmann',
    '👩‍🚒' => 'Feuerwehrfrau',
    '👮‍♂' => 'Polizist',
    '👮‍♀' => 'Polizistin',
    '🕵‍♂' => 'Detektiv',
    '🕵‍♀' => 'Detektivin',
    '💂‍♂' => 'Wachsoldat',
    '💂‍♀' => 'Wachsoldatin',
    '👷‍♂' => 'Bauarbeiter',
    '👷‍♀' => 'Bauarbeiterin',
    '👳‍♂' => 'Mann mit Turban',
    '👳‍♀' => 'Frau mit Turban',
    '🤵‍♂' => 'Mann im Smoking',
    '🤵‍♀' => 'Frau im Smoking',
    '👰‍♂' => 'Mann mit Schleier',
    '👰‍♀' => 'Frau mit Schleier',
    '👩‍🍼' => 'Frau, die Baby die Flasche gibt',
    '👨‍🍼' => 'Mann, der Baby die Flasche gibt',
    '🧑‍🍼' => 'Person, die Baby die Flasche gibt',
    '🧑‍🎄' => 'Weihnachtsperson',
    '🦸‍♂' => 'Superheld',
    '🦸‍♀' => 'Heldin',
    '🦹‍♂' => 'männlicher Bösewicht',
    '🦹‍♀' => 'weiblicher Bösewicht',
    '🧙‍♂' => 'Magier',
    '🧙‍♀' => 'Magierin',
    '🧚‍♂' => 'männliche Fee',
    '🧚‍♀' => 'Fee',
    '🧛‍♂' => 'männlicher Vampir',
    '🧛‍♀' => 'weiblicher Vampir',
    '🧜‍♂' => 'Wassermann',
    '🧜‍♀' => 'Meerjungfrau',
    '🧝‍♂' => 'Elf',
    '🧝‍♀' => 'Elfe',
    '🧞‍♂' => 'männlicher Flaschengeist',
    '🧞‍♀' => 'weiblicher Flaschengeist',
    '🧟‍♂' => 'männlicher Zombie',
    '🧟‍♀' => 'weiblicher Zombie',
    '💆‍♂' => 'Mann, der eine Kopfmassage bekommt',
    '💆‍♀' => 'Frau, die eine Kopfmassage bekommt',
    '💇‍♂' => 'Mann beim Haareschneiden',
    '💇‍♀' => 'Frau beim Haareschneiden',
    '🚶‍♂' => 'Fussgänger',
    '🚶‍♀' => 'Fussgängerin',
    '🧍‍♂' => 'stehender Mann',
    '🧍‍♀' => 'stehende Frau',
    '🧎‍♂' => 'kniender Mann',
    '🧎‍♀' => 'kniende Frau',
    '🧑‍🦯' => 'Person mit Langstock',
    '👨‍🦯' => 'Mann mit Langstock',
    '👩‍🦯' => 'Frau mit Langstock',
    '🧑‍🦼' => 'Person in elektrischem Rollstuhl',
    '👨‍🦼' => 'Mann in elektrischem Rollstuhl',
    '👩‍🦼' => 'Frau in elektrischem Rollstuhl',
    '🧑‍🦽' => 'Person in manuellem Rollstuhl',
    '👨‍🦽' => 'Mann in manuellem Rollstuhl',
    '👩‍🦽' => 'Frau in manuellem Rollstuhl',
    '🏃‍♂' => 'laufender Mann',
    '🏃‍♀' => 'laufende Frau',
    '🧑‍🩰' => 'Balletttänzerin',
    '👯‍♂' => 'Männer mit Hasenohren',
    '👯‍♀' => 'Frauen mit Hasenohren',
    '🧖‍♂' => 'Mann in Dampfsauna',
    '🧖‍♀' => 'Frau in Dampfsauna',
    '🧗‍♂' => 'Bergsteiger',
    '🧗‍♀' => 'Bergsteigerin',
    '🏌‍♂' => 'Golfer',
    '🏌‍♀' => 'Golferin',
    '🏄‍♂' => 'Surfer',
    '🏄‍♀' => 'Surferin',
    '🚣‍♂' => 'Mann im Ruderboot',
    '🚣‍♀' => 'Frau im Ruderboot',
    '🏊‍♂' => 'Schwimmer',
    '🏊‍♀' => 'Schwimmerin',
    '⛹‍♂' => 'Mann mit Ball',
    '⛹‍♀' => 'Frau mit Ball',
    '🏋‍♂' => 'Gewichtheber',
    '🏋‍♀' => 'Gewichtheberin',
    '🚴‍♂' => 'Radfahrer',
    '🚴‍♀' => 'Radfahrerin',
    '🚵‍♂' => 'Mountainbiker',
    '🚵‍♀' => 'Mountainbikerin',
    '🤸‍♂' => 'Rad schlagender Mann',
    '🤸‍♀' => 'Rad schlagende Frau',
    '🤼‍♂' => 'ringende Männer',
    '🤼‍♀' => 'ringende Frauen',
    '🤽‍♂' => 'Wasserballspieler',
    '🤽‍♀' => 'Wasserballspielerin',
    '🤾‍♂' => 'Handballspieler',
    '🤾‍♀' => 'Handballspielerin',
    '🤹‍♂' => 'Jongleur',
    '🤹‍♀' => 'Jongleurin',
    '🧘‍♂' => 'Mann im Lotossitz',
    '🧘‍♀' => 'Frau im Lotossitz',
    '🧑‍🧒' => 'Familie: 1 Erwachsene(r), 1 Kind',
    '🐕‍🦺' => 'Assistenzhund',
    '🐈‍⬛' => 'schwarze Katze',
    '🐻‍❄' => 'Eisbär',
    '🐦‍⬛' => 'schwarzer Vogel',
    '🐦‍🔥' => 'Phönix',
    '🍋‍🟩' => 'Limette',
    '🍄‍🟫' => 'brauner Pilz',
    '⛓‍💥' => 'gebrochene Kette',
    '🏳‍🌈' => 'Regenbogenflagge',
    '🏳‍⚧' => 'Transgender-Flagge',
    '🏴‍☠' => 'Piratenflagge',
    '👋🏻' => 'winkende Hand: helle Hautfarbe',
    '👋🏼' => 'winkende Hand: mittelhelle Hautfarbe',
    '👋🏽' => 'winkende Hand: mittlere Hautfarbe',
    '👋🏾' => 'winkende Hand: mitteldunkle Hautfarbe',
    '👋🏿' => 'winkende Hand: dunkle Hautfarbe',
    '🤚🏻' => 'erhobene Hand von hinten: helle Hautfarbe',
    '🤚🏼' => 'erhobene Hand von hinten: mittelhelle Hautfarbe',
    '🤚🏽' => 'erhobene Hand von hinten: mittlere Hautfarbe',
    '🤚🏾' => 'erhobene Hand von hinten: mitteldunkle Hautfarbe',
    '🤚🏿' => 'erhobene Hand von hinten: dunkle Hautfarbe',
    '🖐🏻' => 'Hand mit gespreizten Fingern: helle Hautfarbe',
    '🖐🏼' => 'Hand mit gespreizten Fingern: mittelhelle Hautfarbe',
    '🖐🏽' => 'Hand mit gespreizten Fingern: mittlere Hautfarbe',
    '🖐🏾' => 'Hand mit gespreizten Fingern: mitteldunkle Hautfarbe',
    '🖐🏿' => 'Hand mit gespreizten Fingern: dunkle Hautfarbe',
    '✋🏻' => 'erhobene Hand: helle Hautfarbe',
    '✋🏼' => 'erhobene Hand: mittelhelle Hautfarbe',
    '✋🏽' => 'erhobene Hand: mittlere Hautfarbe',
    '✋🏾' => 'erhobene Hand: mitteldunkle Hautfarbe',
    '✋🏿' => 'erhobene Hand: dunkle Hautfarbe',
    '🖖🏻' => 'vulkanischer Gruss: helle Hautfarbe',
    '🖖🏼' => 'vulkanischer Gruss: mittelhelle Hautfarbe',
    '🖖🏽' => 'vulkanischer Gruss: mittlere Hautfarbe',
    '🖖🏾' => 'vulkanischer Gruss: mitteldunkle Hautfarbe',
    '🖖🏿' => 'vulkanischer Gruss: dunkle Hautfarbe',
    '🫱🏻' => 'nach rechts weisende Hand: helle Hautfarbe',
    '🫱🏼' => 'nach rechts weisende Hand: mittelhelle Hautfarbe',
    '🫱🏽' => 'nach rechts weisende Hand: mittlere Hautfarbe',
    '🫱🏾' => 'nach rechts weisende Hand: mitteldunkle Hautfarbe',
    '🫱🏿' => 'nach rechts weisende Hand: dunkle Hautfarbe',
    '🫲🏻' => 'nach links weisende Hand: helle Hautfarbe',
    '🫲🏼' => 'nach links weisende Hand: mittelhelle Hautfarbe',
    '🫲🏽' => 'nach links weisende Hand: mittlere Hautfarbe',
    '🫲🏾' => 'nach links weisende Hand: mitteldunkle Hautfarbe',
    '🫲🏿' => 'nach links weisende Hand: dunkle Hautfarbe',
    '🫳🏻' => 'Hand mit Handfläche nach unten: helle Hautfarbe',
    '🫳🏼' => 'Hand mit Handfläche nach unten: mittelhelle Hautfarbe',
    '🫳🏽' => 'Hand mit Handfläche nach unten: mittlere Hautfarbe',
    '🫳🏾' => 'Hand mit Handfläche nach unten: mitteldunkle Hautfarbe',
    '🫳🏿' => 'Hand mit Handfläche nach unten: dunkle Hautfarbe',
    '🫴🏻' => 'Hand mit Handfläche nach oben: helle Hautfarbe',
    '🫴🏼' => 'Hand mit Handfläche nach oben: mittelhelle Hautfarbe',
    '🫴🏽' => 'Hand mit Handfläche nach oben: mittlere Hautfarbe',
    '🫴🏾' => 'Hand mit Handfläche nach oben: mitteldunkle Hautfarbe',
    '🫴🏿' => 'Hand mit Handfläche nach oben: dunkle Hautfarbe',
    '🫷🏻' => 'nach links schiebende Hand: helle Hautfarbe',
    '🫷🏼' => 'nach links schiebende Hand: mittelhelle Hautfarbe',
    '🫷🏽' => 'nach links schiebende Hand: mittlere Hautfarbe',
    '🫷🏾' => 'nach links schiebende Hand: mitteldunkle Hautfarbe',
    '🫷🏿' => 'nach links schiebende Hand: dunkle Hautfarbe',
    '🫸🏻' => 'nach rechts schiebende Hand: helle Hautfarbe',
    '🫸🏼' => 'nach rechts schiebende Hand: mittelhelle Hautfarbe',
    '🫸🏽' => 'nach rechts schiebende Hand: mittlere Hautfarbe',
    '🫸🏾' => 'nach rechts schiebende Hand: mitteldunkle Hautfarbe',
    '🫸🏿' => 'nach rechts schiebende Hand: dunkle Hautfarbe',
    '👌🏻' => 'OK-Zeichen: helle Hautfarbe',
    '👌🏼' => 'OK-Zeichen: mittelhelle Hautfarbe',
    '👌🏽' => 'OK-Zeichen: mittlere Hautfarbe',
    '👌🏾' => 'OK-Zeichen: mitteldunkle Hautfarbe',
    '👌🏿' => 'OK-Zeichen: dunkle Hautfarbe',
    '🤌🏻' => 'zusammengedrückte Finger: helle Hautfarbe',
    '🤌🏼' => 'zusammengedrückte Finger: mittelhelle Hautfarbe',
    '🤌🏽' => 'zusammengedrückte Finger: mittlere Hautfarbe',
    '🤌🏾' => 'zusammengedrückte Finger: mitteldunkle Hautfarbe',
    '🤌🏿' => 'zusammengedrückte Finger: dunkle Hautfarbe',
    '🤏🏻' => 'Wenig-Geste: helle Hautfarbe',
    '🤏🏼' => 'Wenig-Geste: mittelhelle Hautfarbe',
    '🤏🏽' => 'Wenig-Geste: mittlere Hautfarbe',
    '🤏🏾' => 'Wenig-Geste: mitteldunkle Hautfarbe',
    '🤏🏿' => 'Wenig-Geste: dunkle Hautfarbe',
    '✌🏻' => 'Victory-Geste: helle Hautfarbe',
    '✌🏼' => 'Victory-Geste: mittelhelle Hautfarbe',
    '✌🏽' => 'Victory-Geste: mittlere Hautfarbe',
    '✌🏾' => 'Victory-Geste: mitteldunkle Hautfarbe',
    '✌🏿' => 'Victory-Geste: dunkle Hautfarbe',
    '🤞🏻' => 'Hand mit gekreuzten Fingern: helle Hautfarbe',
    '🤞🏼' => 'Hand mit gekreuzten Fingern: mittelhelle Hautfarbe',
    '🤞🏽' => 'Hand mit gekreuzten Fingern: mittlere Hautfarbe',
    '🤞🏾' => 'Hand mit gekreuzten Fingern: mitteldunkle Hautfarbe',
    '🤞🏿' => 'Hand mit gekreuzten Fingern: dunkle Hautfarbe',
    '🫰🏻' => 'Hand mit gekreuztem Zeigefinger und Daumen: helle Hautfarbe',
    '🫰🏼' => 'Hand mit gekreuztem Zeigefinger und Daumen: mittelhelle Hautfarbe',
    '🫰🏽' => 'Hand mit gekreuztem Zeigefinger und Daumen: mittlere Hautfarbe',
    '🫰🏾' => 'Hand mit gekreuztem Zeigefinger und Daumen: mitteldunkle Hautfarbe',
    '🫰🏿' => 'Hand mit gekreuztem Zeigefinger und Daumen: dunkle Hautfarbe',
    '🤟🏻' => 'Ich-liebe-dich-Geste: helle Hautfarbe',
    '🤟🏼' => 'Ich-liebe-dich-Geste: mittelhelle Hautfarbe',
    '🤟🏽' => 'Ich-liebe-dich-Geste: mittlere Hautfarbe',
    '🤟🏾' => 'Ich-liebe-dich-Geste: mitteldunkle Hautfarbe',
    '🤟🏿' => 'Ich-liebe-dich-Geste: dunkle Hautfarbe',
    '🤘🏻' => 'Teufelsgruss: helle Hautfarbe',
    '🤘🏼' => 'Teufelsgruss: mittelhelle Hautfarbe',
    '🤘🏽' => 'Teufelsgruss: mittlere Hautfarbe',
    '🤘🏾' => 'Teufelsgruss: mitteldunkle Hautfarbe',
    '🤘🏿' => 'Teufelsgruss: dunkle Hautfarbe',
    '🤙🏻' => 'Ruf-mich-an-Handzeichen: helle Hautfarbe',
    '🤙🏼' => 'Ruf-mich-an-Handzeichen: mittelhelle Hautfarbe',
    '🤙🏽' => 'Ruf-mich-an-Handzeichen: mittlere Hautfarbe',
    '🤙🏾' => 'Ruf-mich-an-Handzeichen: mitteldunkle Hautfarbe',
    '🤙🏿' => 'Ruf-mich-an-Handzeichen: dunkle Hautfarbe',
    '👈🏻' => 'nach links weisender Zeigefinger: helle Hautfarbe',
    '👈🏼' => 'nach links weisender Zeigefinger: mittelhelle Hautfarbe',
    '👈🏽' => 'nach links weisender Zeigefinger: mittlere Hautfarbe',
    '👈🏾' => 'nach links weisender Zeigefinger: mitteldunkle Hautfarbe',
    '👈🏿' => 'nach links weisender Zeigefinger: dunkle Hautfarbe',
    '👉🏻' => 'nach rechts weisender Zeigefinger: helle Hautfarbe',
    '👉🏼' => 'nach rechts weisender Zeigefinger: mittelhelle Hautfarbe',
    '👉🏽' => 'nach rechts weisender Zeigefinger: mittlere Hautfarbe',
    '👉🏾' => 'nach rechts weisender Zeigefinger: mitteldunkle Hautfarbe',
    '👉🏿' => 'nach rechts weisender Zeigefinger: dunkle Hautfarbe',
    '👆🏻' => 'nach oben weisender Zeigefinger von hinten: helle Hautfarbe',
    '👆🏼' => 'nach oben weisender Zeigefinger von hinten: mittelhelle Hautfarbe',
    '👆🏽' => 'nach oben weisender Zeigefinger von hinten: mittlere Hautfarbe',
    '👆🏾' => 'nach oben weisender Zeigefinger von hinten: mitteldunkle Hautfarbe',
    '👆🏿' => 'nach oben weisender Zeigefinger von hinten: dunkle Hautfarbe',
    '🖕🏻' => 'Mittelfinger: helle Hautfarbe',
    '🖕🏼' => 'Mittelfinger: mittelhelle Hautfarbe',
    '🖕🏽' => 'Mittelfinger: mittlere Hautfarbe',
    '🖕🏾' => 'Mittelfinger: mitteldunkle Hautfarbe',
    '🖕🏿' => 'Mittelfinger: dunkle Hautfarbe',
    '👇🏻' => 'nach unten weisender Zeigefinger: helle Hautfarbe',
    '👇🏼' => 'nach unten weisender Zeigefinger: mittelhelle Hautfarbe',
    '👇🏽' => 'nach unten weisender Zeigefinger: mittlere Hautfarbe',
    '👇🏾' => 'nach unten weisender Zeigefinger: mitteldunkle Hautfarbe',
    '👇🏿' => 'nach unten weisender Zeigefinger: dunkle Hautfarbe',
    '☝🏻' => 'nach oben weisender Zeigefinger von vorne: helle Hautfarbe',
    '☝🏼' => 'nach oben weisender Zeigefinger von vorne: mittelhelle Hautfarbe',
    '☝🏽' => 'nach oben weisender Zeigefinger von vorne: mittlere Hautfarbe',
    '☝🏾' => 'nach oben weisender Zeigefinger von vorne: mitteldunkle Hautfarbe',
    '☝🏿' => 'nach oben weisender Zeigefinger von vorne: dunkle Hautfarbe',
    '🫵🏻' => 'auf Betrachter zeigender Zeigefinger: helle Hautfarbe',
    '🫵🏼' => 'auf Betrachter zeigender Zeigefinger: mittelhelle Hautfarbe',
    '🫵🏽' => 'auf Betrachter zeigender Zeigefinger: mittlere Hautfarbe',
    '🫵🏾' => 'auf Betrachter zeigender Zeigefinger: mitteldunkle Hautfarbe',
    '🫵🏿' => 'auf Betrachter zeigender Zeigefinger: dunkle Hautfarbe',
    '👍🏻' => 'Daumen hoch: helle Hautfarbe',
    '👍🏼' => 'Daumen hoch: mittelhelle Hautfarbe',
    '👍🏽' => 'Daumen hoch: mittlere Hautfarbe',
    '👍🏾' => 'Daumen hoch: mitteldunkle Hautfarbe',
    '👍🏿' => 'Daumen hoch: dunkle Hautfarbe',
    '👎🏻' => 'Daumen runter: helle Hautfarbe',
    '👎🏼' => 'Daumen runter: mittelhelle Hautfarbe',
    '👎🏽' => 'Daumen runter: mittlere Hautfarbe',
    '👎🏾' => 'Daumen runter: mitteldunkle Hautfarbe',
    '👎🏿' => 'Daumen runter: dunkle Hautfarbe',
    '✊🏻' => 'erhobene Faust: helle Hautfarbe',
    '✊🏼' => 'erhobene Faust: mittelhelle Hautfarbe',
    '✊🏽' => 'erhobene Faust: mittlere Hautfarbe',
    '✊🏾' => 'erhobene Faust: mitteldunkle Hautfarbe',
    '✊🏿' => 'erhobene Faust: dunkle Hautfarbe',
    '👊🏻' => 'geballte Faust: helle Hautfarbe',
    '👊🏼' => 'geballte Faust: mittelhelle Hautfarbe',
    '👊🏽' => 'geballte Faust: mittlere Hautfarbe',
    '👊🏾' => 'geballte Faust: mitteldunkle Hautfarbe',
    '👊🏿' => 'geballte Faust: dunkle Hautfarbe',
    '🤛🏻' => 'Faust nach links: helle Hautfarbe',
    '🤛🏼' => 'Faust nach links: mittelhelle Hautfarbe',
    '🤛🏽' => 'Faust nach links: mittlere Hautfarbe',
    '🤛🏾' => 'Faust nach links: mitteldunkle Hautfarbe',
    '🤛🏿' => 'Faust nach links: dunkle Hautfarbe',
    '🤜🏻' => 'Faust nach rechts: helle Hautfarbe',
    '🤜🏼' => 'Faust nach rechts: mittelhelle Hautfarbe',
    '🤜🏽' => 'Faust nach rechts: mittlere Hautfarbe',
    '🤜🏾' => 'Faust nach rechts: mitteldunkle Hautfarbe',
    '🤜🏿' => 'Faust nach rechts: dunkle Hautfarbe',
    '👏🏻' => 'klatschende Hände: helle Hautfarbe',
    '👏🏼' => 'klatschende Hände: mittelhelle Hautfarbe',
    '👏🏽' => 'klatschende Hände: mittlere Hautfarbe',
    '👏🏾' => 'klatschende Hände: mitteldunkle Hautfarbe',
    '👏🏿' => 'klatschende Hände: dunkle Hautfarbe',
    '🙌🏻' => 'zwei erhobene Handflächen: helle Hautfarbe',
    '🙌🏼' => 'zwei erhobene Handflächen: mittelhelle Hautfarbe',
    '🙌🏽' => 'zwei erhobene Handflächen: mittlere Hautfarbe',
    '🙌🏾' => 'zwei erhobene Handflächen: mitteldunkle Hautfarbe',
    '🙌🏿' => 'zwei erhobene Handflächen: dunkle Hautfarbe',
    '🫶🏻' => 'Hände, die Herz bilden: helle Hautfarbe',
    '🫶🏼' => 'Hände, die Herz bilden: mittelhelle Hautfarbe',
    '🫶🏽' => 'Hände, die Herz bilden: mittlere Hautfarbe',
    '🫶🏾' => 'Hände, die Herz bilden: mitteldunkle Hautfarbe',
    '🫶🏿' => 'Hände, die Herz bilden: dunkle Hautfarbe',
    '👐🏻' => 'offene Hände: helle Hautfarbe',
    '👐🏼' => 'offene Hände: mittelhelle Hautfarbe',
    '👐🏽' => 'offene Hände: mittlere Hautfarbe',
    '👐🏾' => 'offene Hände: mitteldunkle Hautfarbe',
    '👐🏿' => 'offene Hände: dunkle Hautfarbe',
    '🤲🏻' => 'Handflächen nach oben: helle Hautfarbe',
    '🤲🏼' => 'Handflächen nach oben: mittelhelle Hautfarbe',
    '🤲🏽' => 'Handflächen nach oben: mittlere Hautfarbe',
    '🤲🏾' => 'Handflächen nach oben: mitteldunkle Hautfarbe',
    '🤲🏿' => 'Handflächen nach oben: dunkle Hautfarbe',
    '🤝🏻' => 'Handschlag: helle Hautfarbe',
    '🤝🏼' => 'Handschlag: mittelhelle Hautfarbe',
    '🤝🏽' => 'Handschlag: mittlere Hautfarbe',
    '🤝🏾' => 'Handschlag: mitteldunkle Hautfarbe',
    '🤝🏿' => 'Handschlag: dunkle Hautfarbe',
    '🙏🏻' => 'zusammengelegte Handflächen: helle Hautfarbe',
    '🙏🏼' => 'zusammengelegte Handflächen: mittelhelle Hautfarbe',
    '🙏🏽' => 'zusammengelegte Handflächen: mittlere Hautfarbe',
    '🙏🏾' => 'zusammengelegte Handflächen: mitteldunkle Hautfarbe',
    '🙏🏿' => 'zusammengelegte Handflächen: dunkle Hautfarbe',
    '✍🏻' => 'schreibende Hand: helle Hautfarbe',
    '✍🏼' => 'schreibende Hand: mittelhelle Hautfarbe',
    '✍🏽' => 'schreibende Hand: mittlere Hautfarbe',
    '✍🏾' => 'schreibende Hand: mitteldunkle Hautfarbe',
    '✍🏿' => 'schreibende Hand: dunkle Hautfarbe',
    '💅🏻' => 'Nagellack: helle Hautfarbe',
    '💅🏼' => 'Nagellack: mittelhelle Hautfarbe',
    '💅🏽' => 'Nagellack: mittlere Hautfarbe',
    '💅🏾' => 'Nagellack: mitteldunkle Hautfarbe',
    '💅🏿' => 'Nagellack: dunkle Hautfarbe',
    '🤳🏻' => 'Selfie: helle Hautfarbe',
    '🤳🏼' => 'Selfie: mittelhelle Hautfarbe',
    '🤳🏽' => 'Selfie: mittlere Hautfarbe',
    '🤳🏾' => 'Selfie: mitteldunkle Hautfarbe',
    '🤳🏿' => 'Selfie: dunkle Hautfarbe',
    '💪🏻' => 'angespannter Bizeps: helle Hautfarbe',
    '💪🏼' => 'angespannter Bizeps: mittelhelle Hautfarbe',
    '💪🏽' => 'angespannter Bizeps: mittlere Hautfarbe',
    '💪🏾' => 'angespannter Bizeps: mitteldunkle Hautfarbe',
    '💪🏿' => 'angespannter Bizeps: dunkle Hautfarbe',
    '🦵🏻' => 'Bein: helle Hautfarbe',
    '🦵🏼' => 'Bein: mittelhelle Hautfarbe',
    '🦵🏽' => 'Bein: mittlere Hautfarbe',
    '🦵🏾' => 'Bein: mitteldunkle Hautfarbe',
    '🦵🏿' => 'Bein: dunkle Hautfarbe',
    '🦶🏻' => 'Fuss: helle Hautfarbe',
    '🦶🏼' => 'Fuss: mittelhelle Hautfarbe',
    '🦶🏽' => 'Fuss: mittlere Hautfarbe',
    '🦶🏾' => 'Fuss: mitteldunkle Hautfarbe',
    '🦶🏿' => 'Fuss: dunkle Hautfarbe',
    '👂🏻' => 'Ohr: helle Hautfarbe',
    '👂🏼' => 'Ohr: mittelhelle Hautfarbe',
    '👂🏽' => 'Ohr: mittlere Hautfarbe',
    '👂🏾' => 'Ohr: mitteldunkle Hautfarbe',
    '👂🏿' => 'Ohr: dunkle Hautfarbe',
    '🦻🏻' => 'Ohr mit Hörgerät: helle Hautfarbe',
    '🦻🏼' => 'Ohr mit Hörgerät: mittelhelle Hautfarbe',
    '🦻🏽' => 'Ohr mit Hörgerät: mittlere Hautfarbe',
    '🦻🏾' => 'Ohr mit Hörgerät: mitteldunkle Hautfarbe',
    '🦻🏿' => 'Ohr mit Hörgerät: dunkle Hautfarbe',
    '👃🏻' => 'Nase: helle Hautfarbe',
    '👃🏼' => 'Nase: mittelhelle Hautfarbe',
    '👃🏽' => 'Nase: mittlere Hautfarbe',
    '👃🏾' => 'Nase: mitteldunkle Hautfarbe',
    '👃🏿' => 'Nase: dunkle Hautfarbe',
    '👶🏻' => 'Baby: helle Hautfarbe',
    '👶🏼' => 'Baby: mittelhelle Hautfarbe',
    '👶🏽' => 'Baby: mittlere Hautfarbe',
    '👶🏾' => 'Baby: mitteldunkle Hautfarbe',
    '👶🏿' => 'Baby: dunkle Hautfarbe',
    '🧒🏻' => 'Kind: helle Hautfarbe',
    '🧒🏼' => 'Kind: mittelhelle Hautfarbe',
    '🧒🏽' => 'Kind: mittlere Hautfarbe',
    '🧒🏾' => 'Kind: mitteldunkle Hautfarbe',
    '🧒🏿' => 'Kind: dunkle Hautfarbe',
    '👦🏻' => 'Junge: helle Hautfarbe',
    '👦🏼' => 'Junge: mittelhelle Hautfarbe',
    '👦🏽' => 'Junge: mittlere Hautfarbe',
    '👦🏾' => 'Junge: mitteldunkle Hautfarbe',
    '👦🏿' => 'Junge: dunkle Hautfarbe',
    '👧🏻' => 'Mädchen: helle Hautfarbe',
    '👧🏼' => 'Mädchen: mittelhelle Hautfarbe',
    '👧🏽' => 'Mädchen: mittlere Hautfarbe',
    '👧🏾' => 'Mädchen: mitteldunkle Hautfarbe',
    '👧🏿' => 'Mädchen: dunkle Hautfarbe',
    '🧑🏻' => 'Person: helle Hautfarbe',
    '🧑🏼' => 'Person: mittelhelle Hautfarbe',
    '🧑🏽' => 'Person: mittlere Hautfarbe',
    '🧑🏾' => 'Person: mitteldunkle Hautfarbe',
    '🧑🏿' => 'Person: dunkle Hautfarbe',
    '👱🏻' => 'Person: helle Hautfarbe, blondes Haar',
    '👱🏼' => 'Person: mittelhelle Hautfarbe, blondes Haar',
    '👱🏽' => 'Person: mittlere Hautfarbe, blondes Haar',
    '👱🏾' => 'Person: mitteldunkle Hautfarbe, blondes Haar',
    '👱🏿' => 'Person: dunkle Hautfarbe, blondes Haar',
    '👨🏻' => 'Mann: helle Hautfarbe',
    '👨🏼' => 'Mann: mittelhelle Hautfarbe',
    '👨🏽' => 'Mann: mittlere Hautfarbe',
    '👨🏾' => 'Mann: mitteldunkle Hautfarbe',
    '👨🏿' => 'Mann: dunkle Hautfarbe',
    '🧔🏻' => 'Person: helle Hautfarbe, Bart',
    '🧔🏼' => 'Person: mittelhelle Hautfarbe, Bart',
    '🧔🏽' => 'Person: mittlere Hautfarbe, Bart',
    '🧔🏾' => 'Person: mitteldunkle Hautfarbe, Bart',
    '🧔🏿' => 'Person: dunkle Hautfarbe, Bart',
    '👩🏻' => 'Frau: helle Hautfarbe',
    '👩🏼' => 'Frau: mittelhelle Hautfarbe',
    '👩🏽' => 'Frau: mittlere Hautfarbe',
    '👩🏾' => 'Frau: mitteldunkle Hautfarbe',
    '👩🏿' => 'Frau: dunkle Hautfarbe',
    '🧓🏻' => 'ältere Person: helle Hautfarbe',
    '🧓🏼' => 'ältere Person: mittelhelle Hautfarbe',
    '🧓🏽' => 'ältere Person: mittlere Hautfarbe',
    '🧓🏾' => 'ältere Person: mitteldunkle Hautfarbe',
    '🧓🏿' => 'ältere Person: dunkle Hautfarbe',
    '👴🏻' => 'älterer Mann: helle Hautfarbe',
    '👴🏼' => 'älterer Mann: mittelhelle Hautfarbe',
    '👴🏽' => 'älterer Mann: mittlere Hautfarbe',
    '👴🏾' => 'älterer Mann: mitteldunkle Hautfarbe',
    '👴🏿' => 'älterer Mann: dunkle Hautfarbe',
    '👵🏻' => 'ältere Frau: helle Hautfarbe',
    '👵🏼' => 'ältere Frau: mittelhelle Hautfarbe',
    '👵🏽' => 'ältere Frau: mittlere Hautfarbe',
    '👵🏾' => 'ältere Frau: mitteldunkle Hautfarbe',
    '👵🏿' => 'ältere Frau: dunkle Hautfarbe',
    '🙍🏻' => 'missmutige Person: helle Hautfarbe',
    '🙍🏼' => 'missmutige Person: mittelhelle Hautfarbe',
    '🙍🏽' => 'missmutige Person: mittlere Hautfarbe',
    '🙍🏾' => 'missmutige Person: mitteldunkle Hautfarbe',
    '🙍🏿' => 'missmutige Person: dunkle Hautfarbe',
    '🙎🏻' => 'schmollende Person: helle Hautfarbe',
    '🙎🏼' => 'schmollende Person: mittelhelle Hautfarbe',
    '🙎🏽' => 'schmollende Person: mittlere Hautfarbe',
    '🙎🏾' => 'schmollende Person: mitteldunkle Hautfarbe',
    '🙎🏿' => 'schmollende Person: dunkle Hautfarbe',
    '🙅🏻' => 'Person mit überkreuzten Armen: helle Hautfarbe',
    '🙅🏼' => 'Person mit überkreuzten Armen: mittelhelle Hautfarbe',
    '🙅🏽' => 'Person mit überkreuzten Armen: mittlere Hautfarbe',
    '🙅🏾' => 'Person mit überkreuzten Armen: mitteldunkle Hautfarbe',
    '🙅🏿' => 'Person mit überkreuzten Armen: dunkle Hautfarbe',
    '🙆🏻' => 'Person mit Händen auf dem Kopf: helle Hautfarbe',
    '🙆🏼' => 'Person mit Händen auf dem Kopf: mittelhelle Hautfarbe',
    '🙆🏽' => 'Person mit Händen auf dem Kopf: mittlere Hautfarbe',
    '🙆🏾' => 'Person mit Händen auf dem Kopf: mitteldunkle Hautfarbe',
    '🙆🏿' => 'Person mit Händen auf dem Kopf: dunkle Hautfarbe',
    '💁🏻' => 'Infoschalter-Mitarbeiter(in): helle Hautfarbe',
    '💁🏼' => 'Infoschalter-Mitarbeiter(in): mittelhelle Hautfarbe',
    '💁🏽' => 'Infoschalter-Mitarbeiter(in): mittlere Hautfarbe',
    '💁🏾' => 'Infoschalter-Mitarbeiter(in): mitteldunkle Hautfarbe',
    '💁🏿' => 'Infoschalter-Mitarbeiter(in): dunkle Hautfarbe',
    '🙋🏻' => 'Person mit erhobenem Arm: helle Hautfarbe',
    '🙋🏼' => 'Person mit erhobenem Arm: mittelhelle Hautfarbe',
    '🙋🏽' => 'Person mit erhobenem Arm: mittlere Hautfarbe',
    '🙋🏾' => 'Person mit erhobenem Arm: mitteldunkle Hautfarbe',
    '🙋🏿' => 'Person mit erhobenem Arm: dunkle Hautfarbe',
    '🧏🏻' => 'gehörlose Person: helle Hautfarbe',
    '🧏🏼' => 'gehörlose Person: mittelhelle Hautfarbe',
    '🧏🏽' => 'gehörlose Person: mittlere Hautfarbe',
    '🧏🏾' => 'gehörlose Person: mitteldunkle Hautfarbe',
    '🧏🏿' => 'gehörlose Person: dunkle Hautfarbe',
    '🙇🏻' => 'sich verbeugende Person: helle Hautfarbe',
    '🙇🏼' => 'sich verbeugende Person: mittelhelle Hautfarbe',
    '🙇🏽' => 'sich verbeugende Person: mittlere Hautfarbe',
    '🙇🏾' => 'sich verbeugende Person: mitteldunkle Hautfarbe',
    '🙇🏿' => 'sich verbeugende Person: dunkle Hautfarbe',
    '🤦🏻' => 'sich an den Kopf fassende Person: helle Hautfarbe',
    '🤦🏼' => 'sich an den Kopf fassende Person: mittelhelle Hautfarbe',
    '🤦🏽' => 'sich an den Kopf fassende Person: mittlere Hautfarbe',
    '🤦🏾' => 'sich an den Kopf fassende Person: mitteldunkle Hautfarbe',
    '🤦🏿' => 'sich an den Kopf fassende Person: dunkle Hautfarbe',
    '🤷🏻' => 'schulterzuckende Person: helle Hautfarbe',
    '🤷🏼' => 'schulterzuckende Person: mittelhelle Hautfarbe',
    '🤷🏽' => 'schulterzuckende Person: mittlere Hautfarbe',
    '🤷🏾' => 'schulterzuckende Person: mitteldunkle Hautfarbe',
    '🤷🏿' => 'schulterzuckende Person: dunkle Hautfarbe',
    '👮🏻' => 'Polizist(in): helle Hautfarbe',
    '👮🏼' => 'Polizist(in): mittelhelle Hautfarbe',
    '👮🏽' => 'Polizist(in): mittlere Hautfarbe',
    '👮🏾' => 'Polizist(in): mitteldunkle Hautfarbe',
    '👮🏿' => 'Polizist(in): dunkle Hautfarbe',
    '🕵🏻' => 'Detektiv(in): helle Hautfarbe',
    '🕵🏼' => 'Detektiv(in): mittelhelle Hautfarbe',
    '🕵🏽' => 'Detektiv(in): mittlere Hautfarbe',
    '🕵🏾' => 'Detektiv(in): mitteldunkle Hautfarbe',
    '🕵🏿' => 'Detektiv(in): dunkle Hautfarbe',
    '💂🏻' => 'Wache: helle Hautfarbe',
    '💂🏼' => 'Wache: mittelhelle Hautfarbe',
    '💂🏽' => 'Wache: mittlere Hautfarbe',
    '💂🏾' => 'Wache: mitteldunkle Hautfarbe',
    '💂🏿' => 'Wache: dunkle Hautfarbe',
    '🥷🏻' => 'Ninja: helle Hautfarbe',
    '🥷🏼' => 'Ninja: mittelhelle Hautfarbe',
    '🥷🏽' => 'Ninja: mittlere Hautfarbe',
    '🥷🏾' => 'Ninja: mitteldunkle Hautfarbe',
    '🥷🏿' => 'Ninja: dunkle Hautfarbe',
    '👷🏻' => 'Bauarbeiter(in): helle Hautfarbe',
    '👷🏼' => 'Bauarbeiter(in): mittelhelle Hautfarbe',
    '👷🏽' => 'Bauarbeiter(in): mittlere Hautfarbe',
    '👷🏾' => 'Bauarbeiter(in): mitteldunkle Hautfarbe',
    '👷🏿' => 'Bauarbeiter(in): dunkle Hautfarbe',
    '🫅🏻' => 'Person mit Krone: helle Hautfarbe',
    '🫅🏼' => 'Person mit Krone: mittelhelle Hautfarbe',
    '🫅🏽' => 'Person mit Krone: mittlere Hautfarbe',
    '🫅🏾' => 'Person mit Krone: mitteldunkle Hautfarbe',
    '🫅🏿' => 'Person mit Krone: dunkle Hautfarbe',
    '🤴🏻' => 'Prinz: helle Hautfarbe',
    '🤴🏼' => 'Prinz: mittelhelle Hautfarbe',
    '🤴🏽' => 'Prinz: mittlere Hautfarbe',
    '🤴🏾' => 'Prinz: mitteldunkle Hautfarbe',
    '🤴🏿' => 'Prinz: dunkle Hautfarbe',
    '👸🏻' => 'Prinzessin: helle Hautfarbe',
    '👸🏼' => 'Prinzessin: mittelhelle Hautfarbe',
    '👸🏽' => 'Prinzessin: mittlere Hautfarbe',
    '👸🏾' => 'Prinzessin: mitteldunkle Hautfarbe',
    '👸🏿' => 'Prinzessin: dunkle Hautfarbe',
    '👳🏻' => 'Person mit Turban: helle Hautfarbe',
    '👳🏼' => 'Person mit Turban: mittelhelle Hautfarbe',
    '👳🏽' => 'Person mit Turban: mittlere Hautfarbe',
    '👳🏾' => 'Person mit Turban: mitteldunkle Hautfarbe',
    '👳🏿' => 'Person mit Turban: dunkle Hautfarbe',
    '👲🏻' => 'Mann mit chinesischem Hut: helle Hautfarbe',
    '👲🏼' => 'Mann mit chinesischem Hut: mittelhelle Hautfarbe',
    '👲🏽' => 'Mann mit chinesischem Hut: mittlere Hautfarbe',
    '👲🏾' => 'Mann mit chinesischem Hut: mitteldunkle Hautfarbe',
    '👲🏿' => 'Mann mit chinesischem Hut: dunkle Hautfarbe',
    '🧕🏻' => 'Frau mit Kopftuch: helle Hautfarbe',
    '🧕🏼' => 'Frau mit Kopftuch: mittelhelle Hautfarbe',
    '🧕🏽' => 'Frau mit Kopftuch: mittlere Hautfarbe',
    '🧕🏾' => 'Frau mit Kopftuch: mitteldunkle Hautfarbe',
    '🧕🏿' => 'Frau mit Kopftuch: dunkle Hautfarbe',
    '🤵🏻' => 'Person im Smoking: helle Hautfarbe',
    '🤵🏼' => 'Person im Smoking: mittelhelle Hautfarbe',
    '🤵🏽' => 'Person im Smoking: mittlere Hautfarbe',
    '🤵🏾' => 'Person im Smoking: mitteldunkle Hautfarbe',
    '🤵🏿' => 'Person im Smoking: dunkle Hautfarbe',
    '👰🏻' => 'Person mit Schleier: helle Hautfarbe',
    '👰🏼' => 'Person mit Schleier: mittelhelle Hautfarbe',
    '👰🏽' => 'Person mit Schleier: mittlere Hautfarbe',
    '👰🏾' => 'Person mit Schleier: mitteldunkle Hautfarbe',
    '👰🏿' => 'Person mit Schleier: dunkle Hautfarbe',
    '🤰🏻' => 'schwangere Frau: helle Hautfarbe',
    '🤰🏼' => 'schwangere Frau: mittelhelle Hautfarbe',
    '🤰🏽' => 'schwangere Frau: mittlere Hautfarbe',
    '🤰🏾' => 'schwangere Frau: mitteldunkle Hautfarbe',
    '🤰🏿' => 'schwangere Frau: dunkle Hautfarbe',
    '🫃🏻' => 'schwangerer Mann: helle Hautfarbe',
    '🫃🏼' => 'schwangerer Mann: mittelhelle Hautfarbe',
    '🫃🏽' => 'schwangerer Mann: mittlere Hautfarbe',
    '🫃🏾' => 'schwangerer Mann: mitteldunkle Hautfarbe',
    '🫃🏿' => 'schwangerer Mann: dunkle Hautfarbe',
    '🫄🏻' => 'schwangere Person: helle Hautfarbe',
    '🫄🏼' => 'schwangere Person: mittelhelle Hautfarbe',
    '🫄🏽' => 'schwangere Person: mittlere Hautfarbe',
    '🫄🏾' => 'schwangere Person: mitteldunkle Hautfarbe',
    '🫄🏿' => 'schwangere Person: dunkle Hautfarbe',
    '🤱🏻' => 'Stillen: helle Hautfarbe',
    '🤱🏼' => 'Stillen: mittelhelle Hautfarbe',
    '🤱🏽' => 'Stillen: mittlere Hautfarbe',
    '🤱🏾' => 'Stillen: mitteldunkle Hautfarbe',
    '🤱🏿' => 'Stillen: dunkle Hautfarbe',
    '👼🏻' => 'Putte: helle Hautfarbe',
    '👼🏼' => 'Putte: mittelhelle Hautfarbe',
    '👼🏽' => 'Putte: mittlere Hautfarbe',
    '👼🏾' => 'Putte: mitteldunkle Hautfarbe',
    '👼🏿' => 'Putte: dunkle Hautfarbe',
    '🎅🏻' => 'Weihnachtsmann: helle Hautfarbe',
    '🎅🏼' => 'Weihnachtsmann: mittelhelle Hautfarbe',
    '🎅🏽' => 'Weihnachtsmann: mittlere Hautfarbe',
    '🎅🏾' => 'Weihnachtsmann: mitteldunkle Hautfarbe',
    '🎅🏿' => 'Weihnachtsmann: dunkle Hautfarbe',
    '🤶🏻' => 'Weihnachtsfrau: helle Hautfarbe',
    '🤶🏼' => 'Weihnachtsfrau: mittelhelle Hautfarbe',
    '🤶🏽' => 'Weihnachtsfrau: mittlere Hautfarbe',
    '🤶🏾' => 'Weihnachtsfrau: mitteldunkle Hautfarbe',
    '🤶🏿' => 'Weihnachtsfrau: dunkle Hautfarbe',
    '🦸🏻' => 'Superheld(in): helle Hautfarbe',
    '🦸🏼' => 'Superheld(in): mittelhelle Hautfarbe',
    '🦸🏽' => 'Superheld(in): mittlere Hautfarbe',
    '🦸🏾' => 'Superheld(in): mitteldunkle Hautfarbe',
    '🦸🏿' => 'Superheld(in): dunkle Hautfarbe',
    '🦹🏻' => 'Bösewicht: helle Hautfarbe',
    '🦹🏼' => 'Bösewicht: mittelhelle Hautfarbe',
    '🦹🏽' => 'Bösewicht: mittlere Hautfarbe',
    '🦹🏾' => 'Bösewicht: mitteldunkle Hautfarbe',
    '🦹🏿' => 'Bösewicht: dunkle Hautfarbe',
    '🧙🏻' => 'Magier(in): helle Hautfarbe',
    '🧙🏼' => 'Magier(in): mittelhelle Hautfarbe',
    '🧙🏽' => 'Magier(in): mittlere Hautfarbe',
    '🧙🏾' => 'Magier(in): mitteldunkle Hautfarbe',
    '🧙🏿' => 'Magier(in): dunkle Hautfarbe',
    '🧚🏻' => 'Märchenfee: helle Hautfarbe',
    '🧚🏼' => 'Märchenfee: mittelhelle Hautfarbe',
    '🧚🏽' => 'Märchenfee: mittlere Hautfarbe',
    '🧚🏾' => 'Märchenfee: mitteldunkle Hautfarbe',
    '🧚🏿' => 'Märchenfee: dunkle Hautfarbe',
    '🧛🏻' => 'Vampir: helle Hautfarbe',
    '🧛🏼' => 'Vampir: mittelhelle Hautfarbe',
    '🧛🏽' => 'Vampir: mittlere Hautfarbe',
    '🧛🏾' => 'Vampir: mitteldunkle Hautfarbe',
    '🧛🏿' => 'Vampir: dunkle Hautfarbe',
    '🧜🏻' => 'Wassermensch: helle Hautfarbe',
    '🧜🏼' => 'Wassermensch: mittelhelle Hautfarbe',
    '🧜🏽' => 'Wassermensch: mittlere Hautfarbe',
    '🧜🏾' => 'Wassermensch: mitteldunkle Hautfarbe',
    '🧜🏿' => 'Wassermensch: dunkle Hautfarbe',
    '🧝🏻' => 'Elf(e): helle Hautfarbe',
    '🧝🏼' => 'Elf(e): mittelhelle Hautfarbe',
    '🧝🏽' => 'Elf(e): mittlere Hautfarbe',
    '🧝🏾' => 'Elf(e): mitteldunkle Hautfarbe',
    '🧝🏿' => 'Elf(e): dunkle Hautfarbe',
    '💆🏻' => 'Person, die eine Kopfmassage bekommt: helle Hautfarbe',
    '💆🏼' => 'Person, die eine Kopfmassage bekommt: mittelhelle Hautfarbe',
    '💆🏽' => 'Person, die eine Kopfmassage bekommt: mittlere Hautfarbe',
    '💆🏾' => 'Person, die eine Kopfmassage bekommt: mitteldunkle Hautfarbe',
    '💆🏿' => 'Person, die eine Kopfmassage bekommt: dunkle Hautfarbe',
    '💇🏻' => 'Person beim Haareschneiden: helle Hautfarbe',
    '💇🏼' => 'Person beim Haareschneiden: mittelhelle Hautfarbe',
    '💇🏽' => 'Person beim Haareschneiden: mittlere Hautfarbe',
    '💇🏾' => 'Person beim Haareschneiden: mitteldunkle Hautfarbe',
    '💇🏿' => 'Person beim Haareschneiden: dunkle Hautfarbe',
    '🚶🏻' => 'Fussgänger(in): helle Hautfarbe',
    '🚶🏼' => 'Fussgänger(in): mittelhelle Hautfarbe',
    '🚶🏽' => 'Fussgänger(in): mittlere Hautfarbe',
    '🚶🏾' => 'Fussgänger(in): mitteldunkle Hautfarbe',
    '🚶🏿' => 'Fussgänger(in): dunkle Hautfarbe',
    '🧍🏻' => 'stehende Person: helle Hautfarbe',
    '🧍🏼' => 'stehende Person: mittelhelle Hautfarbe',
    '🧍🏽' => 'stehende Person: mittlere Hautfarbe',
    '🧍🏾' => 'stehende Person: mitteldunkle Hautfarbe',
    '🧍🏿' => 'stehende Person: dunkle Hautfarbe',
    '🧎🏻' => 'kniende Person: helle Hautfarbe',
    '🧎🏼' => 'kniende Person: mittelhelle Hautfarbe',
    '🧎🏽' => 'kniende Person: mittlere Hautfarbe',
    '🧎🏾' => 'kniende Person: mitteldunkle Hautfarbe',
    '🧎🏿' => 'kniende Person: dunkle Hautfarbe',
    '🏃🏻' => 'laufende Person: helle Hautfarbe',
    '🏃🏼' => 'laufende Person: mittelhelle Hautfarbe',
    '🏃🏽' => 'laufende Person: mittlere Hautfarbe',
    '🏃🏾' => 'laufende Person: mitteldunkle Hautfarbe',
    '🏃🏿' => 'laufende Person: dunkle Hautfarbe',
    '💃🏻' => 'tanzende Frau: helle Hautfarbe',
    '💃🏼' => 'tanzende Frau: mittelhelle Hautfarbe',
    '💃🏽' => 'tanzende Frau: mittlere Hautfarbe',
    '💃🏾' => 'tanzende Frau: mitteldunkle Hautfarbe',
    '💃🏿' => 'tanzende Frau: dunkle Hautfarbe',
    '🕺🏻' => 'tanzender Mann: helle Hautfarbe',
    '🕺🏼' => 'tanzender Mann: mittelhelle Hautfarbe',
    '🕺🏽' => 'tanzender Mann: mittlere Hautfarbe',
    '🕺🏾' => 'tanzender Mann: mitteldunkle Hautfarbe',
    '🕺🏿' => 'tanzender Mann: dunkle Hautfarbe',
    '🕴🏻' => 'schwebender Mann im Anzug: helle Hautfarbe',
    '🕴🏼' => 'schwebender Mann im Anzug: mittelhelle Hautfarbe',
    '🕴🏽' => 'schwebender Mann im Anzug: mittlere Hautfarbe',
    '🕴🏾' => 'schwebender Mann im Anzug: mitteldunkle Hautfarbe',
    '🕴🏿' => 'schwebender Mann im Anzug: dunkle Hautfarbe',
    '👯🏻' => 'Personen mit Hasenohren: helle Hautfarbe',
    '👯🏼' => 'Personen mit Hasenohren: mittelhelle Hautfarbe',
    '👯🏽' => 'Personen mit Hasenohren: mittlere Hautfarbe',
    '👯🏾' => 'Personen mit Hasenohren: mitteldunkle Hautfarbe',
    '👯🏿' => 'Personen mit Hasenohren: dunkle Hautfarbe',
    '🧖🏻' => 'Person in Dampfsauna: helle Hautfarbe',
    '🧖🏼' => 'Person in Dampfsauna: mittelhelle Hautfarbe',
    '🧖🏽' => 'Person in Dampfsauna: mittlere Hautfarbe',
    '🧖🏾' => 'Person in Dampfsauna: mitteldunkle Hautfarbe',
    '🧖🏿' => 'Person in Dampfsauna: dunkle Hautfarbe',
    '🧗🏻' => 'Bergsteiger(in): helle Hautfarbe',
    '🧗🏼' => 'Bergsteiger(in): mittelhelle Hautfarbe',
    '🧗🏽' => 'Bergsteiger(in): mittlere Hautfarbe',
    '🧗🏾' => 'Bergsteiger(in): mitteldunkle Hautfarbe',
    '🧗🏿' => 'Bergsteiger(in): dunkle Hautfarbe',
    '🏇🏻' => 'Pferderennen: helle Hautfarbe',
    '🏇🏼' => 'Pferderennen: mittelhelle Hautfarbe',
    '🏇🏽' => 'Pferderennen: mittlere Hautfarbe',
    '🏇🏾' => 'Pferderennen: mitteldunkle Hautfarbe',
    '🏇🏿' => 'Pferderennen: dunkle Hautfarbe',
    '🏂🏻' => 'Snowboarder(in): helle Hautfarbe',
    '🏂🏼' => 'Snowboarder(in): mittelhelle Hautfarbe',
    '🏂🏽' => 'Snowboarder(in): mittlere Hautfarbe',
    '🏂🏾' => 'Snowboarder(in): mitteldunkle Hautfarbe',
    '🏂🏿' => 'Snowboarder(in): dunkle Hautfarbe',
    '🏌🏻' => 'Golfer(in): helle Hautfarbe',
    '🏌🏼' => 'Golfer(in): mittelhelle Hautfarbe',
    '🏌🏽' => 'Golfer(in): mittlere Hautfarbe',
    '🏌🏾' => 'Golfer(in): mitteldunkle Hautfarbe',
    '🏌🏿' => 'Golfer(in): dunkle Hautfarbe',
    '🏄🏻' => 'Surfer(in): helle Hautfarbe',
    '🏄🏼' => 'Surfer(in): mittelhelle Hautfarbe',
    '🏄🏽' => 'Surfer(in): mittlere Hautfarbe',
    '🏄🏾' => 'Surfer(in): mitteldunkle Hautfarbe',
    '🏄🏿' => 'Surfer(in): dunkle Hautfarbe',
    '🚣🏻' => 'Person im Ruderboot: helle Hautfarbe',
    '🚣🏼' => 'Person im Ruderboot: mittelhelle Hautfarbe',
    '🚣🏽' => 'Person im Ruderboot: mittlere Hautfarbe',
    '🚣🏾' => 'Person im Ruderboot: mitteldunkle Hautfarbe',
    '🚣🏿' => 'Person im Ruderboot: dunkle Hautfarbe',
    '🏊🏻' => 'Schwimmer(in): helle Hautfarbe',
    '🏊🏼' => 'Schwimmer(in): mittelhelle Hautfarbe',
    '🏊🏽' => 'Schwimmer(in): mittlere Hautfarbe',
    '🏊🏾' => 'Schwimmer(in): mitteldunkle Hautfarbe',
    '🏊🏿' => 'Schwimmer(in): dunkle Hautfarbe',
    '⛹🏻' => 'Person mit Ball: helle Hautfarbe',
    '⛹🏼' => 'Person mit Ball: mittelhelle Hautfarbe',
    '⛹🏽' => 'Person mit Ball: mittlere Hautfarbe',
    '⛹🏾' => 'Person mit Ball: mitteldunkle Hautfarbe',
    '⛹🏿' => 'Person mit Ball: dunkle Hautfarbe',
    '🏋🏻' => 'Gewichtheber(in): helle Hautfarbe',
    '🏋🏼' => 'Gewichtheber(in): mittelhelle Hautfarbe',
    '🏋🏽' => 'Gewichtheber(in): mittlere Hautfarbe',
    '🏋🏾' => 'Gewichtheber(in): mitteldunkle Hautfarbe',
    '🏋🏿' => 'Gewichtheber(in): dunkle Hautfarbe',
    '🚴🏻' => 'Radfahrer(in): helle Hautfarbe',
    '🚴🏼' => 'Radfahrer(in): mittelhelle Hautfarbe',
    '🚴🏽' => 'Radfahrer(in): mittlere Hautfarbe',
    '🚴🏾' => 'Radfahrer(in): mitteldunkle Hautfarbe',
    '🚴🏿' => 'Radfahrer(in): dunkle Hautfarbe',
    '🚵🏻' => 'Mountainbiker(in): helle Hautfarbe',
    '🚵🏼' => 'Mountainbiker(in): mittelhelle Hautfarbe',
    '🚵🏽' => 'Mountainbiker(in): mittlere Hautfarbe',
    '🚵🏾' => 'Mountainbiker(in): mitteldunkle Hautfarbe',
    '🚵🏿' => 'Mountainbiker(in): dunkle Hautfarbe',
    '🤸🏻' => 'Rad schlagende Person: helle Hautfarbe',
    '🤸🏼' => 'Rad schlagende Person: mittelhelle Hautfarbe',
    '🤸🏽' => 'Rad schlagende Person: mittlere Hautfarbe',
    '🤸🏾' => 'Rad schlagende Person: mitteldunkle Hautfarbe',
    '🤸🏿' => 'Rad schlagende Person: dunkle Hautfarbe',
    '🤼🏻' => 'Ringer(in): helle Hautfarbe',
    '🤼🏼' => 'Ringer(in): mittelhelle Hautfarbe',
    '🤼🏽' => 'Ringer(in): mittlere Hautfarbe',
    '🤼🏾' => 'Ringer(in): mitteldunkle Hautfarbe',
    '🤼🏿' => 'Ringer(in): dunkle Hautfarbe',
    '🤽🏻' => 'Wasserballspieler(in): helle Hautfarbe',
    '🤽🏼' => 'Wasserballspieler(in): mittelhelle Hautfarbe',
    '🤽🏽' => 'Wasserballspieler(in): mittlere Hautfarbe',
    '🤽🏾' => 'Wasserballspieler(in): mitteldunkle Hautfarbe',
    '🤽🏿' => 'Wasserballspieler(in): dunkle Hautfarbe',
    '🤾🏻' => 'Handballspieler(in): helle Hautfarbe',
    '🤾🏼' => 'Handballspieler(in): mittelhelle Hautfarbe',
    '🤾🏽' => 'Handballspieler(in): mittlere Hautfarbe',
    '🤾🏾' => 'Handballspieler(in): mitteldunkle Hautfarbe',
    '🤾🏿' => 'Handballspieler(in): dunkle Hautfarbe',
    '🤹🏻' => 'Jongleur(in): helle Hautfarbe',
    '🤹🏼' => 'Jongleur(in): mittelhelle Hautfarbe',
    '🤹🏽' => 'Jongleur(in): mittlere Hautfarbe',
    '🤹🏾' => 'Jongleur(in): mitteldunkle Hautfarbe',
    '🤹🏿' => 'Jongleur(in): dunkle Hautfarbe',
    '🧘🏻' => 'Person im Lotossitz: helle Hautfarbe',
    '🧘🏼' => 'Person im Lotossitz: mittelhelle Hautfarbe',
    '🧘🏽' => 'Person im Lotossitz: mittlere Hautfarbe',
    '🧘🏾' => 'Person im Lotossitz: mitteldunkle Hautfarbe',
    '🧘🏿' => 'Person im Lotossitz: dunkle Hautfarbe',
    '🛀🏻' => 'badende Person: helle Hautfarbe',
    '🛀🏼' => 'badende Person: mittelhelle Hautfarbe',
    '🛀🏽' => 'badende Person: mittlere Hautfarbe',
    '🛀🏾' => 'badende Person: mitteldunkle Hautfarbe',
    '🛀🏿' => 'badende Person: dunkle Hautfarbe',
    '🛌🏻' => 'im Bett liegende Person: helle Hautfarbe',
    '🛌🏼' => 'im Bett liegende Person: mittelhelle Hautfarbe',
    '🛌🏽' => 'im Bett liegende Person: mittlere Hautfarbe',
    '🛌🏾' => 'im Bett liegende Person: mitteldunkle Hautfarbe',
    '🛌🏿' => 'im Bett liegende Person: dunkle Hautfarbe',
    '👭🏻' => 'Händchen haltende Frauen: helle Hautfarbe',
    '👭🏼' => 'Händchen haltende Frauen: mittelhelle Hautfarbe',
    '👭🏽' => 'Händchen haltende Frauen: mittlere Hautfarbe',
    '👭🏾' => 'Händchen haltende Frauen: mitteldunkle Hautfarbe',
    '👭🏿' => 'Händchen haltende Frauen: dunkle Hautfarbe',
    '👫🏻' => 'Mann und Frau halten Hände: helle Hautfarbe',
    '👫🏼' => 'Mann und Frau halten Hände: mittelhelle Hautfarbe',
    '👫🏽' => 'Mann und Frau halten Hände: mittlere Hautfarbe',
    '👫🏾' => 'Mann und Frau halten Hände: mitteldunkle Hautfarbe',
    '👫🏿' => 'Mann und Frau halten Hände: dunkle Hautfarbe',
    '👬🏻' => 'Händchen haltende Männer: helle Hautfarbe',
    '👬🏼' => 'Händchen haltende Männer: mittelhelle Hautfarbe',
    '👬🏽' => 'Händchen haltende Männer: mittlere Hautfarbe',
    '👬🏾' => 'Händchen haltende Männer: mitteldunkle Hautfarbe',
    '👬🏿' => 'Händchen haltende Männer: dunkle Hautfarbe',
    '💏🏻' => 'sich küssendes Paar: helle Hautfarbe',
    '💏🏼' => 'sich küssendes Paar: mittelhelle Hautfarbe',
    '💏🏽' => 'sich küssendes Paar: mittlere Hautfarbe',
    '💏🏾' => 'sich küssendes Paar: mitteldunkle Hautfarbe',
    '💏🏿' => 'sich küssendes Paar: dunkle Hautfarbe',
    '💑🏻' => 'Liebespaar: helle Hautfarbe',
    '💑🏼' => 'Liebespaar: mittelhelle Hautfarbe',
    '💑🏽' => 'Liebespaar: mittlere Hautfarbe',
    '💑🏾' => 'Liebespaar: mitteldunkle Hautfarbe',
    '💑🏿' => 'Liebespaar: dunkle Hautfarbe',
    '🇦🇨' => 'Flagge: Ascension',
    '🇦🇩' => 'Flagge: Andorra',
    '🇦🇪' => 'Flagge: Vereinigte Arabische Emirate',
    '🇦🇫' => 'Flagge: Afghanistan',
    '🇦🇬' => 'Flagge: Antigua und Barbuda',
    '🇦🇮' => 'Flagge: Anguilla',
    '🇦🇱' => 'Flagge: Albanien',
    '🇦🇲' => 'Flagge: Armenien',
    '🇦🇴' => 'Flagge: Angola',
    '🇦🇶' => 'Flagge: Antarktis',
    '🇦🇷' => 'Flagge: Argentinien',
    '🇦🇸' => 'Flagge: Amerikanisch-Samoa',
    '🇦🇹' => 'Flagge: Österreich',
    '🇦🇺' => 'Flagge: Australien',
    '🇦🇼' => 'Flagge: Aruba',
    '🇦🇽' => 'Flagge: Ålandinseln',
    '🇦🇿' => 'Flagge: Aserbaidschan',
    '🇧🇦' => 'Flagge: Bosnien und Herzegowina',
    '🇧🇧' => 'Flagge: Barbados',
    '🇧🇩' => 'Flagge: Bangladesch',
    '🇧🇪' => 'Flagge: Belgien',
    '🇧🇫' => 'Flagge: Burkina Faso',
    '🇧🇬' => 'Flagge: Bulgarien',
    '🇧🇭' => 'Flagge: Bahrain',
    '🇧🇮' => 'Flagge: Burundi',
    '🇧🇯' => 'Flagge: Benin',
    '🇧🇱' => 'Flagge: St. Barthélemy',
    '🇧🇲' => 'Flagge: Bermuda',
    '🇧🇳' => 'Flagge: Brunei Darussalam',
    '🇧🇴' => 'Flagge: Bolivien',
    '🇧🇶' => 'Flagge: Karibische Niederlande',
    '🇧🇷' => 'Flagge: Brasilien',
    '🇧🇸' => 'Flagge: Bahamas',
    '🇧🇹' => 'Flagge: Bhutan',
    '🇧🇻' => 'Flagge: Bouvetinsel',
    '🇧🇼' => 'Flagge: Botsuana',
    '🇧🇾' => 'Flagge: Belarus',
    '🇧🇿' => 'Flagge: Belize',
    '🇨🇦' => 'Flagge: Kanada',
    '🇨🇨' => 'Flagge: Kokosinseln',
    '🇨🇩' => 'Flagge: Kongo-Kinshasa',
    '🇨🇫' => 'Flagge: Zentralafrikanische Republik',
    '🇨🇬' => 'Flagge: Kongo-Brazzaville',
    '🇨🇭' => 'Flagge: Schweiz',
    '🇨🇮' => 'Flagge: Côte d’Ivoire',
    '🇨🇰' => 'Flagge: Cookinseln',
    '🇨🇱' => 'Flagge: Chile',
    '🇨🇲' => 'Flagge: Kamerun',
    '🇨🇳' => 'Flagge: China',
    '🇨🇴' => 'Flagge: Kolumbien',
    '🇨🇵' => 'Flagge: Clipperton-Insel',
    '🇨🇶' => 'Flagge: Sark',
    '🇨🇷' => 'Flagge: Costa Rica',
    '🇨🇺' => 'Flagge: Kuba',
    '🇨🇻' => 'Flagge: Cabo Verde',
    '🇨🇼' => 'Flagge: Curaçao',
    '🇨🇽' => 'Flagge: Weihnachtsinsel',
    '🇨🇾' => 'Flagge: Zypern',
    '🇨🇿' => 'Flagge: Tschechien',
    '🇩🇪' => 'Flagge: Deutschland',
    '🇩🇬' => 'Flagge: Diego Garcia',
    '🇩🇯' => 'Flagge: Dschibuti',
    '🇩🇰' => 'Flagge: Dänemark',
    '🇩🇲' => 'Flagge: Dominica',
    '🇩🇴' => 'Flagge: Dominikanische Republik',
    '🇩🇿' => 'Flagge: Algerien',
    '🇪🇦' => 'Flagge: Ceuta und Melilla',
    '🇪🇨' => 'Flagge: Ecuador',
    '🇪🇪' => 'Flagge: Estland',
    '🇪🇬' => 'Flagge: Ägypten',
    '🇪🇭' => 'Flagge: Westsahara',
    '🇪🇷' => 'Flagge: Eritrea',
    '🇪🇸' => 'Flagge: Spanien',
    '🇪🇹' => 'Flagge: Äthiopien',
    '🇪🇺' => 'Flagge: Europäische Union',
    '🇫🇮' => 'Flagge: Finnland',
    '🇫🇯' => 'Flagge: Fidschi',
    '🇫🇰' => 'Flagge: Falklandinseln',
    '🇫🇲' => 'Flagge: Mikronesien',
    '🇫🇴' => 'Flagge: Färöer',
    '🇫🇷' => 'Flagge: Frankreich',
    '🇬🇦' => 'Flagge: Gabun',
    '🇬🇧' => 'Flagge: Vereinigtes Königreich',
    '🇬🇩' => 'Flagge: Grenada',
    '🇬🇪' => 'Flagge: Georgien',
    '🇬🇫' => 'Flagge: Französisch-Guayana',
    '🇬🇬' => 'Flagge: Guernsey',
    '🇬🇭' => 'Flagge: Ghana',
    '🇬🇮' => 'Flagge: Gibraltar',
    '🇬🇱' => 'Flagge: Grönland',
    '🇬🇲' => 'Flagge: Gambia',
    '🇬🇳' => 'Flagge: Guinea',
    '🇬🇵' => 'Flagge: Guadeloupe',
    '🇬🇶' => 'Flagge: Äquatorialguinea',
    '🇬🇷' => 'Flagge: Griechenland',
    '🇬🇸' => 'Flagge: Südgeorgien und die Südlichen Sandwichinseln',
    '🇬🇹' => 'Flagge: Guatemala',
    '🇬🇺' => 'Flagge: Guam',
    '🇬🇼' => 'Flagge: Guinea-Bissau',
    '🇬🇾' => 'Flagge: Guyana',
    '🇭🇰' => 'Flagge: Sonderverwaltungsregion Hongkong',
    '🇭🇲' => 'Flagge: Heard und McDonaldinseln',
    '🇭🇳' => 'Flagge: Honduras',
    '🇭🇷' => 'Flagge: Kroatien',
    '🇭🇹' => 'Flagge: Haiti',
    '🇭🇺' => 'Flagge: Ungarn',
    '🇮🇨' => 'Flagge: Kanarische Inseln',
    '🇮🇩' => 'Flagge: Indonesien',
    '🇮🇪' => 'Flagge: Irland',
    '🇮🇱' => 'Flagge: Israel',
    '🇮🇲' => 'Flagge: Isle of Man',
    '🇮🇳' => 'Flagge: Indien',
    '🇮🇴' => 'Flagge: Britisches Territorium im Indischen Ozean',
    '🇮🇶' => 'Flagge: Irak',
    '🇮🇷' => 'Flagge: Iran',
    '🇮🇸' => 'Flagge: Island',
    '🇮🇹' => 'Flagge: Italien',
    '🇯🇪' => 'Flagge: Jersey',
    '🇯🇲' => 'Flagge: Jamaika',
    '🇯🇴' => 'Flagge: Jordanien',
    '🇯🇵' => 'Flagge: Japan',
    '🇰🇪' => 'Flagge: Kenia',
    '🇰🇬' => 'Flagge: Kirgisistan',
    '🇰🇭' => 'Flagge: Kambodscha',
    '🇰🇮' => 'Flagge: Kiribati',
    '🇰🇲' => 'Flagge: Komoren',
    '🇰🇳' => 'Flagge: St. Kitts und Nevis',
    '🇰🇵' => 'Flagge: Nordkorea',
    '🇰🇷' => 'Flagge: Südkorea',
    '🇰🇼' => 'Flagge: Kuwait',
    '🇰🇾' => 'Flagge: Kaimaninseln',
    '🇰🇿' => 'Flagge: Kasachstan',
    '🇱🇦' => 'Flagge: Laos',
    '🇱🇧' => 'Flagge: Libanon',
    '🇱🇨' => 'Flagge: St. Lucia',
    '🇱🇮' => 'Flagge: Liechtenstein',
    '🇱🇰' => 'Flagge: Sri Lanka',
    '🇱🇷' => 'Flagge: Liberia',
    '🇱🇸' => 'Flagge: Lesotho',
    '🇱🇹' => 'Flagge: Litauen',
    '🇱🇺' => 'Flagge: Luxemburg',
    '🇱🇻' => 'Flagge: Lettland',
    '🇱🇾' => 'Flagge: Libyen',
    '🇲🇦' => 'Flagge: Marokko',
    '🇲🇨' => 'Flagge: Monaco',
    '🇲🇩' => 'Flagge: Republik Moldau',
    '🇲🇪' => 'Flagge: Montenegro',
    '🇲🇫' => 'Flagge: St. Martin',
    '🇲🇬' => 'Flagge: Madagaskar',
    '🇲🇭' => 'Flagge: Marshallinseln',
    '🇲🇰' => 'Flagge: Nordmazedonien',
    '🇲🇱' => 'Flagge: Mali',
    '🇲🇲' => 'Flagge: Myanmar',
    '🇲🇳' => 'Flagge: Mongolei',
    '🇲🇴' => 'Flagge: Sonderverwaltungsregion Macau',
    '🇲🇵' => 'Flagge: Nördliche Marianen',
    '🇲🇶' => 'Flagge: Martinique',
    '🇲🇷' => 'Flagge: Mauretanien',
    '🇲🇸' => 'Flagge: Montserrat',
    '🇲🇹' => 'Flagge: Malta',
    '🇲🇺' => 'Flagge: Mauritius',
    '🇲🇻' => 'Flagge: Malediven',
    '🇲🇼' => 'Flagge: Malawi',
    '🇲🇽' => 'Flagge: Mexiko',
    '🇲🇾' => 'Flagge: Malaysia',
    '🇲🇿' => 'Flagge: Mosambik',
    '🇳🇦' => 'Flagge: Namibia',
    '🇳🇨' => 'Flagge: Neukaledonien',
    '🇳🇪' => 'Flagge: Niger',
    '🇳🇫' => 'Flagge: Norfolkinsel',
    '🇳🇬' => 'Flagge: Nigeria',
    '🇳🇮' => 'Flagge: Nicaragua',
    '🇳🇱' => 'Flagge: Niederlande',
    '🇳🇴' => 'Flagge: Norwegen',
    '🇳🇵' => 'Flagge: Nepal',
    '🇳🇷' => 'Flagge: Nauru',
    '🇳🇺' => 'Flagge: Niue',
    '🇳🇿' => 'Flagge: Neuseeland',
    '🇴🇲' => 'Flagge: Oman',
    '🇵🇦' => 'Flagge: Panama',
    '🇵🇪' => 'Flagge: Peru',
    '🇵🇫' => 'Flagge: Französisch-Polynesien',
    '🇵🇬' => 'Flagge: Papua-Neuguinea',
    '🇵🇭' => 'Flagge: Philippinen',
    '🇵🇰' => 'Flagge: Pakistan',
    '🇵🇱' => 'Flagge: Polen',
    '🇵🇲' => 'Flagge: St. Pierre und Miquelon',
    '🇵🇳' => 'Flagge: Pitcairninseln',
    '🇵🇷' => 'Flagge: Puerto Rico',
    '🇵🇸' => 'Flagge: Palästinensische Autonomiegebiete',
    '🇵🇹' => 'Flagge: Portugal',
    '🇵🇼' => 'Flagge: Palau',
    '🇵🇾' => 'Flagge: Paraguay',
    '🇶🇦' => 'Flagge: Katar',
    '🇷🇪' => 'Flagge: Réunion',
    '🇷🇴' => 'Flagge: Rumänien',
    '🇷🇸' => 'Flagge: Serbien',
    '🇷🇺' => 'Flagge: Russland',
    '🇷🇼' => 'Flagge: Ruanda',
    '🇸🇦' => 'Flagge: Saudi-Arabien',
    '🇸🇧' => 'Flagge: Salomonen',
    '🇸🇨' => 'Flagge: Seychellen',
    '🇸🇩' => 'Flagge: Sudan',
    '🇸🇪' => 'Flagge: Schweden',
    '🇸🇬' => 'Flagge: Singapur',
    '🇸🇭' => 'Flagge: St. Helena',
    '🇸🇮' => 'Flagge: Slowenien',
    '🇸🇯' => 'Flagge: Spitzbergen und Jan Mayen',
    '🇸🇰' => 'Flagge: Slowakei',
    '🇸🇱' => 'Flagge: Sierra Leone',
    '🇸🇲' => 'Flagge: San Marino',
    '🇸🇳' => 'Flagge: Senegal',
    '🇸🇴' => 'Flagge: Somalia',
    '🇸🇷' => 'Flagge: Suriname',
    '🇸🇸' => 'Flagge: Südsudan',
    '🇸🇹' => 'Flagge: São Tomé und Príncipe',
    '🇸🇻' => 'Flagge: El Salvador',
    '🇸🇽' => 'Flagge: Sint Maarten',
    '🇸🇾' => 'Flagge: Syrien',
    '🇸🇿' => 'Flagge: Eswatini',
    '🇹🇦' => 'Flagge: Tristan da Cunha',
    '🇹🇨' => 'Flagge: Turks- und Caicosinseln',
    '🇹🇩' => 'Flagge: Tschad',
    '🇹🇫' => 'Flagge: Französische Süd- und Antarktisgebiete',
    '🇹🇬' => 'Flagge: Togo',
    '🇹🇭' => 'Flagge: Thailand',
    '🇹🇯' => 'Flagge: Tadschikistan',
    '🇹🇰' => 'Flagge: Tokelau',
    '🇹🇱' => 'Flagge: Timor-Leste',
    '🇹🇲' => 'Flagge: Turkmenistan',
    '🇹🇳' => 'Flagge: Tunesien',
    '🇹🇴' => 'Flagge: Tonga',
    '🇹🇷' => 'Flagge: Türkei',
    '🇹🇹' => 'Flagge: Trinidad und Tobago',
    '🇹🇻' => 'Flagge: Tuvalu',
    '🇹🇼' => 'Flagge: Taiwan',
    '🇹🇿' => 'Flagge: Tansania',
    '🇺🇦' => 'Flagge: Ukraine',
    '🇺🇬' => 'Flagge: Uganda',
    '🇺🇲' => 'Flagge: Amerikanische Überseeinseln',
    '🇺🇳' => 'Flagge: Vereinte Nationen',
    '🇺🇸' => 'Flagge: Vereinigte Staaten',
    '🇺🇾' => 'Flagge: Uruguay',
    '🇺🇿' => 'Flagge: Usbekistan',
    '🇻🇦' => 'Flagge: Vatikanstadt',
    '🇻🇨' => 'Flagge: St. Vincent und die Grenadinen',
    '🇻🇪' => 'Flagge: Venezuela',
    '🇻🇬' => 'Flagge: Britische Jungferninseln',
    '🇻🇮' => 'Flagge: Amerikanische Jungferninseln',
    '🇻🇳' => 'Flagge: Vietnam',
    '🇻🇺' => 'Flagge: Vanuatu',
    '🇼🇫' => 'Flagge: Wallis und Futuna',
    '🇼🇸' => 'Flagge: Samoa',
    '🇽🇰' => 'Flagge: Kosovo',
    '🇾🇪' => 'Flagge: Jemen',
    '🇾🇹' => 'Flagge: Mayotte',
    '🇿🇦' => 'Flagge: Südafrika',
    '🇿🇲' => 'Flagge: Sambia',
    '🇿🇼' => 'Flagge: Simbabwe',
    '🔟' => 'Taste: 10',
    '🏻' => 'helle Hautfarbe',
    '🏼' => 'mittelhelle Hautfarbe',
    '🏽' => 'mittlere Hautfarbe',
    '🏾' => 'mitteldunkle Hautfarbe',
    '🏿' => 'dunkle Hautfarbe',
    '😀' => 'grinsendes Gesicht',
    '😃' => 'grinsendes Gesicht mit grossen Augen',
    '😄' => 'grinsendes Gesicht mit lachenden Augen',
    '😁' => 'strahlendes Gesicht mit lachenden Augen',
    '😆' => 'Grinsegesicht mit zugekniffenen Augen',
    '😅' => 'grinsendes Gesicht mit Schweisstropfen',
    '🤣' => 'sich vor Lachen auf dem Boden wälzen',
    '😂' => 'Gesicht mit Freudentränen',
    '🙂' => 'leicht lächelndes Gesicht',
    '🙃' => 'umgekehrtes Gesicht',
    '🫠' => 'schmelzendes Gesicht',
    '😉' => 'zwinkerndes Gesicht',
    '😊' => 'lächelndes Gesicht mit lachenden Augen',
    '😇' => 'lächelndes Gesicht mit Heiligenschein',
    '🥰' => 'lächelndes Gesicht mit Herzen',
    '😍' => 'lächelndes Gesicht mit herzförmigen Augen',
    '🤩' => 'überwältigt',
    '😘' => 'Kuss zuwerfendes Gesicht',
    '😗' => 'küssendes Gesicht',
    '☺' => 'lächelndes Gesicht',
    '😚' => 'küssendes Gesicht mit geschlossenen Augen',
    '😙' => 'küssendes Gesicht mit lächelnden Augen',
    '🥲' => 'lachendes Gesicht mit Träne',
    '😋' => 'sich die Lippen leckendes Gesicht',
    '😛' => 'Gesicht mit herausgestreckter Zunge',
    '😜' => 'zwinkerndes Gesicht mit herausgestreckter Zunge',
    '🤪' => 'irres Gesicht',
    '😝' => 'Gesicht mit herausgestreckter Zunge und zusammengekniffenen Augen',
    '🤑' => 'Gesicht mit Dollarzeichen',
    '🤗' => 'Gesicht mit umarmenden Händen',
    '🤭' => 'verlegen kicherndes Gesicht',
    '🫢' => 'Gesicht mit offenen Augen und Hand über dem Mund',
    '🫣' => 'Gesicht mit durch die Finger linsendem Auge',
    '🤫' => 'ermahnendes Gesicht',
    '🤔' => 'nachdenkendes Gesicht',
    '🫡' => 'salutierendes Gesicht',
    '🤐' => 'Gesicht mit Reissverschlussmund',
    '🤨' => 'Gesicht mit hochgezogenen Augenbrauen',
    '😐' => 'neutrales Gesicht',
    '😑' => 'ausdrucksloses Gesicht',
    '😶' => 'Gesicht ohne Mund',
    '🫥' => 'gestricheltes Gesicht',
    '😏' => 'süffisant lächelndes Gesicht',
    '😒' => 'verstimmtes Gesicht',
    '🙄' => 'Augen verdrehendes Gesicht',
    '😬' => 'Grimassen schneidendes Gesicht',
    '🤥' => 'lügendes Gesicht',
    '🫨' => 'zitterndes Doppelgesicht',
    '😌' => 'erleichtertes Gesicht',
    '😔' => 'nachdenkliches Gesicht',
    '😪' => 'schläfriges Gesicht',
    '🤤' => 'sabberndes Gesicht',
    '😴' => 'schlafendes Gesicht',
    '🫩' => 'Gesicht mit Augenringen',
    '😷' => 'Gesicht mit Atemschutzmaske',
    '🤒' => 'Gesicht mit Fieberthermometer',
    '🤕' => 'Gesicht mit Kopfverband',
    '🤢' => 'würgendes Gesicht',
    '🤮' => 'kotzendes Gesicht',
    '🤧' => 'niesendes Gesicht',
    '🥵' => 'schwitzendes Gesicht',
    '🥶' => 'frierendes Gesicht',
    '🥴' => 'schwindeliges Gesicht',
    '😵' => 'benommenes Gesicht',
    '🤯' => 'explodierender Kopf',
    '🤠' => 'Gesicht mit Cowboyhut',
    '🥳' => 'Partygesicht',
    '🥸' => 'verkleidet',
    '😎' => 'lächelndes Gesicht mit Sonnenbrille',
    '🤓' => 'Strebergesicht',
    '🧐' => 'Gesicht mit Monokel',
    '😕' => 'verwundertes Gesicht',
    '🫤' => 'Gesicht mit schrägem Mund',
    '😟' => 'besorgtes Gesicht',
    '🙁' => 'betrübtes Gesicht',
    '☹' => 'düsteres Gesicht',
    '😮' => 'Gesicht mit offenem Mund',
    '😯' => 'verdutztes Gesicht',
    '😲' => 'erstauntes Gesicht',
    '😳' => 'errötetes Gesicht mit grossen Augen',
    '🫪' => 'verzerrtes Gesicht',
    '🥺' => 'bettelndes Gesicht',
    '🥹' => 'Gesicht, das Tränen zurückhält',
    '😦' => 'entsetztes Gesicht',
    '😧' => 'qualvolles Gesicht',
    '😨' => 'ängstliches Gesicht',
    '😰' => 'besorgtes Gesicht mit Schweisstropfen',
    '😥' => 'trauriges aber erleichtertes Gesicht',
    '😢' => 'weinendes Gesicht',
    '😭' => 'heulendes Gesicht',
    '😱' => 'vor Angst schreiendes Gesicht',
    '😖' => 'verwirrtes Gesicht',
    '😣' => 'entschlossenes Gesicht',
    '😞' => 'enttäuschtes Gesicht',
    '😓' => 'bedrücktes Gesicht mit Schweiss',
    '😩' => 'erschöpftes Gesicht',
    '😫' => 'müdes Gesicht',
    '🥱' => 'gähnendes Gesicht',
    '😤' => 'schnaubendes Gesicht',
    '😡' => 'schmollendes Gesicht',
    '😠' => 'verärgertes Gesicht',
    '🤬' => 'Gesicht mit Symbolen über dem Mund',
    '😈' => 'grinsendes Gesicht mit Hörnern',
    '👿' => 'wütendes Gesicht mit Hörnern',
    '💀' => 'Totenkopf',
    '☠' => 'Totenkopf mit gekreuzten Knochen',
    '💩' => 'Kothaufen',
    '🤡' => 'Clown-Gesicht',
    '👹' => 'Ungeheuer',
    '👺' => 'Kobold',
    '👻' => 'Gespenst',
    '👽' => 'Ausserirdischer',
    '👾' => 'Computerspiel-Monster',
    '🤖' => 'Roboter',
    '😺' => 'grinsende Katze',
    '😸' => 'grinsende Katze mit lachenden Augen',
    '😹' => 'Katze mit Freudentränen',
    '😻' => 'lachende Katze mit Herzen als Augen',
    '😼' => 'verwegen lächelnde Katze',
    '😽' => 'küssende Katze',
    '🙀' => 'erschöpfte Katze',
    '😿' => 'weinende Katze',
    '😾' => 'schmollende Katze',
    '🙈' => 'sich die Augen zuhaltendes Affengesicht',
    '🙉' => 'sich die Ohren zuhaltendes Affengesicht',
    '🙊' => 'sich den Mund zuhaltendes Affengesicht',
    '💌' => 'Liebesbrief',
    '💘' => 'Herz mit Pfeil',
    '💝' => 'Herz mit Schleife',
    '💖' => 'funkelndes Herz',
    '💗' => 'wachsendes Herz',
    '💓' => 'schlagendes Herz',
    '💞' => 'kreisende Herzen',
    '💕' => 'zwei Herzen',
    '💟' => 'Herzdekoration',
    '❣' => 'Herz als Ausrufezeichen',
    '💔' => 'gebrochenes Herz',
    '❤' => 'rotes Herz',
    '🩷' => 'pinkes Herz',
    '🧡' => 'oranges Herz',
    '💛' => 'gelbes Herz',
    '💚' => 'grünes Herz',
    '💙' => 'blaues Herz',
    '🩵' => 'hellblaues Herz',
    '💜' => 'lila Herz',
    '🤎' => 'braunes Herz',
    '🖤' => 'schwarzes Herz',
    '🩶' => 'graues Herz',
    '🤍' => 'weisses Herz',
    '💋' => 'Kussabdruck',
    '💯' => '100 Punkte',
    '💢' => 'Ärger',
    '🫯' => 'Kampfwolke',
    '💥' => 'Zusammenstoss',
    '💫' => 'schwindlig',
    '💦' => 'Schweisstropfen',
    '💨' => 'Staubwolke',
    '🕳' => 'Loch',
    '💬' => 'Sprechblase mit drei Punkten',
    '🗨' => 'Sprechblase links',
    '🗯' => 'Sprechblase für wütende Aussage rechts',
    '💭' => 'Gedankenblase',
    '💤' => 'Schlafen',
    '👋' => 'winkende Hand',
    '🤚' => 'erhobene Hand von hinten',
    '🖐' => 'Hand mit gespreizten Fingern',
    '✋' => 'erhobene Hand',
    '🖖' => 'vulkanischer Gruss',
    '🫱' => 'nach rechts weisende Hand',
    '🫲' => 'nach links weisende Hand',
    '🫳' => 'Hand mit Handfläche nach unten',
    '🫴' => 'Hand mit Handfläche nach oben',
    '🫷' => 'nach links schiebende Hand',
    '🫸' => 'nach rechts schiebende Hand',
    '👌' => 'OK-Zeichen',
    '🤌' => 'zusammengedrückte Finger',
    '🤏' => 'Wenig-Geste',
    '✌' => 'Victory-Geste',
    '🤞' => 'Hand mit gekreuzten Fingern',
    '🫰' => 'Hand mit gekreuztem Zeigefinger und Daumen',
    '🤟' => 'Ich-liebe-dich-Geste',
    '🤘' => 'Teufelsgruss',
    '🤙' => 'Ruf-mich-an-Handzeichen',
    '👈' => 'nach links weisender Zeigefinger',
    '👉' => 'nach rechts weisender Zeigefinger',
    '👆' => 'nach oben weisender Zeigefinger von hinten',
    '🖕' => 'Mittelfinger',
    '👇' => 'nach unten weisender Zeigefinger',
    '☝' => 'nach oben weisender Zeigefinger von vorne',
    '🫵' => 'auf Betrachter zeigender Zeigefinger',
    '👍' => 'Daumen hoch',
    '👎' => 'Daumen runter',
    '✊' => 'erhobene Faust',
    '👊' => 'geballte Faust',
    '🤛' => 'Faust nach links',
    '🤜' => 'Faust nach rechts',
    '👏' => 'klatschende Hände',
    '🙌' => 'zwei erhobene Handflächen',
    '🫶' => 'Hände, die Herz bilden',
    '👐' => 'offene Hände',
    '🤲' => 'Handflächen nach oben',
    '🤝' => 'Handschlag',
    '🙏' => 'zusammengelegte Handflächen',
    '✍' => 'schreibende Hand',
    '💅' => 'Nagellack',
    '🤳' => 'Selfie',
    '💪' => 'angespannter Bizeps',
    '🦾' => 'Armprothese',
    '🦿' => 'Beinprothese',
    '🦵' => 'Bein',
    '🦶' => 'Fuss',
    '👂' => 'Ohr',
    '🦻' => 'Ohr mit Hörgerät',
    '👃' => 'Nase',
    '🧠' => 'Gehirn',
    '🫀' => 'Herz (Organ)',
    '🫁' => 'Lunge',
    '🦷' => 'Zahn',
    '🦴' => 'Knochen',
    '👀' => 'Augen',
    '👁' => 'Auge',
    '👅' => 'Zunge',
    '👄' => 'Mund',
    '🫦' => 'auf Lippe beissen',
    '👶' => 'Baby',
    '🧒' => 'Kind',
    '👦' => 'Junge',
    '👧' => 'Mädchen',
    '🧑' => 'Person',
    '👱' => 'Person: blondes Haar',
    '👨' => 'Mann',
    '🧔' => 'Person: Bart',
    '👩' => 'Frau',
    '🧓' => 'ältere Person',
    '👴' => 'älterer Mann',
    '👵' => 'ältere Frau',
    '🙍' => 'missmutige Person',
    '🙎' => 'schmollende Person',
    '🙅' => 'Person mit überkreuzten Armen',
    '🙆' => 'Person mit Händen auf dem Kopf',
    '💁' => 'Infoschalter-Mitarbeiter(in)',
    '🙋' => 'Person mit erhobenem Arm',
    '🧏' => 'gehörlose Person',
    '🙇' => 'sich verbeugende Person',
    '🤦' => 'sich an den Kopf fassende Person',
    '🤷' => 'schulterzuckende Person',
    '👮' => 'Polizist(in)',
    '🕵' => 'Detektiv(in)',
    '💂' => 'Wache',
    '🥷' => 'Ninja',
    '👷' => 'Bauarbeiter(in)',
    '🫅' => 'Person mit Krone',
    '🤴' => 'Prinz',
    '👸' => 'Prinzessin',
    '👳' => 'Person mit Turban',
    '👲' => 'Mann mit chinesischem Hut',
    '🧕' => 'Frau mit Kopftuch',
    '🤵' => 'Person im Smoking',
    '👰' => 'Person mit Schleier',
    '🤰' => 'schwangere Frau',
    '🫃' => 'schwangerer Mann',
    '🫄' => 'schwangere Person',
    '🤱' => 'Stillen',
    '👼' => 'Putte',
    '🎅' => 'Weihnachtsmann',
    '🤶' => 'Weihnachtsfrau',
    '🦸' => 'Superheld(in)',
    '🦹' => 'Bösewicht',
    '🧙' => 'Magier(in)',
    '🧚' => 'Märchenfee',
    '🧛' => 'Vampir',
    '🧜' => 'Wassermensch',
    '🧝' => 'Elf(e)',
    '🧞' => 'Flaschengeist',
    '🧟' => 'Zombie',
    '🧌' => 'Troll',
    '🫈' => 'haariges Wesen',
    '💆' => 'Person, die eine Kopfmassage bekommt',
    '💇' => 'Person beim Haareschneiden',
    '🚶' => 'Fussgänger(in)',
    '🧍' => 'stehende Person',
    '🧎' => 'kniende Person',
    '🏃' => 'laufende Person',
    '💃' => 'tanzende Frau',
    '🕺' => 'tanzender Mann',
    '🕴' => 'schwebender Mann im Anzug',
    '👯' => 'Personen mit Hasenohren',
    '🧖' => 'Person in Dampfsauna',
    '🧗' => 'Bergsteiger(in)',
    '🤺' => 'Fechter(in)',
    '🏇' => 'Pferderennen',
    '⛷' => 'Skifahrer(in)',
    '🏂' => 'Snowboarder(in)',
    '🏌' => 'Golfer(in)',
    '🏄' => 'Surfer(in)',
    '🚣' => 'Person im Ruderboot',
    '🏊' => 'Schwimmer(in)',
    '⛹' => 'Person mit Ball',
    '🏋' => 'Gewichtheber(in)',
    '🚴' => 'Radfahrer(in)',
    '🚵' => 'Mountainbiker(in)',
    '🤸' => 'Rad schlagende Person',
    '🤼' => 'Ringer(in)',
    '🤽' => 'Wasserballspieler(in)',
    '🤾' => 'Handballspieler(in)',
    '🤹' => 'Jongleur(in)',
    '🧘' => 'Person im Lotossitz',
    '🛀' => 'badende Person',
    '🛌' => 'im Bett liegende Person',
    '👭' => 'Händchen haltende Frauen',
    '👫' => 'Mann und Frau halten Hände',
    '👬' => 'Händchen haltende Männer',
    '💏' => 'sich küssendes Paar',
    '💑' => 'Liebespaar',
    '🗣' => 'sprechender Kopf',
    '👤' => 'Silhouette einer Büste',
    '👥' => 'Silhouette mehrerer Büsten',
    '🫂' => 'sich umarmende Personen',
    '👪' => 'Familie',
    '👣' => 'Fussabdrücke',
    '🫆' => 'Fingerabdruck',
    '🦰' => 'rotes Haar',
    '🦱' => 'lockiges Haar',
    '🦳' => 'weisses Haar',
    '🦲' => 'Glatze',
    '🐵' => 'Affengesicht',
    '🐒' => 'Affe',
    '🦍' => 'Gorilla',
    '🦧' => 'Orang-Utan',
    '🐶' => 'Hundegesicht',
    '🐕' => 'Hund',
    '🦮' => 'Blindenhund',
    '🐩' => 'Pudel',
    '🐺' => 'Wolf',
    '🦊' => 'Fuchs',
    '🦝' => 'Waschbär',
    '🐱' => 'Katzengesicht',
    '🐈' => 'Katze',
    '🦁' => 'Löwe',
    '🐯' => 'Tigergesicht',
    '🐅' => 'Tiger',
    '🐆' => 'Leopard',
    '🐴' => 'Pferdegesicht',
    '🫎' => 'Elch',
    '🫏' => 'Esel',
    '🐎' => 'Pferd',
    '🦄' => 'Einhorn',
    '🦓' => 'Zebra',
    '🦌' => 'Hirsch',
    '🦬' => 'Bison',
    '🐮' => 'Kuhgesicht',
    '🐂' => 'Ochse',
    '🐃' => 'Wasserbüffel',
    '🐄' => 'Kuh',
    '🐷' => 'Schweinegesicht',
    '🐖' => 'Schwein',
    '🐗' => 'Wildschwein',
    '🐽' => 'Schweinerüssel',
    '🐏' => 'Widder',
    '🐑' => 'Schaf',
    '🐐' => 'Ziege',
    '🐪' => 'Dromedar',
    '🐫' => 'Kamel',
    '🦙' => 'Lama',
    '🦒' => 'Giraffe',
    '🐘' => 'Elefant',
    '🦣' => 'Mammut',
    '🦏' => 'Nashorn',
    '🦛' => 'Nilpferd',
    '🐭' => 'Mäusegesicht',
    '🐁' => 'Maus',
    '🐀' => 'Ratte',
    '🐹' => 'Hamster',
    '🐰' => 'Hasengesicht',
    '🐇' => 'Hase',
    '🐿' => 'Streifenhörnchen',
    '🦫' => 'Biber',
    '🦔' => 'Igel',
    '🦇' => 'Fledermaus',
    '🐻' => 'Bär',
    '🐨' => 'Koala',
    '🐼' => 'Panda',
    '🦥' => 'Faultier',
    '🦦' => 'Otter',
    '🦨' => 'Stinktier',
    '🦘' => 'Känguru',
    '🦡' => 'Dachs',
    '🐾' => 'Tatzenabdrücke',
    '🦃' => 'Truthahn',
    '🐔' => 'Huhn',
    '🐓' => 'Hahn',
    '🐣' => 'schlüpfendes Küken',
    '🐤' => 'Küken',
    '🐥' => 'Küken von vorne',
    '🐦' => 'Vogel',
    '🐧' => 'Pinguin',
    '🕊' => 'Taube',
    '🦅' => 'Adler',
    '🦆' => 'Ente',
    '🦢' => 'Schwan',
    '🦉' => 'Eule',
    '🦤' => 'Dodo',
    '🪶' => 'Feder',
    '🦩' => 'Flamingo',
    '🦚' => 'Pfau',
    '🦜' => 'Papagei',
    '🪽' => 'Flügel',
    '🪿' => 'Gans',
    '🐸' => 'Frosch',
    '🐊' => 'Krokodil',
    '🐢' => 'Schildkröte',
    '🦎' => 'Eidechse',
    '🐍' => 'Schlange',
    '🐲' => 'Drachengesicht',
    '🐉' => 'Drache',
    '🦕' => 'Sauropode',
    '🦖' => 'T-Rex',
    '🐳' => 'blasender Wal',
    '🐋' => 'Wal',
    '🐬' => 'Delfin',
    '🫍' => 'Orca',
    '🦭' => 'Seehund',
    '🐟' => 'Fisch',
    '🐠' => 'Tropenfisch',
    '🐡' => 'Kugelfisch',
    '🦈' => 'Hai',
    '🐙' => 'Oktopus',
    '🐚' => 'Schneckenhaus',
    '🪸' => 'Koralle',
    '🪼' => 'Qualle',
    '🦀' => 'Krebs',
    '🦞' => 'Hummer',
    '🦐' => 'Garnele',
    '🦑' => 'Tintenfisch',
    '🦪' => 'Auster',
    '🐌' => 'Schnecke',
    '🦋' => 'Schmetterling',
    '🐛' => 'Raupe',
    '🐜' => 'Ameise',
    '🐝' => 'Biene',
    '🪲' => 'Käfer',
    '🐞' => 'Marienkäfer',
    '🦗' => 'Grille',
    '🪳' => 'Kakerlake',
    '🕷' => 'Spinne',
    '🕸' => 'Spinnennetz',
    '🦂' => 'Skorpion',
    '🦟' => 'Mücke',
    '🪰' => 'Fliege',
    '🪱' => 'Wurm',
    '🦠' => 'Mikrobe',
    '💐' => 'Blumenstrauss',
    '🌸' => 'Kirschblüte',
    '💮' => 'Blumenstempel',
    '🪷' => 'Lotusblüte',
    '🏵' => 'Rosette',
    '🌹' => 'Rose',
    '🥀' => 'welke Blume',
    '🌺' => 'Hibiskus',
    '🌻' => 'Sonnenblume',
    '🌼' => 'gelbe Blüte',
    '🌷' => 'Tulpe',
    '🪻' => 'Hyazinthe',
    '🌱' => 'Spross',
    '🪴' => 'Topfpflanze',
    '🌲' => 'Nadelbaum',
    '🌳' => 'Laubbaum',
    '🌴' => 'Palme',
    '🌵' => 'Kaktus',
    '🌾' => 'Reisähre',
    '🌿' => 'Kräuter',
    '☘' => 'Kleeblatt',
    '🍀' => 'Glücksklee',
    '🍁' => 'Ahornblatt',
    '🍂' => 'Laub',
    '🍃' => 'Blätter im Wind',
    '🪹' => 'leeres Nest',
    '🪺' => 'Nest mit Eiern',
    '🍄' => 'Fliegenpilz',
    '🪾' => 'kahler Baum',
    '🍇' => 'Trauben',
    '🍈' => 'Honigmelone',
    '🍉' => 'Wassermelone',
    '🍊' => 'Mandarine',
    '🍋' => 'Zitrone',
    '🍌' => 'Banane',
    '🍍' => 'Ananas',
    '🥭' => 'Mango',
    '🍎' => 'roter Apfel',
    '🍏' => 'grüner Apfel',
    '🍐' => 'Birne',
    '🍑' => 'Pfirsich',
    '🍒' => 'Kirschen',
    '🍓' => 'Erdbeere',
    '🫐' => 'Blaubeeren',
    '🥝' => 'Kiwi',
    '🍅' => 'Tomate',
    '🫒' => 'Olive',
    '🥥' => 'Kokosnuss',
    '🥑' => 'Avocado',
    '🍆' => 'Aubergine',
    '🥔' => 'Kartoffel',
    '🥕' => 'Karotte',
    '🌽' => 'Maiskolben',
    '🌶' => 'Peperoni',
    '🫑' => 'Paprika',
    '🥒' => 'Gurke',
    '🥬' => 'Blattgemüse',
    '🥦' => 'Brokkoli',
    '🧄' => 'Knoblauch',
    '🧅' => 'Zwiebel',
    '🥜' => 'Erdnuss',
    '🫘' => 'Bohnen',
    '🌰' => 'Kastanie',
    '🫚' => 'Ingwer',
    '🫛' => 'Erbsenschote',
    '🫜' => 'Wurzelgemüse',
    '🍞' => 'Brot',
    '🥐' => 'Croissant',
    '🥖' => 'Baguette',
    '🫓' => 'Fladenbrot',
    '🥨' => 'Brezel',
    '🥯' => 'Bagel',
    '🥞' => 'Pfannkuchen',
    '🧇' => 'Waffel',
    '🧀' => 'Käsestück',
    '🍖' => 'Fleischhachse',
    '🍗' => 'Hähnchenschenkel',
    '🥩' => 'Fleischstück',
    '🥓' => 'Bacon',
    '🍔' => 'Hamburger',
    '🍟' => 'Pommes frites',
    '🍕' => 'Pizza',
    '🌭' => 'Hotdog',
    '🥪' => 'Sandwich',
    '🌮' => 'Taco',
    '🌯' => 'Burrito',
    '🫔' => 'Tamale',
    '🥙' => 'Döner',
    '🧆' => 'Falafel',
    '🥚' => 'Ei',
    '🍳' => 'Spiegelei in Bratpfanne',
    '🥘' => 'Pfannengericht',
    '🍲' => 'Topf mit Essen',
    '🫕' => 'Fondue',
    '🥣' => 'Schüssel mit Löffel',
    '🥗' => 'Salat',
    '🍿' => 'Popcorn',
    '🧈' => 'Butter',
    '🧂' => 'Salz',
    '🥫' => 'Konserve',
    '🍱' => 'Bento-Box',
    '🍘' => 'Reiscracker',
    '🍙' => 'Reisbällchen',
    '🍚' => 'Reis in Schüssel',
    '🍛' => 'Reis mit Curry',
    '🍜' => 'Schüssel und Essstäbchen',
    '🍝' => 'Spaghetti',
    '🍠' => 'geröstete Süsskartoffel',
    '🍢' => 'Oden',
    '🍣' => 'Sushi',
    '🍤' => 'frittierte Garnele',
    '🍥' => 'Fischfrikadelle',
    '🥮' => 'Mondkuchen',
    '🍡' => 'Dango',
    '🥟' => 'Teigtasche',
    '🥠' => 'Glückskeks',
    '🥡' => 'Takeaway-Schachtel',
    '🍦' => 'Softeis',
    '🍧' => 'Wassereis',
    '🍨' => 'Eiscreme',
    '🍩' => 'Donut',
    '🍪' => 'Keks',
    '🎂' => 'Geburtstagskuchen',
    '🍰' => 'Torte',
    '🧁' => 'Cupcake',
    '🥧' => 'Kuchen',
    '🍫' => 'Schokoladentafel',
    '🍬' => 'Bonbon',
    '🍭' => 'Lutscher',
    '🍮' => 'Pudding',
    '🍯' => 'Honigtopf',
    '🍼' => 'Babyflasche',
    '🥛' => 'Glas Milch',
    '☕' => 'Heissgetränk',
    '🫖' => 'Teekanne',
    '🍵' => 'Teetasse ohne Henkel',
    '🍶' => 'Sake-Flasche mit Tasse',
    '🍾' => 'Flasche mit knallendem Korken',
    '🍷' => 'Weinglas',
    '🍸' => 'Cocktailglas',
    '🍹' => 'Cocktail',
    '🍺' => 'Bierkrug',
    '🍻' => 'Bierkrüge',
    '🥂' => 'Sektgläser',
    '🥃' => 'Trinkglas',
    '🫗' => 'Flüssigkeit ausgiessen',
    '🥤' => 'Becher mit Strohhalm',
    '🧋' => 'Bubble Tea',
    '🧃' => 'Trinkpäckchen',
    '🧉' => 'Mate-Tee',
    '🧊' => 'Eiswürfel',
    '🥢' => 'Essstäbchen',
    '🍽' => 'Teller mit Messer und Gabel',
    '🍴' => 'Messer und Gabel',
    '🥄' => 'Löffel',
    '🔪' => 'Küchenmesser',
    '🫙' => 'Einmachglas',
    '🏺' => 'Amphore',
    '🌍' => 'Globus mit Europa und Afrika',
    '🌎' => 'Globus mit Amerika',
    '🌏' => 'Globus mit Asien und Australien',
    '🌐' => 'Globus mit Meridianen',
    '🗺' => 'Weltkarte',
    '🗾' => 'Umriss von Japan',
    '🧭' => 'Kompass',
    '🏔' => 'schneebedeckter Berg',
    '⛰' => 'Berg',
    '🛘' => 'Erdrutsch',
    '🌋' => 'Vulkan',
    '🗻' => 'Fuji',
    '🏕' => 'Camping',
    '🏖' => 'Strand mit Sonnenschirm',
    '🏜' => 'Wüste',
    '🏝' => 'einsame Insel',
    '🏞' => 'Nationalpark',
    '🏟' => 'Stadion',
    '🏛' => 'antikes Gebäude',
    '🏗' => 'Kran',
    '🧱' => 'Ziegelstein',
    '🪨' => 'Felsen',
    '🪵' => 'Holz',
    '🛖' => 'Hütte',
    '🏘' => 'Wohnhäuser',
    '🏚' => 'verfallenes Haus',
    '🏠' => 'Haus',
    '🏡' => 'Haus mit Garten',
    '🏢' => 'Bürogebäude',
    '🏣' => 'japanisches Postgebäude',
    '🏤' => 'Postgebäude',
    '🏥' => 'Krankenhaus',
    '🏦' => 'Bank',
    '🏨' => 'Hotel',
    '🏩' => 'Stundenhotel',
    '🏪' => 'Minimarkt',
    '🏫' => 'Schule',
    '🏬' => 'Kaufhaus',
    '🏭' => 'Fabrik',
    '🏯' => 'japanisches Schloss',
    '🏰' => 'Schloss',
    '💒' => 'Hochzeit',
    '🗼' => 'Tokyo Tower',
    '🗽' => 'Freiheitsstatue',
    '⛪' => 'Kirche',
    '🕌' => 'Moschee',
    '🛕' => 'Hindutempel',
    '🕍' => 'Synagoge',
    '⛩' => 'Shinto-Schrein',
    '🕋' => 'Kaaba',
    '⛲' => 'Springbrunnen',
    '⛺' => 'Zelt',
    '🌁' => 'neblig',
    '🌃' => 'Sternenhimmel',
    '🏙' => 'Skyline',
    '🌄' => 'Sonnenaufgang über Bergen',
    '🌅' => 'Sonnenaufgang über dem Meer',
    '🌆' => 'Abendstimmung in der Stadt',
    '🌇' => 'Sonnenuntergang in der Stadt',
    '🌉' => 'Brücke vor Nachthimmel',
    '♨' => 'heisse Quellen',
    '🎠' => 'Karussellpferd',
    '🛝' => 'Spielplatzrutsche',
    '🎡' => 'Riesenrad',
    '🎢' => 'Achterbahn',
    '💈' => 'Barbershop-Säule',
    '🎪' => 'Zirkuszelt',
    '🚂' => 'Dampflokomotive',
    '🚃' => 'Eisenbahnwagen',
    '🚄' => 'Hochgeschwindigkeitszug mit spitzer Nase',
    '🚅' => 'Hochgeschwindigkeitszug',
    '🚆' => 'Zug',
    '🚇' => 'U-Bahn',
    '🚈' => 'S-Bahn',
    '🚉' => 'Bahnhof',
    '🚊' => 'Strassenbahn',
    '🚝' => 'Einschienenbahn',
    '🚞' => 'Bergbahn',
    '🚋' => 'Strassenbahnwagen',
    '🚌' => 'Bus',
    '🚍' => 'Bus von vorne',
    '🚎' => 'Oberleitungsbus',
    '🚐' => 'Kleinbus',
    '🚑' => 'Krankenwagen',
    '🚒' => 'Feuerwehrauto',
    '🚓' => 'Polizeiwagen',
    '🚔' => 'Polizeiwagen von vorne',
    '🚕' => 'Taxi',
    '🚖' => 'Taxi von vorne',
    '🚗' => 'Auto',
    '🚘' => 'Auto von vorne',
    '🚙' => 'Wohnmobil',
    '🛻' => 'Pick-up',
    '🚚' => 'Lieferwagen',
    '🚛' => 'Sattelzug',
    '🚜' => 'Traktor',
    '🏎' => 'Rennauto',
    '🏍' => 'Motorrad',
    '🛵' => 'Motorroller',
    '🦽' => 'manueller Rollstuhl',
    '🦼' => 'elektrischer Rollstuhl',
    '🛺' => 'Autorikscha',
    '🚲' => 'Fahrrad',
    '🛴' => 'Tretroller',
    '🛹' => 'Skateboard',
    '🛼' => 'Rollschuh',
    '🚏' => 'Bushaltestelle',
    '🛣' => 'Autobahn',
    '🛤' => 'Bahngleis',
    '🛢' => 'Ölfass',
    '⛽' => 'Tanksäule',
    '🛞' => 'Autorad',
    '🚨' => 'Polizeilicht',
    '🚥' => 'horizontale Verkehrsampel',
    '🚦' => 'vertikale Verkehrsampel',
    '🛑' => 'Stoppschild',
    '🚧' => 'Baustellenabsperrung',
    '⚓' => 'Anker',
    '🛟' => 'Rettungsring',
    '⛵' => 'Segelboot',
    '🛶' => 'Kanu',
    '🚤' => 'Schnellboot',
    '🛳' => 'Passagierschiff',
    '⛴' => 'Fähre',
    '🛥' => 'Motorboot',
    '🚢' => 'Schiff',
    '✈' => 'Flugzeug',
    '🛩' => 'kleines Flugzeug',
    '🛫' => 'Abflug',
    '🛬' => 'Landung eines Flugzeugs',
    '🪂' => 'Fallschirm',
    '💺' => 'Sitzplatz',
    '🚁' => 'Hubschrauber',
    '🚟' => 'Schwebebahn',
    '🚠' => 'Bergschwebebahn',
    '🚡' => 'Bergseilbahn',
    '🛰' => 'Satellit',
    '🚀' => 'Rakete',
    '🛸' => 'fliegende Untertasse',
    '🛎' => 'Rezeptionsklingel',
    '🧳' => 'Gepäck',
    '⌛' => 'Sanduhr',
    '⏳' => 'laufende Sanduhr',
    '⌚' => 'Armbanduhr',
    '⏰' => 'Wecker',
    '⏱' => 'Stoppuhr',
    '⏲' => 'Zeitschaltuhr',
    '🕰' => 'Kaminuhr',
    '🕛' => 'Ziffernblatt 12:00 Uhr',
    '🕧' => '12:30 Uhr',
    '🕐' => '1:00 Uhr',
    '🕜' => '1:30 Uhr',
    '🕑' => '2:00 Uhr',
    '🕝' => '2:30 Uhr',
    '🕒' => '3:00 Uhr',
    '🕞' => '3:30 Uhr',
    '🕓' => '4:00 Uhr',
    '🕟' => '4:30 Uhr',
    '🕔' => '5:00 Uhr',
    '🕠' => '5:30 Uhr',
    '🕕' => '6:00 Uhr',
    '🕡' => '6:30 Uhr',
    '🕖' => '7:00 Uhr',
    '🕢' => '7:30 Uhr',
    '🕗' => '8:00 Uhr',
    '🕣' => '8:30 Uhr',
    '🕘' => '9:00 Uhr',
    '🕤' => '9:30 Uhr',
    '🕙' => '10:00 Uhr',
    '🕥' => '10:30 Uhr',
    '🕚' => '11:00 Uhr',
    '🕦' => '11:30 Uhr',
    '🌑' => 'Neumond',
    '🌒' => 'erstes Mondviertel',
    '🌓' => 'zunehmender Halbmond',
    '🌔' => 'zweites Mondviertel',
    '🌕' => 'Vollmond',
    '🌖' => 'drittes Mondviertel',
    '🌗' => 'abnehmender Halbmond',
    '🌘' => 'letztes Mondviertel',
    '🌙' => 'Mondsichel',
    '🌚' => 'Neumond mit Gesicht',
    '🌛' => 'Mondsichel mit Gesicht links',
    '🌜' => 'Mondsichel mit Gesicht rechts',
    '🌡' => 'Thermometer',
    '☀' => 'Sonne',
    '🌝' => 'Vollmond mit Gesicht',
    '🌞' => 'Sonne mit Gesicht',
    '🪐' => 'Ringplanet',
    '⭐' => 'weisser mittelgrosser Stern',
    '🌟' => 'funkelnder Stern',
    '🌠' => 'Sternschnuppe',
    '🌌' => 'Milchstrasse',
    '☁' => 'Wolke',
    '⛅' => 'Sonne hinter Wolke',
    '⛈' => 'Wolke mit Blitz und Regen',
    '🌤' => 'Sonne hinter kleiner Wolke',
    '🌥' => 'Sonne hinter grosser Wolke',
    '🌦' => 'Sonne hinter Regenwolke',
    '🌧' => 'Wolke mit Regen',
    '🌨' => 'Wolke mit Schnee',
    '🌩' => 'Wolke mit Blitz',
    '🌪' => 'Wirbelsturm',
    '🌫' => 'Nebel',
    '🌬' => 'Wind',
    '🌀' => 'Wirbel',
    '🌈' => 'Regenbogen',
    '🌂' => 'geschlossener Regenschirm',
    '☂' => 'Regenschirm',
    '☔' => 'Regenschirm im Regen',
    '⛱' => 'aufgestellter Sonnenschirm',
    '⚡' => 'Hochspannung',
    '❄' => 'Schneeflocke',
    '☃' => 'Schneemann im Schnee',
    '⛄' => 'Schneemann ohne Schneeflocken',
    '☄' => 'Komet',
    '🔥' => 'Feuer',
    '💧' => 'Tropfen',
    '🌊' => 'Welle',
    '🎃' => 'Halloweenkürbis',
    '🎄' => 'Weihnachtsbaum',
    '🎆' => 'Feuerwerk',
    '🎇' => 'Wunderkerze',
    '🧨' => 'Feuerwerkskörper',
    '✨' => 'funkelnde Sterne',
    '🎈' => 'Luftballon',
    '🎉' => 'Konfettibombe',
    '🎊' => 'Konfettiball',
    '🎋' => 'Tanabata-Baum',
    '🎍' => 'Piniendekoration',
    '🎎' => 'japanische Puppen',
    '🎏' => 'traditionelle japanische Windsäcke',
    '🎐' => 'japanisches Windspiel',
    '🎑' => 'traditionelles Mondfest',
    '🧧' => 'roter Umschlag',
    '🎀' => 'pinke Schleife',
    '🎁' => 'Geschenk',
    '🎗' => 'Gedenkschleife',
    '🎟' => 'Eintrittskarten',
    '🎫' => 'Ticket',
    '🎖' => 'Militärorden',
    '🏆' => 'Pokal',
    '🏅' => 'Sportmedaille',
    '🥇' => 'Goldmedaille',
    '🥈' => 'Silbermedaille',
    '🥉' => 'Bronzemedaille',
    '⚽' => 'Fussball',
    '⚾' => 'Baseball',
    '🥎' => 'Softball',
    '🏀' => 'Basketball',
    '🏐' => 'Volleyball',
    '🏈' => 'Football',
    '🏉' => 'Rugbyball',
    '🎾' => 'Tennisball',
    '🥏' => 'Frisbee',
    '🎳' => 'Bowling',
    '🏏' => 'Kricket',
    '🏑' => 'Feldhockey',
    '🏒' => 'Eishockey',
    '🥍' => 'Lacrosse',
    '🏓' => 'Tischtennis',
    '🏸' => 'Badminton',
    '🥊' => 'Boxhandschuh',
    '🥋' => 'Kampfsportanzug',
    '🥅' => 'Tor',
    '⛳' => 'Golffahne',
    '⛸' => 'Schlittschuh',
    '🎣' => 'Angel mit Fisch',
    '🤿' => 'Tauchmaske',
    '🎽' => 'Laufshirt',
    '🎿' => 'Ski',
    '🛷' => 'Schlitten',
    '🥌' => 'Curlingstein',
    '🎯' => 'Darts',
    '🪀' => 'Jo-Jo',
    '🪁' => 'Drachen',
    '🔫' => 'Wasserpistole',
    '🎱' => 'Billardkugel',
    '🔮' => 'Kristallkugel',
    '🪄' => 'Zauberstab',
    '🎮' => 'Gamepad',
    '🕹' => 'Joystick',
    '🎰' => 'Spielautomat',
    '🎲' => 'Spielwürfel',
    '🧩' => 'Puzzleteil',
    '🧸' => 'Teddybär',
    '🪅' => 'Piñata',
    '🪩' => 'Discokugel',
    '🪆' => 'Matroschka',
    '♠' => 'Pik',
    '♥' => 'Herz',
    '♦' => 'Karo',
    '♣' => 'Kreuz',
    '♟' => 'Bauer Schach',
    '🃏' => 'Jokerkarte',
    '🀄' => 'Mahjong-Stein',
    '🎴' => 'japanische Blumenkarte',
    '🎭' => 'Masken',
    '🖼' => 'gerahmtes Bild',
    '🎨' => 'Mischpalette',
    '🧵' => 'Faden',
    '🪡' => 'Nähnadel',
    '🧶' => 'Wollknäuel',
    '🪢' => 'Knoten',
    '👓' => 'Brille',
    '🕶' => 'Sonnenbrille',
    '🥽' => 'Schutzbrille',
    '🥼' => 'Laborkittel',
    '🦺' => 'Sicherheitsweste',
    '👔' => 'Hemd mit Krawatte',
    '👕' => 'T-Shirt',
    '👖' => 'Jeans',
    '🧣' => 'Schal',
    '🧤' => 'Handschuhe',
    '🧥' => 'Mantel',
    '🧦' => 'Socken',
    '👗' => 'Kleid',
    '👘' => 'Kimono',
    '🥻' => 'Sari',
    '🩱' => 'einteiliger Badeanzug',
    '🩲' => 'Slip',
    '🩳' => 'Shorts',
    '👙' => 'Bikini',
    '👚' => 'Bluse',
    '🪭' => 'Faltfächer',
    '👛' => 'Geldbörse',
    '👜' => 'Handtasche',
    '👝' => 'Clutch',
    '🛍' => 'Einkaufstüten',
    '🎒' => 'Schulranzen',
    '🩴' => 'Zehensandale',
    '👞' => 'Herrenschuh',
    '👟' => 'Sportschuh',
    '🥾' => 'Wanderstiefel',
    '🥿' => 'flacher Schuh',
    '👠' => 'Stöckelschuh',
    '👡' => 'Damensandale',
    '🩰' => 'Ballettschuhe',
    '👢' => 'Damenstiefel',
    '🪮' => 'Haarkamm',
    '👑' => 'Krone',
    '👒' => 'Damenhut',
    '🎩' => 'Zylinder',
    '🎓' => 'Doktorhut',
    '🧢' => 'Baseballmütze',
    '🪖' => 'Militärhelm',
    '⛑' => 'Rettungshelm',
    '📿' => 'Gebetskette',
    '💄' => 'Lippenstift',
    '💍' => 'Ring',
    '💎' => 'Edelstein',
    '🔇' => 'durchgestrichener Lautsprecher',
    '🔈' => 'Lautsprecher mit geringer Lautstärke',
    '🔉' => 'Lautsprecher mit mittlerer Lautstärke',
    '🔊' => 'Lautsprecher mit hoher Lautstärke',
    '📢' => 'Lautsprecher',
    '📣' => 'Megafon',
    '📯' => 'Posthorn',
    '🔔' => 'Glocke',
    '🔕' => 'durchgestrichene Glocke',
    '🎼' => 'Notenschlüssel',
    '🎵' => 'Musiknote',
    '🎶' => 'Musiknoten',
    '🎙' => 'Studiomikrofon',
    '🎚' => 'Schieberegler',
    '🎛' => 'Drehregler',
    '🎤' => 'Mikrofon',
    '🎧' => 'Kopfhörer',
    '📻' => 'Radio',
    '🎷' => 'Saxofon',
    '🎺' => 'Trompete',
    '🪊' => 'Posaune',
    '🪗' => 'Akkordeon',
    '🎸' => 'Gitarre',
    '🎹' => 'Klaviatur',
    '🎻' => 'Geige',
    '🪕' => 'Banjo',
    '🥁' => 'Trommel',
    '🪘' => 'afrikanische Trommel',
    '🪇' => 'Maracas',
    '🪈' => 'Flöte',
    '🪉' => 'Harfe',
    '📱' => 'Mobiltelefon',
    '📲' => 'Mobiltelefon mit Pfeil',
    '☎' => 'Telefon',
    '📞' => 'Telefonhörer',
    '📟' => 'Pager',
    '📠' => 'Faxgerät',
    '🔋' => 'Batterie',
    '🪫' => 'schwache Batterie',
    '🔌' => 'Netzstecker',
    '💻' => 'Laptop',
    '🖥' => 'Desktopcomputer',
    '🖨' => 'Drucker',
    '⌨' => 'Tastatur',
    '🖱' => 'Computermaus',
    '🖲' => 'Trackball',
    '💽' => 'Minidisc',
    '💾' => 'Diskette',
    '💿' => 'CD',
    '📀' => 'DVD',
    '🧮' => 'Abakus',
    '🎥' => 'Filmkamera',
    '🎞' => 'Filmstreifen',
    '📽' => 'Filmprojektor',
    '🎬' => 'Filmklappe',
    '📺' => 'Fernseher',
    '📷' => 'Fotoapparat',
    '📸' => 'Fotoapparat mit Blitz',
    '📹' => 'Videokamera',
    '📼' => 'Videokassette',
    '🔍' => 'Lupe nach links',
    '🔎' => 'Lupe nach rechts',
    '🕯' => 'Kerze',
    '💡' => 'Glühbirne',
    '🔦' => 'Taschenlampe',
    '🏮' => 'rote Papierlaterne',
    '🪔' => 'Öllampe',
    '📔' => 'Notizbuch mit dekorativem Einband',
    '📕' => 'geschlossenes Buch',
    '📖' => 'offenes Buch',
    '📗' => 'grünes Buch',
    '📘' => 'blaues Buch',
    '📙' => 'orangefarbenes Buch',
    '📚' => 'Bücherstapel',
    '📓' => 'Notizbuch',
    '📒' => 'Spiralblock',
    '📃' => 'teilweise eingerolltes Blatt',
    '📜' => 'Schriftrolle',
    '📄' => 'Vorderseite eines Blattes',
    '📰' => 'Zeitung',
    '🗞' => 'zusammengerollte Zeitung',
    '📑' => 'Pagemarker',
    '🔖' => 'Lesezeichen',
    '🏷' => 'Etikett',
    '🪙' => 'Münze',
    '💰' => 'Geldsack',
    '🪎' => 'Schatztruhe',
    '💴' => 'Yen-Banknote',
    '💵' => 'Dollar-Banknote',
    '💶' => 'Euro-Banknote',
    '💷' => 'Pfund-Banknote',
    '💸' => 'Geldschein mit Flügeln',
    '💳' => 'Kreditkarte',
    '🧾' => 'Beleg',
    '💹' => 'steigende Kurve mit Yen-Zeichen',
    '✉' => 'Briefumschlag',
    '📧' => 'E-Mail',
    '📨' => 'eingehender Briefumschlag',
    '📩' => 'Umschlag mit Pfeil',
    '📤' => 'Postausgang',
    '📥' => 'Posteingang',
    '📦' => 'Paket',
    '📫' => 'geschlossener Briefkasten mit Post',
    '📪' => 'geschlossener Briefkasten ohne Post',
    '📬' => 'offener Briefkasten mit Post',
    '📭' => 'offener Briefkasten ohne Post',
    '📮' => 'Briefkasten',
    '🗳' => 'Urne mit Wahlzettel',
    '✏' => 'Bleistift',
    '✒' => 'schwarzer Federhalter',
    '🖋' => 'Füllhalter',
    '🖊' => 'Kugelschreiber',
    '🖌' => 'Pinsel',
    '🖍' => 'Wachsmalstift',
    '📝' => 'Papier und Bleistift',
    '💼' => 'Aktentasche',
    '📁' => 'Ordner',
    '📂' => 'geöffneter Ordner',
    '🗂' => 'Karteireiter',
    '📅' => 'Kalender',
    '📆' => 'Abreisskalender',
    '🗒' => 'Notizblock',
    '🗓' => 'Spiralkalender',
    '📇' => 'Rotationskartei',
    '📈' => 'Aufwärtstrend',
    '📉' => 'Abwärtstrend',
    '📊' => 'Balkendiagramm',
    '📋' => 'Klemmbrett',
    '📌' => 'Reisszwecke',
    '📍' => 'Stecknadel',
    '📎' => 'Büroklammer',
    '🖇' => 'verhakte Büroklammern',
    '📏' => 'Lineal',
    '📐' => 'dreieckiges Lineal',
    '✂' => 'Schere',
    '🗃' => 'Karteikasten',
    '🗄' => 'Aktenschrank',
    '🗑' => 'Papierkorb',
    '🔒' => 'geschlossenes Schloss',
    '🔓' => 'offenes Schloss',
    '🔏' => 'Schloss mit Füller',
    '🔐' => 'Schloss mit Schlüssel',
    '🔑' => 'Schlüssel',
    '🗝' => 'alter Schlüssel',
    '🔨' => 'Hammer',
    '🪓' => 'Axt',
    '⛏' => 'Pickel',
    '⚒' => 'Hammer und Pickel',
    '🛠' => 'Hammer und Schraubenschlüssel',
    '🗡' => 'Dolch',
    '⚔' => 'gekreuzte Schwerter',
    '💣' => 'Bombe',
    '🪃' => 'Bumerang',
    '🏹' => 'Pfeil und Bogen',
    '🛡' => 'Schutzschild',
    '🪚' => 'Handsäge',
    '🔧' => 'Schraubenschlüssel',
    '🪛' => 'Schraubenzieher',
    '🔩' => 'Mutter und Schraube',
    '⚙' => 'Zahnrad',
    '🗜' => 'Schraubzwinge',
    '⚖' => 'Waage',
    '🦯' => 'Blindenstock',
    '🔗' => 'Linksymbol',
    '⛓' => 'Ketten',
    '🪝' => 'Haken',
    '🧰' => 'Werkzeugkasten',
    '🧲' => 'Magnet',
    '🪜' => 'Leiter',
    '🪏' => 'Schaufel',
    '⚗' => 'Destillierapparat',
    '🧪' => 'Reagenzglas',
    '🧫' => 'Petrischale',
    '🧬' => 'DNA',
    '🔬' => 'Mikroskop',
    '🔭' => 'Teleskop',
    '📡' => 'Satellitenschüssel',
    '💉' => 'Spritze',
    '🩸' => 'Blutstropfen',
    '💊' => 'Kapsel',
    '🩹' => 'Heftpflaster',
    '🩼' => 'Krücke',
    '🩺' => 'Stethoskop',
    '🩻' => 'Röntgenbild',
    '🚪' => 'Tür',
    '🛗' => 'Fahrstuhl',
    '🪞' => 'Spiegel',
    '🪟' => 'Fenster',
    '🛏' => 'Bett',
    '🛋' => 'Sofa und Lampe',
    '🪑' => 'Stuhl',
    '🚽' => 'Toilette',
    '🪠' => 'Saugglocke',
    '🚿' => 'Dusche',
    '🛁' => 'Badewanne',
    '🪤' => 'Mausefalle',
    '🪒' => 'Rasierer',
    '🧴' => 'Creme',
    '🧷' => 'Sicherheitsnadel',
    '🧹' => 'Besen',
    '🧺' => 'Korb',
    '🧻' => 'Küchenrolle',
    '🪣' => 'Eimer',
    '🧼' => 'Seife',
    '🫧' => 'Blasen',
    '🪥' => 'Zahnbürste',
    '🧽' => 'Schwamm',
    '🧯' => 'Feuerlöscher',
    '🛒' => 'Einkaufswagen',
    '🚬' => 'Zigarette',
    '⚰' => 'Sarg',
    '🪦' => 'Grabstein',
    '⚱' => 'Urne',
    '🧿' => 'Nazar-Amulett',
    '🪬' => 'Hamsa',
    '🗿' => 'Statue',
    '🪧' => 'Protestschild',
    '🪪' => 'Ausweis',
    '🏧' => 'Symbol „Geldautomat“',
    '🚮' => 'Symbol „Papierkorb“',
    '🚰' => 'Trinkwasser',
    '♿' => 'Symbol „Rollstuhl“',
    '🚹' => 'Herren',
    '🚺' => 'Damen',
    '🚻' => 'Toiletten',
    '🚼' => 'Symbol „Baby“',
    '🚾' => 'WC',
    '🛂' => 'Passkontrolle',
    '🛃' => 'Zollkontrolle',
    '🛄' => 'Gepäckausgabe',
    '🛅' => 'Gepäckaufbewahrung',
    '⚠' => 'Warnung',
    '🚸' => 'Kinder überqueren die Strasse',
    '⛔' => 'Zutritt verboten',
    '🚫' => 'Verboten',
    '🚳' => 'Fahrräder verboten',
    '🚭' => 'Rauchverbot',
    '🚯' => 'Abfall verboten',
    '🚱' => 'Kein Trinkwasser',
    '🚷' => 'Fussgänger verboten',
    '📵' => 'Mobiltelefone verboten',
    '🔞' => 'Minderjährige verboten',
    '☢' => 'Radioaktiv',
    '☣' => 'Biogefährdung',
    '⬆' => 'Pfeil nach oben',
    '↗' => 'Pfeil nach rechts oben',
    '➡' => 'Pfeil nach rechts',
    '↘' => 'Pfeil nach rechts unten',
    '⬇' => 'Pfeil nach unten',
    '↙' => 'Pfeil nach links unten',
    '⬅' => 'Pfeil nach links',
    '↖' => 'Pfeil nach links oben',
    '↕' => 'Pfeil nach oben und unten',
    '↔' => 'Pfeil nach links und rechts',
    '↩' => 'geschwungener Pfeil nach links',
    '↪' => 'geschwungener Pfeil nach rechts',
    '⤴' => 'geschwungener Pfeil nach oben',
    '⤵' => 'geschwungener Pfeil nach unten',
    '🔃' => 'kreisförmige Pfeile im Uhrzeigersinn',
    '🔄' => 'Pfeile gegen den Uhrzeigersinn',
    '🔙' => 'BACK-Pfeil',
    '🔚' => 'END-Pfeil',
    '🔛' => 'ON!-Pfeil',
    '🔜' => 'SOON-Pfeil',
    '🔝' => 'TOP-Pfeil',
    '🛐' => 'religiöse Stätte',
    '⚛' => 'Atomzeichen',
    '🕉' => 'om',
    '✡' => 'Davidstern',
    '☸' => 'Dharma-Rad',
    '☯' => 'Yin und Yang',
    '✝' => 'lateinisches Kreuz',
    '☦' => 'orthodoxes Kreuz',
    '☪' => 'Hilal und Stern',
    '☮' => 'Friedenszeichen',
    '🕎' => 'Menora',
    '🔯' => 'Hexagramm mit Punkt',
    '🪯' => 'Khanda',
    '♈' => 'Widder (Sternzeichen)',
    '♉' => 'Stier (Sternzeichen)',
    '♊' => 'Zwillinge (Sternzeichen)',
    '♋' => 'Krebs (Sternzeichen)',
    '♌' => 'Löwe (Sternzeichen)',
    '♍' => 'Jungfrau (Sternzeichen)',
    '♎' => 'Waage (Sternzeichen)',
    '♏' => 'Skorpion (Sternzeichen)',
    '♐' => 'Schütze (Sternzeichen)',
    '♑' => 'Steinbock (Sternzeichen)',
    '♒' => 'Wassermann (Sternzeichen)',
    '♓' => 'Fische (Sternzeichen)',
    '⛎' => 'Schlangenträger',
    '🔀' => 'Zufallsmodus',
    '🔁' => 'Wiederholen',
    '🔂' => 'Titel wiederholen',
    '▶' => 'Wiedergabe',
    '⏩' => 'Doppelpfeile nach rechts',
    '⏭' => 'Nächster Titel',
    '⏯' => 'Wiedergabe oder Pause',
    '◀' => 'Pfeil zurück',
    '⏪' => 'Zurückspulen',
    '⏮' => 'Vorheriger Titel',
    '🔼' => 'Aufwärts-Schaltfläche',
    '⏫' => 'Doppelpfeile nach oben',
    '🔽' => 'Abwärts-Schaltfläche',
    '⏬' => 'Doppelpfeile nach unten',
    '⏸' => 'Pause',
    '⏹' => 'Stopp',
    '⏺' => 'Aufnehmen',
    '⏏' => 'Auswerfen',
    '🎦' => 'Kinosymbol',
    '🔅' => 'Taste Dimmen',
    '🔆' => 'Heller-Taste',
    '📶' => 'balkenförmige Signalstärkenanzeige',
    '🛜' => 'WLAN',
    '📳' => 'Vibrationsmodus',
    '📴' => 'Mobiltelefon aus',
    '♀' => 'Frauensymbol',
    '♂' => 'Männersymbol',
    '⚧' => 'Transgender-Symbol',
    '✖' => 'mal',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'geteilt durch',
    '🟰' => 'Gleichheitszeichen extrafett',
    '♾' => 'Unendlichkeit',
    '‼' => 'doppeltes Ausrufezeichen',
    '⁉' => 'Ausrufe- und Fragezeichen',
    '❓' => 'rotes Fragezeichen',
    '❔' => 'weisses Fragezeichen',
    '❕' => 'weisses Ausrufezeichen',
    '❗' => 'rotes Ausrufezeichen',
    '〰' => 'Wellenlinie',
    '💱' => 'Geldwechsel',
    '💲' => 'Dollarzeichen extrafett',
    '⚕' => 'Äskulapstab',
    '♻' => 'Recycling-Symbol',
    '⚜' => 'Lilie',
    '🔱' => 'Dreizack',
    '📛' => 'Namensschild',
    '🔰' => 'japanisches Anfänger-Zeichen',
    '⭕' => 'hohler roter Kreis',
    '✅' => 'weisses Häkchen',
    '☑' => 'abgehaktes Kästchen',
    '✔' => 'kräftiges Häkchen',
    '❌' => 'Kreuzzeichen',
    '❎' => 'angekreuztes Kästchen',
    '➰' => 'Schleife',
    '➿' => 'Doppelschleife',
    '〽' => 'Teilalternationszeichen',
    '✳' => 'achtzackiger Stern',
    '✴' => 'achtstrahliger Stern',
    '❇' => 'Funkeln',
    '™' => 'Markenzeichen',
    '🫟' => 'Spritzer',
    '🔠' => 'Eingabesymbol lateinische Grossbuchstaben',
    '🔡' => 'Eingabesymbol lateinische Kleinbuchstaben',
    '🔢' => 'Eingabesymbol Zahlen',
    '🔣' => 'Eingabesymbol Sonderzeichen',
    '🔤' => 'Eingabesymbol lateinische Buchstaben',
    '🅰' => 'Grossbuchstabe A in rotem Quadrat',
    '🆎' => 'Grossbuchstaben AB in rotem Quadrat',
    '🅱' => 'Grossbuchstabe B in rotem Quadrat',
    '🆑' => 'Grossbuchstaben CL in rotem Quadrat',
    '🆒' => 'Wort „Cool“ in blauem Quadrat',
    '🆓' => 'Wort „Free“ in blauem Quadrat',
    'ℹ' => 'Buchstabe „i“ in blauem Quadrat',
    '🆔' => 'Grossbuchstaben ID in lila Quadrat',
    'Ⓜ' => 'Buchstabe „M“ in Kreis',
    '🆕' => 'Wort „New“ in blauem Quadrat',
    '🆖' => 'Grossbuchstaben NG in blauem Quadrat',
    '🅾' => 'Grossbuchstabe O in rotem Quadrat',
    '🆗' => 'Grossbuchstaben OK in blauem Quadrat',
    '🅿' => 'Grossbuchstabe P in blauem Quadrat',
    '🆘' => 'SOS-Zeichen',
    '🆙' => 'Schriftzug „UP!“ im blauen Quadrat',
    '🆚' => 'Schriftzug VS in orangem Quadrat',
    '🈁' => 'Schriftzeichen „koko“',
    '🈂' => 'Schriftzeichen „sa“',
    '🈷' => 'Schriftzeichen für „Monatsbetrag“',
    '🈶' => 'Schriftzeichen für „nicht gratis“',
    '🈯' => 'Schriftzeichen für „reserviert“',
    '🉐' => 'Schriftzeichen für „Schnäppchen“',
    '🈹' => 'Schriftzeichen für „Rabatt“',
    '🈚' => 'Schriftzeichen für „gratis“',
    '🈲' => 'Schriftzeichen für „verbieten“',
    '🉑' => 'Schriftzeichen für „akzeptieren“',
    '🈸' => 'Schriftzeichen für „anwenden“',
    '🈴' => 'Schriftzeichen für „Note zum Bestehen“',
    '🈳' => 'Schriftzeichen für „Zimmer frei“',
    '㊗' => 'Schriftzeichen für „Gratulation“',
    '㊙' => 'Schriftzeichen für „Geheimnis“',
    '🈺' => 'Schriftzeichen für „Geöffnet“',
    '🈵' => 'Schriftzeichen für „Kein Zimmer frei“',
    '🔴' => 'roter Punkt',
    '🟠' => 'oranger Punkt',
    '🟡' => 'gelber Punkt',
    '🟢' => 'grüner Punkt',
    '🔵' => 'blauer Punkt',
    '🟣' => 'lila Punkt',
    '🟤' => 'brauner Punkt',
    '⚫' => 'schwarzer Punkt',
    '⚪' => 'weisser Punkt',
    '🟥' => 'rotes Quadrat',
    '🟧' => 'oranges Quadrat',
    '🟨' => 'gelbes Quadrat',
    '🟩' => 'grünes Quadrat',
    '🟦' => 'blaues Quadrat',
    '🟪' => 'lila Quadrat',
    '🟫' => 'braunes Quadrat',
    '⬛' => 'grosses schwarzes Quadrat',
    '⬜' => 'grosses weisses Quadrat',
    '◼' => 'mittelgrosses schwarzes Quadrat',
    '◻' => 'mittelgrosses weisses Quadrat',
    '◾' => 'mittelkleines schwarzes Quadrat',
    '◽' => 'mittelkleines weisses Quadrat',
    '▪' => 'kleines schwarzes Quadrat',
    '▫' => 'kleines weisses Quadrat',
    '🔶' => 'grosse orangefarbene Raute',
    '🔷' => 'grosse blaue Raute',
    '🔸' => 'kleine orangefarbene Raute',
    '🔹' => 'kleine blaue Raute',
    '🔺' => 'rotes Dreieck mit der Spitze nach oben',
    '🔻' => 'rotes Dreieck mit der Spitze nach unten',
    '💠' => 'Rautenform mit Punkt',
    '🔘' => 'Optionsfeld',
    '🔳' => 'weisse quadratische Schaltfläche',
    '🔲' => 'schwarze quadratische Schaltfläche',
    '🏁' => 'Zielflagge',
    '🚩' => 'Wimpel',
    '🎌' => 'überkreuzte Flaggen',
    '🏴' => 'schwarze Flagge',
    '🏳' => 'weisse Flagge',
];
