<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'sumba: babba, babba, launin fata mai haske, launin fata mai madaidaicin haske',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'sumba: babba, babba, launin fata mai haske, madaidaicin launin fata',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'sumba: babba, babba, launin fata mai haske, launin fata mai madaidaicin duhu',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'sumba: babba, babba, launin fata mai haske, launin fata mai duhu',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'sumba: babba, babba, launin fata mai madaidaicin haske, launin fata mai haske',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'sumba: babba, babba, launin fata mai madaidaicin haske, madaidaicin launin fata',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'sumba: babba, babba, launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'sumba: babba, babba, launin fata mai madaidaicin haske, launin fata mai duhu',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'sumba: babba, babba, madaidaicin launin fata, launin fata mai haske',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'sumba: babba, babba, madaidaicin launin fata, launin fata mai madaidaicin haske',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'sumba: babba, babba, madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'sumba: babba, babba, madaidaicin launin fata, launin fata mai duhu',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'sumba: babba, babba, launin fata mai madaidaicin duhu, launin fata mai haske',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'sumba: babba, babba, launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'sumba: babba, babba, launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'sumba: babba, babba, launin fata mai madaidaicin duhu, launin fata mai duhu',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'sumba: babba, babba, launin fata mai duhu, launin fata mai haske',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'sumba: babba, babba, launin fata mai duhu, launin fata mai madaidaicin haske',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'sumba: babba, babba, launin fata mai duhu, madaidaicin launin fata',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'sumba: babba, babba, launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👨🏻‍❤‍💋‍👨🏻' => 'sumba: namiji, namiji, launin fata mai haske',
    '👨🏻‍❤‍💋‍👨🏼' => 'sumba: namiji, namiji, launin fata mai haske, launin fata mai madaidaicin haske',
    '👨🏻‍❤‍💋‍👨🏽' => 'sumba: namiji, namiji, launin fata mai haske, madaidaicin launin fata',
    '👨🏻‍❤‍💋‍👨🏾' => 'sumba: namiji, namiji, launin fata mai haske, launin fata mai madaidaicin duhu',
    '👨🏻‍❤‍💋‍👨🏿' => 'sumba: namiji, namiji, launin fata mai haske, launin fata mai duhu',
    '👨🏼‍❤‍💋‍👨🏻' => 'sumba: namiji, namiji, launin fata mai madaidaicin haske, launin fata mai haske',
    '👨🏼‍❤‍💋‍👨🏼' => 'sumba: namiji, namiji, launin fata mai madaidaicin haske',
    '👨🏼‍❤‍💋‍👨🏽' => 'sumba: namiji, namiji, launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👨🏼‍❤‍💋‍👨🏾' => 'sumba: namiji, namiji, launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👨🏼‍❤‍💋‍👨🏿' => 'sumba: namiji, namiji, launin fata mai madaidaicin haske, launin fata mai duhu',
    '👨🏽‍❤‍💋‍👨🏻' => 'sumba: namiji, namiji, madaidaicin launin fata, launin fata mai haske',
    '👨🏽‍❤‍💋‍👨🏼' => 'sumba: namiji, namiji, madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👨🏽‍❤‍💋‍👨🏽' => 'sumba: namiji, namiji, madaidaicin launin fata',
    '👨🏽‍❤‍💋‍👨🏾' => 'sumba: namiji, namiji, madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👨🏽‍❤‍💋‍👨🏿' => 'sumba: namiji, namiji, madaidaicin launin fata, launin fata mai duhu',
    '👨🏾‍❤‍💋‍👨🏻' => 'sumba: namiji, namiji, launin fata mai madaidaicin duhu, launin fata mai haske',
    '👨🏾‍❤‍💋‍👨🏼' => 'sumba: namiji, namiji, launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👨🏾‍❤‍💋‍👨🏽' => 'sumba: namiji, namiji, launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👨🏾‍❤‍💋‍👨🏾' => 'sumba: namiji, namiji, launin fata mai madaidaicin duhu',
    '👨🏾‍❤‍💋‍👨🏿' => 'sumba: namiji, namiji, launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👨🏿‍❤‍💋‍👨🏻' => 'sumba: namiji, namiji, launin fata mai duhu, launin fata mai haske',
    '👨🏿‍❤‍💋‍👨🏼' => 'sumba: namiji, namiji, launin fata mai duhu, launin fata mai madaidaicin haske',
    '👨🏿‍❤‍💋‍👨🏽' => 'sumba: namiji, namiji, launin fata mai duhu, madaidaicin launin fata',
    '👨🏿‍❤‍💋‍👨🏾' => 'sumba: namiji, namiji, launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👨🏿‍❤‍💋‍👨🏿' => 'sumba: namiji, namiji, launin fata mai duhu',
    '👩🏻‍❤‍💋‍👨🏻' => 'sumba: mace, namiji, launin fata mai haske',
    '👩🏻‍❤‍💋‍👨🏼' => 'sumba: mace, namiji, launin fata mai haske, launin fata mai madaidaicin haske',
    '👩🏻‍❤‍💋‍👨🏽' => 'sumba: mace, namiji, launin fata mai haske, madaidaicin launin fata',
    '👩🏻‍❤‍💋‍👨🏾' => 'sumba: mace, namiji, launin fata mai haske, launin fata mai madaidaicin duhu',
    '👩🏻‍❤‍💋‍👨🏿' => 'sumba: mace, namiji, launin fata mai haske, launin fata mai duhu',
    '👩🏼‍❤‍💋‍👨🏻' => 'sumba: mace, namiji, launin fata mai madaidaicin haske, launin fata mai haske',
    '👩🏼‍❤‍💋‍👨🏼' => 'sumba: mace, namiji, launin fata mai madaidaicin haske',
    '👩🏼‍❤‍💋‍👨🏽' => 'sumba: mace, namiji, launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👩🏼‍❤‍💋‍👨🏾' => 'sumba: mace, namiji, launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👩🏼‍❤‍💋‍👨🏿' => 'sumba: mace, namiji, launin fata mai madaidaicin haske, launin fata mai duhu',
    '👩🏽‍❤‍💋‍👨🏻' => 'sumba: mace, namiji, madaidaicin launin fata, launin fata mai haske',
    '👩🏽‍❤‍💋‍👨🏼' => 'sumba: mace, namiji, madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👩🏽‍❤‍💋‍👨🏽' => 'sumba: mace, namiji, madaidaicin launin fata',
    '👩🏽‍❤‍💋‍👨🏾' => 'sumba: mace, namiji, madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👩🏽‍❤‍💋‍👨🏿' => 'sumba: mace, namiji, madaidaicin launin fata, launin fata mai duhu',
    '👩🏾‍❤‍💋‍👨🏻' => 'sumba: mace, namiji, launin fata mai madaidaicin duhu, launin fata mai haske',
    '👩🏾‍❤‍💋‍👨🏼' => 'sumba: mace, namiji, launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👩🏾‍❤‍💋‍👨🏽' => 'sumba: mace, namiji, launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👩🏾‍❤‍💋‍👨🏾' => 'sumba: mace, namiji, launin fata mai madaidaicin duhu',
    '👩🏾‍❤‍💋‍👨🏿' => 'sumba: mace, namiji, launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👩🏿‍❤‍💋‍👨🏻' => 'sumba: mace, namiji, launin fata mai duhu, launin fata mai haske',
    '👩🏿‍❤‍💋‍👨🏼' => 'sumba: mace, namiji, launin fata mai duhu, launin fata mai madaidaicin haske',
    '👩🏿‍❤‍💋‍👨🏽' => 'sumba: mace, namiji, launin fata mai duhu, madaidaicin launin fata',
    '👩🏿‍❤‍💋‍👨🏾' => 'sumba: mace, namiji, launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👩🏿‍❤‍💋‍👨🏿' => 'sumba: mace, namiji, launin fata mai duhu',
    '👩🏻‍❤‍💋‍👩🏻' => 'sumba: mace, mace, launin fata mai haske',
    '👩🏻‍❤‍💋‍👩🏼' => 'sumba: mace, mace, launin fata mai haske, launin fata mai madaidaicin haske',
    '👩🏻‍❤‍💋‍👩🏽' => 'sumba: mace, mace, launin fata mai haske, madaidaicin launin fata',
    '👩🏻‍❤‍💋‍👩🏾' => 'sumba: mace, mace, launin fata mai haske, launin fata mai madaidaicin duhu',
    '👩🏻‍❤‍💋‍👩🏿' => 'sumba: mace, mace, launin fata mai haske, launin fata mai duhu',
    '👩🏼‍❤‍💋‍👩🏻' => 'sumba: mace, mace, launin fata mai madaidaicin haske, launin fata mai haske',
    '👩🏼‍❤‍💋‍👩🏼' => 'sumba: mace, mace, launin fata mai madaidaicin haske',
    '👩🏼‍❤‍💋‍👩🏽' => 'sumba: mace, mace, launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👩🏼‍❤‍💋‍👩🏾' => 'sumba: mace, mace, launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👩🏼‍❤‍💋‍👩🏿' => 'sumba: mace, mace, launin fata mai madaidaicin haske, launin fata mai duhu',
    '👩🏽‍❤‍💋‍👩🏻' => 'sumba: mace, mace, madaidaicin launin fata, launin fata mai haske',
    '👩🏽‍❤‍💋‍👩🏼' => 'sumba: mace, mace, madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👩🏽‍❤‍💋‍👩🏽' => 'sumba: mace, mace, madaidaicin launin fata',
    '👩🏽‍❤‍💋‍👩🏾' => 'sumba: mace, mace, madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👩🏽‍❤‍💋‍👩🏿' => 'sumba: mace, mace, madaidaicin launin fata, launin fata mai duhu',
    '👩🏾‍❤‍💋‍👩🏻' => 'sumba: mace, mace, launin fata mai madaidaicin duhu, launin fata mai haske',
    '👩🏾‍❤‍💋‍👩🏼' => 'sumba: mace, mace, launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👩🏾‍❤‍💋‍👩🏽' => 'sumba: mace, mace, launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👩🏾‍❤‍💋‍👩🏾' => 'sumba: mace, mace, launin fata mai madaidaicin duhu',
    '👩🏾‍❤‍💋‍👩🏿' => 'sumba: mace, mace, launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👩🏿‍❤‍💋‍👩🏻' => 'sumba: mace, mace, launin fata mai duhu, launin fata mai haske',
    '👩🏿‍❤‍💋‍👩🏼' => 'sumba: mace, mace, launin fata mai duhu, launin fata mai madaidaicin haske',
    '👩🏿‍❤‍💋‍👩🏽' => 'sumba: mace, mace, launin fata mai duhu, madaidaicin launin fata',
    '👩🏿‍❤‍💋‍👩🏾' => 'sumba: mace, mace, launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👩🏿‍❤‍💋‍👩🏿' => 'sumba: mace, mace, launin fata mai duhu',
    '🧑🏻‍🫯‍🧑🏼' => 'mutane masu kokawa: launin fata mai haske, launin fata mai madaidaicin haske',
    '🧑🏻‍🫯‍🧑🏽' => 'mutane masu kokawa: launin fata mai haske, madaidaicin launin fata',
    '🧑🏻‍🫯‍🧑🏾' => 'mutane masu kokawa: launin fata mai haske, launin fata mai madaidaicin duhu',
    '🧑🏻‍🫯‍🧑🏿' => 'mutane masu kokawa: launin fata mai haske, launin fata mai duhu',
    '🧑🏼‍🫯‍🧑🏻' => 'mutane masu kokawa: launin fata mai madaidaicin haske, launin fata mai haske',
    '🧑🏼‍🫯‍🧑🏽' => 'mutane masu kokawa: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '🧑🏼‍🫯‍🧑🏾' => 'mutane masu kokawa: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '🧑🏼‍🫯‍🧑🏿' => 'mutane masu kokawa: launin fata mai madaidaicin haske, launin fata mai duhu',
    '🧑🏽‍🫯‍🧑🏻' => 'mutane masu kokawa: madaidaicin launin fata, launin fata mai haske',
    '🧑🏽‍🫯‍🧑🏼' => 'mutane masu kokawa: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '🧑🏽‍🫯‍🧑🏾' => 'mutane masu kokawa: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '🧑🏽‍🫯‍🧑🏿' => 'mutane masu kokawa: madaidaicin launin fata, launin fata mai duhu',
    '🧑🏾‍🫯‍🧑🏻' => 'mutane masu kokawa: launin fata mai madaidaicin duhu, launin fata mai haske',
    '🧑🏾‍🫯‍🧑🏼' => 'mutane masu kokawa: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '🧑🏾‍🫯‍🧑🏽' => 'mutane masu kokawa: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '🧑🏾‍🫯‍🧑🏿' => 'mutane masu kokawa: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '🧑🏿‍🫯‍🧑🏻' => 'mutane masu kokawa: launin fata mai duhu, launin fata mai haske',
    '🧑🏿‍🫯‍🧑🏼' => 'mutane masu kokawa: launin fata mai duhu, launin fata mai madaidaicin haske',
    '🧑🏿‍🫯‍🧑🏽' => 'mutane masu kokawa: launin fata mai duhu, madaidaicin launin fata',
    '🧑🏿‍🫯‍🧑🏾' => 'mutane masu kokawa: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '🧑🏻‍❤‍🧑🏼' => 'miji da mata tare da zuciya: babba, babba, launin fata mai haske, launin fata mai madaidaicin haske',
    '🧑🏻‍❤‍🧑🏽' => 'miji da mata tare da zuciya: babba, babba, launin fata mai haske, madaidaicin launin fata',
    '🧑🏻‍❤‍🧑🏾' => 'miji da mata tare da zuciya: babba, babba, launin fata mai haske, launin fata mai madaidaicin duhu',
    '🧑🏻‍❤‍🧑🏿' => 'miji da mata tare da zuciya: babba, babba, launin fata mai haske, launin fata mai duhu',
    '🧑🏼‍❤‍🧑🏻' => 'miji da mata tare da zuciya: babba, babba, launin fata mai madaidaicin haske, launin fata mai haske',
    '🧑🏼‍❤‍🧑🏽' => 'miji da mata tare da zuciya: babba, babba, launin fata mai madaidaicin haske, madaidaicin launin fata',
    '🧑🏼‍❤‍🧑🏾' => 'miji da mata tare da zuciya: babba, babba, launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '🧑🏼‍❤‍🧑🏿' => 'miji da mata tare da zuciya: babba, babba, launin fata mai madaidaicin haske, launin fata mai duhu',
    '🧑🏽‍❤‍🧑🏻' => 'miji da mata tare da zuciya: babba, babba, madaidaicin launin fata, launin fata mai haske',
    '🧑🏽‍❤‍🧑🏼' => 'miji da mata tare da zuciya: babba, babba, madaidaicin launin fata, launin fata mai madaidaicin haske',
    '🧑🏽‍❤‍🧑🏾' => 'miji da mata tare da zuciya: babba, babba, madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '🧑🏽‍❤‍🧑🏿' => 'miji da mata tare da zuciya: babba, babba, madaidaicin launin fata, launin fata mai duhu',
    '🧑🏾‍❤‍🧑🏻' => 'miji da mata tare da zuciya: babba, babba, launin fata mai madaidaicin duhu, launin fata mai haske',
    '🧑🏾‍❤‍🧑🏼' => 'miji da mata tare da zuciya: babba, babba, launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '🧑🏾‍❤‍🧑🏽' => 'miji da mata tare da zuciya: babba, babba, launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '🧑🏾‍❤‍🧑🏿' => 'miji da mata tare da zuciya: babba, babba, launin fata mai madaidaicin duhu, launin fata mai duhu',
    '🧑🏿‍❤‍🧑🏻' => 'miji da mata tare da zuciya: babba, babba, launin fata mai duhu, launin fata mai haske',
    '🧑🏿‍❤‍🧑🏼' => 'miji da mata tare da zuciya: babba, babba, launin fata mai duhu, launin fata mai madaidaicin haske',
    '🧑🏿‍❤‍🧑🏽' => 'miji da mata tare da zuciya: babba, babba, launin fata mai duhu, madaidaicin launin fata',
    '🧑🏿‍❤‍🧑🏾' => 'miji da mata tare da zuciya: babba, babba, launin fata mai duhu, launin fata mai madaidaicin duhu',
    '🧑🏻‍🐰‍🧑🏼' => 'mutane masu kunnuwan zomo yin biki: launin fata mai haske, launin fata mai madaidaicin haske',
    '🧑🏻‍🐰‍🧑🏽' => 'mutane masu kunnuwan zomo yin biki: launin fata mai haske, madaidaicin launin fata',
    '🧑🏻‍🐰‍🧑🏾' => 'mutane masu kunnuwan zomo yin biki: launin fata mai haske, launin fata mai madaidaicin duhu',
    '🧑🏻‍🐰‍🧑🏿' => 'mutane masu kunnuwan zomo yin biki: launin fata mai haske, launin fata mai duhu',
    '🧑🏼‍🐰‍🧑🏻' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, launin fata mai haske',
    '🧑🏼‍🐰‍🧑🏽' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '🧑🏼‍🐰‍🧑🏾' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '🧑🏼‍🐰‍🧑🏿' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, launin fata mai duhu',
    '🧑🏽‍🐰‍🧑🏻' => 'mutane masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai haske',
    '🧑🏽‍🐰‍🧑🏼' => 'mutane masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '🧑🏽‍🐰‍🧑🏾' => 'mutane masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '🧑🏽‍🐰‍🧑🏿' => 'mutane masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai duhu',
    '🧑🏾‍🐰‍🧑🏻' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, launin fata mai haske',
    '🧑🏾‍🐰‍🧑🏼' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '🧑🏾‍🐰‍🧑🏽' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '🧑🏾‍🐰‍🧑🏿' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '🧑🏿‍🐰‍🧑🏻' => 'mutane masu kunnuwan zomo yin biki: launin fata mai duhu, launin fata mai haske',
    '🧑🏿‍🐰‍🧑🏼' => 'mutane masu kunnuwan zomo yin biki: launin fata mai duhu, launin fata mai madaidaicin haske',
    '🧑🏿‍🐰‍🧑🏽' => 'mutane masu kunnuwan zomo yin biki: launin fata mai duhu, madaidaicin launin fata',
    '🧑🏿‍🐰‍🧑🏾' => 'mutane masu kunnuwan zomo yin biki: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👨🏻‍🫯‍👨🏼' => 'maza masu kokawa: launin fata mai haske, launin fata mai madaidaicin haske',
    '👨🏻‍🫯‍👨🏽' => 'maza masu kokawa: launin fata mai haske, madaidaicin launin fata',
    '👨🏻‍🫯‍👨🏾' => 'maza masu kokawa: launin fata mai haske, launin fata mai madaidaicin duhu',
    '👨🏻‍🫯‍👨🏿' => 'maza masu kokawa: launin fata mai haske, launin fata mai duhu',
    '👨🏼‍🫯‍👨🏻' => 'maza masu kokawa: launin fata mai madaidaicin haske, launin fata mai haske',
    '👨🏼‍🫯‍👨🏽' => 'maza masu kokawa: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👨🏼‍🫯‍👨🏾' => 'maza masu kokawa: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👨🏼‍🫯‍👨🏿' => 'maza masu kokawa: launin fata mai madaidaicin haske, launin fata mai duhu',
    '👨🏽‍🫯‍👨🏻' => 'maza masu kokawa: madaidaicin launin fata, launin fata mai haske',
    '👨🏽‍🫯‍👨🏼' => 'maza masu kokawa: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👨🏽‍🫯‍👨🏾' => 'maza masu kokawa: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👨🏽‍🫯‍👨🏿' => 'maza masu kokawa: madaidaicin launin fata, launin fata mai duhu',
    '👨🏾‍🫯‍👨🏻' => 'maza masu kokawa: launin fata mai madaidaicin duhu, launin fata mai haske',
    '👨🏾‍🫯‍👨🏼' => 'maza masu kokawa: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👨🏾‍🫯‍👨🏽' => 'maza masu kokawa: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👨🏾‍🫯‍👨🏿' => 'maza masu kokawa: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👨🏿‍🫯‍👨🏻' => 'maza masu kokawa: launin fata mai duhu, launin fata mai haske',
    '👨🏿‍🫯‍👨🏼' => 'maza masu kokawa: launin fata mai duhu, launin fata mai madaidaicin haske',
    '👨🏿‍🫯‍👨🏽' => 'maza masu kokawa: launin fata mai duhu, madaidaicin launin fata',
    '👨🏿‍🫯‍👨🏾' => 'maza masu kokawa: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👨🏻‍❤‍👨🏻' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai haske',
    '👨🏻‍❤‍👨🏼' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai haske, launin fata mai madaidaicin haske',
    '👨🏻‍❤‍👨🏽' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai haske, madaidaicin launin fata',
    '👨🏻‍❤‍👨🏾' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai haske, launin fata mai madaidaicin duhu',
    '👨🏻‍❤‍👨🏿' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai haske, launin fata mai duhu',
    '👨🏼‍❤‍👨🏻' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin haske, launin fata mai haske',
    '👨🏼‍❤‍👨🏼' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin haske',
    '👨🏼‍❤‍👨🏽' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👨🏼‍❤‍👨🏾' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👨🏼‍❤‍👨🏿' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin haske, launin fata mai duhu',
    '👨🏽‍❤‍👨🏻' => 'miji da mata tare da zuciya: namiji, namiji, madaidaicin launin fata, launin fata mai haske',
    '👨🏽‍❤‍👨🏼' => 'miji da mata tare da zuciya: namiji, namiji, madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👨🏽‍❤‍👨🏽' => 'miji da mata tare da zuciya: namiji, namiji, madaidaicin launin fata',
    '👨🏽‍❤‍👨🏾' => 'miji da mata tare da zuciya: namiji, namiji, madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👨🏽‍❤‍👨🏿' => 'miji da mata tare da zuciya: namiji, namiji, madaidaicin launin fata, launin fata mai duhu',
    '👨🏾‍❤‍👨🏻' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin duhu, launin fata mai haske',
    '👨🏾‍❤‍👨🏼' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👨🏾‍❤‍👨🏽' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👨🏾‍❤‍👨🏾' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin duhu',
    '👨🏾‍❤‍👨🏿' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👨🏿‍❤‍👨🏻' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai duhu, launin fata mai haske',
    '👨🏿‍❤‍👨🏼' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai duhu, launin fata mai madaidaicin haske',
    '👨🏿‍❤‍👨🏽' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai duhu, madaidaicin launin fata',
    '👨🏿‍❤‍👨🏾' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👨🏿‍❤‍👨🏿' => 'miji da mata tare da zuciya: namiji, namiji, launin fata mai duhu',
    '👨🏻‍🐰‍👨🏼' => 'maza masu kunnuwan zomo yin biki: launin fata mai haske, launin fata mai madaidaicin haske',
    '👨🏻‍🐰‍👨🏽' => 'maza masu kunnuwan zomo yin biki: launin fata mai haske, madaidaicin launin fata',
    '👨🏻‍🐰‍👨🏾' => 'maza masu kunnuwan zomo yin biki: launin fata mai haske, launin fata mai madaidaicin duhu',
    '👨🏻‍🐰‍👨🏿' => 'maza masu kunnuwan zomo yin biki: launin fata mai haske, launin fata mai duhu',
    '👨🏼‍🐰‍👨🏻' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, launin fata mai haske',
    '👨🏼‍🐰‍👨🏽' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👨🏼‍🐰‍👨🏾' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👨🏼‍🐰‍👨🏿' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, launin fata mai duhu',
    '👨🏽‍🐰‍👨🏻' => 'maza masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai haske',
    '👨🏽‍🐰‍👨🏼' => 'maza masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👨🏽‍🐰‍👨🏾' => 'maza masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👨🏽‍🐰‍👨🏿' => 'maza masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai duhu',
    '👨🏾‍🐰‍👨🏻' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, launin fata mai haske',
    '👨🏾‍🐰‍👨🏼' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👨🏾‍🐰‍👨🏽' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👨🏾‍🐰‍👨🏿' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👨🏿‍🐰‍👨🏻' => 'maza masu kunnuwan zomo yin biki: launin fata mai duhu, launin fata mai haske',
    '👨🏿‍🐰‍👨🏼' => 'maza masu kunnuwan zomo yin biki: launin fata mai duhu, launin fata mai madaidaicin haske',
    '👨🏿‍🐰‍👨🏽' => 'maza masu kunnuwan zomo yin biki: launin fata mai duhu, madaidaicin launin fata',
    '👨🏿‍🐰‍👨🏾' => 'maza masu kunnuwan zomo yin biki: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👩🏻‍🫯‍👩🏼' => 'mata masu kokawa: launin fata mai haske, launin fata mai madaidaicin haske',
    '👩🏻‍🫯‍👩🏽' => 'mata masu kokawa: launin fata mai haske, madaidaicin launin fata',
    '👩🏻‍🫯‍👩🏾' => 'mata masu kokawa: launin fata mai haske, launin fata mai madaidaicin duhu',
    '👩🏻‍🫯‍👩🏿' => 'mata masu kokawa: launin fata mai haske, launin fata mai duhu',
    '👩🏼‍🫯‍👩🏻' => 'mata masu kokawa: launin fata mai madaidaicin haske, launin fata mai haske',
    '👩🏼‍🫯‍👩🏽' => 'mata masu kokawa: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👩🏼‍🫯‍👩🏾' => 'mata masu kokawa: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👩🏼‍🫯‍👩🏿' => 'mata masu kokawa: launin fata mai madaidaicin haske, launin fata mai duhu',
    '👩🏽‍🫯‍👩🏻' => 'mata masu kokawa: madaidaicin launin fata, launin fata mai haske',
    '👩🏽‍🫯‍👩🏼' => 'mata masu kokawa: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👩🏽‍🫯‍👩🏾' => 'mata masu kokawa: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👩🏽‍🫯‍👩🏿' => 'mata masu kokawa: madaidaicin launin fata, launin fata mai duhu',
    '👩🏾‍🫯‍👩🏻' => 'mata masu kokawa: launin fata mai madaidaicin duhu, launin fata mai haske',
    '👩🏾‍🫯‍👩🏼' => 'mata masu kokawa: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👩🏾‍🫯‍👩🏽' => 'mata masu kokawa: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👩🏾‍🫯‍👩🏿' => 'mata masu kokawa: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👩🏿‍🫯‍👩🏻' => 'mata masu kokawa: launin fata mai duhu, launin fata mai haske',
    '👩🏿‍🫯‍👩🏼' => 'mata masu kokawa: launin fata mai duhu, launin fata mai madaidaicin haske',
    '👩🏿‍🫯‍👩🏽' => 'mata masu kokawa: launin fata mai duhu, madaidaicin launin fata',
    '👩🏿‍🫯‍👩🏾' => 'mata masu kokawa: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👩🏻‍❤‍👨🏻' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai haske',
    '👩🏻‍❤‍👨🏼' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai haske, launin fata mai madaidaicin haske',
    '👩🏻‍❤‍👨🏽' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai haske, madaidaicin launin fata',
    '👩🏻‍❤‍👨🏾' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai haske, launin fata mai madaidaicin duhu',
    '👩🏻‍❤‍👨🏿' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai haske, launin fata mai duhu',
    '👩🏼‍❤‍👨🏻' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin haske, launin fata mai haske',
    '👩🏼‍❤‍👨🏼' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin haske',
    '👩🏼‍❤‍👨🏽' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👩🏼‍❤‍👨🏾' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👩🏼‍❤‍👨🏿' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin haske, launin fata mai duhu',
    '👩🏽‍❤‍👨🏻' => 'miji da mata tare da zuciya: mace, namiji, madaidaicin launin fata, launin fata mai haske',
    '👩🏽‍❤‍👨🏼' => 'miji da mata tare da zuciya: mace, namiji, madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👩🏽‍❤‍👨🏽' => 'miji da mata tare da zuciya: mace, namiji, madaidaicin launin fata',
    '👩🏽‍❤‍👨🏾' => 'miji da mata tare da zuciya: mace, namiji, madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👩🏽‍❤‍👨🏿' => 'miji da mata tare da zuciya: mace, namiji, madaidaicin launin fata, launin fata mai duhu',
    '👩🏾‍❤‍👨🏻' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin duhu, launin fata mai haske',
    '👩🏾‍❤‍👨🏼' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👩🏾‍❤‍👨🏽' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👩🏾‍❤‍👨🏾' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin duhu',
    '👩🏾‍❤‍👨🏿' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👩🏿‍❤‍👨🏻' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai duhu, launin fata mai haske',
    '👩🏿‍❤‍👨🏼' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai duhu, launin fata mai madaidaicin haske',
    '👩🏿‍❤‍👨🏽' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai duhu, madaidaicin launin fata',
    '👩🏿‍❤‍👨🏾' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👩🏿‍❤‍👨🏿' => 'miji da mata tare da zuciya: mace, namiji, launin fata mai duhu',
    '👩🏻‍❤‍👩🏻' => 'miji da mata tare da zuciya: mace, mace, launin fata mai haske',
    '👩🏻‍❤‍👩🏼' => 'miji da mata tare da zuciya: mace, mace, launin fata mai haske, launin fata mai madaidaicin haske',
    '👩🏻‍❤‍👩🏽' => 'miji da mata tare da zuciya: mace, mace, launin fata mai haske, madaidaicin launin fata',
    '👩🏻‍❤‍👩🏾' => 'miji da mata tare da zuciya: mace, mace, launin fata mai haske, launin fata mai madaidaicin duhu',
    '👩🏻‍❤‍👩🏿' => 'miji da mata tare da zuciya: mace, mace, launin fata mai haske, launin fata mai duhu',
    '👩🏼‍❤‍👩🏻' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin haske, launin fata mai haske',
    '👩🏼‍❤‍👩🏼' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin haske',
    '👩🏼‍❤‍👩🏽' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👩🏼‍❤‍👩🏾' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👩🏼‍❤‍👩🏿' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin haske, launin fata mai duhu',
    '👩🏽‍❤‍👩🏻' => 'miji da mata tare da zuciya: mace, mace, madaidaicin launin fata, launin fata mai haske',
    '👩🏽‍❤‍👩🏼' => 'miji da mata tare da zuciya: mace, mace, madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👩🏽‍❤‍👩🏽' => 'miji da mata tare da zuciya: mace, mace, madaidaicin launin fata',
    '👩🏽‍❤‍👩🏾' => 'miji da mata tare da zuciya: mace, mace, madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👩🏽‍❤‍👩🏿' => 'miji da mata tare da zuciya: mace, mace, madaidaicin launin fata, launin fata mai duhu',
    '👩🏾‍❤‍👩🏻' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin duhu, launin fata mai haske',
    '👩🏾‍❤‍👩🏼' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👩🏾‍❤‍👩🏽' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👩🏾‍❤‍👩🏾' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin duhu',
    '👩🏾‍❤‍👩🏿' => 'miji da mata tare da zuciya: mace, mace, launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👩🏿‍❤‍👩🏻' => 'miji da mata tare da zuciya: mace, mace, launin fata mai duhu, launin fata mai haske',
    '👩🏿‍❤‍👩🏼' => 'miji da mata tare da zuciya: mace, mace, launin fata mai duhu, launin fata mai madaidaicin haske',
    '👩🏿‍❤‍👩🏽' => 'miji da mata tare da zuciya: mace, mace, launin fata mai duhu, madaidaicin launin fata',
    '👩🏿‍❤‍👩🏾' => 'miji da mata tare da zuciya: mace, mace, launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👩🏿‍❤‍👩🏿' => 'miji da mata tare da zuciya: mace, mace, launin fata mai duhu',
    '👩🏻‍🐰‍👩🏼' => 'mata masu kunnuwan zomo yin biki: launin fata mai haske, launin fata mai madaidaicin haske',
    '👩🏻‍🐰‍👩🏽' => 'mata masu kunnuwan zomo yin biki: launin fata mai haske, madaidaicin launin fata',
    '👩🏻‍🐰‍👩🏾' => 'mata masu kunnuwan zomo yin biki: launin fata mai haske, launin fata mai madaidaicin duhu',
    '👩🏻‍🐰‍👩🏿' => 'mata masu kunnuwan zomo yin biki: launin fata mai haske, launin fata mai duhu',
    '👩🏼‍🐰‍👩🏻' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, launin fata mai haske',
    '👩🏼‍🐰‍👩🏽' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👩🏼‍🐰‍👩🏾' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👩🏼‍🐰‍👩🏿' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske, launin fata mai duhu',
    '👩🏽‍🐰‍👩🏻' => 'mata masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai haske',
    '👩🏽‍🐰‍👩🏼' => 'mata masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👩🏽‍🐰‍👩🏾' => 'mata masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👩🏽‍🐰‍👩🏿' => 'mata masu kunnuwan zomo yin biki: madaidaicin launin fata, launin fata mai duhu',
    '👩🏾‍🐰‍👩🏻' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, launin fata mai haske',
    '👩🏾‍🐰‍👩🏼' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👩🏾‍🐰‍👩🏽' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👩🏾‍🐰‍👩🏿' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👩🏿‍🐰‍👩🏻' => 'mata masu kunnuwan zomo yin biki: launin fata mai duhu, launin fata mai haske',
    '👩🏿‍🐰‍👩🏼' => 'mata masu kunnuwan zomo yin biki: launin fata mai duhu, launin fata mai madaidaicin haske',
    '👩🏿‍🐰‍👩🏽' => 'mata masu kunnuwan zomo yin biki: launin fata mai duhu, madaidaicin launin fata',
    '👩🏿‍🐰‍👩🏾' => 'mata masu kunnuwan zomo yin biki: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '🧑🏻‍🤝‍🧑🏻' => 'mutane masu rikon hannaye: launin fata mai haske',
    '🧑🏻‍🤝‍🧑🏼' => 'mutane masu rikon hannaye: launin fata mai haske, launin fata mai madaidaicin haske',
    '🧑🏻‍🤝‍🧑🏽' => 'mutane masu rikon hannaye: launin fata mai haske, madaidaicin launin fata',
    '🧑🏻‍🤝‍🧑🏾' => 'mutane masu rikon hannaye: launin fata mai haske, launin fata mai madaidaicin duhu',
    '🧑🏻‍🤝‍🧑🏿' => 'mutane masu rikon hannaye: launin fata mai haske, launin fata mai duhu',
    '🧑🏼‍🤝‍🧑🏻' => 'mutane masu rikon hannaye: launin fata mai madaidaicin haske, launin fata mai haske',
    '🧑🏼‍🤝‍🧑🏼' => 'mutane masu rikon hannaye: launin fata mai madaidaicin haske',
    '🧑🏼‍🤝‍🧑🏽' => 'mutane masu rikon hannaye: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '🧑🏼‍🤝‍🧑🏾' => 'mutane masu rikon hannaye: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '🧑🏼‍🤝‍🧑🏿' => 'mutane masu rikon hannaye: launin fata mai madaidaicin haske, launin fata mai duhu',
    '🧑🏽‍🤝‍🧑🏻' => 'mutane masu rikon hannaye: madaidaicin launin fata, launin fata mai haske',
    '🧑🏽‍🤝‍🧑🏼' => 'mutane masu rikon hannaye: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '🧑🏽‍🤝‍🧑🏽' => 'mutane masu rikon hannaye: madaidaicin launin fata',
    '🧑🏽‍🤝‍🧑🏾' => 'mutane masu rikon hannaye: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '🧑🏽‍🤝‍🧑🏿' => 'mutane masu rikon hannaye: madaidaicin launin fata, launin fata mai duhu',
    '🧑🏾‍🤝‍🧑🏻' => 'mutane masu rikon hannaye: launin fata mai madaidaicin duhu, launin fata mai haske',
    '🧑🏾‍🤝‍🧑🏼' => 'mutane masu rikon hannaye: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '🧑🏾‍🤝‍🧑🏽' => 'mutane masu rikon hannaye: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '🧑🏾‍🤝‍🧑🏾' => 'mutane masu rikon hannaye: launin fata mai madaidaicin duhu',
    '🧑🏾‍🤝‍🧑🏿' => 'mutane masu rikon hannaye: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '🧑🏿‍🤝‍🧑🏻' => 'mutane masu rikon hannaye: launin fata mai duhu, launin fata mai haske',
    '🧑🏿‍🤝‍🧑🏼' => 'mutane masu rikon hannaye: launin fata mai duhu, launin fata mai madaidaicin haske',
    '🧑🏿‍🤝‍🧑🏽' => 'mutane masu rikon hannaye: launin fata mai duhu, madaidaicin launin fata',
    '🧑🏿‍🤝‍🧑🏾' => 'mutane masu rikon hannaye: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '🧑🏿‍🤝‍🧑🏿' => 'mutane masu rikon hannaye: launin fata mai duhu',
    '👩🏻‍🤝‍👩🏼' => 'namiji da mata suna riƙew da hannuwa: launin fata mai haske, launin fata mai madaidaicin haske',
    '👩🏻‍🤝‍👩🏽' => 'namiji da mata suna riƙew da hannuwa: launin fata mai haske, madaidaicin launin fata',
    '👩🏻‍🤝‍👩🏾' => 'namiji da mata suna riƙew da hannuwa: launin fata mai haske, launin fata mai madaidaicin duhu',
    '👩🏻‍🤝‍👩🏿' => 'namiji da mata suna riƙew da hannuwa: launin fata mai haske, launin fata mai duhu',
    '👩🏼‍🤝‍👩🏻' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin haske, launin fata mai haske',
    '👩🏼‍🤝‍👩🏽' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👩🏼‍🤝‍👩🏾' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👩🏼‍🤝‍👩🏿' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin haske, launin fata mai duhu',
    '👩🏽‍🤝‍👩🏻' => 'namiji da mata suna riƙew da hannuwa: madaidaicin launin fata, launin fata mai haske',
    '👩🏽‍🤝‍👩🏼' => 'namiji da mata suna riƙew da hannuwa: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👩🏽‍🤝‍👩🏾' => 'namiji da mata suna riƙew da hannuwa: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👩🏽‍🤝‍👩🏿' => 'namiji da mata suna riƙew da hannuwa: madaidaicin launin fata, launin fata mai duhu',
    '👩🏾‍🤝‍👩🏻' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin duhu, launin fata mai haske',
    '👩🏾‍🤝‍👩🏼' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👩🏾‍🤝‍👩🏽' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👩🏾‍🤝‍👩🏿' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👩🏿‍🤝‍👩🏻' => 'namiji da mata suna riƙew da hannuwa: launin fata mai duhu, launin fata mai haske',
    '👩🏿‍🤝‍👩🏼' => 'namiji da mata suna riƙew da hannuwa: launin fata mai duhu, launin fata mai madaidaicin haske',
    '👩🏿‍🤝‍👩🏽' => 'namiji da mata suna riƙew da hannuwa: launin fata mai duhu, madaidaicin launin fata',
    '👩🏿‍🤝‍👩🏾' => 'namiji da mata suna riƙew da hannuwa: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👩🏻‍🤝‍👨🏼' => 'namiji da mace riƙe da hannuwa: launin fata mai haske, launin fata mai madaidaicin haske',
    '👩🏻‍🤝‍👨🏽' => 'namiji da mace riƙe da hannuwa: launin fata mai haske, madaidaicin launin fata',
    '👩🏻‍🤝‍👨🏾' => 'namiji da mace riƙe da hannuwa: launin fata mai haske, launin fata mai madaidaicin duhu',
    '👩🏻‍🤝‍👨🏿' => 'namiji da mace riƙe da hannuwa: launin fata mai haske, launin fata mai duhu',
    '👩🏼‍🤝‍👨🏻' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin haske, launin fata mai haske',
    '👩🏼‍🤝‍👨🏽' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👩🏼‍🤝‍👨🏾' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👩🏼‍🤝‍👨🏿' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin haske, launin fata mai duhu',
    '👩🏽‍🤝‍👨🏻' => 'namiji da mace riƙe da hannuwa: madaidaicin launin fata, launin fata mai haske',
    '👩🏽‍🤝‍👨🏼' => 'namiji da mace riƙe da hannuwa: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👩🏽‍🤝‍👨🏾' => 'namiji da mace riƙe da hannuwa: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👩🏽‍🤝‍👨🏿' => 'namiji da mace riƙe da hannuwa: madaidaicin launin fata, launin fata mai duhu',
    '👩🏾‍🤝‍👨🏻' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin duhu, launin fata mai haske',
    '👩🏾‍🤝‍👨🏼' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👩🏾‍🤝‍👨🏽' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👩🏾‍🤝‍👨🏿' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👩🏿‍🤝‍👨🏻' => 'namiji da mace riƙe da hannuwa: launin fata mai duhu, launin fata mai haske',
    '👩🏿‍🤝‍👨🏼' => 'namiji da mace riƙe da hannuwa: launin fata mai duhu, launin fata mai madaidaicin haske',
    '👩🏿‍🤝‍👨🏽' => 'namiji da mace riƙe da hannuwa: launin fata mai duhu, madaidaicin launin fata',
    '👩🏿‍🤝‍👨🏾' => 'namiji da mace riƙe da hannuwa: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👨🏻‍🤝‍👨🏼' => 'maza biyu riƙe da hannuwa: launin fata mai haske, launin fata mai madaidaicin haske',
    '👨🏻‍🤝‍👨🏽' => 'maza biyu riƙe da hannuwa: launin fata mai haske, madaidaicin launin fata',
    '👨🏻‍🤝‍👨🏾' => 'maza biyu riƙe da hannuwa: launin fata mai haske, launin fata mai madaidaicin duhu',
    '👨🏻‍🤝‍👨🏿' => 'maza biyu riƙe da hannuwa: launin fata mai haske, launin fata mai duhu',
    '👨🏼‍🤝‍👨🏻' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin haske, launin fata mai haske',
    '👨🏼‍🤝‍👨🏽' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '👨🏼‍🤝‍👨🏾' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '👨🏼‍🤝‍👨🏿' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin haske, launin fata mai duhu',
    '👨🏽‍🤝‍👨🏻' => 'maza biyu riƙe da hannuwa: madaidaicin launin fata, launin fata mai haske',
    '👨🏽‍🤝‍👨🏼' => 'maza biyu riƙe da hannuwa: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '👨🏽‍🤝‍👨🏾' => 'maza biyu riƙe da hannuwa: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '👨🏽‍🤝‍👨🏿' => 'maza biyu riƙe da hannuwa: madaidaicin launin fata, launin fata mai duhu',
    '👨🏾‍🤝‍👨🏻' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin duhu, launin fata mai haske',
    '👨🏾‍🤝‍👨🏼' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '👨🏾‍🤝‍👨🏽' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '👨🏾‍🤝‍👨🏿' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '👨🏿‍🤝‍👨🏻' => 'maza biyu riƙe da hannuwa: launin fata mai duhu, launin fata mai haske',
    '👨🏿‍🤝‍👨🏼' => 'maza biyu riƙe da hannuwa: launin fata mai duhu, launin fata mai madaidaicin haske',
    '👨🏿‍🤝‍👨🏽' => 'maza biyu riƙe da hannuwa: launin fata mai duhu, madaidaicin launin fata',
    '👨🏿‍🤝‍👨🏾' => 'maza biyu riƙe da hannuwa: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👩‍❤‍💋‍👨' => 'sumba: mace, namiji',
    '👨‍❤‍💋‍👨' => 'sumba: namiji, namiji',
    '👩‍❤‍💋‍👩' => 'sumba: mace, mace',
    '👨‍👩‍👧‍👦' => 'iyali: namiji, mace, yarinya, yaro',
    '👨‍👩‍👦‍👦' => 'iyali: namiji, mace, yaro, yaro',
    '👨‍👩‍👧‍👧' => 'iyali: namiji, mace, yarinya, yarinya',
    '👨‍👨‍👧‍👦' => 'iyali: namiji, namiji, yarinya, yaro',
    '👨‍👨‍👦‍👦' => 'iyali: namiji, namiji, yaro, yaro',
    '👨‍👨‍👧‍👧' => 'iyali: namiji, namiji, yarinya, yarinya',
    '👩‍👩‍👧‍👦' => 'iyali: mace, mace, yarinya, yaro',
    '👩‍👩‍👦‍👦' => 'iyali: mace, mace, yaro, yaro',
    '👩‍👩‍👧‍👧' => 'iyali: mace, mace, yarinya, yarinya',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'tuta: Ingila',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'tuta: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'iyali: manya, manya, yara, yara',
    '🫱🏻‍🫲🏼' => 'musafiha: launin fata mai haske, launin fata mai madaidaicin haske',
    '🫱🏻‍🫲🏽' => 'musafiha: launin fata mai haske, madaidaicin launin fata',
    '🫱🏻‍🫲🏾' => 'musafiha: launin fata mai haske, launin fata mai madaidaicin duhu',
    '🫱🏻‍🫲🏿' => 'musafiha: launin fata mai haske, launin fata mai duhu',
    '🫱🏼‍🫲🏻' => 'musafiha: launin fata mai madaidaicin haske, launin fata mai haske',
    '🫱🏼‍🫲🏽' => 'musafiha: launin fata mai madaidaicin haske, madaidaicin launin fata',
    '🫱🏼‍🫲🏾' => 'musafiha: launin fata mai madaidaicin haske, launin fata mai madaidaicin duhu',
    '🫱🏼‍🫲🏿' => 'musafiha: launin fata mai madaidaicin haske, launin fata mai duhu',
    '🫱🏽‍🫲🏻' => 'musafiha: madaidaicin launin fata, launin fata mai haske',
    '🫱🏽‍🫲🏼' => 'musafiha: madaidaicin launin fata, launin fata mai madaidaicin haske',
    '🫱🏽‍🫲🏾' => 'musafiha: madaidaicin launin fata, launin fata mai madaidaicin duhu',
    '🫱🏽‍🫲🏿' => 'musafiha: madaidaicin launin fata, launin fata mai duhu',
    '🫱🏾‍🫲🏻' => 'musafiha: launin fata mai madaidaicin duhu, launin fata mai haske',
    '🫱🏾‍🫲🏼' => 'musafiha: launin fata mai madaidaicin duhu, launin fata mai madaidaicin haske',
    '🫱🏾‍🫲🏽' => 'musafiha: launin fata mai madaidaicin duhu, madaidaicin launin fata',
    '🫱🏾‍🫲🏿' => 'musafiha: launin fata mai madaidaicin duhu, launin fata mai duhu',
    '🫱🏿‍🫲🏻' => 'musafiha: launin fata mai duhu, launin fata mai haske',
    '🫱🏿‍🫲🏼' => 'musafiha: launin fata mai duhu, launin fata mai madaidaicin haske',
    '🫱🏿‍🫲🏽' => 'musafiha: launin fata mai duhu, madaidaicin launin fata',
    '🫱🏿‍🫲🏾' => 'musafiha: launin fata mai duhu, launin fata mai madaidaicin duhu',
    '👩‍❤‍👨' => 'miji da mata tare da zuciya: mace, namiji',
    '👨‍❤‍👨' => 'miji da mata tare da zuciya: namiji, namiji',
    '👩‍❤‍👩' => 'miji da mata tare da zuciya: mace, mace',
    '👨‍👩‍👦' => 'iyali: namiji, mace, yaro',
    '👨‍👩‍👧' => 'iyali: namiji, mace, yarinya',
    '👨‍👨‍👦' => 'iyali: namiji, namiji, yaro',
    '👨‍👨‍👧' => 'iyali: namiji, namiji, yarinya',
    '👩‍👩‍👦' => 'iyali: mace, mace, yaro',
    '👩‍👩‍👧' => 'iyali: mace, mace, yarinya',
    '👨‍👦‍👦' => 'iyali: namiji, yaro, yaro',
    '👨‍👧‍👦' => 'iyali: namiji, yarinya, yaro',
    '👨‍👧‍👧' => 'iyali: namiji, yarinya, yarinya',
    '👩‍👦‍👦' => 'iyali: mace, yaro, yaro',
    '👩‍👧‍👦' => 'iyali: mace, yarinya, yaro',
    '👩‍👧‍👧' => 'iyali: mace, yarinya, yarinya',
    '🧑‍🤝‍🧑' => 'mutane masu rikon hannaye',
    '🧑‍🧑‍🧒' => 'iyali: manya, manya, yara',
    '🧑‍🧒‍🧒' => 'iyali: manya, yara, yara',
    '🧑🏻‍🦰' => 'babba: launin fata mai haske, jan gashi',
    '🧑🏼‍🦰' => 'babba: launin fata mai madaidaicin haske, jan gashi',
    '🧑🏽‍🦰' => 'babba: madaidaicin launin fata, jan gashi',
    '🧑🏾‍🦰' => 'babba: launin fata mai madaidaicin duhu, jan gashi',
    '🧑🏿‍🦰' => 'babba: launin fata mai duhu, jan gashi',
    '🧑🏻‍🦱' => 'babba: launin fata mai haske, gashi mai laushi',
    '🧑🏼‍🦱' => 'babba: launin fata mai madaidaicin haske, gashi mai laushi',
    '🧑🏽‍🦱' => 'babba: madaidaicin launin fata, gashi mai laushi',
    '🧑🏾‍🦱' => 'babba: launin fata mai madaidaicin duhu, gashi mai laushi',
    '🧑🏿‍🦱' => 'babba: launin fata mai duhu, gashi mai laushi',
    '🧑🏻‍🦳' => 'babba: launin fata mai haske, farin gashi',
    '🧑🏼‍🦳' => 'babba: launin fata mai madaidaicin haske, farin gashi',
    '🧑🏽‍🦳' => 'babba: madaidaicin launin fata, farin gashi',
    '🧑🏾‍🦳' => 'babba: launin fata mai madaidaicin duhu, farin gashi',
    '🧑🏿‍🦳' => 'babba: launin fata mai duhu, farin gashi',
    '🧑🏻‍🦲' => 'babba: launin fata mai haske, sanƙo',
    '🧑🏼‍🦲' => 'babba: launin fata mai madaidaicin haske, sanƙo',
    '🧑🏽‍🦲' => 'babba: madaidaicin launin fata, sanƙo',
    '🧑🏾‍🦲' => 'babba: launin fata mai madaidaicin duhu, sanƙo',
    '🧑🏿‍🦲' => 'babba: launin fata mai duhu, sanƙo',
    '🧑🏻‍🩰' => 'mai rawar ballet: launin fata mai haske',
    '🧑🏼‍🩰' => 'mai rawar ballet: launin fata mai madaidaicin haske',
    '🧑🏽‍🩰' => 'mai rawar ballet: madaidaicin launin fata',
    '🧑🏾‍🩰' => 'mai rawar ballet: launin fata mai madaidaicin duhu',
    '🧑🏿‍🩰' => 'mai rawar ballet: launin fata mai duhu',
    '🧔🏻‍♂' => 'na miji: launin fata mai haske, gemu',
    '🧔🏼‍♂' => 'na miji: launin fata mai madaidaicin haske, gemu',
    '🧔🏽‍♂' => 'na miji: madaidaicin launin fata, gemu',
    '🧔🏾‍♂' => 'na miji: launin fata mai madaidaicin duhu, gemu',
    '🧔🏿‍♂' => 'na miji: launin fata mai duhu, gemu',
    '👱🏻‍♂' => 'namiji mai farin gashi: launin fata mai haske',
    '👱🏼‍♂' => 'namiji mai farin gashi: launin fata mai madaidaicin haske',
    '👱🏽‍♂' => 'namiji mai farin gashi: madaidaicin launin fata',
    '👱🏾‍♂' => 'namiji mai farin gashi: launin fata mai madaidaicin duhu',
    '👱🏿‍♂' => 'namiji mai farin gashi: launin fata mai duhu',
    '👨🏻‍🦰' => 'namiji: launin fata mai haske, jan gashi',
    '👨🏼‍🦰' => 'namiji: launin fata mai madaidaicin haske, jan gashi',
    '👨🏽‍🦰' => 'namiji: madaidaicin launin fata, jan gashi',
    '👨🏾‍🦰' => 'namiji: launin fata mai madaidaicin duhu, jan gashi',
    '👨🏿‍🦰' => 'namiji: launin fata mai duhu, jan gashi',
    '👨🏻‍🦱' => 'namiji: launin fata mai haske, gashi mai laushi',
    '👨🏼‍🦱' => 'namiji: launin fata mai madaidaicin haske, gashi mai laushi',
    '👨🏽‍🦱' => 'namiji: madaidaicin launin fata, gashi mai laushi',
    '👨🏾‍🦱' => 'namiji: launin fata mai madaidaicin duhu, gashi mai laushi',
    '👨🏿‍🦱' => 'namiji: launin fata mai duhu, gashi mai laushi',
    '👨🏻‍🦳' => 'namiji: launin fata mai haske, farin gashi',
    '👨🏼‍🦳' => 'namiji: launin fata mai madaidaicin haske, farin gashi',
    '👨🏽‍🦳' => 'namiji: madaidaicin launin fata, farin gashi',
    '👨🏾‍🦳' => 'namiji: launin fata mai madaidaicin duhu, farin gashi',
    '👨🏿‍🦳' => 'namiji: launin fata mai duhu, farin gashi',
    '👨🏻‍🦲' => 'namiji: launin fata mai haske, sanƙo',
    '👨🏼‍🦲' => 'namiji: launin fata mai madaidaicin haske, sanƙo',
    '👨🏽‍🦲' => 'namiji: madaidaicin launin fata, sanƙo',
    '👨🏾‍🦲' => 'namiji: launin fata mai madaidaicin duhu, sanƙo',
    '👨🏿‍🦲' => 'namiji: launin fata mai duhu, sanƙo',
    '🧔🏻‍♀' => 'mace:gemu: launin fata mai haske',
    '🧔🏼‍♀' => 'mace:gemu: launin fata mai madaidaicin haske',
    '🧔🏽‍♀' => 'mace:gemu: madaidaicin launin fata',
    '🧔🏾‍♀' => 'mace:gemu: launin fata mai madaidaicin duhu',
    '🧔🏿‍♀' => 'mace:gemu: launin fata mai duhu',
    '👱🏻‍♀' => 'mace mai farin gashi: launin fata mai haske',
    '👱🏼‍♀' => 'mace mai farin gashi: launin fata mai madaidaicin haske',
    '👱🏽‍♀' => 'mace mai farin gashi: madaidaicin launin fata',
    '👱🏾‍♀' => 'mace mai farin gashi: launin fata mai madaidaicin duhu',
    '👱🏿‍♀' => 'mace mai farin gashi: launin fata mai duhu',
    '👩🏻‍🦰' => 'mace: launin fata mai haske, jan gashi',
    '👩🏼‍🦰' => 'mace: launin fata mai madaidaicin haske, jan gashi',
    '👩🏽‍🦰' => 'mace: madaidaicin launin fata, jan gashi',
    '👩🏾‍🦰' => 'mace: launin fata mai madaidaicin duhu, jan gashi',
    '👩🏿‍🦰' => 'mace: launin fata mai duhu, jan gashi',
    '👩🏻‍🦱' => 'mace: launin fata mai haske, gashi mai laushi',
    '👩🏼‍🦱' => 'mace: launin fata mai madaidaicin haske, gashi mai laushi',
    '👩🏽‍🦱' => 'mace: madaidaicin launin fata, gashi mai laushi',
    '👩🏾‍🦱' => 'mace: launin fata mai madaidaicin duhu, gashi mai laushi',
    '👩🏿‍🦱' => 'mace: launin fata mai duhu, gashi mai laushi',
    '👩🏻‍🦳' => 'mace: launin fata mai haske, farin gashi',
    '👩🏼‍🦳' => 'mace: launin fata mai madaidaicin haske, farin gashi',
    '👩🏽‍🦳' => 'mace: madaidaicin launin fata, farin gashi',
    '👩🏾‍🦳' => 'mace: launin fata mai madaidaicin duhu, farin gashi',
    '👩🏿‍🦳' => 'mace: launin fata mai duhu, farin gashi',
    '👩🏻‍🦲' => 'mace: launin fata mai haske, sanƙo',
    '👩🏼‍🦲' => 'mace: launin fata mai madaidaicin haske, sanƙo',
    '👩🏽‍🦲' => 'mace: madaidaicin launin fata, sanƙo',
    '👩🏾‍🦲' => 'mace: launin fata mai madaidaicin duhu, sanƙo',
    '👩🏿‍🦲' => 'mace: launin fata mai duhu, sanƙo',
    '🙍🏻‍♂' => 'namiji mai ɓacin rai: launin fata mai haske',
    '🙍🏼‍♂' => 'namiji mai ɓacin rai: launin fata mai madaidaicin haske',
    '🙍🏽‍♂' => 'namiji mai ɓacin rai: madaidaicin launin fata',
    '🙍🏾‍♂' => 'namiji mai ɓacin rai: launin fata mai madaidaicin duhu',
    '🙍🏿‍♂' => 'namiji mai ɓacin rai: launin fata mai duhu',
    '🙍🏻‍♀' => 'mace mai ɓacin rai: launin fata mai haske',
    '🙍🏼‍♀' => 'mace mai ɓacin rai: launin fata mai madaidaicin haske',
    '🙍🏽‍♀' => 'mace mai ɓacin rai: madaidaicin launin fata',
    '🙍🏾‍♀' => 'mace mai ɓacin rai: launin fata mai madaidaicin duhu',
    '🙍🏿‍♀' => 'mace mai ɓacin rai: launin fata mai duhu',
    '🙎🏻‍♂' => 'mutum mai ɓacin zuciya: launin fata mai haske',
    '🙎🏼‍♂' => 'mutum mai ɓacin zuciya: launin fata mai madaidaicin haske',
    '🙎🏽‍♂' => 'mutum mai ɓacin zuciya: madaidaicin launin fata',
    '🙎🏾‍♂' => 'mutum mai ɓacin zuciya: launin fata mai madaidaicin duhu',
    '🙎🏿‍♂' => 'mutum mai ɓacin zuciya: launin fata mai duhu',
    '🙎🏻‍♀' => 'mace mai ɓacin zuciya: launin fata mai haske',
    '🙎🏼‍♀' => 'mace mai ɓacin zuciya: launin fata mai madaidaicin haske',
    '🙎🏽‍♀' => 'mace mai ɓacin zuciya: madaidaicin launin fata',
    '🙎🏾‍♀' => 'mace mai ɓacin zuciya: launin fata mai madaidaicin duhu',
    '🙎🏿‍♀' => 'mace mai ɓacin zuciya: launin fata mai duhu',
    '🙅🏻‍♂' => 'namiji mai nunawa A’A da hannu: launin fata mai haske',
    '🙅🏼‍♂' => 'namiji mai nunawa A’A da hannu: launin fata mai madaidaicin haske',
    '🙅🏽‍♂' => 'namiji mai nunawa A’A da hannu: madaidaicin launin fata',
    '🙅🏾‍♂' => 'namiji mai nunawa A’A da hannu: launin fata mai madaidaicin duhu',
    '🙅🏿‍♂' => 'namiji mai nunawa A’A da hannu: launin fata mai duhu',
    '🙅🏻‍♀' => 'mace mai nunawa A’A da hannu: launin fata mai haske',
    '🙅🏼‍♀' => 'mace mai nunawa A’A da hannu: launin fata mai madaidaicin haske',
    '🙅🏽‍♀' => 'mace mai nunawa A’A da hannu: madaidaicin launin fata',
    '🙅🏾‍♀' => 'mace mai nunawa A’A da hannu: launin fata mai madaidaicin duhu',
    '🙅🏿‍♀' => 'mace mai nunawa A’A da hannu: launin fata mai duhu',
    '🙆🏻‍♂' => 'namiji mai nunawa TO da hannu: launin fata mai haske',
    '🙆🏼‍♂' => 'namiji mai nunawa TO da hannu: launin fata mai madaidaicin haske',
    '🙆🏽‍♂' => 'namiji mai nunawa TO da hannu: madaidaicin launin fata',
    '🙆🏾‍♂' => 'namiji mai nunawa TO da hannu: launin fata mai madaidaicin duhu',
    '🙆🏿‍♂' => 'namiji mai nunawa TO da hannu: launin fata mai duhu',
    '🙆🏻‍♀' => 'mace mai nunawa TO da hannu: launin fata mai haske',
    '🙆🏼‍♀' => 'mace mai nunawa TO da hannu: launin fata mai madaidaicin haske',
    '🙆🏽‍♀' => 'mace mai nunawa TO da hannu: madaidaicin launin fata',
    '🙆🏾‍♀' => 'mace mai nunawa TO da hannu: launin fata mai madaidaicin duhu',
    '🙆🏿‍♀' => 'mace mai nunawa TO da hannu: launin fata mai duhu',
    '💁🏻‍♂' => 'namiji hannu mai ba da ci-goro: launin fata mai haske',
    '💁🏼‍♂' => 'namiji hannu mai ba da ci-goro: launin fata mai madaidaicin haske',
    '💁🏽‍♂' => 'namiji hannu mai ba da ci-goro: madaidaicin launin fata',
    '💁🏾‍♂' => 'namiji hannu mai ba da ci-goro: launin fata mai madaidaicin duhu',
    '💁🏿‍♂' => 'namiji hannu mai ba da ci-goro: launin fata mai duhu',
    '💁🏻‍♀' => 'mace hannu mai ba da ci-goro: launin fata mai haske',
    '💁🏼‍♀' => 'mace hannu mai ba da ci-goro: launin fata mai madaidaicin haske',
    '💁🏽‍♀' => 'mace hannu mai ba da ci-goro: madaidaicin launin fata',
    '💁🏾‍♀' => 'mace hannu mai ba da ci-goro: launin fata mai madaidaicin duhu',
    '💁🏿‍♀' => 'mace hannu mai ba da ci-goro: launin fata mai duhu',
    '🙋🏻‍♂' => 'namiji mai ɗagawa hannu: launin fata mai haske',
    '🙋🏼‍♂' => 'namiji mai ɗagawa hannu: launin fata mai madaidaicin haske',
    '🙋🏽‍♂' => 'namiji mai ɗagawa hannu: madaidaicin launin fata',
    '🙋🏾‍♂' => 'namiji mai ɗagawa hannu: launin fata mai madaidaicin duhu',
    '🙋🏿‍♂' => 'namiji mai ɗagawa hannu: launin fata mai duhu',
    '🙋🏻‍♀' => 'mace mai ɗagawa hannu: launin fata mai haske',
    '🙋🏼‍♀' => 'mace mai ɗagawa hannu: launin fata mai madaidaicin haske',
    '🙋🏽‍♀' => 'mace mai ɗagawa hannu: madaidaicin launin fata',
    '🙋🏾‍♀' => 'mace mai ɗagawa hannu: launin fata mai madaidaicin duhu',
    '🙋🏿‍♀' => 'mace mai ɗagawa hannu: launin fata mai duhu',
    '🧏🏻‍♂' => 'namijin kurma: launin fata mai haske',
    '🧏🏼‍♂' => 'namijin kurma: launin fata mai madaidaicin haske',
    '🧏🏽‍♂' => 'namijin kurma: madaidaicin launin fata',
    '🧏🏾‍♂' => 'namijin kurma: launin fata mai madaidaicin duhu',
    '🧏🏿‍♂' => 'namijin kurma: launin fata mai duhu',
    '🧏🏻‍♀' => 'kurman mace: launin fata mai haske',
    '🧏🏼‍♀' => 'kurman mace: launin fata mai madaidaicin haske',
    '🧏🏽‍♀' => 'kurman mace: madaidaicin launin fata',
    '🧏🏾‍♀' => 'kurman mace: launin fata mai madaidaicin duhu',
    '🧏🏿‍♀' => 'kurman mace: launin fata mai duhu',
    '🙇🏻‍♂' => 'namiji mai sunkuya: launin fata mai haske',
    '🙇🏼‍♂' => 'namiji mai sunkuya: launin fata mai madaidaicin haske',
    '🙇🏽‍♂' => 'namiji mai sunkuya: madaidaicin launin fata',
    '🙇🏾‍♂' => 'namiji mai sunkuya: launin fata mai madaidaicin duhu',
    '🙇🏿‍♂' => 'namiji mai sunkuya: launin fata mai duhu',
    '🙇🏻‍♀' => 'mace mai sunkuya: launin fata mai haske',
    '🙇🏼‍♀' => 'mace mai sunkuya: launin fata mai madaidaicin haske',
    '🙇🏽‍♀' => 'mace mai sunkuya: madaidaicin launin fata',
    '🙇🏾‍♀' => 'mace mai sunkuya: launin fata mai madaidaicin duhu',
    '🙇🏿‍♀' => 'mace mai sunkuya: launin fata mai duhu',
    '🤦🏻‍♂' => 'namiji nunawa kunya: launin fata mai haske',
    '🤦🏼‍♂' => 'namiji nunawa kunya: launin fata mai madaidaicin haske',
    '🤦🏽‍♂' => 'namiji nunawa kunya: madaidaicin launin fata',
    '🤦🏾‍♂' => 'namiji nunawa kunya: launin fata mai madaidaicin duhu',
    '🤦🏿‍♂' => 'namiji nunawa kunya: launin fata mai duhu',
    '🤦🏻‍♀' => 'mace nunawa kunya: launin fata mai haske',
    '🤦🏼‍♀' => 'mace nunawa kunya: launin fata mai madaidaicin haske',
    '🤦🏽‍♀' => 'mace nunawa kunya: madaidaicin launin fata',
    '🤦🏾‍♀' => 'mace nunawa kunya: launin fata mai madaidaicin duhu',
    '🤦🏿‍♀' => 'mace nunawa kunya: launin fata mai duhu',
    '🤷🏻‍♂' => 'mutum ɗagawa kafaɗa: launin fata mai haske',
    '🤷🏼‍♂' => 'mutum ɗagawa kafaɗa: launin fata mai madaidaicin haske',
    '🤷🏽‍♂' => 'mutum ɗagawa kafaɗa: madaidaicin launin fata',
    '🤷🏾‍♂' => 'mutum ɗagawa kafaɗa: launin fata mai madaidaicin duhu',
    '🤷🏿‍♂' => 'mutum ɗagawa kafaɗa: launin fata mai duhu',
    '🤷🏻‍♀' => 'mace ɗagawa kafaɗa: launin fata mai haske',
    '🤷🏼‍♀' => 'mace ɗagawa kafaɗa: launin fata mai madaidaicin haske',
    '🤷🏽‍♀' => 'mace ɗagawa kafaɗa: madaidaicin launin fata',
    '🤷🏾‍♀' => 'mace ɗagawa kafaɗa: launin fata mai madaidaicin duhu',
    '🤷🏿‍♀' => 'mace ɗagawa kafaɗa: launin fata mai duhu',
    '🧑🏻‍⚕' => 'mai aikin asibiti: launin fata mai haske',
    '🧑🏼‍⚕' => 'mai aikin asibiti: launin fata mai madaidaicin haske',
    '🧑🏽‍⚕' => 'mai aikin asibiti: madaidaicin launin fata',
    '🧑🏾‍⚕' => 'mai aikin asibiti: launin fata mai madaidaicin duhu',
    '🧑🏿‍⚕' => 'mai aikin asibiti: launin fata mai duhu',
    '👨🏻‍⚕' => 'mutum ma’aikacin kula da lafiya: launin fata mai haske',
    '👨🏼‍⚕' => 'mutum ma’aikacin kula da lafiya: launin fata mai madaidaicin haske',
    '👨🏽‍⚕' => 'mutum ma’aikacin kula da lafiya: madaidaicin launin fata',
    '👨🏾‍⚕' => 'mutum ma’aikacin kula da lafiya: launin fata mai madaidaicin duhu',
    '👨🏿‍⚕' => 'mutum ma’aikacin kula da lafiya: launin fata mai duhu',
    '👩🏻‍⚕' => 'mace ma’aikacin kula da lafiya: launin fata mai haske',
    '👩🏼‍⚕' => 'mace ma’aikacin kula da lafiya: launin fata mai madaidaicin haske',
    '👩🏽‍⚕' => 'mace ma’aikacin kula da lafiya: madaidaicin launin fata',
    '👩🏾‍⚕' => 'mace ma’aikacin kula da lafiya: launin fata mai madaidaicin duhu',
    '👩🏿‍⚕' => 'mace ma’aikacin kula da lafiya: launin fata mai duhu',
    '🧑🏻‍🎓' => 'ɗalibi: launin fata mai haske',
    '🧑🏼‍🎓' => 'ɗalibi: launin fata mai madaidaicin haske',
    '🧑🏽‍🎓' => 'ɗalibi: madaidaicin launin fata',
    '🧑🏾‍🎓' => 'ɗalibi: launin fata mai madaidaicin duhu',
    '🧑🏿‍🎓' => 'ɗalibi: launin fata mai duhu',
    '👨🏻‍🎓' => 'mutum ɗalibi: launin fata mai haske',
    '👨🏼‍🎓' => 'mutum ɗalibi: launin fata mai madaidaicin haske',
    '👨🏽‍🎓' => 'mutum ɗalibi: madaidaicin launin fata',
    '👨🏾‍🎓' => 'mutum ɗalibi: launin fata mai madaidaicin duhu',
    '👨🏿‍🎓' => 'mutum ɗalibi: launin fata mai duhu',
    '👩🏻‍🎓' => 'mace ɗalibi: launin fata mai haske',
    '👩🏼‍🎓' => 'mace ɗalibi: launin fata mai madaidaicin haske',
    '👩🏽‍🎓' => 'mace ɗalibi: madaidaicin launin fata',
    '👩🏾‍🎓' => 'mace ɗalibi: launin fata mai madaidaicin duhu',
    '👩🏿‍🎓' => 'mace ɗalibi: launin fata mai duhu',
    '🧑🏻‍🏫' => 'mallami: launin fata mai haske',
    '🧑🏼‍🏫' => 'mallami: launin fata mai madaidaicin haske',
    '🧑🏽‍🏫' => 'mallami: madaidaicin launin fata',
    '🧑🏾‍🏫' => 'mallami: launin fata mai madaidaicin duhu',
    '🧑🏿‍🏫' => 'mallami: launin fata mai duhu',
    '👨🏻‍🏫' => 'mutum malami: launin fata mai haske',
    '👨🏼‍🏫' => 'mutum malami: launin fata mai madaidaicin haske',
    '👨🏽‍🏫' => 'mutum malami: madaidaicin launin fata',
    '👨🏾‍🏫' => 'mutum malami: launin fata mai madaidaicin duhu',
    '👨🏿‍🏫' => 'mutum malami: launin fata mai duhu',
    '👩🏻‍🏫' => 'mace malami: launin fata mai haske',
    '👩🏼‍🏫' => 'mace malami: launin fata mai madaidaicin haske',
    '👩🏽‍🏫' => 'mace malami: madaidaicin launin fata',
    '👩🏾‍🏫' => 'mace malami: launin fata mai madaidaicin duhu',
    '👩🏿‍🏫' => 'mace malami: launin fata mai duhu',
    '🧑🏻‍⚖' => 'hukunci: launin fata mai haske',
    '🧑🏼‍⚖' => 'hukunci: launin fata mai madaidaicin haske',
    '🧑🏽‍⚖' => 'hukunci: madaidaicin launin fata',
    '🧑🏾‍⚖' => 'hukunci: launin fata mai madaidaicin duhu',
    '🧑🏿‍⚖' => 'hukunci: launin fata mai duhu',
    '👨🏻‍⚖' => 'mutum joji: launin fata mai haske',
    '👨🏼‍⚖' => 'mutum joji: launin fata mai madaidaicin haske',
    '👨🏽‍⚖' => 'mutum joji: madaidaicin launin fata',
    '👨🏾‍⚖' => 'mutum joji: launin fata mai madaidaicin duhu',
    '👨🏿‍⚖' => 'mutum joji: launin fata mai duhu',
    '👩🏻‍⚖' => 'mace joji: launin fata mai haske',
    '👩🏼‍⚖' => 'mace joji: launin fata mai madaidaicin haske',
    '👩🏽‍⚖' => 'mace joji: madaidaicin launin fata',
    '👩🏾‍⚖' => 'mace joji: launin fata mai madaidaicin duhu',
    '👩🏿‍⚖' => 'mace joji: launin fata mai duhu',
    '🧑🏻‍🌾' => 'manomi: launin fata mai haske',
    '🧑🏼‍🌾' => 'manomi: launin fata mai madaidaicin haske',
    '🧑🏽‍🌾' => 'manomi: madaidaicin launin fata',
    '🧑🏾‍🌾' => 'manomi: launin fata mai madaidaicin duhu',
    '🧑🏿‍🌾' => 'manomi: launin fata mai duhu',
    '👨🏻‍🌾' => 'mutum manomi: launin fata mai haske',
    '👨🏼‍🌾' => 'mutum manomi: launin fata mai madaidaicin haske',
    '👨🏽‍🌾' => 'mutum manomi: madaidaicin launin fata',
    '👨🏾‍🌾' => 'mutum manomi: launin fata mai madaidaicin duhu',
    '👨🏿‍🌾' => 'mutum manomi: launin fata mai duhu',
    '👩🏻‍🌾' => 'mace manomi: launin fata mai haske',
    '👩🏼‍🌾' => 'mace manomi: launin fata mai madaidaicin haske',
    '👩🏽‍🌾' => 'mace manomi: madaidaicin launin fata',
    '👩🏾‍🌾' => 'mace manomi: launin fata mai madaidaicin duhu',
    '👩🏿‍🌾' => 'mace manomi: launin fata mai duhu',
    '🧑🏻‍🍳' => 'mai dafuwa: launin fata mai haske',
    '🧑🏼‍🍳' => 'mai dafuwa: launin fata mai madaidaicin haske',
    '🧑🏽‍🍳' => 'mai dafuwa: madaidaicin launin fata',
    '🧑🏾‍🍳' => 'mai dafuwa: launin fata mai madaidaicin duhu',
    '🧑🏿‍🍳' => 'mai dafuwa: launin fata mai duhu',
    '👨🏻‍🍳' => 'mutum kuku: launin fata mai haske',
    '👨🏼‍🍳' => 'mutum kuku: launin fata mai madaidaicin haske',
    '👨🏽‍🍳' => 'mutum kuku: madaidaicin launin fata',
    '👨🏾‍🍳' => 'mutum kuku: launin fata mai madaidaicin duhu',
    '👨🏿‍🍳' => 'mutum kuku: launin fata mai duhu',
    '👩🏻‍🍳' => 'mace kuku: launin fata mai haske',
    '👩🏼‍🍳' => 'mace kuku: launin fata mai madaidaicin haske',
    '👩🏽‍🍳' => 'mace kuku: madaidaicin launin fata',
    '👩🏾‍🍳' => 'mace kuku: launin fata mai madaidaicin duhu',
    '👩🏿‍🍳' => 'mace kuku: launin fata mai duhu',
    '🧑🏻‍🔧' => 'mai gyaran mota: launin fata mai haske',
    '🧑🏼‍🔧' => 'mai gyaran mota: launin fata mai madaidaicin haske',
    '🧑🏽‍🔧' => 'mai gyaran mota: madaidaicin launin fata',
    '🧑🏾‍🔧' => 'mai gyaran mota: launin fata mai madaidaicin duhu',
    '🧑🏿‍🔧' => 'mai gyaran mota: launin fata mai duhu',
    '👨🏻‍🔧' => 'mutum makanika: launin fata mai haske',
    '👨🏼‍🔧' => 'mutum makanika: launin fata mai madaidaicin haske',
    '👨🏽‍🔧' => 'mutum makanika: madaidaicin launin fata',
    '👨🏾‍🔧' => 'mutum makanika: launin fata mai madaidaicin duhu',
    '👨🏿‍🔧' => 'mutum makanika: launin fata mai duhu',
    '👩🏻‍🔧' => 'mace makanika: launin fata mai haske',
    '👩🏼‍🔧' => 'mace makanika: launin fata mai madaidaicin haske',
    '👩🏽‍🔧' => 'mace makanika: madaidaicin launin fata',
    '👩🏾‍🔧' => 'mace makanika: launin fata mai madaidaicin duhu',
    '👩🏿‍🔧' => 'mace makanika: launin fata mai duhu',
    '🧑🏻‍🏭' => 'mai aikin masanaʼanta: launin fata mai haske',
    '🧑🏼‍🏭' => 'mai aikin masanaʼanta: launin fata mai madaidaicin haske',
    '🧑🏽‍🏭' => 'mai aikin masanaʼanta: madaidaicin launin fata',
    '🧑🏾‍🏭' => 'mai aikin masanaʼanta: launin fata mai madaidaicin duhu',
    '🧑🏿‍🏭' => 'mai aikin masanaʼanta: launin fata mai duhu',
    '👨🏻‍🏭' => 'mutum ma’aikacin masana’antu: launin fata mai haske',
    '👨🏼‍🏭' => 'mutum ma’aikacin masana’antu: launin fata mai madaidaicin haske',
    '👨🏽‍🏭' => 'mutum ma’aikacin masana’antu: madaidaicin launin fata',
    '👨🏾‍🏭' => 'mutum ma’aikacin masana’antu: launin fata mai madaidaicin duhu',
    '👨🏿‍🏭' => 'mutum ma’aikacin masana’antu: launin fata mai duhu',
    '👩🏻‍🏭' => 'mace ma’aikacin masana’antu: launin fata mai haske',
    '👩🏼‍🏭' => 'mace ma’aikacin masana’antu: launin fata mai madaidaicin haske',
    '👩🏽‍🏭' => 'mace ma’aikacin masana’antu: madaidaicin launin fata',
    '👩🏾‍🏭' => 'mace ma’aikacin masana’antu: launin fata mai madaidaicin duhu',
    '👩🏿‍🏭' => 'mace ma’aikacin masana’antu: launin fata mai duhu',
    '🧑🏻‍💼' => 'mai aikin ofishi: launin fata mai haske',
    '🧑🏼‍💼' => 'mai aikin ofishi: launin fata mai madaidaicin haske',
    '🧑🏽‍💼' => 'mai aikin ofishi: madaidaicin launin fata',
    '🧑🏾‍💼' => 'mai aikin ofishi: launin fata mai madaidaicin duhu',
    '🧑🏿‍💼' => 'mai aikin ofishi: launin fata mai duhu',
    '👨🏻‍💼' => 'mutum ma’aikacin ofis: launin fata mai haske',
    '👨🏼‍💼' => 'mutum ma’aikacin ofis: launin fata mai madaidaicin haske',
    '👨🏽‍💼' => 'mutum ma’aikacin ofis: madaidaicin launin fata',
    '👨🏾‍💼' => 'mutum ma’aikacin ofis: launin fata mai madaidaicin duhu',
    '👨🏿‍💼' => 'mutum ma’aikacin ofis: launin fata mai duhu',
    '👩🏻‍💼' => 'mace ma’aikacin ofis: launin fata mai haske',
    '👩🏼‍💼' => 'mace ma’aikacin ofis: launin fata mai madaidaicin haske',
    '👩🏽‍💼' => 'mace ma’aikacin ofis: madaidaicin launin fata',
    '👩🏾‍💼' => 'mace ma’aikacin ofis: launin fata mai madaidaicin duhu',
    '👩🏿‍💼' => 'mace ma’aikacin ofis: launin fata mai duhu',
    '🧑🏻‍🔬' => 'masanin kimiyya: launin fata mai haske',
    '🧑🏼‍🔬' => 'masanin kimiyya: launin fata mai madaidaicin haske',
    '🧑🏽‍🔬' => 'masanin kimiyya: madaidaicin launin fata',
    '🧑🏾‍🔬' => 'masanin kimiyya: launin fata mai madaidaicin duhu',
    '🧑🏿‍🔬' => 'masanin kimiyya: launin fata mai duhu',
    '👨🏻‍🔬' => 'mutum masanin kimiya: launin fata mai haske',
    '👨🏼‍🔬' => 'mutum masanin kimiya: launin fata mai madaidaicin haske',
    '👨🏽‍🔬' => 'mutum masanin kimiya: madaidaicin launin fata',
    '👨🏾‍🔬' => 'mutum masanin kimiya: launin fata mai madaidaicin duhu',
    '👨🏿‍🔬' => 'mutum masanin kimiya: launin fata mai duhu',
    '👩🏻‍🔬' => 'mace masanin kimiya: launin fata mai haske',
    '👩🏼‍🔬' => 'mace masanin kimiya: launin fata mai madaidaicin haske',
    '👩🏽‍🔬' => 'mace masanin kimiya: madaidaicin launin fata',
    '👩🏾‍🔬' => 'mace masanin kimiya: launin fata mai madaidaicin duhu',
    '👩🏿‍🔬' => 'mace masanin kimiya: launin fata mai duhu',
    '🧑🏻‍💻' => 'masanin fasaha: launin fata mai haske',
    '🧑🏼‍💻' => 'masanin fasaha: launin fata mai madaidaicin haske',
    '🧑🏽‍💻' => 'masanin fasaha: madaidaicin launin fata',
    '🧑🏾‍💻' => 'masanin fasaha: launin fata mai madaidaicin duhu',
    '🧑🏿‍💻' => 'masanin fasaha: launin fata mai duhu',
    '👨🏻‍💻' => 'mutum mai fasaha: launin fata mai haske',
    '👨🏼‍💻' => 'mutum mai fasaha: launin fata mai madaidaicin haske',
    '👨🏽‍💻' => 'mutum mai fasaha: madaidaicin launin fata',
    '👨🏾‍💻' => 'mutum mai fasaha: launin fata mai madaidaicin duhu',
    '👨🏿‍💻' => 'mutum mai fasaha: launin fata mai duhu',
    '👩🏻‍💻' => 'mace mai fasaha: launin fata mai haske',
    '👩🏼‍💻' => 'mace mai fasaha: launin fata mai madaidaicin haske',
    '👩🏽‍💻' => 'mace mai fasaha: madaidaicin launin fata',
    '👩🏾‍💻' => 'mace mai fasaha: launin fata mai madaidaicin duhu',
    '👩🏿‍💻' => 'mace mai fasaha: launin fata mai duhu',
    '🧑🏻‍🎤' => 'mawaƙi: launin fata mai haske',
    '🧑🏼‍🎤' => 'mawaƙi: launin fata mai madaidaicin haske',
    '🧑🏽‍🎤' => 'mawaƙi: madaidaicin launin fata',
    '🧑🏾‍🎤' => 'mawaƙi: launin fata mai madaidaicin duhu',
    '🧑🏿‍🎤' => 'mawaƙi: launin fata mai duhu',
    '👨🏻‍🎤' => 'mutum mawaƙi: launin fata mai haske',
    '👨🏼‍🎤' => 'mutum mawaƙi: launin fata mai madaidaicin haske',
    '👨🏽‍🎤' => 'mutum mawaƙi: madaidaicin launin fata',
    '👨🏾‍🎤' => 'mutum mawaƙi: launin fata mai madaidaicin duhu',
    '👨🏿‍🎤' => 'mutum mawaƙi: launin fata mai duhu',
    '👩🏻‍🎤' => 'mace mawaƙi: launin fata mai haske',
    '👩🏼‍🎤' => 'mace mawaƙi: launin fata mai madaidaicin haske',
    '👩🏽‍🎤' => 'mace mawaƙi: madaidaicin launin fata',
    '👩🏾‍🎤' => 'mace mawaƙi: launin fata mai madaidaicin duhu',
    '👩🏿‍🎤' => 'mace mawaƙi: launin fata mai duhu',
    '🧑🏻‍🎨' => 'mai zane: launin fata mai haske',
    '🧑🏼‍🎨' => 'mai zane: launin fata mai madaidaicin haske',
    '🧑🏽‍🎨' => 'mai zane: madaidaicin launin fata',
    '🧑🏾‍🎨' => 'mai zane: launin fata mai madaidaicin duhu',
    '🧑🏿‍🎨' => 'mai zane: launin fata mai duhu',
    '👨🏻‍🎨' => 'mutum mai zane: launin fata mai haske',
    '👨🏼‍🎨' => 'mutum mai zane: launin fata mai madaidaicin haske',
    '👨🏽‍🎨' => 'mutum mai zane: madaidaicin launin fata',
    '👨🏾‍🎨' => 'mutum mai zane: launin fata mai madaidaicin duhu',
    '👨🏿‍🎨' => 'mutum mai zane: launin fata mai duhu',
    '👩🏻‍🎨' => 'mace mai zane: launin fata mai haske',
    '👩🏼‍🎨' => 'mace mai zane: launin fata mai madaidaicin haske',
    '👩🏽‍🎨' => 'mace mai zane: madaidaicin launin fata',
    '👩🏾‍🎨' => 'mace mai zane: launin fata mai madaidaicin duhu',
    '👩🏿‍🎨' => 'mace mai zane: launin fata mai duhu',
    '🧑🏻‍✈' => 'mai tuka jirgi: launin fata mai haske',
    '🧑🏼‍✈' => 'mai tuka jirgi: launin fata mai madaidaicin haske',
    '🧑🏽‍✈' => 'mai tuka jirgi: madaidaicin launin fata',
    '🧑🏾‍✈' => 'mai tuka jirgi: launin fata mai madaidaicin duhu',
    '🧑🏿‍✈' => 'mai tuka jirgi: launin fata mai duhu',
    '👨🏻‍✈' => 'mutum mai tuƙin jirgin sama: launin fata mai haske',
    '👨🏼‍✈' => 'mutum mai tuƙin jirgin sama: launin fata mai madaidaicin haske',
    '👨🏽‍✈' => 'mutum mai tuƙin jirgin sama: madaidaicin launin fata',
    '👨🏾‍✈' => 'mutum mai tuƙin jirgin sama: launin fata mai madaidaicin duhu',
    '👨🏿‍✈' => 'mutum mai tuƙin jirgin sama: launin fata mai duhu',
    '👩🏻‍✈' => 'mace mai tuƙin jirgin sama: launin fata mai haske',
    '👩🏼‍✈' => 'mace mai tuƙin jirgin sama: launin fata mai madaidaicin haske',
    '👩🏽‍✈' => 'mace mai tuƙin jirgin sama: madaidaicin launin fata',
    '👩🏾‍✈' => 'mace mai tuƙin jirgin sama: launin fata mai madaidaicin duhu',
    '👩🏿‍✈' => 'mace mai tuƙin jirgin sama: launin fata mai duhu',
    '🧑🏻‍🚀' => 'dan sama jannati: launin fata mai haske',
    '🧑🏼‍🚀' => 'dan sama jannati: launin fata mai madaidaicin haske',
    '🧑🏽‍🚀' => 'dan sama jannati: madaidaicin launin fata',
    '🧑🏾‍🚀' => 'dan sama jannati: launin fata mai madaidaicin duhu',
    '🧑🏿‍🚀' => 'dan sama jannati: launin fata mai duhu',
    '👨🏻‍🚀' => 'mutum ɗan sama jannati: launin fata mai haske',
    '👨🏼‍🚀' => 'mutum ɗan sama jannati: launin fata mai madaidaicin haske',
    '👨🏽‍🚀' => 'mutum ɗan sama jannati: madaidaicin launin fata',
    '👨🏾‍🚀' => 'mutum ɗan sama jannati: launin fata mai madaidaicin duhu',
    '👨🏿‍🚀' => 'mutum ɗan sama jannati: launin fata mai duhu',
    '👩🏻‍🚀' => 'mace ‘yar sama jannati: launin fata mai haske',
    '👩🏼‍🚀' => 'mace ‘yar sama jannati: launin fata mai madaidaicin haske',
    '👩🏽‍🚀' => 'mace ‘yar sama jannati: madaidaicin launin fata',
    '👩🏾‍🚀' => 'mace ‘yar sama jannati: launin fata mai madaidaicin duhu',
    '👩🏿‍🚀' => 'mace ‘yar sama jannati: launin fata mai duhu',
    '🧑🏻‍🚒' => 'maʼaikacin kashe gobara: launin fata mai haske',
    '🧑🏼‍🚒' => 'maʼaikacin kashe gobara: launin fata mai madaidaicin haske',
    '🧑🏽‍🚒' => 'maʼaikacin kashe gobara: madaidaicin launin fata',
    '🧑🏾‍🚒' => 'maʼaikacin kashe gobara: launin fata mai madaidaicin duhu',
    '🧑🏿‍🚒' => 'maʼaikacin kashe gobara: launin fata mai duhu',
    '👨🏻‍🚒' => 'mutum ɗan kwana-kwana: launin fata mai haske',
    '👨🏼‍🚒' => 'mutum ɗan kwana-kwana: launin fata mai madaidaicin haske',
    '👨🏽‍🚒' => 'mutum ɗan kwana-kwana: madaidaicin launin fata',
    '👨🏾‍🚒' => 'mutum ɗan kwana-kwana: launin fata mai madaidaicin duhu',
    '👨🏿‍🚒' => 'mutum ɗan kwana-kwana: launin fata mai duhu',
    '👩🏻‍🚒' => 'mace ɗan kwana-kwana: launin fata mai haske',
    '👩🏼‍🚒' => 'mace ɗan kwana-kwana: launin fata mai madaidaicin haske',
    '👩🏽‍🚒' => 'mace ɗan kwana-kwana: madaidaicin launin fata',
    '👩🏾‍🚒' => 'mace ɗan kwana-kwana: launin fata mai madaidaicin duhu',
    '👩🏿‍🚒' => 'mace ɗan kwana-kwana: launin fata mai duhu',
    '👮🏻‍♂' => 'mutum ɗan sanda: launin fata mai haske',
    '👮🏼‍♂' => 'mutum ɗan sanda: launin fata mai madaidaicin haske',
    '👮🏽‍♂' => 'mutum ɗan sanda: madaidaicin launin fata',
    '👮🏾‍♂' => 'mutum ɗan sanda: launin fata mai madaidaicin duhu',
    '👮🏿‍♂' => 'mutum ɗan sanda: launin fata mai duhu',
    '👮🏻‍♀' => 'ɗan sanda na mace: launin fata mai haske',
    '👮🏼‍♀' => 'ɗan sanda na mace: launin fata mai madaidaicin haske',
    '👮🏽‍♀' => 'ɗan sanda na mace: madaidaicin launin fata',
    '👮🏾‍♀' => 'ɗan sanda na mace: launin fata mai madaidaicin duhu',
    '👮🏿‍♀' => 'ɗan sanda na mace: launin fata mai duhu',
    '🕵🏻‍♂' => 'mutum si’aidi: launin fata mai haske',
    '🕵🏼‍♂' => 'mutum si’aidi: launin fata mai madaidaicin haske',
    '🕵🏽‍♂' => 'mutum si’aidi: madaidaicin launin fata',
    '🕵🏾‍♂' => 'mutum si’aidi: launin fata mai madaidaicin duhu',
    '🕵🏿‍♂' => 'mutum si’aidi: launin fata mai duhu',
    '🕵🏻‍♀' => 'mace si’aidi: launin fata mai haske',
    '🕵🏼‍♀' => 'mace si’aidi: launin fata mai madaidaicin haske',
    '🕵🏽‍♀' => 'mace si’aidi: madaidaicin launin fata',
    '🕵🏾‍♀' => 'mace si’aidi: launin fata mai madaidaicin duhu',
    '🕵🏿‍♀' => 'mace si’aidi: launin fata mai duhu',
    '💂🏻‍♂' => 'gadi namiji: launin fata mai haske',
    '💂🏼‍♂' => 'gadi namiji: launin fata mai madaidaicin haske',
    '💂🏽‍♂' => 'gadi namiji: madaidaicin launin fata',
    '💂🏾‍♂' => 'gadi namiji: launin fata mai madaidaicin duhu',
    '💂🏿‍♂' => 'gadi namiji: launin fata mai duhu',
    '💂🏻‍♀' => 'gadi na mace: launin fata mai haske',
    '💂🏼‍♀' => 'gadi na mace: launin fata mai madaidaicin haske',
    '💂🏽‍♀' => 'gadi na mace: madaidaicin launin fata',
    '💂🏾‍♀' => 'gadi na mace: launin fata mai madaidaicin duhu',
    '💂🏿‍♀' => 'gadi na mace: launin fata mai duhu',
    '👷🏻‍♂' => 'mutum ma’aikacin gini: launin fata mai haske',
    '👷🏼‍♂' => 'mutum ma’aikacin gini: launin fata mai madaidaicin haske',
    '👷🏽‍♂' => 'mutum ma’aikacin gini: madaidaicin launin fata',
    '👷🏾‍♂' => 'mutum ma’aikacin gini: launin fata mai madaidaicin duhu',
    '👷🏿‍♂' => 'mutum ma’aikacin gini: launin fata mai duhu',
    '👷🏻‍♀' => 'mace ma’aikacin gini: launin fata mai haske',
    '👷🏼‍♀' => 'mace ma’aikacin gini: launin fata mai madaidaicin haske',
    '👷🏽‍♀' => 'mace ma’aikacin gini: madaidaicin launin fata',
    '👷🏾‍♀' => 'mace ma’aikacin gini: launin fata mai madaidaicin duhu',
    '👷🏿‍♀' => 'mace ma’aikacin gini: launin fata mai duhu',
    '👳🏻‍♂' => 'namiji mai sakawa rawani: launin fata mai haske',
    '👳🏼‍♂' => 'namiji mai sakawa rawani: launin fata mai madaidaicin haske',
    '👳🏽‍♂' => 'namiji mai sakawa rawani: madaidaicin launin fata',
    '👳🏾‍♂' => 'namiji mai sakawa rawani: launin fata mai madaidaicin duhu',
    '👳🏿‍♂' => 'namiji mai sakawa rawani: launin fata mai duhu',
    '👳🏻‍♀' => 'mace mai sakawa rawani: launin fata mai haske',
    '👳🏼‍♀' => 'mace mai sakawa rawani: launin fata mai madaidaicin haske',
    '👳🏽‍♀' => 'mace mai sakawa rawani: madaidaicin launin fata',
    '👳🏾‍♀' => 'mace mai sakawa rawani: launin fata mai madaidaicin duhu',
    '👳🏿‍♀' => 'mace mai sakawa rawani: launin fata mai duhu',
    '🤵🏻‍♂' => 'na mijin da ya sa kayan baturai mai burgewa: launin fata mai haske',
    '🤵🏼‍♂' => 'na mijin da ya sa kayan baturai mai burgewa: launin fata mai madaidaicin haske',
    '🤵🏽‍♂' => 'na mijin da ya sa kayan baturai mai burgewa: madaidaicin launin fata',
    '🤵🏾‍♂' => 'na mijin da ya sa kayan baturai mai burgewa: launin fata mai madaidaicin duhu',
    '🤵🏿‍♂' => 'na mijin da ya sa kayan baturai mai burgewa: launin fata mai duhu',
    '🤵🏻‍♀' => 'mace da ta sa kayan baturai mai burgewa: launin fata mai haske',
    '🤵🏼‍♀' => 'mace da ta sa kayan baturai mai burgewa: launin fata mai madaidaicin haske',
    '🤵🏽‍♀' => 'mace da ta sa kayan baturai mai burgewa: madaidaicin launin fata',
    '🤵🏾‍♀' => 'mace da ta sa kayan baturai mai burgewa: launin fata mai madaidaicin duhu',
    '🤵🏿‍♀' => 'mace da ta sa kayan baturai mai burgewa: launin fata mai duhu',
    '👰🏻‍♂' => 'miji da ya yafa mayafi: launin fata mai haske',
    '👰🏼‍♂' => 'miji da ya yafa mayafi: launin fata mai madaidaicin haske',
    '👰🏽‍♂' => 'miji da ya yafa mayafi: madaidaicin launin fata',
    '👰🏾‍♂' => 'miji da ya yafa mayafi: launin fata mai madaidaicin duhu',
    '👰🏿‍♂' => 'miji da ya yafa mayafi: launin fata mai duhu',
    '👰🏻‍♀' => 'mace da ta yafa mayafi: launin fata mai haske',
    '👰🏼‍♀' => 'mace da ta yafa mayafi: launin fata mai madaidaicin haske',
    '👰🏽‍♀' => 'mace da ta yafa mayafi: madaidaicin launin fata',
    '👰🏾‍♀' => 'mace da ta yafa mayafi: launin fata mai madaidaicin duhu',
    '👰🏿‍♀' => 'mace da ta yafa mayafi: launin fata mai duhu',
    '👩🏻‍🍼' => 'mace mai ba jariri abinci: launin fata mai haske',
    '👩🏼‍🍼' => 'mace mai ba jariri abinci: launin fata mai madaidaicin haske',
    '👩🏽‍🍼' => 'mace mai ba jariri abinci: madaidaicin launin fata',
    '👩🏾‍🍼' => 'mace mai ba jariri abinci: launin fata mai madaidaicin duhu',
    '👩🏿‍🍼' => 'mace mai ba jariri abinci: launin fata mai duhu',
    '👨🏻‍🍼' => 'na miji mai ba jariri abinci: launin fata mai haske',
    '👨🏼‍🍼' => 'na miji mai ba jariri abinci: launin fata mai madaidaicin haske',
    '👨🏽‍🍼' => 'na miji mai ba jariri abinci: madaidaicin launin fata',
    '👨🏾‍🍼' => 'na miji mai ba jariri abinci: launin fata mai madaidaicin duhu',
    '👨🏿‍🍼' => 'na miji mai ba jariri abinci: launin fata mai duhu',
    '🧑🏻‍🍼' => 'mutum mai ba jariri abinci: launin fata mai haske',
    '🧑🏼‍🍼' => 'mutum mai ba jariri abinci: launin fata mai madaidaicin haske',
    '🧑🏽‍🍼' => 'mutum mai ba jariri abinci: madaidaicin launin fata',
    '🧑🏾‍🍼' => 'mutum mai ba jariri abinci: launin fata mai madaidaicin duhu',
    '🧑🏿‍🍼' => 'mutum mai ba jariri abinci: launin fata mai duhu',
    '🧑🏻‍🎄' => 'father Christmas: launin fata mai haske',
    '🧑🏼‍🎄' => 'father Christmas: launin fata mai madaidaicin haske',
    '🧑🏽‍🎄' => 'father Christmas: madaidaicin launin fata',
    '🧑🏾‍🎄' => 'father Christmas: launin fata mai madaidaicin duhu',
    '🧑🏿‍🎄' => 'father Christmas: launin fata mai duhu',
    '🦸🏻‍♂' => 'babban jarumin namiji: launin fata mai haske',
    '🦸🏼‍♂' => 'babban jarumin namiji: launin fata mai madaidaicin haske',
    '🦸🏽‍♂' => 'babban jarumin namiji: madaidaicin launin fata',
    '🦸🏾‍♂' => 'babban jarumin namiji: launin fata mai madaidaicin duhu',
    '🦸🏿‍♂' => 'babban jarumin namiji: launin fata mai duhu',
    '🦸🏻‍♀' => 'jaruma: launin fata mai haske',
    '🦸🏼‍♀' => 'jaruma: launin fata mai madaidaicin haske',
    '🦸🏽‍♀' => 'jaruma: madaidaicin launin fata',
    '🦸🏾‍♀' => 'jaruma: launin fata mai madaidaicin duhu',
    '🦸🏿‍♀' => 'jaruma: launin fata mai duhu',
    '🦹🏻‍♂' => 'mugun namiji: launin fata mai haske',
    '🦹🏼‍♂' => 'mugun namiji: launin fata mai madaidaicin haske',
    '🦹🏽‍♂' => 'mugun namiji: madaidaicin launin fata',
    '🦹🏾‍♂' => 'mugun namiji: launin fata mai madaidaicin duhu',
    '🦹🏿‍♂' => 'mugun namiji: launin fata mai duhu',
    '🦹🏻‍♀' => 'muguwar mace: launin fata mai haske',
    '🦹🏼‍♀' => 'muguwar mace: launin fata mai madaidaicin haske',
    '🦹🏽‍♀' => 'muguwar mace: madaidaicin launin fata',
    '🦹🏾‍♀' => 'muguwar mace: launin fata mai madaidaicin duhu',
    '🦹🏿‍♀' => 'muguwar mace: launin fata mai duhu',
    '🧙🏻‍♂' => 'mutum mai dabo: launin fata mai haske',
    '🧙🏼‍♂' => 'mutum mai dabo: launin fata mai madaidaicin haske',
    '🧙🏽‍♂' => 'mutum mai dabo: madaidaicin launin fata',
    '🧙🏾‍♂' => 'mutum mai dabo: launin fata mai madaidaicin duhu',
    '🧙🏿‍♂' => 'mutum mai dabo: launin fata mai duhu',
    '🧙🏻‍♀' => 'mace mai dabo: launin fata mai haske',
    '🧙🏼‍♀' => 'mace mai dabo: launin fata mai madaidaicin haske',
    '🧙🏽‍♀' => 'mace mai dabo: madaidaicin launin fata',
    '🧙🏾‍♀' => 'mace mai dabo: launin fata mai madaidaicin duhu',
    '🧙🏿‍♀' => 'mace mai dabo: launin fata mai duhu',
    '🧚🏻‍♂' => 'mutum aljani: launin fata mai haske',
    '🧚🏼‍♂' => 'mutum aljani: launin fata mai madaidaicin haske',
    '🧚🏽‍♂' => 'mutum aljani: madaidaicin launin fata',
    '🧚🏾‍♂' => 'mutum aljani: launin fata mai madaidaicin duhu',
    '🧚🏿‍♂' => 'mutum aljani: launin fata mai duhu',
    '🧚🏻‍♀' => 'mace aljana: launin fata mai haske',
    '🧚🏼‍♀' => 'mace aljana: launin fata mai madaidaicin haske',
    '🧚🏽‍♀' => 'mace aljana: madaidaicin launin fata',
    '🧚🏾‍♀' => 'mace aljana: launin fata mai madaidaicin duhu',
    '🧚🏿‍♀' => 'mace aljana: launin fata mai duhu',
    '🧛🏻‍♂' => 'mutum mai shan jini: launin fata mai haske',
    '🧛🏼‍♂' => 'mutum mai shan jini: launin fata mai madaidaicin haske',
    '🧛🏽‍♂' => 'mutum mai shan jini: madaidaicin launin fata',
    '🧛🏾‍♂' => 'mutum mai shan jini: launin fata mai madaidaicin duhu',
    '🧛🏿‍♂' => 'mutum mai shan jini: launin fata mai duhu',
    '🧛🏻‍♀' => 'mace mai shan jini: launin fata mai haske',
    '🧛🏼‍♀' => 'mace mai shan jini: launin fata mai madaidaicin haske',
    '🧛🏽‍♀' => 'mace mai shan jini: madaidaicin launin fata',
    '🧛🏾‍♀' => 'mace mai shan jini: launin fata mai madaidaicin duhu',
    '🧛🏿‍♀' => 'mace mai shan jini: launin fata mai duhu',
    '🧜🏻‍♂' => 'aljanin ruwa: launin fata mai haske',
    '🧜🏼‍♂' => 'aljanin ruwa: launin fata mai madaidaicin haske',
    '🧜🏽‍♂' => 'aljanin ruwa: madaidaicin launin fata',
    '🧜🏾‍♂' => 'aljanin ruwa: launin fata mai madaidaicin duhu',
    '🧜🏿‍♂' => 'aljanin ruwa: launin fata mai duhu',
    '🧜🏻‍♀' => 'aljanar ruwa: launin fata mai haske',
    '🧜🏼‍♀' => 'aljanar ruwa: launin fata mai madaidaicin haske',
    '🧜🏽‍♀' => 'aljanar ruwa: madaidaicin launin fata',
    '🧜🏾‍♀' => 'aljanar ruwa: launin fata mai madaidaicin duhu',
    '🧜🏿‍♀' => 'aljanar ruwa: launin fata mai duhu',
    '🧝🏻‍♂' => 'jinsiri namiji: launin fata mai haske',
    '🧝🏼‍♂' => 'jinsiri namiji: launin fata mai madaidaicin haske',
    '🧝🏽‍♂' => 'jinsiri namiji: madaidaicin launin fata',
    '🧝🏾‍♂' => 'jinsiri namiji: launin fata mai madaidaicin duhu',
    '🧝🏿‍♂' => 'jinsiri namiji: launin fata mai duhu',
    '🧝🏻‍♀' => 'jinsiri na mace: launin fata mai haske',
    '🧝🏼‍♀' => 'jinsiri na mace: launin fata mai madaidaicin haske',
    '🧝🏽‍♀' => 'jinsiri na mace: madaidaicin launin fata',
    '🧝🏾‍♀' => 'jinsiri na mace: launin fata mai madaidaicin duhu',
    '🧝🏿‍♀' => 'jinsiri na mace: launin fata mai duhu',
    '💆🏻‍♂' => 'namiji mai samun tausa: launin fata mai haske',
    '💆🏼‍♂' => 'namiji mai samun tausa: launin fata mai madaidaicin haske',
    '💆🏽‍♂' => 'namiji mai samun tausa: madaidaicin launin fata',
    '💆🏾‍♂' => 'namiji mai samun tausa: launin fata mai madaidaicin duhu',
    '💆🏿‍♂' => 'namiji mai samun tausa: launin fata mai duhu',
    '💆🏻‍♀' => 'mace mai samun tausa: launin fata mai haske',
    '💆🏼‍♀' => 'mace mai samun tausa: launin fata mai madaidaicin haske',
    '💆🏽‍♀' => 'mace mai samun tausa: madaidaicin launin fata',
    '💆🏾‍♀' => 'mace mai samun tausa: launin fata mai madaidaicin duhu',
    '💆🏿‍♀' => 'mace mai samun tausa: launin fata mai duhu',
    '💇🏻‍♂' => 'namiji mai yin aski: launin fata mai haske',
    '💇🏼‍♂' => 'namiji mai yin aski: launin fata mai madaidaicin haske',
    '💇🏽‍♂' => 'namiji mai yin aski: madaidaicin launin fata',
    '💇🏾‍♂' => 'namiji mai yin aski: launin fata mai madaidaicin duhu',
    '💇🏿‍♂' => 'namiji mai yin aski: launin fata mai duhu',
    '💇🏻‍♀' => 'mace mai yin aski: launin fata mai haske',
    '💇🏼‍♀' => 'mace mai yin aski: launin fata mai madaidaicin haske',
    '💇🏽‍♀' => 'mace mai yin aski: madaidaicin launin fata',
    '💇🏾‍♀' => 'mace mai yin aski: launin fata mai madaidaicin duhu',
    '💇🏿‍♀' => 'mace mai yin aski: launin fata mai duhu',
    '🚶🏻‍♂' => 'namiji mai yin tafiya ƙafa: launin fata mai haske',
    '🚶🏼‍♂' => 'namiji mai yin tafiya ƙafa: launin fata mai madaidaicin haske',
    '🚶🏽‍♂' => 'namiji mai yin tafiya ƙafa: madaidaicin launin fata',
    '🚶🏾‍♂' => 'namiji mai yin tafiya ƙafa: launin fata mai madaidaicin duhu',
    '🚶🏿‍♂' => 'namiji mai yin tafiya ƙafa: launin fata mai duhu',
    '🚶🏻‍♀' => 'mace mai yin tafiya ƙafa: launin fata mai haske',
    '🚶🏼‍♀' => 'mace mai yin tafiya ƙafa: launin fata mai madaidaicin haske',
    '🚶🏽‍♀' => 'mace mai yin tafiya ƙafa: madaidaicin launin fata',
    '🚶🏾‍♀' => 'mace mai yin tafiya ƙafa: launin fata mai madaidaicin duhu',
    '🚶🏿‍♀' => 'mace mai yin tafiya ƙafa: launin fata mai duhu',
    '🧍🏻‍♂' => 'miji mai tsaye: launin fata mai haske',
    '🧍🏼‍♂' => 'miji mai tsaye: launin fata mai madaidaicin haske',
    '🧍🏽‍♂' => 'miji mai tsaye: madaidaicin launin fata',
    '🧍🏾‍♂' => 'miji mai tsaye: launin fata mai madaidaicin duhu',
    '🧍🏿‍♂' => 'miji mai tsaye: launin fata mai duhu',
    '🧍🏻‍♀' => 'mace mai tsayuwa: launin fata mai haske',
    '🧍🏼‍♀' => 'mace mai tsayuwa: launin fata mai madaidaicin haske',
    '🧍🏽‍♀' => 'mace mai tsayuwa: madaidaicin launin fata',
    '🧍🏾‍♀' => 'mace mai tsayuwa: launin fata mai madaidaicin duhu',
    '🧍🏿‍♀' => 'mace mai tsayuwa: launin fata mai duhu',
    '🧑🏻‍🦯' => 'mutum mai farin bulala: launin fata mai haske',
    '🧑🏼‍🦯' => 'mutum mai farin bulala: launin fata mai madaidaicin haske',
    '🧑🏽‍🦯' => 'mutum mai farin bulala: madaidaicin launin fata',
    '🧑🏾‍🦯' => 'mutum mai farin bulala: launin fata mai madaidaicin duhu',
    '🧑🏿‍🦯' => 'mutum mai farin bulala: launin fata mai duhu',
    '👨🏻‍🦯' => 'mutum da farar sanda: launin fata mai haske',
    '👨🏼‍🦯' => 'mutum da farar sanda: launin fata mai madaidaicin haske',
    '👨🏽‍🦯' => 'mutum da farar sanda: madaidaicin launin fata',
    '👨🏾‍🦯' => 'mutum da farar sanda: launin fata mai madaidaicin duhu',
    '👨🏿‍🦯' => 'mutum da farar sanda: launin fata mai duhu',
    '👩🏻‍🦯' => 'mace da farar sanda: launin fata mai haske',
    '👩🏼‍🦯' => 'mace da farar sanda: launin fata mai madaidaicin haske',
    '👩🏽‍🦯' => 'mace da farar sanda: madaidaicin launin fata',
    '👩🏾‍🦯' => 'mace da farar sanda: launin fata mai madaidaicin duhu',
    '👩🏿‍🦯' => 'mace da farar sanda: launin fata mai duhu',
    '🧑🏻‍🦼' => 'mutum cikin kujeran gurgu: launin fata mai haske',
    '🧑🏼‍🦼' => 'mutum cikin kujeran gurgu: launin fata mai madaidaicin haske',
    '🧑🏽‍🦼' => 'mutum cikin kujeran gurgu: madaidaicin launin fata',
    '🧑🏾‍🦼' => 'mutum cikin kujeran gurgu: launin fata mai madaidaicin duhu',
    '🧑🏿‍🦼' => 'mutum cikin kujeran gurgu: launin fata mai duhu',
    '👨🏻‍🦼' => 'mutum a keken guragu na lantarki: launin fata mai haske',
    '👨🏼‍🦼' => 'mutum a keken guragu na lantarki: launin fata mai madaidaicin haske',
    '👨🏽‍🦼' => 'mutum a keken guragu na lantarki: madaidaicin launin fata',
    '👨🏾‍🦼' => 'mutum a keken guragu na lantarki: launin fata mai madaidaicin duhu',
    '👨🏿‍🦼' => 'mutum a keken guragu na lantarki: launin fata mai duhu',
    '👩🏻‍🦼' => 'mace a kan keken guragu mai inji: launin fata mai haske',
    '👩🏼‍🦼' => 'mace a kan keken guragu mai inji: launin fata mai madaidaicin haske',
    '👩🏽‍🦼' => 'mace a kan keken guragu mai inji: madaidaicin launin fata',
    '👩🏾‍🦼' => 'mace a kan keken guragu mai inji: launin fata mai madaidaicin duhu',
    '👩🏿‍🦼' => 'mace a kan keken guragu mai inji: launin fata mai duhu',
    '🧑🏻‍🦽' => 'mutum cikin motan gurgu wanda ke bukatan tuki da hannu: launin fata mai haske',
    '🧑🏼‍🦽' => 'mutum cikin motan gurgu wanda ke bukatan tuki da hannu: launin fata mai madaidaicin haske',
    '🧑🏽‍🦽' => 'mutum cikin motan gurgu wanda ke bukatan tuki da hannu: madaidaicin launin fata',
    '🧑🏾‍🦽' => 'mutum cikin motan gurgu wanda ke bukatan tuki da hannu: launin fata mai madaidaicin duhu',
    '🧑🏿‍🦽' => 'mutum cikin motan gurgu wanda ke bukatan tuki da hannu: launin fata mai duhu',
    '👨🏻‍🦽' => 'na miji a cikin motan gurgu da ke bukatan tuki: launin fata mai haske',
    '👨🏼‍🦽' => 'na miji a cikin motan gurgu da ke bukatan tuki: launin fata mai madaidaicin haske',
    '👨🏽‍🦽' => 'na miji a cikin motan gurgu da ke bukatan tuki: madaidaicin launin fata',
    '👨🏾‍🦽' => 'na miji a cikin motan gurgu da ke bukatan tuki: launin fata mai madaidaicin duhu',
    '👨🏿‍🦽' => 'na miji a cikin motan gurgu da ke bukatan tuki: launin fata mai duhu',
    '👩🏻‍🦽' => 'na mace a cikin motan gurgu da ke bukatan tuki: launin fata mai haske',
    '👩🏼‍🦽' => 'na mace a cikin motan gurgu da ke bukatan tuki: launin fata mai madaidaicin haske',
    '👩🏽‍🦽' => 'na mace a cikin motan gurgu da ke bukatan tuki: madaidaicin launin fata',
    '👩🏾‍🦽' => 'na mace a cikin motan gurgu da ke bukatan tuki: launin fata mai madaidaicin duhu',
    '👩🏿‍🦽' => 'na mace a cikin motan gurgu da ke bukatan tuki: launin fata mai duhu',
    '🏃🏻‍♂' => 'namiji mai yin gudu: launin fata mai haske',
    '🏃🏼‍♂' => 'namiji mai yin gudu: launin fata mai madaidaicin haske',
    '🏃🏽‍♂' => 'namiji mai yin gudu: madaidaicin launin fata',
    '🏃🏾‍♂' => 'namiji mai yin gudu: launin fata mai madaidaicin duhu',
    '🏃🏿‍♂' => 'namiji mai yin gudu: launin fata mai duhu',
    '🏃🏻‍♀' => 'mace mai yin gudu: launin fata mai haske',
    '🏃🏼‍♀' => 'mace mai yin gudu: launin fata mai madaidaicin haske',
    '🏃🏽‍♀' => 'mace mai yin gudu: madaidaicin launin fata',
    '🏃🏾‍♀' => 'mace mai yin gudu: launin fata mai madaidaicin duhu',
    '🏃🏿‍♀' => 'mace mai yin gudu: launin fata mai duhu',
    '👯🏻‍♀' => 'mata masu kunnuwan zomo yin biki: launin fata mai haske',
    '👯🏼‍♀' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske',
    '👯🏽‍♀' => 'mata masu kunnuwan zomo yin biki: madaidaicin launin fata',
    '👯🏾‍♀' => 'mata masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu',
    '👯🏿‍♀' => 'mata masu kunnuwan zomo yin biki: launin fata mai duhu',
    '👯🏻‍♂' => 'maza masu kunnuwan zomo yin biki: launin fata mai haske',
    '👯🏼‍♂' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske',
    '👯🏽‍♂' => 'maza masu kunnuwan zomo yin biki: madaidaicin launin fata',
    '👯🏾‍♂' => 'maza masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu',
    '👯🏿‍♂' => 'maza masu kunnuwan zomo yin biki: launin fata mai duhu',
    '🧖🏻‍♂' => 'namiji a cikin ɗakin surace: launin fata mai haske',
    '🧖🏼‍♂' => 'namiji a cikin ɗakin surace: launin fata mai madaidaicin haske',
    '🧖🏽‍♂' => 'namiji a cikin ɗakin surace: madaidaicin launin fata',
    '🧖🏾‍♂' => 'namiji a cikin ɗakin surace: launin fata mai madaidaicin duhu',
    '🧖🏿‍♂' => 'namiji a cikin ɗakin surace: launin fata mai duhu',
    '🧖🏻‍♀' => 'mace a cikin ɗakin surace: launin fata mai haske',
    '🧖🏼‍♀' => 'mace a cikin ɗakin surace: launin fata mai madaidaicin haske',
    '🧖🏽‍♀' => 'mace a cikin ɗakin surace: madaidaicin launin fata',
    '🧖🏾‍♀' => 'mace a cikin ɗakin surace: launin fata mai madaidaicin duhu',
    '🧖🏿‍♀' => 'mace a cikin ɗakin surace: launin fata mai duhu',
    '🧗🏻‍♂' => 'namiji mai hawa: launin fata mai haske',
    '🧗🏼‍♂' => 'namiji mai hawa: launin fata mai madaidaicin haske',
    '🧗🏽‍♂' => 'namiji mai hawa: madaidaicin launin fata',
    '🧗🏾‍♂' => 'namiji mai hawa: launin fata mai madaidaicin duhu',
    '🧗🏿‍♂' => 'namiji mai hawa: launin fata mai duhu',
    '🧗🏻‍♀' => 'mace mai hawa: launin fata mai haske',
    '🧗🏼‍♀' => 'mace mai hawa: launin fata mai madaidaicin haske',
    '🧗🏽‍♀' => 'mace mai hawa: madaidaicin launin fata',
    '🧗🏾‍♀' => 'mace mai hawa: launin fata mai madaidaicin duhu',
    '🧗🏿‍♀' => 'mace mai hawa: launin fata mai duhu',
    '🏌🏻‍♂' => 'namiji mai buga wasan golf: launin fata mai haske',
    '🏌🏼‍♂' => 'namiji mai buga wasan golf: launin fata mai madaidaicin haske',
    '🏌🏽‍♂' => 'namiji mai buga wasan golf: madaidaicin launin fata',
    '🏌🏾‍♂' => 'namiji mai buga wasan golf: launin fata mai madaidaicin duhu',
    '🏌🏿‍♂' => 'namiji mai buga wasan golf: launin fata mai duhu',
    '🏌🏻‍♀' => 'mace mai buga wasan golf: launin fata mai haske',
    '🏌🏼‍♀' => 'mace mai buga wasan golf: launin fata mai madaidaicin haske',
    '🏌🏽‍♀' => 'mace mai buga wasan golf: madaidaicin launin fata',
    '🏌🏾‍♀' => 'mace mai buga wasan golf: launin fata mai madaidaicin duhu',
    '🏌🏿‍♀' => 'mace mai buga wasan golf: launin fata mai duhu',
    '🏄🏻‍♂' => 'namiji mai hawan allon wasa a kan teku: launin fata mai haske',
    '🏄🏼‍♂' => 'namiji mai hawan allon wasa a kan teku: launin fata mai madaidaicin haske',
    '🏄🏽‍♂' => 'namiji mai hawan allon wasa a kan teku: madaidaicin launin fata',
    '🏄🏾‍♂' => 'namiji mai hawan allon wasa a kan teku: launin fata mai madaidaicin duhu',
    '🏄🏿‍♂' => 'namiji mai hawan allon wasa a kan teku: launin fata mai duhu',
    '🏄🏻‍♀' => 'mace mai hawan allon wasa a kan teku: launin fata mai haske',
    '🏄🏼‍♀' => 'mace mai hawan allon wasa a kan teku: launin fata mai madaidaicin haske',
    '🏄🏽‍♀' => 'mace mai hawan allon wasa a kan teku: madaidaicin launin fata',
    '🏄🏾‍♀' => 'mace mai hawan allon wasa a kan teku: launin fata mai madaidaicin duhu',
    '🏄🏿‍♀' => 'mace mai hawan allon wasa a kan teku: launin fata mai duhu',
    '🚣🏻‍♂' => 'namiji mai tuƙa jirgin ruwa: launin fata mai haske',
    '🚣🏼‍♂' => 'namiji mai tuƙa jirgin ruwa: launin fata mai madaidaicin haske',
    '🚣🏽‍♂' => 'namiji mai tuƙa jirgin ruwa: madaidaicin launin fata',
    '🚣🏾‍♂' => 'namiji mai tuƙa jirgin ruwa: launin fata mai madaidaicin duhu',
    '🚣🏿‍♂' => 'namiji mai tuƙa jirgin ruwa: launin fata mai duhu',
    '🚣🏻‍♀' => 'mace mai tuƙa jirgin: launin fata mai haske',
    '🚣🏼‍♀' => 'mace mai tuƙa jirgin: launin fata mai madaidaicin haske',
    '🚣🏽‍♀' => 'mace mai tuƙa jirgin: madaidaicin launin fata',
    '🚣🏾‍♀' => 'mace mai tuƙa jirgin: launin fata mai madaidaicin duhu',
    '🚣🏿‍♀' => 'mace mai tuƙa jirgin: launin fata mai duhu',
    '🏊🏻‍♂' => 'namiji mai yin ninƙaya: launin fata mai haske',
    '🏊🏼‍♂' => 'namiji mai yin ninƙaya: launin fata mai madaidaicin haske',
    '🏊🏽‍♂' => 'namiji mai yin ninƙaya: madaidaicin launin fata',
    '🏊🏾‍♂' => 'namiji mai yin ninƙaya: launin fata mai madaidaicin duhu',
    '🏊🏿‍♂' => 'namiji mai yin ninƙaya: launin fata mai duhu',
    '🏊🏻‍♀' => 'mace mai yin ninƙaya: launin fata mai haske',
    '🏊🏼‍♀' => 'mace mai yin ninƙaya: launin fata mai madaidaicin haske',
    '🏊🏽‍♀' => 'mace mai yin ninƙaya: madaidaicin launin fata',
    '🏊🏾‍♀' => 'mace mai yin ninƙaya: launin fata mai madaidaicin duhu',
    '🏊🏿‍♀' => 'mace mai yin ninƙaya: launin fata mai duhu',
    '⛹🏻‍♂' => 'namiji mai tambara ƙwallo: launin fata mai haske',
    '⛹🏼‍♂' => 'namiji mai tambara ƙwallo: launin fata mai madaidaicin haske',
    '⛹🏽‍♂' => 'namiji mai tambara ƙwallo: madaidaicin launin fata',
    '⛹🏾‍♂' => 'namiji mai tambara ƙwallo: launin fata mai madaidaicin duhu',
    '⛹🏿‍♂' => 'namiji mai tambara ƙwallo: launin fata mai duhu',
    '⛹🏻‍♀' => 'mace mai tambara ƙwallo: launin fata mai haske',
    '⛹🏼‍♀' => 'mace mai tambara ƙwallo: launin fata mai madaidaicin haske',
    '⛹🏽‍♀' => 'mace mai tambara ƙwallo: madaidaicin launin fata',
    '⛹🏾‍♀' => 'mace mai tambara ƙwallo: launin fata mai madaidaicin duhu',
    '⛹🏿‍♀' => 'mace mai tambara ƙwallo: launin fata mai duhu',
    '🏋🏻‍♂' => 'namiji mai ɗaukowa nauyi: launin fata mai haske',
    '🏋🏼‍♂' => 'namiji mai ɗaukowa nauyi: launin fata mai madaidaicin haske',
    '🏋🏽‍♂' => 'namiji mai ɗaukowa nauyi: madaidaicin launin fata',
    '🏋🏾‍♂' => 'namiji mai ɗaukowa nauyi: launin fata mai madaidaicin duhu',
    '🏋🏿‍♂' => 'namiji mai ɗaukowa nauyi: launin fata mai duhu',
    '🏋🏻‍♀' => 'mace mai ɗaukowa nauyi: launin fata mai haske',
    '🏋🏼‍♀' => 'mace mai ɗaukowa nauyi: launin fata mai madaidaicin haske',
    '🏋🏽‍♀' => 'mace mai ɗaukowa nauyi: madaidaicin launin fata',
    '🏋🏾‍♀' => 'mace mai ɗaukowa nauyi: launin fata mai madaidaicin duhu',
    '🏋🏿‍♀' => 'mace mai ɗaukowa nauyi: launin fata mai duhu',
    '🚴🏻‍♂' => 'namiji mai tuƙan babur: launin fata mai haske',
    '🚴🏼‍♂' => 'namiji mai tuƙan babur: launin fata mai madaidaicin haske',
    '🚴🏽‍♂' => 'namiji mai tuƙan babur: madaidaicin launin fata',
    '🚴🏾‍♂' => 'namiji mai tuƙan babur: launin fata mai madaidaicin duhu',
    '🚴🏿‍♂' => 'namiji mai tuƙan babur: launin fata mai duhu',
    '🚴🏻‍♀' => 'mace mai tuƙan babur: launin fata mai haske',
    '🚴🏼‍♀' => 'mace mai tuƙan babur: launin fata mai madaidaicin haske',
    '🚴🏽‍♀' => 'mace mai tuƙan babur: madaidaicin launin fata',
    '🚴🏾‍♀' => 'mace mai tuƙan babur: launin fata mai madaidaicin duhu',
    '🚴🏿‍♀' => 'mace mai tuƙan babur: launin fata mai duhu',
    '🚵🏻‍♂' => 'namiji tuƙan babur a kan tsauni: launin fata mai haske',
    '🚵🏼‍♂' => 'namiji tuƙan babur a kan tsauni: launin fata mai madaidaicin haske',
    '🚵🏽‍♂' => 'namiji tuƙan babur a kan tsauni: madaidaicin launin fata',
    '🚵🏾‍♂' => 'namiji tuƙan babur a kan tsauni: launin fata mai madaidaicin duhu',
    '🚵🏿‍♂' => 'namiji tuƙan babur a kan tsauni: launin fata mai duhu',
    '🚵🏻‍♀' => 'mace tuƙan babur a kan tsauni: launin fata mai haske',
    '🚵🏼‍♀' => 'mace tuƙan babur a kan tsauni: launin fata mai madaidaicin haske',
    '🚵🏽‍♀' => 'mace tuƙan babur a kan tsauni: madaidaicin launin fata',
    '🚵🏾‍♀' => 'mace tuƙan babur a kan tsauni: launin fata mai madaidaicin duhu',
    '🚵🏿‍♀' => 'mace tuƙan babur a kan tsauni: launin fata mai duhu',
    '🤸🏻‍♂' => 'namiji tuƙan amalanke: launin fata mai haske',
    '🤸🏼‍♂' => 'namiji tuƙan amalanke: launin fata mai madaidaicin haske',
    '🤸🏽‍♂' => 'namiji tuƙan amalanke: madaidaicin launin fata',
    '🤸🏾‍♂' => 'namiji tuƙan amalanke: launin fata mai madaidaicin duhu',
    '🤸🏿‍♂' => 'namiji tuƙan amalanke: launin fata mai duhu',
    '🤸🏻‍♀' => 'mace tuƙan amalanke: launin fata mai haske',
    '🤸🏼‍♀' => 'mace tuƙan amalanke: launin fata mai madaidaicin haske',
    '🤸🏽‍♀' => 'mace tuƙan amalanke: madaidaicin launin fata',
    '🤸🏾‍♀' => 'mace tuƙan amalanke: launin fata mai madaidaicin duhu',
    '🤸🏿‍♀' => 'mace tuƙan amalanke: launin fata mai duhu',
    '🤼🏻‍♀' => 'mata masu kokawa: launin fata mai haske',
    '🤼🏼‍♀' => 'mata masu kokawa: launin fata mai madaidaicin haske',
    '🤼🏽‍♀' => 'mata masu kokawa: madaidaicin launin fata',
    '🤼🏾‍♀' => 'mata masu kokawa: launin fata mai madaidaicin duhu',
    '🤼🏿‍♀' => 'mata masu kokawa: launin fata mai duhu',
    '🤼🏻‍♂' => 'maza masu kokawa: launin fata mai haske',
    '🤼🏼‍♂' => 'maza masu kokawa: launin fata mai madaidaicin haske',
    '🤼🏽‍♂' => 'maza masu kokawa: madaidaicin launin fata',
    '🤼🏾‍♂' => 'maza masu kokawa: launin fata mai madaidaicin duhu',
    '🤼🏿‍♂' => 'maza masu kokawa: launin fata mai duhu',
    '🤽🏻‍♂' => 'namiji mai bugan wasan holo na ruwa: launin fata mai haske',
    '🤽🏼‍♂' => 'namiji mai bugan wasan holo na ruwa: launin fata mai madaidaicin haske',
    '🤽🏽‍♂' => 'namiji mai bugan wasan holo na ruwa: madaidaicin launin fata',
    '🤽🏾‍♂' => 'namiji mai bugan wasan holo na ruwa: launin fata mai madaidaicin duhu',
    '🤽🏿‍♂' => 'namiji mai bugan wasan holo na ruwa: launin fata mai duhu',
    '🤽🏻‍♀' => 'mace mai bugan wasan holo na ruwa: launin fata mai haske',
    '🤽🏼‍♀' => 'mace mai bugan wasan holo na ruwa: launin fata mai madaidaicin haske',
    '🤽🏽‍♀' => 'mace mai bugan wasan holo na ruwa: madaidaicin launin fata',
    '🤽🏾‍♀' => 'mace mai bugan wasan holo na ruwa: launin fata mai madaidaicin duhu',
    '🤽🏿‍♀' => 'mace mai bugan wasan holo na ruwa: launin fata mai duhu',
    '🤾🏻‍♂' => 'namiji mai bugan ƙwallon hannu: launin fata mai haske',
    '🤾🏼‍♂' => 'namiji mai bugan ƙwallon hannu: launin fata mai madaidaicin haske',
    '🤾🏽‍♂' => 'namiji mai bugan ƙwallon hannu: madaidaicin launin fata',
    '🤾🏾‍♂' => 'namiji mai bugan ƙwallon hannu: launin fata mai madaidaicin duhu',
    '🤾🏿‍♂' => 'namiji mai bugan ƙwallon hannu: launin fata mai duhu',
    '🤾🏻‍♀' => 'mace mai bugan ƙwallon hannu: launin fata mai haske',
    '🤾🏼‍♀' => 'mace mai bugan ƙwallon hannu: launin fata mai madaidaicin haske',
    '🤾🏽‍♀' => 'mace mai bugan ƙwallon hannu: madaidaicin launin fata',
    '🤾🏾‍♀' => 'mace mai bugan ƙwallon hannu: launin fata mai madaidaicin duhu',
    '🤾🏿‍♀' => 'mace mai bugan ƙwallon hannu: launin fata mai duhu',
    '🤹🏻‍♂' => 'mutum juyawa abu: launin fata mai haske',
    '🤹🏼‍♂' => 'mutum juyawa abu: launin fata mai madaidaicin haske',
    '🤹🏽‍♂' => 'mutum juyawa abu: madaidaicin launin fata',
    '🤹🏾‍♂' => 'mutum juyawa abu: launin fata mai madaidaicin duhu',
    '🤹🏿‍♂' => 'mutum juyawa abu: launin fata mai duhu',
    '🤹🏻‍♀' => 'mace mai juyawa abu a sama: launin fata mai haske',
    '🤹🏼‍♀' => 'mace mai juyawa abu a sama: launin fata mai madaidaicin haske',
    '🤹🏽‍♀' => 'mace mai juyawa abu a sama: madaidaicin launin fata',
    '🤹🏾‍♀' => 'mace mai juyawa abu a sama: launin fata mai madaidaicin duhu',
    '🤹🏿‍♀' => 'mace mai juyawa abu a sama: launin fata mai duhu',
    '🧘🏻‍♂' => 'namiji a wurin furen lotus: launin fata mai haske',
    '🧘🏼‍♂' => 'namiji a wurin furen lotus: launin fata mai madaidaicin haske',
    '🧘🏽‍♂' => 'namiji a wurin furen lotus: madaidaicin launin fata',
    '🧘🏾‍♂' => 'namiji a wurin furen lotus: launin fata mai madaidaicin duhu',
    '🧘🏿‍♂' => 'namiji a wurin furen lotus: launin fata mai duhu',
    '🧘🏻‍♀' => 'mace a wurin furen lotus: launin fata mai haske',
    '🧘🏼‍♀' => 'mace a wurin furen lotus: launin fata mai madaidaicin haske',
    '🧘🏽‍♀' => 'mace a wurin furen lotus: madaidaicin launin fata',
    '🧘🏾‍♀' => 'mace a wurin furen lotus: launin fata mai madaidaicin duhu',
    '🧘🏿‍♀' => 'mace a wurin furen lotus: launin fata mai duhu',
    '🧑‍🦰' => 'babba: jan gashi',
    '🧑‍🦱' => 'babba: gashi mai laushi',
    '🧑‍🦳' => 'babba: farin gashi',
    '🧑‍🦲' => 'babba: sanƙo',
    '👨‍🦰' => 'namiji: jan gashi',
    '👨‍🦱' => 'namiji: gashi mai laushi',
    '👨‍🦳' => 'namiji: farin gashi',
    '👨‍🦲' => 'namiji: sanƙo',
    '👩‍🦰' => 'mace: jan gashi',
    '👩‍🦱' => 'mace: gashi mai laushi',
    '👩‍🦳' => 'mace: farin gashi',
    '👩‍🦲' => 'mace: sanƙo',
    '👨‍👦' => 'iyali: namiji, yaro',
    '👨‍👧' => 'iyali: namiji, yarinya',
    '👩‍👦' => 'iyali: mace, yaro',
    '👩‍👧' => 'iyali: mace, yarinya',
    '😶‍🌫' => 'Fuska a sama',
    '😮‍💨' => 'numfashin fuska',
    '🙂‍↕' => 'Girgiza kai a tsaye',
    '😵‍💫' => 'fuska da ido karkatace',
    '❤‍🔥' => 'zuciya na wuna',
    '❤‍🩹' => 'gyaran zuciya',
    '👁‍🗨' => 'ido a cikin kumfan magana',
    '🧔‍♂' => 'na miji: gemu',
    '👱‍♂' => 'namiji mai farin gashi',
    '🧔‍♀' => 'mace:gemu',
    '👱‍♀' => 'mace mai farin gashi',
    '🙍‍♂' => 'namiji mai ɓacin rai',
    '🙍‍♀' => 'mace mai ɓacin rai',
    '🙎‍♂' => 'mutum mai ɓacin zuciya',
    '🙎‍♀' => 'mace mai ɓacin zuciya',
    '🙅‍♂' => 'namiji mai nunawa A’A da hannu',
    '🙅‍♀' => 'mace mai nunawa A’A da hannu',
    '🙆‍♂' => 'namiji mai nunawa TO da hannu',
    '🙆‍♀' => 'mace mai nunawa TO da hannu',
    '💁‍♂' => 'namiji hannu mai ba da ci-goro',
    '💁‍♀' => 'mace hannu mai ba da ci-goro',
    '🙋‍♂' => 'namiji mai ɗagawa hannu',
    '🙋‍♀' => 'mace mai ɗagawa hannu',
    '🧏‍♂' => 'namijin kurma',
    '🧏‍♀' => 'kurman mace',
    '🙇‍♂' => 'namiji mai sunkuya',
    '🙇‍♀' => 'mace mai sunkuya',
    '🤦‍♂' => 'namiji nunawa kunya',
    '🤦‍♀' => 'mace nunawa kunya',
    '🤷‍♂' => 'mutum ɗagawa kafaɗa',
    '🤷‍♀' => 'mace ɗagawa kafaɗa',
    '🧑‍⚕' => 'mai aikin asibiti',
    '👨‍⚕' => 'mutum ma’aikacin kula da lafiya',
    '👩‍⚕' => 'mace ma’aikacin kula da lafiya',
    '🧑‍🎓' => 'ɗalibi',
    '👨‍🎓' => 'mutum ɗalibi',
    '👩‍🎓' => 'mace ɗalibi',
    '🧑‍🏫' => 'mallami',
    '👨‍🏫' => 'mutum malami',
    '👩‍🏫' => 'mace malami',
    '🧑‍⚖' => 'hukunci',
    '👨‍⚖' => 'mutum joji',
    '👩‍⚖' => 'mace joji',
    '🧑‍🌾' => 'manomi',
    '👨‍🌾' => 'mutum manomi',
    '👩‍🌾' => 'mace manomi',
    '🧑‍🍳' => 'mai dafuwa',
    '👨‍🍳' => 'mutum kuku',
    '👩‍🍳' => 'mace kuku',
    '🧑‍🔧' => 'mai gyaran mota',
    '👨‍🔧' => 'mutum makanika',
    '👩‍🔧' => 'mace makanika',
    '🧑‍🏭' => 'mai aikin masanaʼanta',
    '👨‍🏭' => 'mutum ma’aikacin masana’antu',
    '👩‍🏭' => 'mace ma’aikacin masana’antu',
    '🧑‍💼' => 'mai aikin ofishi',
    '👨‍💼' => 'mutum ma’aikacin ofis',
    '👩‍💼' => 'mace ma’aikacin ofis',
    '🧑‍🔬' => 'masanin kimiyya',
    '👨‍🔬' => 'mutum masanin kimiya',
    '👩‍🔬' => 'mace masanin kimiya',
    '🧑‍💻' => 'masanin fasaha',
    '👨‍💻' => 'mutum mai fasaha',
    '👩‍💻' => 'mace mai fasaha',
    '🧑‍🎤' => 'mawaƙi',
    '👨‍🎤' => 'mutum mawaƙi',
    '👩‍🎤' => 'mace mawaƙi',
    '🧑‍🎨' => 'mai zane',
    '👨‍🎨' => 'mutum mai zane',
    '👩‍🎨' => 'mace mai zane',
    '🧑‍✈' => 'mai tuka jirgi',
    '👨‍✈' => 'mutum mai tuƙin jirgin sama',
    '👩‍✈' => 'mace mai tuƙin jirgin sama',
    '🧑‍🚀' => 'dan sama jannati',
    '👨‍🚀' => 'mutum ɗan sama jannati',
    '👩‍🚀' => 'mace ‘yar sama jannati',
    '🧑‍🚒' => 'maʼaikacin kashe gobara',
    '👨‍🚒' => 'mutum ɗan kwana-kwana',
    '👩‍🚒' => 'mace ɗan kwana-kwana',
    '👮‍♂' => 'mutum ɗan sanda',
    '👮‍♀' => 'ɗan sanda na mace',
    '🕵‍♂' => 'mutum si’aidi',
    '🕵‍♀' => 'mace si’aidi',
    '💂‍♂' => 'gadi namiji',
    '💂‍♀' => 'gadi na mace',
    '👷‍♂' => 'mutum ma’aikacin gini',
    '👷‍♀' => 'mace ma’aikacin gini',
    '👳‍♂' => 'namiji mai sakawa rawani',
    '👳‍♀' => 'mace mai sakawa rawani',
    '🤵‍♂' => 'na mijin da ya sa kayan baturai mai burgewa',
    '🤵‍♀' => 'mace da ta sa kayan baturai mai burgewa',
    '👰‍♂' => 'miji da ya yafa mayafi',
    '👰‍♀' => 'mace da ta yafa mayafi',
    '👩‍🍼' => 'mace mai ba jariri abinci',
    '👨‍🍼' => 'na miji mai ba jariri abinci',
    '🧑‍🍼' => 'mutum mai ba jariri abinci',
    '🧑‍🎄' => 'father Christmas',
    '🦸‍♂' => 'babban jarumin namiji',
    '🦸‍♀' => 'jaruma',
    '🦹‍♂' => 'mugun namiji',
    '🦹‍♀' => 'muguwar mace',
    '🧙‍♂' => 'mutum mai dabo',
    '🧙‍♀' => 'mace mai dabo',
    '🧚‍♂' => 'mutum aljani',
    '🧚‍♀' => 'mace aljana',
    '🧛‍♂' => 'mutum mai shan jini',
    '🧛‍♀' => 'mace mai shan jini',
    '🧜‍♂' => 'aljanin ruwa',
    '🧜‍♀' => 'aljanar ruwa',
    '🧝‍♂' => 'jinsiri namiji',
    '🧝‍♀' => 'jinsiri na mace',
    '🧞‍♂' => 'aljanin larabawa namiji',
    '🧞‍♀' => 'aljanin larabawa na mace',
    '🧟‍♂' => 'gaya mai rai namiji',
    '🧟‍♀' => 'gaya mai rai na mace',
    '💆‍♂' => 'namiji mai samun tausa',
    '💆‍♀' => 'mace mai samun tausa',
    '💇‍♂' => 'namiji mai yin aski',
    '💇‍♀' => 'mace mai yin aski',
    '🚶‍♂' => 'namiji mai yin tafiya ƙafa',
    '🚶‍♀' => 'mace mai yin tafiya ƙafa',
    '🧍‍♂' => 'miji mai tsaye',
    '🧍‍♀' => 'mace mai tsayuwa',
    '🧑‍🦯' => 'mutum mai farin bulala',
    '👨‍🦯' => 'mutum da farar sanda',
    '👩‍🦯' => 'mace da farar sanda',
    '🧑‍🦼' => 'mutum cikin kujeran gurgu',
    '👨‍🦼' => 'mutum a keken guragu na lantarki',
    '👩‍🦼' => 'mace a kan keken guragu mai inji',
    '🧑‍🦽' => 'mutum cikin motan gurgu wanda ke bukatan tuki da hannu',
    '👨‍🦽' => 'na miji a cikin motan gurgu da ke bukatan tuki',
    '👩‍🦽' => 'na mace a cikin motan gurgu da ke bukatan tuki',
    '🏃‍♂' => 'namiji mai yin gudu',
    '🏃‍♀' => 'mace mai yin gudu',
    '🧑‍🩰' => 'mai rawar ballet',
    '👯‍♂' => 'maza masu kunnuwan zomo yin biki',
    '👯‍♀' => 'mata masu kunnuwan zomo yin biki',
    '🧖‍♂' => 'namiji a cikin ɗakin surace',
    '🧖‍♀' => 'mace a cikin ɗakin surace',
    '🧗‍♂' => 'namiji mai hawa',
    '🧗‍♀' => 'mace mai hawa',
    '🏌‍♂' => 'namiji mai buga wasan golf',
    '🏌‍♀' => 'mace mai buga wasan golf',
    '🏄‍♂' => 'namiji mai hawan allon wasa a kan teku',
    '🏄‍♀' => 'mace mai hawan allon wasa a kan teku',
    '🚣‍♂' => 'namiji mai tuƙa jirgin ruwa',
    '🚣‍♀' => 'mace mai tuƙa jirgin',
    '🏊‍♂' => 'namiji mai yin ninƙaya',
    '🏊‍♀' => 'mace mai yin ninƙaya',
    '⛹‍♂' => 'namiji mai tambara ƙwallo',
    '⛹‍♀' => 'mace mai tambara ƙwallo',
    '🏋‍♂' => 'namiji mai ɗaukowa nauyi',
    '🏋‍♀' => 'mace mai ɗaukowa nauyi',
    '🚴‍♂' => 'namiji mai tuƙan babur',
    '🚴‍♀' => 'mace mai tuƙan babur',
    '🚵‍♂' => 'namiji tuƙan babur a kan tsauni',
    '🚵‍♀' => 'mace tuƙan babur a kan tsauni',
    '🤸‍♂' => 'namiji tuƙan amalanke',
    '🤸‍♀' => 'mace tuƙan amalanke',
    '🤼‍♂' => 'maza masu kokawa',
    '🤼‍♀' => 'mata masu kokawa',
    '🤽‍♂' => 'namiji mai bugan wasan holo na ruwa',
    '🤽‍♀' => 'mace mai bugan wasan holo na ruwa',
    '🤾‍♂' => 'namiji mai bugan ƙwallon hannu',
    '🤾‍♀' => 'mace mai bugan ƙwallon hannu',
    '🤹‍♂' => 'mutum juyawa abu',
    '🤹‍♀' => 'mace mai juyawa abu a sama',
    '🧘‍♂' => 'namiji a wurin furen lotus',
    '🧘‍♀' => 'mace a wurin furen lotus',
    '🧑‍🧒' => 'iyali: manya, yara',
    '🐕‍🦺' => 'karen aiki',
    '🐈‍⬛' => 'Bakin kyanwa',
    '🐻‍❄' => 'dabban karshen duniya',
    '🐦‍⬛' => 'babban tsuntsu',
    '🐦‍🔥' => 'phoenix',
    '🍋‍🟩' => 'lemun tsami',
    '🍄‍🟫' => 'naman kazan launin ruwan kasa',
    '⛓‍💥' => 'karyayyen sarkar',
    '🏳‍🌈' => 'tutar baƙangizo',
    '🏳‍⚧' => 'tutan transgender',
    '🏴‍☠' => 'tutan ɗan fashin teku',
    '👋🏻' => 'hannu mai wurgawa: launin fata mai haske',
    '👋🏼' => 'hannu mai wurgawa: launin fata mai madaidaicin haske',
    '👋🏽' => 'hannu mai wurgawa: madaidaicin launin fata',
    '👋🏾' => 'hannu mai wurgawa: launin fata mai madaidaicin duhu',
    '👋🏿' => 'hannu mai wurgawa: launin fata mai duhu',
    '🤚🏻' => 'ɗagaggen bayan hannu: launin fata mai haske',
    '🤚🏼' => 'ɗagaggen bayan hannu: launin fata mai madaidaicin haske',
    '🤚🏽' => 'ɗagaggen bayan hannu: madaidaicin launin fata',
    '🤚🏾' => 'ɗagaggen bayan hannu: launin fata mai madaidaicin duhu',
    '🤚🏿' => 'ɗagaggen bayan hannu: launin fata mai duhu',
    '🖐🏻' => 'ɗagaggen hannu tare da yatsa a faɗaɗɗe: launin fata mai haske',
    '🖐🏼' => 'ɗagaggen hannu tare da yatsa a faɗaɗɗe: launin fata mai madaidaicin haske',
    '🖐🏽' => 'ɗagaggen hannu tare da yatsa a faɗaɗɗe: madaidaicin launin fata',
    '🖐🏾' => 'ɗagaggen hannu tare da yatsa a faɗaɗɗe: launin fata mai madaidaicin duhu',
    '🖐🏿' => 'ɗagaggen hannu tare da yatsa a faɗaɗɗe: launin fata mai duhu',
    '✋🏻' => 'ɗagaggen hannu: launin fata mai haske',
    '✋🏼' => 'ɗagaggen hannu: launin fata mai madaidaicin haske',
    '✋🏽' => 'ɗagaggen hannu: madaidaicin launin fata',
    '✋🏾' => 'ɗagaggen hannu: launin fata mai madaidaicin duhu',
    '✋🏿' => 'ɗagaggen hannu: launin fata mai duhu',
    '🖖🏻' => 'gaisuwar vulcan: launin fata mai haske',
    '🖖🏼' => 'gaisuwar vulcan: launin fata mai madaidaicin haske',
    '🖖🏽' => 'gaisuwar vulcan: madaidaicin launin fata',
    '🖖🏾' => 'gaisuwar vulcan: launin fata mai madaidaicin duhu',
    '🖖🏿' => 'gaisuwar vulcan: launin fata mai duhu',
    '🫱🏻' => 'hannun dama gaba: launin fata mai haske',
    '🫱🏼' => 'hannun dama gaba: launin fata mai madaidaicin haske',
    '🫱🏽' => 'hannun dama gaba: madaidaicin launin fata',
    '🫱🏾' => 'hannun dama gaba: launin fata mai madaidaicin duhu',
    '🫱🏿' => 'hannun dama gaba: launin fata mai duhu',
    '🫲🏻' => 'hannun hagu gaba: launin fata mai haske',
    '🫲🏼' => 'hannun hagu gaba: launin fata mai madaidaicin haske',
    '🫲🏽' => 'hannun hagu gaba: madaidaicin launin fata',
    '🫲🏾' => 'hannun hagu gaba: launin fata mai madaidaicin duhu',
    '🫲🏿' => 'hannun hagu gaba: launin fata mai duhu',
    '🫳🏻' => 'tafin hannu ƙasa: launin fata mai haske',
    '🫳🏼' => 'tafin hannu ƙasa: launin fata mai madaidaicin haske',
    '🫳🏽' => 'tafin hannu ƙasa: madaidaicin launin fata',
    '🫳🏾' => 'tafin hannu ƙasa: launin fata mai madaidaicin duhu',
    '🫳🏿' => 'tafin hannu ƙasa: launin fata mai duhu',
    '🫴🏻' => 'tafin hannu sama: launin fata mai haske',
    '🫴🏼' => 'tafin hannu sama: launin fata mai madaidaicin haske',
    '🫴🏽' => 'tafin hannu sama: madaidaicin launin fata',
    '🫴🏾' => 'tafin hannu sama: launin fata mai madaidaicin duhu',
    '🫴🏿' => 'tafin hannu sama: launin fata mai duhu',
    '🫷🏻' => 'hannun yana turawa hagu: launin fata mai haske',
    '🫷🏼' => 'hannun yana turawa hagu: launin fata mai madaidaicin haske',
    '🫷🏽' => 'hannun yana turawa hagu: madaidaicin launin fata',
    '🫷🏾' => 'hannun yana turawa hagu: launin fata mai madaidaicin duhu',
    '🫷🏿' => 'hannun yana turawa hagu: launin fata mai duhu',
    '🫸🏻' => 'hannu yana turawa dama: launin fata mai haske',
    '🫸🏼' => 'hannu yana turawa dama: launin fata mai madaidaicin haske',
    '🫸🏽' => 'hannu yana turawa dama: madaidaicin launin fata',
    '🫸🏾' => 'hannu yana turawa dama: launin fata mai madaidaicin duhu',
    '🫸🏿' => 'hannu yana turawa dama: launin fata mai duhu',
    '👌🏻' => 'hannun TO: launin fata mai haske',
    '👌🏼' => 'hannun TO: launin fata mai madaidaicin haske',
    '👌🏽' => 'hannun TO: madaidaicin launin fata',
    '👌🏾' => 'hannun TO: launin fata mai madaidaicin duhu',
    '👌🏿' => 'hannun TO: launin fata mai duhu',
    '🤌🏻' => 'tsuke yatsu: launin fata mai haske',
    '🤌🏼' => 'tsuke yatsu: launin fata mai madaidaicin haske',
    '🤌🏽' => 'tsuke yatsu: madaidaicin launin fata',
    '🤌🏾' => 'tsuke yatsu: launin fata mai madaidaicin duhu',
    '🤌🏿' => 'tsuke yatsu: launin fata mai duhu',
    '🤏🏻' => 'tsuke yatsu biyu: launin fata mai haske',
    '🤏🏼' => 'tsuke yatsu biyu: launin fata mai madaidaicin haske',
    '🤏🏽' => 'tsuke yatsu biyu: madaidaicin launin fata',
    '🤏🏾' => 'tsuke yatsu biyu: launin fata mai madaidaicin duhu',
    '🤏🏿' => 'tsuke yatsu biyu: launin fata mai duhu',
    '✌🏻' => 'hannun nasara: launin fata mai haske',
    '✌🏼' => 'hannun nasara: launin fata mai madaidaicin haske',
    '✌🏽' => 'hannun nasara: madaidaicin launin fata',
    '✌🏾' => 'hannun nasara: launin fata mai madaidaicin duhu',
    '✌🏿' => 'hannun nasara: launin fata mai duhu',
    '🤞🏻' => 'haɗaɗɗun yatsu: launin fata mai haske',
    '🤞🏼' => 'haɗaɗɗun yatsu: launin fata mai madaidaicin haske',
    '🤞🏽' => 'haɗaɗɗun yatsu: madaidaicin launin fata',
    '🤞🏾' => 'haɗaɗɗun yatsu: launin fata mai madaidaicin duhu',
    '🤞🏿' => 'haɗaɗɗun yatsu: launin fata mai duhu',
    '🫰🏻' => 'hannu da yatsa da babban yatsa a kewaye: launin fata mai haske',
    '🫰🏼' => 'hannu da yatsa da babban yatsa a kewaye: launin fata mai madaidaicin haske',
    '🫰🏽' => 'hannu da yatsa da babban yatsa a kewaye: madaidaicin launin fata',
    '🫰🏾' => 'hannu da yatsa da babban yatsa a kewaye: launin fata mai madaidaicin duhu',
    '🫰🏿' => 'hannu da yatsa da babban yatsa a kewaye: launin fata mai duhu',
    '🤟🏻' => 'nunin soyayya: launin fata mai haske',
    '🤟🏼' => 'nunin soyayya: launin fata mai madaidaicin haske',
    '🤟🏽' => 'nunin soyayya: madaidaicin launin fata',
    '🤟🏾' => 'nunin soyayya: launin fata mai madaidaicin duhu',
    '🤟🏿' => 'nunin soyayya: launin fata mai duhu',
    '🤘🏻' => 'alamar ƙaho: launin fata mai haske',
    '🤘🏼' => 'alamar ƙaho: launin fata mai madaidaicin haske',
    '🤘🏽' => 'alamar ƙaho: madaidaicin launin fata',
    '🤘🏾' => 'alamar ƙaho: launin fata mai madaidaicin duhu',
    '🤘🏿' => 'alamar ƙaho: launin fata mai duhu',
    '🤙🏻' => 'hannun kira ni: launin fata mai haske',
    '🤙🏼' => 'hannun kira ni: launin fata mai madaidaicin haske',
    '🤙🏽' => 'hannun kira ni: madaidaicin launin fata',
    '🤙🏾' => 'hannun kira ni: launin fata mai madaidaicin duhu',
    '🤙🏿' => 'hannun kira ni: launin fata mai duhu',
    '👈🏻' => 'ɗan ali na baya mai nunawa hagu: launin fata mai haske',
    '👈🏼' => 'ɗan ali na baya mai nunawa hagu: launin fata mai madaidaicin haske',
    '👈🏽' => 'ɗan ali na baya mai nunawa hagu: madaidaicin launin fata',
    '👈🏾' => 'ɗan ali na baya mai nunawa hagu: launin fata mai madaidaicin duhu',
    '👈🏿' => 'ɗan ali na baya mai nunawa hagu: launin fata mai duhu',
    '👉🏻' => 'ɗan ali na baya mai nunawa dama: launin fata mai haske',
    '👉🏼' => 'ɗan ali na baya mai nunawa dama: launin fata mai madaidaicin haske',
    '👉🏽' => 'ɗan ali na baya mai nunawa dama: madaidaicin launin fata',
    '👉🏾' => 'ɗan ali na baya mai nunawa dama: launin fata mai madaidaicin duhu',
    '👉🏿' => 'ɗan ali na baya mai nunawa dama: launin fata mai duhu',
    '👆🏻' => 'ɗan ali na baya mai nunawa sama: launin fata mai haske',
    '👆🏼' => 'ɗan ali na baya mai nunawa sama: launin fata mai madaidaicin haske',
    '👆🏽' => 'ɗan ali na baya mai nunawa sama: madaidaicin launin fata',
    '👆🏾' => 'ɗan ali na baya mai nunawa sama: launin fata mai madaidaicin duhu',
    '👆🏿' => 'ɗan ali na baya mai nunawa sama: launin fata mai duhu',
    '🖕🏻' => 'ɗan yatsan tsakiya: launin fata mai haske',
    '🖕🏼' => 'ɗan yatsan tsakiya: launin fata mai madaidaicin haske',
    '🖕🏽' => 'ɗan yatsan tsakiya: madaidaicin launin fata',
    '🖕🏾' => 'ɗan yatsan tsakiya: launin fata mai madaidaicin duhu',
    '🖕🏿' => 'ɗan yatsan tsakiya: launin fata mai duhu',
    '👇🏻' => 'ɗan ali na baya mai nunawa ƙasa: launin fata mai haske',
    '👇🏼' => 'ɗan ali na baya mai nunawa ƙasa: launin fata mai madaidaicin haske',
    '👇🏽' => 'ɗan ali na baya mai nunawa ƙasa: madaidaicin launin fata',
    '👇🏾' => 'ɗan ali na baya mai nunawa ƙasa: launin fata mai madaidaicin duhu',
    '👇🏿' => 'ɗan ali na baya mai nunawa ƙasa: launin fata mai duhu',
    '☝🏻' => 'ɗan ali mai nunawa sama: launin fata mai haske',
    '☝🏼' => 'ɗan ali mai nunawa sama: launin fata mai madaidaicin haske',
    '☝🏽' => 'ɗan ali mai nunawa sama: madaidaicin launin fata',
    '☝🏾' => 'ɗan ali mai nunawa sama: launin fata mai madaidaicin duhu',
    '☝🏿' => 'ɗan ali mai nunawa sama: launin fata mai duhu',
    '🫵🏻' => 'yatsa yana nuna mai kallo: launin fata mai haske',
    '🫵🏼' => 'yatsa yana nuna mai kallo: launin fata mai madaidaicin haske',
    '🫵🏽' => 'yatsa yana nuna mai kallo: madaidaicin launin fata',
    '🫵🏾' => 'yatsa yana nuna mai kallo: launin fata mai madaidaicin duhu',
    '🫵🏿' => 'yatsa yana nuna mai kallo: launin fata mai duhu',
    '👍🏻' => 'da kyau: launin fata mai haske',
    '👍🏼' => 'da kyau: launin fata mai madaidaicin haske',
    '👍🏽' => 'da kyau: madaidaicin launin fata',
    '👍🏾' => 'da kyau: launin fata mai madaidaicin duhu',
    '👍🏿' => 'da kyau: launin fata mai duhu',
    '👎🏻' => 'babu kyau: launin fata mai haske',
    '👎🏼' => 'babu kyau: launin fata mai madaidaicin haske',
    '👎🏽' => 'babu kyau: madaidaicin launin fata',
    '👎🏾' => 'babu kyau: launin fata mai madaidaicin duhu',
    '👎🏿' => 'babu kyau: launin fata mai duhu',
    '✊🏻' => 'ɗagaggen dunƙulen hannu: launin fata mai haske',
    '✊🏼' => 'ɗagaggen dunƙulen hannu: launin fata mai madaidaicin haske',
    '✊🏽' => 'ɗagaggen dunƙulen hannu: madaidaicin launin fata',
    '✊🏾' => 'ɗagaggen dunƙulen hannu: launin fata mai madaidaicin duhu',
    '✊🏿' => 'ɗagaggen dunƙulen hannu: launin fata mai duhu',
    '👊🏻' => 'dunƙulen hannu mai zuwa: launin fata mai haske',
    '👊🏼' => 'dunƙulen hannu mai zuwa: launin fata mai madaidaicin haske',
    '👊🏽' => 'dunƙulen hannu mai zuwa: madaidaicin launin fata',
    '👊🏾' => 'dunƙulen hannu mai zuwa: launin fata mai madaidaicin duhu',
    '👊🏿' => 'dunƙulen hannu mai zuwa: launin fata mai duhu',
    '🤛🏻' => 'dunƙulen hannu mai fuskanta hagu: launin fata mai haske',
    '🤛🏼' => 'dunƙulen hannu mai fuskanta hagu: launin fata mai madaidaicin haske',
    '🤛🏽' => 'dunƙulen hannu mai fuskanta hagu: madaidaicin launin fata',
    '🤛🏾' => 'dunƙulen hannu mai fuskanta hagu: launin fata mai madaidaicin duhu',
    '🤛🏿' => 'dunƙulen hannu mai fuskanta hagu: launin fata mai duhu',
    '🤜🏻' => 'dunƙulen hannu mai fuskanta dama: launin fata mai haske',
    '🤜🏼' => 'dunƙulen hannu mai fuskanta dama: launin fata mai madaidaicin haske',
    '🤜🏽' => 'dunƙulen hannu mai fuskanta dama: madaidaicin launin fata',
    '🤜🏾' => 'dunƙulen hannu mai fuskanta dama: launin fata mai madaidaicin duhu',
    '🤜🏿' => 'dunƙulen hannu mai fuskanta dama: launin fata mai duhu',
    '👏🏻' => 'hannuwa mai tafawa: launin fata mai haske',
    '👏🏼' => 'hannuwa mai tafawa: launin fata mai madaidaicin haske',
    '👏🏽' => 'hannuwa mai tafawa: madaidaicin launin fata',
    '👏🏾' => 'hannuwa mai tafawa: launin fata mai madaidaicin duhu',
    '👏🏿' => 'hannuwa mai tafawa: launin fata mai duhu',
    '🙌🏻' => 'ɗagaggun hannuwa: launin fata mai haske',
    '🙌🏼' => 'ɗagaggun hannuwa: launin fata mai madaidaicin haske',
    '🙌🏽' => 'ɗagaggun hannuwa: madaidaicin launin fata',
    '🙌🏾' => 'ɗagaggun hannuwa: launin fata mai madaidaicin duhu',
    '🙌🏿' => 'ɗagaggun hannuwa: launin fata mai duhu',
    '🫶🏻' => 'hannayen zuciya: launin fata mai haske',
    '🫶🏼' => 'hannayen zuciya: launin fata mai madaidaicin haske',
    '🫶🏽' => 'hannayen zuciya: madaidaicin launin fata',
    '🫶🏾' => 'hannayen zuciya: launin fata mai madaidaicin duhu',
    '🫶🏿' => 'hannayen zuciya: launin fata mai duhu',
    '👐🏻' => 'buɗaɗɗun hannuwa: launin fata mai haske',
    '👐🏼' => 'buɗaɗɗun hannuwa: launin fata mai madaidaicin haske',
    '👐🏽' => 'buɗaɗɗun hannuwa: madaidaicin launin fata',
    '👐🏾' => 'buɗaɗɗun hannuwa: launin fata mai madaidaicin duhu',
    '👐🏿' => 'buɗaɗɗun hannuwa: launin fata mai duhu',
    '🤲🏻' => 'tafunan hannu a sama tare: launin fata mai haske',
    '🤲🏼' => 'tafunan hannu a sama tare: launin fata mai madaidaicin haske',
    '🤲🏽' => 'tafunan hannu a sama tare: madaidaicin launin fata',
    '🤲🏾' => 'tafunan hannu a sama tare: launin fata mai madaidaicin duhu',
    '🤲🏿' => 'tafunan hannu a sama tare: launin fata mai duhu',
    '🤝🏻' => 'musafiha: launin fata mai haske',
    '🤝🏼' => 'musafiha: launin fata mai madaidaicin haske',
    '🤝🏽' => 'musafiha: madaidaicin launin fata',
    '🤝🏾' => 'musafiha: launin fata mai madaidaicin duhu',
    '🤝🏿' => 'musafiha: launin fata mai duhu',
    '🙏🏻' => 'kalmasassun hannuwa: launin fata mai haske',
    '🙏🏼' => 'kalmasassun hannuwa: launin fata mai madaidaicin haske',
    '🙏🏽' => 'kalmasassun hannuwa: madaidaicin launin fata',
    '🙏🏾' => 'kalmasassun hannuwa: launin fata mai madaidaicin duhu',
    '🙏🏿' => 'kalmasassun hannuwa: launin fata mai duhu',
    '✍🏻' => 'hannu mai rubutawa: launin fata mai haske',
    '✍🏼' => 'hannu mai rubutawa: launin fata mai madaidaicin haske',
    '✍🏽' => 'hannu mai rubutawa: madaidaicin launin fata',
    '✍🏾' => 'hannu mai rubutawa: launin fata mai madaidaicin duhu',
    '✍🏿' => 'hannu mai rubutawa: launin fata mai duhu',
    '💅🏻' => 'jan farce: launin fata mai haske',
    '💅🏼' => 'jan farce: launin fata mai madaidaicin haske',
    '💅🏽' => 'jan farce: madaidaicin launin fata',
    '💅🏾' => 'jan farce: launin fata mai madaidaicin duhu',
    '💅🏿' => 'jan farce: launin fata mai duhu',
    '🤳🏻' => 'hoton kanka: launin fata mai haske',
    '🤳🏼' => 'hoton kanka: launin fata mai madaidaicin haske',
    '🤳🏽' => 'hoton kanka: madaidaicin launin fata',
    '🤳🏾' => 'hoton kanka: launin fata mai madaidaicin duhu',
    '🤳🏿' => 'hoton kanka: launin fata mai duhu',
    '💪🏻' => 'tanƙwararrun ƙwanji: launin fata mai haske',
    '💪🏼' => 'tanƙwararrun ƙwanji: launin fata mai madaidaicin haske',
    '💪🏽' => 'tanƙwararrun ƙwanji: madaidaicin launin fata',
    '💪🏾' => 'tanƙwararrun ƙwanji: launin fata mai madaidaicin duhu',
    '💪🏿' => 'tanƙwararrun ƙwanji: launin fata mai duhu',
    '🦵🏻' => 'ƙafa: launin fata mai haske',
    '🦵🏼' => 'ƙafa: launin fata mai madaidaicin haske',
    '🦵🏽' => 'ƙafa: madaidaicin launin fata',
    '🦵🏾' => 'ƙafa: launin fata mai madaidaicin duhu',
    '🦵🏿' => 'ƙafa: launin fata mai duhu',
    '🦶🏻' => 'tafin ƙafa: launin fata mai haske',
    '🦶🏼' => 'tafin ƙafa: launin fata mai madaidaicin haske',
    '🦶🏽' => 'tafin ƙafa: madaidaicin launin fata',
    '🦶🏾' => 'tafin ƙafa: launin fata mai madaidaicin duhu',
    '🦶🏿' => 'tafin ƙafa: launin fata mai duhu',
    '👂🏻' => 'kunne: launin fata mai haske',
    '👂🏼' => 'kunne: launin fata mai madaidaicin haske',
    '👂🏽' => 'kunne: madaidaicin launin fata',
    '👂🏾' => 'kunne: launin fata mai madaidaicin duhu',
    '👂🏿' => 'kunne: launin fata mai duhu',
    '🦻🏻' => 'kunne da kayan ji: launin fata mai haske',
    '🦻🏼' => 'kunne da kayan ji: launin fata mai madaidaicin haske',
    '🦻🏽' => 'kunne da kayan ji: madaidaicin launin fata',
    '🦻🏾' => 'kunne da kayan ji: launin fata mai madaidaicin duhu',
    '🦻🏿' => 'kunne da kayan ji: launin fata mai duhu',
    '👃🏻' => 'hanci: launin fata mai haske',
    '👃🏼' => 'hanci: launin fata mai madaidaicin haske',
    '👃🏽' => 'hanci: madaidaicin launin fata',
    '👃🏾' => 'hanci: launin fata mai madaidaicin duhu',
    '👃🏿' => 'hanci: launin fata mai duhu',
    '👶🏻' => 'jariri: launin fata mai haske',
    '👶🏼' => 'jariri: launin fata mai madaidaicin haske',
    '👶🏽' => 'jariri: madaidaicin launin fata',
    '👶🏾' => 'jariri: launin fata mai madaidaicin duhu',
    '👶🏿' => 'jariri: launin fata mai duhu',
    '🧒🏻' => 'ɗa: launin fata mai haske',
    '🧒🏼' => 'ɗa: launin fata mai madaidaicin haske',
    '🧒🏽' => 'ɗa: madaidaicin launin fata',
    '🧒🏾' => 'ɗa: launin fata mai madaidaicin duhu',
    '🧒🏿' => 'ɗa: launin fata mai duhu',
    '👦🏻' => 'yaro: launin fata mai haske',
    '👦🏼' => 'yaro: launin fata mai madaidaicin haske',
    '👦🏽' => 'yaro: madaidaicin launin fata',
    '👦🏾' => 'yaro: launin fata mai madaidaicin duhu',
    '👦🏿' => 'yaro: launin fata mai duhu',
    '👧🏻' => 'yarinya: launin fata mai haske',
    '👧🏼' => 'yarinya: launin fata mai madaidaicin haske',
    '👧🏽' => 'yarinya: madaidaicin launin fata',
    '👧🏾' => 'yarinya: launin fata mai madaidaicin duhu',
    '👧🏿' => 'yarinya: launin fata mai duhu',
    '🧑🏻' => 'babba: launin fata mai haske',
    '🧑🏼' => 'babba: launin fata mai madaidaicin haske',
    '🧑🏽' => 'babba: madaidaicin launin fata',
    '🧑🏾' => 'babba: launin fata mai madaidaicin duhu',
    '🧑🏿' => 'babba: launin fata mai duhu',
    '👱🏻' => 'mutum mai farin gashi: launin fata mai haske',
    '👱🏼' => 'mutum mai farin gashi: launin fata mai madaidaicin haske',
    '👱🏽' => 'mutum mai farin gashi: madaidaicin launin fata',
    '👱🏾' => 'mutum mai farin gashi: launin fata mai madaidaicin duhu',
    '👱🏿' => 'mutum mai farin gashi: launin fata mai duhu',
    '👨🏻' => 'namiji: launin fata mai haske',
    '👨🏼' => 'namiji: launin fata mai madaidaicin haske',
    '👨🏽' => 'namiji: madaidaicin launin fata',
    '👨🏾' => 'namiji: launin fata mai madaidaicin duhu',
    '👨🏿' => 'namiji: launin fata mai duhu',
    '🧔🏻' => 'mutumi mai gemu: launin fata mai haske',
    '🧔🏼' => 'mutumi mai gemu: launin fata mai madaidaicin haske',
    '🧔🏽' => 'mutumi mai gemu: madaidaicin launin fata',
    '🧔🏾' => 'mutumi mai gemu: launin fata mai madaidaicin duhu',
    '🧔🏿' => 'mutumi mai gemu: launin fata mai duhu',
    '👩🏻' => 'mace: launin fata mai haske',
    '👩🏼' => 'mace: launin fata mai madaidaicin haske',
    '👩🏽' => 'mace: madaidaicin launin fata',
    '👩🏾' => 'mace: launin fata mai madaidaicin duhu',
    '👩🏿' => 'mace: launin fata mai duhu',
    '🧓🏻' => 'babba mafi tsufa: launin fata mai haske',
    '🧓🏼' => 'babba mafi tsufa: launin fata mai madaidaicin haske',
    '🧓🏽' => 'babba mafi tsufa: madaidaicin launin fata',
    '🧓🏾' => 'babba mafi tsufa: launin fata mai madaidaicin duhu',
    '🧓🏿' => 'babba mafi tsufa: launin fata mai duhu',
    '👴🏻' => 'dattijo: launin fata mai haske',
    '👴🏼' => 'dattijo: launin fata mai madaidaicin haske',
    '👴🏽' => 'dattijo: madaidaicin launin fata',
    '👴🏾' => 'dattijo: launin fata mai madaidaicin duhu',
    '👴🏿' => 'dattijo: launin fata mai duhu',
    '👵🏻' => 'dattijuwa: launin fata mai haske',
    '👵🏼' => 'dattijuwa: launin fata mai madaidaicin haske',
    '👵🏽' => 'dattijuwa: madaidaicin launin fata',
    '👵🏾' => 'dattijuwa: launin fata mai madaidaicin duhu',
    '👵🏿' => 'dattijuwa: launin fata mai duhu',
    '🙍🏻' => 'mutum mai ɓacin rai: launin fata mai haske',
    '🙍🏼' => 'mutum mai ɓacin rai: launin fata mai madaidaicin haske',
    '🙍🏽' => 'mutum mai ɓacin rai: madaidaicin launin fata',
    '🙍🏾' => 'mutum mai ɓacin rai: launin fata mai madaidaicin duhu',
    '🙍🏿' => 'mutum mai ɓacin rai: launin fata mai duhu',
    '🙎🏻' => 'mutum mai nunawa ɓacin zuciya: launin fata mai haske',
    '🙎🏼' => 'mutum mai nunawa ɓacin zuciya: launin fata mai madaidaicin haske',
    '🙎🏽' => 'mutum mai nunawa ɓacin zuciya: madaidaicin launin fata',
    '🙎🏾' => 'mutum mai nunawa ɓacin zuciya: launin fata mai madaidaicin duhu',
    '🙎🏿' => 'mutum mai nunawa ɓacin zuciya: launin fata mai duhu',
    '🙅🏻' => 'mutum mai nunawa A’A da hannu: launin fata mai haske',
    '🙅🏼' => 'mutum mai nunawa A’A da hannu: launin fata mai madaidaicin haske',
    '🙅🏽' => 'mutum mai nunawa A’A da hannu: madaidaicin launin fata',
    '🙅🏾' => 'mutum mai nunawa A’A da hannu: launin fata mai madaidaicin duhu',
    '🙅🏿' => 'mutum mai nunawa A’A da hannu: launin fata mai duhu',
    '🙆🏻' => 'mutum mai nunawa TO da hannu: launin fata mai haske',
    '🙆🏼' => 'mutum mai nunawa TO da hannu: launin fata mai madaidaicin haske',
    '🙆🏽' => 'mutum mai nunawa TO da hannu: madaidaicin launin fata',
    '🙆🏾' => 'mutum mai nunawa TO da hannu: launin fata mai madaidaicin duhu',
    '🙆🏿' => 'mutum mai nunawa TO da hannu: launin fata mai duhu',
    '💁🏻' => 'mutum hannu mai ba da ci-goro: launin fata mai haske',
    '💁🏼' => 'mutum hannu mai ba da ci-goro: launin fata mai madaidaicin haske',
    '💁🏽' => 'mutum hannu mai ba da ci-goro: madaidaicin launin fata',
    '💁🏾' => 'mutum hannu mai ba da ci-goro: launin fata mai madaidaicin duhu',
    '💁🏿' => 'mutum hannu mai ba da ci-goro: launin fata mai duhu',
    '🙋🏻' => 'mutum mai ɗagawa hannu: launin fata mai haske',
    '🙋🏼' => 'mutum mai ɗagawa hannu: launin fata mai madaidaicin haske',
    '🙋🏽' => 'mutum mai ɗagawa hannu: madaidaicin launin fata',
    '🙋🏾' => 'mutum mai ɗagawa hannu: launin fata mai madaidaicin duhu',
    '🙋🏿' => 'mutum mai ɗagawa hannu: launin fata mai duhu',
    '🧏🏻' => 'kurma: launin fata mai haske',
    '🧏🏼' => 'kurma: launin fata mai madaidaicin haske',
    '🧏🏽' => 'kurma: madaidaicin launin fata',
    '🧏🏾' => 'kurma: launin fata mai madaidaicin duhu',
    '🧏🏿' => 'kurma: launin fata mai duhu',
    '🙇🏻' => 'mutum mai sunkuya: launin fata mai haske',
    '🙇🏼' => 'mutum mai sunkuya: launin fata mai madaidaicin haske',
    '🙇🏽' => 'mutum mai sunkuya: madaidaicin launin fata',
    '🙇🏾' => 'mutum mai sunkuya: launin fata mai madaidaicin duhu',
    '🙇🏿' => 'mutum mai sunkuya: launin fata mai duhu',
    '🤦🏻' => 'mutum nunawa kunya: launin fata mai haske',
    '🤦🏼' => 'mutum nunawa kunya: launin fata mai madaidaicin haske',
    '🤦🏽' => 'mutum nunawa kunya: madaidaicin launin fata',
    '🤦🏾' => 'mutum nunawa kunya: launin fata mai madaidaicin duhu',
    '🤦🏿' => 'mutum nunawa kunya: launin fata mai duhu',
    '🤷🏻' => 'mutum ɗaga kafaɗa: launin fata mai haske',
    '🤷🏼' => 'mutum ɗaga kafaɗa: launin fata mai madaidaicin haske',
    '🤷🏽' => 'mutum ɗaga kafaɗa: madaidaicin launin fata',
    '🤷🏾' => 'mutum ɗaga kafaɗa: launin fata mai madaidaicin duhu',
    '🤷🏿' => 'mutum ɗaga kafaɗa: launin fata mai duhu',
    '👮🏻' => 'ɗan sanda: launin fata mai haske',
    '👮🏼' => 'ɗan sanda: launin fata mai madaidaicin haske',
    '👮🏽' => 'ɗan sanda: madaidaicin launin fata',
    '👮🏾' => 'ɗan sanda: launin fata mai madaidaicin duhu',
    '👮🏿' => 'ɗan sanda: launin fata mai duhu',
    '🕵🏻' => 'si’aidi: launin fata mai haske',
    '🕵🏼' => 'si’aidi: launin fata mai madaidaicin haske',
    '🕵🏽' => 'si’aidi: madaidaicin launin fata',
    '🕵🏾' => 'si’aidi: launin fata mai madaidaicin duhu',
    '🕵🏿' => 'si’aidi: launin fata mai duhu',
    '💂🏻' => 'mai gadi: launin fata mai haske',
    '💂🏼' => 'mai gadi: launin fata mai madaidaicin haske',
    '💂🏽' => 'mai gadi: madaidaicin launin fata',
    '💂🏾' => 'mai gadi: launin fata mai madaidaicin duhu',
    '💂🏿' => 'mai gadi: launin fata mai duhu',
    '🥷🏻' => 'shigar ninja: launin fata mai haske',
    '🥷🏼' => 'shigar ninja: launin fata mai madaidaicin haske',
    '🥷🏽' => 'shigar ninja: madaidaicin launin fata',
    '🥷🏾' => 'shigar ninja: launin fata mai madaidaicin duhu',
    '🥷🏿' => 'shigar ninja: launin fata mai duhu',
    '👷🏻' => 'ma’aikacin gini: launin fata mai haske',
    '👷🏼' => 'ma’aikacin gini: launin fata mai madaidaicin haske',
    '👷🏽' => 'ma’aikacin gini: madaidaicin launin fata',
    '👷🏾' => 'ma’aikacin gini: launin fata mai madaidaicin duhu',
    '👷🏿' => 'ma’aikacin gini: launin fata mai duhu',
    '🫅🏻' => 'mutum mai kambi: launin fata mai haske',
    '🫅🏼' => 'mutum mai kambi: launin fata mai madaidaicin haske',
    '🫅🏽' => 'mutum mai kambi: madaidaicin launin fata',
    '🫅🏾' => 'mutum mai kambi: launin fata mai madaidaicin duhu',
    '🫅🏿' => 'mutum mai kambi: launin fata mai duhu',
    '🤴🏻' => 'ɗan sarki: launin fata mai haske',
    '🤴🏼' => 'ɗan sarki: launin fata mai madaidaicin haske',
    '🤴🏽' => 'ɗan sarki: madaidaicin launin fata',
    '🤴🏾' => 'ɗan sarki: launin fata mai madaidaicin duhu',
    '🤴🏿' => 'ɗan sarki: launin fata mai duhu',
    '👸🏻' => 'gimbiya: launin fata mai haske',
    '👸🏼' => 'gimbiya: launin fata mai madaidaicin haske',
    '👸🏽' => 'gimbiya: madaidaicin launin fata',
    '👸🏾' => 'gimbiya: launin fata mai madaidaicin duhu',
    '👸🏿' => 'gimbiya: launin fata mai duhu',
    '👳🏻' => 'mutum mai sakawa rawani: launin fata mai haske',
    '👳🏼' => 'mutum mai sakawa rawani: launin fata mai madaidaicin haske',
    '👳🏽' => 'mutum mai sakawa rawani: madaidaicin launin fata',
    '👳🏾' => 'mutum mai sakawa rawani: launin fata mai madaidaicin duhu',
    '👳🏿' => 'mutum mai sakawa rawani: launin fata mai duhu',
    '👲🏻' => 'mutum mai hulan ’yan Caina: launin fata mai haske',
    '👲🏼' => 'mutum mai hulan ’yan Caina: launin fata mai madaidaicin haske',
    '👲🏽' => 'mutum mai hulan ’yan Caina: madaidaicin launin fata',
    '👲🏾' => 'mutum mai hulan ’yan Caina: launin fata mai madaidaicin duhu',
    '👲🏿' => 'mutum mai hulan ’yan Caina: launin fata mai duhu',
    '🧕🏻' => 'mace da ta saka ɗankwali: launin fata mai haske',
    '🧕🏼' => 'mace da ta saka ɗankwali: launin fata mai madaidaicin haske',
    '🧕🏽' => 'mace da ta saka ɗankwali: madaidaicin launin fata',
    '🧕🏾' => 'mace da ta saka ɗankwali: launin fata mai madaidaicin duhu',
    '🧕🏿' => 'mace da ta saka ɗankwali: launin fata mai duhu',
    '🤵🏻' => 'mutum cikin kwat: launin fata mai haske',
    '🤵🏼' => 'mutum cikin kwat: launin fata mai madaidaicin haske',
    '🤵🏽' => 'mutum cikin kwat: madaidaicin launin fata',
    '🤵🏾' => 'mutum cikin kwat: launin fata mai madaidaicin duhu',
    '🤵🏿' => 'mutum cikin kwat: launin fata mai duhu',
    '👰🏻' => 'amarya da mayafi: launin fata mai haske',
    '👰🏼' => 'amarya da mayafi: launin fata mai madaidaicin haske',
    '👰🏽' => 'amarya da mayafi: madaidaicin launin fata',
    '👰🏾' => 'amarya da mayafi: launin fata mai madaidaicin duhu',
    '👰🏿' => 'amarya da mayafi: launin fata mai duhu',
    '🤰🏻' => 'mace mai ciki: launin fata mai haske',
    '🤰🏼' => 'mace mai ciki: launin fata mai madaidaicin haske',
    '🤰🏽' => 'mace mai ciki: madaidaicin launin fata',
    '🤰🏾' => 'mace mai ciki: launin fata mai madaidaicin duhu',
    '🤰🏿' => 'mace mai ciki: launin fata mai duhu',
    '🫃🏻' => 'namiji mai ciki: launin fata mai haske',
    '🫃🏼' => 'namiji mai ciki: launin fata mai madaidaicin haske',
    '🫃🏽' => 'namiji mai ciki: madaidaicin launin fata',
    '🫃🏾' => 'namiji mai ciki: launin fata mai madaidaicin duhu',
    '🫃🏿' => 'namiji mai ciki: launin fata mai duhu',
    '🫄🏻' => 'mutum mai ciki: launin fata mai haske',
    '🫄🏼' => 'mutum mai ciki: launin fata mai madaidaicin haske',
    '🫄🏽' => 'mutum mai ciki: madaidaicin launin fata',
    '🫄🏾' => 'mutum mai ciki: launin fata mai madaidaicin duhu',
    '🫄🏿' => 'mutum mai ciki: launin fata mai duhu',
    '🤱🏻' => 'shayarwa: launin fata mai haske',
    '🤱🏼' => 'shayarwa: launin fata mai madaidaicin haske',
    '🤱🏽' => 'shayarwa: madaidaicin launin fata',
    '🤱🏾' => 'shayarwa: launin fata mai madaidaicin duhu',
    '🤱🏿' => 'shayarwa: launin fata mai duhu',
    '👼🏻' => 'jaririn malaika: launin fata mai haske',
    '👼🏼' => 'jaririn malaika: launin fata mai madaidaicin haske',
    '👼🏽' => 'jaririn malaika: madaidaicin launin fata',
    '👼🏾' => 'jaririn malaika: launin fata mai madaidaicin duhu',
    '👼🏿' => 'jaririn malaika: launin fata mai duhu',
    '🎅🏻' => 'Tsoho-da-Gemu: launin fata mai haske',
    '🎅🏼' => 'Tsoho-da-Gemu: launin fata mai madaidaicin haske',
    '🎅🏽' => 'Tsoho-da-Gemu: madaidaicin launin fata',
    '🎅🏾' => 'Tsoho-da-Gemu: launin fata mai madaidaicin duhu',
    '🎅🏿' => 'Tsoho-da-Gemu: launin fata mai duhu',
    '🤶🏻' => 'Matar Claus: launin fata mai haske',
    '🤶🏼' => 'Matar Claus: launin fata mai madaidaicin haske',
    '🤶🏽' => 'Matar Claus: madaidaicin launin fata',
    '🤶🏾' => 'Matar Claus: launin fata mai madaidaicin duhu',
    '🤶🏿' => 'Matar Claus: launin fata mai duhu',
    '🦸🏻' => 'jarumi: launin fata mai haske',
    '🦸🏼' => 'jarumi: launin fata mai madaidaicin haske',
    '🦸🏽' => 'jarumi: madaidaicin launin fata',
    '🦸🏾' => 'jarumi: launin fata mai madaidaicin duhu',
    '🦸🏿' => 'jarumi: launin fata mai duhu',
    '🦹🏻' => 'jarumi cikin zane: launin fata mai haske',
    '🦹🏼' => 'jarumi cikin zane: launin fata mai madaidaicin haske',
    '🦹🏽' => 'jarumi cikin zane: madaidaicin launin fata',
    '🦹🏾' => 'jarumi cikin zane: launin fata mai madaidaicin duhu',
    '🦹🏿' => 'jarumi cikin zane: launin fata mai duhu',
    '🧙🏻' => 'mai dabo: launin fata mai haske',
    '🧙🏼' => 'mai dabo: launin fata mai madaidaicin haske',
    '🧙🏽' => 'mai dabo: madaidaicin launin fata',
    '🧙🏾' => 'mai dabo: launin fata mai madaidaicin duhu',
    '🧙🏿' => 'mai dabo: launin fata mai duhu',
    '🧚🏻' => 'aljana: launin fata mai haske',
    '🧚🏼' => 'aljana: launin fata mai madaidaicin haske',
    '🧚🏽' => 'aljana: madaidaicin launin fata',
    '🧚🏾' => 'aljana: launin fata mai madaidaicin duhu',
    '🧚🏿' => 'aljana: launin fata mai duhu',
    '🧛🏻' => 'mai shan jini: launin fata mai haske',
    '🧛🏼' => 'mai shan jini: launin fata mai madaidaicin haske',
    '🧛🏽' => 'mai shan jini: madaidaicin launin fata',
    '🧛🏾' => 'mai shan jini: launin fata mai madaidaicin duhu',
    '🧛🏿' => 'mai shan jini: launin fata mai duhu',
    '🧜🏻' => 'aljanun ruwa: launin fata mai haske',
    '🧜🏼' => 'aljanun ruwa: launin fata mai madaidaicin haske',
    '🧜🏽' => 'aljanun ruwa: madaidaicin launin fata',
    '🧜🏾' => 'aljanun ruwa: launin fata mai madaidaicin duhu',
    '🧜🏿' => 'aljanun ruwa: launin fata mai duhu',
    '🧝🏻' => 'jinsiri: launin fata mai haske',
    '🧝🏼' => 'jinsiri: launin fata mai madaidaicin haske',
    '🧝🏽' => 'jinsiri: madaidaicin launin fata',
    '🧝🏾' => 'jinsiri: launin fata mai madaidaicin duhu',
    '🧝🏿' => 'jinsiri: launin fata mai duhu',
    '💆🏻' => 'mutum mai samun tausa: launin fata mai haske',
    '💆🏼' => 'mutum mai samun tausa: launin fata mai madaidaicin haske',
    '💆🏽' => 'mutum mai samun tausa: madaidaicin launin fata',
    '💆🏾' => 'mutum mai samun tausa: launin fata mai madaidaicin duhu',
    '💆🏿' => 'mutum mai samun tausa: launin fata mai duhu',
    '💇🏻' => 'mutum mai yin aski: launin fata mai haske',
    '💇🏼' => 'mutum mai yin aski: launin fata mai madaidaicin haske',
    '💇🏽' => 'mutum mai yin aski: madaidaicin launin fata',
    '💇🏾' => 'mutum mai yin aski: launin fata mai madaidaicin duhu',
    '💇🏿' => 'mutum mai yin aski: launin fata mai duhu',
    '🚶🏻' => 'mutum mai yin tafiya ƙafa: launin fata mai haske',
    '🚶🏼' => 'mutum mai yin tafiya ƙafa: launin fata mai madaidaicin haske',
    '🚶🏽' => 'mutum mai yin tafiya ƙafa: madaidaicin launin fata',
    '🚶🏾' => 'mutum mai yin tafiya ƙafa: launin fata mai madaidaicin duhu',
    '🚶🏿' => 'mutum mai yin tafiya ƙafa: launin fata mai duhu',
    '🧍🏻' => 'mutum a tsaye: launin fata mai haske',
    '🧍🏼' => 'mutum a tsaye: launin fata mai madaidaicin haske',
    '🧍🏽' => 'mutum a tsaye: madaidaicin launin fata',
    '🧍🏾' => 'mutum a tsaye: launin fata mai madaidaicin duhu',
    '🧍🏿' => 'mutum a tsaye: launin fata mai duhu',
    '🧎🏻' => 'mutum a durƙushe: launin fata mai haske',
    '🧎🏼' => 'mutum a durƙushe: launin fata mai madaidaicin haske',
    '🧎🏽' => 'mutum a durƙushe: madaidaicin launin fata',
    '🧎🏾' => 'mutum a durƙushe: launin fata mai madaidaicin duhu',
    '🧎🏿' => 'mutum a durƙushe: launin fata mai duhu',
    '🏃🏻' => 'mutum mai yin gudu: launin fata mai haske',
    '🏃🏼' => 'mutum mai yin gudu: launin fata mai madaidaicin haske',
    '🏃🏽' => 'mutum mai yin gudu: madaidaicin launin fata',
    '🏃🏾' => 'mutum mai yin gudu: launin fata mai madaidaicin duhu',
    '🏃🏿' => 'mutum mai yin gudu: launin fata mai duhu',
    '💃🏻' => 'mace mai yin rawa: launin fata mai haske',
    '💃🏼' => 'mace mai yin rawa: launin fata mai madaidaicin haske',
    '💃🏽' => 'mace mai yin rawa: madaidaicin launin fata',
    '💃🏾' => 'mace mai yin rawa: launin fata mai madaidaicin duhu',
    '💃🏿' => 'mace mai yin rawa: launin fata mai duhu',
    '🕺🏻' => 'mutum mai yin rawa: launin fata mai haske',
    '🕺🏼' => 'mutum mai yin rawa: launin fata mai madaidaicin haske',
    '🕺🏽' => 'mutum mai yin rawa: madaidaicin launin fata',
    '🕺🏾' => 'mutum mai yin rawa: launin fata mai madaidaicin duhu',
    '🕺🏿' => 'mutum mai yin rawa: launin fata mai duhu',
    '🕴🏻' => 'mutum a cikin kwat na kasuwanci mai jewa: launin fata mai haske',
    '🕴🏼' => 'mutum a cikin kwat na kasuwanci mai jewa: launin fata mai madaidaicin haske',
    '🕴🏽' => 'mutum a cikin kwat na kasuwanci mai jewa: madaidaicin launin fata',
    '🕴🏾' => 'mutum a cikin kwat na kasuwanci mai jewa: launin fata mai madaidaicin duhu',
    '🕴🏿' => 'mutum a cikin kwat na kasuwanci mai jewa: launin fata mai duhu',
    '👯🏻' => 'mutane masu kunnuwan zomo yin biki: launin fata mai haske',
    '👯🏼' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin haske',
    '👯🏽' => 'mutane masu kunnuwan zomo yin biki: madaidaicin launin fata',
    '👯🏾' => 'mutane masu kunnuwan zomo yin biki: launin fata mai madaidaicin duhu',
    '👯🏿' => 'mutane masu kunnuwan zomo yin biki: launin fata mai duhu',
    '🧖🏻' => 'mutum a cikin ɗakin surace: launin fata mai haske',
    '🧖🏼' => 'mutum a cikin ɗakin surace: launin fata mai madaidaicin haske',
    '🧖🏽' => 'mutum a cikin ɗakin surace: madaidaicin launin fata',
    '🧖🏾' => 'mutum a cikin ɗakin surace: launin fata mai madaidaicin duhu',
    '🧖🏿' => 'mutum a cikin ɗakin surace: launin fata mai duhu',
    '🧗🏻' => 'mutum mai hawa: launin fata mai haske',
    '🧗🏼' => 'mutum mai hawa: launin fata mai madaidaicin haske',
    '🧗🏽' => 'mutum mai hawa: madaidaicin launin fata',
    '🧗🏾' => 'mutum mai hawa: launin fata mai madaidaicin duhu',
    '🧗🏿' => 'mutum mai hawa: launin fata mai duhu',
    '🏇🏻' => 'sukuwa: launin fata mai haske',
    '🏇🏼' => 'sukuwa: launin fata mai madaidaicin haske',
    '🏇🏽' => 'sukuwa: madaidaicin launin fata',
    '🏇🏾' => 'sukuwa: launin fata mai madaidaicin duhu',
    '🏇🏿' => 'sukuwa: launin fata mai duhu',
    '🏂🏻' => 'mai tsere kan ƙanƙara: launin fata mai haske',
    '🏂🏼' => 'mai tsere kan ƙanƙara: launin fata mai madaidaicin haske',
    '🏂🏽' => 'mai tsere kan ƙanƙara: madaidaicin launin fata',
    '🏂🏾' => 'mai tsere kan ƙanƙara: launin fata mai madaidaicin duhu',
    '🏂🏿' => 'mai tsere kan ƙanƙara: launin fata mai duhu',
    '🏌🏻' => 'mutum mai buga wasan golf: launin fata mai haske',
    '🏌🏼' => 'mutum mai buga wasan golf: launin fata mai madaidaicin haske',
    '🏌🏽' => 'mutum mai buga wasan golf: madaidaicin launin fata',
    '🏌🏾' => 'mutum mai buga wasan golf: launin fata mai madaidaicin duhu',
    '🏌🏿' => 'mutum mai buga wasan golf: launin fata mai duhu',
    '🏄🏻' => 'mutum mai hawan allon wasa a kan teku: launin fata mai haske',
    '🏄🏼' => 'mutum mai hawan allon wasa a kan teku: launin fata mai madaidaicin haske',
    '🏄🏽' => 'mutum mai hawan allon wasa a kan teku: madaidaicin launin fata',
    '🏄🏾' => 'mutum mai hawan allon wasa a kan teku: launin fata mai madaidaicin duhu',
    '🏄🏿' => 'mutum mai hawan allon wasa a kan teku: launin fata mai duhu',
    '🚣🏻' => 'mutum mai tuƙa jirgin ruwa: launin fata mai haske',
    '🚣🏼' => 'mutum mai tuƙa jirgin ruwa: launin fata mai madaidaicin haske',
    '🚣🏽' => 'mutum mai tuƙa jirgin ruwa: madaidaicin launin fata',
    '🚣🏾' => 'mutum mai tuƙa jirgin ruwa: launin fata mai madaidaicin duhu',
    '🚣🏿' => 'mutum mai tuƙa jirgin ruwa: launin fata mai duhu',
    '🏊🏻' => 'mutum mai yin ninƙaya: launin fata mai haske',
    '🏊🏼' => 'mutum mai yin ninƙaya: launin fata mai madaidaicin haske',
    '🏊🏽' => 'mutum mai yin ninƙaya: madaidaicin launin fata',
    '🏊🏾' => 'mutum mai yin ninƙaya: launin fata mai madaidaicin duhu',
    '🏊🏿' => 'mutum mai yin ninƙaya: launin fata mai duhu',
    '⛹🏻' => 'mutum mai tambara ƙwallo: launin fata mai haske',
    '⛹🏼' => 'mutum mai tambara ƙwallo: launin fata mai madaidaicin haske',
    '⛹🏽' => 'mutum mai tambara ƙwallo: madaidaicin launin fata',
    '⛹🏾' => 'mutum mai tambara ƙwallo: launin fata mai madaidaicin duhu',
    '⛹🏿' => 'mutum mai tambara ƙwallo: launin fata mai duhu',
    '🏋🏻' => 'mutum mai ɗaukowa nauyi: launin fata mai haske',
    '🏋🏼' => 'mutum mai ɗaukowa nauyi: launin fata mai madaidaicin haske',
    '🏋🏽' => 'mutum mai ɗaukowa nauyi: madaidaicin launin fata',
    '🏋🏾' => 'mutum mai ɗaukowa nauyi: launin fata mai madaidaicin duhu',
    '🏋🏿' => 'mutum mai ɗaukowa nauyi: launin fata mai duhu',
    '🚴🏻' => 'mutum mai tuƙa keke: launin fata mai haske',
    '🚴🏼' => 'mutum mai tuƙa keke: launin fata mai madaidaicin haske',
    '🚴🏽' => 'mutum mai tuƙa keke: madaidaicin launin fata',
    '🚴🏾' => 'mutum mai tuƙa keke: launin fata mai madaidaicin duhu',
    '🚴🏿' => 'mutum mai tuƙa keke: launin fata mai duhu',
    '🚵🏻' => 'mutum tuƙan babur a kan tsauni: launin fata mai haske',
    '🚵🏼' => 'mutum tuƙan babur a kan tsauni: launin fata mai madaidaicin haske',
    '🚵🏽' => 'mutum tuƙan babur a kan tsauni: madaidaicin launin fata',
    '🚵🏾' => 'mutum tuƙan babur a kan tsauni: launin fata mai madaidaicin duhu',
    '🚵🏿' => 'mutum tuƙan babur a kan tsauni: launin fata mai duhu',
    '🤸🏻' => 'mutum mai alkafura: launin fata mai haske',
    '🤸🏼' => 'mutum mai alkafura: launin fata mai madaidaicin haske',
    '🤸🏽' => 'mutum mai alkafura: madaidaicin launin fata',
    '🤸🏾' => 'mutum mai alkafura: launin fata mai madaidaicin duhu',
    '🤸🏿' => 'mutum mai alkafura: launin fata mai duhu',
    '🤼🏻' => 'mutane masu kokawa: launin fata mai haske',
    '🤼🏼' => 'mutane masu kokawa: launin fata mai madaidaicin haske',
    '🤼🏽' => 'mutane masu kokawa: madaidaicin launin fata',
    '🤼🏾' => 'mutane masu kokawa: launin fata mai madaidaicin duhu',
    '🤼🏿' => 'mutane masu kokawa: launin fata mai duhu',
    '🤽🏻' => 'mutum mai bugan wasan holo na ruwa: launin fata mai haske',
    '🤽🏼' => 'mutum mai bugan wasan holo na ruwa: launin fata mai madaidaicin haske',
    '🤽🏽' => 'mutum mai bugan wasan holo na ruwa: madaidaicin launin fata',
    '🤽🏾' => 'mutum mai bugan wasan holo na ruwa: launin fata mai madaidaicin duhu',
    '🤽🏿' => 'mutum mai bugan wasan holo na ruwa: launin fata mai duhu',
    '🤾🏻' => 'mutum mai bugan ƙwallon hannu: launin fata mai haske',
    '🤾🏼' => 'mutum mai bugan ƙwallon hannu: launin fata mai madaidaicin haske',
    '🤾🏽' => 'mutum mai bugan ƙwallon hannu: madaidaicin launin fata',
    '🤾🏾' => 'mutum mai bugan ƙwallon hannu: launin fata mai madaidaicin duhu',
    '🤾🏿' => 'mutum mai bugan ƙwallon hannu: launin fata mai duhu',
    '🤹🏻' => 'mutum mai juyawa abu a sama: launin fata mai haske',
    '🤹🏼' => 'mutum mai juyawa abu a sama: launin fata mai madaidaicin haske',
    '🤹🏽' => 'mutum mai juyawa abu a sama: madaidaicin launin fata',
    '🤹🏾' => 'mutum mai juyawa abu a sama: launin fata mai madaidaicin duhu',
    '🤹🏿' => 'mutum mai juyawa abu a sama: launin fata mai duhu',
    '🧘🏻' => 'mutum a wurin furen lotus: launin fata mai haske',
    '🧘🏼' => 'mutum a wurin furen lotus: launin fata mai madaidaicin haske',
    '🧘🏽' => 'mutum a wurin furen lotus: madaidaicin launin fata',
    '🧘🏾' => 'mutum a wurin furen lotus: launin fata mai madaidaicin duhu',
    '🧘🏿' => 'mutum a wurin furen lotus: launin fata mai duhu',
    '🛀🏻' => 'mutum mai yin wanka: launin fata mai haske',
    '🛀🏼' => 'mutum mai yin wanka: launin fata mai madaidaicin haske',
    '🛀🏽' => 'mutum mai yin wanka: madaidaicin launin fata',
    '🛀🏾' => 'mutum mai yin wanka: launin fata mai madaidaicin duhu',
    '🛀🏿' => 'mutum mai yin wanka: launin fata mai duhu',
    '🛌🏻' => 'mutum a kan gado: launin fata mai haske',
    '🛌🏼' => 'mutum a kan gado: launin fata mai madaidaicin haske',
    '🛌🏽' => 'mutum a kan gado: madaidaicin launin fata',
    '🛌🏾' => 'mutum a kan gado: launin fata mai madaidaicin duhu',
    '🛌🏿' => 'mutum a kan gado: launin fata mai duhu',
    '👭🏻' => 'namiji da mata suna riƙew da hannuwa: launin fata mai haske',
    '👭🏼' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin haske',
    '👭🏽' => 'namiji da mata suna riƙew da hannuwa: madaidaicin launin fata',
    '👭🏾' => 'namiji da mata suna riƙew da hannuwa: launin fata mai madaidaicin duhu',
    '👭🏿' => 'namiji da mata suna riƙew da hannuwa: launin fata mai duhu',
    '👫🏻' => 'namiji da mace riƙe da hannuwa: launin fata mai haske',
    '👫🏼' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin haske',
    '👫🏽' => 'namiji da mace riƙe da hannuwa: madaidaicin launin fata',
    '👫🏾' => 'namiji da mace riƙe da hannuwa: launin fata mai madaidaicin duhu',
    '👫🏿' => 'namiji da mace riƙe da hannuwa: launin fata mai duhu',
    '👬🏻' => 'maza biyu riƙe da hannuwa: launin fata mai haske',
    '👬🏼' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin haske',
    '👬🏽' => 'maza biyu riƙe da hannuwa: madaidaicin launin fata',
    '👬🏾' => 'maza biyu riƙe da hannuwa: launin fata mai madaidaicin duhu',
    '👬🏿' => 'maza biyu riƙe da hannuwa: launin fata mai duhu',
    '💏🏻' => 'sumba: launin fata mai haske',
    '💏🏼' => 'sumba: launin fata mai madaidaicin haske',
    '💏🏽' => 'sumba: madaidaicin launin fata',
    '💏🏾' => 'sumba: launin fata mai madaidaicin duhu',
    '💏🏿' => 'sumba: launin fata mai duhu',
    '💑🏻' => 'miji da mata tare da zuciya: launin fata mai haske',
    '💑🏼' => 'miji da mata tare da zuciya: launin fata mai madaidaicin haske',
    '💑🏽' => 'miji da mata tare da zuciya: madaidaicin launin fata',
    '💑🏾' => 'miji da mata tare da zuciya: launin fata mai madaidaicin duhu',
    '💑🏿' => 'miji da mata tare da zuciya: launin fata mai duhu',
    '🇦🇨' => 'tuta: Tsibirin Ascension',
    '🇦🇩' => 'tuta: Andora',
    '🇦🇪' => 'tuta: Haɗaɗɗiyar Daular Larabawa',
    '🇦🇫' => 'tuta: Afaganistan',
    '🇦🇬' => 'tuta: Antigua da Barbuda',
    '🇦🇮' => 'tuta: Angila',
    '🇦🇱' => 'tuta: Albaniya',
    '🇦🇲' => 'tuta: Armeniya',
    '🇦🇴' => 'tuta: Angola',
    '🇦🇶' => 'tuta: Antatika',
    '🇦🇷' => 'tuta: Ajentina',
    '🇦🇸' => 'tuta: Samowa Ta Amurka',
    '🇦🇹' => 'tuta: Ostiriya',
    '🇦🇺' => 'tuta: Ostareliya',
    '🇦🇼' => 'tuta: Aruba',
    '🇦🇽' => 'tuta: Tsibirai na Åland',
    '🇦🇿' => 'tuta: Azarbaijan',
    '🇧🇦' => 'tuta: Bosniya da Harzagobina',
    '🇧🇧' => 'tuta: Barbadas',
    '🇧🇩' => 'tuta: Bangladesh',
    '🇧🇪' => 'tuta: Belgiyom',
    '🇧🇫' => 'tuta: Burkina Faso',
    '🇧🇬' => 'tuta: Bulgariya',
    '🇧🇭' => 'tuta: Baharen',
    '🇧🇮' => 'tuta: Burundi',
    '🇧🇯' => 'tuta: Binin',
    '🇧🇱' => 'tuta: San Barthélemy',
    '🇧🇲' => 'tuta: Barmuda',
    '🇧🇳' => 'tuta: Burune',
    '🇧🇴' => 'tuta: Bolibiya',
    '🇧🇶' => 'tuta: Caribbean Netherlands',
    '🇧🇷' => 'tuta: Birazil',
    '🇧🇸' => 'tuta: Bahamas',
    '🇧🇹' => 'tuta: Butan',
    '🇧🇻' => 'tuta: Tsibirin Bouvet',
    '🇧🇼' => 'tuta: Baswana',
    '🇧🇾' => 'tuta: Belarus',
    '🇧🇿' => 'tuta: Beliz',
    '🇨🇦' => 'tuta: Kanada',
    '🇨🇨' => 'tuta: Tsibirai Cocos (Keeling)',
    '🇨🇩' => 'tuta: Jamhuriyar Dimokuraɗiyyar Kongo',
    '🇨🇫' => 'tuta: Jamhuriyar Afirka Ta Tsakiya',
    '🇨🇬' => 'tuta: Kongo',
    '🇨🇭' => 'tuta: Suwizalan',
    '🇨🇮' => 'tuta: Aibari Kwas',
    '🇨🇰' => 'tuta: Tsibiran Cook',
    '🇨🇱' => 'tuta: Chile',
    '🇨🇲' => 'tuta: Kamaru',
    '🇨🇳' => 'tuta: Sin',
    '🇨🇴' => 'tuta: Kolambiya',
    '🇨🇵' => 'tuta: Tsibirin Clipperton',
    '🇨🇶' => 'tuta: Sark',
    '🇨🇷' => 'tuta: Kwasta Rika',
    '🇨🇺' => 'tuta: Kyuba',
    '🇨🇻' => 'tuta: Tsibiran Cape Verde',
    '🇨🇼' => 'tuta: Ƙasar Curaçao',
    '🇨🇽' => 'tuta: Tsibirin Kirsmati',
    '🇨🇾' => 'tuta: Saifurus',
    '🇨🇿' => 'tuta: Czechia',
    '🇩🇪' => 'tuta: Jamus',
    '🇩🇬' => 'tuta: Tsibirn Diego Garcia',
    '🇩🇯' => 'tuta: Jibuti',
    '🇩🇰' => 'tuta: Danmark',
    '🇩🇲' => 'tuta: Dominika',
    '🇩🇴' => 'tuta: Jamhuriyar Dominika',
    '🇩🇿' => 'tuta: Aljeriya',
    '🇪🇦' => 'tuta: Ceuta da Melilla',
    '🇪🇨' => 'tuta: Ekwador',
    '🇪🇪' => 'tuta: Estoniya',
    '🇪🇬' => 'tuta: Misira',
    '🇪🇭' => 'tuta: Yammacin Sahara',
    '🇪🇷' => 'tuta: Eritireya',
    '🇪🇸' => 'tuta: Sipen',
    '🇪🇹' => 'tuta: Habasha',
    '🇪🇺' => 'tuta: Tarayyar Turai',
    '🇫🇮' => 'tuta: Finlan',
    '🇫🇯' => 'tuta: Fiji',
    '🇫🇰' => 'tuta: Tsibiran Falkilan',
    '🇫🇲' => 'tuta: Mikuronesiya',
    '🇫🇴' => 'tuta: Tsibirai na Faroe',
    '🇫🇷' => 'tuta: Faransa',
    '🇬🇦' => 'tuta: Gabon',
    '🇬🇧' => 'tuta: Biritaniya',
    '🇬🇩' => 'tuta: Girnada',
    '🇬🇪' => 'tuta: Jojiya',
    '🇬🇫' => 'tuta: Gini Ta Faransa',
    '🇬🇬' => 'tuta: Yankin Guernsey',
    '🇬🇭' => 'tuta: Gana',
    '🇬🇮' => 'tuta: Jibaraltar',
    '🇬🇱' => 'tuta: Grinlan',
    '🇬🇲' => 'tuta: Gambiya',
    '🇬🇳' => 'tuta: Gini',
    '🇬🇵' => 'tuta: Gwadaluf',
    '🇬🇶' => 'tuta: Ikwatoriyal Gini',
    '🇬🇷' => 'tuta: Girka',
    '🇬🇸' => 'tuta: Kudancin Geogia da Kudancin Tsibirin Sandiwic',
    '🇬🇹' => 'tuta: Gwatamala',
    '🇬🇺' => 'tuta: Guam',
    '🇬🇼' => 'tuta: Gini Bisau',
    '🇬🇾' => 'tuta: Guyana',
    '🇭🇰' => 'tuta: Babban Yankin Mulkin Hong Kong na Ƙasar Sin',
    '🇭🇲' => 'tuta: Tsibirin Heard da McDonald',
    '🇭🇳' => 'tuta: Yankin Honduras',
    '🇭🇷' => 'tuta: Kurowaishiya',
    '🇭🇹' => 'tuta: Haiti',
    '🇭🇺' => 'tuta: Hungari',
    '🇮🇨' => 'tuta: Tsibiran Canary',
    '🇮🇩' => 'tuta: Indunusiya',
    '🇮🇪' => 'tuta: Ayalan',
    '🇮🇱' => 'tuta: Israʼila',
    '🇮🇲' => 'tuta: Isle of Man',
    '🇮🇳' => 'tuta: Indiya',
    '🇮🇴' => 'tuta: Yankin Birtaniya Na Tekun Indiya',
    '🇮🇶' => 'tuta: Iraƙi',
    '🇮🇷' => 'tuta: Iran',
    '🇮🇸' => 'tuta: Aisalan',
    '🇮🇹' => 'tuta: Italiya',
    '🇯🇪' => 'tuta: Kasar Jersey',
    '🇯🇲' => 'tuta: Jamaika',
    '🇯🇴' => 'tuta: Jordan',
    '🇯🇵' => 'tuta: Japan',
    '🇰🇪' => 'tuta: Kenya',
    '🇰🇬' => 'tuta: Kirgizistan',
    '🇰🇭' => 'tuta: Kambodiya',
    '🇰🇮' => 'tuta: Kiribati',
    '🇰🇲' => 'tuta: Kwamoras',
    '🇰🇳' => 'tuta: San Kiti Da Nebis',
    '🇰🇵' => 'tuta: Koriya Ta Arewa',
    '🇰🇷' => 'tuta: Koriya Ta Kudu',
    '🇰🇼' => 'tuta: Kuwet',
    '🇰🇾' => 'tuta: Tsibiran Kaiman',
    '🇰🇿' => 'tuta: Kazakistan',
    '🇱🇦' => 'tuta: Lawos',
    '🇱🇧' => 'tuta: Labanan',
    '🇱🇨' => 'tuta: San Lusiya',
    '🇱🇮' => 'tuta: Licansitan',
    '🇱🇰' => 'tuta: Siri Lanka',
    '🇱🇷' => 'tuta: Laberiya',
    '🇱🇸' => 'tuta: Lesoto',
    '🇱🇹' => 'tuta: Lituweniya',
    '🇱🇺' => 'tuta: Lukusambur',
    '🇱🇻' => 'tuta: Litibiya',
    '🇱🇾' => 'tuta: Libiya',
    '🇲🇦' => 'tuta: Maroko',
    '🇲🇨' => 'tuta: Monako',
    '🇲🇩' => 'tuta: Maldoba',
    '🇲🇪' => 'tuta: Manteneguro',
    '🇲🇫' => 'tuta: San Martin',
    '🇲🇬' => 'tuta: Madagaskar',
    '🇲🇭' => 'tuta: Tsibiran Marshal',
    '🇲🇰' => 'tuta: Macedonia ta Arewa',
    '🇲🇱' => 'tuta: Mali',
    '🇲🇲' => 'tuta: Burma, Miyamar',
    '🇲🇳' => 'tuta: Mangoliya',
    '🇲🇴' => 'tuta: Babban Yankin Mulkin Macao na Ƙasar Sin',
    '🇲🇵' => 'tuta: Tsibiran Mariyana Na Arewa',
    '🇲🇶' => 'tuta: Martinik',
    '🇲🇷' => 'tuta: Moritaniya',
    '🇲🇸' => 'tuta: Manserati',
    '🇲🇹' => 'tuta: Malta',
    '🇲🇺' => 'tuta: Moritus',
    '🇲🇻' => 'tuta: Maldibi',
    '🇲🇼' => 'tuta: Malawi',
    '🇲🇽' => 'tuta: Mesiko',
    '🇲🇾' => 'tuta: Malesiya',
    '🇲🇿' => 'tuta: Mozambik',
    '🇳🇦' => 'tuta: Namibiya',
    '🇳🇨' => 'tuta: Kaledoniya Sabuwa',
    '🇳🇪' => 'tuta: Nijar',
    '🇳🇫' => 'tuta: Tsibirin Narfalk',
    '🇳🇬' => 'tuta: Nijeriya',
    '🇳🇮' => 'tuta: Nikaraguwa',
    '🇳🇱' => 'tuta: Holan',
    '🇳🇴' => 'tuta: Norwe',
    '🇳🇵' => 'tuta: Nefal',
    '🇳🇷' => 'tuta: Nauru',
    '🇳🇺' => 'tuta: Niue',
    '🇳🇿' => 'tuta: Nuzilan',
    '🇴🇲' => 'tuta: Oman',
    '🇵🇦' => 'tuta: Panama',
    '🇵🇪' => 'tuta: Feru',
    '🇵🇫' => 'tuta: Folinesiya Ta Faransa',
    '🇵🇬' => 'tuta: Papuwa Nugini',
    '🇵🇭' => 'tuta: Filipin',
    '🇵🇰' => 'tuta: Pakistan',
    '🇵🇱' => 'tuta: Polan',
    '🇵🇲' => 'tuta: San Piyar da Mikelan',
    '🇵🇳' => 'tuta: Tsibiran Pitcairn',
    '🇵🇷' => 'tuta: Porto Riko',
    '🇵🇸' => 'tuta: Yankunan Palasɗinu',
    '🇵🇹' => 'tuta: Portugal',
    '🇵🇼' => 'tuta: Palau',
    '🇵🇾' => 'tuta: Faragwai',
    '🇶🇦' => 'tuta: Katar',
    '🇷🇪' => 'tuta: Rawuniyan',
    '🇷🇴' => 'tuta: Romaniya',
    '🇷🇸' => 'tuta: Sabiya',
    '🇷🇺' => 'tuta: Rasha',
    '🇷🇼' => 'tuta: Ruwanda',
    '🇸🇦' => 'tuta: Saudiyya',
    '🇸🇧' => 'tuta: Tsibiran Salaman',
    '🇸🇨' => 'tuta: Seychelles',
    '🇸🇩' => 'tuta: Sudan',
    '🇸🇪' => 'tuta: Suwedan',
    '🇸🇬' => 'tuta: Singapur',
    '🇸🇭' => 'tuta: San Helena',
    '🇸🇮' => 'tuta: Sulobeniya',
    '🇸🇯' => 'tuta: Svalbard da Jan Mayen',
    '🇸🇰' => 'tuta: Sulobakiya',
    '🇸🇱' => 'tuta: Salewo',
    '🇸🇲' => 'tuta: San Marino',
    '🇸🇳' => 'tuta: Sanigal',
    '🇸🇴' => 'tuta: Somaliya',
    '🇸🇷' => 'tuta: Suriname',
    '🇸🇸' => 'tuta: Sudan ta Kudu',
    '🇸🇹' => 'tuta: Sawo Tome Da Paransip',
    '🇸🇻' => 'tuta: El Salbador',
    '🇸🇽' => 'tuta: San Maarten',
    '🇸🇾' => 'tuta: Sham, Siriya',
    '🇸🇿' => 'tuta: Eswatini',
    '🇹🇦' => 'tuta: Tritan da Kunha',
    '🇹🇨' => 'tuta: Turkis Da Tsibiran Kaikwas',
    '🇹🇩' => 'tuta: Cadi',
    '🇹🇫' => 'tuta: Yankin Faransi ta Kudu',
    '🇹🇬' => 'tuta: Togo',
    '🇹🇭' => 'tuta: Tailan',
    '🇹🇯' => 'tuta: Tajikistan',
    '🇹🇰' => 'tuta: Takelau',
    '🇹🇱' => 'tuta: Timor-Leste',
    '🇹🇲' => 'tuta: Turkumenistan',
    '🇹🇳' => 'tuta: Tunisiya',
    '🇹🇴' => 'tuta: Tonga',
    '🇹🇷' => 'tuta: Turkiyya',
    '🇹🇹' => 'tuta: Tirinidad Da Tobago',
    '🇹🇻' => 'tuta: Tubalu',
    '🇹🇼' => 'tuta: Taiwan',
    '🇹🇿' => 'tuta: Tanzaniya',
    '🇺🇦' => 'tuta: Yukaran',
    '🇺🇬' => 'tuta: Yuganda',
    '🇺🇲' => 'tuta: Rukunin Tsibirin U.S',
    '🇺🇳' => 'tuta: Majalisar Ɗinkin Duniya',
    '🇺🇸' => 'tuta: Amurka',
    '🇺🇾' => 'tuta: Yurigwai',
    '🇺🇿' => 'tuta: Uzubekistan',
    '🇻🇦' => 'tuta: Birnin Batikan',
    '🇻🇨' => 'tuta: San Binsan Da Girnadin',
    '🇻🇪' => 'tuta: Benezuwela',
    '🇻🇬' => 'tuta: Tsibirin Birjin Na Birtaniya',
    '🇻🇮' => 'tuta: Tsibiran Birjin Ta Amurka',
    '🇻🇳' => 'tuta: Biyetinam',
    '🇻🇺' => 'tuta: Banuwatu',
    '🇼🇫' => 'tuta: Walis Da Futuna',
    '🇼🇸' => 'tuta: Samoa',
    '🇽🇰' => 'tuta: Kasar Kosovo',
    '🇾🇪' => 'tuta: Yamen',
    '🇾🇹' => 'tuta: Mayoti',
    '🇿🇦' => 'tuta: Afirka Ta Kudu',
    '🇿🇲' => 'tuta: Zambiya',
    '🇿🇼' => 'tuta: Zimbabuwe',
    '🔟' => 'maɓalli na musamman: 10',
    '🏻' => 'launin fata mai haske',
    '🏼' => 'launin fata mai madaidaicin haske',
    '🏽' => 'madaidaicin launin fata',
    '🏾' => 'launin fata mai madaidaicin duhu',
    '🏿' => 'launin fata mai duhu',
    '😀' => 'fuska mai murmushin baki har kunne',
    '😃' => 'fuska mai murmushi tare da manyan idanu',
    '😄' => 'fuska mai murmushi tare da idanu',
    '😁' => 'fuska mai murmushi tare da idanuu',
    '😆' => 'murmushin yaƙe tare da lumshe ido',
    '😅' => 'fuska mai murmushi tare da gumi mai sanyi',
    '🤣' => 'mirgina a daɓe da dariya',
    '😂' => 'fuska mai hawayen murna',
    '🙂' => 'fuska mai murmushi kaɗan',
    '🙃' => 'fuska a birkice',
    '🫠' => 'fuska narke',
    '😉' => 'fuska mai yin ƙifta',
    '😊' => 'fuska mai murmushi haɗe da idanu',
    '😇' => 'fuska mai murmushi tare da da’irar haske',
    '🥰' => 'fuska mai dariya da zukata',
    '😍' => 'fuska mai murmushi tare da idanun zuciya',
    '🤩' => 'buga-tauraro',
    '😘' => 'fuska mai ba da wani sumba',
    '😗' => 'Fuska mai yin sumba',
    '☺' => 'fuska mai murmushi',
    '😚' => 'fuska mai yin sumba tare da rufaffen Idanu',
    '😙' => 'fuska mai sumba da idanu masu murmushi',
    '🥲' => 'fuska mai murmushi ɗauke da hawaye',
    '😋' => 'fuska da take ɗanɗana abinci mai daɗi',
    '😛' => 'fuska tare da harshe a waje',
    '😜' => 'fuska tare da harshe a waje da ido mai ƙifta',
    '🤪' => 'fuska mai masifar so',
    '😝' => 'fuska da harshe waje da rufaffun idanu',
    '🤑' => 'fuska mai bakin-kuɗi',
    '🤗' => 'fuska mai murmushi tare da runguma',
    '🤭' => 'fuska tare da hannu bisa baki',
    '🫢' => 'fuska da buɗe idanu da miƙa baki',
    '🫣' => 'fuska tare da leƙo ido ɗaya',
    '🤫' => 'fuska mai shiru',
    '🤔' => 'fuska mai tunani',
    '🫡' => 'fuska mai sarawa',
    '🤐' => 'fuskar baki mai zif',
    '🤨' => 'fuska tare da ɗagaggiyar gira',
    '😐' => 'fuska mai tsaka-tsakanci',
    '😑' => 'fuska mara shige',
    '😶' => 'fuska ban da baki',
    '🫥' => 'kewaye da ɗige fuska',
    '😏' => 'fuska mai murmushin wauta',
    '😒' => 'fuska mara sha’awa',
    '🙄' => 'fuska tare da idanu masu mirgina',
    '😬' => 'fuska na ɗauren fuska',
    '🤥' => 'fuska mai yin ƙarya',
    '🫨' => 'girgiza fuska',
    '😌' => 'fuska mai kwancin hankali',
    '😔' => 'fuska mai yin tunani',
    '😪' => 'fuska mai jin barci',
    '🤤' => 'fuska mai nuna ɓacin rai',
    '😴' => 'fuska mai yin barci',
    '🫩' => 'fuska mai kumburi a ƙasan ido',
    '😷' => 'fuska mai abin rufen fuska na kula da lafiya',
    '🤒' => 'fuska mai tsinken awon zafin jiki',
    '🤕' => 'fuska mai bandejin-kai',
    '🤢' => 'fuska mai tashin zuciya',
    '🤮' => 'fuska yin amai',
    '🤧' => 'fuska mai yin atishawa',
    '🥵' => 'fuska mai zafi',
    '🥶' => 'fuska mai sanyi',
    '🥴' => 'fuska mai kasala',
    '😵' => 'fuska mai jin jiri',
    '🤯' => 'kai mai bashewa',
    '🤠' => 'fuska mai hular kaboyi',
    '🥳' => 'fuska mai liyafa',
    '🥸' => 'sauya fuska',
    '😎' => 'fuska mai murmushi tare da tabarau',
    '🤓' => 'fuska mai daƙiƙi',
    '🧐' => 'fuska tare da tabarau mai ido ɗaya',
    '😕' => 'rikitacciyar fuska',
    '🫤' => 'fuska mai karkataccen baki',
    '😟' => 'fuska mai damuwa',
    '🙁' => 'fuska mai gama gira kaɗan',
    '☹' => 'fuska mai gama gira',
    '😮' => 'fuska tare da baki a buɗe',
    '😯' => 'fuska mai nitsuwa',
    '😲' => 'fuska mai burgewa',
    '😳' => 'fuska mai murna',
    '🫪' => 'juyayyen fuska',
    '🥺' => 'fuska mai roƙo',
    '🥹' => 'fuska ido ya ciko',
    '😦' => 'fuska mai gama gira tare da baki a buɗe',
    '😧' => 'fuska mai tagayyara',
    '😨' => 'fuska mai jin tsoro',
    '😰' => 'fuska tare da baki a buɗe & gumi mai sanyi',
    '😥' => 'fuska mai ɓata rai mai kwanciyar hankali',
    '😢' => 'fuska mai kuka',
    '😭' => 'fuska mai kuka da ƙarfi',
    '😱' => 'fuska mai yin ƙara a cikin tsoro',
    '😖' => 'fuska mai rikitarwa',
    '😣' => 'fuska mai nacewa',
    '😞' => 'fuska mai ɓacin rai',
    '😓' => 'fuska tare da gumi mai sanyi',
    '😩' => 'gajiyayyiyar fuska',
    '😫' => 'fuska mai gajiya',
    '🥱' => 'fuska mai hamma',
    '😤' => 'fuska tare da tururi daga hanci',
    '😡' => 'fuska mai nuna ɓacin zuciya',
    '😠' => 'fuska mai fushi',
    '🤬' => 'fuska tare da alamomi bisa baki',
    '😈' => 'fuska mai murmushi tare da ƙahoni',
    '👿' => 'fuska mai fushi tare da ƙahoni',
    '💀' => 'ƙoƙon kai',
    '☠' => 'ƙoƙon kai da haɗaɗɗun ƙashushuwa',
    '💩' => 'tsibin kashi',
    '🤡' => 'fuskar cali-cali',
    '👹' => 'dodo',
    '👺' => 'dodanni',
    '👻' => 'fatalwa',
    '👽' => 'baƙon sararin sama',
    '👾' => 'dodon baƙon sararin sama',
    '🤖' => 'fuskar Robot',
    '😺' => 'kyanwa mai murmushi baki a buɗe',
    '😸' => 'kyanwa baki buɗe idanu masu murmushi',
    '😹' => 'fuskar kyanwa tare da hawayen murna',
    '😻' => 'kyanwa mai murmushi da idanun-zuciya',
    '😼' => 'fuskar kyanwa tare da murmushin ɓacin rai',
    '😽' => 'kyanwa mai sumba da rufaffun idanu',
    '🙀' => 'fuskar kyanwa mai gajiya',
    '😿' => 'fuskar kyanwa mai kuka',
    '😾' => 'fuskar kyanwa mai nuna ɓacin zuciya',
    '🙈' => 'biri na kada a gan mamuganci',
    '🙉' => 'biri na kada a ji sharri',
    '🙊' => 'iri na kada a faɗi sharri',
    '💌' => 'wasiƙar soyayya',
    '💘' => 'zuciya tare da kibiya',
    '💝' => 'zuciya tare da ribon',
    '💖' => 'zuciya mai ƙyalƙyali',
    '💗' => 'zuciya mai bunƙasawa',
    '💓' => 'zuciya mai bugawa',
    '💞' => 'zuciyoyi masu juyawa',
    '💕' => 'zuciyoyi biyu',
    '💟' => 'adon zuciya',
    '❣' => 'alamar motsin rai na nauyin zuciya',
    '💔' => 'karyayyiyar zuciya',
    '❤' => 'jar zuciya',
    '🩷' => 'zuciya ruwan hoda',
    '🧡' => 'zuciyar na ruwan goro',
    '💛' => 'rawayan zuciya',
    '💚' => 'koren zuciya',
    '💙' => 'shuɗin zuciya',
    '🩵' => 'zuciya shuɗiya mai haske',
    '💜' => 'zuciya algashi',
    '🤎' => 'zuciya ƙasa-ƙasa',
    '🖤' => 'baƙar zuciya',
    '🩶' => 'zuciya ruwan toka',
    '🤍' => 'farar zuciya',
    '💋' => 'alamar sumba',
    '💯' => 'makunan ɗari',
    '💢' => 'alamar fushi',
    '🫯' => 'gajimaren faɗa',
    '💥' => 'karo',
    '💫' => 'jiri',
    '💦' => 'ɗige-ɗigen gumi',
    '💨' => 'gudu mai sauri',
    '🕳' => 'rami',
    '💬' => 'balan-balan magana',
    '🗨' => 'kumfan magana na hagu',
    '🗯' => 'kumfan fushi na dama',
    '💭' => 'balan-balan tunani',
    '💤' => 'alamar zzz',
    '👋' => 'hannu mai wurgawa',
    '🤚' => 'ɗagaggen bayan hannu',
    '🖐' => 'ɗagaggen hannu tare da yatsa a faɗaɗɗe',
    '✋' => 'ɗagaggen hannu',
    '🖖' => 'gaisuwar vulcan',
    '🫱' => 'hannun dama gaba',
    '🫲' => 'hannun hagu gaba',
    '🫳' => 'tafin hannu ƙasa',
    '🫴' => 'tafin hannu sama',
    '🫷' => 'hannun yana turawa hagu',
    '🫸' => 'hannu yana turawa dama',
    '👌' => 'hannun TO',
    '🤌' => 'tsuke yatsu',
    '🤏' => 'tsuke yatsu biyu',
    '✌' => 'hannun nasara',
    '🤞' => 'haɗaɗɗun yatsu',
    '🫰' => 'hannu da yatsa da babban yatsa a kewaye',
    '🤟' => 'nunin soyayya',
    '🤘' => 'alamar ƙaho',
    '🤙' => 'hannun kira ni',
    '👈' => 'ɗan ali na baya mai nunawa hagu',
    '👉' => 'ɗan ali na baya mai nunawa dama',
    '👆' => 'ɗan ali na baya mai nunawa sama',
    '🖕' => 'ɗan yatsan tsakiya',
    '👇' => 'ɗan ali na baya mai nunawa ƙasa',
    '☝' => 'ɗan ali mai nunawa sama',
    '🫵' => 'yatsa yana nuna mai kallo',
    '👍' => 'da kyau',
    '👎' => 'babu kyau',
    '✊' => 'ɗagaggen dunƙulen hannu',
    '👊' => 'dunƙulen hannu mai zuwa',
    '🤛' => 'dunƙulen hannu mai fuskanta hagu',
    '🤜' => 'dunƙulen hannu mai fuskanta dama',
    '👏' => 'hannuwa mai tafawa',
    '🙌' => 'ɗagaggun hannuwa',
    '🫶' => 'hannayen zuciya',
    '👐' => 'buɗaɗɗun hannuwa',
    '🤲' => 'tafunan hannu a sama tare',
    '🤝' => 'musafiha',
    '🙏' => 'kalmasassun hannuwa',
    '✍' => 'hannu mai rubutawa',
    '💅' => 'jan farce',
    '🤳' => 'hoton kanka',
    '💪' => 'tanƙwararrun ƙwanji',
    '🦾' => 'hannu na inji',
    '🦿' => 'ƙafar inji',
    '🦵' => 'ƙafa',
    '🦶' => 'tafin ƙafa',
    '👂' => 'kunne',
    '🦻' => 'kunne da kayan ji',
    '👃' => 'hanci',
    '🧠' => 'ƙwaƙwalwa',
    '🫀' => 'surar zuciya',
    '🫁' => 'huhu',
    '🦷' => 'haƙuri',
    '🦴' => 'ƙashi',
    '👀' => 'idanu',
    '👁' => 'ido',
    '👅' => 'harshe',
    '👄' => 'baki',
    '🫦' => 'ciza leɓe',
    '👶' => 'jariri',
    '🧒' => 'ɗa',
    '👦' => 'yaro',
    '👧' => 'yarinya',
    '🧑' => 'babba',
    '👱' => 'mutum mai farin gashi',
    '👨' => 'namiji',
    '🧔' => 'mutumi mai gemu',
    '👩' => 'mace',
    '🧓' => 'babba mafi tsufa',
    '👴' => 'dattijo',
    '👵' => 'dattijuwa',
    '🙍' => 'mutum mai ɓacin rai',
    '🙎' => 'mutum mai nunawa ɓacin zuciya',
    '🙅' => 'mutum mai nunawa A’A da hannu',
    '🙆' => 'mutum mai nunawa TO da hannu',
    '💁' => 'mutum hannu mai ba da ci-goro',
    '🙋' => 'mutum mai ɗagawa hannu',
    '🧏' => 'kurma',
    '🙇' => 'mutum mai sunkuya',
    '🤦' => 'mutum nunawa kunya',
    '🤷' => 'mutum ɗaga kafaɗa',
    '👮' => 'ɗan sanda',
    '🕵' => 'si’aidi',
    '💂' => 'mai gadi',
    '🥷' => 'shigar ninja',
    '👷' => 'ma’aikacin gini',
    '🫅' => 'mutum mai kambi',
    '🤴' => 'ɗan sarki',
    '👸' => 'gimbiya',
    '👳' => 'mutum mai sakawa rawani',
    '👲' => 'mutum mai hulan ’yan Caina',
    '🧕' => 'mace da ta saka ɗankwali',
    '🤵' => 'mutum cikin kwat',
    '👰' => 'amarya da mayafi',
    '🤰' => 'mace mai ciki',
    '🫃' => 'namiji mai ciki',
    '🫄' => 'mutum mai ciki',
    '🤱' => 'shayarwa',
    '👼' => 'jaririn malaika',
    '🎅' => 'Tsoho-da-Gemu',
    '🤶' => 'Matar Claus',
    '🦸' => 'jarumi',
    '🦹' => 'jarumi cikin zane',
    '🧙' => 'mai dabo',
    '🧚' => 'aljana',
    '🧛' => 'mai shan jini',
    '🧜' => 'aljanun ruwa',
    '🧝' => 'jinsiri',
    '🧞' => 'aljanin larabawa',
    '🧟' => 'gaya mai rai',
    '🧌' => 'mutum na zane',
    '🫈' => 'halitta mai gashi',
    '💆' => 'mutum mai samun tausa',
    '💇' => 'mutum mai yin aski',
    '🚶' => 'mutum mai yin tafiya ƙafa',
    '🧍' => 'mutum a tsaye',
    '🧎' => 'mutum a durƙushe',
    '🏃' => 'mutum mai yin gudu',
    '💃' => 'mace mai yin rawa',
    '🕺' => 'mutum mai yin rawa',
    '🕴' => 'mutum a cikin kwat na kasuwanci mai jewa',
    '👯' => 'mutane masu kunnuwan zomo yin biki',
    '🧖' => 'mutum a cikin ɗakin surace',
    '🧗' => 'mutum mai hawa',
    '🤺' => 'mutum wasan zorro',
    '🏇' => 'sukuwa',
    '⛷' => 'ɗan wasan ski',
    '🏂' => 'mai tsere kan ƙanƙara',
    '🏌' => 'mutum mai buga wasan golf',
    '🏄' => 'mutum mai hawan allon wasa a kan teku',
    '🚣' => 'mutum mai tuƙa jirgin ruwa',
    '🏊' => 'mutum mai yin ninƙaya',
    '⛹' => 'mutum mai tambara ƙwallo',
    '🏋' => 'mutum mai ɗaukowa nauyi',
    '🚴' => 'mutum mai tuƙa keke',
    '🚵' => 'mutum tuƙan babur a kan tsauni',
    '🤸' => 'mutum mai alkafura',
    '🤼' => 'mutane masu kokawa',
    '🤽' => 'mutum mai bugan wasan holo na ruwa',
    '🤾' => 'mutum mai bugan ƙwallon hannu',
    '🤹' => 'mutum mai juyawa abu a sama',
    '🧘' => 'mutum a wurin furen lotus',
    '🛀' => 'mutum mai yin wanka',
    '🛌' => 'mutum a kan gado',
    '👭' => 'namiji da mata suna riƙew da hannuwa',
    '👫' => 'namiji da mace riƙe da hannuwa',
    '👬' => 'maza biyu riƙe da hannuwa',
    '💏' => 'sumba',
    '💑' => 'miji da mata tare da zuciya',
    '🗣' => 'kai mai yin magana',
    '👤' => 'daga kai har ƙirji',
    '👥' => 'daga kanu har ƙirji',
    '🫂' => 'mutane na runguma',
    '👪' => 'iyali',
    '👣' => 'sawaye',
    '🫆' => 'zanen ɗan yatsa',
    '🦰' => 'jan gashi',
    '🦱' => 'gashi mai laushi',
    '🦳' => 'farin gashi',
    '🦲' => 'sanƙo',
    '🐵' => 'fuskar biri',
    '🐒' => 'biri',
    '🦍' => 'birin gorilla',
    '🦧' => 'babban biri',
    '🐶' => 'fuskar kare',
    '🐕' => 'kare',
    '🦮' => 'karen jagora',
    '🐩' => 'karen poodle',
    '🐺' => 'ƙyarkaci',
    '🦊' => 'yanyawa',
    '🦝' => 'rakon',
    '🐱' => 'fuskar kyanwa',
    '🐈' => 'kyanwa',
    '🦁' => 'zaki',
    '🐯' => 'fuskar damisa mai ratsi-ratsi',
    '🐅' => 'damisa mai ratsi-ratsi',
    '🐆' => 'damisa',
    '🐴' => 'fuskar doki',
    '🫎' => 'karakanda',
    '🫏' => 'jaki',
    '🐎' => 'doki',
    '🦄' => 'fuskar dabbar unicorn',
    '🦓' => 'jakin dawa',
    '🦌' => 'barewa',
    '🦬' => 'gwanki',
    '🐮' => 'fuskar saniya',
    '🐂' => 'takarkari',
    '🐃' => 'ɓaunan ruwa',
    '🐄' => 'saniya',
    '🐷' => 'fuskar alade',
    '🐖' => 'alade',
    '🐗' => 'gadu',
    '🐽' => 'hancin alade',
    '🐏' => 'rago',
    '🐑' => 'tunkiya',
    '🐐' => 'akuya',
    '🐪' => 'raƙumi',
    '🐫' => 'raƙumi mai tozon biyu',
    '🦙' => 'raƙumin dajin llama',
    '🦒' => 'raƙumin dawa',
    '🐘' => 'giwa',
    '🦣' => 'giwa mai dogon haure',
    '🦏' => 'karkanda',
    '🦛' => 'dorina',
    '🐭' => 'fuskar kusu',
    '🐁' => 'kusu',
    '🐀' => 'ɓera',
    '🐹' => 'dabbar hamster',
    '🐰' => 'fuskar zomo',
    '🐇' => 'zomo',
    '🐿' => 'kurege',
    '🦫' => 'dabbar beaver',
    '🦔' => 'dabbar hedgehog',
    '🦇' => 'jemage',
    '🐻' => 'fuskar dabbar bear',
    '🐨' => 'dabbar koala',
    '🐼' => 'fuskar dabbar panda',
    '🦥' => 'dabba mai kasala',
    '🦦' => 'otta',
    '🦨' => 'bodari',
    '🦘' => 'kangaru',
    '🦡' => 'baja',
    '🐾' => 'zanen dagi',
    '🦃' => 'talo-talo',
    '🐔' => 'kaza',
    '🐓' => 'zakara',
    '🐣' => 'ɗan tsako mai ƙyanƙyashe',
    '🐤' => 'ƙaramin ɗan tsako',
    '🐥' => 'ƙaramin ɗan tsako mai dubawa-gaba',
    '🐦' => 'tsuntsu',
    '🐧' => 'tsuntsun Penguin',
    '🕊' => 'kurciya',
    '🦅' => 'mikiya',
    '🦆' => 'agwagwa',
    '🦢' => 'agwagwar ruwa',
    '🦉' => 'mujiya',
    '🦤' => 'agwagwar dodo',
    '🪶' => 'gashin tsuntsu',
    '🦩' => 'filamingo',
    '🦚' => 'ɗawisu',
    '🦜' => 'aku',
    '🪽' => 'fuffuke',
    '🪿' => 'gis',
    '🐸' => 'kwaɗo',
    '🐊' => 'kada',
    '🐢' => 'ƙififfiya',
    '🦎' => 'ƙadangare',
    '🐍' => 'maciji',
    '🐲' => 'fuskar dabbar daragon',
    '🐉' => 'daragon',
    '🦕' => 'dabbar sauropod',
    '🦖' => 'dabbar T-Rex',
    '🐳' => 'dabbar whale mai fitowar da ruwa',
    '🐋' => 'dabbar whale',
    '🐬' => 'kifin dolphin',
    '🫍' => 'kifin orca',
    '🦭' => 'ayu',
    '🐟' => 'kifi',
    '🐠' => 'kifi na wuri mai zafi',
    '🐡' => 'kifi mai kumbura',
    '🦈' => 'kifin shark',
    '🐙' => 'dabbar octopus',
    '🐚' => 'lanƙwasasshen ƙumba',
    '🪸' => 'ciyawa',
    '🪼' => 'jelisih',
    '🦀' => 'ƙaguwa',
    '🦞' => 'ƙaguwar lobster',
    '🦐' => 'jatanlande',
    '🦑' => 'jatan lande na turawa',
    '🦪' => 'oyesta',
    '🐌' => 'dodon koɗi',
    '🦋' => 'malam-buɗe-mana-littafi',
    '🐛' => 'ƙwaro',
    '🐜' => 'cinnaka',
    '🐝' => 'zuma',
    '🪲' => 'buzuzu',
    '🐞' => 'buzuzun turawa',
    '🦗' => 'gyare',
    '🪳' => 'kyankyaso',
    '🕷' => 'gizo',
    '🕸' => 'yanar gizo-gizo',
    '🦂' => 'kunama',
    '🦟' => 'sauro',
    '🪰' => 'ƙuda',
    '🪱' => 'tsutsa',
    '🦠' => 'tsutsar microbe',
    '💐' => 'jerin fure',
    '🌸' => 'hudar cherry',
    '💮' => 'farin fure',
    '🪷' => 'magarya',
    '🏵' => 'rosette',
    '🌹' => 'furen wardi',
    '🥀' => 'lanƙwasasshen fure',
    '🌺' => 'zoɓorodo',
    '🌻' => 'furenrana',
    '🌼' => 'huda',
    '🌷' => 'fure',
    '🪻' => 'hayasin',
    '🌱' => 'dashe',
    '🪴' => 'tsire-tsire na tukunya',
    '🌲' => 'bishiya mai tsanwa',
    '🌳' => 'bishiya mai kaɗe ganye',
    '🌴' => 'bishiyar kwakwa',
    '🌵' => 'kyarana',
    '🌾' => 'damin shinkafa',
    '🌿' => 'ganye',
    '☘' => 'koren ganye',
    '🍀' => 'clover mai ganye huɗu',
    '🍁' => 'busasshen ganye',
    '🍂' => 'ganyen da ya faɗi',
    '🍃' => 'ganye mai yin filfilwa a iska',
    '🪹' => 'sheƙar da ba komai',
    '🪺' => 'sheƙa mai ƙwai',
    '🍄' => 'inuwar-kwaɗi',
    '🪾' => 'bishiya maras ganye',
    '🍇' => 'inabi',
    '🍈' => 'malo',
    '🍉' => 'kankana',
    '🍊' => 'tanjarin',
    '🍋' => 'ruwan lemo',
    '🍌' => 'ayaba',
    '🍍' => 'abarba',
    '🥭' => 'mangoro',
    '🍎' => 'jan tuffa',
    '🍏' => 'koren tuffa',
    '🍐' => 'fiya',
    '🍑' => 'ruwan tufa',
    '🍒' => 'ceri',
    '🍓' => 'sitiroberi',
    '🫐' => 'buluberi',
    '🥝' => 'ɗan itacen kiwi',
    '🍅' => 'tumatir',
    '🫒' => 'zaitun',
    '🥥' => 'kwakwa',
    '🥑' => 'abokado',
    '🍆' => 'gauta',
    '🥔' => 'dankali',
    '🥕' => 'karas',
    '🌽' => 'zangarniyar masara',
    '🌶' => 'barkono mai zafi',
    '🫑' => 'koren tattasai',
    '🥒' => 'kokwamba',
    '🥬' => 'koren ganyayyaki',
    '🥦' => 'burokoli',
    '🧄' => 'tafarnuwa',
    '🧅' => 'albasa',
    '🥜' => 'gyaɗa',
    '🫘' => 'wake',
    '🌰' => 'gyaɗar chestnut',
    '🫚' => 'saiwar citta',
    '🫛' => 'koren wake na fis',
    '🫜' => 'kayan lambu masu saiwa',
    '🍞' => 'burodi',
    '🥐' => 'burodin croissant',
    '🥖' => 'burodin baguette',
    '🫓' => 'kewayayyen burodi',
    '🥨' => 'biskit na pretzel',
    '🥯' => 'burodin bagel',
    '🥞' => 'fanke',
    '🧇' => 'waina',
    '🧀' => 'mayankin cuku',
    '🍖' => 'nama a kan ƙashi',
    '🍗' => 'cinyar kaza',
    '🥩' => 'yankan nama',
    '🥓' => 'naman alade',
    '🍔' => 'biredin hamburger',
    '🍟' => 'soyayyen dankali',
    '🍕' => 'fanken pizza',
    '🌭' => 'biredin hot dog',
    '🥪' => 'abincin sandwich',
    '🌮' => 'fanken taco',
    '🌯' => 'fanken burrito',
    '🫔' => 'biredin tamale',
    '🥙' => 'cikakken burodi',
    '🧆' => 'dunƙulen falafel',
    '🥚' => 'ƙwai',
    '🍳' => 'girkawa',
    '🥘' => 'kwanon mara zurfi na abinci',
    '🍲' => 'tukunyar abinci',
    '🫕' => 'narkakken cuku',
    '🥣' => 'kwano tare da cokali',
    '🥗' => 'salak na ganye',
    '🍿' => 'gugguru',
    '🧈' => 'bota',
    '🧂' => 'gishiri',
    '🥫' => 'abinci na gwangwani',
    '🍱' => 'akwatin bento',
    '🍘' => 'biskit na shinkafa',
    '🍙' => 'curin shinkafa',
    '🍚' => 'dafaffen shinkafa',
    '🍛' => 'shinkafa na kori',
    '🍜' => 'kwano mai dambatawa',
    '🍝' => 'taliya',
    '🍠' => 'gasasshen dankali',
    '🍢' => 'abincin oden',
    '🍣' => 'abincin sushi',
    '🍤' => 'soyayyen jatan lande',
    '🍥' => 'kek na kifi mai juyawa',
    '🥮' => 'kek ɗin wata',
    '🍡' => 'alawar dango',
    '🥟' => 'ƙaramar kwaɓaɓɓiyar fulawa',
    '🥠' => 'biskit na dukiya',
    '🥡' => 'akwatin abinci na fita waje',
    '🍦' => 'ƙanƙara Mai taushi',
    '🍧' => 'rugurgujen ƙanƙara',
    '🍨' => 'ƙanƙara',
    '🍩' => 'donot',
    '🍪' => 'biskit',
    '🎂' => 'kek na ranar haihuwa',
    '🍰' => 'yankin kek',
    '🧁' => 'kek na kofi',
    '🥧' => 'fai',
    '🍫' => 'sandar Cakulan',
    '🍬' => 'alawa',
    '🍭' => 'alawar lollipop',
    '🍮' => 'kwastad',
    '🍯' => 'tukunyar zuma',
    '🍼' => 'kwalbar jarirai',
    '🥛' => 'gilashin madara',
    '☕' => 'shayi mai zafi',
    '🫖' => 'butar shayi',
    '🍵' => 'kofin shayi mara mariƙi',
    '🍶' => 'giyar sake',
    '🍾' => 'kwalba mai murfi mai fashewa',
    '🍷' => 'gilashin giya',
    '🍸' => 'gilashin cocktail',
    '🍹' => 'abinsha na wurin zafi',
    '🍺' => 'kofin giya',
    '🍻' => 'kofofin giya masu yin amo',
    '🥂' => 'gilasan giya masu yin amo',
    '🥃' => 'gilashin tambular',
    '🫗' => 'zuba ruwa',
    '🥤' => 'kofi tare da tsinke',
    '🧋' => 'shayi mai kumfa',
    '🧃' => 'lemon kwali',
    '🧉' => 'kofin sha',
    '🧊' => 'ƙankara',
    '🥢' => 'sandunan cin abinci',
    '🍽' => 'cokali mai yatsu da wuƙa tare da faranti',
    '🍴' => 'cokali mai yatsu da wuƙa',
    '🥄' => 'cokali',
    '🔪' => 'wuƙar kicin',
    '🫙' => 'kurtu',
    '🏺' => 'butar amphora',
    '🌍' => 'taswirar duniya mai nuna Turai-Afirka',
    '🌎' => 'taswirar duniya mai nuna Ƙasashen Amurka',
    '🌏' => 'taswirar duniya mai nuna Asiya-Ostiraliya',
    '🌐' => 'taswirar duniya mai nuna layukan lokaci',
    '🗺' => 'taswirar duniya',
    '🗾' => 'taswirar Japan',
    '🧭' => 'kamfas',
    '🏔' => 'tsauni mai saman ƙanƙara',
    '⛰' => 'tsauni',
    '🛘' => 'zamewar ƙasa',
    '🌋' => 'dutse mai aman wuta',
    '🗻' => 'tsaunin fuji',
    '🏕' => 'zaman ruga',
    '🏖' => 'bakin teku tare da laima',
    '🏜' => 'hamada',
    '🏝' => 'tsibirin hamada',
    '🏞' => 'gandun daji na ƙasa',
    '🏟' => 'filin wasa',
    '🏛' => 'gini na da',
    '🏗' => 'aikin gini na gini',
    '🧱' => 'bulo',
    '🪨' => 'dutse',
    '🪵' => 'itace',
    '🛖' => 'bukka',
    '🏘' => 'gidaje',
    '🏚' => 'zaizayayyen gida',
    '🏠' => 'gida',
    '🏡' => 'gida mai gadina',
    '🏢' => 'ginin ofis',
    '🏣' => 'gidan waya Na Japan',
    '🏤' => 'gidan waya',
    '🏥' => 'asibiti',
    '🏦' => 'banki',
    '🏨' => 'hotal',
    '🏩' => 'hotal na soyayya',
    '🏪' => 'shago a wuri mai dacewa',
    '🏫' => 'makaranta',
    '🏬' => 'babban shago',
    '🏭' => 'masana’anta',
    '🏯' => 'sansani Na Japan',
    '🏰' => 'sansani',
    '💒' => 'bikin aure',
    '🗼' => 'hasumiyar Tokyo',
    '🗽' => 'mutum-mutumi na ’yanci',
    '⛪' => 'coci',
    '🕌' => 'masallaci',
    '🛕' => 'gidan ibanda na hindu',
    '🕍' => 'wurin ibada na yahudawa',
    '⛩' => 'wurin addu’a na shinto',
    '🕋' => 'ɗakin kaaba',
    '⛲' => 'marmaro',
    '⛺' => 'tanti',
    '🌁' => 'mai hazo',
    '🌃' => 'dare mai taurari',
    '🏙' => 'ganowar birni',
    '🌄' => 'fitowar rana bisa tsaunuka',
    '🌅' => 'fitowar rana',
    '🌆' => 'ganowar birni a magariba',
    '🌇' => 'faɗuwar rana',
    '🌉' => 'gada a dare',
    '♨' => 'maɓuɓɓuga mai zafi',
    '🎠' => 'dokin lilon mai juyawa',
    '🛝' => 'filin wasan motsa jiki',
    '🎡' => 'babban lilo',
    '🎢' => 'motocin masa masu juyawa',
    '💈' => 'sandar mai aski',
    '🎪' => 'tantin ’yan wasa',
    '🚂' => 'jirgin ƙasa mai amfani da gawayi',
    '🚃' => 'ƙaramar motar reluwe',
    '🚄' => 'jirgin ƙasa mai matuƙar sauri',
    '🚅' => 'jirgin ƙasa mai gudun tsiya',
    '🚆' => 'jirgin ƙasa',
    '🚇' => 'jirgin ƙarƙashin ƙasa',
    '🚈' => 'reluwe na cunkoso mara yawa',
    '🚉' => 'tasha',
    '🚊' => 'jirgin tram',
    '🚝' => 'reluwe guda',
    '🚞' => 'reluwen tsauni',
    '🚋' => 'ƙaramar motar tram',
    '🚌' => 'bas',
    '🚍' => 'bas mai zuwa',
    '🚎' => 'bas mai aiki da lantarki',
    '🚐' => 'ƙaramar bas',
    '🚑' => 'ambulan',
    '🚒' => 'injin wuta',
    '🚓' => 'motar ’yan sanda',
    '🚔' => 'motar ’yan sanda mai zuwa',
    '🚕' => 'tasi',
    '🚖' => 'tasi mai zuwa',
    '🚗' => 'mota',
    '🚘' => 'mota mai zuwa',
    '🚙' => 'motar amfani na wasanni',
    '🛻' => 'a-kori-kura',
    '🚚' => 'babbar mota ta kai kaya',
    '🚛' => 'tirela mai tarakta',
    '🚜' => 'tarakta',
    '🏎' => 'motar tsere',
    '🏍' => 'babur',
    '🛵' => 'sukuta na inji',
    '🦽' => 'keken hannu',
    '🦼' => 'keken hannu mai inji',
    '🛺' => 'keken adaidaita-sahu',
    '🚲' => 'keke',
    '🛴' => 'sukuta na ƙafa',
    '🛹' => 'allo mai taya',
    '🛼' => 'takalmin taya',
    '🚏' => 'tashar bas',
    '🛣' => 'hanyar mota',
    '🛤' => 'sawun reluwe',
    '🛢' => 'gangar mai',
    '⛽' => 'famfon mai',
    '🛞' => 'taya',
    '🚨' => 'wutar motar ’yan sanda',
    '🚥' => 'wutar tarafik mai kwance',
    '🚦' => 'wutar tarafik mai tsaye',
    '🛑' => 'alamar dakata',
    '🚧' => 'aikin gini',
    '⚓' => 'babban karfi',
    '🛟' => 'balan-balan ceto na ruwa',
    '⛵' => 'jirgin ruwa mai filafilai',
    '🛶' => 'ƙaramin jirgin ruwa',
    '🚤' => 'jirgin ruwa mai sauri',
    '🛳' => 'jirgin ruwa na fasinja',
    '⛴' => 'jirgin fito',
    '🛥' => 'jirgin ruwa mai inji',
    '🚢' => 'jirgin ruwa',
    '✈' => 'jirgin sama',
    '🛩' => 'ƙaramin jirgin sama',
    '🛫' => 'tasowar jirgin sama',
    '🛬' => 'isarwar jirgin sama',
    '🪂' => 'laimar jirgi',
    '💺' => 'wurin zama',
    '🚁' => 'helikafta',
    '🚟' => 'reluwe mai rataya',
    '🚠' => 'motar sama na tsauni',
    '🚡' => 'hanyar mota ta sama',
    '🛰' => 'kumbo',
    '🚀' => 'roka',
    '🛸' => 'faranti mai tasowa',
    '🛎' => 'yaro mai taimaka baƙi ƙararrawa',
    '🧳' => 'kaya',
    '⌛' => 'gilashin lokaci',
    '⏳' => 'gilashin lokaci mai yashi mai gudana',
    '⌚' => 'kallo',
    '⏰' => 'agogon faɗakarwa',
    '⏱' => 'agogo mai awon gudu',
    '⏲' => 'agogon mai ƙirga lokaci',
    '🕰' => 'agogon mantelpiece',
    '🕛' => 'ƙarfe goma sha biyu',
    '🕧' => 'sha biyu da rabi',
    '🕐' => 'ƙarfe ɗaya',
    '🕜' => 'ɗaya da rabi',
    '🕑' => 'ƙarfe biyu',
    '🕝' => 'biyu da rabi',
    '🕒' => 'ƙarfe uku',
    '🕞' => 'uku da rabi',
    '🕓' => 'ƙarfe huɗu',
    '🕟' => 'huɗu da rabi',
    '🕔' => 'ƙarfe biyar',
    '🕠' => 'biyar da rabi',
    '🕕' => 'ƙarfe shida',
    '🕡' => 'shida da rabi',
    '🕖' => 'ƙarfe bakwai',
    '🕢' => 'bakwai da rabi',
    '🕗' => 'ƙarfe takwas',
    '🕣' => 'takwas da rabi',
    '🕘' => 'ƙarfe tara',
    '🕤' => 'tara da rabi',
    '🕙' => 'ƙarfe goma',
    '🕥' => 'goma da rabi',
    '🕚' => 'ƙarfe goma sha ɗaya',
    '🕦' => 'sha ɗaya da rabi',
    '🌑' => 'sabon wata',
    '🌒' => 'hilalin wata mai ƙaruwa',
    '🌓' => 'wata na farkon kwata',
    '🌔' => 'wata wucewa rabi mai ƙaruwa',
    '🌕' => 'cikakken wata',
    '🌖' => 'wata wucewa rabi mai ragewa',
    '🌗' => 'wata na ƙarshen kwata',
    '🌘' => 'hilalin wata mai ragewa',
    '🌙' => 'hilalin wata',
    '🌚' => 'fuskar sabon wata',
    '🌛' => 'wata na farkon kwata tare da fuska',
    '🌜' => 'wata na ƙarshen kwata tare da fuska',
    '🌡' => 'mai aunin zafin jiki',
    '☀' => 'rana',
    '🌝' => 'cikakken wata tare da fuska',
    '🌞' => 'rana tare da fuska',
    '🪐' => 'duniya mai zobe',
    '⭐' => 'farin matsakaicin tauraro',
    '🌟' => 'tauraro mai haske',
    '🌠' => 'mashi',
    '🌌' => 'hanyar sama',
    '☁' => 'gajimare',
    '⛅' => 'rana a bayan gajimare',
    '⛈' => 'gajimare tare da aradu da ruwan sama',
    '🌤' => 'rana a bayan ƙaramin gajimare',
    '🌥' => 'rana a bayan babban gajimare',
    '🌦' => 'rana a bayan gajimaren ruwan sama',
    '🌧' => 'gajimare tare da ruwan sama',
    '🌨' => 'gajimare tare da ƙanƙara',
    '🌩' => 'gajimare tare da aradu',
    '🌪' => 'guguwa mai ƙarfi',
    '🌫' => 'hazo',
    '🌬' => 'fuskar iska',
    '🌀' => 'babban ruwa da iska',
    '🌈' => 'baƙangizo',
    '🌂' => 'rufaffiyar laima',
    '☂' => 'laima',
    '☔' => 'laima tare da ɗige-ɗigen ruwan sama',
    '⛱' => 'laima a ƙasa',
    '⚡' => 'ƙarfin wuta na sama',
    '❄' => 'ɓarɓashin ƙanƙara',
    '☃' => 'mutumin ƙanƙari',
    '⛄' => 'mutumin ƙanƙara ban da ƙanƙara',
    '☄' => 'taurariya mai wutsiya',
    '🔥' => 'wuta',
    '💧' => 'ɗan ɗigo',
    '🌊' => 'igiyar ruwa',
    '🎃' => 'fitilar-jack-o',
    '🎄' => 'bishiyar kirsimati',
    '🎆' => 'wasan wuta',
    '🎇' => 'na’urar sa wuta a gas',
    '🧨' => 'mai ƙyalƙyalin wuta',
    '✨' => 'ƙyalƙyalai',
    '🎈' => 'balan-balan',
    '🎉' => 'mai bashewa na biki',
    '🎊' => 'ƙwallon confetti',
    '🎋' => 'bishiyar tanabata',
    '🎍' => 'adon bishiyar pine',
    '🎎' => 'yar tsana Na Japan',
    '🎏' => 'tutar safa',
    '🎐' => 'ƙararrawar ƙarfe ta iska',
    '🎑' => 'bikin kallon wata',
    '🧧' => 'jar ambulan',
    '🎀' => 'ribon',
    '🎁' => 'naɗaɗɗiyar tsaraba',
    '🎗' => 'ribon na tunatarwa',
    '🎟' => 'shigarwa',
    '🎫' => 'tikiti',
    '🎖' => 'medal na soja',
    '🏆' => 'kofi',
    '🏅' => 'medal na wasanni',
    '🥇' => 'medal na farko',
    '🥈' => 'medal na biyu',
    '🥉' => 'medal na uku',
    '⚽' => 'ƙwallon ƙafa',
    '⚾' => 'wasan baseball',
    '🥎' => 'bal ta wasan kirket',
    '🏀' => 'wasan ƙwallon kwando',
    '🏐' => 'wasan ƙwallon raga',
    '🏈' => 'ƙwallon ƙafa na amurka',
    '🏉' => 'ƙwallon ƙafa na rugby',
    '🎾' => 'wasan tanis',
    '🥏' => 'faifai na jifa',
    '🎳' => 'wasan bowling',
    '🏏' => 'wasan kurket',
    '🏑' => 'wasan gora na fili',
    '🏒' => 'wasan gora na ƙanƙara',
    '🥍' => 'wasan lacrosse',
    '🏓' => 'ƙwallon tebur',
    '🏸' => 'ƙwallon gashi',
    '🥊' => 'safar hannu na dambe',
    '🥋' => 'rigar iyawar wasan faɗa',
    '🥅' => 'ragar gol',
    '⛳' => 'tuta a cikin rami',
    '⛸' => 'wasa kan ƙanƙara',
    '🎣' => 'fatsa',
    '🤿' => 'gilashin nutso',
    '🎽' => 'rigar gudu',
    '🎿' => 'wasan skis',
    '🛷' => 'motar kaya kan ƙanƙara',
    '🥌' => 'dutsen wasan curling',
    '🎯' => 'bugawa ta kai tsaye',
    '🪀' => 'zaren yo-yo',
    '🪁' => 'fiffiluwa',
    '🔫' => 'ƙaramar bindiga',
    '🎱' => 'ƙwallon pool 8',
    '🔮' => 'balon kallo',
    '🪄' => 'sandan sihiri',
    '🎮' => 'wasan bidiyo',
    '🕹' => 'abin buga wasa',
    '🎰' => 'na’urar kaya mai karɓin kuɗi',
    '🎲' => 'dayis na wasa',
    '🧩' => 'wasa mai wuyar warwara',
    '🧸' => 'tunkun wasa',
    '🪅' => 'pinata',
    '🪩' => 'ƙwallon madubi',
    '🪆' => 'ƴartsana mai sheƙa',
    '♠' => 'zubin suffa',
    '♥' => 'zubin kubbi',
    '♦' => 'zubin zi',
    '♣' => 'zubin kuri',
    '♟' => 'dara',
    '🃏' => 'joka',
    '🀄' => 'jan daragon na mahjong',
    '🎴' => 'katunan wasa mai fure',
    '🎭' => 'wasan kwaikwayo',
    '🖼' => 'hoto mai firem',
    '🎨' => 'allon mai zane',
    '🧵' => 'zare',
    '🪡' => 'allurar ɗinki',
    '🧶' => 'ƙwallon zare',
    '🪢' => 'ƙulli',
    '👓' => 'gilashin ido',
    '🕶' => 'gilashin rana',
    '🥽' => 'tabarau na ido',
    '🥼' => 'rigar likita',
    '🦺' => 'falmaran ta kariya',
    '👔' => 'taye',
    '👕' => 'ti-shat',
    '👖' => 'jin',
    '🧣' => 'ɗankwali',
    '🧤' => 'safar hannu',
    '🧥' => 'kwat',
    '🧦' => 'safa',
    '👗' => 'riga',
    '👘' => 'rigar kimono',
    '🥻' => 'naɗin sari',
    '🩱' => 'rigar ninƙaya-guda',
    '🩲' => 'ɗan diras',
    '🩳' => 'gajeren wando',
    '👙' => 'kayan bikini',
    '👚' => 'suturar mace',
    '🪭' => 'mafici mai naɗewa',
    '👛' => 'ƙaramar jakar hannu',
    '👜' => 'jakar mata',
    '👝' => 'jaka mara hannu',
    '🛍' => 'jakukkuna sayayya',
    '🎒' => 'jakar baya ta makaranta',
    '🩴' => 'sandal mai maɗauri',
    '👞' => 'takalmin maza',
    '👟' => 'takalmin gudu',
    '🥾' => 'takalmin yawo',
    '🥿' => 'takalmi lebur',
    '👠' => 'takalmi mai doguwar dunduniya',
    '👡' => 'sandal na mata',
    '🩰' => 'takalam rawar ballet',
    '👢' => 'but na mace',
    '🪮' => 'matajin gashi',
    '👑' => 'kambi',
    '👒' => 'hular mace',
    '🎩' => 'shaho',
    '🎓' => 'hular saukar karatu',
    '🧢' => 'hula mai baki',
    '🪖' => 'hular-kwano',
    '⛑' => 'hular kwano na ma’aikacin ceto',
    '📿' => 'cazbi',
    '💄' => 'jan-baki',
    '💍' => 'zobe',
    '💎' => 'lu’ulu’u',
    '🔇' => 'mai magana da aka yiwa shiru',
    '🔈' => 'sifika ƙarfin murya na ƙasa',
    '🔉' => 'sifika matsakaicin ƙarfin murya',
    '🔊' => 'sifika ƙarfin murya na sama',
    '📢' => 'lasifika',
    '📣' => 'bututun ƙara magana',
    '📯' => 'kakaki na gidan waya',
    '🔔' => 'ƙararrawa',
    '🔕' => 'ƙararrawa mai maƙalatu',
    '🎼' => 'alamar raujin kiɗa',
    '🎵' => 'rubutun kiɗa',
    '🎶' => 'rubuce-rubucen kiɗa',
    '🎙' => 'makurofon na sutudiyo',
    '🎚' => 'majanyin lebur',
    '🎛' => 'mamurɗin sarrafa',
    '🎤' => 'makurofon',
    '🎧' => 'mazirorin kunne',
    '📻' => 'rediyo',
    '🎷' => 'mabushi',
    '🎺' => 'kakaki',
    '🪊' => 'algaita',
    '🪗' => 'akodiyon',
    '🎸' => 'jita',
    '🎹' => 'kibod na kiɗa',
    '🎻' => 'goge',
    '🪕' => 'gurmin banjo',
    '🥁' => 'ganga',
    '🪘' => 'doguwar ganga',
    '🪇' => 'kacau-kacau',
    '🪈' => 'sarewa',
    '🪉' => 'abin kiɗa na harp',
    '📱' => 'wayar hannu',
    '📲' => 'wayar hannu tare da kibiya',
    '☎' => 'tarho',
    '📞' => 'kan tarho',
    '📟' => 'na’urar faɗakarwa',
    '📠' => 'injin faks',
    '🔋' => 'batir',
    '🪫' => 'batir ya yi sanyi',
    '🔌' => 'fulogin lantarki',
    '💻' => 'kwamfutar tafi-da-gidanka',
    '🖥' => 'kwamfutar na destof',
    '🖨' => 'na’urar ɗab’i',
    '⌨' => 'kibod',
    '🖱' => 'linzamin kwamfuta',
    '🖲' => 'bal na bin sawu',
    '💽' => 'diskin kwamfuta',
    '💾' => 'diski na floppy',
    '💿' => 'diski na da’ira',
    '📀' => 'faifan dvd',
    '🧮' => 'abakus',
    '🎥' => 'kyamarar fim',
    '🎞' => 'firem-firem na fim',
    '📽' => 'frajekta na fim',
    '🎬' => 'allon nunan wasan fim',
    '📺' => 'talabijan',
    '📷' => 'kyamara',
    '📸' => 'kyamara mai ƙyalla',
    '📹' => 'kyamarar bidiyo',
    '📼' => 'kaset na bidiyo',
    '🔍' => 'gilashi mai ƙara girma mai nunawa hagu',
    '🔎' => 'gilashi mai ƙara girma mai nunawa dama',
    '🕯' => 'kyandir',
    '💡' => 'kwan fitila',
    '🔦' => 'tocila',
    '🏮' => 'jan fitilan takarda',
    '🪔' => 'fitilar diya',
    '📔' => 'littafin rubutu mai sama na ado',
    '📕' => 'rufaffen littafi',
    '📖' => 'buɗaɗɗen littafi',
    '📗' => 'koren littafi',
    '📘' => 'shuɗin littafi',
    '📙' => 'littafi mai ruwan goro',
    '📚' => 'littattafai',
    '📓' => 'littafin rubutu',
    '📒' => 'laja',
    '📃' => 'shafi mai nannaɗi',
    '📜' => 'gungura',
    '📄' => 'shafi mai kallon sama',
    '📰' => 'jarida',
    '🗞' => 'naɗaɗɗiyar jarida',
    '📑' => 'maɓallan ma’ajiyar rubutu',
    '🔖' => 'ma’ajiyar rubutu',
    '🏷' => 'alamar liƙawa',
    '🪙' => 'tsabar kuɗi',
    '💰' => 'jakar kuɗi',
    '🪎' => 'akwatin dukiya',
    '💴' => 'takardar kuɗi na yen',
    '💵' => 'takardar kuɗi na dala',
    '💶' => 'takardar kuɗi na euro',
    '💷' => 'takardar kuɗi na fam',
    '💸' => 'kuɗi mai fikafiki',
    '💳' => 'katin bashi',
    '🧾' => 'rasit',
    '💹' => 'zanen lissafi mai ƙaruwa da yen',
    '✉' => 'ambulo',
    '📧' => 'imel',
    '📨' => 'ambulo mai shigowa',
    '📩' => 'ambulo tare da kibiya',
    '📤' => 'tire na akwatin saƙon gefe',
    '📥' => 'tire na akwatin saƙo',
    '📦' => 'fakiti',
    '📫' => 'rufaffen akwatin saƙo da ɗagaggiyar tuta',
    '📪' => 'rufaffen akwatin saƙo tare tuta ƙasa-ƙasa',
    '📬' => 'buɗaɗɗen akwatin saƙo da ɗagaggiyar tuta',
    '📭' => 'buɗaɗɗen akwatin saƙo tare tuta ƙasa-ƙasa',
    '📮' => 'akwatin wasiƙa',
    '🗳' => 'akwatin ƙuri’a mai ƙuri’a',
    '✏' => 'fensir',
    '✒' => 'baƙin bakin alƙalami',
    '🖋' => 'alƙalamin ruwa',
    '🖊' => 'alƙalami',
    '🖌' => 'buroshin fenti',
    '🖍' => 'fensir mai launi',
    '📝' => 'daftari',
    '💼' => 'jakar hannu',
    '📁' => 'foldar fayil',
    '📂' => 'buɗaɗɗiyar foldar fayil',
    '🗂' => 'masu rabawa fihirisan kati',
    '📅' => 'kalanda',
    '📆' => 'kalanda da aka yage',
    '🗒' => 'littafin rubutu mai lanƙwasawa',
    '🗓' => 'kalanda mai lanƙwasawa',
    '📇' => 'katin fihirisa',
    '📈' => 'zanen-lissafi mai ƙarawa',
    '📉' => 'zanen-lissafi mai ragewa',
    '📊' => 'allon jadawali',
    '📋' => 'allon zane',
    '📌' => 'mai yin maki wuri',
    '📍' => 'kewayen mai yin maki wuri',
    '📎' => 'kilif',
    '🖇' => 'haɗaɗɗen kilif',
    '📏' => 'miƙaƙƙiyar rula',
    '📐' => 'rula na alwatika',
    '✂' => 'almakashi',
    '🗃' => 'akwatin fayil na kati',
    '🗄' => 'kabad na fayil',
    '🗑' => 'kwandon shara',
    '🔒' => 'a kulle',
    '🔓' => 'a buɗe',
    '🔏' => 'a kulle tare da alƙalami',
    '🔐' => 'a kulle da makulli',
    '🔑' => 'makulli',
    '🗝' => 'tsohon makulli',
    '🔨' => 'guduma',
    '🪓' => 'gatari',
    '⛏' => 'diga',
    '⚒' => 'guduma da diga',
    '🛠' => 'gudana da sufana',
    '🗡' => 'wuƙar ƙugu',
    '⚔' => 'haɗaɗɗun takuba',
    '💣' => 'bam',
    '🪃' => 'majefi',
    '🏹' => 'baka da kibiya',
    '🛡' => 'garkuwa',
    '🪚' => 'zarton kafinta',
    '🔧' => 'sufana',
    '🪛' => 'sukurudireba',
    '🔩' => 'noti da ƙusa',
    '⚙' => 'giya',
    '🗜' => 'kayan ɗaurewa',
    '⚖' => 'sikeli',
    '🦯' => 'farar sanda',
    '🔗' => 'mahaɗa',
    '⛓' => 'sarƙoƙi',
    '🪝' => 'ƙugiya',
    '🧰' => 'akwatin kayan aiki',
    '🧲' => 'maganaɗisu',
    '🪜' => 'tsani',
    '🪏' => 'shebur',
    '⚗' => 'tukunyar alembic',
    '🧪' => 'bututun gwaji',
    '🧫' => 'tasar petri',
    '🧬' => 'dna',
    '🔬' => 'madubin kimiyya',
    '🔭' => 'madubin hangen nesa',
    '📡' => 'eriya na kumbo',
    '💉' => 'allura',
    '🩸' => 'ɗigon jini',
    '💊' => 'ƙwaya',
    '🩹' => 'bandeji na liƙawa',
    '🩼' => 'sandar guragu',
    '🩺' => 'maʼunin likita',
    '🩻' => 'hoton x-ray',
    '🚪' => 'ƙofa',
    '🛗' => 'lif',
    '🪞' => 'madubi',
    '🪟' => 'taga',
    '🛏' => 'gado',
    '🛋' => 'kujerar kwance da fitila',
    '🪑' => 'kujera',
    '🚽' => 'ban-ɗaki',
    '🪠' => 'mazuƙin-ruwa',
    '🚿' => 'shawa',
    '🛁' => 'baho',
    '🪤' => 'tarkon ɓera',
    '🪒' => 'reza',
    '🧴' => 'kwalbar man shafawa',
    '🧷' => 'fil na kariya',
    '🧹' => 'tsintsiya',
    '🧺' => 'kwando',
    '🧻' => 'kwakwaron takarda',
    '🪣' => 'bokiti',
    '🧼' => 'sabulu',
    '🫧' => 'kumfa',
    '🪥' => 'burushin haƙori',
    '🧽' => 'soso',
    '🧯' => 'tokar kashe gobara',
    '🛒' => 'amalanke',
    '🚬' => 'sigari',
    '⚰' => 'akwatin gawa',
    '🪦' => 'dutsen rubutun kan kabari',
    '⚱' => 'tukunyar jana’iza',
    '🧿' => 'layar nazar',
    '🪬' => 'alamar hamsa',
    '🗿' => 'sassaƙar moai',
    '🪧' => 'alamar maƙalawa',
    '🪪' => 'katin shaida',
    '🏧' => 'alamar ATM',
    '🚮' => 'alamar shara a cikin bola',
    '🚰' => 'ruwan sha',
    '♿' => 'alamar kujera mai wili',
    '🚹' => 'ɗakin maza',
    '🚺' => 'ɗakin mata',
    '🚻' => 'bayan gida',
    '🚼' => 'alamar jariri',
    '🚾' => 'tukunyar bahaya',
    '🛂' => 'mai duba fasfo',
    '🛃' => 'kwastam',
    '🛄' => 'wajen ɗaukar kaya',
    '🛅' => 'kaya da aka bari',
    '⚠' => 'gargaɗi',
    '🚸' => 'yara masu ƙetare hanya',
    '⛔' => 'ba shiga',
    '🚫' => 'an hana',
    '🚳' => 'an hana ma keke',
    '🚭' => 'ba a shan taba',
    '🚯' => 'ba a zubar da shara',
    '🚱' => 'ruwa mara kyau',
    '🚷' => 'an hana ma masu tafiya a ƙafa',
    '📵' => 'an hana wayoyin hannu',
    '🔞' => 'an hana ga ƙasa da shekara sha takwas',
    '☢' => 'rediyoaktif',
    '☣' => 'mai haɗari ga hallitu',
    '⬆' => 'kibiya sama',
    '↗' => 'kibiyar sama ta dama',
    '➡' => 'kibiya dama',
    '↘' => 'kibiyar ƙasa ta dama',
    '⬇' => 'kibiya ƙasa',
    '↙' => 'kibiyar ƙasa ta hagu',
    '⬅' => 'kibiya hagu',
    '↖' => 'kibiyar sama ta hagu',
    '↕' => 'kibiyar ƙasa ta sama',
    '↔' => 'kibiyar hagu-dama',
    '↩' => 'kibiyar dama mai lanƙwasa ta hagu',
    '↪' => 'kibiyar hagu mai lanƙwasa ta dama',
    '⤴' => 'kibiyar dama mai lanƙwasa ta sama',
    '⤵' => 'kibiyar dama mai lanƙwasa ta ƙasa',
    '🔃' => 'kibiyoyi a tsaye ta hannun dama',
    '🔄' => 'maɓallin kibiyoyi ta hannun hagu',
    '🔙' => 'Kibiya Ta BAYA',
    '🔚' => 'Kibiya Ta ƘARSHE',
    '🔛' => 'Kibiyar A KUNNE!',
    '🔜' => 'Kibiyar BA DA DAƊEWA BA',
    '🔝' => 'Kibiya KAI',
    '🛐' => 'wurin Ibada',
    '⚛' => 'alamar ƙwayar zarra',
    '🕉' => 'alamar om',
    '✡' => 'tauraron Dauda',
    '☸' => 'wilin dharma',
    '☯' => 'alamar yin yang',
    '✝' => 'kuros na latin',
    '☦' => 'kuros na gargajiya',
    '☪' => 'tauroro da hilali',
    '☮' => 'alamar zaman lafiya',
    '🕎' => 'menora',
    '🔯' => 'tauraro mai tsini-shida mai ɗigo',
    '🪯' => 'khanda',
    '♈' => 'Kan rago',
    '♉' => 'Bijimi',
    '♊' => 'Tagwaye',
    '♋' => 'Ƙaguwa ta Falaki',
    '♌' => 'Zaki na Falaki',
    '♍' => 'Budurwa',
    '♎' => 'Maʼauni',
    '♏' => 'Kunama ta Falaki',
    '♐' => 'Baka',
    '♑' => 'Taure',
    '♒' => 'Guga',
    '♓' => 'Kifi na Falaki',
    '⛎' => 'Taurarin Ophiuchus',
    '🔀' => 'maɓallin lale waƙoƙi',
    '🔁' => 'maɓallin maimaitawa',
    '🔂' => 'maɓallin maimaitawa sau ɗaya',
    '▶' => 'maɓallin kaɗa',
    '⏩' => 'maɓallin turawa waƙa gaba',
    '⏭' => 'maɓallin waƙa ta gaba',
    '⏯' => 'maɓallin kaɗa ko dakatar da',
    '◀' => 'maɓallin juyawa baya',
    '⏪' => 'maɓallin juyawa baya mai sauri',
    '⏮' => 'maɓallin waƙa na ƙarshe',
    '🔼' => 'maɓallin sama',
    '⏫' => 'maɓallin sama na sauri',
    '🔽' => 'maɓallin ƙasa',
    '⏬' => 'maɓallin ƙasa na sauri',
    '⏸' => 'maɓallin dakatar da',
    '⏹' => 'maɓallin tsaya',
    '⏺' => 'maɓallin naɗawa',
    '⏏' => 'maɓallin fitarwa',
    '🎦' => 'silima',
    '🔅' => 'maɓallin dushe',
    '🔆' => 'maɓallin haske',
    '📶' => 'sandunan eriya',
    '🛜' => 'hanyar iska',
    '📳' => 'yanayin jijjiga',
    '📴' => 'wayar hannu a kashe',
    '♀' => 'alamar mace',
    '♂' => 'alamar namiji',
    '⚧' => 'alamar mata-maza',
    '✖' => 'riɓanya',
    '➕' => 'tarawa',
    '➖' => 'deɓewa',
    '➗' => 'rabawa',
    '🟰' => 'alamar daidai mai nauyi',
    '♾' => 'rashin iyaka',
    '‼' => 'alamar motsin rai biyu',
    '⁉' => 'alamar motsin rai da tambaya',
    '❓' => 'jar alamar tambaya',
    '❔' => 'farar alamar tambaya',
    '❕' => 'farar alamar motsin rai',
    '❗' => 'jar alamar motsin rai',
    '〰' => 'alamar fid da ma’ana mai igiyar ruwa',
    '💱' => 'musayar kuɗin ƙasa',
    '💲' => 'alamar dala mai kauri',
    '⚕' => 'alamar kula da lafiya',
    '♻' => 'alamar maimaita',
    '⚜' => 'alamar fleur-de-lis',
    '🔱' => 'alamar mashi mai ƙarshe uku',
    '📛' => 'bajon suna',
    '🔰' => 'alama Na Japan don ɗan koyo',
    '⭕' => 'jar daʼira buɗaɗɗiya',
    '✅' => 'alamar zaɓi',
    '☑' => 'akwatin ƙuri’a mai alamar yarda',
    '✔' => 'alamar yarda',
    '❌' => 'alamar kuros',
    '❎' => 'maɓallin alamar kuros',
    '➰' => 'lanƙwasasshen maɗauki',
    '➿' => 'lanƙwasasshen maɗauki biyu',
    '〽' => 'alamar maimaitawar kashi',
    '✳' => 'asterisk mai tsini takwas',
    '✴' => 'tauraro mai tsini takwas',
    '❇' => 'ƙyalƙyali',
    '™' => 'tambarin kamfani',
    '🫟' => 'fantsama',
    '🔠' => 'alamar shigarwar manyan baƙaƙe na latin',
    '🔡' => 'alamar shigarwa ƙananan baƙaƙe na latin',
    '🔢' => 'shigarwar lambobi',
    '🔣' => 'shigarwar alamomi',
    '🔤' => 'shigarwar baƙaƙe na latin',
    '🅰' => 'maɓallin A (irin jini)',
    '🆎' => 'maɓallin AB (irin jini)',
    '🅱' => 'maɓallin B (irin jini)',
    '🆑' => 'maɓallin CL',
    '🆒' => 'maɓallin MAI NI’IMA',
    '🆓' => 'maɓallin KYAUTA',
    'ℹ' => 'bayani',
    '🆔' => 'maɓallin ID',
    'Ⓜ' => 'M da aka saka da’ira',
    '🆕' => 'maɓallin SABO',
    '🆖' => 'maɓallin NG',
    '🅾' => 'maɓallin O (irin jini)',
    '🆗' => 'maɓallin TO',
    '🅿' => 'maɓallin P',
    '🆘' => 'maɓallin SOS',
    '🆙' => 'maɓalli na SAMA!',
    '🆚' => 'maɓallin VS',
    '🈁' => 'maɓallin "a nan" Na Japan',
    '🈂' => 'maɓallin "cajin aiki" Na Japan',
    '🈷' => 'maɓallin "kuɗin wata-wata" Na Japan',
    '🈶' => 'maɓallin "ba kyauta ba" Na Japan',
    '🈯' => 'maɓallin "ƙayyadadde" Na Japan',
    '🉐' => 'maɓallin "ciniki" Na Japan',
    '🈹' => 'maɓallin "rangwame" Na Japan',
    '🈚' => 'maɓallin "kyauta" Na Japan',
    '🈲' => 'maɓallin "an hana" Na Japan',
    '🉑' => 'maɓallin "wanda ake yarda da" Na Japan',
    '🈸' => 'maɓallin "buƙata" Na Japan',
    '🈴' => 'maɓallin "yarjejeniya" Na Japan',
    '🈳' => 'maɓallin "mara komai" Na Japan',
    '㊗' => 'maɓallin "murna" Na Japan',
    '㊙' => 'maɓallin "asiri" Na Japan',
    '🈺' => 'maɓallin "a buɗe don kasuwanci" Na Japan',
    '🈵' => 'maɓallin "a cike" Na Japan',
    '🔴' => 'jar da’ira',
    '🟠' => 'daʼira ruwan lemo',
    '🟡' => 'daʼira rawaya',
    '🟢' => 'daʼira kore',
    '🔵' => 'shuɗin da’ira',
    '🟣' => 'daʼira launin shuni',
    '🟤' => 'daʼira ruwan ƙasa',
    '⚫' => 'baƙin da’ira',
    '⚪' => 'farin da’ira',
    '🟥' => 'jan murabbaʼi',
    '🟧' => 'ruwan lemo murabbaʼi',
    '🟨' => 'rawaya murabbaʼi',
    '🟩' => 'koren murabbaʼi',
    '🟦' => 'shuɗi murabbaʼi',
    '🟪' => 'ruwan shuni murabbaʼi',
    '🟫' => 'ruwan ƙasa murabbaʼi',
    '⬛' => 'baƙin babban murabba’i',
    '⬜' => 'farin babban murabba’i',
    '◼' => 'baƙin matsakaicin murabba’i',
    '◻' => 'farin matsakaicin murabba’i',
    '◾' => 'baƙin matsakaicin-ƙaramin murabba’i',
    '◽' => 'farin matsakaicin-ƙaramin murabba’i',
    '▪' => 'baƙin ƙaramin murabba’i',
    '▫' => 'farin ƙaramin murabba’i',
    '🔶' => 'babban daimun na ruwan goro',
    '🔷' => 'babban daimun na shuɗi',
    '🔸' => 'ƙaramin diamun na ruwan goro',
    '🔹' => 'ƙaramin diamun na shuɗi',
    '🔺' => 'jan alwatika mai nunawa sama',
    '🔻' => 'jan alwatika mai nunawa ƙasa',
    '💠' => 'daimun tare da ɗigo',
    '🔘' => 'maɓallin rediyo',
    '🔳' => 'maɓallin farin murabba’i',
    '🔲' => 'maɓallin baƙin murabba’i',
    '🏁' => 'tuta mai alamar murabba’i',
    '🚩' => 'tuta na alwatika',
    '🎌' => 'haɗaɗɗun tutoci',
    '🏴' => 'baƙar tuta',
    '🏳' => 'farar tuta',
];
