<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'целувка: възрастен, възрастен, светла кожа, средно светла кожа',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'целувка: възрастен, възрастен, светла кожа, средна на цвят кожа',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'целувка: възрастен, възрастен, светла кожа, средно тъмна кожа',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'целувка: възрастен, възрастен, светла кожа, тъмна кожа',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'целувка: възрастен, възрастен, средно светла кожа, светла кожа',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'целувка: възрастен, възрастен, средно светла кожа, средна на цвят кожа',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'целувка: възрастен, възрастен, средно светла кожа, средно тъмна кожа',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'целувка: възрастен, възрастен, средно светла кожа, тъмна кожа',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'целувка: възрастен, възрастен, средна на цвят кожа, светла кожа',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'целувка: възрастен, възрастен, средна на цвят кожа, средно светла кожа',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'целувка: възрастен, възрастен, средна на цвят кожа, средно тъмна кожа',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'целувка: възрастен, възрастен, средна на цвят кожа, тъмна кожа',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'целувка: възрастен, възрастен, средно тъмна кожа, светла кожа',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'целувка: възрастен, възрастен, средно тъмна кожа, средно светла кожа',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'целувка: възрастен, възрастен, средно тъмна кожа, средна на цвят кожа',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'целувка: възрастен, възрастен, средно тъмна кожа, тъмна кожа',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'целувка: възрастен, възрастен, тъмна кожа, светла кожа',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'целувка: възрастен, възрастен, тъмна кожа, средно светла кожа',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'целувка: възрастен, възрастен, тъмна кожа, средна на цвят кожа',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'целувка: възрастен, възрастен, тъмна кожа, средно тъмна кожа',
    '👨🏻‍❤‍💋‍👨🏻' => 'целувка: мъж, мъж, светла кожа',
    '👨🏻‍❤‍💋‍👨🏼' => 'целувка: мъж, мъж, светла кожа, средно светла кожа',
    '👨🏻‍❤‍💋‍👨🏽' => 'целувка: мъж, мъж, светла кожа, средна на цвят кожа',
    '👨🏻‍❤‍💋‍👨🏾' => 'целувка: мъж, мъж, светла кожа, средно тъмна кожа',
    '👨🏻‍❤‍💋‍👨🏿' => 'целувка: мъж, мъж, светла кожа, тъмна кожа',
    '👨🏼‍❤‍💋‍👨🏻' => 'целувка: мъж, мъж, средно светла кожа, светла кожа',
    '👨🏼‍❤‍💋‍👨🏼' => 'целувка: мъж, мъж, средно светла кожа',
    '👨🏼‍❤‍💋‍👨🏽' => 'целувка: мъж, мъж, средно светла кожа, средна на цвят кожа',
    '👨🏼‍❤‍💋‍👨🏾' => 'целувка: мъж, мъж, средно светла кожа, средно тъмна кожа',
    '👨🏼‍❤‍💋‍👨🏿' => 'целувка: мъж, мъж, средно светла кожа, тъмна кожа',
    '👨🏽‍❤‍💋‍👨🏻' => 'целувка: мъж, мъж, средна на цвят кожа, светла кожа',
    '👨🏽‍❤‍💋‍👨🏼' => 'целувка: мъж, мъж, средна на цвят кожа, средно светла кожа',
    '👨🏽‍❤‍💋‍👨🏽' => 'целувка: мъж, мъж, средна на цвят кожа',
    '👨🏽‍❤‍💋‍👨🏾' => 'целувка: мъж, мъж, средна на цвят кожа, средно тъмна кожа',
    '👨🏽‍❤‍💋‍👨🏿' => 'целувка: мъж, мъж, средна на цвят кожа, тъмна кожа',
    '👨🏾‍❤‍💋‍👨🏻' => 'целувка: мъж, мъж, средно тъмна кожа, светла кожа',
    '👨🏾‍❤‍💋‍👨🏼' => 'целувка: мъж, мъж, средно тъмна кожа, средно светла кожа',
    '👨🏾‍❤‍💋‍👨🏽' => 'целувка: мъж, мъж, средно тъмна кожа, средна на цвят кожа',
    '👨🏾‍❤‍💋‍👨🏾' => 'целувка: мъж, мъж, средно тъмна кожа',
    '👨🏾‍❤‍💋‍👨🏿' => 'целувка: мъж, мъж, средно тъмна кожа, тъмна кожа',
    '👨🏿‍❤‍💋‍👨🏻' => 'целувка: мъж, мъж, тъмна кожа, светла кожа',
    '👨🏿‍❤‍💋‍👨🏼' => 'целувка: мъж, мъж, тъмна кожа, средно светла кожа',
    '👨🏿‍❤‍💋‍👨🏽' => 'целувка: мъж, мъж, тъмна кожа, средна на цвят кожа',
    '👨🏿‍❤‍💋‍👨🏾' => 'целувка: мъж, мъж, тъмна кожа, средно тъмна кожа',
    '👨🏿‍❤‍💋‍👨🏿' => 'целувка: мъж, мъж, тъмна кожа',
    '👩🏻‍❤‍💋‍👨🏻' => 'целувка: жена, мъж, светла кожа',
    '👩🏻‍❤‍💋‍👨🏼' => 'целувка: жена, мъж, светла кожа, средно светла кожа',
    '👩🏻‍❤‍💋‍👨🏽' => 'целувка: жена, мъж, светла кожа, средна на цвят кожа',
    '👩🏻‍❤‍💋‍👨🏾' => 'целувка: жена, мъж, светла кожа, средно тъмна кожа',
    '👩🏻‍❤‍💋‍👨🏿' => 'целувка: жена, мъж, светла кожа, тъмна кожа',
    '👩🏼‍❤‍💋‍👨🏻' => 'целувка: жена, мъж, средно светла кожа, светла кожа',
    '👩🏼‍❤‍💋‍👨🏼' => 'целувка: жена, мъж, средно светла кожа',
    '👩🏼‍❤‍💋‍👨🏽' => 'целувка: жена, мъж, средно светла кожа, средна на цвят кожа',
    '👩🏼‍❤‍💋‍👨🏾' => 'целувка: жена, мъж, средно светла кожа, средно тъмна кожа',
    '👩🏼‍❤‍💋‍👨🏿' => 'целувка: жена, мъж, средно светла кожа, тъмна кожа',
    '👩🏽‍❤‍💋‍👨🏻' => 'целувка: жена, мъж, средна на цвят кожа, светла кожа',
    '👩🏽‍❤‍💋‍👨🏼' => 'целувка: жена, мъж, средна на цвят кожа, средно светла кожа',
    '👩🏽‍❤‍💋‍👨🏽' => 'целувка: жена, мъж, средна на цвят кожа',
    '👩🏽‍❤‍💋‍👨🏾' => 'целувка: жена, мъж, средна на цвят кожа, средно тъмна кожа',
    '👩🏽‍❤‍💋‍👨🏿' => 'целувка: жена, мъж, средна на цвят кожа, тъмна кожа',
    '👩🏾‍❤‍💋‍👨🏻' => 'целувка: жена, мъж, средно тъмна кожа, светла кожа',
    '👩🏾‍❤‍💋‍👨🏼' => 'целувка: жена, мъж, средно тъмна кожа, средно светла кожа',
    '👩🏾‍❤‍💋‍👨🏽' => 'целувка: жена, мъж, средно тъмна кожа, средна на цвят кожа',
    '👩🏾‍❤‍💋‍👨🏾' => 'целувка: жена, мъж, средно тъмна кожа',
    '👩🏾‍❤‍💋‍👨🏿' => 'целувка: жена, мъж, средно тъмна кожа, тъмна кожа',
    '👩🏿‍❤‍💋‍👨🏻' => 'целувка: жена, мъж, тъмна кожа, светла кожа',
    '👩🏿‍❤‍💋‍👨🏼' => 'целувка: жена, мъж, тъмна кожа, средно светла кожа',
    '👩🏿‍❤‍💋‍👨🏽' => 'целувка: жена, мъж, тъмна кожа, средна на цвят кожа',
    '👩🏿‍❤‍💋‍👨🏾' => 'целувка: жена, мъж, тъмна кожа, средно тъмна кожа',
    '👩🏿‍❤‍💋‍👨🏿' => 'целувка: жена, мъж, тъмна кожа',
    '👩🏻‍❤‍💋‍👩🏻' => 'целувка: жена, жена, светла кожа',
    '👩🏻‍❤‍💋‍👩🏼' => 'целувка: жена, жена, светла кожа, средно светла кожа',
    '👩🏻‍❤‍💋‍👩🏽' => 'целувка: жена, жена, светла кожа, средна на цвят кожа',
    '👩🏻‍❤‍💋‍👩🏾' => 'целувка: жена, жена, светла кожа, средно тъмна кожа',
    '👩🏻‍❤‍💋‍👩🏿' => 'целувка: жена, жена, светла кожа, тъмна кожа',
    '👩🏼‍❤‍💋‍👩🏻' => 'целувка: жена, жена, средно светла кожа, светла кожа',
    '👩🏼‍❤‍💋‍👩🏼' => 'целувка: жена, жена, средно светла кожа',
    '👩🏼‍❤‍💋‍👩🏽' => 'целувка: жена, жена, средно светла кожа, средна на цвят кожа',
    '👩🏼‍❤‍💋‍👩🏾' => 'целувка: жена, жена, средно светла кожа, средно тъмна кожа',
    '👩🏼‍❤‍💋‍👩🏿' => 'целувка: жена, жена, средно светла кожа, тъмна кожа',
    '👩🏽‍❤‍💋‍👩🏻' => 'целувка: жена, жена, средна на цвят кожа, светла кожа',
    '👩🏽‍❤‍💋‍👩🏼' => 'целувка: жена, жена, средна на цвят кожа, средно светла кожа',
    '👩🏽‍❤‍💋‍👩🏽' => 'целувка: жена, жена, средна на цвят кожа',
    '👩🏽‍❤‍💋‍👩🏾' => 'целувка: жена, жена, средна на цвят кожа, средно тъмна кожа',
    '👩🏽‍❤‍💋‍👩🏿' => 'целувка: жена, жена, средна на цвят кожа, тъмна кожа',
    '👩🏾‍❤‍💋‍👩🏻' => 'целувка: жена, жена, средно тъмна кожа, светла кожа',
    '👩🏾‍❤‍💋‍👩🏼' => 'целувка: жена, жена, средно тъмна кожа, средно светла кожа',
    '👩🏾‍❤‍💋‍👩🏽' => 'целувка: жена, жена, средно тъмна кожа, средна на цвят кожа',
    '👩🏾‍❤‍💋‍👩🏾' => 'целувка: жена, жена, средно тъмна кожа',
    '👩🏾‍❤‍💋‍👩🏿' => 'целувка: жена, жена, средно тъмна кожа, тъмна кожа',
    '👩🏿‍❤‍💋‍👩🏻' => 'целувка: жена, жена, тъмна кожа, светла кожа',
    '👩🏿‍❤‍💋‍👩🏼' => 'целувка: жена, жена, тъмна кожа, средно светла кожа',
    '👩🏿‍❤‍💋‍👩🏽' => 'целувка: жена, жена, тъмна кожа, средна на цвят кожа',
    '👩🏿‍❤‍💋‍👩🏾' => 'целувка: жена, жена, тъмна кожа, средно тъмна кожа',
    '👩🏿‍❤‍💋‍👩🏿' => 'целувка: жена, жена, тъмна кожа',
    '🧑🏻‍🫯‍🧑🏼' => 'борци: светла кожа и средно светла кожа',
    '🧑🏻‍🫯‍🧑🏽' => 'борци: светла кожа и средна на цвят кожа',
    '🧑🏻‍🫯‍🧑🏾' => 'борци: светла кожа и средно тъмна кожа',
    '🧑🏻‍🫯‍🧑🏿' => 'борци: светла кожа и тъмна кожа',
    '🧑🏼‍🫯‍🧑🏻' => 'борци: средно светла кожа и светла кожа',
    '🧑🏼‍🫯‍🧑🏽' => 'борци: средно светла кожа и средна на цвят кожа',
    '🧑🏼‍🫯‍🧑🏾' => 'борци: средно светла кожа и средно тъмна кожа',
    '🧑🏼‍🫯‍🧑🏿' => 'борци: средно светла кожа и тъмна кожа',
    '🧑🏽‍🫯‍🧑🏻' => 'борци: средна на цвят кожа и светла кожа',
    '🧑🏽‍🫯‍🧑🏼' => 'борци: средна на цвят кожа и средно светла кожа',
    '🧑🏽‍🫯‍🧑🏾' => 'борци: средна на цвят кожа и средно тъмна кожа',
    '🧑🏽‍🫯‍🧑🏿' => 'борци: средна на цвят кожа и тъмна кожа',
    '🧑🏾‍🫯‍🧑🏻' => 'борци: средно тъмна кожа и светла кожа',
    '🧑🏾‍🫯‍🧑🏼' => 'борци: средно тъмна кожа и средно светла кожа',
    '🧑🏾‍🫯‍🧑🏽' => 'борци: средно тъмна кожа и средна на цвят кожа',
    '🧑🏾‍🫯‍🧑🏿' => 'борци: средно тъмна кожа и тъмна кожа',
    '🧑🏿‍🫯‍🧑🏻' => 'борци: тъмна кожа и светла кожа',
    '🧑🏿‍🫯‍🧑🏼' => 'борци: тъмна кожа и средно светла кожа',
    '🧑🏿‍🫯‍🧑🏽' => 'борци: тъмна кожа и средна на цвят кожа',
    '🧑🏿‍🫯‍🧑🏾' => 'борци: тъмна кожа и средно тъмна кожа',
    '🧑🏻‍❤‍🧑🏼' => 'Двойка и сърце: възрастен, възрастен, светла кожа, средно светла кожа',
    '🧑🏻‍❤‍🧑🏽' => 'Двойка и сърце: възрастен, възрастен, светла кожа, средна на цвят кожа',
    '🧑🏻‍❤‍🧑🏾' => 'Двойка и сърце: възрастен, възрастен, светла кожа, средно тъмна кожа',
    '🧑🏻‍❤‍🧑🏿' => 'Двойка и сърце: възрастен, възрастен, светла кожа, тъмна кожа',
    '🧑🏼‍❤‍🧑🏻' => 'Двойка и сърце: възрастен, възрастен, средно светла кожа, светла кожа',
    '🧑🏼‍❤‍🧑🏽' => 'Двойка и сърце: възрастен, възрастен, средно светла кожа, средна на цвят кожа',
    '🧑🏼‍❤‍🧑🏾' => 'Двойка и сърце: възрастен, възрастен, средно светла кожа, средно тъмна кожа',
    '🧑🏼‍❤‍🧑🏿' => 'Двойка и сърце: възрастен, възрастен, средно светла кожа, тъмна кожа',
    '🧑🏽‍❤‍🧑🏻' => 'Двойка и сърце: възрастен, възрастен, средна на цвят кожа, светла кожа',
    '🧑🏽‍❤‍🧑🏼' => 'Двойка и сърце: възрастен, възрастен, средна на цвят кожа, средно светла кожа',
    '🧑🏽‍❤‍🧑🏾' => 'Двойка и сърце: възрастен, възрастен, средна на цвят кожа, средно тъмна кожа',
    '🧑🏽‍❤‍🧑🏿' => 'Двойка и сърце: възрастен, възрастен, средна на цвят кожа, тъмна кожа',
    '🧑🏾‍❤‍🧑🏻' => 'Двойка и сърце: възрастен, възрастен, средно тъмна кожа, светла кожа',
    '🧑🏾‍❤‍🧑🏼' => 'Двойка и сърце: възрастен, възрастен, средно тъмна кожа, средно светла кожа',
    '🧑🏾‍❤‍🧑🏽' => 'Двойка и сърце: възрастен, възрастен, средно тъмна кожа, средна на цвят кожа',
    '🧑🏾‍❤‍🧑🏿' => 'Двойка и сърце: възрастен, възрастен, средно тъмна кожа, тъмна кожа',
    '🧑🏿‍❤‍🧑🏻' => 'Двойка и сърце: възрастен, възрастен, тъмна кожа, светла кожа',
    '🧑🏿‍❤‍🧑🏼' => 'Двойка и сърце: възрастен, възрастен, тъмна кожа, средно светла кожа',
    '🧑🏿‍❤‍🧑🏽' => 'Двойка и сърце: възрастен, възрастен, тъмна кожа, средна на цвят кожа',
    '🧑🏿‍❤‍🧑🏾' => 'Двойка и сърце: възрастен, възрастен, тъмна кожа, средно тъмна кожа',
    '🧑🏻‍🐰‍🧑🏼' => 'забавляващи се хора: светла кожа и средно светла кожа',
    '🧑🏻‍🐰‍🧑🏽' => 'забавляващи се хора: светла кожа и средна на цвят кожа',
    '🧑🏻‍🐰‍🧑🏾' => 'забавляващи се хора: светла кожа и средно тъмна кожа',
    '🧑🏻‍🐰‍🧑🏿' => 'забавляващи се хора: светла кожа и тъмна кожа',
    '🧑🏼‍🐰‍🧑🏻' => 'забавляващи се хора: средно светла кожа и светла кожа',
    '🧑🏼‍🐰‍🧑🏽' => 'забавляващи се хора: средно светла кожа и средна на цвят кожа',
    '🧑🏼‍🐰‍🧑🏾' => 'забавляващи се хора: средно светла кожа и средно тъмна кожа',
    '🧑🏼‍🐰‍🧑🏿' => 'забавляващи се хора: средно светла кожа и тъмна кожа',
    '🧑🏽‍🐰‍🧑🏻' => 'забавляващи се хора: средна на цвят кожа и светла кожа',
    '🧑🏽‍🐰‍🧑🏼' => 'забавляващи се хора: средна на цвят кожа и средно светла кожа',
    '🧑🏽‍🐰‍🧑🏾' => 'забавляващи се хора: средна на цвят кожа и средно тъмна кожа',
    '🧑🏽‍🐰‍🧑🏿' => 'забавляващи се хора: средна на цвят кожа и тъмна кожа',
    '🧑🏾‍🐰‍🧑🏻' => 'забавляващи се хора: средно тъмна кожа и светла кожа',
    '🧑🏾‍🐰‍🧑🏼' => 'забавляващи се хора: средно тъмна кожа и средно светла кожа',
    '🧑🏾‍🐰‍🧑🏽' => 'забавляващи се хора: средно тъмна кожа и средна на цвят кожа',
    '🧑🏾‍🐰‍🧑🏿' => 'забавляващи се хора: средно тъмна кожа и тъмна кожа',
    '🧑🏿‍🐰‍🧑🏻' => 'забавляващи се хора: тъмна кожа и светла кожа',
    '🧑🏿‍🐰‍🧑🏼' => 'забавляващи се хора: тъмна кожа и средно светла кожа',
    '🧑🏿‍🐰‍🧑🏽' => 'забавляващи се хора: тъмна кожа и средна на цвят кожа',
    '🧑🏿‍🐰‍🧑🏾' => 'забавляващи се хора: тъмна кожа и средно тъмна кожа',
    '👨🏻‍🫯‍👨🏼' => 'борещи се мъже: светла кожа и средно светла кожа',
    '👨🏻‍🫯‍👨🏽' => 'борещи се мъже: светла кожа и средна на цвят кожа',
    '👨🏻‍🫯‍👨🏾' => 'борещи се мъже: светла кожа и средно тъмна кожа',
    '👨🏻‍🫯‍👨🏿' => 'борещи се мъже: светла кожа и тъмна кожа',
    '👨🏼‍🫯‍👨🏻' => 'борещи се мъже: средно светла кожа и светла кожа',
    '👨🏼‍🫯‍👨🏽' => 'борещи се мъже: средно светла кожа и средна на цвят кожа',
    '👨🏼‍🫯‍👨🏾' => 'борещи се мъже: средно светла кожа и средно тъмна кожа',
    '👨🏼‍🫯‍👨🏿' => 'борещи се мъже: средно светла кожа и тъмна кожа',
    '👨🏽‍🫯‍👨🏻' => 'борещи се мъже: средна на цвят кожа и светла кожа',
    '👨🏽‍🫯‍👨🏼' => 'борещи се мъже: средна на цвят кожа и средно светла кожа',
    '👨🏽‍🫯‍👨🏾' => 'борещи се мъже: средна на цвят кожа и средно тъмна кожа',
    '👨🏽‍🫯‍👨🏿' => 'борещи се мъже: средна на цвят кожа и тъмна кожа',
    '👨🏾‍🫯‍👨🏻' => 'борещи се мъже: средно тъмна кожа и светла кожа',
    '👨🏾‍🫯‍👨🏼' => 'борещи се мъже: средно тъмна кожа и средно светла кожа',
    '👨🏾‍🫯‍👨🏽' => 'борещи се мъже: средно тъмна кожа и средна на цвят кожа',
    '👨🏾‍🫯‍👨🏿' => 'борещи се мъже: средно тъмна кожа и тъмна кожа',
    '👨🏿‍🫯‍👨🏻' => 'борещи се мъже: тъмна кожа и светла кожа',
    '👨🏿‍🫯‍👨🏼' => 'борещи се мъже: тъмна кожа и средно светла кожа',
    '👨🏿‍🫯‍👨🏽' => 'борещи се мъже: тъмна кожа и средна на цвят кожа',
    '👨🏿‍🫯‍👨🏾' => 'борещи се мъже: тъмна кожа и средно тъмна кожа',
    '👨🏻‍❤‍👨🏻' => 'Двойка и сърце: мъж, мъж, светла кожа',
    '👨🏻‍❤‍👨🏼' => 'Двойка и сърце: мъж, мъж, светла кожа, средно светла кожа',
    '👨🏻‍❤‍👨🏽' => 'Двойка и сърце: мъж, мъж, светла кожа, средна на цвят кожа',
    '👨🏻‍❤‍👨🏾' => 'Двойка и сърце: мъж, мъж, светла кожа, средно тъмна кожа',
    '👨🏻‍❤‍👨🏿' => 'Двойка и сърце: мъж, мъж, светла кожа, тъмна кожа',
    '👨🏼‍❤‍👨🏻' => 'Двойка и сърце: мъж, мъж, средно светла кожа, светла кожа',
    '👨🏼‍❤‍👨🏼' => 'Двойка и сърце: мъж, мъж, средно светла кожа',
    '👨🏼‍❤‍👨🏽' => 'Двойка и сърце: мъж, мъж, средно светла кожа, средна на цвят кожа',
    '👨🏼‍❤‍👨🏾' => 'Двойка и сърце: мъж, мъж, средно светла кожа, средно тъмна кожа',
    '👨🏼‍❤‍👨🏿' => 'Двойка и сърце: мъж, мъж, средно светла кожа, тъмна кожа',
    '👨🏽‍❤‍👨🏻' => 'Двойка и сърце: мъж, мъж, средна на цвят кожа, светла кожа',
    '👨🏽‍❤‍👨🏼' => 'Двойка и сърце: мъж, мъж, средна на цвят кожа, средно светла кожа',
    '👨🏽‍❤‍👨🏽' => 'Двойка и сърце: мъж, мъж, средна на цвят кожа',
    '👨🏽‍❤‍👨🏾' => 'Двойка и сърце: мъж, мъж, средна на цвят кожа, средно тъмна кожа',
    '👨🏽‍❤‍👨🏿' => 'Двойка и сърце: мъж, мъж, средна на цвят кожа, тъмна кожа',
    '👨🏾‍❤‍👨🏻' => 'Двойка и сърце: мъж, мъж, средно тъмна кожа, светла кожа',
    '👨🏾‍❤‍👨🏼' => 'Двойка и сърце: мъж, мъж, средно тъмна кожа, средно светла кожа',
    '👨🏾‍❤‍👨🏽' => 'Двойка и сърце: мъж, мъж, средно тъмна кожа, средна на цвят кожа',
    '👨🏾‍❤‍👨🏾' => 'Двойка и сърце: мъж, мъж, средно тъмна кожа',
    '👨🏾‍❤‍👨🏿' => 'Двойка и сърце: мъж, мъж, средно тъмна кожа, тъмна кожа',
    '👨🏿‍❤‍👨🏻' => 'Двойка и сърце: мъж, мъж, тъмна кожа, светла кожа',
    '👨🏿‍❤‍👨🏼' => 'Двойка и сърце: мъж, мъж, тъмна кожа, средно светла кожа',
    '👨🏿‍❤‍👨🏽' => 'Двойка и сърце: мъж, мъж, тъмна кожа, средна на цвят кожа',
    '👨🏿‍❤‍👨🏾' => 'Двойка и сърце: мъж, мъж, тъмна кожа, средно тъмна кожа',
    '👨🏿‍❤‍👨🏿' => 'Двойка и сърце: мъж, мъж, тъмна кожа',
    '👨🏻‍🐰‍👨🏼' => 'веселящи се мъже със заешки уши: светла кожа и средно светла кожа',
    '👨🏻‍🐰‍👨🏽' => 'веселящи се мъже със заешки уши: светла кожа и средна на цвят кожа',
    '👨🏻‍🐰‍👨🏾' => 'веселящи се мъже със заешки уши: светла кожа и средно тъмна кожа',
    '👨🏻‍🐰‍👨🏿' => 'веселящи се мъже със заешки уши: светла кожа и тъмна кожа',
    '👨🏼‍🐰‍👨🏻' => 'веселящи се мъже със заешки уши: средно светла кожа и светла кожа',
    '👨🏼‍🐰‍👨🏽' => 'веселящи се мъже със заешки уши: средно светла кожа и средна на цвят кожа',
    '👨🏼‍🐰‍👨🏾' => 'веселящи се мъже със заешки уши: средно светла кожа и средно тъмна кожа',
    '👨🏼‍🐰‍👨🏿' => 'веселящи се мъже със заешки уши: средно светла кожа и тъмна кожа',
    '👨🏽‍🐰‍👨🏻' => 'веселящи се мъже със заешки уши: средна на цвят кожа и светла кожа',
    '👨🏽‍🐰‍👨🏼' => 'веселящи се мъже със заешки уши: средна на цвят кожа и средно светла кожа',
    '👨🏽‍🐰‍👨🏾' => 'веселящи се мъже със заешки уши: средна на цвят кожа и средно тъмна кожа',
    '👨🏽‍🐰‍👨🏿' => 'веселящи се мъже със заешки уши: средна на цвят кожа и тъмна кожа',
    '👨🏾‍🐰‍👨🏻' => 'веселящи се мъже със заешки уши: средно тъмна кожа и светла кожа',
    '👨🏾‍🐰‍👨🏼' => 'веселящи се мъже със заешки уши: средно тъмна кожа и средно светла кожа',
    '👨🏾‍🐰‍👨🏽' => 'веселящи се мъже със заешки уши: средно тъмна кожа и средна на цвят кожа',
    '👨🏾‍🐰‍👨🏿' => 'веселящи се мъже със заешки уши: средно тъмна кожа и тъмна кожа',
    '👨🏿‍🐰‍👨🏻' => 'веселящи се мъже със заешки уши: тъмна кожа и светла кожа',
    '👨🏿‍🐰‍👨🏼' => 'веселящи се мъже със заешки уши: тъмна кожа и средно светла кожа',
    '👨🏿‍🐰‍👨🏽' => 'веселящи се мъже със заешки уши: тъмна кожа и средна на цвят кожа',
    '👨🏿‍🐰‍👨🏾' => 'веселящи се мъже със заешки уши: тъмна кожа и средно тъмна кожа',
    '👩🏻‍🫯‍👩🏼' => 'борещи се жени: светла кожа и средно светла кожа',
    '👩🏻‍🫯‍👩🏽' => 'борещи се жени: светла кожа и средна на цвят кожа',
    '👩🏻‍🫯‍👩🏾' => 'борещи се жени: светла кожа и средно тъмна кожа',
    '👩🏻‍🫯‍👩🏿' => 'борещи се жени: светла кожа и тъмна кожа',
    '👩🏼‍🫯‍👩🏻' => 'борещи се жени: средно светла кожа и светла кожа',
    '👩🏼‍🫯‍👩🏽' => 'борещи се жени: средно светла кожа и средна на цвят кожа',
    '👩🏼‍🫯‍👩🏾' => 'борещи се жени: средно светла кожа и средно тъмна кожа',
    '👩🏼‍🫯‍👩🏿' => 'борещи се жени: средно светла кожа и тъмна кожа',
    '👩🏽‍🫯‍👩🏻' => 'борещи се жени: средна на цвят кожа и светла кожа',
    '👩🏽‍🫯‍👩🏼' => 'борещи се жени: средна на цвят кожа и средно светла кожа',
    '👩🏽‍🫯‍👩🏾' => 'борещи се жени: средна на цвят кожа и средно тъмна кожа',
    '👩🏽‍🫯‍👩🏿' => 'борещи се жени: средна на цвят кожа и тъмна кожа',
    '👩🏾‍🫯‍👩🏻' => 'борещи се жени: средно тъмна кожа и светла кожа',
    '👩🏾‍🫯‍👩🏼' => 'борещи се жени: средно тъмна кожа и средно светла кожа',
    '👩🏾‍🫯‍👩🏽' => 'борещи се жени: средно тъмна кожа и средна на цвят кожа',
    '👩🏾‍🫯‍👩🏿' => 'борещи се жени: средно тъмна кожа и тъмна кожа',
    '👩🏿‍🫯‍👩🏻' => 'борещи се жени: тъмна кожа и светла кожа',
    '👩🏿‍🫯‍👩🏼' => 'борещи се жени: тъмна кожа и средно светла кожа',
    '👩🏿‍🫯‍👩🏽' => 'борещи се жени: тъмна кожа и средна на цвят кожа',
    '👩🏿‍🫯‍👩🏾' => 'борещи се жени: тъмна кожа и средно тъмна кожа',
    '👩🏻‍❤‍👨🏻' => 'Двойка и сърце: жена, мъж, светла кожа',
    '👩🏻‍❤‍👨🏼' => 'Двойка и сърце: жена, мъж, светла кожа, средно светла кожа',
    '👩🏻‍❤‍👨🏽' => 'Двойка и сърце: жена, мъж, светла кожа, средна на цвят кожа',
    '👩🏻‍❤‍👨🏾' => 'Двойка и сърце: жена, мъж, светла кожа, средно тъмна кожа',
    '👩🏻‍❤‍👨🏿' => 'Двойка и сърце: жена, мъж, светла кожа, тъмна кожа',
    '👩🏼‍❤‍👨🏻' => 'Двойка и сърце: жена, мъж, средно светла кожа, светла кожа',
    '👩🏼‍❤‍👨🏼' => 'Двойка и сърце: жена, мъж, средно светла кожа',
    '👩🏼‍❤‍👨🏽' => 'Двойка и сърце: жена, мъж, средно светла кожа, средна на цвят кожа',
    '👩🏼‍❤‍👨🏾' => 'Двойка и сърце: жена, мъж, средно светла кожа, средно тъмна кожа',
    '👩🏼‍❤‍👨🏿' => 'Двойка и сърце: жена, мъж, средно светла кожа, тъмна кожа',
    '👩🏽‍❤‍👨🏻' => 'Двойка и сърце: жена, мъж, средна на цвят кожа, светла кожа',
    '👩🏽‍❤‍👨🏼' => 'Двойка и сърце: жена, мъж, средна на цвят кожа, средно светла кожа',
    '👩🏽‍❤‍👨🏽' => 'Двойка и сърце: жена, мъж, средна на цвят кожа',
    '👩🏽‍❤‍👨🏾' => 'Двойка и сърце: жена, мъж, средна на цвят кожа, средно тъмна кожа',
    '👩🏽‍❤‍👨🏿' => 'Двойка и сърце: жена, мъж, средна на цвят кожа, тъмна кожа',
    '👩🏾‍❤‍👨🏻' => 'Двойка и сърце: жена, мъж, средно тъмна кожа, светла кожа',
    '👩🏾‍❤‍👨🏼' => 'Двойка и сърце: жена, мъж, средно тъмна кожа, средно светла кожа',
    '👩🏾‍❤‍👨🏽' => 'Двойка и сърце: жена, мъж, средно тъмна кожа, средна на цвят кожа',
    '👩🏾‍❤‍👨🏾' => 'Двойка и сърце: жена, мъж, средно тъмна кожа',
    '👩🏾‍❤‍👨🏿' => 'Двойка и сърце: жена, мъж, средно тъмна кожа, тъмна кожа',
    '👩🏿‍❤‍👨🏻' => 'Двойка и сърце: жена, мъж, тъмна кожа, светла кожа',
    '👩🏿‍❤‍👨🏼' => 'Двойка и сърце: жена, мъж, тъмна кожа, средно светла кожа',
    '👩🏿‍❤‍👨🏽' => 'Двойка и сърце: жена, мъж, тъмна кожа, средна на цвят кожа',
    '👩🏿‍❤‍👨🏾' => 'Двойка и сърце: жена, мъж, тъмна кожа, средно тъмна кожа',
    '👩🏿‍❤‍👨🏿' => 'Двойка и сърце: жена, мъж, тъмна кожа',
    '👩🏻‍❤‍👩🏻' => 'Двойка и сърце: жена, жена, светла кожа',
    '👩🏻‍❤‍👩🏼' => 'Двойка и сърце: жена, жена, светла кожа, средно светла кожа',
    '👩🏻‍❤‍👩🏽' => 'Двойка и сърце: жена, жена, светла кожа, средна на цвят кожа',
    '👩🏻‍❤‍👩🏾' => 'Двойка и сърце: жена, жена, светла кожа, средно тъмна кожа',
    '👩🏻‍❤‍👩🏿' => 'Двойка и сърце: жена, жена, светла кожа, тъмна кожа',
    '👩🏼‍❤‍👩🏻' => 'Двойка и сърце: жена, жена, средно светла кожа, светла кожа',
    '👩🏼‍❤‍👩🏼' => 'Двойка и сърце: жена, жена, средно светла кожа',
    '👩🏼‍❤‍👩🏽' => 'Двойка и сърце: жена, жена, средно светла кожа, средна на цвят кожа',
    '👩🏼‍❤‍👩🏾' => 'Двойка и сърце: жена, жена, средно светла кожа, средно тъмна кожа',
    '👩🏼‍❤‍👩🏿' => 'Двойка и сърце: жена, жена, средно светла кожа, тъмна кожа',
    '👩🏽‍❤‍👩🏻' => 'Двойка и сърце: жена, жена, средна на цвят кожа, светла кожа',
    '👩🏽‍❤‍👩🏼' => 'Двойка и сърце: жена, жена, средна на цвят кожа, средно светла кожа',
    '👩🏽‍❤‍👩🏽' => 'Двойка и сърце: жена, жена, средна на цвят кожа',
    '👩🏽‍❤‍👩🏾' => 'Двойка и сърце: жена, жена, средна на цвят кожа, средно тъмна кожа',
    '👩🏽‍❤‍👩🏿' => 'Двойка и сърце: жена, жена, средна на цвят кожа, тъмна кожа',
    '👩🏾‍❤‍👩🏻' => 'Двойка и сърце: жена, жена, средно тъмна кожа, светла кожа',
    '👩🏾‍❤‍👩🏼' => 'Двойка и сърце: жена, жена, средно тъмна кожа, средно светла кожа',
    '👩🏾‍❤‍👩🏽' => 'Двойка и сърце: жена, жена, средно тъмна кожа, средна на цвят кожа',
    '👩🏾‍❤‍👩🏾' => 'Двойка и сърце: жена, жена, средно тъмна кожа',
    '👩🏾‍❤‍👩🏿' => 'Двойка и сърце: жена, жена, средно тъмна кожа, тъмна кожа',
    '👩🏿‍❤‍👩🏻' => 'Двойка и сърце: жена, жена, тъмна кожа, светла кожа',
    '👩🏿‍❤‍👩🏼' => 'Двойка и сърце: жена, жена, тъмна кожа, средно светла кожа',
    '👩🏿‍❤‍👩🏽' => 'Двойка и сърце: жена, жена, тъмна кожа, средна на цвят кожа',
    '👩🏿‍❤‍👩🏾' => 'Двойка и сърце: жена, жена, тъмна кожа, средно тъмна кожа',
    '👩🏿‍❤‍👩🏿' => 'Двойка и сърце: жена, жена, тъмна кожа',
    '👩🏻‍🐰‍👩🏼' => 'забавляващи се жени със заешки уши: светла кожа и средно светла кожа',
    '👩🏻‍🐰‍👩🏽' => 'забавляващи се жени със заешки уши: светла кожа и средна на цвят кожа',
    '👩🏻‍🐰‍👩🏾' => 'забавляващи се жени със заешки уши: светла кожа и средно тъмна кожа',
    '👩🏻‍🐰‍👩🏿' => 'забавляващи се жени със заешки уши: светла кожа и тъмна кожа',
    '👩🏼‍🐰‍👩🏻' => 'забавляващи се жени със заешки уши: средно светла кожа и светла кожа',
    '👩🏼‍🐰‍👩🏽' => 'забавляващи се жени със заешки уши: средно светла кожа и средна на цвят кожа',
    '👩🏼‍🐰‍👩🏾' => 'забавляващи се жени със заешки уши: средно светла кожа и средно тъмна кожа',
    '👩🏼‍🐰‍👩🏿' => 'забавляващи се жени със заешки уши: средно светла кожа и тъмна кожа',
    '👩🏽‍🐰‍👩🏻' => 'забавляващи се жени със заешки уши: средна на цвят кожа и светла кожа',
    '👩🏽‍🐰‍👩🏼' => 'забавляващи се жени със заешки уши: средна на цвят кожа и средно светла кожа',
    '👩🏽‍🐰‍👩🏾' => 'забавляващи се жени със заешки уши: средна на цвят кожа и средно тъмна кожа',
    '👩🏽‍🐰‍👩🏿' => 'забавляващи се жени със заешки уши: средна на цвят кожа и тъмна кожа',
    '👩🏾‍🐰‍👩🏻' => 'забавляващи се жени със заешки уши: средно тъмна кожа и светла кожа',
    '👩🏾‍🐰‍👩🏼' => 'забавляващи се жени със заешки уши: средно тъмна кожа и средно светла кожа',
    '👩🏾‍🐰‍👩🏽' => 'забавляващи се жени със заешки уши: средно тъмна кожа и средна на цвят кожа',
    '👩🏾‍🐰‍👩🏿' => 'забавляващи се жени със заешки уши: средно тъмна кожа и тъмна кожа',
    '👩🏿‍🐰‍👩🏻' => 'забавляващи се жени със заешки уши: тъмна кожа и светла кожа',
    '👩🏿‍🐰‍👩🏼' => 'забавляващи се жени със заешки уши: тъмна кожа и средно светла кожа',
    '👩🏿‍🐰‍👩🏽' => 'забавляващи се жени със заешки уши: тъмна кожа и средна на цвят кожа',
    '👩🏿‍🐰‍👩🏾' => 'забавляващи се жени със заешки уши: тъмна кожа и средно тъмна кожа',
    '🧑🏻‍🤝‍🧑🏻' => 'хора, които се държат за ръце: светла кожа',
    '🧑🏻‍🤝‍🧑🏼' => 'хора, които се държат за ръце: светла кожа и средно светла кожа',
    '🧑🏻‍🤝‍🧑🏽' => 'хора, които се държат за ръце: светла кожа и средна на цвят кожа',
    '🧑🏻‍🤝‍🧑🏾' => 'хора, които се държат за ръце: светла кожа и средно тъмна кожа',
    '🧑🏻‍🤝‍🧑🏿' => 'хора, които се държат за ръце: светла кожа и тъмна кожа',
    '🧑🏼‍🤝‍🧑🏻' => 'хора, които се държат за ръце: средно светла кожа и светла кожа',
    '🧑🏼‍🤝‍🧑🏼' => 'хора, които се държат за ръце: средно светла кожа',
    '🧑🏼‍🤝‍🧑🏽' => 'хора, които се държат за ръце: средно светла кожа и средна на цвят кожа',
    '🧑🏼‍🤝‍🧑🏾' => 'хора, които се държат за ръце: средно светла кожа и средно тъмна кожа',
    '🧑🏼‍🤝‍🧑🏿' => 'хора, които се държат за ръце: средно светла кожа и тъмна кожа',
    '🧑🏽‍🤝‍🧑🏻' => 'хора, които се държат за ръце: средна на цвят кожа и светла кожа',
    '🧑🏽‍🤝‍🧑🏼' => 'хора, които се държат за ръце: средна на цвят кожа и средно светла кожа',
    '🧑🏽‍🤝‍🧑🏽' => 'хора, които се държат за ръце: средна на цвят кожа',
    '🧑🏽‍🤝‍🧑🏾' => 'хора, които се държат за ръце: средна на цвят кожа и средно тъмна кожа',
    '🧑🏽‍🤝‍🧑🏿' => 'хора, които се държат за ръце: средна на цвят кожа и тъмна кожа',
    '🧑🏾‍🤝‍🧑🏻' => 'хора, които се държат за ръце: средно тъмна кожа и светла кожа',
    '🧑🏾‍🤝‍🧑🏼' => 'хора, които се държат за ръце: средно тъмна кожа и средно светла кожа',
    '🧑🏾‍🤝‍🧑🏽' => 'хора, които се държат за ръце: средно тъмна кожа и средна на цвят кожа',
    '🧑🏾‍🤝‍🧑🏾' => 'хора, които се държат за ръце: средно тъмна кожа',
    '🧑🏾‍🤝‍🧑🏿' => 'хора, които се държат за ръце: средно тъмна кожа и тъмна кожа',
    '🧑🏿‍🤝‍🧑🏻' => 'хора, които се държат за ръце: тъмна кожа и светла кожа',
    '🧑🏿‍🤝‍🧑🏼' => 'хора, които се държат за ръце: тъмна кожа и средно светла кожа',
    '🧑🏿‍🤝‍🧑🏽' => 'хора, които се държат за ръце: тъмна кожа и средна на цвят кожа',
    '🧑🏿‍🤝‍🧑🏾' => 'хора, които се държат за ръце: тъмна кожа и средно тъмна кожа',
    '🧑🏿‍🤝‍🧑🏿' => 'хора, които се държат за ръце: тъмна кожа',
    '👩🏻‍🤝‍👩🏼' => 'Две жени, държащи се за ръце: светла кожа и средно светла кожа',
    '👩🏻‍🤝‍👩🏽' => 'Две жени, държащи се за ръце: светла кожа и средна на цвят кожа',
    '👩🏻‍🤝‍👩🏾' => 'Две жени, държащи се за ръце: светла кожа и средно тъмна кожа',
    '👩🏻‍🤝‍👩🏿' => 'Две жени, държащи се за ръце: светла кожа и тъмна кожа',
    '👩🏼‍🤝‍👩🏻' => 'Две жени, държащи се за ръце: средно светла кожа и светла кожа',
    '👩🏼‍🤝‍👩🏽' => 'Две жени, държащи се за ръце: средно светла кожа и средна на цвят кожа',
    '👩🏼‍🤝‍👩🏾' => 'Две жени, държащи се за ръце: средно светла кожа и средно тъмна кожа',
    '👩🏼‍🤝‍👩🏿' => 'Две жени, държащи се за ръце: средно светла кожа и тъмна кожа',
    '👩🏽‍🤝‍👩🏻' => 'Две жени, държащи се за ръце: средна на цвят кожа и светла кожа',
    '👩🏽‍🤝‍👩🏼' => 'Две жени, държащи се за ръце: средна на цвят кожа и средно светла кожа',
    '👩🏽‍🤝‍👩🏾' => 'Две жени, държащи се за ръце: средна на цвят кожа и средно тъмна кожа',
    '👩🏽‍🤝‍👩🏿' => 'Две жени, държащи се за ръце: средна на цвят кожа и тъмна кожа',
    '👩🏾‍🤝‍👩🏻' => 'Две жени, държащи се за ръце: средно тъмна кожа и светла кожа',
    '👩🏾‍🤝‍👩🏼' => 'Две жени, държащи се за ръце: средно тъмна кожа и средно светла кожа',
    '👩🏾‍🤝‍👩🏽' => 'Две жени, държащи се за ръце: средно тъмна кожа и средна на цвят кожа',
    '👩🏾‍🤝‍👩🏿' => 'Две жени, държащи се за ръце: средно тъмна кожа и тъмна кожа',
    '👩🏿‍🤝‍👩🏻' => 'Две жени, държащи се за ръце: тъмна кожа и светла кожа',
    '👩🏿‍🤝‍👩🏼' => 'Две жени, държащи се за ръце: тъмна кожа и средно светла кожа',
    '👩🏿‍🤝‍👩🏽' => 'Две жени, държащи се за ръце: тъмна кожа и средна на цвят кожа',
    '👩🏿‍🤝‍👩🏾' => 'Две жени, държащи се за ръце: тъмна кожа и средно тъмна кожа',
    '👩🏻‍🤝‍👨🏼' => 'Мъж и жена, държащи се за ръце: светла кожа и средно светла кожа',
    '👩🏻‍🤝‍👨🏽' => 'Мъж и жена, държащи се за ръце: светла кожа и средна на цвят кожа',
    '👩🏻‍🤝‍👨🏾' => 'Мъж и жена, държащи се за ръце: светла кожа и средно тъмна кожа',
    '👩🏻‍🤝‍👨🏿' => 'Мъж и жена, държащи се за ръце: светла кожа и тъмна кожа',
    '👩🏼‍🤝‍👨🏻' => 'Мъж и жена, държащи се за ръце: средно светла кожа и светла кожа',
    '👩🏼‍🤝‍👨🏽' => 'Мъж и жена, държащи се за ръце: средно светла кожа и средна на цвят кожа',
    '👩🏼‍🤝‍👨🏾' => 'Мъж и жена, държащи се за ръце: средно светла кожа и средно тъмна кожа',
    '👩🏼‍🤝‍👨🏿' => 'Мъж и жена, държащи се за ръце: средно светла кожа и тъмна кожа',
    '👩🏽‍🤝‍👨🏻' => 'Мъж и жена, държащи се за ръце: средна на цвят кожа и светла кожа',
    '👩🏽‍🤝‍👨🏼' => 'Мъж и жена, държащи се за ръце: средна на цвят кожа и средно светла кожа',
    '👩🏽‍🤝‍👨🏾' => 'Мъж и жена, държащи се за ръце: средна на цвят кожа и средно тъмна кожа',
    '👩🏽‍🤝‍👨🏿' => 'Мъж и жена, държащи се за ръце: средна на цвят кожа и тъмна кожа',
    '👩🏾‍🤝‍👨🏻' => 'Мъж и жена, държащи се за ръце: средно тъмна кожа и светла кожа',
    '👩🏾‍🤝‍👨🏼' => 'Мъж и жена, държащи се за ръце: средно тъмна кожа и средно светла кожа',
    '👩🏾‍🤝‍👨🏽' => 'Мъж и жена, държащи се за ръце: средно тъмна кожа и средна на цвят кожа',
    '👩🏾‍🤝‍👨🏿' => 'Мъж и жена, държащи се за ръце: средно тъмна кожа и тъмна кожа',
    '👩🏿‍🤝‍👨🏻' => 'Мъж и жена, държащи се за ръце: тъмна кожа и светла кожа',
    '👩🏿‍🤝‍👨🏼' => 'Мъж и жена, държащи се за ръце: тъмна кожа и средно светла кожа',
    '👩🏿‍🤝‍👨🏽' => 'Мъж и жена, държащи се за ръце: тъмна кожа и средна на цвят кожа',
    '👩🏿‍🤝‍👨🏾' => 'Мъж и жена, държащи се за ръце: тъмна кожа и средно тъмна кожа',
    '👨🏻‍🤝‍👨🏼' => 'Двама мъже, държащи се за ръце: светла кожа и средно светла кожа',
    '👨🏻‍🤝‍👨🏽' => 'Двама мъже, държащи се за ръце: светла кожа и средна на цвят кожа',
    '👨🏻‍🤝‍👨🏾' => 'Двама мъже, държащи се за ръце: светла кожа и средно тъмна кожа',
    '👨🏻‍🤝‍👨🏿' => 'Двама мъже, държащи се за ръце: светла кожа и тъмна кожа',
    '👨🏼‍🤝‍👨🏻' => 'Двама мъже, държащи се за ръце: средно светла кожа и светла кожа',
    '👨🏼‍🤝‍👨🏽' => 'Двама мъже, държащи се за ръце: средно светла кожа и средна на цвят кожа',
    '👨🏼‍🤝‍👨🏾' => 'Двама мъже, държащи се за ръце: средно светла кожа и средно тъмна кожа',
    '👨🏼‍🤝‍👨🏿' => 'Двама мъже, държащи се за ръце: средно светла кожа и тъмна кожа',
    '👨🏽‍🤝‍👨🏻' => 'Двама мъже, държащи се за ръце: средна на цвят кожа и светла кожа',
    '👨🏽‍🤝‍👨🏼' => 'Двама мъже, държащи се за ръце: средна на цвят кожа и средно светла кожа',
    '👨🏽‍🤝‍👨🏾' => 'Двама мъже, държащи се за ръце: средна на цвят кожа и средно тъмна кожа',
    '👨🏽‍🤝‍👨🏿' => 'Двама мъже, държащи се за ръце: средна на цвят кожа и тъмна кожа',
    '👨🏾‍🤝‍👨🏻' => 'Двама мъже, държащи се за ръце: средно тъмна кожа и светла кожа',
    '👨🏾‍🤝‍👨🏼' => 'Двама мъже, държащи се за ръце: средно тъмна кожа и средно светла кожа',
    '👨🏾‍🤝‍👨🏽' => 'Двама мъже, държащи се за ръце: средно тъмна кожа и средна на цвят кожа',
    '👨🏾‍🤝‍👨🏿' => 'Двама мъже, държащи се за ръце: средно тъмна кожа и тъмна кожа',
    '👨🏿‍🤝‍👨🏻' => 'Двама мъже, държащи се за ръце: тъмна кожа и светла кожа',
    '👨🏿‍🤝‍👨🏼' => 'Двама мъже, държащи се за ръце: тъмна кожа и средно светла кожа',
    '👨🏿‍🤝‍👨🏽' => 'Двама мъже, държащи се за ръце: тъмна кожа и средна на цвят кожа',
    '👨🏿‍🤝‍👨🏾' => 'Двама мъже, държащи се за ръце: тъмна кожа и средно тъмна кожа',
    '👩‍❤‍💋‍👨' => 'целувка: жена и мъж',
    '👨‍❤‍💋‍👨' => 'целувка: мъж и мъж',
    '👩‍❤‍💋‍👩' => 'целувка: жена и жена',
    '👨‍👩‍👧‍👦' => 'семейство: мъж, жена, момиче, момче',
    '👨‍👩‍👦‍👦' => 'семейство: мъж, жена, момче, момче',
    '👨‍👩‍👧‍👧' => 'семейство: мъж, жена, момиче, момиче',
    '👨‍👨‍👧‍👦' => 'семейство: мъж, мъж, момиче, момче',
    '👨‍👨‍👦‍👦' => 'семейство: мъж, мъж, момче, момче',
    '👨‍👨‍👧‍👧' => 'семейство: мъж, мъж, момиче, момиче',
    '👩‍👩‍👧‍👦' => 'семейство: жена, жена, момиче, момче',
    '👩‍👩‍👦‍👦' => 'семейство: жена, жена, момче, момче',
    '👩‍👩‍👧‍👧' => 'семейство: жена, жена, момиче, момиче',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'Флаг: Англия',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'Флаг: Шотландия',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'Флаг: Уелс',
    '🧑‍🧑‍🧒‍🧒' => 'семейство: възрастен, възрастен, дете, дете',
    '🚶🏻‍♀‍➡' => 'ходеща жена: светла кожа и в посока надясно',
    '🚶🏼‍♀‍➡' => 'ходеща жена: средно светла кожа и в посока надясно',
    '🚶🏽‍♀‍➡' => 'ходеща жена: средна на цвят кожа и в посока надясно',
    '🚶🏾‍♀‍➡' => 'ходеща жена: средно тъмна кожа и в посока надясно',
    '🚶🏿‍♀‍➡' => 'ходеща жена: тъмна кожа и в посока надясно',
    '🚶🏻‍♂‍➡' => 'ходещ мъж: светла кожа и в посока надясно',
    '🚶🏼‍♂‍➡' => 'ходещ мъж: средно светла кожа и в посока надясно',
    '🚶🏽‍♂‍➡' => 'ходещ мъж: средна на цвят кожа и в посока надясно',
    '🚶🏾‍♂‍➡' => 'ходещ мъж: средно тъмна кожа и в посока надясно',
    '🚶🏿‍♂‍➡' => 'ходещ мъж: тъмна кожа и в посока надясно',
    '🧎🏻‍♀‍➡' => 'коленичила жена: светла кожа и в посока надясно',
    '🧎🏼‍♀‍➡' => 'коленичила жена: средно светла кожа и в посока надясно',
    '🧎🏽‍♀‍➡' => 'коленичила жена: средна на цвят кожа и в посока надясно',
    '🧎🏾‍♀‍➡' => 'коленичила жена: средно тъмна кожа и в посока надясно',
    '🧎🏿‍♀‍➡' => 'коленичила жена: тъмна кожа и в посока надясно',
    '🧎🏻‍♂‍➡' => 'коленичил мъж: светла кожа и в посока надясно',
    '🧎🏼‍♂‍➡' => 'коленичил мъж: средно светла кожа и в посока надясно',
    '🧎🏽‍♂‍➡' => 'коленичил мъж: средна на цвят кожа и в посока надясно',
    '🧎🏾‍♂‍➡' => 'коленичил мъж: средно тъмна кожа и в посока надясно',
    '🧎🏿‍♂‍➡' => 'коленичил мъж: тъмна кожа и в посока надясно',
    '🧑🏻‍🦯‍➡' => 'човек с бял бастун: светла кожа и в посока надясно',
    '🧑🏼‍🦯‍➡' => 'човек с бял бастун: средно светла кожа и в посока надясно',
    '🧑🏽‍🦯‍➡' => 'човек с бял бастун: средна на цвят кожа и в посока надясно',
    '🧑🏾‍🦯‍➡' => 'човек с бял бастун: средно тъмна кожа и в посока надясно',
    '🧑🏿‍🦯‍➡' => 'човек с бял бастун: тъмна кожа и в посока надясно',
    '👨🏻‍🦯‍➡' => 'мъж с бял бастун: светла кожа и в посока надясно',
    '👨🏼‍🦯‍➡' => 'мъж с бял бастун: средно светла кожа и в посока надясно',
    '👨🏽‍🦯‍➡' => 'мъж с бял бастун: средна на цвят кожа и в посока надясно',
    '👨🏾‍🦯‍➡' => 'мъж с бял бастун: средно тъмна кожа и в посока надясно',
    '👨🏿‍🦯‍➡' => 'мъж с бял бастун: тъмна кожа и в посока надясно',
    '👩🏻‍🦯‍➡' => 'жена с бял бастун: светла кожа и в посока надясно',
    '👩🏼‍🦯‍➡' => 'жена с бял бастун: средно светла кожа и в посока надясно',
    '👩🏽‍🦯‍➡' => 'жена с бял бастун: средна на цвят кожа и в посока надясно',
    '👩🏾‍🦯‍➡' => 'жена с бял бастун: средно тъмна кожа и в посока надясно',
    '👩🏿‍🦯‍➡' => 'жена с бял бастун: тъмна кожа и в посока надясно',
    '🧑🏻‍🦼‍➡' => 'човек в моторизирана инвалидна количка: светла кожа и в посока надясно',
    '🧑🏼‍🦼‍➡' => 'човек в моторизирана инвалидна количка: средно светла кожа и в посока надясно',
    '🧑🏽‍🦼‍➡' => 'човек в моторизирана инвалидна количка: средна на цвят кожа и в посока надясно',
    '🧑🏾‍🦼‍➡' => 'човек в моторизирана инвалидна количка: средно тъмна кожа и в посока надясно',
    '🧑🏿‍🦼‍➡' => 'човек в моторизирана инвалидна количка: тъмна кожа и в посока надясно',
    '👨🏻‍🦼‍➡' => 'мъж в акумулаторна инвалидна количка: светла кожа и в посока надясно',
    '👨🏼‍🦼‍➡' => 'мъж в акумулаторна инвалидна количка: средно светла кожа и в посока надясно',
    '👨🏽‍🦼‍➡' => 'мъж в акумулаторна инвалидна количка: средна на цвят кожа и в посока надясно',
    '👨🏾‍🦼‍➡' => 'мъж в акумулаторна инвалидна количка: средно тъмна кожа и в посока надясно',
    '👨🏿‍🦼‍➡' => 'мъж в акумулаторна инвалидна количка: тъмна кожа и в посока надясно',
    '👩🏻‍🦼‍➡' => 'жена в акумулаторна инвалидна количка: светла кожа и в посока надясно',
    '👩🏼‍🦼‍➡' => 'жена в акумулаторна инвалидна количка: средно светла кожа и в посока надясно',
    '👩🏽‍🦼‍➡' => 'жена в акумулаторна инвалидна количка: средна на цвят кожа и в посока надясно',
    '👩🏾‍🦼‍➡' => 'жена в акумулаторна инвалидна количка: средно тъмна кожа и в посока надясно',
    '👩🏿‍🦼‍➡' => 'жена в акумулаторна инвалидна количка: тъмна кожа и в посока надясно',
    '🧑🏻‍🦽‍➡' => 'човек в инвалидна количка: светла кожа и в посока надясно',
    '🧑🏼‍🦽‍➡' => 'човек в инвалидна количка: средно светла кожа и в посока надясно',
    '🧑🏽‍🦽‍➡' => 'човек в инвалидна количка: средна на цвят кожа и в посока надясно',
    '🧑🏾‍🦽‍➡' => 'човек в инвалидна количка: средно тъмна кожа и в посока надясно',
    '🧑🏿‍🦽‍➡' => 'човек в инвалидна количка: тъмна кожа и в посока надясно',
    '👨🏻‍🦽‍➡' => 'мъж в инвалидна количка: светла кожа и в посока надясно',
    '👨🏼‍🦽‍➡' => 'мъж в инвалидна количка: средно светла кожа и в посока надясно',
    '👨🏽‍🦽‍➡' => 'мъж в инвалидна количка: средна на цвят кожа и в посока надясно',
    '👨🏾‍🦽‍➡' => 'мъж в инвалидна количка: средно тъмна кожа и в посока надясно',
    '👨🏿‍🦽‍➡' => 'мъж в инвалидна количка: тъмна кожа и в посока надясно',
    '👩🏻‍🦽‍➡' => 'жена в инвалидна количка: светла кожа и в посока надясно',
    '👩🏼‍🦽‍➡' => 'жена в инвалидна количка: средно светла кожа и в посока надясно',
    '👩🏽‍🦽‍➡' => 'жена в инвалидна количка: средна на цвят кожа и в посока надясно',
    '👩🏾‍🦽‍➡' => 'жена в инвалидна количка: средно тъмна кожа и в посока надясно',
    '👩🏿‍🦽‍➡' => 'жена в инвалидна количка: тъмна кожа и в посока надясно',
    '🏃🏻‍♀‍➡' => 'тичаща жена: светла кожа и в посока надясно',
    '🏃🏼‍♀‍➡' => 'тичаща жена: средно светла кожа и в посока надясно',
    '🏃🏽‍♀‍➡' => 'тичаща жена: средна на цвят кожа и в посока надясно',
    '🏃🏾‍♀‍➡' => 'тичаща жена: средно тъмна кожа и в посока надясно',
    '🏃🏿‍♀‍➡' => 'тичаща жена: тъмна кожа и в посока надясно',
    '🏃🏻‍♂‍➡' => 'тичащ мъж: светла кожа и в посока надясно',
    '🏃🏼‍♂‍➡' => 'тичащ мъж: средно светла кожа и в посока надясно',
    '🏃🏽‍♂‍➡' => 'тичащ мъж: средна на цвят кожа и в посока надясно',
    '🏃🏾‍♂‍➡' => 'тичащ мъж: средно тъмна кожа и в посока надясно',
    '🏃🏿‍♂‍➡' => 'тичащ мъж: тъмна кожа и в посока надясно',
    '🫱🏻‍🫲🏼' => 'ръкостискане: светла кожа и средно светла кожа',
    '🫱🏻‍🫲🏽' => 'ръкостискане: светла кожа и средна на цвят кожа',
    '🫱🏻‍🫲🏾' => 'ръкостискане: светла кожа и средно тъмна кожа',
    '🫱🏻‍🫲🏿' => 'ръкостискане: светла кожа и тъмна кожа',
    '🫱🏼‍🫲🏻' => 'ръкостискане: средно светла кожа и светла кожа',
    '🫱🏼‍🫲🏽' => 'ръкостискане: средно светла кожа и средна на цвят кожа',
    '🫱🏼‍🫲🏾' => 'ръкостискане: средно светла кожа и средно тъмна кожа',
    '🫱🏼‍🫲🏿' => 'ръкостискане: средно светла кожа и тъмна кожа',
    '🫱🏽‍🫲🏻' => 'ръкостискане: средна на цвят кожа и светла кожа',
    '🫱🏽‍🫲🏼' => 'ръкостискане: средна на цвят кожа и средно светла кожа',
    '🫱🏽‍🫲🏾' => 'ръкостискане: средна на цвят кожа и средно тъмна кожа',
    '🫱🏽‍🫲🏿' => 'ръкостискане: средна на цвят кожа и тъмна кожа',
    '🫱🏾‍🫲🏻' => 'ръкостискане: средно тъмна кожа и светла кожа',
    '🫱🏾‍🫲🏼' => 'ръкостискане: средно тъмна кожа и средно светла кожа',
    '🫱🏾‍🫲🏽' => 'ръкостискане: средно тъмна кожа и средна на цвят кожа',
    '🫱🏾‍🫲🏿' => 'ръкостискане: средно тъмна кожа и тъмна кожа',
    '🫱🏿‍🫲🏻' => 'ръкостискане: тъмна кожа и светла кожа',
    '🫱🏿‍🫲🏼' => 'ръкостискане: тъмна кожа и средно светла кожа',
    '🫱🏿‍🫲🏽' => 'ръкостискане: тъмна кожа и средна на цвят кожа',
    '🫱🏿‍🫲🏾' => 'ръкостискане: тъмна кожа и средно тъмна кожа',
    '🚶‍♀‍➡' => 'ходеща жена: в посока надясно',
    '🚶‍♂‍➡' => 'ходещ мъж: в посока надясно',
    '🧎‍♀‍➡' => 'коленичила жена: в посока надясно',
    '🧎‍♂‍➡' => 'коленичил мъж: в посока надясно',
    '🧑‍🦯‍➡' => 'човек с бял бастун: в посока надясно',
    '👨‍🦯‍➡' => 'мъж с бял бастун: в посока надясно',
    '👩‍🦯‍➡' => 'жена с бял бастун: в посока надясно',
    '🧑‍🦼‍➡' => 'човек в моторизирана инвалидна количка: в посока надясно',
    '👨‍🦼‍➡' => 'мъж в акумулаторна инвалидна количка: в посока надясно',
    '👩‍🦼‍➡' => 'жена в акумулаторна инвалидна количка: в посока надясно',
    '🧑‍🦽‍➡' => 'човек в инвалидна количка: в посока надясно',
    '👨‍🦽‍➡' => 'мъж в инвалидна количка: в посока надясно',
    '👩‍🦽‍➡' => 'жена в инвалидна количка: в посока надясно',
    '🏃‍♀‍➡' => 'тичаща жена: в посока надясно',
    '🏃‍♂‍➡' => 'тичащ мъж: в посока надясно',
    '👩‍❤‍👨' => 'Двойка и сърце: жена и мъж',
    '👨‍❤‍👨' => 'Двойка и сърце: мъж и мъж',
    '👩‍❤‍👩' => 'Двойка и сърце: жена и жена',
    '👨‍👩‍👦' => 'семейство: мъж, жена, момче',
    '👨‍👩‍👧' => 'семейство: мъж, жена, момиче',
    '👨‍👨‍👦' => 'семейство: мъж, мъж, момче',
    '👨‍👨‍👧' => 'семейство: мъж, мъж, момиче',
    '👩‍👩‍👦' => 'семейство: жена, жена, момче',
    '👩‍👩‍👧' => 'семейство: жена, жена, момиче',
    '👨‍👦‍👦' => 'семейство: мъж, момче, момче',
    '👨‍👧‍👦' => 'семейство: мъж, момиче, момче',
    '👨‍👧‍👧' => 'семейство: мъж, момиче, момиче',
    '👩‍👦‍👦' => 'семейство: жена, момче, момче',
    '👩‍👧‍👦' => 'семейство: жена, момиче, момче',
    '👩‍👧‍👧' => 'семейство: жена, момиче, момиче',
    '🧑‍🤝‍🧑' => 'хора, които се държат за ръце',
    '🧑‍🧑‍🧒' => 'семейство: възрастен, възрастен, дете',
    '🧑‍🧒‍🧒' => 'семейство: възрастен, дете, дете',
    '🧑🏻‍🦰' => 'възрастен: светла кожа и рижа коса',
    '🧑🏼‍🦰' => 'възрастен: средно светла кожа и рижа коса',
    '🧑🏽‍🦰' => 'възрастен: средна на цвят кожа и рижа коса',
    '🧑🏾‍🦰' => 'възрастен: средно тъмна кожа и рижа коса',
    '🧑🏿‍🦰' => 'възрастен: тъмна кожа и рижа коса',
    '🧑🏻‍🦱' => 'възрастен: светла кожа и къдрава коса',
    '🧑🏼‍🦱' => 'възрастен: средно светла кожа и къдрава коса',
    '🧑🏽‍🦱' => 'възрастен: средна на цвят кожа и къдрава коса',
    '🧑🏾‍🦱' => 'възрастен: средно тъмна кожа и къдрава коса',
    '🧑🏿‍🦱' => 'възрастен: тъмна кожа и къдрава коса',
    '🧑🏻‍🦳' => 'възрастен: светла кожа и побеляла коса',
    '🧑🏼‍🦳' => 'възрастен: средно светла кожа и побеляла коса',
    '🧑🏽‍🦳' => 'възрастен: средна на цвят кожа и побеляла коса',
    '🧑🏾‍🦳' => 'възрастен: средно тъмна кожа и побеляла коса',
    '🧑🏿‍🦳' => 'възрастен: тъмна кожа и побеляла коса',
    '🧑🏻‍🦲' => 'възрастен: светла кожа и плешив човек',
    '🧑🏼‍🦲' => 'възрастен: средно светла кожа и плешив човек',
    '🧑🏽‍🦲' => 'възрастен: средна на цвят кожа и плешив човек',
    '🧑🏾‍🦲' => 'възрастен: средно тъмна кожа и плешив човек',
    '🧑🏿‍🦲' => 'възрастен: тъмна кожа и плешив човек',
    '🧑🏻‍🩰' => 'балерина: светла кожа',
    '🧑🏼‍🩰' => 'балерина: средно светла кожа',
    '🧑🏽‍🩰' => 'балерина: средна на цвят кожа',
    '🧑🏾‍🩰' => 'балерина: средно тъмна кожа',
    '🧑🏿‍🩰' => 'балерина: тъмна кожа',
    '🧔🏻‍♂' => 'мъж: светла кожа и брада',
    '🧔🏼‍♂' => 'мъж: средно светла кожа и брада',
    '🧔🏽‍♂' => 'мъж: средна на цвят кожа и брада',
    '🧔🏾‍♂' => 'мъж: средно тъмна кожа и брада',
    '🧔🏿‍♂' => 'мъж: тъмна кожа и брада',
    '👱🏻‍♂' => 'блондин: светла кожа',
    '👱🏼‍♂' => 'блондин: средно светла кожа',
    '👱🏽‍♂' => 'блондин: средна на цвят кожа',
    '👱🏾‍♂' => 'блондин: средно тъмна кожа',
    '👱🏿‍♂' => 'блондин: тъмна кожа',
    '👨🏻‍🦰' => 'мъж: светла кожа и рижа коса',
    '👨🏼‍🦰' => 'мъж: средно светла кожа и рижа коса',
    '👨🏽‍🦰' => 'мъж: средна на цвят кожа и рижа коса',
    '👨🏾‍🦰' => 'мъж: средно тъмна кожа и рижа коса',
    '👨🏿‍🦰' => 'мъж: тъмна кожа и рижа коса',
    '👨🏻‍🦱' => 'мъж: светла кожа и къдрава коса',
    '👨🏼‍🦱' => 'мъж: средно светла кожа и къдрава коса',
    '👨🏽‍🦱' => 'мъж: средна на цвят кожа и къдрава коса',
    '👨🏾‍🦱' => 'мъж: средно тъмна кожа и къдрава коса',
    '👨🏿‍🦱' => 'мъж: тъмна кожа и къдрава коса',
    '👨🏻‍🦳' => 'мъж: светла кожа и побеляла коса',
    '👨🏼‍🦳' => 'мъж: средно светла кожа и побеляла коса',
    '👨🏽‍🦳' => 'мъж: средна на цвят кожа и побеляла коса',
    '👨🏾‍🦳' => 'мъж: средно тъмна кожа и побеляла коса',
    '👨🏿‍🦳' => 'мъж: тъмна кожа и побеляла коса',
    '👨🏻‍🦲' => 'мъж: светла кожа и плешив човек',
    '👨🏼‍🦲' => 'мъж: средно светла кожа и плешив човек',
    '👨🏽‍🦲' => 'мъж: средна на цвят кожа и плешив човек',
    '👨🏾‍🦲' => 'мъж: средно тъмна кожа и плешив човек',
    '👨🏿‍🦲' => 'мъж: тъмна кожа и плешив човек',
    '🧔🏻‍♀' => 'жена: светла кожа и брада',
    '🧔🏼‍♀' => 'жена: средно светла кожа и брада',
    '🧔🏽‍♀' => 'жена: средна на цвят кожа и брада',
    '🧔🏾‍♀' => 'жена: средно тъмна кожа и брада',
    '🧔🏿‍♀' => 'жена: тъмна кожа и брада',
    '👱🏻‍♀' => 'блондинка: светла кожа',
    '👱🏼‍♀' => 'блондинка: средно светла кожа',
    '👱🏽‍♀' => 'блондинка: средна на цвят кожа',
    '👱🏾‍♀' => 'блондинка: средно тъмна кожа',
    '👱🏿‍♀' => 'блондинка: тъмна кожа',
    '👩🏻‍🦰' => 'жена: светла кожа и рижа коса',
    '👩🏼‍🦰' => 'жена: средно светла кожа и рижа коса',
    '👩🏽‍🦰' => 'жена: средна на цвят кожа и рижа коса',
    '👩🏾‍🦰' => 'жена: средно тъмна кожа и рижа коса',
    '👩🏿‍🦰' => 'жена: тъмна кожа и рижа коса',
    '👩🏻‍🦱' => 'жена: светла кожа и къдрава коса',
    '👩🏼‍🦱' => 'жена: средно светла кожа и къдрава коса',
    '👩🏽‍🦱' => 'жена: средна на цвят кожа и къдрава коса',
    '👩🏾‍🦱' => 'жена: средно тъмна кожа и къдрава коса',
    '👩🏿‍🦱' => 'жена: тъмна кожа и къдрава коса',
    '👩🏻‍🦳' => 'жена: светла кожа и побеляла коса',
    '👩🏼‍🦳' => 'жена: средно светла кожа и побеляла коса',
    '👩🏽‍🦳' => 'жена: средна на цвят кожа и побеляла коса',
    '👩🏾‍🦳' => 'жена: средно тъмна кожа и побеляла коса',
    '👩🏿‍🦳' => 'жена: тъмна кожа и побеляла коса',
    '👩🏻‍🦲' => 'жена: светла кожа и плешив човек',
    '👩🏼‍🦲' => 'жена: средно светла кожа и плешив човек',
    '👩🏽‍🦲' => 'жена: средна на цвят кожа и плешив човек',
    '👩🏾‍🦲' => 'жена: средно тъмна кожа и плешив човек',
    '👩🏿‍🦲' => 'жена: тъмна кожа и плешив човек',
    '🙍🏻‍♂' => 'намръщен мъж: светла кожа',
    '🙍🏼‍♂' => 'намръщен мъж: средно светла кожа',
    '🙍🏽‍♂' => 'намръщен мъж: средна на цвят кожа',
    '🙍🏾‍♂' => 'намръщен мъж: средно тъмна кожа',
    '🙍🏿‍♂' => 'намръщен мъж: тъмна кожа',
    '🙍🏻‍♀' => 'намръщена жена: светла кожа',
    '🙍🏼‍♀' => 'намръщена жена: средно светла кожа',
    '🙍🏽‍♀' => 'намръщена жена: средна на цвят кожа',
    '🙍🏾‍♀' => 'намръщена жена: средно тъмна кожа',
    '🙍🏿‍♀' => 'намръщена жена: тъмна кожа',
    '🙎🏻‍♂' => 'нацупен мъж: светла кожа',
    '🙎🏼‍♂' => 'нацупен мъж: средно светла кожа',
    '🙎🏽‍♂' => 'нацупен мъж: средна на цвят кожа',
    '🙎🏾‍♂' => 'нацупен мъж: средно тъмна кожа',
    '🙎🏿‍♂' => 'нацупен мъж: тъмна кожа',
    '🙎🏻‍♀' => 'нацупена жена: светла кожа',
    '🙎🏼‍♀' => 'нацупена жена: средно светла кожа',
    '🙎🏽‍♀' => 'нацупена жена: средна на цвят кожа',
    '🙎🏾‍♀' => 'нацупена жена: средно тъмна кожа',
    '🙎🏿‍♀' => 'нацупена жена: тъмна кожа',
    '🙅🏻‍♂' => 'мъж, правещ жест за „не“: светла кожа',
    '🙅🏼‍♂' => 'мъж, правещ жест за „не“: средно светла кожа',
    '🙅🏽‍♂' => 'мъж, правещ жест за „не“: средна на цвят кожа',
    '🙅🏾‍♂' => 'мъж, правещ жест за „не“: средно тъмна кожа',
    '🙅🏿‍♂' => 'мъж, правещ жест за „не“: тъмна кожа',
    '🙅🏻‍♀' => 'жена, правеща жест за „не“: светла кожа',
    '🙅🏼‍♀' => 'жена, правеща жест за „не“: средно светла кожа',
    '🙅🏽‍♀' => 'жена, правеща жест за „не“: средна на цвят кожа',
    '🙅🏾‍♀' => 'жена, правеща жест за „не“: средно тъмна кожа',
    '🙅🏿‍♀' => 'жена, правеща жест за „не“: тъмна кожа',
    '🙆🏻‍♂' => 'мъж, правещ жест за „окей“: светла кожа',
    '🙆🏼‍♂' => 'мъж, правещ жест за „окей“: средно светла кожа',
    '🙆🏽‍♂' => 'мъж, правещ жест за „окей“: средна на цвят кожа',
    '🙆🏾‍♂' => 'мъж, правещ жест за „окей“: средно тъмна кожа',
    '🙆🏿‍♂' => 'мъж, правещ жест за „окей“: тъмна кожа',
    '🙆🏻‍♀' => 'жена, правеща жест за „окей“: светла кожа',
    '🙆🏼‍♀' => 'жена, правеща жест за „окей“: средно светла кожа',
    '🙆🏽‍♀' => 'жена, правеща жест за „окей“: средна на цвят кожа',
    '🙆🏾‍♀' => 'жена, правеща жест за „окей“: средно тъмна кожа',
    '🙆🏿‍♀' => 'жена, правеща жест за „окей“: тъмна кожа',
    '💁🏻‍♂' => 'мъж от информационна служба: светла кожа',
    '💁🏼‍♂' => 'мъж от информационна служба: средно светла кожа',
    '💁🏽‍♂' => 'мъж от информационна служба: средна на цвят кожа',
    '💁🏾‍♂' => 'мъж от информационна служба: средно тъмна кожа',
    '💁🏿‍♂' => 'мъж от информационна служба: тъмна кожа',
    '💁🏻‍♀' => 'жена от информационна служба: светла кожа',
    '💁🏼‍♀' => 'жена от информационна служба: средно светла кожа',
    '💁🏽‍♀' => 'жена от информационна служба: средна на цвят кожа',
    '💁🏾‍♀' => 'жена от информационна служба: средно тъмна кожа',
    '💁🏿‍♀' => 'жена от информационна служба: тъмна кожа',
    '🙋🏻‍♂' => 'щастлив мъж, вдигнал ръка: светла кожа',
    '🙋🏼‍♂' => 'щастлив мъж, вдигнал ръка: средно светла кожа',
    '🙋🏽‍♂' => 'щастлив мъж, вдигнал ръка: средна на цвят кожа',
    '🙋🏾‍♂' => 'щастлив мъж, вдигнал ръка: средно тъмна кожа',
    '🙋🏿‍♂' => 'щастлив мъж, вдигнал ръка: тъмна кожа',
    '🙋🏻‍♀' => 'щастлива жена, вдигнала ръка: светла кожа',
    '🙋🏼‍♀' => 'щастлива жена, вдигнала ръка: средно светла кожа',
    '🙋🏽‍♀' => 'щастлива жена, вдигнала ръка: средна на цвят кожа',
    '🙋🏾‍♀' => 'щастлива жена, вдигнала ръка: средно тъмна кожа',
    '🙋🏿‍♀' => 'щастлива жена, вдигнала ръка: тъмна кожа',
    '🧏🏻‍♂' => 'глух мъж: светла кожа',
    '🧏🏼‍♂' => 'глух мъж: средно светла кожа',
    '🧏🏽‍♂' => 'глух мъж: средна на цвят кожа',
    '🧏🏾‍♂' => 'глух мъж: средно тъмна кожа',
    '🧏🏿‍♂' => 'глух мъж: тъмна кожа',
    '🧏🏻‍♀' => 'глуха жена: светла кожа',
    '🧏🏼‍♀' => 'глуха жена: средно светла кожа',
    '🧏🏽‍♀' => 'глуха жена: средна на цвят кожа',
    '🧏🏾‍♀' => 'глуха жена: средно тъмна кожа',
    '🧏🏿‍♀' => 'глуха жена: тъмна кожа',
    '🙇🏻‍♂' => 'покланящ се мъж: светла кожа',
    '🙇🏼‍♂' => 'покланящ се мъж: средно светла кожа',
    '🙇🏽‍♂' => 'покланящ се мъж: средна на цвят кожа',
    '🙇🏾‍♂' => 'покланящ се мъж: средно тъмна кожа',
    '🙇🏿‍♂' => 'покланящ се мъж: тъмна кожа',
    '🙇🏻‍♀' => 'покланяща се жена: светла кожа',
    '🙇🏼‍♀' => 'покланяща се жена: средно светла кожа',
    '🙇🏽‍♀' => 'покланяща се жена: средна на цвят кожа',
    '🙇🏾‍♀' => 'покланяща се жена: средно тъмна кожа',
    '🙇🏿‍♀' => 'покланяща се жена: тъмна кожа',
    '🤦🏻‍♂' => 'мъж с ръка върху лицето: светла кожа',
    '🤦🏼‍♂' => 'мъж с ръка върху лицето: средно светла кожа',
    '🤦🏽‍♂' => 'мъж с ръка върху лицето: средна на цвят кожа',
    '🤦🏾‍♂' => 'мъж с ръка върху лицето: средно тъмна кожа',
    '🤦🏿‍♂' => 'мъж с ръка върху лицето: тъмна кожа',
    '🤦🏻‍♀' => 'жена с ръка върху лицето: светла кожа',
    '🤦🏼‍♀' => 'жена с ръка върху лицето: средно светла кожа',
    '🤦🏽‍♀' => 'жена с ръка върху лицето: средна на цвят кожа',
    '🤦🏾‍♀' => 'жена с ръка върху лицето: средно тъмна кожа',
    '🤦🏿‍♀' => 'жена с ръка върху лицето: тъмна кожа',
    '🤷🏻‍♂' => 'мъж свива рамене: светла кожа',
    '🤷🏼‍♂' => 'мъж свива рамене: средно светла кожа',
    '🤷🏽‍♂' => 'мъж свива рамене: средна на цвят кожа',
    '🤷🏾‍♂' => 'мъж свива рамене: средно тъмна кожа',
    '🤷🏿‍♂' => 'мъж свива рамене: тъмна кожа',
    '🤷🏻‍♀' => 'жена свива рамене: светла кожа',
    '🤷🏼‍♀' => 'жена свива рамене: средно светла кожа',
    '🤷🏽‍♀' => 'жена свива рамене: средна на цвят кожа',
    '🤷🏾‍♀' => 'жена свива рамене: средно тъмна кожа',
    '🤷🏿‍♀' => 'жена свива рамене: тъмна кожа',
    '🧑🏻‍⚕' => 'здравен служител: светла кожа',
    '🧑🏼‍⚕' => 'здравен служител: средно светла кожа',
    '🧑🏽‍⚕' => 'здравен служител: средна на цвят кожа',
    '🧑🏾‍⚕' => 'здравен служител: средно тъмна кожа',
    '🧑🏿‍⚕' => 'здравен служител: тъмна кожа',
    '👨🏻‍⚕' => 'здравен работник: светла кожа',
    '👨🏼‍⚕' => 'здравен работник: средно светла кожа',
    '👨🏽‍⚕' => 'здравен работник: средна на цвят кожа',
    '👨🏾‍⚕' => 'здравен работник: средно тъмна кожа',
    '👨🏿‍⚕' => 'здравен работник: тъмна кожа',
    '👩🏻‍⚕' => 'здравна работничка: светла кожа',
    '👩🏼‍⚕' => 'здравна работничка: средно светла кожа',
    '👩🏽‍⚕' => 'здравна работничка: средна на цвят кожа',
    '👩🏾‍⚕' => 'здравна работничка: средно тъмна кожа',
    '👩🏿‍⚕' => 'здравна работничка: тъмна кожа',
    '🧑🏻‍🎓' => 'учащ: светла кожа',
    '🧑🏼‍🎓' => 'учащ: средно светла кожа',
    '🧑🏽‍🎓' => 'учащ: средна на цвят кожа',
    '🧑🏾‍🎓' => 'учащ: средно тъмна кожа',
    '🧑🏿‍🎓' => 'учащ: тъмна кожа',
    '👨🏻‍🎓' => 'студент: светла кожа',
    '👨🏼‍🎓' => 'студент: средно светла кожа',
    '👨🏽‍🎓' => 'студент: средна на цвят кожа',
    '👨🏾‍🎓' => 'студент: средно тъмна кожа',
    '👨🏿‍🎓' => 'студент: тъмна кожа',
    '👩🏻‍🎓' => 'студентка: светла кожа',
    '👩🏼‍🎓' => 'студентка: средно светла кожа',
    '👩🏽‍🎓' => 'студентка: средна на цвят кожа',
    '👩🏾‍🎓' => 'студентка: средно тъмна кожа',
    '👩🏿‍🎓' => 'студентка: тъмна кожа',
    '🧑🏻‍🏫' => 'преподавател: светла кожа',
    '🧑🏼‍🏫' => 'преподавател: средно светла кожа',
    '🧑🏽‍🏫' => 'преподавател: средна на цвят кожа',
    '🧑🏾‍🏫' => 'преподавател: средно тъмна кожа',
    '🧑🏿‍🏫' => 'преподавател: тъмна кожа',
    '👨🏻‍🏫' => 'учител: светла кожа',
    '👨🏼‍🏫' => 'учител: средно светла кожа',
    '👨🏽‍🏫' => 'учител: средна на цвят кожа',
    '👨🏾‍🏫' => 'учител: средно тъмна кожа',
    '👨🏿‍🏫' => 'учител: тъмна кожа',
    '👩🏻‍🏫' => 'учителка: светла кожа',
    '👩🏼‍🏫' => 'учителка: средно светла кожа',
    '👩🏽‍🏫' => 'учителка: средна на цвят кожа',
    '👩🏾‍🏫' => 'учителка: средно тъмна кожа',
    '👩🏿‍🏫' => 'учителка: тъмна кожа',
    '🧑🏻‍⚖' => 'съдия: светла кожа',
    '🧑🏼‍⚖' => 'съдия: средно светла кожа',
    '🧑🏽‍⚖' => 'съдия: средна на цвят кожа',
    '🧑🏾‍⚖' => 'съдия: средно тъмна кожа',
    '🧑🏿‍⚖' => 'съдия: тъмна кожа',
    '👨🏻‍⚖' => 'мъж съдия: светла кожа',
    '👨🏼‍⚖' => 'мъж съдия: средно светла кожа',
    '👨🏽‍⚖' => 'мъж съдия: средна на цвят кожа',
    '👨🏾‍⚖' => 'мъж съдия: средно тъмна кожа',
    '👨🏿‍⚖' => 'мъж съдия: тъмна кожа',
    '👩🏻‍⚖' => 'съдийка: светла кожа',
    '👩🏼‍⚖' => 'съдийка: средно светла кожа',
    '👩🏽‍⚖' => 'съдийка: средна на цвят кожа',
    '👩🏾‍⚖' => 'съдийка: средно тъмна кожа',
    '👩🏿‍⚖' => 'съдийка: тъмна кожа',
    '🧑🏻‍🌾' => 'земеделец: светла кожа',
    '🧑🏼‍🌾' => 'земеделец: средно светла кожа',
    '🧑🏽‍🌾' => 'земеделец: средна на цвят кожа',
    '🧑🏾‍🌾' => 'земеделец: средно тъмна кожа',
    '🧑🏿‍🌾' => 'земеделец: тъмна кожа',
    '👨🏻‍🌾' => 'фермер: светла кожа',
    '👨🏼‍🌾' => 'фермер: средно светла кожа',
    '👨🏽‍🌾' => 'фермер: средна на цвят кожа',
    '👨🏾‍🌾' => 'фермер: средно тъмна кожа',
    '👨🏿‍🌾' => 'фермер: тъмна кожа',
    '👩🏻‍🌾' => 'фермерка: светла кожа',
    '👩🏼‍🌾' => 'фермерка: средно светла кожа',
    '👩🏽‍🌾' => 'фермерка: средна на цвят кожа',
    '👩🏾‍🌾' => 'фермерка: средно тъмна кожа',
    '👩🏿‍🌾' => 'фермерка: тъмна кожа',
    '🧑🏻‍🍳' => 'готвач: светла кожа',
    '🧑🏼‍🍳' => 'готвач: средно светла кожа',
    '🧑🏽‍🍳' => 'готвач: средна на цвят кожа',
    '🧑🏾‍🍳' => 'готвач: средно тъмна кожа',
    '🧑🏿‍🍳' => 'готвач: тъмна кожа',
    '👨🏻‍🍳' => 'мъж готвач: светла кожа',
    '👨🏼‍🍳' => 'мъж готвач: средно светла кожа',
    '👨🏽‍🍳' => 'мъж готвач: средна на цвят кожа',
    '👨🏾‍🍳' => 'мъж готвач: средно тъмна кожа',
    '👨🏿‍🍳' => 'мъж готвач: тъмна кожа',
    '👩🏻‍🍳' => 'готвачка: светла кожа',
    '👩🏼‍🍳' => 'готвачка: средно светла кожа',
    '👩🏽‍🍳' => 'готвачка: средна на цвят кожа',
    '👩🏾‍🍳' => 'готвачка: средно тъмна кожа',
    '👩🏿‍🍳' => 'готвачка: тъмна кожа',
    '🧑🏻‍🔧' => 'механик: светла кожа',
    '🧑🏼‍🔧' => 'механик: средно светла кожа',
    '🧑🏽‍🔧' => 'механик: средна на цвят кожа',
    '🧑🏾‍🔧' => 'механик: средно тъмна кожа',
    '🧑🏿‍🔧' => 'механик: тъмна кожа',
    '👨🏻‍🔧' => 'мъж механик: светла кожа',
    '👨🏼‍🔧' => 'мъж механик: средно светла кожа',
    '👨🏽‍🔧' => 'мъж механик: средна на цвят кожа',
    '👨🏾‍🔧' => 'мъж механик: средно тъмна кожа',
    '👨🏿‍🔧' => 'мъж механик: тъмна кожа',
    '👩🏻‍🔧' => 'жена механик: светла кожа',
    '👩🏼‍🔧' => 'жена механик: средно светла кожа',
    '👩🏽‍🔧' => 'жена механик: средна на цвят кожа',
    '👩🏾‍🔧' => 'жена механик: средно тъмна кожа',
    '👩🏿‍🔧' => 'жена механик: тъмна кожа',
    '🧑🏻‍🏭' => 'работник във фабрика: светла кожа',
    '🧑🏼‍🏭' => 'работник във фабрика: средно светла кожа',
    '🧑🏽‍🏭' => 'работник във фабрика: средна на цвят кожа',
    '🧑🏾‍🏭' => 'работник във фабрика: средно тъмна кожа',
    '🧑🏿‍🏭' => 'работник във фабрика: тъмна кожа',
    '👨🏻‍🏭' => 'работник в завод: светла кожа',
    '👨🏼‍🏭' => 'работник в завод: средно светла кожа',
    '👨🏽‍🏭' => 'работник в завод: средна на цвят кожа',
    '👨🏾‍🏭' => 'работник в завод: средно тъмна кожа',
    '👨🏿‍🏭' => 'работник в завод: тъмна кожа',
    '👩🏻‍🏭' => 'работничка в завод: светла кожа',
    '👩🏼‍🏭' => 'работничка в завод: средно светла кожа',
    '👩🏽‍🏭' => 'работничка в завод: средна на цвят кожа',
    '👩🏾‍🏭' => 'работничка в завод: средно тъмна кожа',
    '👩🏿‍🏭' => 'работничка в завод: тъмна кожа',
    '🧑🏻‍💼' => 'служител: светла кожа',
    '🧑🏼‍💼' => 'служител: средно светла кожа',
    '🧑🏽‍💼' => 'служител: средна на цвят кожа',
    '🧑🏾‍💼' => 'служител: средно тъмна кожа',
    '🧑🏿‍💼' => 'служител: тъмна кожа',
    '👨🏻‍💼' => 'служител в офис: светла кожа',
    '👨🏼‍💼' => 'служител в офис: средно светла кожа',
    '👨🏽‍💼' => 'служител в офис: средна на цвят кожа',
    '👨🏾‍💼' => 'служител в офис: средно тъмна кожа',
    '👨🏿‍💼' => 'служител в офис: тъмна кожа',
    '👩🏻‍💼' => 'служителка в офис: светла кожа',
    '👩🏼‍💼' => 'служителка в офис: средно светла кожа',
    '👩🏽‍💼' => 'служителка в офис: средна на цвят кожа',
    '👩🏾‍💼' => 'служителка в офис: средно тъмна кожа',
    '👩🏿‍💼' => 'служителка в офис: тъмна кожа',
    '🧑🏻‍🔬' => 'учен: светла кожа',
    '🧑🏼‍🔬' => 'учен: средно светла кожа',
    '🧑🏽‍🔬' => 'учен: средна на цвят кожа',
    '🧑🏾‍🔬' => 'учен: средно тъмна кожа',
    '🧑🏿‍🔬' => 'учен: тъмна кожа',
    '👨🏻‍🔬' => 'мъж учен: светла кожа',
    '👨🏼‍🔬' => 'мъж учен: средно светла кожа',
    '👨🏽‍🔬' => 'мъж учен: средна на цвят кожа',
    '👨🏾‍🔬' => 'мъж учен: средно тъмна кожа',
    '👨🏿‍🔬' => 'мъж учен: тъмна кожа',
    '👩🏻‍🔬' => 'жена учен: светла кожа',
    '👩🏼‍🔬' => 'жена учен: средно светла кожа',
    '👩🏽‍🔬' => 'жена учен: средна на цвят кожа',
    '👩🏾‍🔬' => 'жена учен: средно тъмна кожа',
    '👩🏿‍🔬' => 'жена учен: тъмна кожа',
    '🧑🏻‍💻' => 'програмист: светла кожа',
    '🧑🏼‍💻' => 'програмист: средно светла кожа',
    '🧑🏽‍💻' => 'програмист: средна на цвят кожа',
    '🧑🏾‍💻' => 'програмист: средно тъмна кожа',
    '🧑🏿‍💻' => 'програмист: тъмна кожа',
    '👨🏻‍💻' => 'мъж в сферата на технологиите: светла кожа',
    '👨🏼‍💻' => 'мъж в сферата на технологиите: средно светла кожа',
    '👨🏽‍💻' => 'мъж в сферата на технологиите: средна на цвят кожа',
    '👨🏾‍💻' => 'мъж в сферата на технологиите: средно тъмна кожа',
    '👨🏿‍💻' => 'мъж в сферата на технологиите: тъмна кожа',
    '👩🏻‍💻' => 'жена в сферата на технологиите: светла кожа',
    '👩🏼‍💻' => 'жена в сферата на технологиите: средно светла кожа',
    '👩🏽‍💻' => 'жена в сферата на технологиите: средна на цвят кожа',
    '👩🏾‍💻' => 'жена в сферата на технологиите: средно тъмна кожа',
    '👩🏿‍💻' => 'жена в сферата на технологиите: тъмна кожа',
    '🧑🏻‍🎤' => 'певец: светла кожа',
    '🧑🏼‍🎤' => 'певец: средно светла кожа',
    '🧑🏽‍🎤' => 'певец: средна на цвят кожа',
    '🧑🏾‍🎤' => 'певец: средно тъмна кожа',
    '🧑🏿‍🎤' => 'певец: тъмна кожа',
    '👨🏻‍🎤' => 'мъж певец: светла кожа',
    '👨🏼‍🎤' => 'мъж певец: средно светла кожа',
    '👨🏽‍🎤' => 'мъж певец: средна на цвят кожа',
    '👨🏾‍🎤' => 'мъж певец: средно тъмна кожа',
    '👨🏿‍🎤' => 'мъж певец: тъмна кожа',
    '👩🏻‍🎤' => 'певица: светла кожа',
    '👩🏼‍🎤' => 'певица: средно светла кожа',
    '👩🏽‍🎤' => 'певица: средна на цвят кожа',
    '👩🏾‍🎤' => 'певица: средно тъмна кожа',
    '👩🏿‍🎤' => 'певица: тъмна кожа',
    '🧑🏻‍🎨' => 'художник: светла кожа',
    '🧑🏼‍🎨' => 'художник: средно светла кожа',
    '🧑🏽‍🎨' => 'художник: средна на цвят кожа',
    '🧑🏾‍🎨' => 'художник: средно тъмна кожа',
    '🧑🏿‍🎨' => 'художник: тъмна кожа',
    '👨🏻‍🎨' => 'мъж художник: светла кожа',
    '👨🏼‍🎨' => 'мъж художник: средно светла кожа',
    '👨🏽‍🎨' => 'мъж художник: средна на цвят кожа',
    '👨🏾‍🎨' => 'мъж художник: средно тъмна кожа',
    '👨🏿‍🎨' => 'мъж художник: тъмна кожа',
    '👩🏻‍🎨' => 'художничка: светла кожа',
    '👩🏼‍🎨' => 'художничка: средно светла кожа',
    '👩🏽‍🎨' => 'художничка: средна на цвят кожа',
    '👩🏾‍🎨' => 'художничка: средно тъмна кожа',
    '👩🏿‍🎨' => 'художничка: тъмна кожа',
    '🧑🏻‍✈' => 'пилот: светла кожа',
    '🧑🏼‍✈' => 'пилот: средно светла кожа',
    '🧑🏽‍✈' => 'пилот: средна на цвят кожа',
    '🧑🏾‍✈' => 'пилот: средно тъмна кожа',
    '🧑🏿‍✈' => 'пилот: тъмна кожа',
    '👨🏻‍✈' => 'мъж пилот: светла кожа',
    '👨🏼‍✈' => 'мъж пилот: средно светла кожа',
    '👨🏽‍✈' => 'мъж пилот: средна на цвят кожа',
    '👨🏾‍✈' => 'мъж пилот: средно тъмна кожа',
    '👨🏿‍✈' => 'мъж пилот: тъмна кожа',
    '👩🏻‍✈' => 'жена пилот: светла кожа',
    '👩🏼‍✈' => 'жена пилот: средно светла кожа',
    '👩🏽‍✈' => 'жена пилот: средна на цвят кожа',
    '👩🏾‍✈' => 'жена пилот: средно тъмна кожа',
    '👩🏿‍✈' => 'жена пилот: тъмна кожа',
    '🧑🏻‍🚀' => 'астронавт: светла кожа',
    '🧑🏼‍🚀' => 'астронавт: средно светла кожа',
    '🧑🏽‍🚀' => 'астронавт: средна на цвят кожа',
    '🧑🏾‍🚀' => 'астронавт: средно тъмна кожа',
    '🧑🏿‍🚀' => 'астронавт: тъмна кожа',
    '👨🏻‍🚀' => 'космонавт: светла кожа',
    '👨🏼‍🚀' => 'космонавт: средно светла кожа',
    '👨🏽‍🚀' => 'космонавт: средна на цвят кожа',
    '👨🏾‍🚀' => 'космонавт: средно тъмна кожа',
    '👨🏿‍🚀' => 'космонавт: тъмна кожа',
    '👩🏻‍🚀' => 'жена космонавт: светла кожа',
    '👩🏼‍🚀' => 'жена космонавт: средно светла кожа',
    '👩🏽‍🚀' => 'жена космонавт: средна на цвят кожа',
    '👩🏾‍🚀' => 'жена космонавт: средно тъмна кожа',
    '👩🏿‍🚀' => 'жена космонавт: тъмна кожа',
    '🧑🏻‍🚒' => 'пожарникар: светла кожа',
    '🧑🏼‍🚒' => 'пожарникар: средно светла кожа',
    '🧑🏽‍🚒' => 'пожарникар: средна на цвят кожа',
    '🧑🏾‍🚒' => 'пожарникар: средно тъмна кожа',
    '🧑🏿‍🚒' => 'пожарникар: тъмна кожа',
    '👨🏻‍🚒' => 'мъж пожарникар: светла кожа',
    '👨🏼‍🚒' => 'мъж пожарникар: средно светла кожа',
    '👨🏽‍🚒' => 'мъж пожарникар: средна на цвят кожа',
    '👨🏾‍🚒' => 'мъж пожарникар: средно тъмна кожа',
    '👨🏿‍🚒' => 'мъж пожарникар: тъмна кожа',
    '👩🏻‍🚒' => 'жена пожарникар: светла кожа',
    '👩🏼‍🚒' => 'жена пожарникар: средно светла кожа',
    '👩🏽‍🚒' => 'жена пожарникар: средна на цвят кожа',
    '👩🏾‍🚒' => 'жена пожарникар: средно тъмна кожа',
    '👩🏿‍🚒' => 'жена пожарникар: тъмна кожа',
    '👮🏻‍♂' => 'полицай: светла кожа',
    '👮🏼‍♂' => 'полицай: средно светла кожа',
    '👮🏽‍♂' => 'полицай: средна на цвят кожа',
    '👮🏾‍♂' => 'полицай: средно тъмна кожа',
    '👮🏿‍♂' => 'полицай: тъмна кожа',
    '👮🏻‍♀' => 'полицайка: светла кожа',
    '👮🏼‍♀' => 'полицайка: средно светла кожа',
    '👮🏽‍♀' => 'полицайка: средна на цвят кожа',
    '👮🏾‍♀' => 'полицайка: средно тъмна кожа',
    '👮🏿‍♀' => 'полицайка: тъмна кожа',
    '🕵🏻‍♂' => 'мъж детектив: светла кожа',
    '🕵🏼‍♂' => 'мъж детектив: средно светла кожа',
    '🕵🏽‍♂' => 'мъж детектив: средна на цвят кожа',
    '🕵🏾‍♂' => 'мъж детектив: средно тъмна кожа',
    '🕵🏿‍♂' => 'мъж детектив: тъмна кожа',
    '🕵🏻‍♀' => 'жена детектив: светла кожа',
    '🕵🏼‍♀' => 'жена детектив: средно светла кожа',
    '🕵🏽‍♀' => 'жена детектив: средна на цвят кожа',
    '🕵🏾‍♀' => 'жена детектив: средно тъмна кожа',
    '🕵🏿‍♀' => 'жена детектив: тъмна кожа',
    '💂🏻‍♂' => 'мъж гвардеец: светла кожа',
    '💂🏼‍♂' => 'мъж гвардеец: средно светла кожа',
    '💂🏽‍♂' => 'мъж гвардеец: средна на цвят кожа',
    '💂🏾‍♂' => 'мъж гвардеец: средно тъмна кожа',
    '💂🏿‍♂' => 'мъж гвардеец: тъмна кожа',
    '💂🏻‍♀' => 'жена гвардеец: светла кожа',
    '💂🏼‍♀' => 'жена гвардеец: средно светла кожа',
    '💂🏽‍♀' => 'жена гвардеец: средна на цвят кожа',
    '💂🏾‍♀' => 'жена гвардеец: средно тъмна кожа',
    '💂🏿‍♀' => 'жена гвардеец: тъмна кожа',
    '👷🏻‍♂' => 'строителен работник: светла кожа',
    '👷🏼‍♂' => 'строителен работник: средно светла кожа',
    '👷🏽‍♂' => 'строителен работник: средна на цвят кожа',
    '👷🏾‍♂' => 'строителен работник: средно тъмна кожа',
    '👷🏿‍♂' => 'строителен работник: тъмна кожа',
    '👷🏻‍♀' => 'жена строителен работник: светла кожа',
    '👷🏼‍♀' => 'жена строителен работник: средно светла кожа',
    '👷🏽‍♀' => 'жена строителен работник: средна на цвят кожа',
    '👷🏾‍♀' => 'жена строителен работник: средно тъмна кожа',
    '👷🏿‍♀' => 'жена строителен работник: тъмна кожа',
    '👳🏻‍♂' => 'мъж с тюрбан: светла кожа',
    '👳🏼‍♂' => 'мъж с тюрбан: средно светла кожа',
    '👳🏽‍♂' => 'мъж с тюрбан: средна на цвят кожа',
    '👳🏾‍♂' => 'мъж с тюрбан: средно тъмна кожа',
    '👳🏿‍♂' => 'мъж с тюрбан: тъмна кожа',
    '👳🏻‍♀' => 'жена с тюрбан: светла кожа',
    '👳🏼‍♀' => 'жена с тюрбан: средно светла кожа',
    '👳🏽‍♀' => 'жена с тюрбан: средна на цвят кожа',
    '👳🏾‍♀' => 'жена с тюрбан: средно тъмна кожа',
    '👳🏿‍♀' => 'жена с тюрбан: тъмна кожа',
    '🤵🏻‍♂' => 'мъж във фрак: светла кожа',
    '🤵🏼‍♂' => 'мъж във фрак: средно светла кожа',
    '🤵🏽‍♂' => 'мъж във фрак: средна на цвят кожа',
    '🤵🏾‍♂' => 'мъж във фрак: средно тъмна кожа',
    '🤵🏿‍♂' => 'мъж във фрак: тъмна кожа',
    '🤵🏻‍♀' => 'жена във фрак: светла кожа',
    '🤵🏼‍♀' => 'жена във фрак: средно светла кожа',
    '🤵🏽‍♀' => 'жена във фрак: средна на цвят кожа',
    '🤵🏾‍♀' => 'жена във фрак: средно тъмна кожа',
    '🤵🏿‍♀' => 'жена във фрак: тъмна кожа',
    '👰🏻‍♂' => 'мъж с було: светла кожа',
    '👰🏼‍♂' => 'мъж с було: средно светла кожа',
    '👰🏽‍♂' => 'мъж с було: средна на цвят кожа',
    '👰🏾‍♂' => 'мъж с було: средно тъмна кожа',
    '👰🏿‍♂' => 'мъж с було: тъмна кожа',
    '👰🏻‍♀' => 'жена с було: светла кожа',
    '👰🏼‍♀' => 'жена с було: средно светла кожа',
    '👰🏽‍♀' => 'жена с було: средна на цвят кожа',
    '👰🏾‍♀' => 'жена с було: средно тъмна кожа',
    '👰🏿‍♀' => 'жена с було: тъмна кожа',
    '👩🏻‍🍼' => 'жена, хранеща бебе: светла кожа',
    '👩🏼‍🍼' => 'жена, хранеща бебе: средно светла кожа',
    '👩🏽‍🍼' => 'жена, хранеща бебе: средна на цвят кожа',
    '👩🏾‍🍼' => 'жена, хранеща бебе: средно тъмна кожа',
    '👩🏿‍🍼' => 'жена, хранеща бебе: тъмна кожа',
    '👨🏻‍🍼' => 'мъж, хранещ бебе: светла кожа',
    '👨🏼‍🍼' => 'мъж, хранещ бебе: средно светла кожа',
    '👨🏽‍🍼' => 'мъж, хранещ бебе: средна на цвят кожа',
    '👨🏾‍🍼' => 'мъж, хранещ бебе: средно тъмна кожа',
    '👨🏿‍🍼' => 'мъж, хранещ бебе: тъмна кожа',
    '🧑🏻‍🍼' => 'човек, хранещ бебе: светла кожа',
    '🧑🏼‍🍼' => 'човек, хранещ бебе: средно светла кожа',
    '🧑🏽‍🍼' => 'човек, хранещ бебе: средна на цвят кожа',
    '🧑🏾‍🍼' => 'човек, хранещ бебе: средно тъмна кожа',
    '🧑🏿‍🍼' => 'човек, хранещ бебе: тъмна кожа',
    '🧑🏻‍🎄' => 'г-х коледа: светла кожа',
    '🧑🏼‍🎄' => 'г-х коледа: средно светла кожа',
    '🧑🏽‍🎄' => 'г-х коледа: средна на цвят кожа',
    '🧑🏾‍🎄' => 'г-х коледа: средно тъмна кожа',
    '🧑🏿‍🎄' => 'г-х коледа: тъмна кожа',
    '🦸🏻‍♂' => 'супергерой: светла кожа',
    '🦸🏼‍♂' => 'супергерой: средно светла кожа',
    '🦸🏽‍♂' => 'супергерой: средна на цвят кожа',
    '🦸🏾‍♂' => 'супергерой: средно тъмна кожа',
    '🦸🏿‍♂' => 'супергерой: тъмна кожа',
    '🦸🏻‍♀' => 'супергерой от женски пол: светла кожа',
    '🦸🏼‍♀' => 'супергерой от женски пол: средно светла кожа',
    '🦸🏽‍♀' => 'супергерой от женски пол: средна на цвят кожа',
    '🦸🏾‍♀' => 'супергерой от женски пол: средно тъмна кожа',
    '🦸🏿‍♀' => 'супергерой от женски пол: тъмна кожа',
    '🦹🏻‍♂' => 'мъж суперзлодей: светла кожа',
    '🦹🏼‍♂' => 'мъж суперзлодей: средно светла кожа',
    '🦹🏽‍♂' => 'мъж суперзлодей: средна на цвят кожа',
    '🦹🏾‍♂' => 'мъж суперзлодей: средно тъмна кожа',
    '🦹🏿‍♂' => 'мъж суперзлодей: тъмна кожа',
    '🦹🏻‍♀' => 'жена суперзлодей: светла кожа',
    '🦹🏼‍♀' => 'жена суперзлодей: средно светла кожа',
    '🦹🏽‍♀' => 'жена суперзлодей: средна на цвят кожа',
    '🦹🏾‍♀' => 'жена суперзлодей: средно тъмна кожа',
    '🦹🏿‍♀' => 'жена суперзлодей: тъмна кожа',
    '🧙🏻‍♂' => 'мъж магьосник: светла кожа',
    '🧙🏼‍♂' => 'мъж магьосник: средно светла кожа',
    '🧙🏽‍♂' => 'мъж магьосник: средна на цвят кожа',
    '🧙🏾‍♂' => 'мъж магьосник: средно тъмна кожа',
    '🧙🏿‍♂' => 'мъж магьосник: тъмна кожа',
    '🧙🏻‍♀' => 'магьосница: светла кожа',
    '🧙🏼‍♀' => 'магьосница: средно светла кожа',
    '🧙🏽‍♀' => 'магьосница: средна на цвят кожа',
    '🧙🏾‍♀' => 'магьосница: средно тъмна кожа',
    '🧙🏿‍♀' => 'магьосница: тъмна кожа',
    '🧚🏻‍♂' => 'мъж фея: светла кожа',
    '🧚🏼‍♂' => 'мъж фея: средно светла кожа',
    '🧚🏽‍♂' => 'мъж фея: средна на цвят кожа',
    '🧚🏾‍♂' => 'мъж фея: средно тъмна кожа',
    '🧚🏿‍♂' => 'мъж фея: тъмна кожа',
    '🧚🏻‍♀' => 'жена фея: светла кожа',
    '🧚🏼‍♀' => 'жена фея: средно светла кожа',
    '🧚🏽‍♀' => 'жена фея: средна на цвят кожа',
    '🧚🏾‍♀' => 'жена фея: средно тъмна кожа',
    '🧚🏿‍♀' => 'жена фея: тъмна кожа',
    '🧛🏻‍♂' => 'мъж вампир: светла кожа',
    '🧛🏼‍♂' => 'мъж вампир: средно светла кожа',
    '🧛🏽‍♂' => 'мъж вампир: средна на цвят кожа',
    '🧛🏾‍♂' => 'мъж вампир: средно тъмна кожа',
    '🧛🏿‍♂' => 'мъж вампир: тъмна кожа',
    '🧛🏻‍♀' => 'жена вампир: светла кожа',
    '🧛🏼‍♀' => 'жена вампир: средно светла кожа',
    '🧛🏽‍♀' => 'жена вампир: средна на цвят кожа',
    '🧛🏾‍♀' => 'жена вампир: средно тъмна кожа',
    '🧛🏿‍♀' => 'жена вампир: тъмна кожа',
    '🧜🏻‍♂' => 'мъж амфибия: светла кожа',
    '🧜🏼‍♂' => 'мъж амфибия: средно светла кожа',
    '🧜🏽‍♂' => 'мъж амфибия: средна на цвят кожа',
    '🧜🏾‍♂' => 'мъж амфибия: средно тъмна кожа',
    '🧜🏿‍♂' => 'мъж амфибия: тъмна кожа',
    '🧜🏻‍♀' => 'русалка: светла кожа',
    '🧜🏼‍♀' => 'русалка: средно светла кожа',
    '🧜🏽‍♀' => 'русалка: средна на цвят кожа',
    '🧜🏾‍♀' => 'русалка: средно тъмна кожа',
    '🧜🏿‍♀' => 'русалка: тъмна кожа',
    '🧝🏻‍♂' => 'мъж елф: светла кожа',
    '🧝🏼‍♂' => 'мъж елф: средно светла кожа',
    '🧝🏽‍♂' => 'мъж елф: средна на цвят кожа',
    '🧝🏾‍♂' => 'мъж елф: средно тъмна кожа',
    '🧝🏿‍♂' => 'мъж елф: тъмна кожа',
    '🧝🏻‍♀' => 'жена елф: светла кожа',
    '🧝🏼‍♀' => 'жена елф: средно светла кожа',
    '🧝🏽‍♀' => 'жена елф: средна на цвят кожа',
    '🧝🏾‍♀' => 'жена елф: средно тъмна кожа',
    '🧝🏿‍♀' => 'жена елф: тъмна кожа',
    '💆🏻‍♂' => 'мъж с масажирано лице: светла кожа',
    '💆🏼‍♂' => 'мъж с масажирано лице: средно светла кожа',
    '💆🏽‍♂' => 'мъж с масажирано лице: средна на цвят кожа',
    '💆🏾‍♂' => 'мъж с масажирано лице: средно тъмна кожа',
    '💆🏿‍♂' => 'мъж с масажирано лице: тъмна кожа',
    '💆🏻‍♀' => 'жена с масажирано лице: светла кожа',
    '💆🏼‍♀' => 'жена с масажирано лице: средно светла кожа',
    '💆🏽‍♀' => 'жена с масажирано лице: средна на цвят кожа',
    '💆🏾‍♀' => 'жена с масажирано лице: средно тъмна кожа',
    '💆🏿‍♀' => 'жена с масажирано лице: тъмна кожа',
    '💇🏻‍♂' => 'подстригван мъж: светла кожа',
    '💇🏼‍♂' => 'подстригван мъж: средно светла кожа',
    '💇🏽‍♂' => 'подстригван мъж: средна на цвят кожа',
    '💇🏾‍♂' => 'подстригван мъж: средно тъмна кожа',
    '💇🏿‍♂' => 'подстригван мъж: тъмна кожа',
    '💇🏻‍♀' => 'подстригвана жена: светла кожа',
    '💇🏼‍♀' => 'подстригвана жена: средно светла кожа',
    '💇🏽‍♀' => 'подстригвана жена: средна на цвят кожа',
    '💇🏾‍♀' => 'подстригвана жена: средно тъмна кожа',
    '💇🏿‍♀' => 'подстригвана жена: тъмна кожа',
    '🚶🏻‍♂' => 'ходещ мъж: светла кожа',
    '🚶🏼‍♂' => 'ходещ мъж: средно светла кожа',
    '🚶🏽‍♂' => 'ходещ мъж: средна на цвят кожа',
    '🚶🏾‍♂' => 'ходещ мъж: средно тъмна кожа',
    '🚶🏿‍♂' => 'ходещ мъж: тъмна кожа',
    '🚶🏻‍♀' => 'ходеща жена: светла кожа',
    '🚶🏼‍♀' => 'ходеща жена: средно светла кожа',
    '🚶🏽‍♀' => 'ходеща жена: средна на цвят кожа',
    '🚶🏾‍♀' => 'ходеща жена: средно тъмна кожа',
    '🚶🏿‍♀' => 'ходеща жена: тъмна кожа',
    '🚶🏻‍➡' => 'пешеходец: светла кожа и в посока надясно',
    '🚶🏼‍➡' => 'пешеходец: средно светла кожа и в посока надясно',
    '🚶🏽‍➡' => 'пешеходец: средна на цвят кожа и в посока надясно',
    '🚶🏾‍➡' => 'пешеходец: средно тъмна кожа и в посока надясно',
    '🚶🏿‍➡' => 'пешеходец: тъмна кожа и в посока надясно',
    '🧍🏻‍♂' => 'изправен мъж: светла кожа',
    '🧍🏼‍♂' => 'изправен мъж: средно светла кожа',
    '🧍🏽‍♂' => 'изправен мъж: средна на цвят кожа',
    '🧍🏾‍♂' => 'изправен мъж: средно тъмна кожа',
    '🧍🏿‍♂' => 'изправен мъж: тъмна кожа',
    '🧍🏻‍♀' => 'изправена жена: светла кожа',
    '🧍🏼‍♀' => 'изправена жена: средно светла кожа',
    '🧍🏽‍♀' => 'изправена жена: средна на цвят кожа',
    '🧍🏾‍♀' => 'изправена жена: средно тъмна кожа',
    '🧍🏿‍♀' => 'изправена жена: тъмна кожа',
    '🧎🏻‍♂' => 'коленичил мъж: светла кожа',
    '🧎🏼‍♂' => 'коленичил мъж: средно светла кожа',
    '🧎🏽‍♂' => 'коленичил мъж: средна на цвят кожа',
    '🧎🏾‍♂' => 'коленичил мъж: средно тъмна кожа',
    '🧎🏿‍♂' => 'коленичил мъж: тъмна кожа',
    '🧎🏻‍♀' => 'коленичила жена: светла кожа',
    '🧎🏼‍♀' => 'коленичила жена: средно светла кожа',
    '🧎🏽‍♀' => 'коленичила жена: средна на цвят кожа',
    '🧎🏾‍♀' => 'коленичила жена: средно тъмна кожа',
    '🧎🏿‍♀' => 'коленичила жена: тъмна кожа',
    '🧎🏻‍➡' => 'коленичил човек: светла кожа и в посока надясно',
    '🧎🏼‍➡' => 'коленичил човек: средно светла кожа и в посока надясно',
    '🧎🏽‍➡' => 'коленичил човек: средна на цвят кожа и в посока надясно',
    '🧎🏾‍➡' => 'коленичил човек: средно тъмна кожа и в посока надясно',
    '🧎🏿‍➡' => 'коленичил човек: тъмна кожа и в посока надясно',
    '🧑🏻‍🦯' => 'човек с бял бастун: светла кожа',
    '🧑🏼‍🦯' => 'човек с бял бастун: средно светла кожа',
    '🧑🏽‍🦯' => 'човек с бял бастун: средна на цвят кожа',
    '🧑🏾‍🦯' => 'човек с бял бастун: средно тъмна кожа',
    '🧑🏿‍🦯' => 'човек с бял бастун: тъмна кожа',
    '👨🏻‍🦯' => 'мъж с бял бастун: светла кожа',
    '👨🏼‍🦯' => 'мъж с бял бастун: средно светла кожа',
    '👨🏽‍🦯' => 'мъж с бял бастун: средна на цвят кожа',
    '👨🏾‍🦯' => 'мъж с бял бастун: средно тъмна кожа',
    '👨🏿‍🦯' => 'мъж с бял бастун: тъмна кожа',
    '👩🏻‍🦯' => 'жена с бял бастун: светла кожа',
    '👩🏼‍🦯' => 'жена с бял бастун: средно светла кожа',
    '👩🏽‍🦯' => 'жена с бял бастун: средна на цвят кожа',
    '👩🏾‍🦯' => 'жена с бял бастун: средно тъмна кожа',
    '👩🏿‍🦯' => 'жена с бял бастун: тъмна кожа',
    '🧑🏻‍🦼' => 'човек в моторизирана инвалидна количка: светла кожа',
    '🧑🏼‍🦼' => 'човек в моторизирана инвалидна количка: средно светла кожа',
    '🧑🏽‍🦼' => 'човек в моторизирана инвалидна количка: средна на цвят кожа',
    '🧑🏾‍🦼' => 'човек в моторизирана инвалидна количка: средно тъмна кожа',
    '🧑🏿‍🦼' => 'човек в моторизирана инвалидна количка: тъмна кожа',
    '👨🏻‍🦼' => 'мъж в акумулаторна инвалидна количка: светла кожа',
    '👨🏼‍🦼' => 'мъж в акумулаторна инвалидна количка: средно светла кожа',
    '👨🏽‍🦼' => 'мъж в акумулаторна инвалидна количка: средна на цвят кожа',
    '👨🏾‍🦼' => 'мъж в акумулаторна инвалидна количка: средно тъмна кожа',
    '👨🏿‍🦼' => 'мъж в акумулаторна инвалидна количка: тъмна кожа',
    '👩🏻‍🦼' => 'жена в акумулаторна инвалидна количка: светла кожа',
    '👩🏼‍🦼' => 'жена в акумулаторна инвалидна количка: средно светла кожа',
    '👩🏽‍🦼' => 'жена в акумулаторна инвалидна количка: средна на цвят кожа',
    '👩🏾‍🦼' => 'жена в акумулаторна инвалидна количка: средно тъмна кожа',
    '👩🏿‍🦼' => 'жена в акумулаторна инвалидна количка: тъмна кожа',
    '🧑🏻‍🦽' => 'човек в инвалидна количка: светла кожа',
    '🧑🏼‍🦽' => 'човек в инвалидна количка: средно светла кожа',
    '🧑🏽‍🦽' => 'човек в инвалидна количка: средна на цвят кожа',
    '🧑🏾‍🦽' => 'човек в инвалидна количка: средно тъмна кожа',
    '🧑🏿‍🦽' => 'човек в инвалидна количка: тъмна кожа',
    '👨🏻‍🦽' => 'мъж в инвалидна количка: светла кожа',
    '👨🏼‍🦽' => 'мъж в инвалидна количка: средно светла кожа',
    '👨🏽‍🦽' => 'мъж в инвалидна количка: средна на цвят кожа',
    '👨🏾‍🦽' => 'мъж в инвалидна количка: средно тъмна кожа',
    '👨🏿‍🦽' => 'мъж в инвалидна количка: тъмна кожа',
    '👩🏻‍🦽' => 'жена в инвалидна количка: светла кожа',
    '👩🏼‍🦽' => 'жена в инвалидна количка: средно светла кожа',
    '👩🏽‍🦽' => 'жена в инвалидна количка: средна на цвят кожа',
    '👩🏾‍🦽' => 'жена в инвалидна количка: средно тъмна кожа',
    '👩🏿‍🦽' => 'жена в инвалидна количка: тъмна кожа',
    '🏃🏻‍♂' => 'тичащ мъж: светла кожа',
    '🏃🏼‍♂' => 'тичащ мъж: средно светла кожа',
    '🏃🏽‍♂' => 'тичащ мъж: средна на цвят кожа',
    '🏃🏾‍♂' => 'тичащ мъж: средно тъмна кожа',
    '🏃🏿‍♂' => 'тичащ мъж: тъмна кожа',
    '🏃🏻‍♀' => 'тичаща жена: светла кожа',
    '🏃🏼‍♀' => 'тичаща жена: средно светла кожа',
    '🏃🏽‍♀' => 'тичаща жена: средна на цвят кожа',
    '🏃🏾‍♀' => 'тичаща жена: средно тъмна кожа',
    '🏃🏿‍♀' => 'тичаща жена: тъмна кожа',
    '🏃🏻‍➡' => 'бегач: светла кожа и в посока надясно',
    '🏃🏼‍➡' => 'бегач: средно светла кожа и в посока надясно',
    '🏃🏽‍➡' => 'бегач: средна на цвят кожа и в посока надясно',
    '🏃🏾‍➡' => 'бегач: средно тъмна кожа и в посока надясно',
    '🏃🏿‍➡' => 'бегач: тъмна кожа и в посока надясно',
    '👯🏻‍♀' => 'забавляващи се жени със заешки уши: светла кожа',
    '👯🏼‍♀' => 'забавляващи се жени със заешки уши: средно светла кожа',
    '👯🏽‍♀' => 'забавляващи се жени със заешки уши: средна на цвят кожа',
    '👯🏾‍♀' => 'забавляващи се жени със заешки уши: средно тъмна кожа',
    '👯🏿‍♀' => 'забавляващи се жени със заешки уши: тъмна кожа',
    '👯🏻‍♂' => 'веселящи се мъже със заешки уши: светла кожа',
    '👯🏼‍♂' => 'веселящи се мъже със заешки уши: средно светла кожа',
    '👯🏽‍♂' => 'веселящи се мъже със заешки уши: средна на цвят кожа',
    '👯🏾‍♂' => 'веселящи се мъже със заешки уши: средно тъмна кожа',
    '👯🏿‍♂' => 'веселящи се мъже със заешки уши: тъмна кожа',
    '🧖🏻‍♂' => 'мъж в помещение с пара: светла кожа',
    '🧖🏼‍♂' => 'мъж в помещение с пара: средно светла кожа',
    '🧖🏽‍♂' => 'мъж в помещение с пара: средна на цвят кожа',
    '🧖🏾‍♂' => 'мъж в помещение с пара: средно тъмна кожа',
    '🧖🏿‍♂' => 'мъж в помещение с пара: тъмна кожа',
    '🧖🏻‍♀' => 'жена в помещение с пара: светла кожа',
    '🧖🏼‍♀' => 'жена в помещение с пара: средно светла кожа',
    '🧖🏽‍♀' => 'жена в помещение с пара: средна на цвят кожа',
    '🧖🏾‍♀' => 'жена в помещение с пара: средно тъмна кожа',
    '🧖🏿‍♀' => 'жена в помещение с пара: тъмна кожа',
    '🧗🏻‍♂' => 'катерач: светла кожа',
    '🧗🏼‍♂' => 'катерач: средно светла кожа',
    '🧗🏽‍♂' => 'катерач: средна на цвят кожа',
    '🧗🏾‍♂' => 'катерач: средно тъмна кожа',
    '🧗🏿‍♂' => 'катерач: тъмна кожа',
    '🧗🏻‍♀' => 'катерачка: светла кожа',
    '🧗🏼‍♀' => 'катерачка: средно светла кожа',
    '🧗🏽‍♀' => 'катерачка: средна на цвят кожа',
    '🧗🏾‍♀' => 'катерачка: средно тъмна кожа',
    '🧗🏿‍♀' => 'катерачка: тъмна кожа',
    '🏌🏻‍♂' => 'мъж, играещ голф: светла кожа',
    '🏌🏼‍♂' => 'мъж, играещ голф: средно светла кожа',
    '🏌🏽‍♂' => 'мъж, играещ голф: средна на цвят кожа',
    '🏌🏾‍♂' => 'мъж, играещ голф: средно тъмна кожа',
    '🏌🏿‍♂' => 'мъж, играещ голф: тъмна кожа',
    '🏌🏻‍♀' => 'жена, играеща голф: светла кожа',
    '🏌🏼‍♀' => 'жена, играеща голф: средно светла кожа',
    '🏌🏽‍♀' => 'жена, играеща голф: средна на цвят кожа',
    '🏌🏾‍♀' => 'жена, играеща голф: средно тъмна кожа',
    '🏌🏿‍♀' => 'жена, играеща голф: тъмна кожа',
    '🏄🏻‍♂' => 'мъж, каращ сърф: светла кожа',
    '🏄🏼‍♂' => 'мъж, каращ сърф: средно светла кожа',
    '🏄🏽‍♂' => 'мъж, каращ сърф: средна на цвят кожа',
    '🏄🏾‍♂' => 'мъж, каращ сърф: средно тъмна кожа',
    '🏄🏿‍♂' => 'мъж, каращ сърф: тъмна кожа',
    '🏄🏻‍♀' => 'сърфистка: светла кожа',
    '🏄🏼‍♀' => 'сърфистка: средно светла кожа',
    '🏄🏽‍♀' => 'сърфистка: средна на цвят кожа',
    '🏄🏾‍♀' => 'сърфистка: средно тъмна кожа',
    '🏄🏿‍♀' => 'сърфистка: тъмна кожа',
    '🚣🏻‍♂' => 'гребящ мъж: светла кожа',
    '🚣🏼‍♂' => 'гребящ мъж: средно светла кожа',
    '🚣🏽‍♂' => 'гребящ мъж: средна на цвят кожа',
    '🚣🏾‍♂' => 'гребящ мъж: средно тъмна кожа',
    '🚣🏿‍♂' => 'гребящ мъж: тъмна кожа',
    '🚣🏻‍♀' => 'гребяща жена: светла кожа',
    '🚣🏼‍♀' => 'гребяща жена: средно светла кожа',
    '🚣🏽‍♀' => 'гребяща жена: средна на цвят кожа',
    '🚣🏾‍♀' => 'гребяща жена: средно тъмна кожа',
    '🚣🏿‍♀' => 'гребяща жена: тъмна кожа',
    '🏊🏻‍♂' => 'плуващ мъж: светла кожа',
    '🏊🏼‍♂' => 'плуващ мъж: средно светла кожа',
    '🏊🏽‍♂' => 'плуващ мъж: средна на цвят кожа',
    '🏊🏾‍♂' => 'плуващ мъж: средно тъмна кожа',
    '🏊🏿‍♂' => 'плуващ мъж: тъмна кожа',
    '🏊🏻‍♀' => 'плувкиня: светла кожа',
    '🏊🏼‍♀' => 'плувкиня: средно светла кожа',
    '🏊🏽‍♀' => 'плувкиня: средна на цвят кожа',
    '🏊🏾‍♀' => 'плувкиня: средно тъмна кожа',
    '🏊🏿‍♀' => 'плувкиня: тъмна кожа',
    '⛹🏻‍♂' => 'мъж с топка: светла кожа',
    '⛹🏼‍♂' => 'мъж с топка: средно светла кожа',
    '⛹🏽‍♂' => 'мъж с топка: средна на цвят кожа',
    '⛹🏾‍♂' => 'мъж с топка: средно тъмна кожа',
    '⛹🏿‍♂' => 'мъж с топка: тъмна кожа',
    '⛹🏻‍♀' => 'жена с топка: светла кожа',
    '⛹🏼‍♀' => 'жена с топка: средно светла кожа',
    '⛹🏽‍♀' => 'жена с топка: средна на цвят кожа',
    '⛹🏾‍♀' => 'жена с топка: средно тъмна кожа',
    '⛹🏿‍♀' => 'жена с топка: тъмна кожа',
    '🏋🏻‍♂' => 'вдигащ тежести мъж: светла кожа',
    '🏋🏼‍♂' => 'вдигащ тежести мъж: средно светла кожа',
    '🏋🏽‍♂' => 'вдигащ тежести мъж: средна на цвят кожа',
    '🏋🏾‍♂' => 'вдигащ тежести мъж: средно тъмна кожа',
    '🏋🏿‍♂' => 'вдигащ тежести мъж: тъмна кожа',
    '🏋🏻‍♀' => 'вдигаща тежести жена: светла кожа',
    '🏋🏼‍♀' => 'вдигаща тежести жена: средно светла кожа',
    '🏋🏽‍♀' => 'вдигаща тежести жена: средна на цвят кожа',
    '🏋🏾‍♀' => 'вдигаща тежести жена: средно тъмна кожа',
    '🏋🏿‍♀' => 'вдигаща тежести жена: тъмна кожа',
    '🚴🏻‍♂' => 'мъж на велосипед: светла кожа',
    '🚴🏼‍♂' => 'мъж на велосипед: средно светла кожа',
    '🚴🏽‍♂' => 'мъж на велосипед: средна на цвят кожа',
    '🚴🏾‍♂' => 'мъж на велосипед: средно тъмна кожа',
    '🚴🏿‍♂' => 'мъж на велосипед: тъмна кожа',
    '🚴🏻‍♀' => 'велосипедистка: светла кожа',
    '🚴🏼‍♀' => 'велосипедистка: средно светла кожа',
    '🚴🏽‍♀' => 'велосипедистка: средна на цвят кожа',
    '🚴🏾‍♀' => 'велосипедистка: средно тъмна кожа',
    '🚴🏿‍♀' => 'велосипедистка: тъмна кожа',
    '🚵🏻‍♂' => 'мъж на планински велосипед: светла кожа',
    '🚵🏼‍♂' => 'мъж на планински велосипед: средно светла кожа',
    '🚵🏽‍♂' => 'мъж на планински велосипед: средна на цвят кожа',
    '🚵🏾‍♂' => 'мъж на планински велосипед: средно тъмна кожа',
    '🚵🏿‍♂' => 'мъж на планински велосипед: тъмна кожа',
    '🚵🏻‍♀' => 'жена на планински велосипед: светла кожа',
    '🚵🏼‍♀' => 'жена на планински велосипед: средно светла кожа',
    '🚵🏽‍♀' => 'жена на планински велосипед: средна на цвят кожа',
    '🚵🏾‍♀' => 'жена на планински велосипед: средно тъмна кожа',
    '🚵🏿‍♀' => 'жена на планински велосипед: тъмна кожа',
    '🤸🏻‍♂' => 'акробат: светла кожа',
    '🤸🏼‍♂' => 'акробат: средно светла кожа',
    '🤸🏽‍♂' => 'акробат: средна на цвят кожа',
    '🤸🏾‍♂' => 'акробат: средно тъмна кожа',
    '🤸🏿‍♂' => 'акробат: тъмна кожа',
    '🤸🏻‍♀' => 'акробатка: светла кожа',
    '🤸🏼‍♀' => 'акробатка: средно светла кожа',
    '🤸🏽‍♀' => 'акробатка: средна на цвят кожа',
    '🤸🏾‍♀' => 'акробатка: средно тъмна кожа',
    '🤸🏿‍♀' => 'акробатка: тъмна кожа',
    '🤼🏻‍♀' => 'борещи се жени: светла кожа',
    '🤼🏼‍♀' => 'борещи се жени: средно светла кожа',
    '🤼🏽‍♀' => 'борещи се жени: средна на цвят кожа',
    '🤼🏾‍♀' => 'борещи се жени: средно тъмна кожа',
    '🤼🏿‍♀' => 'борещи се жени: тъмна кожа',
    '🤼🏻‍♂' => 'борещи се мъже: светла кожа',
    '🤼🏼‍♂' => 'борещи се мъже: средно светла кожа',
    '🤼🏽‍♂' => 'борещи се мъже: средна на цвят кожа',
    '🤼🏾‍♂' => 'борещи се мъже: средно тъмна кожа',
    '🤼🏿‍♂' => 'борещи се мъже: тъмна кожа',
    '🤽🏻‍♂' => 'мъж, играещ водна топка: светла кожа',
    '🤽🏼‍♂' => 'мъж, играещ водна топка: средно светла кожа',
    '🤽🏽‍♂' => 'мъж, играещ водна топка: средна на цвят кожа',
    '🤽🏾‍♂' => 'мъж, играещ водна топка: средно тъмна кожа',
    '🤽🏿‍♂' => 'мъж, играещ водна топка: тъмна кожа',
    '🤽🏻‍♀' => 'жена, играеща водна топка: светла кожа',
    '🤽🏼‍♀' => 'жена, играеща водна топка: средно светла кожа',
    '🤽🏽‍♀' => 'жена, играеща водна топка: средна на цвят кожа',
    '🤽🏾‍♀' => 'жена, играеща водна топка: средно тъмна кожа',
    '🤽🏿‍♀' => 'жена, играеща водна топка: тъмна кожа',
    '🤾🏻‍♂' => 'хандбалист: светла кожа',
    '🤾🏼‍♂' => 'хандбалист: средно светла кожа',
    '🤾🏽‍♂' => 'хандбалист: средна на цвят кожа',
    '🤾🏾‍♂' => 'хандбалист: средно тъмна кожа',
    '🤾🏿‍♂' => 'хандбалист: тъмна кожа',
    '🤾🏻‍♀' => 'хандбалистка: светла кожа',
    '🤾🏼‍♀' => 'хандбалистка: средно светла кожа',
    '🤾🏽‍♀' => 'хандбалистка: средна на цвят кожа',
    '🤾🏾‍♀' => 'хандбалистка: средно тъмна кожа',
    '🤾🏿‍♀' => 'хандбалистка: тъмна кожа',
    '🤹🏻‍♂' => 'жонгльор: светла кожа',
    '🤹🏼‍♂' => 'жонгльор: средно светла кожа',
    '🤹🏽‍♂' => 'жонгльор: средна на цвят кожа',
    '🤹🏾‍♂' => 'жонгльор: средно тъмна кожа',
    '🤹🏿‍♂' => 'жонгльор: тъмна кожа',
    '🤹🏻‍♀' => 'жонгльорка: светла кожа',
    '🤹🏼‍♀' => 'жонгльорка: средно светла кожа',
    '🤹🏽‍♀' => 'жонгльорка: средна на цвят кожа',
    '🤹🏾‍♀' => 'жонгльорка: средно тъмна кожа',
    '🤹🏿‍♀' => 'жонгльорка: тъмна кожа',
    '🧘🏻‍♂' => 'мъж в поза „лотос“: светла кожа',
    '🧘🏼‍♂' => 'мъж в поза „лотос“: средно светла кожа',
    '🧘🏽‍♂' => 'мъж в поза „лотос“: средна на цвят кожа',
    '🧘🏾‍♂' => 'мъж в поза „лотос“: средно тъмна кожа',
    '🧘🏿‍♂' => 'мъж в поза „лотос“: тъмна кожа',
    '🧘🏻‍♀' => 'жена в поза „лотос“: светла кожа',
    '🧘🏼‍♀' => 'жена в поза „лотос“: средно светла кожа',
    '🧘🏽‍♀' => 'жена в поза „лотос“: средна на цвят кожа',
    '🧘🏾‍♀' => 'жена в поза „лотос“: средно тъмна кожа',
    '🧘🏿‍♀' => 'жена в поза „лотос“: тъмна кожа',
    '🧑‍🦰' => 'възрастен: рижа коса',
    '🧑‍🦱' => 'възрастен: къдрава коса',
    '🧑‍🦳' => 'възрастен: побеляла коса',
    '🧑‍🦲' => 'възрастен: плешив човек',
    '👨‍🦰' => 'мъж: рижа коса',
    '👨‍🦱' => 'мъж: къдрава коса',
    '👨‍🦳' => 'мъж: побеляла коса',
    '👨‍🦲' => 'мъж: плешив човек',
    '👩‍🦰' => 'жена: рижа коса',
    '👩‍🦱' => 'жена: къдрава коса',
    '👩‍🦳' => 'жена: побеляла коса',
    '👩‍🦲' => 'жена: плешив човек',
    '🚶‍➡' => 'пешеходец: в посока надясно',
    '🧎‍➡' => 'коленичил човек: в посока надясно',
    '🏃‍➡' => 'бегач: в посока надясно',
    '👨‍👦' => 'семейство: мъж и момче',
    '👨‍👧' => 'семейство: мъж и момиче',
    '👩‍👦' => 'семейство: жена и момче',
    '👩‍👧' => 'семейство: жена и момиче',
    '😶‍🌫' => 'лице в облаци',
    '😮‍💨' => 'издишващо лице',
    '🙂‍↕' => 'глава, която прави вертикални движения',
    '😵‍💫' => 'лице със спираловидни очи',
    '❤‍🔥' => 'сърце в пламъци',
    '❤‍🩹' => 'превързано сърце',
    '👁‍🗨' => 'око в балонче за говор',
    '🧔‍♂' => 'мъж: брада',
    '👱‍♂' => 'блондин',
    '🧔‍♀' => 'жена: брада',
    '👱‍♀' => 'блондинка',
    '🙍‍♂' => 'намръщен мъж',
    '🙍‍♀' => 'намръщена жена',
    '🙎‍♂' => 'нацупен мъж',
    '🙎‍♀' => 'нацупена жена',
    '🙅‍♂' => 'мъж, правещ жест за „не“',
    '🙅‍♀' => 'жена, правеща жест за „не“',
    '🙆‍♂' => 'мъж, правещ жест за „окей“',
    '🙆‍♀' => 'жена, правеща жест за „окей“',
    '💁‍♂' => 'мъж от информационна служба',
    '💁‍♀' => 'жена от информационна служба',
    '🙋‍♂' => 'щастлив мъж, вдигнал ръка',
    '🙋‍♀' => 'щастлива жена, вдигнала ръка',
    '🧏‍♂' => 'глух мъж',
    '🧏‍♀' => 'глуха жена',
    '🙇‍♂' => 'покланящ се мъж',
    '🙇‍♀' => 'покланяща се жена',
    '🤦‍♂' => 'мъж с ръка върху лицето',
    '🤦‍♀' => 'жена с ръка върху лицето',
    '🤷‍♂' => 'мъж свива рамене',
    '🤷‍♀' => 'жена свива рамене',
    '🧑‍⚕' => 'здравен служител',
    '👨‍⚕' => 'здравен работник',
    '👩‍⚕' => 'здравна работничка',
    '🧑‍🎓' => 'учащ',
    '👨‍🎓' => 'студент',
    '👩‍🎓' => 'студентка',
    '🧑‍🏫' => 'преподавател',
    '👨‍🏫' => 'учител',
    '👩‍🏫' => 'учителка',
    '🧑‍⚖' => 'съдия',
    '👨‍⚖' => 'мъж съдия',
    '👩‍⚖' => 'съдийка',
    '🧑‍🌾' => 'земеделец',
    '👨‍🌾' => 'фермер',
    '👩‍🌾' => 'фермерка',
    '🧑‍🍳' => 'готвач',
    '👨‍🍳' => 'мъж готвач',
    '👩‍🍳' => 'готвачка',
    '🧑‍🔧' => 'механик',
    '👨‍🔧' => 'мъж механик',
    '👩‍🔧' => 'жена механик',
    '🧑‍🏭' => 'работник във фабрика',
    '👨‍🏭' => 'работник в завод',
    '👩‍🏭' => 'работничка в завод',
    '🧑‍💼' => 'служител',
    '👨‍💼' => 'служител в офис',
    '👩‍💼' => 'служителка в офис',
    '🧑‍🔬' => 'учен',
    '👨‍🔬' => 'мъж учен',
    '👩‍🔬' => 'жена учен',
    '🧑‍💻' => 'програмист',
    '👨‍💻' => 'мъж в сферата на технологиите',
    '👩‍💻' => 'жена в сферата на технологиите',
    '🧑‍🎤' => 'певец',
    '👨‍🎤' => 'мъж певец',
    '👩‍🎤' => 'певица',
    '🧑‍🎨' => 'художник',
    '👨‍🎨' => 'мъж художник',
    '👩‍🎨' => 'художничка',
    '🧑‍✈' => 'пилот',
    '👨‍✈' => 'мъж пилот',
    '👩‍✈' => 'жена пилот',
    '🧑‍🚀' => 'астронавт',
    '👨‍🚀' => 'космонавт',
    '👩‍🚀' => 'жена космонавт',
    '🧑‍🚒' => 'пожарникар',
    '👨‍🚒' => 'мъж пожарникар',
    '👩‍🚒' => 'жена пожарникар',
    '👮‍♂' => 'полицай',
    '👮‍♀' => 'полицайка',
    '🕵‍♂' => 'мъж детектив',
    '🕵‍♀' => 'жена детектив',
    '💂‍♂' => 'мъж гвардеец',
    '💂‍♀' => 'жена гвардеец',
    '👷‍♂' => 'строителен работник',
    '👷‍♀' => 'жена строителен работник',
    '👳‍♂' => 'мъж с тюрбан',
    '👳‍♀' => 'жена с тюрбан',
    '🤵‍♂' => 'мъж във фрак',
    '🤵‍♀' => 'жена във фрак',
    '👰‍♂' => 'мъж с було',
    '👰‍♀' => 'жена с було',
    '👩‍🍼' => 'жена, хранеща бебе',
    '👨‍🍼' => 'мъж, хранещ бебе',
    '🧑‍🍼' => 'човек, хранещ бебе',
    '🧑‍🎄' => 'г-х коледа',
    '🦸‍♂' => 'супергерой',
    '🦸‍♀' => 'супергерой от женски пол',
    '🦹‍♂' => 'мъж суперзлодей',
    '🦹‍♀' => 'жена суперзлодей',
    '🧙‍♂' => 'мъж магьосник',
    '🧙‍♀' => 'магьосница',
    '🧚‍♂' => 'мъж фея',
    '🧚‍♀' => 'жена фея',
    '🧛‍♂' => 'мъж вампир',
    '🧛‍♀' => 'жена вампир',
    '🧜‍♂' => 'мъж амфибия',
    '🧜‍♀' => 'русалка',
    '🧝‍♂' => 'мъж елф',
    '🧝‍♀' => 'жена елф',
    '🧞‍♂' => 'мъж джин',
    '🧞‍♀' => 'жена джин',
    '🧟‍♂' => 'мъж зомби',
    '🧟‍♀' => 'жена зомби',
    '💆‍♂' => 'мъж с масажирано лице',
    '💆‍♀' => 'жена с масажирано лице',
    '💇‍♂' => 'подстригван мъж',
    '💇‍♀' => 'подстригвана жена',
    '🚶‍♂' => 'ходещ мъж',
    '🚶‍♀' => 'ходеща жена',
    '🧍‍♂' => 'изправен мъж',
    '🧍‍♀' => 'изправена жена',
    '🧎‍♂' => 'коленичил мъж',
    '🧎‍♀' => 'коленичила жена',
    '🧑‍🦯' => 'човек с бял бастун',
    '👨‍🦯' => 'мъж с бял бастун',
    '👩‍🦯' => 'жена с бял бастун',
    '🧑‍🦼' => 'човек в моторизирана инвалидна количка',
    '👨‍🦼' => 'мъж в акумулаторна инвалидна количка',
    '👩‍🦼' => 'жена в акумулаторна инвалидна количка',
    '🧑‍🦽' => 'човек в инвалидна количка',
    '👨‍🦽' => 'мъж в инвалидна количка',
    '👩‍🦽' => 'жена в инвалидна количка',
    '🏃‍♂' => 'тичащ мъж',
    '🏃‍♀' => 'тичаща жена',
    '🧑‍🩰' => 'балерина',
    '👯‍♂' => 'веселящи се мъже със заешки уши',
    '👯‍♀' => 'забавляващи се жени със заешки уши',
    '🧖‍♂' => 'мъж в помещение с пара',
    '🧖‍♀' => 'жена в помещение с пара',
    '🧗‍♂' => 'катерач',
    '🧗‍♀' => 'катерачка',
    '🏌‍♂' => 'мъж, играещ голф',
    '🏌‍♀' => 'жена, играеща голф',
    '🏄‍♂' => 'мъж, каращ сърф',
    '🏄‍♀' => 'сърфистка',
    '🚣‍♂' => 'гребящ мъж',
    '🚣‍♀' => 'гребяща жена',
    '🏊‍♂' => 'плуващ мъж',
    '🏊‍♀' => 'плувкиня',
    '⛹‍♂' => 'мъж с топка',
    '⛹‍♀' => 'жена с топка',
    '🏋‍♂' => 'вдигащ тежести мъж',
    '🏋‍♀' => 'вдигаща тежести жена',
    '🚴‍♂' => 'мъж на велосипед',
    '🚴‍♀' => 'велосипедистка',
    '🚵‍♂' => 'мъж на планински велосипед',
    '🚵‍♀' => 'жена на планински велосипед',
    '🤸‍♂' => 'акробат',
    '🤸‍♀' => 'акробатка',
    '🤼‍♂' => 'борещи се мъже',
    '🤼‍♀' => 'борещи се жени',
    '🤽‍♂' => 'мъж, играещ водна топка',
    '🤽‍♀' => 'жена, играеща водна топка',
    '🤾‍♂' => 'хандбалист',
    '🤾‍♀' => 'хандбалистка',
    '🤹‍♂' => 'жонгльор',
    '🤹‍♀' => 'жонгльорка',
    '🧘‍♂' => 'мъж в поза „лотос“',
    '🧘‍♀' => 'жена в поза „лотос“',
    '🧑‍🧒' => 'семейство: възрастен, дете',
    '🐕‍🦺' => 'служебно куче',
    '🐈‍⬛' => 'черна котка',
    '🐻‍❄' => 'бяла мечка',
    '🐦‍⬛' => 'кос',
    '🐦‍🔥' => 'феникс',
    '🍋‍🟩' => 'лайм',
    '🍄‍🟫' => 'кафява печурка',
    '⛓‍💥' => 'скъсана верига',
    '🏳‍🌈' => 'флагът на дъгата',
    '🏳‍⚧' => 'знаме в синьо, розово и бяло',
    '🏴‍☠' => 'пиратски флаг',
    '👋🏻' => 'Махане с ръка: светла кожа',
    '👋🏼' => 'Махане с ръка: средно светла кожа',
    '👋🏽' => 'Махане с ръка: средна на цвят кожа',
    '👋🏾' => 'Махане с ръка: средно тъмна кожа',
    '👋🏿' => 'Махане с ръка: тъмна кожа',
    '🤚🏻' => 'вдигната длан: светла кожа',
    '🤚🏼' => 'вдигната длан: средно светла кожа',
    '🤚🏽' => 'вдигната длан: средна на цвят кожа',
    '🤚🏾' => 'вдигната длан: средно тъмна кожа',
    '🤚🏿' => 'вдигната длан: тъмна кожа',
    '🖐🏻' => 'Вдигната ръка с разперени пръсти: светла кожа',
    '🖐🏼' => 'Вдигната ръка с разперени пръсти: средно светла кожа',
    '🖐🏽' => 'Вдигната ръка с разперени пръсти: средна на цвят кожа',
    '🖐🏾' => 'Вдигната ръка с разперени пръсти: средно тъмна кожа',
    '🖐🏿' => 'Вдигната ръка с разперени пръсти: тъмна кожа',
    '✋🏻' => 'Вдигната ръка: светла кожа',
    '✋🏼' => 'Вдигната ръка: средно светла кожа',
    '✋🏽' => 'Вдигната ръка: средна на цвят кожа',
    '✋🏾' => 'Вдигната ръка: средно тъмна кожа',
    '✋🏿' => 'Вдигната ръка: тъмна кожа',
    '🖖🏻' => 'Поздрав на вулканите: светла кожа',
    '🖖🏼' => 'Поздрав на вулканите: средно светла кожа',
    '🖖🏽' => 'Поздрав на вулканите: средна на цвят кожа',
    '🖖🏾' => 'Поздрав на вулканите: средно тъмна кожа',
    '🖖🏿' => 'Поздрав на вулканите: тъмна кожа',
    '🫱🏻' => 'сочеща надясно ръка: светла кожа',
    '🫱🏼' => 'сочеща надясно ръка: средно светла кожа',
    '🫱🏽' => 'сочеща надясно ръка: средна на цвят кожа',
    '🫱🏾' => 'сочеща надясно ръка: средно тъмна кожа',
    '🫱🏿' => 'сочеща надясно ръка: тъмна кожа',
    '🫲🏻' => 'сочеща наляво ръка: светла кожа',
    '🫲🏼' => 'сочеща наляво ръка: средно светла кожа',
    '🫲🏽' => 'сочеща наляво ръка: средна на цвят кожа',
    '🫲🏾' => 'сочеща наляво ръка: средно тъмна кожа',
    '🫲🏿' => 'сочеща наляво ръка: тъмна кожа',
    '🫳🏻' => 'ръка с длан надолу: светла кожа',
    '🫳🏼' => 'ръка с длан надолу: средно светла кожа',
    '🫳🏽' => 'ръка с длан надолу: средна на цвят кожа',
    '🫳🏾' => 'ръка с длан надолу: средно тъмна кожа',
    '🫳🏿' => 'ръка с длан надолу: тъмна кожа',
    '🫴🏻' => 'ръка с длан нагоре: светла кожа',
    '🫴🏼' => 'ръка с длан нагоре: средно светла кожа',
    '🫴🏽' => 'ръка с длан нагоре: средна на цвят кожа',
    '🫴🏾' => 'ръка с длан нагоре: средно тъмна кожа',
    '🫴🏿' => 'ръка с длан нагоре: тъмна кожа',
    '🫷🏻' => 'натискаща наляво ръка: светла кожа',
    '🫷🏼' => 'натискаща наляво ръка: средно светла кожа',
    '🫷🏽' => 'натискаща наляво ръка: средна на цвят кожа',
    '🫷🏾' => 'натискаща наляво ръка: средно тъмна кожа',
    '🫷🏿' => 'натискаща наляво ръка: тъмна кожа',
    '🫸🏻' => 'натискаща надясно ръка: светла кожа',
    '🫸🏼' => 'натискаща надясно ръка: средно светла кожа',
    '🫸🏽' => 'натискаща надясно ръка: средна на цвят кожа',
    '🫸🏾' => 'натискаща надясно ръка: средно тъмна кожа',
    '🫸🏿' => 'натискаща надясно ръка: тъмна кожа',
    '👌🏻' => 'Жест „окей“: светла кожа',
    '👌🏼' => 'Жест „окей“: средно светла кожа',
    '👌🏽' => 'Жест „окей“: средна на цвят кожа',
    '👌🏾' => 'Жест „окей“: средно тъмна кожа',
    '👌🏿' => 'Жест „окей“: тъмна кожа',
    '🤌🏻' => 'събрани пръсти: светла кожа',
    '🤌🏼' => 'събрани пръсти: средно светла кожа',
    '🤌🏽' => 'събрани пръсти: средна на цвят кожа',
    '🤌🏾' => 'събрани пръсти: средно тъмна кожа',
    '🤌🏿' => 'събрани пръсти: тъмна кожа',
    '🤏🏻' => 'ръка с приближени палец и показалец: светла кожа',
    '🤏🏼' => 'ръка с приближени палец и показалец: средно светла кожа',
    '🤏🏽' => 'ръка с приближени палец и показалец: средна на цвят кожа',
    '🤏🏾' => 'ръка с приближени палец и показалец: средно тъмна кожа',
    '🤏🏿' => 'ръка с приближени палец и показалец: тъмна кожа',
    '✌🏻' => 'Жест за победа: светла кожа',
    '✌🏼' => 'Жест за победа: средно светла кожа',
    '✌🏽' => 'Жест за победа: средна на цвят кожа',
    '✌🏾' => 'Жест за победа: средно тъмна кожа',
    '✌🏿' => 'Жест за победа: тъмна кожа',
    '🤞🏻' => 'стискане на палци: светла кожа',
    '🤞🏼' => 'стискане на палци: средно светла кожа',
    '🤞🏽' => 'стискане на палци: средна на цвят кожа',
    '🤞🏾' => 'стискане на палци: средно тъмна кожа',
    '🤞🏿' => 'стискане на палци: тъмна кожа',
    '🫰🏻' => 'ръка с преплетени палец и показалец: светла кожа',
    '🫰🏼' => 'ръка с преплетени палец и показалец: средно светла кожа',
    '🫰🏽' => 'ръка с преплетени палец и показалец: средна на цвят кожа',
    '🫰🏾' => 'ръка с преплетени палец и показалец: средно тъмна кожа',
    '🫰🏿' => 'ръка с преплетени палец и показалец: тъмна кожа',
    '🤟🏻' => 'жест „обичам те“: светла кожа',
    '🤟🏼' => 'жест „обичам те“: средно светла кожа',
    '🤟🏽' => 'жест „обичам те“: средна на цвят кожа',
    '🤟🏾' => 'жест „обичам те“: средно тъмна кожа',
    '🤟🏿' => 'жест „обичам те“: тъмна кожа',
    '🤘🏻' => 'Знак на рогата: светла кожа',
    '🤘🏼' => 'Знак на рогата: средно светла кожа',
    '🤘🏽' => 'Знак на рогата: средна на цвят кожа',
    '🤘🏾' => 'Знак на рогата: средно тъмна кожа',
    '🤘🏿' => 'Знак на рогата: тъмна кожа',
    '🤙🏻' => 'знак за обаждане: светла кожа',
    '🤙🏼' => 'знак за обаждане: средно светла кожа',
    '🤙🏽' => 'знак за обаждане: средна на цвят кожа',
    '🤙🏾' => 'знак за обаждане: средно тъмна кожа',
    '🤙🏿' => 'знак за обаждане: тъмна кожа',
    '👈🏻' => 'показалец, сочещ наляво: светла кожа',
    '👈🏼' => 'показалец, сочещ наляво: средно светла кожа',
    '👈🏽' => 'показалец, сочещ наляво: средна на цвят кожа',
    '👈🏾' => 'показалец, сочещ наляво: средно тъмна кожа',
    '👈🏿' => 'показалец, сочещ наляво: тъмна кожа',
    '👉🏻' => 'показалец, сочещ надясно: светла кожа',
    '👉🏼' => 'показалец, сочещ надясно: средно светла кожа',
    '👉🏽' => 'показалец, сочещ надясно: средна на цвят кожа',
    '👉🏾' => 'показалец, сочещ надясно: средно тъмна кожа',
    '👉🏿' => 'показалец, сочещ надясно: тъмна кожа',
    '👆🏻' => 'показалец, сочещ нагоре: светла кожа',
    '👆🏼' => 'показалец, сочещ нагоре: средно светла кожа',
    '👆🏽' => 'показалец, сочещ нагоре: средна на цвят кожа',
    '👆🏾' => 'показалец, сочещ нагоре: средно тъмна кожа',
    '👆🏿' => 'показалец, сочещ нагоре: тъмна кожа',
    '🖕🏻' => 'среден пръст: светла кожа',
    '🖕🏼' => 'среден пръст: средно светла кожа',
    '🖕🏽' => 'среден пръст: средна на цвят кожа',
    '🖕🏾' => 'среден пръст: средно тъмна кожа',
    '🖕🏿' => 'среден пръст: тъмна кожа',
    '👇🏻' => 'показалец, сочещ надолу: светла кожа',
    '👇🏼' => 'показалец, сочещ надолу: средно светла кожа',
    '👇🏽' => 'показалец, сочещ надолу: средна на цвят кожа',
    '👇🏾' => 'показалец, сочещ надолу: средно тъмна кожа',
    '👇🏿' => 'показалец, сочещ надолу: тъмна кожа',
    '☝🏻' => 'Показалец нагоре: светла кожа',
    '☝🏼' => 'Показалец нагоре: средно светла кожа',
    '☝🏽' => 'Показалец нагоре: средна на цвят кожа',
    '☝🏾' => 'Показалец нагоре: средно тъмна кожа',
    '☝🏿' => 'Показалец нагоре: тъмна кожа',
    '🫵🏻' => 'показалец, сочещ към гледащия: светла кожа',
    '🫵🏼' => 'показалец, сочещ към гледащия: средно светла кожа',
    '🫵🏽' => 'показалец, сочещ към гледащия: средна на цвят кожа',
    '🫵🏾' => 'показалец, сочещ към гледащия: средно тъмна кожа',
    '🫵🏿' => 'показалец, сочещ към гледащия: тъмна кожа',
    '👍🏻' => 'Палец нагоре: светла кожа',
    '👍🏼' => 'Палец нагоре: средно светла кожа',
    '👍🏽' => 'Палец нагоре: средна на цвят кожа',
    '👍🏾' => 'Палец нагоре: средно тъмна кожа',
    '👍🏿' => 'Палец нагоре: тъмна кожа',
    '👎🏻' => 'Палец надолу: светла кожа',
    '👎🏼' => 'Палец надолу: средно светла кожа',
    '👎🏽' => 'Палец надолу: средна на цвят кожа',
    '👎🏾' => 'Палец надолу: средно тъмна кожа',
    '👎🏿' => 'Палец надолу: тъмна кожа',
    '✊🏻' => 'Вдигнат юмрук: светла кожа',
    '✊🏼' => 'Вдигнат юмрук: средно светла кожа',
    '✊🏽' => 'Вдигнат юмрук: средна на цвят кожа',
    '✊🏾' => 'Вдигнат юмрук: средно тъмна кожа',
    '✊🏿' => 'Вдигнат юмрук: тъмна кожа',
    '👊🏻' => 'юмрук: светла кожа',
    '👊🏼' => 'юмрук: средно светла кожа',
    '👊🏽' => 'юмрук: средна на цвят кожа',
    '👊🏾' => 'юмрук: средно тъмна кожа',
    '👊🏿' => 'юмрук: тъмна кожа',
    '🤛🏻' => 'обърнат наляво юмрук: светла кожа',
    '🤛🏼' => 'обърнат наляво юмрук: средно светла кожа',
    '🤛🏽' => 'обърнат наляво юмрук: средна на цвят кожа',
    '🤛🏾' => 'обърнат наляво юмрук: средно тъмна кожа',
    '🤛🏿' => 'обърнат наляво юмрук: тъмна кожа',
    '🤜🏻' => 'обърнат надясно юмрук: светла кожа',
    '🤜🏼' => 'обърнат надясно юмрук: средно светла кожа',
    '🤜🏽' => 'обърнат надясно юмрук: средна на цвят кожа',
    '🤜🏾' => 'обърнат надясно юмрук: средно тъмна кожа',
    '🤜🏿' => 'обърнат надясно юмрук: тъмна кожа',
    '👏🏻' => 'Пляскащи ръце: светла кожа',
    '👏🏼' => 'Пляскащи ръце: средно светла кожа',
    '👏🏽' => 'Пляскащи ръце: средна на цвят кожа',
    '👏🏾' => 'Пляскащи ръце: средно тъмна кожа',
    '👏🏿' => 'Пляскащи ръце: тъмна кожа',
    '🙌🏻' => 'Човек с вдигнати ръце: светла кожа',
    '🙌🏼' => 'Човек с вдигнати ръце: средно светла кожа',
    '🙌🏽' => 'Човек с вдигнати ръце: средна на цвят кожа',
    '🙌🏾' => 'Човек с вдигнати ръце: средно тъмна кожа',
    '🙌🏿' => 'Човек с вдигнати ръце: тъмна кожа',
    '🫶🏻' => 'ръце във формата на сърце: светла кожа',
    '🫶🏼' => 'ръце във формата на сърце: средно светла кожа',
    '🫶🏽' => 'ръце във формата на сърце: средна на цвят кожа',
    '🫶🏾' => 'ръце във формата на сърце: средно тъмна кожа',
    '🫶🏿' => 'ръце във формата на сърце: тъмна кожа',
    '👐🏻' => 'Отворени ръце: светла кожа',
    '👐🏼' => 'Отворени ръце: средно светла кожа',
    '👐🏽' => 'Отворени ръце: средна на цвят кожа',
    '👐🏾' => 'Отворени ръце: средно тъмна кожа',
    '👐🏿' => 'Отворени ръце: тъмна кожа',
    '🤲🏻' => 'Събрани длани, сочещи нагоре: светла кожа',
    '🤲🏼' => 'Събрани длани, сочещи нагоре: средно светла кожа',
    '🤲🏽' => 'Събрани длани, сочещи нагоре: средна на цвят кожа',
    '🤲🏾' => 'Събрани длани, сочещи нагоре: средно тъмна кожа',
    '🤲🏿' => 'Събрани длани, сочещи нагоре: тъмна кожа',
    '🤝🏻' => 'ръкостискане: светла кожа',
    '🤝🏼' => 'ръкостискане: средно светла кожа',
    '🤝🏽' => 'ръкостискане: средна на цвят кожа',
    '🤝🏾' => 'ръкостискане: средно тъмна кожа',
    '🤝🏿' => 'ръкостискане: тъмна кожа',
    '🙏🏻' => 'Събрани ръце: светла кожа',
    '🙏🏼' => 'Събрани ръце: средно светла кожа',
    '🙏🏽' => 'Събрани ръце: средна на цвят кожа',
    '🙏🏾' => 'Събрани ръце: средно тъмна кожа',
    '🙏🏿' => 'Събрани ръце: тъмна кожа',
    '✍🏻' => 'Пишеща ръка: светла кожа',
    '✍🏼' => 'Пишеща ръка: средно светла кожа',
    '✍🏽' => 'Пишеща ръка: средна на цвят кожа',
    '✍🏾' => 'Пишеща ръка: средно тъмна кожа',
    '✍🏿' => 'Пишеща ръка: тъмна кожа',
    '💅🏻' => 'Лак за нокти: светла кожа',
    '💅🏼' => 'Лак за нокти: средно светла кожа',
    '💅🏽' => 'Лак за нокти: средна на цвят кожа',
    '💅🏾' => 'Лак за нокти: средно тъмна кожа',
    '💅🏿' => 'Лак за нокти: тъмна кожа',
    '🤳🏻' => 'селфи: светла кожа',
    '🤳🏼' => 'селфи: средно светла кожа',
    '🤳🏽' => 'селфи: средна на цвят кожа',
    '🤳🏾' => 'селфи: средно тъмна кожа',
    '🤳🏿' => 'селфи: тъмна кожа',
    '💪🏻' => 'Стегнат бицепс: светла кожа',
    '💪🏼' => 'Стегнат бицепс: средно светла кожа',
    '💪🏽' => 'Стегнат бицепс: средна на цвят кожа',
    '💪🏾' => 'Стегнат бицепс: средно тъмна кожа',
    '💪🏿' => 'Стегнат бицепс: тъмна кожа',
    '🦵🏻' => 'крак: светла кожа',
    '🦵🏼' => 'крак: средно светла кожа',
    '🦵🏽' => 'крак: средна на цвят кожа',
    '🦵🏾' => 'крак: средно тъмна кожа',
    '🦵🏿' => 'крак: тъмна кожа',
    '🦶🏻' => 'стъпало: светла кожа',
    '🦶🏼' => 'стъпало: средно светла кожа',
    '🦶🏽' => 'стъпало: средна на цвят кожа',
    '🦶🏾' => 'стъпало: средно тъмна кожа',
    '🦶🏿' => 'стъпало: тъмна кожа',
    '👂🏻' => 'ухо: светла кожа',
    '👂🏼' => 'ухо: средно светла кожа',
    '👂🏽' => 'ухо: средна на цвят кожа',
    '👂🏾' => 'ухо: средно тъмна кожа',
    '👂🏿' => 'ухо: тъмна кожа',
    '🦻🏻' => 'ухо със слухов апарат: светла кожа',
    '🦻🏼' => 'ухо със слухов апарат: средно светла кожа',
    '🦻🏽' => 'ухо със слухов апарат: средна на цвят кожа',
    '🦻🏾' => 'ухо със слухов апарат: средно тъмна кожа',
    '🦻🏿' => 'ухо със слухов апарат: тъмна кожа',
    '👃🏻' => 'нос: светла кожа',
    '👃🏼' => 'нос: средно светла кожа',
    '👃🏽' => 'нос: средна на цвят кожа',
    '👃🏾' => 'нос: средно тъмна кожа',
    '👃🏿' => 'нос: тъмна кожа',
    '👶🏻' => 'бебе: светла кожа',
    '👶🏼' => 'бебе: средно светла кожа',
    '👶🏽' => 'бебе: средна на цвят кожа',
    '👶🏾' => 'бебе: средно тъмна кожа',
    '👶🏿' => 'бебе: тъмна кожа',
    '🧒🏻' => 'дете: светла кожа',
    '🧒🏼' => 'дете: средно светла кожа',
    '🧒🏽' => 'дете: средна на цвят кожа',
    '🧒🏾' => 'дете: средно тъмна кожа',
    '🧒🏿' => 'дете: тъмна кожа',
    '👦🏻' => 'момче: светла кожа',
    '👦🏼' => 'момче: средно светла кожа',
    '👦🏽' => 'момче: средна на цвят кожа',
    '👦🏾' => 'момче: средно тъмна кожа',
    '👦🏿' => 'момче: тъмна кожа',
    '👧🏻' => 'момиче: светла кожа',
    '👧🏼' => 'момиче: средно светла кожа',
    '👧🏽' => 'момиче: средна на цвят кожа',
    '👧🏾' => 'момиче: средно тъмна кожа',
    '👧🏿' => 'момиче: тъмна кожа',
    '🧑🏻' => 'възрастен: светла кожа',
    '🧑🏼' => 'възрастен: средно светла кожа',
    '🧑🏽' => 'възрастен: средна на цвят кожа',
    '🧑🏾' => 'възрастен: средно тъмна кожа',
    '🧑🏿' => 'възрастен: тъмна кожа',
    '👱🏻' => 'блондин/ка: светла кожа',
    '👱🏼' => 'блондин/ка: средно светла кожа',
    '👱🏽' => 'блондин/ка: средна на цвят кожа',
    '👱🏾' => 'блондин/ка: средно тъмна кожа',
    '👱🏿' => 'блондин/ка: тъмна кожа',
    '👨🏻' => 'мъж: светла кожа',
    '👨🏼' => 'мъж: средно светла кожа',
    '👨🏽' => 'мъж: средна на цвят кожа',
    '👨🏾' => 'мъж: средно тъмна кожа',
    '👨🏿' => 'мъж: тъмна кожа',
    '🧔🏻' => 'човек с брада: светла кожа',
    '🧔🏼' => 'човек с брада: средно светла кожа',
    '🧔🏽' => 'човек с брада: средна на цвят кожа',
    '🧔🏾' => 'човек с брада: средно тъмна кожа',
    '🧔🏿' => 'човек с брада: тъмна кожа',
    '👩🏻' => 'жена: светла кожа',
    '👩🏼' => 'жена: средно светла кожа',
    '👩🏽' => 'жена: средна на цвят кожа',
    '👩🏾' => 'жена: средно тъмна кожа',
    '👩🏿' => 'жена: тъмна кожа',
    '🧓🏻' => 'по-възрастен човек: светла кожа',
    '🧓🏼' => 'по-възрастен човек: средно светла кожа',
    '🧓🏽' => 'по-възрастен човек: средна на цвят кожа',
    '🧓🏾' => 'по-възрастен човек: средно тъмна кожа',
    '🧓🏿' => 'по-възрастен човек: тъмна кожа',
    '👴🏻' => 'старец: светла кожа',
    '👴🏼' => 'старец: средно светла кожа',
    '👴🏽' => 'старец: средна на цвят кожа',
    '👴🏾' => 'старец: средно тъмна кожа',
    '👴🏿' => 'старец: тъмна кожа',
    '👵🏻' => 'старица: светла кожа',
    '👵🏼' => 'старица: средно светла кожа',
    '👵🏽' => 'старица: средна на цвят кожа',
    '👵🏾' => 'старица: средно тъмна кожа',
    '👵🏿' => 'старица: тъмна кожа',
    '🙍🏻' => 'Намръщен човек: светла кожа',
    '🙍🏼' => 'Намръщен човек: средно светла кожа',
    '🙍🏽' => 'Намръщен човек: средна на цвят кожа',
    '🙍🏾' => 'Намръщен човек: средно тъмна кожа',
    '🙍🏿' => 'Намръщен човек: тъмна кожа',
    '🙎🏻' => 'Нацупен човек: светла кожа',
    '🙎🏼' => 'Нацупен човек: средно светла кожа',
    '🙎🏽' => 'Нацупен човек: средна на цвят кожа',
    '🙎🏾' => 'Нацупен човек: средно тъмна кожа',
    '🙎🏿' => 'Нацупен човек: тъмна кожа',
    '🙅🏻' => 'жест за „не“: светла кожа',
    '🙅🏼' => 'жест за „не“: средно светла кожа',
    '🙅🏽' => 'жест за „не“: средна на цвят кожа',
    '🙅🏾' => 'жест за „не“: средно тъмна кожа',
    '🙅🏿' => 'жест за „не“: тъмна кожа',
    '🙆🏻' => 'жест за „окей“: светла кожа',
    '🙆🏼' => 'жест за „окей“: средно светла кожа',
    '🙆🏽' => 'жест за „окей“: средна на цвят кожа',
    '🙆🏾' => 'жест за „окей“: средно тъмна кожа',
    '🙆🏿' => 'жест за „окей“: тъмна кожа',
    '💁🏻' => 'Човек от информационна служба: светла кожа',
    '💁🏼' => 'Човек от информационна служба: средно светла кожа',
    '💁🏽' => 'Човек от информационна служба: средна на цвят кожа',
    '💁🏾' => 'Човек от информационна служба: средно тъмна кожа',
    '💁🏿' => 'Човек от информационна служба: тъмна кожа',
    '🙋🏻' => 'Щастлив човек, вдигнал ръка: светла кожа',
    '🙋🏼' => 'Щастлив човек, вдигнал ръка: средно светла кожа',
    '🙋🏽' => 'Щастлив човек, вдигнал ръка: средна на цвят кожа',
    '🙋🏾' => 'Щастлив човек, вдигнал ръка: средно тъмна кожа',
    '🙋🏿' => 'Щастлив човек, вдигнал ръка: тъмна кожа',
    '🧏🏻' => 'глух човек: светла кожа',
    '🧏🏼' => 'глух човек: средно светла кожа',
    '🧏🏽' => 'глух човек: средна на цвят кожа',
    '🧏🏾' => 'глух човек: средно тъмна кожа',
    '🧏🏿' => 'глух човек: тъмна кожа',
    '🙇🏻' => 'Покланящ се човек: светла кожа',
    '🙇🏼' => 'Покланящ се човек: средно светла кожа',
    '🙇🏽' => 'Покланящ се човек: средна на цвят кожа',
    '🙇🏾' => 'Покланящ се човек: средно тъмна кожа',
    '🙇🏿' => 'Покланящ се човек: тъмна кожа',
    '🤦🏻' => 'ръка върху лице: светла кожа',
    '🤦🏼' => 'ръка върху лице: средно светла кожа',
    '🤦🏽' => 'ръка върху лице: средна на цвят кожа',
    '🤦🏾' => 'ръка върху лице: средно тъмна кожа',
    '🤦🏿' => 'ръка върху лице: тъмна кожа',
    '🤷🏻' => 'свиване на рамене: светла кожа',
    '🤷🏼' => 'свиване на рамене: средно светла кожа',
    '🤷🏽' => 'свиване на рамене: средна на цвят кожа',
    '🤷🏾' => 'свиване на рамене: средно тъмна кожа',
    '🤷🏿' => 'свиване на рамене: тъмна кожа',
    '👮🏻' => 'полицейски служител: светла кожа',
    '👮🏼' => 'полицейски служител: средно светла кожа',
    '👮🏽' => 'полицейски служител: средна на цвят кожа',
    '👮🏾' => 'полицейски служител: средно тъмна кожа',
    '👮🏿' => 'полицейски служител: тъмна кожа',
    '🕵🏻' => 'детектив: светла кожа',
    '🕵🏼' => 'детектив: средно светла кожа',
    '🕵🏽' => 'детектив: средна на цвят кожа',
    '🕵🏾' => 'детектив: средно тъмна кожа',
    '🕵🏿' => 'детектив: тъмна кожа',
    '💂🏻' => 'гвардеец: светла кожа',
    '💂🏼' => 'гвардеец: средно светла кожа',
    '💂🏽' => 'гвардеец: средна на цвят кожа',
    '💂🏾' => 'гвардеец: средно тъмна кожа',
    '💂🏿' => 'гвардеец: тъмна кожа',
    '🥷🏻' => 'нинджа: светла кожа',
    '🥷🏼' => 'нинджа: средно светла кожа',
    '🥷🏽' => 'нинджа: средна на цвят кожа',
    '🥷🏾' => 'нинджа: средно тъмна кожа',
    '🥷🏿' => 'нинджа: тъмна кожа',
    '👷🏻' => 'строител: светла кожа',
    '👷🏼' => 'строител: средно светла кожа',
    '👷🏽' => 'строител: средна на цвят кожа',
    '👷🏾' => 'строител: средно тъмна кожа',
    '👷🏿' => 'строител: тъмна кожа',
    '🫅🏻' => 'човек с корона: светла кожа',
    '🫅🏼' => 'човек с корона: средно светла кожа',
    '🫅🏽' => 'човек с корона: средна на цвят кожа',
    '🫅🏾' => 'човек с корона: средно тъмна кожа',
    '🫅🏿' => 'човек с корона: тъмна кожа',
    '🤴🏻' => 'принц: светла кожа',
    '🤴🏼' => 'принц: средно светла кожа',
    '🤴🏽' => 'принц: средна на цвят кожа',
    '🤴🏾' => 'принц: средно тъмна кожа',
    '🤴🏿' => 'принц: тъмна кожа',
    '👸🏻' => 'принцеса: светла кожа',
    '👸🏼' => 'принцеса: средно светла кожа',
    '👸🏽' => 'принцеса: средна на цвят кожа',
    '👸🏾' => 'принцеса: средно тъмна кожа',
    '👸🏿' => 'принцеса: тъмна кожа',
    '👳🏻' => 'човек с тюрбан: светла кожа',
    '👳🏼' => 'човек с тюрбан: средно светла кожа',
    '👳🏽' => 'човек с тюрбан: средна на цвят кожа',
    '👳🏾' => 'човек с тюрбан: средно тъмна кожа',
    '👳🏿' => 'човек с тюрбан: тъмна кожа',
    '👲🏻' => 'Мъж с китайска шапчица: светла кожа',
    '👲🏼' => 'Мъж с китайска шапчица: средно светла кожа',
    '👲🏽' => 'Мъж с китайска шапчица: средна на цвят кожа',
    '👲🏾' => 'Мъж с китайска шапчица: средно тъмна кожа',
    '👲🏿' => 'Мъж с китайска шапчица: тъмна кожа',
    '🧕🏻' => 'жена с кърпа за глава: светла кожа',
    '🧕🏼' => 'жена с кърпа за глава: средно светла кожа',
    '🧕🏽' => 'жена с кърпа за глава: средна на цвят кожа',
    '🧕🏾' => 'жена с кърпа за глава: средно тъмна кожа',
    '🧕🏿' => 'жена с кърпа за глава: тъмна кожа',
    '🤵🏻' => 'човек във фрак: светла кожа',
    '🤵🏼' => 'човек във фрак: средно светла кожа',
    '🤵🏽' => 'човек във фрак: средна на цвят кожа',
    '🤵🏾' => 'човек във фрак: средно тъмна кожа',
    '🤵🏿' => 'човек във фрак: тъмна кожа',
    '👰🏻' => 'човек с було: светла кожа',
    '👰🏼' => 'човек с було: средно светла кожа',
    '👰🏽' => 'човек с було: средна на цвят кожа',
    '👰🏾' => 'човек с було: средно тъмна кожа',
    '👰🏿' => 'човек с було: тъмна кожа',
    '🤰🏻' => 'бременна жена: светла кожа',
    '🤰🏼' => 'бременна жена: средно светла кожа',
    '🤰🏽' => 'бременна жена: средна на цвят кожа',
    '🤰🏾' => 'бременна жена: средно тъмна кожа',
    '🤰🏿' => 'бременна жена: тъмна кожа',
    '🫃🏻' => 'бременен мъж: светла кожа',
    '🫃🏼' => 'бременен мъж: средно светла кожа',
    '🫃🏽' => 'бременен мъж: средна на цвят кожа',
    '🫃🏾' => 'бременен мъж: средно тъмна кожа',
    '🫃🏿' => 'бременен мъж: тъмна кожа',
    '🫄🏻' => 'бременен човек: светла кожа',
    '🫄🏼' => 'бременен човек: средно светла кожа',
    '🫄🏽' => 'бременен човек: средна на цвят кожа',
    '🫄🏾' => 'бременен човек: средно тъмна кожа',
    '🫄🏿' => 'бременен човек: тъмна кожа',
    '🤱🏻' => 'кърмене: светла кожа',
    '🤱🏼' => 'кърмене: средно светла кожа',
    '🤱🏽' => 'кърмене: средна на цвят кожа',
    '🤱🏾' => 'кърмене: средно тъмна кожа',
    '🤱🏿' => 'кърмене: тъмна кожа',
    '👼🏻' => 'ангелче: светла кожа',
    '👼🏼' => 'ангелче: средно светла кожа',
    '👼🏽' => 'ангелче: средна на цвят кожа',
    '👼🏾' => 'ангелче: средно тъмна кожа',
    '👼🏿' => 'ангелче: тъмна кожа',
    '🎅🏻' => 'дядо коледа: светла кожа',
    '🎅🏼' => 'дядо коледа: средно светла кожа',
    '🎅🏽' => 'дядо коледа: средна на цвят кожа',
    '🎅🏾' => 'дядо коледа: средно тъмна кожа',
    '🎅🏿' => 'дядо коледа: тъмна кожа',
    '🤶🏻' => 'баба коледа: светла кожа',
    '🤶🏼' => 'баба коледа: средно светла кожа',
    '🤶🏽' => 'баба коледа: средна на цвят кожа',
    '🤶🏾' => 'баба коледа: средно тъмна кожа',
    '🤶🏿' => 'баба коледа: тъмна кожа',
    '🦸🏻' => 'жена супергерой: светла кожа',
    '🦸🏼' => 'жена супергерой: средно светла кожа',
    '🦸🏽' => 'жена супергерой: средна на цвят кожа',
    '🦸🏾' => 'жена супергерой: средно тъмна кожа',
    '🦸🏿' => 'жена супергерой: тъмна кожа',
    '🦹🏻' => 'суперзлодей: светла кожа',
    '🦹🏼' => 'суперзлодей: средно светла кожа',
    '🦹🏽' => 'суперзлодей: средна на цвят кожа',
    '🦹🏾' => 'суперзлодей: средно тъмна кожа',
    '🦹🏿' => 'суперзлодей: тъмна кожа',
    '🧙🏻' => 'жена магьосник: светла кожа',
    '🧙🏼' => 'жена магьосник: средно светла кожа',
    '🧙🏽' => 'жена магьосник: средна на цвят кожа',
    '🧙🏾' => 'жена магьосник: средно тъмна кожа',
    '🧙🏿' => 'жена магьосник: тъмна кожа',
    '🧚🏻' => 'фея: светла кожа',
    '🧚🏼' => 'фея: средно светла кожа',
    '🧚🏽' => 'фея: средна на цвят кожа',
    '🧚🏾' => 'фея: средно тъмна кожа',
    '🧚🏿' => 'фея: тъмна кожа',
    '🧛🏻' => 'вампир: светла кожа',
    '🧛🏼' => 'вампир: средно светла кожа',
    '🧛🏽' => 'вампир: средна на цвят кожа',
    '🧛🏾' => 'вампир: средно тъмна кожа',
    '🧛🏿' => 'вампир: тъмна кожа',
    '🧜🏻' => 'жена амфибия: светла кожа',
    '🧜🏼' => 'жена амфибия: средно светла кожа',
    '🧜🏽' => 'жена амфибия: средна на цвят кожа',
    '🧜🏾' => 'жена амфибия: средно тъмна кожа',
    '🧜🏿' => 'жена амфибия: тъмна кожа',
    '🧝🏻' => 'елф: светла кожа',
    '🧝🏼' => 'елф: средно светла кожа',
    '🧝🏽' => 'елф: средна на цвят кожа',
    '🧝🏾' => 'елф: средно тъмна кожа',
    '🧝🏿' => 'елф: тъмна кожа',
    '💆🏻' => 'Масаж на лицето: светла кожа',
    '💆🏼' => 'Масаж на лицето: средно светла кожа',
    '💆🏽' => 'Масаж на лицето: средна на цвят кожа',
    '💆🏾' => 'Масаж на лицето: средно тъмна кожа',
    '💆🏿' => 'Масаж на лицето: тъмна кожа',
    '💇🏻' => 'прическа: светла кожа',
    '💇🏼' => 'прическа: средно светла кожа',
    '💇🏽' => 'прическа: средна на цвят кожа',
    '💇🏾' => 'прическа: средно тъмна кожа',
    '💇🏿' => 'прическа: тъмна кожа',
    '🚶🏻' => 'пешеходец: светла кожа',
    '🚶🏼' => 'пешеходец: средно светла кожа',
    '🚶🏽' => 'пешеходец: средна на цвят кожа',
    '🚶🏾' => 'пешеходец: средно тъмна кожа',
    '🚶🏿' => 'пешеходец: тъмна кожа',
    '🧍🏻' => 'изправен човек: светла кожа',
    '🧍🏼' => 'изправен човек: средно светла кожа',
    '🧍🏽' => 'изправен човек: средна на цвят кожа',
    '🧍🏾' => 'изправен човек: средно тъмна кожа',
    '🧍🏿' => 'изправен човек: тъмна кожа',
    '🧎🏻' => 'коленичил човек: светла кожа',
    '🧎🏼' => 'коленичил човек: средно светла кожа',
    '🧎🏽' => 'коленичил човек: средна на цвят кожа',
    '🧎🏾' => 'коленичил човек: средно тъмна кожа',
    '🧎🏿' => 'коленичил човек: тъмна кожа',
    '🏃🏻' => 'бегач: светла кожа',
    '🏃🏼' => 'бегач: средно светла кожа',
    '🏃🏽' => 'бегач: средна на цвят кожа',
    '🏃🏾' => 'бегач: средно тъмна кожа',
    '🏃🏿' => 'бегач: тъмна кожа',
    '💃🏻' => 'танцьорка: светла кожа',
    '💃🏼' => 'танцьорка: средно светла кожа',
    '💃🏽' => 'танцьорка: средна на цвят кожа',
    '💃🏾' => 'танцьорка: средно тъмна кожа',
    '💃🏿' => 'танцьорка: тъмна кожа',
    '🕺🏻' => 'танцуващ мъж: светла кожа',
    '🕺🏼' => 'танцуващ мъж: средно светла кожа',
    '🕺🏽' => 'танцуващ мъж: средна на цвят кожа',
    '🕺🏾' => 'танцуващ мъж: средно тъмна кожа',
    '🕺🏿' => 'танцуващ мъж: тъмна кожа',
    '🕴🏻' => 'Левитиращ мъж в костюм: светла кожа',
    '🕴🏼' => 'Левитиращ мъж в костюм: средно светла кожа',
    '🕴🏽' => 'Левитиращ мъж в костюм: средна на цвят кожа',
    '🕴🏾' => 'Левитиращ мъж в костюм: средно тъмна кожа',
    '🕴🏿' => 'Левитиращ мъж в костюм: тъмна кожа',
    '👯🏻' => 'забавляващи се хора: светла кожа',
    '👯🏼' => 'забавляващи се хора: средно светла кожа',
    '👯🏽' => 'забавляващи се хора: средна на цвят кожа',
    '👯🏾' => 'забавляващи се хора: средно тъмна кожа',
    '👯🏿' => 'забавляващи се хора: тъмна кожа',
    '🧖🏻' => 'човек в помещение с пара: светла кожа',
    '🧖🏼' => 'човек в помещение с пара: средно светла кожа',
    '🧖🏽' => 'човек в помещение с пара: средна на цвят кожа',
    '🧖🏾' => 'човек в помещение с пара: средно тъмна кожа',
    '🧖🏿' => 'човек в помещение с пара: тъмна кожа',
    '🧗🏻' => 'катерещ се човек: светла кожа',
    '🧗🏼' => 'катерещ се човек: средно светла кожа',
    '🧗🏽' => 'катерещ се човек: средна на цвят кожа',
    '🧗🏾' => 'катерещ се човек: средно тъмна кожа',
    '🧗🏿' => 'катерещ се човек: тъмна кожа',
    '🏇🏻' => 'Конни надбягвания: светла кожа',
    '🏇🏼' => 'Конни надбягвания: средно светла кожа',
    '🏇🏽' => 'Конни надбягвания: средна на цвят кожа',
    '🏇🏾' => 'Конни надбягвания: средно тъмна кожа',
    '🏇🏿' => 'Конни надбягвания: тъмна кожа',
    '🏂🏻' => 'сноубордист: светла кожа',
    '🏂🏼' => 'сноубордист: средно светла кожа',
    '🏂🏽' => 'сноубордист: средна на цвят кожа',
    '🏂🏾' => 'сноубордист: средно тъмна кожа',
    '🏂🏿' => 'сноубордист: тъмна кожа',
    '🏌🏻' => 'Играч на голф: светла кожа',
    '🏌🏼' => 'Играч на голф: средно светла кожа',
    '🏌🏽' => 'Играч на голф: средна на цвят кожа',
    '🏌🏾' => 'Играч на голф: средно тъмна кожа',
    '🏌🏿' => 'Играч на голф: тъмна кожа',
    '🏄🏻' => 'сърфист: светла кожа',
    '🏄🏼' => 'сърфист: средно светла кожа',
    '🏄🏽' => 'сърфист: средна на цвят кожа',
    '🏄🏾' => 'сърфист: средно тъмна кожа',
    '🏄🏿' => 'сърфист: тъмна кожа',
    '🚣🏻' => 'човек в гребна лодка: светла кожа',
    '🚣🏼' => 'човек в гребна лодка: средно светла кожа',
    '🚣🏽' => 'човек в гребна лодка: средна на цвят кожа',
    '🚣🏾' => 'човек в гребна лодка: средно тъмна кожа',
    '🚣🏿' => 'човек в гребна лодка: тъмна кожа',
    '🏊🏻' => 'плувец: светла кожа',
    '🏊🏼' => 'плувец: средно светла кожа',
    '🏊🏽' => 'плувец: средна на цвят кожа',
    '🏊🏾' => 'плувец: средно тъмна кожа',
    '🏊🏿' => 'плувец: тъмна кожа',
    '⛹🏻' => 'Човек с топка: светла кожа',
    '⛹🏼' => 'Човек с топка: средно светла кожа',
    '⛹🏽' => 'Човек с топка: средна на цвят кожа',
    '⛹🏾' => 'Човек с топка: средно тъмна кожа',
    '⛹🏿' => 'Човек с топка: тъмна кожа',
    '🏋🏻' => 'тежкоатлет: светла кожа',
    '🏋🏼' => 'тежкоатлет: средно светла кожа',
    '🏋🏽' => 'тежкоатлет: средна на цвят кожа',
    '🏋🏾' => 'тежкоатлет: средно тъмна кожа',
    '🏋🏿' => 'тежкоатлет: тъмна кожа',
    '🚴🏻' => 'велосипедист: светла кожа',
    '🚴🏼' => 'велосипедист: средно светла кожа',
    '🚴🏽' => 'велосипедист: средна на цвят кожа',
    '🚴🏾' => 'велосипедист: средно тъмна кожа',
    '🚴🏿' => 'велосипедист: тъмна кожа',
    '🚵🏻' => 'Планински колоездач: светла кожа',
    '🚵🏼' => 'Планински колоездач: средно светла кожа',
    '🚵🏽' => 'Планински колоездач: средна на цвят кожа',
    '🚵🏾' => 'Планински колоездач: средно тъмна кожа',
    '🚵🏿' => 'Планински колоездач: тъмна кожа',
    '🤸🏻' => 'циганско колело: светла кожа',
    '🤸🏼' => 'циганско колело: средно светла кожа',
    '🤸🏽' => 'циганско колело: средна на цвят кожа',
    '🤸🏾' => 'циганско колело: средно тъмна кожа',
    '🤸🏿' => 'циганско колело: тъмна кожа',
    '🤼🏻' => 'борци: светла кожа',
    '🤼🏼' => 'борци: средно светла кожа',
    '🤼🏽' => 'борци: средна на цвят кожа',
    '🤼🏾' => 'борци: средно тъмна кожа',
    '🤼🏿' => 'борци: тъмна кожа',
    '🤽🏻' => 'водна топка: светла кожа',
    '🤽🏼' => 'водна топка: средно светла кожа',
    '🤽🏽' => 'водна топка: средна на цвят кожа',
    '🤽🏾' => 'водна топка: средно тъмна кожа',
    '🤽🏿' => 'водна топка: тъмна кожа',
    '🤾🏻' => 'хандбал: светла кожа',
    '🤾🏼' => 'хандбал: средно светла кожа',
    '🤾🏽' => 'хандбал: средна на цвят кожа',
    '🤾🏾' => 'хандбал: средно тъмна кожа',
    '🤾🏿' => 'хандбал: тъмна кожа',
    '🤹🏻' => 'жонглиране: светла кожа',
    '🤹🏼' => 'жонглиране: средно светла кожа',
    '🤹🏽' => 'жонглиране: средна на цвят кожа',
    '🤹🏾' => 'жонглиране: средно тъмна кожа',
    '🤹🏿' => 'жонглиране: тъмна кожа',
    '🧘🏻' => 'човек в поза „лотус“: светла кожа',
    '🧘🏼' => 'човек в поза „лотус“: средно светла кожа',
    '🧘🏽' => 'човек в поза „лотус“: средна на цвят кожа',
    '🧘🏾' => 'човек в поза „лотус“: средно тъмна кожа',
    '🧘🏿' => 'човек в поза „лотус“: тъмна кожа',
    '🛀🏻' => 'къпещ се човек: светла кожа',
    '🛀🏼' => 'къпещ се човек: средно светла кожа',
    '🛀🏽' => 'къпещ се човек: средна на цвят кожа',
    '🛀🏾' => 'къпещ се човек: средно тъмна кожа',
    '🛀🏿' => 'къпещ се човек: тъмна кожа',
    '🛌🏻' => 'Човек в леглото: светла кожа',
    '🛌🏼' => 'Човек в леглото: средно светла кожа',
    '🛌🏽' => 'Човек в леглото: средна на цвят кожа',
    '🛌🏾' => 'Човек в леглото: средно тъмна кожа',
    '🛌🏿' => 'Човек в леглото: тъмна кожа',
    '👭🏻' => 'Две жени, държащи се за ръце: светла кожа',
    '👭🏼' => 'Две жени, държащи се за ръце: средно светла кожа',
    '👭🏽' => 'Две жени, държащи се за ръце: средна на цвят кожа',
    '👭🏾' => 'Две жени, държащи се за ръце: средно тъмна кожа',
    '👭🏿' => 'Две жени, държащи се за ръце: тъмна кожа',
    '👫🏻' => 'Мъж и жена, държащи се за ръце: светла кожа',
    '👫🏼' => 'Мъж и жена, държащи се за ръце: средно светла кожа',
    '👫🏽' => 'Мъж и жена, държащи се за ръце: средна на цвят кожа',
    '👫🏾' => 'Мъж и жена, държащи се за ръце: средно тъмна кожа',
    '👫🏿' => 'Мъж и жена, държащи се за ръце: тъмна кожа',
    '👬🏻' => 'Двама мъже, държащи се за ръце: светла кожа',
    '👬🏼' => 'Двама мъже, държащи се за ръце: средно светла кожа',
    '👬🏽' => 'Двама мъже, държащи се за ръце: средна на цвят кожа',
    '👬🏾' => 'Двама мъже, държащи се за ръце: средно тъмна кожа',
    '👬🏿' => 'Двама мъже, държащи се за ръце: тъмна кожа',
    '💏🏻' => 'целувка: светла кожа',
    '💏🏼' => 'целувка: средно светла кожа',
    '💏🏽' => 'целувка: средна на цвят кожа',
    '💏🏾' => 'целувка: средно тъмна кожа',
    '💏🏿' => 'целувка: тъмна кожа',
    '💑🏻' => 'Двойка и сърце: светла кожа',
    '💑🏼' => 'Двойка и сърце: средно светла кожа',
    '💑🏽' => 'Двойка и сърце: средна на цвят кожа',
    '💑🏾' => 'Двойка и сърце: средно тъмна кожа',
    '💑🏿' => 'Двойка и сърце: тъмна кожа',
    '🇦🇨' => 'Флаг: остров Възнесение',
    '🇦🇩' => 'Флаг: Андора',
    '🇦🇪' => 'Флаг: Обединени арабски емирства',
    '🇦🇫' => 'Флаг: Афганистан',
    '🇦🇬' => 'Флаг: Антигуа и Барбуда',
    '🇦🇮' => 'Флаг: Ангуила',
    '🇦🇱' => 'Флаг: Албания',
    '🇦🇲' => 'Флаг: Армения',
    '🇦🇴' => 'Флаг: Ангола',
    '🇦🇶' => 'Флаг: Антарктика',
    '🇦🇷' => 'Флаг: Аржентина',
    '🇦🇸' => 'Флаг: Американска Самоа',
    '🇦🇹' => 'Флаг: Австрия',
    '🇦🇺' => 'Флаг: Австралия',
    '🇦🇼' => 'Флаг: Аруба',
    '🇦🇽' => 'Флаг: Оландски острови',
    '🇦🇿' => 'Флаг: Азербайджан',
    '🇧🇦' => 'Флаг: Босна и Херцеговина',
    '🇧🇧' => 'Флаг: Барбадос',
    '🇧🇩' => 'Флаг: Бангладеш',
    '🇧🇪' => 'Флаг: Белгия',
    '🇧🇫' => 'Флаг: Буркина Фасо',
    '🇧🇬' => 'Флаг: България',
    '🇧🇭' => 'Флаг: Бахрейн',
    '🇧🇮' => 'Флаг: Бурунди',
    '🇧🇯' => 'Флаг: Бенин',
    '🇧🇱' => 'Флаг: Сен Бартелеми',
    '🇧🇲' => 'Флаг: Бермудски острови',
    '🇧🇳' => 'Флаг: Бруней Даруссалам',
    '🇧🇴' => 'Флаг: Боливия',
    '🇧🇶' => 'Флаг: Карибска Нидерландия',
    '🇧🇷' => 'Флаг: Бразилия',
    '🇧🇸' => 'Флаг: Бахамски острови',
    '🇧🇹' => 'Флаг: Бутан',
    '🇧🇻' => 'Флаг: остров Буве',
    '🇧🇼' => 'Флаг: Ботсвана',
    '🇧🇾' => 'Флаг: Беларус',
    '🇧🇿' => 'Флаг: Белиз',
    '🇨🇦' => 'Флаг: Канада',
    '🇨🇨' => 'Флаг: Кокосови острови (острови Кийлинг)',
    '🇨🇩' => 'Флаг: Конго (Киншаса)',
    '🇨🇫' => 'Флаг: Централноафриканска република',
    '🇨🇬' => 'Флаг: Конго (Бразавил)',
    '🇨🇭' => 'Флаг: Швейцария',
    '🇨🇮' => 'Флаг: Кот д’Ивоар',
    '🇨🇰' => 'Флаг: острови Кук',
    '🇨🇱' => 'Флаг: Чили',
    '🇨🇲' => 'Флаг: Камерун',
    '🇨🇳' => 'Флаг: Китай',
    '🇨🇴' => 'Флаг: Колумбия',
    '🇨🇵' => 'Флаг: остров Клипертон',
    '🇨🇶' => 'Флаг: Сарк',
    '🇨🇷' => 'Флаг: Коста Рика',
    '🇨🇺' => 'Флаг: Куба',
    '🇨🇻' => 'Флаг: Кабо Верде',
    '🇨🇼' => 'Флаг: Кюрасао',
    '🇨🇽' => 'Флаг: остров Рождество',
    '🇨🇾' => 'Флаг: Кипър',
    '🇨🇿' => 'Флаг: Чехия',
    '🇩🇪' => 'Флаг: Германия',
    '🇩🇬' => 'Флаг: Диего Гарсия',
    '🇩🇯' => 'Флаг: Джибути',
    '🇩🇰' => 'Флаг: Дания',
    '🇩🇲' => 'Флаг: Доминика',
    '🇩🇴' => 'Флаг: Доминиканска република',
    '🇩🇿' => 'Флаг: Алжир',
    '🇪🇦' => 'Флаг: Сеута и Мелия',
    '🇪🇨' => 'Флаг: Еквадор',
    '🇪🇪' => 'Флаг: Естония',
    '🇪🇬' => 'Флаг: Египет',
    '🇪🇭' => 'Флаг: Западна Сахара',
    '🇪🇷' => 'Флаг: Еритрея',
    '🇪🇸' => 'Флаг: Испания',
    '🇪🇹' => 'Флаг: Етиопия',
    '🇪🇺' => 'Флаг: Европейски съюз',
    '🇫🇮' => 'Флаг: Финландия',
    '🇫🇯' => 'Флаг: Фиджи',
    '🇫🇰' => 'Флаг: Фолкландски острови',
    '🇫🇲' => 'Флаг: Микронезия',
    '🇫🇴' => 'Флаг: Фарьорски острови',
    '🇫🇷' => 'Флаг: Франция',
    '🇬🇦' => 'Флаг: Габон',
    '🇬🇧' => 'Флаг: Обединеното кралство',
    '🇬🇩' => 'Флаг: Гренада',
    '🇬🇪' => 'Флаг: Грузия',
    '🇬🇫' => 'Флаг: Френска Гвиана',
    '🇬🇬' => 'Флаг: Гърнзи',
    '🇬🇭' => 'Флаг: Гана',
    '🇬🇮' => 'Флаг: Гибралтар',
    '🇬🇱' => 'Флаг: Гренландия',
    '🇬🇲' => 'Флаг: Гамбия',
    '🇬🇳' => 'Флаг: Гвинея',
    '🇬🇵' => 'Флаг: Гваделупа',
    '🇬🇶' => 'Флаг: Екваториална Гвинея',
    '🇬🇷' => 'Флаг: Гърция',
    '🇬🇸' => 'Флаг: Южна Джорджия и Южни Сандвичеви острови',
    '🇬🇹' => 'Флаг: Гватемала',
    '🇬🇺' => 'Флаг: Гуам',
    '🇬🇼' => 'Флаг: Гвинея-Бисау',
    '🇬🇾' => 'Флаг: Гаяна',
    '🇭🇰' => 'Флаг: Хонконг, САР на Китай',
    '🇭🇲' => 'Флаг: острови Хърд и Макдоналд',
    '🇭🇳' => 'Флаг: Хондурас',
    '🇭🇷' => 'Флаг: Хърватия',
    '🇭🇹' => 'Флаг: Хаити',
    '🇭🇺' => 'Флаг: Унгария',
    '🇮🇨' => 'Флаг: Канарски острови',
    '🇮🇩' => 'Флаг: Индонезия',
    '🇮🇪' => 'Флаг: Ирландия',
    '🇮🇱' => 'Флаг: Израел',
    '🇮🇲' => 'Флаг: остров Ман',
    '🇮🇳' => 'Флаг: Индия',
    '🇮🇴' => 'Флаг: Британска територия в Индийския океан',
    '🇮🇶' => 'Флаг: Ирак',
    '🇮🇷' => 'Флаг: Иран',
    '🇮🇸' => 'Флаг: Исландия',
    '🇮🇹' => 'Флаг: Италия',
    '🇯🇪' => 'Флаг: Джърси',
    '🇯🇲' => 'Флаг: Ямайка',
    '🇯🇴' => 'Флаг: Йордания',
    '🇯🇵' => 'Флаг: Япония',
    '🇰🇪' => 'Флаг: Кения',
    '🇰🇬' => 'Флаг: Киргизстан',
    '🇰🇭' => 'Флаг: Камбоджа',
    '🇰🇮' => 'Флаг: Кирибати',
    '🇰🇲' => 'Флаг: Коморски острови',
    '🇰🇳' => 'Флаг: Сейнт Китс и Невис',
    '🇰🇵' => 'Флаг: Северна Корея',
    '🇰🇷' => 'Флаг: Южна Корея',
    '🇰🇼' => 'Флаг: Кувейт',
    '🇰🇾' => 'Флаг: Кайманови острови',
    '🇰🇿' => 'Флаг: Казахстан',
    '🇱🇦' => 'Флаг: Лаос',
    '🇱🇧' => 'Флаг: Ливан',
    '🇱🇨' => 'Флаг: Сейнт Лусия',
    '🇱🇮' => 'Флаг: Лихтенщайн',
    '🇱🇰' => 'Флаг: Шри Ланка',
    '🇱🇷' => 'Флаг: Либерия',
    '🇱🇸' => 'Флаг: Лесото',
    '🇱🇹' => 'Флаг: Литва',
    '🇱🇺' => 'Флаг: Люксембург',
    '🇱🇻' => 'Флаг: Латвия',
    '🇱🇾' => 'Флаг: Либия',
    '🇲🇦' => 'Флаг: Мароко',
    '🇲🇨' => 'Флаг: Монако',
    '🇲🇩' => 'Флаг: Молдова',
    '🇲🇪' => 'Флаг: Черна гора',
    '🇲🇫' => 'Флаг: Сен Мартен',
    '🇲🇬' => 'Флаг: Мадагаскар',
    '🇲🇭' => 'Флаг: Маршалови острови',
    '🇲🇰' => 'Флаг: Северна Македония',
    '🇲🇱' => 'Флаг: Мали',
    '🇲🇲' => 'Флаг: Мианмар (Бирма)',
    '🇲🇳' => 'Флаг: Монголия',
    '🇲🇴' => 'Флаг: Макао, САР на Китай',
    '🇲🇵' => 'Флаг: Северни Мариански острови',
    '🇲🇶' => 'Флаг: Мартиника',
    '🇲🇷' => 'Флаг: Мавритания',
    '🇲🇸' => 'Флаг: Монтсерат',
    '🇲🇹' => 'Флаг: Малта',
    '🇲🇺' => 'Флаг: Мавриций',
    '🇲🇻' => 'Флаг: Малдиви',
    '🇲🇼' => 'Флаг: Малави',
    '🇲🇽' => 'Флаг: Мексико',
    '🇲🇾' => 'Флаг: Малайзия',
    '🇲🇿' => 'Флаг: Мозамбик',
    '🇳🇦' => 'Флаг: Намибия',
    '🇳🇨' => 'Флаг: Нова Каледония',
    '🇳🇪' => 'Флаг: Нигер',
    '🇳🇫' => 'Флаг: остров Норфолк',
    '🇳🇬' => 'Флаг: Нигерия',
    '🇳🇮' => 'Флаг: Никарагуа',
    '🇳🇱' => 'Флаг: Нидерландия',
    '🇳🇴' => 'Флаг: Норвегия',
    '🇳🇵' => 'Флаг: Непал',
    '🇳🇷' => 'Флаг: Науру',
    '🇳🇺' => 'Флаг: Ниуе',
    '🇳🇿' => 'Флаг: Нова Зеландия',
    '🇴🇲' => 'Флаг: Оман',
    '🇵🇦' => 'Флаг: Панама',
    '🇵🇪' => 'Флаг: Перу',
    '🇵🇫' => 'Флаг: Френска Полинезия',
    '🇵🇬' => 'Флаг: Папуа-Нова Гвинея',
    '🇵🇭' => 'Флаг: Филипини',
    '🇵🇰' => 'Флаг: Пакистан',
    '🇵🇱' => 'Флаг: Полша',
    '🇵🇲' => 'Флаг: Сен Пиер и Микелон',
    '🇵🇳' => 'Флаг: Острови Питкерн',
    '🇵🇷' => 'Флаг: Пуерто Рико',
    '🇵🇸' => 'Флаг: Палестински територии',
    '🇵🇹' => 'Флаг: Португалия',
    '🇵🇼' => 'Флаг: Палау',
    '🇵🇾' => 'Флаг: Парагвай',
    '🇶🇦' => 'Флаг: Катар',
    '🇷🇪' => 'Флаг: Реюнион',
    '🇷🇴' => 'Флаг: Румъния',
    '🇷🇸' => 'Флаг: Сърбия',
    '🇷🇺' => 'Флаг: Русия',
    '🇷🇼' => 'Флаг: Руанда',
    '🇸🇦' => 'Флаг: Саудитска Арабия',
    '🇸🇧' => 'Флаг: Соломонови острови',
    '🇸🇨' => 'Флаг: Сейшели',
    '🇸🇩' => 'Флаг: Судан',
    '🇸🇪' => 'Флаг: Швеция',
    '🇸🇬' => 'Флаг: Сингапур',
    '🇸🇭' => 'Флаг: Света Елена',
    '🇸🇮' => 'Флаг: Словения',
    '🇸🇯' => 'Флаг: Свалбард и Ян Майен',
    '🇸🇰' => 'Флаг: Словакия',
    '🇸🇱' => 'Флаг: Сиера Леоне',
    '🇸🇲' => 'Флаг: Сан Марино',
    '🇸🇳' => 'Флаг: Сенегал',
    '🇸🇴' => 'Флаг: Сомалия',
    '🇸🇷' => 'Флаг: Суринам',
    '🇸🇸' => 'Флаг: Южен Судан',
    '🇸🇹' => 'Флаг: Сао Томе и Принсипи',
    '🇸🇻' => 'Флаг: Салвадор',
    '🇸🇽' => 'Флаг: Синт Мартен',
    '🇸🇾' => 'Флаг: Сирия',
    '🇸🇿' => 'Флаг: Есватини',
    '🇹🇦' => 'Флаг: Тристан да Куня',
    '🇹🇨' => 'Флаг: острови Търкс и Кайкос',
    '🇹🇩' => 'Флаг: Чад',
    '🇹🇫' => 'Флаг: Френски южни територии',
    '🇹🇬' => 'Флаг: Того',
    '🇹🇭' => 'Флаг: Тайланд',
    '🇹🇯' => 'Флаг: Таджикистан',
    '🇹🇰' => 'Флаг: Токелау',
    '🇹🇱' => 'Флаг: Тимор Лесте',
    '🇹🇲' => 'Флаг: Туркменистан',
    '🇹🇳' => 'Флаг: Тунис',
    '🇹🇴' => 'Флаг: Тонга',
    '🇹🇷' => 'Флаг: Турция',
    '🇹🇹' => 'Флаг: Тринидад и Тобаго',
    '🇹🇻' => 'Флаг: Тувалу',
    '🇹🇼' => 'Флаг: Тайван',
    '🇹🇿' => 'Флаг: Танзания',
    '🇺🇦' => 'Флаг: Украйна',
    '🇺🇬' => 'Флаг: Уганда',
    '🇺🇲' => 'Флаг: Отдалечени острови на САЩ',
    '🇺🇳' => 'Флаг: Организация на обединените нации',
    '🇺🇸' => 'Флаг: Съединени щати',
    '🇺🇾' => 'Флаг: Уругвай',
    '🇺🇿' => 'Флаг: Узбекистан',
    '🇻🇦' => 'Флаг: Ватикан',
    '🇻🇨' => 'Флаг: Сейнт Винсънт и Гренадини',
    '🇻🇪' => 'Флаг: Венецуела',
    '🇻🇬' => 'Флаг: Британски Вирджински острови',
    '🇻🇮' => 'Флаг: Американски Вирджински острови',
    '🇻🇳' => 'Флаг: Виетнам',
    '🇻🇺' => 'Флаг: Вануату',
    '🇼🇫' => 'Флаг: Уолис и Футуна',
    '🇼🇸' => 'Флаг: Самоа',
    '🇽🇰' => 'Флаг: Косово',
    '🇾🇪' => 'Флаг: Йемен',
    '🇾🇹' => 'Флаг: Майот',
    '🇿🇦' => 'Флаг: Южна Африка',
    '🇿🇲' => 'Флаг: Замбия',
    '🇿🇼' => 'Флаг: Зимбабве',
    '🔟' => 'Клавиш: 10',
    '🏻' => 'светла кожа',
    '🏼' => 'средно светла кожа',
    '🏽' => 'средна на цвят кожа',
    '🏾' => 'средно тъмна кожа',
    '🏿' => 'тъмна кожа',
    '😀' => 'Широко усмихнато лице',
    '😃' => 'Широко усмихнато лице с големи очи',
    '😄' => 'Широко усмихнато лице с усмихнати очи',
    '😁' => 'Сияещо лице с усмихващи се очи',
    '😆' => 'широко усмихнато лице с присвити очи',
    '😅' => 'Широко усмихнато лице с пот на челото',
    '🤣' => 'Заливащо се от смях лице',
    '😂' => 'Лице със сълзи от радост',
    '🙂' => 'Леко усмихнато лице',
    '🙃' => 'Обърнато наобратно лице',
    '🫠' => 'топящо се лице',
    '😉' => 'Намигащо лице',
    '😊' => 'Усмихнато лице с усмихнати очи',
    '😇' => 'Усмихнато лице с ореол',
    '🥰' => 'усмихнато лице със сърца',
    '😍' => 'Усмихнато лице с очи във форма на сърце',
    '🤩' => 'дълбоко запленен',
    '😘' => 'Лице, пращащо въздушна целувка',
    '😗' => 'Целуващо лице',
    '☺' => 'Усмихнато лице',
    '😚' => 'Целуващо лице със затворени очи',
    '😙' => 'Целуващо лице с усмихнати очи',
    '🥲' => 'усмихнато лице със сълза',
    '😋' => 'Лице, наслаждаващо се на вкусна храна',
    '😛' => 'Плезещо се лице',
    '😜' => 'Намигащо и плезещо се лице',
    '🤪' => 'Налудничаво лице',
    '😝' => 'Лице с изплезен език и стиснати очи',
    '🤑' => 'Лице с пари в устата',
    '🤗' => 'Прегръщащо лице',
    '🤭' => 'Лице с ръка пред устата',
    '🫢' => 'лице с широко отворени очи и ръка пред устата',
    '🫣' => 'лице, надничащо зад ръцете си',
    '🤫' => 'Лице, което прави „шт!“',
    '🤔' => 'Замислено лице',
    '🫡' => 'козируващо лице',
    '🤐' => 'Лице с уста с цип',
    '🤨' => 'Лице с повдигната вежда',
    '😐' => 'Неутрално лице',
    '😑' => 'Безизразно лице',
    '😶' => 'Лице без уста',
    '🫥' => 'лице с пунктир',
    '😏' => 'Подсмихващо се лице',
    '😒' => 'Недоволно лице',
    '🙄' => 'Лице с извъртени нагоре очи',
    '😬' => 'Лице с гримаса',
    '🤥' => 'лъжещо лице',
    '🫨' => 'треперещо лице',
    '😌' => 'Облекчено лице',
    '😔' => 'Угрижено лице',
    '😪' => 'Сънено лице',
    '🤤' => 'лице с капеща слюнка',
    '😴' => 'Спящо лице',
    '🫩' => 'лице с торбички под очите',
    '😷' => 'Лице с медицинска маска',
    '🤒' => 'Лице с термометър',
    '🤕' => 'Лице с превръзка на главата',
    '🤢' => 'лице пред повръщане',
    '🤮' => 'Повръщащо лице',
    '🤧' => 'кихащо лице',
    '🥵' => 'зачервено лице',
    '🥶' => 'замръзнало лице',
    '🥴' => 'опиянено лице',
    '😵' => 'лице със зачеркнати очи',
    '🤯' => 'Експлодираща глава',
    '🤠' => 'лице с каубойска шапка',
    '🥳' => 'купонджийско лице',
    '🥸' => 'маскирано лице',
    '😎' => 'Усмихнато лице със слънчеви очила',
    '🤓' => 'лице на зубър',
    '🧐' => 'Лице с монокъл',
    '😕' => 'Объркано лице',
    '🫤' => 'лице с диагонална уста',
    '😟' => 'Разтревожено лице',
    '🙁' => 'Леко намръщено лице',
    '☹' => 'Намръщено лице',
    '😮' => 'Лице с отворена уста',
    '😯' => 'Изненадано лице',
    '😲' => 'изумено лице',
    '😳' => 'Изчервено лице',
    '🫪' => 'изкривено лице',
    '🥺' => 'умоляващо лице',
    '🥹' => 'лице, което сдържа сълзите си',
    '😦' => 'Намръщено лице с отворена уста',
    '😧' => 'Изстрадало лице',
    '😨' => 'Изплашено лице',
    '😰' => 'Лице с отворена уста и студена пот',
    '😥' => 'Лице с разочарование и облекчение',
    '😢' => 'Разплакано лице',
    '😭' => 'Силно плачещо лице',
    '😱' => 'Лице, крещящо от страх',
    '😖' => 'Смутено лице',
    '😣' => 'Упорито лице',
    '😞' => 'Разочаровано лице',
    '😓' => 'наведено лице с пот',
    '😩' => 'Изтощено лице',
    '😫' => 'Уморено лице',
    '🥱' => 'прозяващо се лице',
    '😤' => 'Лице с излизаща от носа пара',
    '😡' => 'гневно лице',
    '😠' => 'Ядосано лице',
    '🤬' => 'Лице със символи върху устата',
    '😈' => 'Усмихнато лице с рога',
    '👿' => 'ядосано лице с рога',
    '💀' => 'череп',
    '☠' => 'Череп с кръстосани кости',
    '💩' => 'изпражнение',
    '🤡' => 'клоунско лице',
    '👹' => 'страшилище',
    '👺' => 'гоблин',
    '👻' => 'призрак',
    '👽' => 'извънземно',
    '👾' => 'извънземно чудовище',
    '🤖' => 'Лице на робот',
    '😺' => 'Усмихнато котешко лице с отворена уста',
    '😸' => 'Ухилено котешко лице с усмихнати очи',
    '😹' => 'Котешко лице със сълзи от радост',
    '😻' => 'Усмихнато котешко лице с очи с форма на сърце',
    '😼' => 'Котешко лице с изкривена усмивка',
    '😽' => 'Целуващо котешко лице със затворени очи',
    '🙀' => 'Изтощено котешко лице',
    '😿' => 'Плачещо котешко лице',
    '😾' => 'Нацупено котешко лице',
    '🙈' => '„не видях“',
    '🙉' => '„не чух“',
    '🙊' => '„не знам“',
    '💌' => 'Любовно писмо',
    '💘' => 'Сърце със стрела',
    '💝' => 'Сърце с панделка',
    '💖' => 'Блестящо сърце',
    '💗' => 'растящо сърце',
    '💓' => 'Биещо сърце',
    '💞' => 'Обикалящи сърца',
    '💕' => 'Две сърца',
    '💟' => 'Украса сърце',
    '❣' => 'Плътен орнамент от сърце – удивителна',
    '💔' => 'Разбито сърце',
    '❤' => 'Червено сърце',
    '🩷' => 'розово сърце',
    '🧡' => 'оранжево сърце',
    '💛' => 'Жълто сърце',
    '💚' => 'Зелено сърце',
    '💙' => 'Синьо сърце',
    '🩵' => 'светлосиньо сърце',
    '💜' => 'Лилаво сърце',
    '🤎' => 'кафяво сърце',
    '🖤' => 'черно сърце',
    '🩶' => 'сиво сърце',
    '🤍' => 'бяло сърце',
    '💋' => 'Отпечатък от целувка',
    '💯' => 'сто точки',
    '💢' => 'Символ за гняв',
    '🫯' => 'облак от бой',
    '💥' => 'сблъсък',
    '💫' => 'замайване',
    '💦' => 'капки пот',
    '💨' => 'спринт',
    '🕳' => 'дупка',
    '💬' => 'Балонче за говор',
    '🗨' => 'Балонче за говор отляво',
    '🗯' => 'Балонче за гняв отдясно',
    '💭' => 'Балонче за мисъл',
    '💤' => 'спане',
    '👋' => 'Махане с ръка',
    '🤚' => 'вдигната длан',
    '🖐' => 'Вдигната ръка с разперени пръсти',
    '✋' => 'Вдигната ръка',
    '🖖' => 'Поздрав на вулканите',
    '🫱' => 'сочеща надясно ръка',
    '🫲' => 'сочеща наляво ръка',
    '🫳' => 'ръка с длан надолу',
    '🫴' => 'ръка с длан нагоре',
    '🫷' => 'натискаща наляво ръка',
    '🫸' => 'натискаща надясно ръка',
    '👌' => 'Жест „окей“',
    '🤌' => 'събрани пръсти',
    '🤏' => 'ръка с приближени палец и показалец',
    '✌' => 'Жест за победа',
    '🤞' => 'стискане на палци',
    '🫰' => 'ръка с преплетени палец и показалец',
    '🤟' => 'жест „обичам те“',
    '🤘' => 'Знак на рогата',
    '🤙' => 'знак за обаждане',
    '👈' => 'показалец, сочещ наляво',
    '👉' => 'показалец, сочещ надясно',
    '👆' => 'показалец, сочещ нагоре',
    '🖕' => 'среден пръст',
    '👇' => 'показалец, сочещ надолу',
    '☝' => 'Показалец нагоре',
    '🫵' => 'показалец, сочещ към гледащия',
    '👍' => 'Палец нагоре',
    '👎' => 'Палец надолу',
    '✊' => 'Вдигнат юмрук',
    '👊' => 'юмрук',
    '🤛' => 'обърнат наляво юмрук',
    '🤜' => 'обърнат надясно юмрук',
    '👏' => 'Пляскащи ръце',
    '🙌' => 'Човек с вдигнати ръце',
    '🫶' => 'ръце във формата на сърце',
    '👐' => 'Отворени ръце',
    '🤲' => 'Събрани длани, сочещи нагоре',
    '🤝' => 'ръкостискане',
    '🙏' => 'Събрани ръце',
    '✍' => 'Пишеща ръка',
    '💅' => 'Лак за нокти',
    '🤳' => 'селфи',
    '💪' => 'Стегнат бицепс',
    '🦾' => 'механична ръка',
    '🦿' => 'механичен крак',
    '🦵' => 'крак',
    '🦶' => 'стъпало',
    '👂' => 'ухо',
    '🦻' => 'ухо със слухов апарат',
    '👃' => 'нос',
    '🧠' => 'мозък',
    '🫀' => 'сърце',
    '🫁' => 'дробове',
    '🦷' => 'зъб',
    '🦴' => 'кокал',
    '👀' => 'очи',
    '👁' => 'око',
    '👅' => 'език',
    '👄' => 'уста',
    '🫦' => 'прехапана устна',
    '👶' => 'бебе',
    '🧒' => 'дете',
    '👦' => 'момче',
    '👧' => 'момиче',
    '🧑' => 'възрастен',
    '👱' => 'блондин/ка',
    '👨' => 'мъж',
    '🧔' => 'човек с брада',
    '👩' => 'жена',
    '🧓' => 'по-възрастен човек',
    '👴' => 'старец',
    '👵' => 'старица',
    '🙍' => 'Намръщен човек',
    '🙎' => 'Нацупен човек',
    '🙅' => 'жест за „не“',
    '🙆' => 'жест за „окей“',
    '💁' => 'Човек от информационна служба',
    '🙋' => 'Щастлив човек, вдигнал ръка',
    '🧏' => 'глух човек',
    '🙇' => 'Покланящ се човек',
    '🤦' => 'ръка върху лице',
    '🤷' => 'свиване на рамене',
    '👮' => 'полицейски служител',
    '🕵' => 'детектив',
    '💂' => 'гвардеец',
    '🥷' => 'нинджа',
    '👷' => 'строител',
    '🫅' => 'човек с корона',
    '🤴' => 'принц',
    '👸' => 'принцеса',
    '👳' => 'човек с тюрбан',
    '👲' => 'Мъж с китайска шапчица',
    '🧕' => 'жена с кърпа за глава',
    '🤵' => 'човек във фрак',
    '👰' => 'човек с було',
    '🤰' => 'бременна жена',
    '🫃' => 'бременен мъж',
    '🫄' => 'бременен човек',
    '🤱' => 'кърмене',
    '👼' => 'ангелче',
    '🎅' => 'дядо коледа',
    '🤶' => 'баба коледа',
    '🦸' => 'жена супергерой',
    '🦹' => 'суперзлодей',
    '🧙' => 'жена магьосник',
    '🧚' => 'фея',
    '🧛' => 'вампир',
    '🧜' => 'жена амфибия',
    '🧝' => 'елф',
    '🧞' => 'женски джин',
    '🧟' => 'зомби',
    '🧌' => 'трол',
    '🫈' => 'космато същество',
    '💆' => 'Масаж на лицето',
    '💇' => 'прическа',
    '🚶' => 'пешеходец',
    '🧍' => 'изправен човек',
    '🧎' => 'коленичил човек',
    '🏃' => 'бегач',
    '💃' => 'танцьорка',
    '🕺' => 'танцуващ мъж',
    '🕴' => 'Левитиращ мъж в костюм',
    '👯' => 'забавляващи се хора',
    '🧖' => 'човек в помещение с пара',
    '🧗' => 'катерещ се човек',
    '🤺' => 'фехтовач',
    '🏇' => 'Конни надбягвания',
    '⛷' => 'скиор',
    '🏂' => 'сноубордист',
    '🏌' => 'Играч на голф',
    '🏄' => 'сърфист',
    '🚣' => 'човек в гребна лодка',
    '🏊' => 'плувец',
    '⛹' => 'Човек с топка',
    '🏋' => 'тежкоатлет',
    '🚴' => 'велосипедист',
    '🚵' => 'Планински колоездач',
    '🤸' => 'циганско колело',
    '🤼' => 'борци',
    '🤽' => 'водна топка',
    '🤾' => 'хандбал',
    '🤹' => 'жонглиране',
    '🧘' => 'човек в поза „лотус“',
    '🛀' => 'къпещ се човек',
    '🛌' => 'Човек в леглото',
    '👭' => 'Две жени, държащи се за ръце',
    '👫' => 'Мъж и жена, държащи се за ръце',
    '👬' => 'Двама мъже, държащи се за ръце',
    '💏' => 'целувка',
    '💑' => 'Двойка и сърце',
    '🗣' => 'Говореща глава',
    '👤' => 'Силует на бюст',
    '👥' => 'Силуети на бюстове',
    '🫂' => 'прегръщащи се хора',
    '👪' => 'семейство',
    '👣' => 'стъпки',
    '🫆' => 'пръстов отпечатък',
    '🦰' => 'рижа коса',
    '🦱' => 'къдрава коса',
    '🦳' => 'побеляла коса',
    '🦲' => 'плешив човек',
    '🐵' => 'Лице на маймуна',
    '🐒' => 'маймуна',
    '🦍' => 'горила',
    '🦧' => 'орангутан',
    '🐶' => 'муцуна на куче',
    '🐕' => 'куче',
    '🦮' => 'куче водач',
    '🐩' => 'пудел',
    '🐺' => 'вълк',
    '🦊' => 'лисица',
    '🦝' => 'енот',
    '🐱' => 'муцуна на котка',
    '🐈' => 'котка',
    '🦁' => 'лъв',
    '🐯' => 'муцуна на тигър',
    '🐅' => 'тигър',
    '🐆' => 'леопард',
    '🐴' => 'муцуна на кон',
    '🫎' => 'лос',
    '🫏' => 'магаре',
    '🐎' => 'кон',
    '🦄' => 'еднорог',
    '🦓' => 'зебра',
    '🦌' => 'елен',
    '🦬' => 'бизон',
    '🐮' => 'муцуна на крава',
    '🐂' => 'вол',
    '🐃' => 'воден бивол',
    '🐄' => 'крава',
    '🐷' => 'зурла на прасе',
    '🐖' => 'прасе',
    '🐗' => 'глиган',
    '🐽' => 'зурла',
    '🐏' => 'овен',
    '🐑' => 'овца',
    '🐐' => 'коза',
    '🐪' => 'камила',
    '🐫' => 'двугърба камила',
    '🦙' => 'лама',
    '🦒' => 'жираф',
    '🐘' => 'слон',
    '🦣' => 'мамут',
    '🦏' => 'носорог',
    '🦛' => 'хипопотам',
    '🐭' => 'муцуна на мишка',
    '🐁' => 'мишка',
    '🐀' => 'плъх',
    '🐹' => 'хамстер',
    '🐰' => 'муцуна на заек',
    '🐇' => 'заек',
    '🐿' => 'катерица',
    '🦫' => 'бобър',
    '🦔' => 'таралеж',
    '🦇' => 'прилеп',
    '🐻' => 'мечка',
    '🐨' => 'коала',
    '🐼' => 'панда',
    '🦥' => 'ленивец',
    '🦦' => 'видра',
    '🦨' => 'скункс',
    '🦘' => 'кенгуру',
    '🦡' => 'язовец',
    '🐾' => 'следи от лапи',
    '🦃' => 'пуйка',
    '🐔' => 'кокошка',
    '🐓' => 'петел',
    '🐣' => 'излюпващо се пиленце',
    '🐤' => 'пиленце',
    '🐥' => 'пиленце, гледано отпред',
    '🐦' => 'птица',
    '🐧' => 'пингвин',
    '🕊' => 'гълъб',
    '🦅' => 'орел',
    '🦆' => 'патица',
    '🦢' => 'лебед',
    '🦉' => 'бухал',
    '🦤' => 'Додо',
    '🪶' => 'перо',
    '🦩' => 'фламинго',
    '🦚' => 'паун',
    '🦜' => 'папагал',
    '🪽' => 'крило',
    '🪿' => 'гъска',
    '🐸' => 'жаба',
    '🐊' => 'крокодил',
    '🐢' => 'костенурка',
    '🦎' => 'гущер',
    '🐍' => 'змия',
    '🐲' => 'глава на дракон',
    '🐉' => 'дракон',
    '🦕' => 'завропод',
    '🦖' => 'тиранозавър',
    '🐳' => 'пръскащ кит',
    '🐋' => 'кит',
    '🐬' => 'делфин',
    '🫍' => 'косатка',
    '🦭' => 'тюлен',
    '🐟' => 'риба',
    '🐠' => 'тропическа риба',
    '🐡' => 'риба балон',
    '🦈' => 'акула',
    '🐙' => 'октопод',
    '🐚' => 'спирална раковина',
    '🪸' => 'корал',
    '🪼' => 'медуза',
    '🦀' => 'рак',
    '🦞' => 'омар',
    '🦐' => 'скарида',
    '🦑' => 'калмар',
    '🦪' => 'стрида',
    '🐌' => 'охлюв',
    '🦋' => 'пеперуда',
    '🐛' => 'буболечка',
    '🐜' => 'мравка',
    '🐝' => 'пчела',
    '🪲' => 'бръмбар',
    '🐞' => 'калинка',
    '🦗' => 'щурец',
    '🪳' => 'хлебарка',
    '🕷' => 'паяк',
    '🕸' => 'паяжина',
    '🦂' => 'скорпион',
    '🦟' => 'комар',
    '🪰' => 'муха',
    '🪱' => 'червей',
    '🦠' => 'микроб',
    '💐' => 'букет',
    '🌸' => 'черешов цвят',
    '💮' => 'бяло цвете',
    '🪷' => 'лотус',
    '🏵' => 'розета',
    '🌹' => 'роза',
    '🥀' => 'повехнало цвете',
    '🌺' => 'хибискус',
    '🌻' => 'слънчоглед',
    '🌼' => 'цвят',
    '🌷' => 'лале',
    '🪻' => 'зюмбюл',
    '🌱' => 'кълн',
    '🪴' => 'растение в саксия',
    '🌲' => 'вечнозелено дърво',
    '🌳' => 'листопадно дърво',
    '🌴' => 'палма',
    '🌵' => 'кактус',
    '🌾' => 'оризов клас',
    '🌿' => 'билка',
    '☘' => 'детелина',
    '🍀' => 'четирилистна детелина',
    '🍁' => 'кленов лист',
    '🍂' => 'паднало листо',
    '🍃' => 'листо, носено от вятъра',
    '🪹' => 'празно гнездо',
    '🪺' => 'гнездо с яйца',
    '🍄' => 'гъба',
    '🪾' => 'дърво без листа',
    '🍇' => 'грозде',
    '🍈' => 'пъпеш',
    '🍉' => 'диня',
    '🍊' => 'мандарина',
    '🍋' => 'лимон',
    '🍌' => 'банан',
    '🍍' => 'ананас',
    '🥭' => 'манго',
    '🍎' => 'червена ябълка',
    '🍏' => 'зелена ябълка',
    '🍐' => 'круша',
    '🍑' => 'праскова',
    '🍒' => 'череши',
    '🍓' => 'ягода',
    '🫐' => 'черни боровинки',
    '🥝' => 'плод киви',
    '🍅' => 'домат',
    '🫒' => 'маслина',
    '🥥' => 'кокосов орех',
    '🥑' => 'авокадо',
    '🍆' => 'патладжан',
    '🥔' => 'картоф',
    '🥕' => 'морков',
    '🌽' => 'царевичен кочан',
    '🌶' => 'люта чушка',
    '🫑' => 'пипер тип долма',
    '🥒' => 'краставица',
    '🥬' => 'листен зеленчук',
    '🥦' => 'броколи',
    '🧄' => 'чесън',
    '🧅' => 'лук',
    '🥜' => 'фъстъци',
    '🫘' => 'боб',
    '🌰' => 'кестен',
    '🫚' => 'корен от джинджифил',
    '🫛' => 'грахова шушулка',
    '🫜' => 'кореноплоден зеленчук',
    '🍞' => 'хляб',
    '🥐' => 'кроасан',
    '🥖' => 'багета',
    '🫓' => 'плосък хляб',
    '🥨' => 'брецел',
    '🥯' => 'геврек',
    '🥞' => 'палачинки',
    '🧇' => 'гофрета',
    '🧀' => 'резен сирене',
    '🍖' => 'месо с кост',
    '🍗' => 'пилешко бутче',
    '🥩' => 'парче месо',
    '🥓' => 'бекон',
    '🍔' => 'хамбургер',
    '🍟' => 'пържени картофи',
    '🍕' => 'пица',
    '🌭' => 'хотдог',
    '🥪' => 'сандвич',
    '🌮' => 'тако',
    '🌯' => 'бурито',
    '🫔' => 'тамалес',
    '🥙' => 'пълнена питка',
    '🧆' => 'фалафел',
    '🥚' => 'яйце',
    '🍳' => 'готвене',
    '🥘' => 'тава с храна',
    '🍲' => 'тенджера с храна',
    '🫕' => 'фондю',
    '🥣' => 'купа с лъжица',
    '🥗' => 'зелена салата',
    '🍿' => 'пуканки',
    '🧈' => 'масло',
    '🧂' => 'сол',
    '🥫' => 'консервирана храна',
    '🍱' => 'кутия за бенто',
    '🍘' => 'оризов крекер',
    '🍙' => 'топка ориз',
    '🍚' => 'сготвен ориз',
    '🍛' => 'ориз с къри',
    '🍜' => 'изпускаща пара купа',
    '🍝' => 'спагети',
    '🍠' => 'печен сладък картоф',
    '🍢' => 'оден',
    '🍣' => 'суши',
    '🍤' => 'пържена скарида',
    '🍥' => 'камабоко със спирален орнамент',
    '🥮' => 'лунен кейк',
    '🍡' => 'данго',
    '🥟' => 'пелмен',
    '🥠' => 'бисквита с късметче',
    '🥡' => 'кутия за храна за вкъщи',
    '🍦' => 'крем сладолед',
    '🍧' => 'леден десерт',
    '🍨' => 'сладолед',
    '🍩' => 'поничка',
    '🍪' => 'бисквитка',
    '🎂' => 'торта за рожден ден',
    '🍰' => 'шорткейк',
    '🧁' => 'къпкейк',
    '🥧' => 'пай',
    '🍫' => 'шоколадово блокче',
    '🍬' => 'бонбон',
    '🍭' => 'близалка',
    '🍮' => 'яйчен крем',
    '🍯' => 'гърне с мед',
    '🍼' => 'Бебешка бутилка',
    '🥛' => 'чаша мляко',
    '☕' => 'топла напитка',
    '🫖' => 'чайник',
    '🍵' => 'чаена чаша без дръжка',
    '🍶' => 'саке',
    '🍾' => 'бутилка с изхвърчаща тапа',
    '🍷' => 'винена чаша',
    '🍸' => 'коктейлна чаша',
    '🍹' => 'тропическа напитка',
    '🍺' => 'халба бира',
    '🍻' => 'звънтящи халби за бира',
    '🥂' => 'звънтящи чаши',
    '🥃' => 'ниска чаша',
    '🫗' => 'изливаща се течност',
    '🥤' => 'чаша със сламка',
    '🧋' => 'перлен чай',
    '🧃' => 'кутия за напитки',
    '🧉' => 'мате',
    '🧊' => 'кубче лед',
    '🥢' => 'пръчици за хранене',
    '🍽' => 'нож и вилица с чиния',
    '🍴' => 'нож и вилица',
    '🥄' => 'лъжица',
    '🔪' => 'кухненски нож',
    '🫙' => 'буркан',
    '🏺' => 'амфора',
    '🌍' => 'глобус с Европа и Африка',
    '🌎' => 'глобус със Северна и Южна Америка',
    '🌏' => 'глобус с Азия и Австралия',
    '🌐' => 'глобус с меридиани',
    '🗺' => 'карта на света',
    '🗾' => 'карта на Япония',
    '🧭' => 'компас',
    '🏔' => 'покрита със сняг планина',
    '⛰' => 'планина',
    '🛘' => 'свлачище',
    '🌋' => 'вулкан',
    '🗻' => 'връх Фуджи',
    '🏕' => 'къмпинг',
    '🏖' => 'плаж с чадър',
    '🏜' => 'пустиня',
    '🏝' => 'необитаем остров',
    '🏞' => 'национален парк',
    '🏟' => 'стадион',
    '🏛' => 'класическа сграда',
    '🏗' => 'строеж',
    '🧱' => 'тухла',
    '🪨' => 'скала',
    '🪵' => 'дървен материал',
    '🛖' => 'колиба',
    '🏘' => 'къщи',
    '🏚' => 'запусната къща',
    '🏠' => 'къща',
    '🏡' => 'къща с градина',
    '🏢' => 'офисна сграда',
    '🏣' => 'японска поща',
    '🏤' => 'поща',
    '🏥' => 'болница',
    '🏦' => 'банка',
    '🏨' => 'хотел',
    '🏩' => 'любовен хотел',
    '🏪' => 'смесен магазин',
    '🏫' => 'училище',
    '🏬' => 'универсален магазин',
    '🏭' => 'фабрика',
    '🏯' => 'японски замък',
    '🏰' => 'замък',
    '💒' => 'сватба',
    '🗼' => 'Кулата в Токио',
    '🗽' => 'Статуята на свободата',
    '⛪' => 'църква',
    '🕌' => 'джамия',
    '🛕' => 'индуистки храм',
    '🕍' => 'синагога',
    '⛩' => 'шинтоистки храм',
    '🕋' => 'кааба',
    '⛲' => 'фонтан',
    '⛺' => 'палатка',
    '🌁' => 'мъгливо',
    '🌃' => 'звездна нощ',
    '🏙' => 'градски изглед',
    '🌄' => 'изгрев над планини',
    '🌅' => 'изгрев',
    '🌆' => 'градски изглед по здрач',
    '🌇' => 'залез',
    '🌉' => 'мост през нощта',
    '♨' => 'горещ извор',
    '🎠' => 'кон от въртележка',
    '🛝' => 'детска пързалка',
    '🎡' => 'виенско колело',
    '🎢' => 'влакче в увеселителен парк',
    '💈' => 'знак на бръснар',
    '🎪' => 'циркова шатра',
    '🚂' => 'локомотив',
    '🚃' => 'вагон',
    '🚄' => 'високоскоростен влак',
    '🚅' => 'високоскоростен влак стрела',
    '🚆' => 'влак',
    '🚇' => 'метро',
    '🚈' => 'лека железница',
    '🚉' => 'гара',
    '🚊' => 'трамвай',
    '🚝' => 'монорелсова железница',
    '🚞' => 'планинска железница',
    '🚋' => 'трамваен вагон',
    '🚌' => 'автобус',
    '🚍' => 'приближаващ автобус',
    '🚎' => 'тролейбус',
    '🚐' => 'минибус',
    '🚑' => 'линейка',
    '🚒' => 'пожарен автомобил',
    '🚓' => 'полицейска кола',
    '🚔' => 'приближаваща полицейска кола',
    '🚕' => 'такси',
    '🚖' => 'приближаващо такси',
    '🚗' => 'автомобил',
    '🚘' => 'приближаващ автомобил',
    '🚙' => 'автомобил с повишена проходимост',
    '🛻' => 'пикап',
    '🚚' => 'камион за доставки',
    '🚛' => 'камион с полуремарке',
    '🚜' => 'трактор',
    '🏎' => 'състезателен автомобил',
    '🏍' => 'мотоциклет',
    '🛵' => 'моторен скутер',
    '🦽' => 'рингова инвалидна количка',
    '🦼' => 'акумулаторна инвалидна количка',
    '🛺' => 'авторикша',
    '🚲' => 'велосипед',
    '🛴' => 'тротинетка',
    '🛹' => 'скейтборд',
    '🛼' => 'ролери',
    '🚏' => 'автобусна спирка',
    '🛣' => 'магистрала',
    '🛤' => 'железопътна линия',
    '🛢' => 'варел за нефт',
    '⛽' => 'колонка за гориво',
    '🛞' => 'колело',
    '🚨' => 'полицейска лампа',
    '🚥' => 'хоризонтален светофар',
    '🚦' => 'вертикален светофар',
    '🛑' => 'знак стоп',
    '🚧' => 'строителни дейности',
    '⚓' => 'котва',
    '🛟' => 'спасителен пояс',
    '⛵' => 'яхта',
    '🛶' => 'кану',
    '🚤' => 'моторна лодка',
    '🛳' => 'пътнически кораб',
    '⛴' => 'ферибот',
    '🛥' => 'моторна яхта',
    '🚢' => 'кораб',
    '✈' => 'самолет',
    '🛩' => 'малък самолет',
    '🛫' => 'излитащ самолет',
    '🛬' => 'кацащ самолет',
    '🪂' => 'парашут',
    '💺' => 'седалка',
    '🚁' => 'хеликоптер',
    '🚟' => 'окачена железница',
    '🚠' => 'лифт',
    '🚡' => 'въжена линия',
    '🛰' => 'спътник',
    '🚀' => 'ракета',
    '🛸' => 'летяща чиния',
    '🛎' => 'звънец за рецепция',
    '🧳' => 'багаж',
    '⌛' => 'пясъчен часовник',
    '⏳' => 'пясъчен часовник с падащ пясък',
    '⌚' => 'ръчен часовник',
    '⏰' => 'будилник',
    '⏱' => 'хронометър',
    '⏲' => 'таймер',
    '🕰' => 'часовник за камина',
    '🕛' => 'дванадесет часът',
    '🕧' => 'дванадесет часът и половина',
    '🕐' => 'един часът',
    '🕜' => 'един и половина часът',
    '🕑' => 'два часът',
    '🕝' => 'два и половина часът',
    '🕒' => 'три часът',
    '🕞' => 'три и половина часът',
    '🕓' => 'четири часът',
    '🕟' => 'четири и половина часът',
    '🕔' => 'пет часът',
    '🕠' => 'пет и половина часът',
    '🕕' => 'шест часът',
    '🕡' => 'шест и половина часът',
    '🕖' => 'седем часът',
    '🕢' => 'седем и половина часът',
    '🕗' => 'осем часът',
    '🕣' => 'осем и половина часът',
    '🕘' => 'девет часът',
    '🕤' => 'девет и половина часът',
    '🕙' => 'десет часът',
    '🕥' => 'десет и половина часът',
    '🕚' => 'единадесет часът',
    '🕦' => 'единадесет и половина часът',
    '🌑' => 'новолуние',
    '🌒' => 'нарастващ полумесец на Луната',
    '🌓' => 'Луната в първа четвърт',
    '🌔' => 'нарастваща полупълна Луна',
    '🌕' => 'пълнолуние',
    '🌖' => 'намаляваща полупълна Луна',
    '🌗' => 'последна четвърт на Луната',
    '🌘' => 'намаляващ полумесец на Луната',
    '🌙' => 'полумесец',
    '🌚' => 'Луната в новолуние с лице',
    '🌛' => 'Луната в първа четвърт с лице',
    '🌜' => 'Луната в последна четвърт с лице',
    '🌡' => 'термометър',
    '☀' => 'слънце',
    '🌝' => 'Луната в пълнолуние с лице',
    '🌞' => 'Слънце с лице',
    '🪐' => 'планета с пръстен',
    '⭐' => 'звезда',
    '🌟' => 'блестяща звезда',
    '🌠' => 'падаща звезда',
    '🌌' => 'Млечният път',
    '☁' => 'облак',
    '⛅' => 'слънце зад облак',
    '⛈' => 'облак с дъжд и светкавица',
    '🌤' => 'слънце зад малък облак',
    '🌥' => 'слънце зад голям облак',
    '🌦' => 'слънце зад облак с дъжд',
    '🌧' => 'облак с дъжд',
    '🌨' => 'облак със сняг',
    '🌩' => 'облак със светкавица',
    '🌪' => 'торнадо',
    '🌫' => 'мъгла',
    '🌬' => 'лице, издухващо вятър',
    '🌀' => 'циклон',
    '🌈' => 'дъга',
    '🌂' => 'затворен чадър',
    '☂' => 'чадър',
    '☔' => 'чадър с дъждовни капки',
    '⛱' => 'плажен чадър',
    '⚡' => 'високо напрежение',
    '❄' => 'снежинка',
    '☃' => 'снежен човек',
    '⛄' => 'снежен човек без сняг',
    '☄' => 'комета',
    '🔥' => 'огън',
    '💧' => 'капка',
    '🌊' => 'вълна',
    '🎃' => 'тиквен фенер',
    '🎄' => 'коледна елха',
    '🎆' => 'фойерверки',
    '🎇' => 'фойерверк',
    '🧨' => 'пиратка',
    '✨' => 'звездички',
    '🎈' => 'балон',
    '🎉' => 'конфети',
    '🎊' => 'топка с конфети',
    '🎋' => 'дърво за танабата',
    '🎍' => 'украса кадомацу',
    '🎎' => 'японски кукли',
    '🎏' => 'коинобори',
    '🎐' => 'вятърни камбанки',
    '🎑' => 'церемония цукими',
    '🧧' => 'червен плик',
    '🎀' => 'панделка',
    '🎁' => 'опакован подарък',
    '🎗' => 'лента за напомняне',
    '🎟' => 'билети за вход',
    '🎫' => 'билет',
    '🎖' => 'военен медал',
    '🏆' => 'спортна купа',
    '🏅' => 'спортен медал',
    '🥇' => 'медал за първо място',
    '🥈' => 'медал за второ място',
    '🥉' => 'медал за трето място',
    '⚽' => 'футболна топка',
    '⚾' => 'бейзболна топка',
    '🥎' => 'софтбол',
    '🏀' => 'баскетболна топка',
    '🏐' => 'волейбол',
    '🏈' => 'топка за американски футбол',
    '🏉' => 'топка за ръгби',
    '🎾' => 'тенис',
    '🥏' => 'фризби',
    '🎳' => 'боулинг',
    '🏏' => 'крикет',
    '🏑' => 'хокей на трева',
    '🏒' => 'стик и шайба за хокей на лед',
    '🥍' => 'лакрос',
    '🏓' => 'тенис на маса',
    '🏸' => 'бадминтон',
    '🥊' => 'боксова ръкавица',
    '🥋' => 'дреха за бойни изкуства',
    '🥅' => 'мрежа за голове',
    '⛳' => 'флагче в дупка',
    '⛸' => 'кънка за лед',
    '🎣' => 'въдица',
    '🤿' => 'маска за гмуркане',
    '🎽' => 'фланелка',
    '🎿' => 'ски',
    '🛷' => 'шейна',
    '🥌' => 'камък за кърлинг',
    '🎯' => 'точен удар',
    '🪀' => 'йо-йо',
    '🪁' => 'хвърчило',
    '🔫' => 'воден пистолет',
    '🎱' => 'билярд',
    '🔮' => 'Кристално кълбо',
    '🪄' => 'вълшебна пръчица',
    '🎮' => 'видеоигра',
    '🕹' => 'джойстик',
    '🎰' => 'ротативка',
    '🎲' => 'зар за игра',
    '🧩' => 'част от пъзел',
    '🧸' => 'плюшено мече',
    '🪅' => 'пинята',
    '🪩' => 'диско топка',
    '🪆' => 'матрьошки',
    '♠' => 'пика',
    '♥' => 'купа',
    '♦' => 'каро',
    '♣' => 'спатия',
    '♟' => 'пешка',
    '🃏' => 'жокер',
    '🀄' => '„червен дракон“ в маджонг',
    '🎴' => 'карти за игра ханафуда',
    '🎭' => 'сценични изкуства',
    '🖼' => 'картина в рамка',
    '🎨' => 'палитра на художник',
    '🧵' => 'конец',
    '🪡' => 'шивашка игла',
    '🧶' => 'прежда',
    '🪢' => 'възел',
    '👓' => 'очила',
    '🕶' => 'тъмни очила',
    '🥽' => 'предпазни очила',
    '🥼' => 'лабораторна престилка',
    '🦺' => 'светлоотразителна жилетка',
    '👔' => 'вратовръзка',
    '👕' => 'тениска',
    '👖' => 'дънки',
    '🧣' => 'шал',
    '🧤' => 'ръкавици',
    '🧥' => 'палто',
    '🧦' => 'чорапи',
    '👗' => 'рокля',
    '👘' => 'кимоно',
    '🥻' => 'сари',
    '🩱' => 'цял бански',
    '🩲' => 'бански',
    '🩳' => 'плувни шорти',
    '👙' => 'бикини',
    '👚' => 'дамско облекло',
    '🪭' => 'ръчно сгъваемо ветрило',
    '👛' => 'портмоне',
    '👜' => 'чанта',
    '👝' => 'чантичка',
    '🛍' => 'пазарски чанти',
    '🎒' => 'ученическа раница',
    '🩴' => 'джапанка',
    '👞' => 'мъжка обувка',
    '👟' => 'спортна обувка',
    '🥾' => 'туристическа обувка',
    '🥿' => 'обувка без ток',
    '👠' => 'обувка с висок ток',
    '👡' => 'дамска отворена обувка',
    '🩰' => 'балетни обувки',
    '👢' => 'дамски ботуш',
    '🪮' => 'декоративен гребен',
    '👑' => 'корона',
    '👒' => 'дамска шапка',
    '🎩' => 'цилиндър',
    '🎓' => 'шапка за дипломиране',
    '🧢' => 'шапка с козирка',
    '🪖' => 'военна каска',
    '⛑' => 'каска с бял кръст',
    '📿' => 'броеница',
    '💄' => 'червило',
    '💍' => 'пръстен',
    '💎' => 'скъпоценен камък',
    '🔇' => 'изключен високоговорител',
    '🔈' => 'високоговорител със слаб звук',
    '🔉' => 'високоговорител със средносилен звук',
    '🔊' => 'високоговорител със силен звук',
    '📢' => 'Високоговорител за обществени места',
    '📣' => 'мегафон',
    '📯' => 'пощенски рог',
    '🔔' => 'звънец',
    '🔕' => 'зачертан звънец',
    '🎼' => 'нотен запис',
    '🎵' => 'нота',
    '🎶' => 'ноти',
    '🎙' => 'студиен микрофон',
    '🎚' => 'плъзгач за нивото',
    '🎛' => 'копчета за управление',
    '🎤' => 'микрофон',
    '🎧' => 'слушалки',
    '📻' => 'радио',
    '🎷' => 'саксофон',
    '🎺' => 'тромпет',
    '🪊' => 'тромбон',
    '🪗' => 'акордеон',
    '🎸' => 'китара',
    '🎹' => 'клавиатура на музикален инструмент',
    '🎻' => 'цигулка',
    '🪕' => 'банджо',
    '🥁' => 'барабан',
    '🪘' => 'висок барабан',
    '🪇' => 'маракаси',
    '🪈' => 'флейта',
    '🪉' => 'арфа',
    '📱' => 'мобилен телефон',
    '📲' => 'мобилен телефон със стрелка',
    '☎' => 'телефон',
    '📞' => 'телефонна слушалка',
    '📟' => 'пейджър',
    '📠' => 'факс',
    '🔋' => 'батерия',
    '🪫' => 'изтощена батерия',
    '🔌' => 'електрически щепсел',
    '💻' => 'лаптоп',
    '🖥' => 'настолен компютър',
    '🖨' => 'принтер',
    '⌨' => 'клавиатура',
    '🖱' => 'компютърна мишка',
    '🖲' => 'трекбол',
    '💽' => 'минидиск',
    '💾' => 'дискета',
    '💿' => 'оптичен диск',
    '📀' => '[DVD]',
    '🧮' => 'сметало',
    '🎥' => 'филмова камера',
    '🎞' => 'филмови кадри',
    '📽' => 'кинопроектор',
    '🎬' => 'клапа',
    '📺' => 'телевизор',
    '📷' => 'фотоапарат',
    '📸' => 'фотоапарат със светкавица',
    '📹' => 'видеокамера',
    '📼' => 'видеокасета',
    '🔍' => 'наклонена наляво лупа',
    '🔎' => 'наклонена надясно лупа',
    '🕯' => 'свещ',
    '💡' => 'електрическа крушка',
    '🔦' => 'фенерче',
    '🏮' => 'червен хартиен фенер',
    '🪔' => 'маслена лампа',
    '📔' => 'бележник с декоративна корица',
    '📕' => 'затворена книга',
    '📖' => 'отворена книга',
    '📗' => 'зелена книга',
    '📘' => 'синя книга',
    '📙' => 'оранжева книга',
    '📚' => 'книги',
    '📓' => 'бележник',
    '📒' => 'главна книга',
    '📃' => 'завита страница',
    '📜' => 'свитък',
    '📄' => 'страница с лицето нагоре',
    '📰' => 'вестник',
    '🗞' => 'навит на руло вестник',
    '📑' => 'отметки',
    '🔖' => 'отметка',
    '🏷' => 'етикет',
    '🪙' => 'монета',
    '💰' => 'торба с пари',
    '🪎' => 'сандък със съкровища',
    '💴' => 'банкнота със знак за йена',
    '💵' => 'банкнота със знак за долар',
    '💶' => 'банкнота със знак за евро',
    '💷' => 'банкнота със знак за лира',
    '💸' => 'пари с крила',
    '💳' => 'кредитна карта',
    '🧾' => 'разписка',
    '💹' => 'възходяща диаграма със знак за йена',
    '✉' => 'плик',
    '📧' => 'имейл',
    '📨' => 'пристигащ плик',
    '📩' => 'Плик със стрелка',
    '📤' => 'изходяща тава',
    '📥' => 'входяща тава',
    '📦' => 'пакет',
    '📫' => 'затворена пощенска кутия с вдигнато флагче',
    '📪' => 'затворена пощенска кутия със спуснато флагче',
    '📬' => 'отворена пощенска кутия с вдигнато флагче',
    '📭' => 'отворена пощенска кутия със спуснато флагче',
    '📮' => 'пощенска кутия',
    '🗳' => 'урна за гласуване с бюлетина',
    '✏' => 'молив',
    '✒' => 'черен писец',
    '🖋' => 'писалка',
    '🖊' => 'химикалка',
    '🖌' => 'четка',
    '🖍' => 'пастел',
    '📝' => 'бележка',
    '💼' => 'чанта за документи',
    '📁' => 'папка за документи',
    '📂' => 'отворена папка',
    '🗂' => 'разделители за картотека',
    '📅' => 'календар',
    '📆' => 'календар с късащи се листове',
    '🗒' => 'бележник със спирала',
    '🗓' => 'календар със спирала',
    '📇' => 'картотека',
    '📈' => 'възходяща диаграма',
    '📉' => 'низходяща диаграма',
    '📊' => 'Стълбовидна диаграма',
    '📋' => 'клипборд',
    '📌' => 'кабърче',
    '📍' => 'кръгло кабърче',
    '📎' => 'кламер',
    '🖇' => 'съединени кламери',
    '📏' => 'линия',
    '📐' => 'триъгълник',
    '✂' => 'ножици',
    '🗃' => 'картотечна кутия',
    '🗄' => 'картотечен шкаф',
    '🗑' => 'кошче',
    '🔒' => 'катинар',
    '🔓' => 'отворен катинар',
    '🔏' => 'катинар с писалка',
    '🔐' => 'затворен катинар с ключ',
    '🔑' => 'ключ',
    '🗝' => 'стар ключ',
    '🔨' => 'чук',
    '🪓' => 'брадва',
    '⛏' => 'кирка',
    '⚒' => 'чук и кирка',
    '🛠' => 'чук и гаечен ключ',
    '🗡' => 'кинжал',
    '⚔' => 'кръстосани мечове',
    '💣' => 'бомба',
    '🪃' => 'бумеранг',
    '🏹' => 'лък и стрела',
    '🛡' => 'щит',
    '🪚' => 'трион',
    '🔧' => 'Гаечен ключ',
    '🪛' => 'отвертка',
    '🔩' => 'болт и гайка',
    '⚙' => 'зъбно колело',
    '🗜' => 'стяга',
    '⚖' => 'везна',
    '🦯' => 'бял бастун',
    '🔗' => 'връзка',
    '⛓' => 'вериги',
    '🪝' => 'кука',
    '🧰' => 'кутия за инструменти',
    '🧲' => 'магнит',
    '🪜' => 'стълба',
    '🪏' => 'лопата',
    '⚗' => 'аламбик',
    '🧪' => 'епруветка',
    '🧫' => 'блюдо на Петри',
    '🧬' => 'ДНК',
    '🔬' => 'микроскоп',
    '🔭' => 'телескоп',
    '📡' => 'сателитна антена',
    '💉' => 'спринцовка',
    '🩸' => 'капка кръв',
    '💊' => 'хапче',
    '🩹' => 'лепенка за рани',
    '🩼' => 'патерица',
    '🩺' => 'стетоскоп',
    '🩻' => 'рентген',
    '🚪' => 'врата',
    '🛗' => 'асансьор',
    '🪞' => 'огледало',
    '🪟' => 'прозорец',
    '🛏' => 'легло',
    '🛋' => 'канапе и лампа',
    '🪑' => 'стол',
    '🚽' => 'тоалетна чиния',
    '🪠' => 'вакуумна помпа за отпушване',
    '🚿' => 'душ',
    '🛁' => 'вана',
    '🪤' => 'капан за мишки',
    '🪒' => 'бръснач',
    '🧴' => 'бутилка с лосион',
    '🧷' => 'безопасна игла',
    '🧹' => 'метла',
    '🧺' => 'кошница',
    '🧻' => 'тоалетна хартия',
    '🪣' => 'кофа',
    '🧼' => 'сапун',
    '🫧' => 'балончета',
    '🪥' => 'четка за зъби',
    '🧽' => 'гъба за баня',
    '🧯' => 'пожарогасител',
    '🛒' => 'количка за пазаруване',
    '🚬' => 'цигара',
    '⚰' => 'ковчег',
    '🪦' => 'надгробна плоча',
    '⚱' => 'погребална урна',
    '🧿' => 'назар',
    '🪬' => 'хамса',
    '🗿' => 'моаи',
    '🪧' => 'плакат',
    '🪪' => 'документ за самоличност',
    '🏧' => 'знак за банкомат',
    '🚮' => 'символ за място за изхвърляне на боклук',
    '🚰' => 'питейна вода',
    '♿' => 'символ за инвалидна количка',
    '🚹' => 'мъжка тоалетна',
    '🚺' => 'женска тоалетна',
    '🚻' => 'обществена тоалетна',
    '🚼' => 'символ на бебе',
    '🚾' => 'тоалетна',
    '🛂' => 'паспортен контрол',
    '🛃' => 'митница',
    '🛄' => 'получаване на багаж',
    '🛅' => 'съхранение на багаж',
    '⚠' => 'предупредителен знак',
    '🚸' => 'пресичащи деца',
    '⛔' => 'влизането забранено',
    '🚫' => 'забранено',
    '🚳' => 'забранено за велосипеди',
    '🚭' => 'пушенето забранено',
    '🚯' => 'забранено изхвърляне на боклук',
    '🚱' => 'непитейна вода',
    '🚷' => 'забранено за пешеходци',
    '📵' => 'забранени мобилни телефони',
    '🔞' => 'забранено за лица под осемнадесет години',
    '☢' => 'радиоактивно',
    '☣' => 'биологична опасност',
    '⬆' => 'стрелка нагоре',
    '↗' => 'стрелка нагоре и надясно',
    '➡' => 'стрелка надясно',
    '↘' => 'стрелка надолу и надясно',
    '⬇' => 'стрелка надолу',
    '↙' => 'стрелка надолу и наляво',
    '⬅' => 'стрелка наляво',
    '↖' => 'стрелка нагоре и наляво',
    '↕' => 'Стрелка нагоре и надолу',
    '↔' => 'стрелка наляво и надясно',
    '↩' => 'извита наляво дясна стрелка',
    '↪' => 'извита надясно лява стрелка',
    '⤴' => 'извита нагоре дясна стрелка',
    '⤵' => 'извита надолу дясна стрелка',
    '🔃' => 'вертикални стрелки по часовниковата стрелка',
    '🔄' => 'бутон със стрелки срещу часовниковата стрелка',
    '🔙' => 'стрелка с back',
    '🔚' => 'стрелка с end',
    '🔛' => 'стрелка с „on!“',
    '🔜' => 'стрелка със soon',
    '🔝' => 'стрелка с top',
    '🛐' => 'място за религиозно преклонение',
    '⚛' => 'символ на атом',
    '🕉' => 'ом',
    '✡' => 'звезда на Давид',
    '☸' => 'колелото на дхарма',
    '☯' => 'ин и ян',
    '✝' => 'латински кръст',
    '☦' => 'православен кръст',
    '☪' => 'полумесец със звезда',
    '☮' => 'символ на мира',
    '🕎' => 'менора',
    '🔯' => 'шестолъчна звезда с точка',
    '🪯' => 'кханда',
    '♈' => 'зодиакален знак овен',
    '♉' => 'зодиакален знак телец',
    '♊' => 'зодиакален знак близнаци',
    '♋' => 'зодиакален знак рак',
    '♌' => 'зодиакален знак лъв',
    '♍' => 'зодиакален знак дева',
    '♎' => 'зодиакален знак везни',
    '♏' => 'зодиакален знак скорпион',
    '♐' => 'зодиакален знак стрелец',
    '♑' => 'зодиакален знак козирог',
    '♒' => 'зодиакален знак водолей',
    '♓' => 'зодиакален знак риби',
    '⛎' => 'зодиакален знак змиеносец',
    '🔀' => 'бутон за разбъркване',
    '🔁' => 'бутон за повтаряне',
    '🔂' => 'бутон за единично повтаряне',
    '▶' => 'бутон за пускане',
    '⏩' => 'бутон за превъртане напред',
    '⏭' => 'бутон за следващия запис',
    '⏯' => 'бутон за пускане или пауза',
    '◀' => 'бутон за връщане',
    '⏪' => 'бутон за превъртане назад',
    '⏮' => 'бутон за предишния запис',
    '🔼' => 'бутон за нагоре',
    '⏫' => 'бутон за бързо изкачване',
    '🔽' => 'бутон за надолу',
    '⏬' => 'бутон за бързо слизане',
    '⏸' => 'бутон за пауза',
    '⏹' => 'бутон за стоп',
    '⏺' => 'бутон за запис',
    '⏏' => 'бутон за изваждане',
    '🎦' => 'кино',
    '🔅' => 'бутон за ниска яркост',
    '🔆' => 'бутон за висока яркост',
    '📶' => 'стълбчета за сила на сигнал',
    '🛜' => 'безжичен',
    '📳' => 'режим на вибрация',
    '📴' => 'изключен мобилен телефон',
    '♀' => 'знак за женски пол',
    '♂' => 'знак за мъжки пол',
    '⚧' => 'символ за трансджендър',
    '✖' => 'Удебелен знак за умножение',
    '➕' => 'Удебелен знак плюс',
    '➖' => 'Удебелен знак минус',
    '➗' => 'Удебелен знак за деление',
    '🟰' => 'удебелен знак за равенство',
    '♾' => 'безкрайност',
    '‼' => 'двойна удивителна',
    '⁉' => 'удивителна и въпросителна',
    '❓' => 'червена въпросителна',
    '❔' => 'бяла въпросителна',
    '❕' => 'бяла удивителна',
    '❗' => 'червена удивителна',
    '〰' => 'Вълнообразно тире',
    '💱' => 'обмен на валута',
    '💲' => 'удебелен знак за долар',
    '⚕' => 'символ за медицина',
    '♻' => 'символ за рециклиране',
    '⚜' => 'хералдическа лилия',
    '🔱' => 'тризъбец',
    '📛' => 'бадж',
    '🔰' => 'японски символ за начинаещ',
    '⭕' => 'удебелена червена окръжност',
    '✅' => 'удебелена бяла отметка',
    '☑' => 'поле с отметка',
    '✔' => 'Удебелена отметка',
    '❌' => 'кръстче',
    '❎' => 'бутон с кръстче',
    '➰' => 'примка',
    '➿' => 'двойна примка',
    '〽' => 'знак за смяна на ролята',
    '✳' => 'звезда с осем лъча',
    '✴' => 'осмолъчна звезда',
    '❇' => 'искра',
    '™' => 'търговска марка',
    '🫟' => 'петно',
    '🔠' => 'въвеждане на главни букви на латиница',
    '🔡' => 'въвеждане на малки букви на латиница',
    '🔢' => 'въвеждане на цифри',
    '🔣' => 'въвеждане на символи',
    '🔤' => 'въвеждане на букви на латиница',
    '🅰' => 'бутон с „А“',
    '🆎' => 'бутон с „AB“',
    '🅱' => 'бутон с „B“',
    '🆑' => '„CL“ в квадрат',
    '🆒' => '„Cool“ в квадрат',
    '🆓' => '„Free“ в квадрат',
    'ℹ' => 'Източник на информация',
    '🆔' => '„ID“ в квадрат',
    'Ⓜ' => 'Буква „M“ в кръг',
    '🆕' => '„New“ в квадрат',
    '🆖' => '„NG“ в квадрат',
    '🅾' => 'квадрат с „0“ (кръвна група)',
    '🆗' => '„Окей“ в квадрат',
    '🅿' => 'Бутон с „P“',
    '🆘' => '„SOS“ в квадрат',
    '🆙' => 'Бутон с „up!“',
    '🆚' => '„VS“ в квадрат',
    '🈁' => '„Коко“ от катакана в квадрат',
    '🈂' => '„Са“ от катакана в квадрат',
    '🈷' => 'Идеограма „луна“ в квадрат',
    '🈶' => 'Идеограма „съществувам“ в квадрат',
    '🈯' => 'Идеограма „пръст“ в квадрат',
    '🉐' => 'Идеограма за предимство в кръг',
    '🈹' => 'Идеограма „разделяне“ в квадрат',
    '🈚' => 'Идеограма „отрицание“ в квадрат',
    '🈲' => 'Идеограма „забранявам“ в квадрат',
    '🉑' => 'Идеограма за приемане в кръг',
    '🈸' => 'Идеограма „прилагам“ в квадрат',
    '🈴' => 'Идеограма „заедно“ в квадрат',
    '🈳' => 'Идеограма „празно“ в квадрат',
    '㊗' => 'Идеограма за поздравление в кръг',
    '㊙' => 'Идеограма за тайна в кръг',
    '🈺' => 'Идеограма „отворено“ в квадрат',
    '🈵' => 'Идеограма „пълнота“ в квадрат',
    '🔴' => 'червен кръг',
    '🟠' => 'оранжев кръг',
    '🟡' => 'жълт кръг',
    '🟢' => 'зелен кръг',
    '🔵' => 'син кръг',
    '🟣' => 'лилав кръг',
    '🟤' => 'кафяв кръг',
    '⚫' => 'черен кръг',
    '⚪' => 'бял кръг',
    '🟥' => 'червен квадрат',
    '🟧' => 'оранжев квадрат',
    '🟨' => 'жълт квадрат',
    '🟩' => 'зелен квадрат',
    '🟦' => 'син квадрат',
    '🟪' => 'лилав квадрат',
    '🟫' => 'кафяв квадрат',
    '⬛' => 'черен голям квадрат',
    '⬜' => 'бял голям квадрат',
    '◼' => 'черен среден квадрат',
    '◻' => 'Бял среден квадрат',
    '◾' => 'черен средномалък квадрат',
    '◽' => 'Бял средномалък квадрат',
    '▪' => 'малък черен квадрат',
    '▫' => 'малък бял квадрат',
    '🔶' => 'голям оранжев ромб',
    '🔷' => 'голям син ромб',
    '🔸' => 'малък оранжев ромб',
    '🔹' => 'малък син ромб',
    '🔺' => 'сочещ нагоре червен триъгълник',
    '🔻' => 'сочещ надолу червен триъгълник',
    '💠' => 'ромб с точка в средата',
    '🔘' => 'бутон за избор',
    '🔳' => 'квадратен бутон с бял контур',
    '🔲' => 'квадратен бутон с черен контур',
    '🏁' => 'кариран флаг',
    '🚩' => 'триъгълно знаме',
    '🎌' => 'кръстосани знамена',
    '🏴' => 'черно знаме',
    '🏳' => 'бяло знаме',
];
