<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'cusan: person, person, arlliw croen golau, arlliw croen canolig-golau',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'cusan: person, person, arlliw croen golau, arlliw croen canolog',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'cusan: person, person, arlliw croen golau, arlliw croen canolig-tywyll',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'cusan: person, person, arlliw croen golau, arlliw croen tywyll',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'cusan: person, person, arlliw croen canolig-golau, arlliw croen golau',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'cusan: person, person, arlliw croen canolig-golau, arlliw croen canolog',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'cusan: person, person, arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'cusan: person, person, arlliw croen canolig-golau, arlliw croen tywyll',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'cusan: person, person, arlliw croen canolog, arlliw croen golau',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'cusan: person, person, arlliw croen canolog, arlliw croen canolig-golau',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'cusan: person, person, arlliw croen canolog, arlliw croen canolig-tywyll',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'cusan: person, person, arlliw croen canolog, arlliw croen tywyll',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'cusan: person, person, arlliw croen canolig-tywyll, arlliw croen golau',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'cusan: person, person, arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'cusan: person, person, arlliw croen canolig-tywyll, arlliw croen canolog',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'cusan: person, person, arlliw croen canolig-tywyll, arlliw croen tywyll',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'cusan: person, person, arlliw croen tywyll, arlliw croen golau',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'cusan: person, person, arlliw croen tywyll, arlliw croen canolig-golau',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'cusan: person, person, arlliw croen tywyll, arlliw croen canolog',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'cusan: person, person, arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👨🏻‍❤‍💋‍👨🏻' => 'cusan: dyn, dyn, arlliw croen golau',
    '👨🏻‍❤‍💋‍👨🏼' => 'cusan: dyn, dyn, arlliw croen golau, arlliw croen canolig-golau',
    '👨🏻‍❤‍💋‍👨🏽' => 'cusan: dyn, dyn, arlliw croen golau, arlliw croen canolog',
    '👨🏻‍❤‍💋‍👨🏾' => 'cusan: dyn, dyn, arlliw croen golau, arlliw croen canolig-tywyll',
    '👨🏻‍❤‍💋‍👨🏿' => 'cusan: dyn, dyn, arlliw croen golau, arlliw croen tywyll',
    '👨🏼‍❤‍💋‍👨🏻' => 'cusan: dyn, dyn, arlliw croen canolig-golau, arlliw croen golau',
    '👨🏼‍❤‍💋‍👨🏼' => 'cusan: dyn, dyn, arlliw croen canolig-golau',
    '👨🏼‍❤‍💋‍👨🏽' => 'cusan: dyn, dyn, arlliw croen canolig-golau, arlliw croen canolog',
    '👨🏼‍❤‍💋‍👨🏾' => 'cusan: dyn, dyn, arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👨🏼‍❤‍💋‍👨🏿' => 'cusan: dyn, dyn, arlliw croen canolig-golau, arlliw croen tywyll',
    '👨🏽‍❤‍💋‍👨🏻' => 'cusan: dyn, dyn, arlliw croen canolog, arlliw croen golau',
    '👨🏽‍❤‍💋‍👨🏼' => 'cusan: dyn, dyn, arlliw croen canolog, arlliw croen canolig-golau',
    '👨🏽‍❤‍💋‍👨🏽' => 'cusan: dyn, dyn, arlliw croen canolog',
    '👨🏽‍❤‍💋‍👨🏾' => 'cusan: dyn, dyn, arlliw croen canolog, arlliw croen canolig-tywyll',
    '👨🏽‍❤‍💋‍👨🏿' => 'cusan: dyn, dyn, arlliw croen canolog, arlliw croen tywyll',
    '👨🏾‍❤‍💋‍👨🏻' => 'cusan: dyn, dyn, arlliw croen canolig-tywyll, arlliw croen golau',
    '👨🏾‍❤‍💋‍👨🏼' => 'cusan: dyn, dyn, arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👨🏾‍❤‍💋‍👨🏽' => 'cusan: dyn, dyn, arlliw croen canolig-tywyll, arlliw croen canolog',
    '👨🏾‍❤‍💋‍👨🏾' => 'cusan: dyn, dyn, arlliw croen canolig-tywyll',
    '👨🏾‍❤‍💋‍👨🏿' => 'cusan: dyn, dyn, arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👨🏿‍❤‍💋‍👨🏻' => 'cusan: dyn, dyn, arlliw croen tywyll, arlliw croen golau',
    '👨🏿‍❤‍💋‍👨🏼' => 'cusan: dyn, dyn, arlliw croen tywyll, arlliw croen canolig-golau',
    '👨🏿‍❤‍💋‍👨🏽' => 'cusan: dyn, dyn, arlliw croen tywyll, arlliw croen canolog',
    '👨🏿‍❤‍💋‍👨🏾' => 'cusan: dyn, dyn, arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👨🏿‍❤‍💋‍👨🏿' => 'cusan: dyn, dyn, arlliw croen tywyll',
    '👩🏻‍❤‍💋‍👨🏻' => 'cusan: menyw, dyn, arlliw croen golau',
    '👩🏻‍❤‍💋‍👨🏼' => 'cusan: menyw, dyn, arlliw croen golau, arlliw croen canolig-golau',
    '👩🏻‍❤‍💋‍👨🏽' => 'cusan: menyw, dyn, arlliw croen golau, arlliw croen canolog',
    '👩🏻‍❤‍💋‍👨🏾' => 'cusan: menyw, dyn, arlliw croen golau, arlliw croen canolig-tywyll',
    '👩🏻‍❤‍💋‍👨🏿' => 'cusan: menyw, dyn, arlliw croen golau, arlliw croen tywyll',
    '👩🏼‍❤‍💋‍👨🏻' => 'cusan: menyw, dyn, arlliw croen canolig-golau, arlliw croen golau',
    '👩🏼‍❤‍💋‍👨🏼' => 'cusan: menyw, dyn, arlliw croen canolig-golau',
    '👩🏼‍❤‍💋‍👨🏽' => 'cusan: menyw, dyn, arlliw croen canolig-golau, arlliw croen canolog',
    '👩🏼‍❤‍💋‍👨🏾' => 'cusan: menyw, dyn, arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👩🏼‍❤‍💋‍👨🏿' => 'cusan: menyw, dyn, arlliw croen canolig-golau, arlliw croen tywyll',
    '👩🏽‍❤‍💋‍👨🏻' => 'cusan: menyw, dyn, arlliw croen canolog, arlliw croen golau',
    '👩🏽‍❤‍💋‍👨🏼' => 'cusan: menyw, dyn, arlliw croen canolog, arlliw croen canolig-golau',
    '👩🏽‍❤‍💋‍👨🏽' => 'cusan: menyw, dyn, arlliw croen canolog',
    '👩🏽‍❤‍💋‍👨🏾' => 'cusan: menyw, dyn, arlliw croen canolog, arlliw croen canolig-tywyll',
    '👩🏽‍❤‍💋‍👨🏿' => 'cusan: menyw, dyn, arlliw croen canolog, arlliw croen tywyll',
    '👩🏾‍❤‍💋‍👨🏻' => 'cusan: menyw, dyn, arlliw croen canolig-tywyll, arlliw croen golau',
    '👩🏾‍❤‍💋‍👨🏼' => 'cusan: menyw, dyn, arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👩🏾‍❤‍💋‍👨🏽' => 'cusan: menyw, dyn, arlliw croen canolig-tywyll, arlliw croen canolog',
    '👩🏾‍❤‍💋‍👨🏾' => 'cusan: menyw, dyn, arlliw croen canolig-tywyll',
    '👩🏾‍❤‍💋‍👨🏿' => 'cusan: menyw, dyn, arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👩🏿‍❤‍💋‍👨🏻' => 'cusan: menyw, dyn, arlliw croen tywyll, arlliw croen golau',
    '👩🏿‍❤‍💋‍👨🏼' => 'cusan: menyw, dyn, arlliw croen tywyll, arlliw croen canolig-golau',
    '👩🏿‍❤‍💋‍👨🏽' => 'cusan: menyw, dyn, arlliw croen tywyll, arlliw croen canolog',
    '👩🏿‍❤‍💋‍👨🏾' => 'cusan: menyw, dyn, arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👩🏿‍❤‍💋‍👨🏿' => 'cusan: menyw, dyn, arlliw croen tywyll',
    '👩🏻‍❤‍💋‍👩🏻' => 'cusan: menyw, menyw, arlliw croen golau',
    '👩🏻‍❤‍💋‍👩🏼' => 'cusan: menyw, menyw, arlliw croen golau, arlliw croen canolig-golau',
    '👩🏻‍❤‍💋‍👩🏽' => 'cusan: menyw, menyw, arlliw croen golau, arlliw croen canolog',
    '👩🏻‍❤‍💋‍👩🏾' => 'cusan: menyw, menyw, arlliw croen golau, arlliw croen canolig-tywyll',
    '👩🏻‍❤‍💋‍👩🏿' => 'cusan: menyw, menyw, arlliw croen golau, arlliw croen tywyll',
    '👩🏼‍❤‍💋‍👩🏻' => 'cusan: menyw, menyw, arlliw croen canolig-golau, arlliw croen golau',
    '👩🏼‍❤‍💋‍👩🏼' => 'cusan: menyw, menyw, arlliw croen canolig-golau',
    '👩🏼‍❤‍💋‍👩🏽' => 'cusan: menyw, menyw, arlliw croen canolig-golau, arlliw croen canolog',
    '👩🏼‍❤‍💋‍👩🏾' => 'cusan: menyw, menyw, arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👩🏼‍❤‍💋‍👩🏿' => 'cusan: menyw, menyw, arlliw croen canolig-golau, arlliw croen tywyll',
    '👩🏽‍❤‍💋‍👩🏻' => 'cusan: menyw, menyw, arlliw croen canolog, arlliw croen golau',
    '👩🏽‍❤‍💋‍👩🏼' => 'cusan: menyw, menyw, arlliw croen canolog, arlliw croen canolig-golau',
    '👩🏽‍❤‍💋‍👩🏽' => 'cusan: menyw, menyw, arlliw croen canolog',
    '👩🏽‍❤‍💋‍👩🏾' => 'cusan: menyw, menyw, arlliw croen canolog, arlliw croen canolig-tywyll',
    '👩🏽‍❤‍💋‍👩🏿' => 'cusan: menyw, menyw, arlliw croen canolog, arlliw croen tywyll',
    '👩🏾‍❤‍💋‍👩🏻' => 'cusan: menyw, menyw, arlliw croen canolig-tywyll, arlliw croen golau',
    '👩🏾‍❤‍💋‍👩🏼' => 'cusan: menyw, menyw, arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👩🏾‍❤‍💋‍👩🏽' => 'cusan: menyw, menyw, arlliw croen canolig-tywyll, arlliw croen canolog',
    '👩🏾‍❤‍💋‍👩🏾' => 'cusan: menyw, menyw, arlliw croen canolig-tywyll',
    '👩🏾‍❤‍💋‍👩🏿' => 'cusan: menyw, menyw, arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👩🏿‍❤‍💋‍👩🏻' => 'cusan: menyw, menyw, arlliw croen tywyll, arlliw croen golau',
    '👩🏿‍❤‍💋‍👩🏼' => 'cusan: menyw, menyw, arlliw croen tywyll, arlliw croen canolig-golau',
    '👩🏿‍❤‍💋‍👩🏽' => 'cusan: menyw, menyw, arlliw croen tywyll, arlliw croen canolog',
    '👩🏿‍❤‍💋‍👩🏾' => 'cusan: menyw, menyw, arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👩🏿‍❤‍💋‍👩🏿' => 'cusan: menyw, menyw, arlliw croen tywyll',
    '🧑🏻‍🫯‍🧑🏼' => 'taflwyr codwm: arlliw croen golau, arlliw croen canolig-golau',
    '🧑🏻‍🫯‍🧑🏽' => 'taflwyr codwm: arlliw croen golau, arlliw croen canolog',
    '🧑🏻‍🫯‍🧑🏾' => 'taflwyr codwm: arlliw croen golau, arlliw croen canolig-tywyll',
    '🧑🏻‍🫯‍🧑🏿' => 'taflwyr codwm: arlliw croen golau, arlliw croen tywyll',
    '🧑🏼‍🫯‍🧑🏻' => 'taflwyr codwm: arlliw croen canolig-golau, arlliw croen golau',
    '🧑🏼‍🫯‍🧑🏽' => 'taflwyr codwm: arlliw croen canolig-golau, arlliw croen canolog',
    '🧑🏼‍🫯‍🧑🏾' => 'taflwyr codwm: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '🧑🏼‍🫯‍🧑🏿' => 'taflwyr codwm: arlliw croen canolig-golau, arlliw croen tywyll',
    '🧑🏽‍🫯‍🧑🏻' => 'taflwyr codwm: arlliw croen canolog, arlliw croen golau',
    '🧑🏽‍🫯‍🧑🏼' => 'taflwyr codwm: arlliw croen canolog, arlliw croen canolig-golau',
    '🧑🏽‍🫯‍🧑🏾' => 'taflwyr codwm: arlliw croen canolog, arlliw croen canolig-tywyll',
    '🧑🏽‍🫯‍🧑🏿' => 'taflwyr codwm: arlliw croen canolog, arlliw croen tywyll',
    '🧑🏾‍🫯‍🧑🏻' => 'taflwyr codwm: arlliw croen canolig-tywyll, arlliw croen golau',
    '🧑🏾‍🫯‍🧑🏼' => 'taflwyr codwm: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '🧑🏾‍🫯‍🧑🏽' => 'taflwyr codwm: arlliw croen canolig-tywyll, arlliw croen canolog',
    '🧑🏾‍🫯‍🧑🏿' => 'taflwyr codwm: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '🧑🏿‍🫯‍🧑🏻' => 'taflwyr codwm: arlliw croen tywyll, arlliw croen golau',
    '🧑🏿‍🫯‍🧑🏼' => 'taflwyr codwm: arlliw croen tywyll, arlliw croen canolig-golau',
    '🧑🏿‍🫯‍🧑🏽' => 'taflwyr codwm: arlliw croen tywyll, arlliw croen canolog',
    '🧑🏿‍🫯‍🧑🏾' => 'taflwyr codwm: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '🧑🏻‍❤‍🧑🏼' => 'pâr a chalon: person, person, arlliw croen golau, arlliw croen canolig-golau',
    '🧑🏻‍❤‍🧑🏽' => 'pâr a chalon: person, person, arlliw croen golau, arlliw croen canolog',
    '🧑🏻‍❤‍🧑🏾' => 'pâr a chalon: person, person, arlliw croen golau, arlliw croen canolig-tywyll',
    '🧑🏻‍❤‍🧑🏿' => 'pâr a chalon: person, person, arlliw croen golau, arlliw croen tywyll',
    '🧑🏼‍❤‍🧑🏻' => 'pâr a chalon: person, person, arlliw croen canolig-golau, arlliw croen golau',
    '🧑🏼‍❤‍🧑🏽' => 'pâr a chalon: person, person, arlliw croen canolig-golau, arlliw croen canolog',
    '🧑🏼‍❤‍🧑🏾' => 'pâr a chalon: person, person, arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '🧑🏼‍❤‍🧑🏿' => 'pâr a chalon: person, person, arlliw croen canolig-golau, arlliw croen tywyll',
    '🧑🏽‍❤‍🧑🏻' => 'pâr a chalon: person, person, arlliw croen canolog, arlliw croen golau',
    '🧑🏽‍❤‍🧑🏼' => 'pâr a chalon: person, person, arlliw croen canolog, arlliw croen canolig-golau',
    '🧑🏽‍❤‍🧑🏾' => 'pâr a chalon: person, person, arlliw croen canolog, arlliw croen canolig-tywyll',
    '🧑🏽‍❤‍🧑🏿' => 'pâr a chalon: person, person, arlliw croen canolog, arlliw croen tywyll',
    '🧑🏾‍❤‍🧑🏻' => 'pâr a chalon: person, person, arlliw croen canolig-tywyll, arlliw croen golau',
    '🧑🏾‍❤‍🧑🏼' => 'pâr a chalon: person, person, arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '🧑🏾‍❤‍🧑🏽' => 'pâr a chalon: person, person, arlliw croen canolig-tywyll, arlliw croen canolog',
    '🧑🏾‍❤‍🧑🏿' => 'pâr a chalon: person, person, arlliw croen canolig-tywyll, arlliw croen tywyll',
    '🧑🏿‍❤‍🧑🏻' => 'pâr a chalon: person, person, arlliw croen tywyll, arlliw croen golau',
    '🧑🏿‍❤‍🧑🏼' => 'pâr a chalon: person, person, arlliw croen tywyll, arlliw croen canolig-golau',
    '🧑🏿‍❤‍🧑🏽' => 'pâr a chalon: person, person, arlliw croen tywyll, arlliw croen canolog',
    '🧑🏿‍❤‍🧑🏾' => 'pâr a chalon: person, person, arlliw croen tywyll, arlliw croen canolig-tywyll',
    '🧑🏻‍🐰‍🧑🏼' => 'pobl mewn parti: arlliw croen golau, arlliw croen canolig-golau',
    '🧑🏻‍🐰‍🧑🏽' => 'pobl mewn parti: arlliw croen golau, arlliw croen canolog',
    '🧑🏻‍🐰‍🧑🏾' => 'pobl mewn parti: arlliw croen golau, arlliw croen canolig-tywyll',
    '🧑🏻‍🐰‍🧑🏿' => 'pobl mewn parti: arlliw croen golau, arlliw croen tywyll',
    '🧑🏼‍🐰‍🧑🏻' => 'pobl mewn parti: arlliw croen canolig-golau, arlliw croen golau',
    '🧑🏼‍🐰‍🧑🏽' => 'pobl mewn parti: arlliw croen canolig-golau, arlliw croen canolog',
    '🧑🏼‍🐰‍🧑🏾' => 'pobl mewn parti: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '🧑🏼‍🐰‍🧑🏿' => 'pobl mewn parti: arlliw croen canolig-golau, arlliw croen tywyll',
    '🧑🏽‍🐰‍🧑🏻' => 'pobl mewn parti: arlliw croen canolog, arlliw croen golau',
    '🧑🏽‍🐰‍🧑🏼' => 'pobl mewn parti: arlliw croen canolog, arlliw croen canolig-golau',
    '🧑🏽‍🐰‍🧑🏾' => 'pobl mewn parti: arlliw croen canolog, arlliw croen canolig-tywyll',
    '🧑🏽‍🐰‍🧑🏿' => 'pobl mewn parti: arlliw croen canolog, arlliw croen tywyll',
    '🧑🏾‍🐰‍🧑🏻' => 'pobl mewn parti: arlliw croen canolig-tywyll, arlliw croen golau',
    '🧑🏾‍🐰‍🧑🏼' => 'pobl mewn parti: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '🧑🏾‍🐰‍🧑🏽' => 'pobl mewn parti: arlliw croen canolig-tywyll, arlliw croen canolog',
    '🧑🏾‍🐰‍🧑🏿' => 'pobl mewn parti: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '🧑🏿‍🐰‍🧑🏻' => 'pobl mewn parti: arlliw croen tywyll, arlliw croen golau',
    '🧑🏿‍🐰‍🧑🏼' => 'pobl mewn parti: arlliw croen tywyll, arlliw croen canolig-golau',
    '🧑🏿‍🐰‍🧑🏽' => 'pobl mewn parti: arlliw croen tywyll, arlliw croen canolog',
    '🧑🏿‍🐰‍🧑🏾' => 'pobl mewn parti: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👨🏻‍🫯‍👨🏼' => 'dynion yn reslo: arlliw croen golau, arlliw croen canolig-golau',
    '👨🏻‍🫯‍👨🏽' => 'dynion yn reslo: arlliw croen golau, arlliw croen canolog',
    '👨🏻‍🫯‍👨🏾' => 'dynion yn reslo: arlliw croen golau, arlliw croen canolig-tywyll',
    '👨🏻‍🫯‍👨🏿' => 'dynion yn reslo: arlliw croen golau, arlliw croen tywyll',
    '👨🏼‍🫯‍👨🏻' => 'dynion yn reslo: arlliw croen canolig-golau, arlliw croen golau',
    '👨🏼‍🫯‍👨🏽' => 'dynion yn reslo: arlliw croen canolig-golau, arlliw croen canolog',
    '👨🏼‍🫯‍👨🏾' => 'dynion yn reslo: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👨🏼‍🫯‍👨🏿' => 'dynion yn reslo: arlliw croen canolig-golau, arlliw croen tywyll',
    '👨🏽‍🫯‍👨🏻' => 'dynion yn reslo: arlliw croen canolog, arlliw croen golau',
    '👨🏽‍🫯‍👨🏼' => 'dynion yn reslo: arlliw croen canolog, arlliw croen canolig-golau',
    '👨🏽‍🫯‍👨🏾' => 'dynion yn reslo: arlliw croen canolog, arlliw croen canolig-tywyll',
    '👨🏽‍🫯‍👨🏿' => 'dynion yn reslo: arlliw croen canolog, arlliw croen tywyll',
    '👨🏾‍🫯‍👨🏻' => 'dynion yn reslo: arlliw croen canolig-tywyll, arlliw croen golau',
    '👨🏾‍🫯‍👨🏼' => 'dynion yn reslo: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👨🏾‍🫯‍👨🏽' => 'dynion yn reslo: arlliw croen canolig-tywyll, arlliw croen canolog',
    '👨🏾‍🫯‍👨🏿' => 'dynion yn reslo: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👨🏿‍🫯‍👨🏻' => 'dynion yn reslo: arlliw croen tywyll, arlliw croen golau',
    '👨🏿‍🫯‍👨🏼' => 'dynion yn reslo: arlliw croen tywyll, arlliw croen canolig-golau',
    '👨🏿‍🫯‍👨🏽' => 'dynion yn reslo: arlliw croen tywyll, arlliw croen canolog',
    '👨🏿‍🫯‍👨🏾' => 'dynion yn reslo: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👨🏻‍❤‍👨🏻' => 'pâr a chalon: dyn, dyn, arlliw croen golau',
    '👨🏻‍❤‍👨🏼' => 'pâr a chalon: dyn, dyn, arlliw croen golau, arlliw croen canolig-golau',
    '👨🏻‍❤‍👨🏽' => 'pâr a chalon: dyn, dyn, arlliw croen golau, arlliw croen canolog',
    '👨🏻‍❤‍👨🏾' => 'pâr a chalon: dyn, dyn, arlliw croen golau, arlliw croen canolig-tywyll',
    '👨🏻‍❤‍👨🏿' => 'pâr a chalon: dyn, dyn, arlliw croen golau, arlliw croen tywyll',
    '👨🏼‍❤‍👨🏻' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-golau, arlliw croen golau',
    '👨🏼‍❤‍👨🏼' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-golau',
    '👨🏼‍❤‍👨🏽' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-golau, arlliw croen canolog',
    '👨🏼‍❤‍👨🏾' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👨🏼‍❤‍👨🏿' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-golau, arlliw croen tywyll',
    '👨🏽‍❤‍👨🏻' => 'pâr a chalon: dyn, dyn, arlliw croen canolog, arlliw croen golau',
    '👨🏽‍❤‍👨🏼' => 'pâr a chalon: dyn, dyn, arlliw croen canolog, arlliw croen canolig-golau',
    '👨🏽‍❤‍👨🏽' => 'pâr a chalon: dyn, dyn, arlliw croen canolog',
    '👨🏽‍❤‍👨🏾' => 'pâr a chalon: dyn, dyn, arlliw croen canolog, arlliw croen canolig-tywyll',
    '👨🏽‍❤‍👨🏿' => 'pâr a chalon: dyn, dyn, arlliw croen canolog, arlliw croen tywyll',
    '👨🏾‍❤‍👨🏻' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-tywyll, arlliw croen golau',
    '👨🏾‍❤‍👨🏼' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👨🏾‍❤‍👨🏽' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-tywyll, arlliw croen canolog',
    '👨🏾‍❤‍👨🏾' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-tywyll',
    '👨🏾‍❤‍👨🏿' => 'pâr a chalon: dyn, dyn, arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👨🏿‍❤‍👨🏻' => 'pâr a chalon: dyn, dyn, arlliw croen tywyll, arlliw croen golau',
    '👨🏿‍❤‍👨🏼' => 'pâr a chalon: dyn, dyn, arlliw croen tywyll, arlliw croen canolig-golau',
    '👨🏿‍❤‍👨🏽' => 'pâr a chalon: dyn, dyn, arlliw croen tywyll, arlliw croen canolog',
    '👨🏿‍❤‍👨🏾' => 'pâr a chalon: dyn, dyn, arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👨🏿‍❤‍👨🏿' => 'pâr a chalon: dyn, dyn, arlliw croen tywyll',
    '👨🏻‍🐰‍👨🏼' => 'dyn mewn parti: arlliw croen golau, arlliw croen canolig-golau',
    '👨🏻‍🐰‍👨🏽' => 'dyn mewn parti: arlliw croen golau, arlliw croen canolog',
    '👨🏻‍🐰‍👨🏾' => 'dyn mewn parti: arlliw croen golau, arlliw croen canolig-tywyll',
    '👨🏻‍🐰‍👨🏿' => 'dyn mewn parti: arlliw croen golau, arlliw croen tywyll',
    '👨🏼‍🐰‍👨🏻' => 'dyn mewn parti: arlliw croen canolig-golau, arlliw croen golau',
    '👨🏼‍🐰‍👨🏽' => 'dyn mewn parti: arlliw croen canolig-golau, arlliw croen canolog',
    '👨🏼‍🐰‍👨🏾' => 'dyn mewn parti: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👨🏼‍🐰‍👨🏿' => 'dyn mewn parti: arlliw croen canolig-golau, arlliw croen tywyll',
    '👨🏽‍🐰‍👨🏻' => 'dyn mewn parti: arlliw croen canolog, arlliw croen golau',
    '👨🏽‍🐰‍👨🏼' => 'dyn mewn parti: arlliw croen canolog, arlliw croen canolig-golau',
    '👨🏽‍🐰‍👨🏾' => 'dyn mewn parti: arlliw croen canolog, arlliw croen canolig-tywyll',
    '👨🏽‍🐰‍👨🏿' => 'dyn mewn parti: arlliw croen canolog, arlliw croen tywyll',
    '👨🏾‍🐰‍👨🏻' => 'dyn mewn parti: arlliw croen canolig-tywyll, arlliw croen golau',
    '👨🏾‍🐰‍👨🏼' => 'dyn mewn parti: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👨🏾‍🐰‍👨🏽' => 'dyn mewn parti: arlliw croen canolig-tywyll, arlliw croen canolog',
    '👨🏾‍🐰‍👨🏿' => 'dyn mewn parti: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👨🏿‍🐰‍👨🏻' => 'dyn mewn parti: arlliw croen tywyll, arlliw croen golau',
    '👨🏿‍🐰‍👨🏼' => 'dyn mewn parti: arlliw croen tywyll, arlliw croen canolig-golau',
    '👨🏿‍🐰‍👨🏽' => 'dyn mewn parti: arlliw croen tywyll, arlliw croen canolog',
    '👨🏿‍🐰‍👨🏾' => 'dyn mewn parti: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👩🏻‍🫯‍👩🏼' => 'menywod yn reslo: arlliw croen golau, arlliw croen canolig-golau',
    '👩🏻‍🫯‍👩🏽' => 'menywod yn reslo: arlliw croen golau, arlliw croen canolog',
    '👩🏻‍🫯‍👩🏾' => 'menywod yn reslo: arlliw croen golau, arlliw croen canolig-tywyll',
    '👩🏻‍🫯‍👩🏿' => 'menywod yn reslo: arlliw croen golau, arlliw croen tywyll',
    '👩🏼‍🫯‍👩🏻' => 'menywod yn reslo: arlliw croen canolig-golau, arlliw croen golau',
    '👩🏼‍🫯‍👩🏽' => 'menywod yn reslo: arlliw croen canolig-golau, arlliw croen canolog',
    '👩🏼‍🫯‍👩🏾' => 'menywod yn reslo: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👩🏼‍🫯‍👩🏿' => 'menywod yn reslo: arlliw croen canolig-golau, arlliw croen tywyll',
    '👩🏽‍🫯‍👩🏻' => 'menywod yn reslo: arlliw croen canolog, arlliw croen golau',
    '👩🏽‍🫯‍👩🏼' => 'menywod yn reslo: arlliw croen canolog, arlliw croen canolig-golau',
    '👩🏽‍🫯‍👩🏾' => 'menywod yn reslo: arlliw croen canolog, arlliw croen canolig-tywyll',
    '👩🏽‍🫯‍👩🏿' => 'menywod yn reslo: arlliw croen canolog, arlliw croen tywyll',
    '👩🏾‍🫯‍👩🏻' => 'menywod yn reslo: arlliw croen canolig-tywyll, arlliw croen golau',
    '👩🏾‍🫯‍👩🏼' => 'menywod yn reslo: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👩🏾‍🫯‍👩🏽' => 'menywod yn reslo: arlliw croen canolig-tywyll, arlliw croen canolog',
    '👩🏾‍🫯‍👩🏿' => 'menywod yn reslo: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👩🏿‍🫯‍👩🏻' => 'menywod yn reslo: arlliw croen tywyll, arlliw croen golau',
    '👩🏿‍🫯‍👩🏼' => 'menywod yn reslo: arlliw croen tywyll, arlliw croen canolig-golau',
    '👩🏿‍🫯‍👩🏽' => 'menywod yn reslo: arlliw croen tywyll, arlliw croen canolog',
    '👩🏿‍🫯‍👩🏾' => 'menywod yn reslo: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👩🏻‍❤‍👨🏻' => 'pâr a chalon: menyw, dyn, arlliw croen golau',
    '👩🏻‍❤‍👨🏼' => 'pâr a chalon: menyw, dyn, arlliw croen golau, arlliw croen canolig-golau',
    '👩🏻‍❤‍👨🏽' => 'pâr a chalon: menyw, dyn, arlliw croen golau, arlliw croen canolog',
    '👩🏻‍❤‍👨🏾' => 'pâr a chalon: menyw, dyn, arlliw croen golau, arlliw croen canolig-tywyll',
    '👩🏻‍❤‍👨🏿' => 'pâr a chalon: menyw, dyn, arlliw croen golau, arlliw croen tywyll',
    '👩🏼‍❤‍👨🏻' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-golau, arlliw croen golau',
    '👩🏼‍❤‍👨🏼' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-golau',
    '👩🏼‍❤‍👨🏽' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-golau, arlliw croen canolog',
    '👩🏼‍❤‍👨🏾' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👩🏼‍❤‍👨🏿' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-golau, arlliw croen tywyll',
    '👩🏽‍❤‍👨🏻' => 'pâr a chalon: menyw, dyn, arlliw croen canolog, arlliw croen golau',
    '👩🏽‍❤‍👨🏼' => 'pâr a chalon: menyw, dyn, arlliw croen canolog, arlliw croen canolig-golau',
    '👩🏽‍❤‍👨🏽' => 'pâr a chalon: menyw, dyn, arlliw croen canolog',
    '👩🏽‍❤‍👨🏾' => 'pâr a chalon: menyw, dyn, arlliw croen canolog, arlliw croen canolig-tywyll',
    '👩🏽‍❤‍👨🏿' => 'pâr a chalon: menyw, dyn, arlliw croen canolog, arlliw croen tywyll',
    '👩🏾‍❤‍👨🏻' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-tywyll, arlliw croen golau',
    '👩🏾‍❤‍👨🏼' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👩🏾‍❤‍👨🏽' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-tywyll, arlliw croen canolog',
    '👩🏾‍❤‍👨🏾' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-tywyll',
    '👩🏾‍❤‍👨🏿' => 'pâr a chalon: menyw, dyn, arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👩🏿‍❤‍👨🏻' => 'pâr a chalon: menyw, dyn, arlliw croen tywyll, arlliw croen golau',
    '👩🏿‍❤‍👨🏼' => 'pâr a chalon: menyw, dyn, arlliw croen tywyll, arlliw croen canolig-golau',
    '👩🏿‍❤‍👨🏽' => 'pâr a chalon: menyw, dyn, arlliw croen tywyll, arlliw croen canolog',
    '👩🏿‍❤‍👨🏾' => 'pâr a chalon: menyw, dyn, arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👩🏿‍❤‍👨🏿' => 'pâr a chalon: menyw, dyn, arlliw croen tywyll',
    '👩🏻‍❤‍👩🏻' => 'pâr a chalon: menyw, menyw, arlliw croen golau',
    '👩🏻‍❤‍👩🏼' => 'pâr a chalon: menyw, menyw, arlliw croen golau, arlliw croen canolig-golau',
    '👩🏻‍❤‍👩🏽' => 'pâr a chalon: menyw, menyw, arlliw croen golau, arlliw croen canolog',
    '👩🏻‍❤‍👩🏾' => 'pâr a chalon: menyw, menyw, arlliw croen golau, arlliw croen canolig-tywyll',
    '👩🏻‍❤‍👩🏿' => 'pâr a chalon: menyw, menyw, arlliw croen golau, arlliw croen tywyll',
    '👩🏼‍❤‍👩🏻' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-golau, arlliw croen golau',
    '👩🏼‍❤‍👩🏼' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-golau',
    '👩🏼‍❤‍👩🏽' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-golau, arlliw croen canolog',
    '👩🏼‍❤‍👩🏾' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👩🏼‍❤‍👩🏿' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-golau, arlliw croen tywyll',
    '👩🏽‍❤‍👩🏻' => 'pâr a chalon: menyw, menyw, arlliw croen canolog, arlliw croen golau',
    '👩🏽‍❤‍👩🏼' => 'pâr a chalon: menyw, menyw, arlliw croen canolog, arlliw croen canolig-golau',
    '👩🏽‍❤‍👩🏽' => 'pâr a chalon: menyw, menyw, arlliw croen canolog',
    '👩🏽‍❤‍👩🏾' => 'pâr a chalon: menyw, menyw, arlliw croen canolog, arlliw croen canolig-tywyll',
    '👩🏽‍❤‍👩🏿' => 'pâr a chalon: menyw, menyw, arlliw croen canolog, arlliw croen tywyll',
    '👩🏾‍❤‍👩🏻' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-tywyll, arlliw croen golau',
    '👩🏾‍❤‍👩🏼' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👩🏾‍❤‍👩🏽' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-tywyll, arlliw croen canolog',
    '👩🏾‍❤‍👩🏾' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-tywyll',
    '👩🏾‍❤‍👩🏿' => 'pâr a chalon: menyw, menyw, arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👩🏿‍❤‍👩🏻' => 'pâr a chalon: menyw, menyw, arlliw croen tywyll, arlliw croen golau',
    '👩🏿‍❤‍👩🏼' => 'pâr a chalon: menyw, menyw, arlliw croen tywyll, arlliw croen canolig-golau',
    '👩🏿‍❤‍👩🏽' => 'pâr a chalon: menyw, menyw, arlliw croen tywyll, arlliw croen canolog',
    '👩🏿‍❤‍👩🏾' => 'pâr a chalon: menyw, menyw, arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👩🏿‍❤‍👩🏿' => 'pâr a chalon: menyw, menyw, arlliw croen tywyll',
    '👩🏻‍🐰‍👩🏼' => 'menyw mewn parti: arlliw croen golau, arlliw croen canolig-golau',
    '👩🏻‍🐰‍👩🏽' => 'menyw mewn parti: arlliw croen golau, arlliw croen canolog',
    '👩🏻‍🐰‍👩🏾' => 'menyw mewn parti: arlliw croen golau, arlliw croen canolig-tywyll',
    '👩🏻‍🐰‍👩🏿' => 'menyw mewn parti: arlliw croen golau, arlliw croen tywyll',
    '👩🏼‍🐰‍👩🏻' => 'menyw mewn parti: arlliw croen canolig-golau, arlliw croen golau',
    '👩🏼‍🐰‍👩🏽' => 'menyw mewn parti: arlliw croen canolig-golau, arlliw croen canolog',
    '👩🏼‍🐰‍👩🏾' => 'menyw mewn parti: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👩🏼‍🐰‍👩🏿' => 'menyw mewn parti: arlliw croen canolig-golau, arlliw croen tywyll',
    '👩🏽‍🐰‍👩🏻' => 'menyw mewn parti: arlliw croen canolog, arlliw croen golau',
    '👩🏽‍🐰‍👩🏼' => 'menyw mewn parti: arlliw croen canolog, arlliw croen canolig-golau',
    '👩🏽‍🐰‍👩🏾' => 'menyw mewn parti: arlliw croen canolog, arlliw croen canolig-tywyll',
    '👩🏽‍🐰‍👩🏿' => 'menyw mewn parti: arlliw croen canolog, arlliw croen tywyll',
    '👩🏾‍🐰‍👩🏻' => 'menyw mewn parti: arlliw croen canolig-tywyll, arlliw croen golau',
    '👩🏾‍🐰‍👩🏼' => 'menyw mewn parti: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👩🏾‍🐰‍👩🏽' => 'menyw mewn parti: arlliw croen canolig-tywyll, arlliw croen canolog',
    '👩🏾‍🐰‍👩🏿' => 'menyw mewn parti: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👩🏿‍🐰‍👩🏻' => 'menyw mewn parti: arlliw croen tywyll, arlliw croen golau',
    '👩🏿‍🐰‍👩🏼' => 'menyw mewn parti: arlliw croen tywyll, arlliw croen canolig-golau',
    '👩🏿‍🐰‍👩🏽' => 'menyw mewn parti: arlliw croen tywyll, arlliw croen canolog',
    '👩🏿‍🐰‍👩🏾' => 'menyw mewn parti: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '🧑🏻‍🤝‍🧑🏻' => 'pobl yn dal dwylo: arlliw croen golau',
    '🧑🏻‍🤝‍🧑🏼' => 'pobl yn dal dwylo: arlliw croen golau, arlliw croen canolig-golau',
    '🧑🏻‍🤝‍🧑🏽' => 'pobl yn dal dwylo: arlliw croen golau, arlliw croen canolog',
    '🧑🏻‍🤝‍🧑🏾' => 'pobl yn dal dwylo: arlliw croen golau, arlliw croen canolig-tywyll',
    '🧑🏻‍🤝‍🧑🏿' => 'pobl yn dal dwylo: arlliw croen golau, arlliw croen tywyll',
    '🧑🏼‍🤝‍🧑🏻' => 'pobl yn dal dwylo: arlliw croen canolig-golau, arlliw croen golau',
    '🧑🏼‍🤝‍🧑🏼' => 'pobl yn dal dwylo: arlliw croen canolig-golau',
    '🧑🏼‍🤝‍🧑🏽' => 'pobl yn dal dwylo: arlliw croen canolig-golau, arlliw croen canolog',
    '🧑🏼‍🤝‍🧑🏾' => 'pobl yn dal dwylo: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '🧑🏼‍🤝‍🧑🏿' => 'pobl yn dal dwylo: arlliw croen canolig-golau, arlliw croen tywyll',
    '🧑🏽‍🤝‍🧑🏻' => 'pobl yn dal dwylo: arlliw croen canolog, arlliw croen golau',
    '🧑🏽‍🤝‍🧑🏼' => 'pobl yn dal dwylo: arlliw croen canolog, arlliw croen canolig-golau',
    '🧑🏽‍🤝‍🧑🏽' => 'pobl yn dal dwylo: arlliw croen canolog',
    '🧑🏽‍🤝‍🧑🏾' => 'pobl yn dal dwylo: arlliw croen canolog, arlliw croen canolig-tywyll',
    '🧑🏽‍🤝‍🧑🏿' => 'pobl yn dal dwylo: arlliw croen canolog, arlliw croen tywyll',
    '🧑🏾‍🤝‍🧑🏻' => 'pobl yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen golau',
    '🧑🏾‍🤝‍🧑🏼' => 'pobl yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '🧑🏾‍🤝‍🧑🏽' => 'pobl yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen canolog',
    '🧑🏾‍🤝‍🧑🏾' => 'pobl yn dal dwylo: arlliw croen canolig-tywyll',
    '🧑🏾‍🤝‍🧑🏿' => 'pobl yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '🧑🏿‍🤝‍🧑🏻' => 'pobl yn dal dwylo: arlliw croen tywyll, arlliw croen golau',
    '🧑🏿‍🤝‍🧑🏼' => 'pobl yn dal dwylo: arlliw croen tywyll, arlliw croen canolig-golau',
    '🧑🏿‍🤝‍🧑🏽' => 'pobl yn dal dwylo: arlliw croen tywyll, arlliw croen canolog',
    '🧑🏿‍🤝‍🧑🏾' => 'pobl yn dal dwylo: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '🧑🏿‍🤝‍🧑🏿' => 'pobl yn dal dwylo: arlliw croen tywyll',
    '👩🏻‍🤝‍👩🏼' => 'dwy fenyw yn dal dwylo: arlliw croen golau, arlliw croen canolig-golau',
    '👩🏻‍🤝‍👩🏽' => 'dwy fenyw yn dal dwylo: arlliw croen golau, arlliw croen canolog',
    '👩🏻‍🤝‍👩🏾' => 'dwy fenyw yn dal dwylo: arlliw croen golau, arlliw croen canolig-tywyll',
    '👩🏻‍🤝‍👩🏿' => 'dwy fenyw yn dal dwylo: arlliw croen golau, arlliw croen tywyll',
    '👩🏼‍🤝‍👩🏻' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-golau, arlliw croen golau',
    '👩🏼‍🤝‍👩🏽' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-golau, arlliw croen canolog',
    '👩🏼‍🤝‍👩🏾' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👩🏼‍🤝‍👩🏿' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-golau, arlliw croen tywyll',
    '👩🏽‍🤝‍👩🏻' => 'dwy fenyw yn dal dwylo: arlliw croen canolog, arlliw croen golau',
    '👩🏽‍🤝‍👩🏼' => 'dwy fenyw yn dal dwylo: arlliw croen canolog, arlliw croen canolig-golau',
    '👩🏽‍🤝‍👩🏾' => 'dwy fenyw yn dal dwylo: arlliw croen canolog, arlliw croen canolig-tywyll',
    '👩🏽‍🤝‍👩🏿' => 'dwy fenyw yn dal dwylo: arlliw croen canolog, arlliw croen tywyll',
    '👩🏾‍🤝‍👩🏻' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen golau',
    '👩🏾‍🤝‍👩🏼' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👩🏾‍🤝‍👩🏽' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen canolog',
    '👩🏾‍🤝‍👩🏿' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👩🏿‍🤝‍👩🏻' => 'dwy fenyw yn dal dwylo: arlliw croen tywyll, arlliw croen golau',
    '👩🏿‍🤝‍👩🏼' => 'dwy fenyw yn dal dwylo: arlliw croen tywyll, arlliw croen canolig-golau',
    '👩🏿‍🤝‍👩🏽' => 'dwy fenyw yn dal dwylo: arlliw croen tywyll, arlliw croen canolog',
    '👩🏿‍🤝‍👩🏾' => 'dwy fenyw yn dal dwylo: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👩🏻‍🤝‍👨🏼' => 'dyn a menyw yn dal dwylo: arlliw croen golau, arlliw croen canolig-golau',
    '👩🏻‍🤝‍👨🏽' => 'dyn a menyw yn dal dwylo: arlliw croen golau, arlliw croen canolog',
    '👩🏻‍🤝‍👨🏾' => 'dyn a menyw yn dal dwylo: arlliw croen golau, arlliw croen canolig-tywyll',
    '👩🏻‍🤝‍👨🏿' => 'dyn a menyw yn dal dwylo: arlliw croen golau, arlliw croen tywyll',
    '👩🏼‍🤝‍👨🏻' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-golau, arlliw croen golau',
    '👩🏼‍🤝‍👨🏽' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-golau, arlliw croen canolog',
    '👩🏼‍🤝‍👨🏾' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👩🏼‍🤝‍👨🏿' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-golau, arlliw croen tywyll',
    '👩🏽‍🤝‍👨🏻' => 'dyn a menyw yn dal dwylo: arlliw croen canolog, arlliw croen golau',
    '👩🏽‍🤝‍👨🏼' => 'dyn a menyw yn dal dwylo: arlliw croen canolog, arlliw croen canolig-golau',
    '👩🏽‍🤝‍👨🏾' => 'dyn a menyw yn dal dwylo: arlliw croen canolog, arlliw croen canolig-tywyll',
    '👩🏽‍🤝‍👨🏿' => 'dyn a menyw yn dal dwylo: arlliw croen canolog, arlliw croen tywyll',
    '👩🏾‍🤝‍👨🏻' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen golau',
    '👩🏾‍🤝‍👨🏼' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👩🏾‍🤝‍👨🏽' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen canolog',
    '👩🏾‍🤝‍👨🏿' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👩🏿‍🤝‍👨🏻' => 'dyn a menyw yn dal dwylo: arlliw croen tywyll, arlliw croen golau',
    '👩🏿‍🤝‍👨🏼' => 'dyn a menyw yn dal dwylo: arlliw croen tywyll, arlliw croen canolig-golau',
    '👩🏿‍🤝‍👨🏽' => 'dyn a menyw yn dal dwylo: arlliw croen tywyll, arlliw croen canolog',
    '👩🏿‍🤝‍👨🏾' => 'dyn a menyw yn dal dwylo: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👨🏻‍🤝‍👨🏼' => 'dau ddyn yn dal dwylo: arlliw croen golau, arlliw croen canolig-golau',
    '👨🏻‍🤝‍👨🏽' => 'dau ddyn yn dal dwylo: arlliw croen golau, arlliw croen canolog',
    '👨🏻‍🤝‍👨🏾' => 'dau ddyn yn dal dwylo: arlliw croen golau, arlliw croen canolig-tywyll',
    '👨🏻‍🤝‍👨🏿' => 'dau ddyn yn dal dwylo: arlliw croen golau, arlliw croen tywyll',
    '👨🏼‍🤝‍👨🏻' => 'dau ddyn yn dal dwylo: arlliw croen canolig-golau, arlliw croen golau',
    '👨🏼‍🤝‍👨🏽' => 'dau ddyn yn dal dwylo: arlliw croen canolig-golau, arlliw croen canolog',
    '👨🏼‍🤝‍👨🏾' => 'dau ddyn yn dal dwylo: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '👨🏼‍🤝‍👨🏿' => 'dau ddyn yn dal dwylo: arlliw croen canolig-golau, arlliw croen tywyll',
    '👨🏽‍🤝‍👨🏻' => 'dau ddyn yn dal dwylo: arlliw croen canolog, arlliw croen golau',
    '👨🏽‍🤝‍👨🏼' => 'dau ddyn yn dal dwylo: arlliw croen canolog, arlliw croen canolig-golau',
    '👨🏽‍🤝‍👨🏾' => 'dau ddyn yn dal dwylo: arlliw croen canolog, arlliw croen canolig-tywyll',
    '👨🏽‍🤝‍👨🏿' => 'dau ddyn yn dal dwylo: arlliw croen canolog, arlliw croen tywyll',
    '👨🏾‍🤝‍👨🏻' => 'dau ddyn yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen golau',
    '👨🏾‍🤝‍👨🏼' => 'dau ddyn yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '👨🏾‍🤝‍👨🏽' => 'dau ddyn yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen canolog',
    '👨🏾‍🤝‍👨🏿' => 'dau ddyn yn dal dwylo: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '👨🏿‍🤝‍👨🏻' => 'dau ddyn yn dal dwylo: arlliw croen tywyll, arlliw croen golau',
    '👨🏿‍🤝‍👨🏼' => 'dau ddyn yn dal dwylo: arlliw croen tywyll, arlliw croen canolig-golau',
    '👨🏿‍🤝‍👨🏽' => 'dau ddyn yn dal dwylo: arlliw croen tywyll, arlliw croen canolog',
    '👨🏿‍🤝‍👨🏾' => 'dau ddyn yn dal dwylo: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '👩‍❤‍💋‍👨' => 'cusan: menyw, dyn',
    '👨‍❤‍💋‍👨' => 'cusan: dyn, dyn',
    '👩‍❤‍💋‍👩' => 'cusan: menyw, menyw',
    '👨‍👩‍👧‍👦' => 'teulu: dyn, menyw, merch, bachgen',
    '👨‍👩‍👦‍👦' => 'teulu: dyn, menyw, bachgen, bachgen',
    '👨‍👩‍👧‍👧' => 'teulu: dyn, menyw, merch, merch',
    '👨‍👨‍👧‍👦' => 'teulu: dyn, dyn, merch, bachgen',
    '👨‍👨‍👦‍👦' => 'teulu: dyn, dyn, bachgen, bachgen',
    '👨‍👨‍👧‍👧' => 'teulu: dyn, dyn, merch, merch',
    '👩‍👩‍👧‍👦' => 'teulu: menyw, menyw, merch, bachgen',
    '👩‍👩‍👦‍👦' => 'teulu: menyw, menyw, bachgen, bachgen',
    '👩‍👩‍👧‍👧' => 'teulu: menyw, menyw, merch, merch',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'baner: Lloegr',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'baner: Yr Alban',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'baner: Cymru',
    '🧑‍🧑‍🧒‍🧒' => 'teulu: oedolyn, oedolyn, plentyn, plentyn',
    '🚶🏻‍♀‍➡' => 'menyw yn cerdded: arlliw croen golau, wynebu i’r dde',
    '🚶🏼‍♀‍➡' => 'menyw yn cerdded: arlliw croen canolig-golau, wynebu i’r dde',
    '🚶🏽‍♀‍➡' => 'menyw yn cerdded: arlliw croen canolog, wynebu i’r dde',
    '🚶🏾‍♀‍➡' => 'menyw yn cerdded: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🚶🏿‍♀‍➡' => 'menyw yn cerdded: arlliw croen tywyll, wynebu i’r dde',
    '🚶🏻‍♂‍➡' => 'dyn yn cerdded: arlliw croen golau, wynebu i’r dde',
    '🚶🏼‍♂‍➡' => 'dyn yn cerdded: arlliw croen canolig-golau, wynebu i’r dde',
    '🚶🏽‍♂‍➡' => 'dyn yn cerdded: arlliw croen canolog, wynebu i’r dde',
    '🚶🏾‍♂‍➡' => 'dyn yn cerdded: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🚶🏿‍♂‍➡' => 'dyn yn cerdded: arlliw croen tywyll, wynebu i’r dde',
    '🧎🏻‍♀‍➡' => 'menyw yn penlinio: arlliw croen golau, wynebu i’r dde',
    '🧎🏼‍♀‍➡' => 'menyw yn penlinio: arlliw croen canolig-golau, wynebu i’r dde',
    '🧎🏽‍♀‍➡' => 'menyw yn penlinio: arlliw croen canolog, wynebu i’r dde',
    '🧎🏾‍♀‍➡' => 'menyw yn penlinio: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🧎🏿‍♀‍➡' => 'menyw yn penlinio: arlliw croen tywyll, wynebu i’r dde',
    '🧎🏻‍♂‍➡' => 'dyn yn penlinio: arlliw croen golau, wynebu i’r dde',
    '🧎🏼‍♂‍➡' => 'dyn yn penlinio: arlliw croen canolig-golau, wynebu i’r dde',
    '🧎🏽‍♂‍➡' => 'dyn yn penlinio: arlliw croen canolog, wynebu i’r dde',
    '🧎🏾‍♂‍➡' => 'dyn yn penlinio: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🧎🏿‍♂‍➡' => 'dyn yn penlinio: arlliw croen tywyll, wynebu i’r dde',
    '🧑🏻‍🦯‍➡' => 'person â ffon gerdded: arlliw croen golau, wynebu i’r dde',
    '🧑🏼‍🦯‍➡' => 'person â ffon gerdded: arlliw croen canolig-golau, wynebu i’r dde',
    '🧑🏽‍🦯‍➡' => 'person â ffon gerdded: arlliw croen canolog, wynebu i’r dde',
    '🧑🏾‍🦯‍➡' => 'person â ffon gerdded: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🧑🏿‍🦯‍➡' => 'person â ffon gerdded: arlliw croen tywyll, wynebu i’r dde',
    '👨🏻‍🦯‍➡' => 'dyn â ffon wen: arlliw croen golau, wynebu i’r dde',
    '👨🏼‍🦯‍➡' => 'dyn â ffon wen: arlliw croen canolig-golau, wynebu i’r dde',
    '👨🏽‍🦯‍➡' => 'dyn â ffon wen: arlliw croen canolog, wynebu i’r dde',
    '👨🏾‍🦯‍➡' => 'dyn â ffon wen: arlliw croen canolig-tywyll, wynebu i’r dde',
    '👨🏿‍🦯‍➡' => 'dyn â ffon wen: arlliw croen tywyll, wynebu i’r dde',
    '👩🏻‍🦯‍➡' => 'menyw â ffon wen: arlliw croen golau, wynebu i’r dde',
    '👩🏼‍🦯‍➡' => 'menyw â ffon wen: arlliw croen canolig-golau, wynebu i’r dde',
    '👩🏽‍🦯‍➡' => 'menyw â ffon wen: arlliw croen canolog, wynebu i’r dde',
    '👩🏾‍🦯‍➡' => 'menyw â ffon wen: arlliw croen canolig-tywyll, wynebu i’r dde',
    '👩🏿‍🦯‍➡' => 'menyw â ffon wen: arlliw croen tywyll, wynebu i’r dde',
    '🧑🏻‍🦼‍➡' => 'person mewn cadair olwyn drydan: arlliw croen golau, wynebu i’r dde',
    '🧑🏼‍🦼‍➡' => 'person mewn cadair olwyn drydan: arlliw croen canolig-golau, wynebu i’r dde',
    '🧑🏽‍🦼‍➡' => 'person mewn cadair olwyn drydan: arlliw croen canolog, wynebu i’r dde',
    '🧑🏾‍🦼‍➡' => 'person mewn cadair olwyn drydan: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🧑🏿‍🦼‍➡' => 'person mewn cadair olwyn drydan: arlliw croen tywyll, wynebu i’r dde',
    '👨🏻‍🦼‍➡' => 'dyn mewn cadair olwyn fodur: arlliw croen golau, wynebu i’r dde',
    '👨🏼‍🦼‍➡' => 'dyn mewn cadair olwyn fodur: arlliw croen canolig-golau, wynebu i’r dde',
    '👨🏽‍🦼‍➡' => 'dyn mewn cadair olwyn fodur: arlliw croen canolog, wynebu i’r dde',
    '👨🏾‍🦼‍➡' => 'dyn mewn cadair olwyn fodur: arlliw croen canolig-tywyll, wynebu i’r dde',
    '👨🏿‍🦼‍➡' => 'dyn mewn cadair olwyn fodur: arlliw croen tywyll, wynebu i’r dde',
    '👩🏻‍🦼‍➡' => 'menyw mewn cadair olwyn fodur: arlliw croen golau, wynebu i’r dde',
    '👩🏼‍🦼‍➡' => 'menyw mewn cadair olwyn fodur: arlliw croen canolig-golau, wynebu i’r dde',
    '👩🏽‍🦼‍➡' => 'menyw mewn cadair olwyn fodur: arlliw croen canolog, wynebu i’r dde',
    '👩🏾‍🦼‍➡' => 'menyw mewn cadair olwyn fodur: arlliw croen canolig-tywyll, wynebu i’r dde',
    '👩🏿‍🦼‍➡' => 'menyw mewn cadair olwyn fodur: arlliw croen tywyll, wynebu i’r dde',
    '🧑🏻‍🦽‍➡' => 'person mewn cadair olwyn â llaw: arlliw croen golau, wynebu i’r dde',
    '🧑🏼‍🦽‍➡' => 'person mewn cadair olwyn â llaw: arlliw croen canolig-golau, wynebu i’r dde',
    '🧑🏽‍🦽‍➡' => 'person mewn cadair olwyn â llaw: arlliw croen canolog, wynebu i’r dde',
    '🧑🏾‍🦽‍➡' => 'person mewn cadair olwyn â llaw: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🧑🏿‍🦽‍➡' => 'person mewn cadair olwyn â llaw: arlliw croen tywyll, wynebu i’r dde',
    '👨🏻‍🦽‍➡' => 'dyn mewn cadair olwyn: arlliw croen golau, wynebu i’r dde',
    '👨🏼‍🦽‍➡' => 'dyn mewn cadair olwyn: arlliw croen canolig-golau, wynebu i’r dde',
    '👨🏽‍🦽‍➡' => 'dyn mewn cadair olwyn: arlliw croen canolog, wynebu i’r dde',
    '👨🏾‍🦽‍➡' => 'dyn mewn cadair olwyn: arlliw croen canolig-tywyll, wynebu i’r dde',
    '👨🏿‍🦽‍➡' => 'dyn mewn cadair olwyn: arlliw croen tywyll, wynebu i’r dde',
    '👩🏻‍🦽‍➡' => 'menyw mewn cadair olwyn: arlliw croen golau, wynebu i’r dde',
    '👩🏼‍🦽‍➡' => 'menyw mewn cadair olwyn: arlliw croen canolig-golau, wynebu i’r dde',
    '👩🏽‍🦽‍➡' => 'menyw mewn cadair olwyn: arlliw croen canolog, wynebu i’r dde',
    '👩🏾‍🦽‍➡' => 'menyw mewn cadair olwyn: arlliw croen canolig-tywyll, wynebu i’r dde',
    '👩🏿‍🦽‍➡' => 'menyw mewn cadair olwyn: arlliw croen tywyll, wynebu i’r dde',
    '🏃🏻‍♀‍➡' => 'menyw yn rhedeg: arlliw croen golau, wynebu i’r dde',
    '🏃🏼‍♀‍➡' => 'menyw yn rhedeg: arlliw croen canolig-golau, wynebu i’r dde',
    '🏃🏽‍♀‍➡' => 'menyw yn rhedeg: arlliw croen canolog, wynebu i’r dde',
    '🏃🏾‍♀‍➡' => 'menyw yn rhedeg: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🏃🏿‍♀‍➡' => 'menyw yn rhedeg: arlliw croen tywyll, wynebu i’r dde',
    '🏃🏻‍♂‍➡' => 'dyn yn rhedeg: arlliw croen golau, wynebu i’r dde',
    '🏃🏼‍♂‍➡' => 'dyn yn rhedeg: arlliw croen canolig-golau, wynebu i’r dde',
    '🏃🏽‍♂‍➡' => 'dyn yn rhedeg: arlliw croen canolog, wynebu i’r dde',
    '🏃🏾‍♂‍➡' => 'dyn yn rhedeg: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🏃🏿‍♂‍➡' => 'dyn yn rhedeg: arlliw croen tywyll, wynebu i’r dde',
    '🫱🏻‍🫲🏼' => 'ysgwyd dwylo: arlliw croen golau, arlliw croen canolig-golau',
    '🫱🏻‍🫲🏽' => 'ysgwyd dwylo: arlliw croen golau, arlliw croen canolog',
    '🫱🏻‍🫲🏾' => 'ysgwyd dwylo: arlliw croen golau, arlliw croen canolig-tywyll',
    '🫱🏻‍🫲🏿' => 'ysgwyd dwylo: arlliw croen golau, arlliw croen tywyll',
    '🫱🏼‍🫲🏻' => 'ysgwyd dwylo: arlliw croen canolig-golau, arlliw croen golau',
    '🫱🏼‍🫲🏽' => 'ysgwyd dwylo: arlliw croen canolig-golau, arlliw croen canolog',
    '🫱🏼‍🫲🏾' => 'ysgwyd dwylo: arlliw croen canolig-golau, arlliw croen canolig-tywyll',
    '🫱🏼‍🫲🏿' => 'ysgwyd dwylo: arlliw croen canolig-golau, arlliw croen tywyll',
    '🫱🏽‍🫲🏻' => 'ysgwyd dwylo: arlliw croen canolog, arlliw croen golau',
    '🫱🏽‍🫲🏼' => 'ysgwyd dwylo: arlliw croen canolog, arlliw croen canolig-golau',
    '🫱🏽‍🫲🏾' => 'ysgwyd dwylo: arlliw croen canolog, arlliw croen canolig-tywyll',
    '🫱🏽‍🫲🏿' => 'ysgwyd dwylo: arlliw croen canolog, arlliw croen tywyll',
    '🫱🏾‍🫲🏻' => 'ysgwyd dwylo: arlliw croen canolig-tywyll, arlliw croen golau',
    '🫱🏾‍🫲🏼' => 'ysgwyd dwylo: arlliw croen canolig-tywyll, arlliw croen canolig-golau',
    '🫱🏾‍🫲🏽' => 'ysgwyd dwylo: arlliw croen canolig-tywyll, arlliw croen canolog',
    '🫱🏾‍🫲🏿' => 'ysgwyd dwylo: arlliw croen canolig-tywyll, arlliw croen tywyll',
    '🫱🏿‍🫲🏻' => 'ysgwyd dwylo: arlliw croen tywyll, arlliw croen golau',
    '🫱🏿‍🫲🏼' => 'ysgwyd dwylo: arlliw croen tywyll, arlliw croen canolig-golau',
    '🫱🏿‍🫲🏽' => 'ysgwyd dwylo: arlliw croen tywyll, arlliw croen canolog',
    '🫱🏿‍🫲🏾' => 'ysgwyd dwylo: arlliw croen tywyll, arlliw croen canolig-tywyll',
    '🚶‍♀‍➡' => 'menyw yn cerdded: wynebu i’r dde',
    '🚶‍♂‍➡' => 'dyn yn cerdded: wynebu i’r dde',
    '🧎‍♀‍➡' => 'menyw yn penlinio: wynebu i’r dde',
    '🧎‍♂‍➡' => 'dyn yn penlinio: wynebu i’r dde',
    '🧑‍🦯‍➡' => 'person â ffon gerdded: wynebu i’r dde',
    '👨‍🦯‍➡' => 'dyn â ffon wen: wynebu i’r dde',
    '👩‍🦯‍➡' => 'menyw â ffon wen: wynebu i’r dde',
    '🧑‍🦼‍➡' => 'person mewn cadair olwyn drydan: wynebu i’r dde',
    '👨‍🦼‍➡' => 'dyn mewn cadair olwyn fodur: wynebu i’r dde',
    '👩‍🦼‍➡' => 'menyw mewn cadair olwyn fodur: wynebu i’r dde',
    '🧑‍🦽‍➡' => 'person mewn cadair olwyn â llaw: wynebu i’r dde',
    '👨‍🦽‍➡' => 'dyn mewn cadair olwyn: wynebu i’r dde',
    '👩‍🦽‍➡' => 'menyw mewn cadair olwyn: wynebu i’r dde',
    '🏃‍♀‍➡' => 'menyw yn rhedeg: wynebu i’r dde',
    '🏃‍♂‍➡' => 'dyn yn rhedeg: wynebu i’r dde',
    '👩‍❤‍👨' => 'pâr a chalon: menyw, dyn',
    '👨‍❤‍👨' => 'pâr a chalon: dyn, dyn',
    '👩‍❤‍👩' => 'pâr a chalon: menyw, menyw',
    '👨‍👩‍👦' => 'teulu: dyn, menyw, bachgen',
    '👨‍👩‍👧' => 'teulu: dyn, menyw, merch',
    '👨‍👨‍👦' => 'teulu: dyn, dyn, bachgen',
    '👨‍👨‍👧' => 'teulu: dyn, dyn, merch',
    '👩‍👩‍👦' => 'teulu: menyw, menyw, bachgen',
    '👩‍👩‍👧' => 'teulu: menyw, menyw, merch',
    '👨‍👦‍👦' => 'teulu: dyn, bachgen, bachgen',
    '👨‍👧‍👦' => 'teulu: dyn, merch, bachgen',
    '👨‍👧‍👧' => 'teulu: dyn, merch, merch',
    '👩‍👦‍👦' => 'teulu: menyw, bachgen, bachgen',
    '👩‍👧‍👦' => 'teulu: menyw, merch, bachgen',
    '👩‍👧‍👧' => 'teulu: menyw, merch, merch',
    '🧑‍🤝‍🧑' => 'pobl yn dal dwylo',
    '🧑‍🧑‍🧒' => 'teulu: oedolyn, oedolyn, plentyn',
    '🧑‍🧒‍🧒' => 'teulu: oedolyn, plentyn, plentyn',
    '🧑🏻‍🦰' => 'person: arlliw croen golau, gwallt coch',
    '🧑🏼‍🦰' => 'person: arlliw croen canolig-golau, gwallt coch',
    '🧑🏽‍🦰' => 'person: arlliw croen canolog, gwallt coch',
    '🧑🏾‍🦰' => 'person: arlliw croen canolig-tywyll, gwallt coch',
    '🧑🏿‍🦰' => 'person: arlliw croen tywyll, gwallt coch',
    '🧑🏻‍🦱' => 'person: arlliw croen golau, gwallt cyrliog',
    '🧑🏼‍🦱' => 'person: arlliw croen canolig-golau, gwallt cyrliog',
    '🧑🏽‍🦱' => 'person: arlliw croen canolog, gwallt cyrliog',
    '🧑🏾‍🦱' => 'person: arlliw croen canolig-tywyll, gwallt cyrliog',
    '🧑🏿‍🦱' => 'person: arlliw croen tywyll, gwallt cyrliog',
    '🧑🏻‍🦳' => 'person: arlliw croen golau, gwallt gwyn',
    '🧑🏼‍🦳' => 'person: arlliw croen canolig-golau, gwallt gwyn',
    '🧑🏽‍🦳' => 'person: arlliw croen canolog, gwallt gwyn',
    '🧑🏾‍🦳' => 'person: arlliw croen canolig-tywyll, gwallt gwyn',
    '🧑🏿‍🦳' => 'person: arlliw croen tywyll, gwallt gwyn',
    '🧑🏻‍🦲' => 'person: arlliw croen golau, moel',
    '🧑🏼‍🦲' => 'person: arlliw croen canolig-golau, moel',
    '🧑🏽‍🦲' => 'person: arlliw croen canolog, moel',
    '🧑🏾‍🦲' => 'person: arlliw croen canolig-tywyll, moel',
    '🧑🏿‍🦲' => 'person: arlliw croen tywyll, moel',
    '🧑🏻‍🩰' => 'dawnsiwr/dawnswraig bale: arlliw croen golau',
    '🧑🏼‍🩰' => 'dawnsiwr/dawnswraig bale: arlliw croen canolig-golau',
    '🧑🏽‍🩰' => 'dawnsiwr/dawnswraig bale: arlliw croen canolog',
    '🧑🏾‍🩰' => 'dawnsiwr/dawnswraig bale: arlliw croen canolig-tywyll',
    '🧑🏿‍🩰' => 'dawnsiwr/dawnswraig bale: arlliw croen tywyll',
    '🧔🏻‍♂' => 'dyn: arlliw croen golau, barf',
    '🧔🏼‍♂' => 'dyn: arlliw croen canolig-golau, barf',
    '🧔🏽‍♂' => 'dyn: arlliw croen canolog, barf',
    '🧔🏾‍♂' => 'dyn: arlliw croen canolig-tywyll, barf',
    '🧔🏿‍♂' => 'dyn: arlliw croen tywyll, barf',
    '👱🏻‍♂' => 'dyn â gwallt golau: arlliw croen golau',
    '👱🏼‍♂' => 'dyn â gwallt golau: arlliw croen canolig-golau',
    '👱🏽‍♂' => 'dyn â gwallt golau: arlliw croen canolog',
    '👱🏾‍♂' => 'dyn â gwallt golau: arlliw croen canolig-tywyll',
    '👱🏿‍♂' => 'dyn â gwallt golau: arlliw croen tywyll',
    '👨🏻‍🦰' => 'dyn: arlliw croen golau, gwallt coch',
    '👨🏼‍🦰' => 'dyn: arlliw croen canolig-golau, gwallt coch',
    '👨🏽‍🦰' => 'dyn: arlliw croen canolog, gwallt coch',
    '👨🏾‍🦰' => 'dyn: arlliw croen canolig-tywyll, gwallt coch',
    '👨🏿‍🦰' => 'dyn: arlliw croen tywyll, gwallt coch',
    '👨🏻‍🦱' => 'dyn: arlliw croen golau, gwallt cyrliog',
    '👨🏼‍🦱' => 'dyn: arlliw croen canolig-golau, gwallt cyrliog',
    '👨🏽‍🦱' => 'dyn: arlliw croen canolog, gwallt cyrliog',
    '👨🏾‍🦱' => 'dyn: arlliw croen canolig-tywyll, gwallt cyrliog',
    '👨🏿‍🦱' => 'dyn: arlliw croen tywyll, gwallt cyrliog',
    '👨🏻‍🦳' => 'dyn: arlliw croen golau, gwallt gwyn',
    '👨🏼‍🦳' => 'dyn: arlliw croen canolig-golau, gwallt gwyn',
    '👨🏽‍🦳' => 'dyn: arlliw croen canolog, gwallt gwyn',
    '👨🏾‍🦳' => 'dyn: arlliw croen canolig-tywyll, gwallt gwyn',
    '👨🏿‍🦳' => 'dyn: arlliw croen tywyll, gwallt gwyn',
    '👨🏻‍🦲' => 'dyn: arlliw croen golau, moel',
    '👨🏼‍🦲' => 'dyn: arlliw croen canolig-golau, moel',
    '👨🏽‍🦲' => 'dyn: arlliw croen canolog, moel',
    '👨🏾‍🦲' => 'dyn: arlliw croen canolig-tywyll, moel',
    '👨🏿‍🦲' => 'dyn: arlliw croen tywyll, moel',
    '🧔🏻‍♀' => 'menyw: arlliw croen golau, barf',
    '🧔🏼‍♀' => 'menyw: arlliw croen canolig-golau, barf',
    '🧔🏽‍♀' => 'menyw: arlliw croen canolog, barf',
    '🧔🏾‍♀' => 'menyw: arlliw croen canolig-tywyll, barf',
    '🧔🏿‍♀' => 'menyw: arlliw croen tywyll, barf',
    '👱🏻‍♀' => 'menyw â gwallt golau: arlliw croen golau',
    '👱🏼‍♀' => 'menyw â gwallt golau: arlliw croen canolig-golau',
    '👱🏽‍♀' => 'menyw â gwallt golau: arlliw croen canolog',
    '👱🏾‍♀' => 'menyw â gwallt golau: arlliw croen canolig-tywyll',
    '👱🏿‍♀' => 'menyw â gwallt golau: arlliw croen tywyll',
    '👩🏻‍🦰' => 'menyw: arlliw croen golau, gwallt coch',
    '👩🏼‍🦰' => 'menyw: arlliw croen canolig-golau, gwallt coch',
    '👩🏽‍🦰' => 'menyw: arlliw croen canolog, gwallt coch',
    '👩🏾‍🦰' => 'menyw: arlliw croen canolig-tywyll, gwallt coch',
    '👩🏿‍🦰' => 'menyw: arlliw croen tywyll, gwallt coch',
    '👩🏻‍🦱' => 'menyw: arlliw croen golau, gwallt cyrliog',
    '👩🏼‍🦱' => 'menyw: arlliw croen canolig-golau, gwallt cyrliog',
    '👩🏽‍🦱' => 'menyw: arlliw croen canolog, gwallt cyrliog',
    '👩🏾‍🦱' => 'menyw: arlliw croen canolig-tywyll, gwallt cyrliog',
    '👩🏿‍🦱' => 'menyw: arlliw croen tywyll, gwallt cyrliog',
    '👩🏻‍🦳' => 'menyw: arlliw croen golau, gwallt gwyn',
    '👩🏼‍🦳' => 'menyw: arlliw croen canolig-golau, gwallt gwyn',
    '👩🏽‍🦳' => 'menyw: arlliw croen canolog, gwallt gwyn',
    '👩🏾‍🦳' => 'menyw: arlliw croen canolig-tywyll, gwallt gwyn',
    '👩🏿‍🦳' => 'menyw: arlliw croen tywyll, gwallt gwyn',
    '👩🏻‍🦲' => 'menyw: arlliw croen golau, moel',
    '👩🏼‍🦲' => 'menyw: arlliw croen canolig-golau, moel',
    '👩🏽‍🦲' => 'menyw: arlliw croen canolog, moel',
    '👩🏾‍🦲' => 'menyw: arlliw croen canolig-tywyll, moel',
    '👩🏿‍🦲' => 'menyw: arlliw croen tywyll, moel',
    '🙍🏻‍♂' => 'dyn yn gwgu: arlliw croen golau',
    '🙍🏼‍♂' => 'dyn yn gwgu: arlliw croen canolig-golau',
    '🙍🏽‍♂' => 'dyn yn gwgu: arlliw croen canolog',
    '🙍🏾‍♂' => 'dyn yn gwgu: arlliw croen canolig-tywyll',
    '🙍🏿‍♂' => 'dyn yn gwgu: arlliw croen tywyll',
    '🙍🏻‍♀' => 'menyw yn gwgu: arlliw croen golau',
    '🙍🏼‍♀' => 'menyw yn gwgu: arlliw croen canolig-golau',
    '🙍🏽‍♀' => 'menyw yn gwgu: arlliw croen canolog',
    '🙍🏾‍♀' => 'menyw yn gwgu: arlliw croen canolig-tywyll',
    '🙍🏿‍♀' => 'menyw yn gwgu: arlliw croen tywyll',
    '🙎🏻‍♂' => 'dyn yn pwdu: arlliw croen golau',
    '🙎🏼‍♂' => 'dyn yn pwdu: arlliw croen canolig-golau',
    '🙎🏽‍♂' => 'dyn yn pwdu: arlliw croen canolog',
    '🙎🏾‍♂' => 'dyn yn pwdu: arlliw croen canolig-tywyll',
    '🙎🏿‍♂' => 'dyn yn pwdu: arlliw croen tywyll',
    '🙎🏻‍♀' => 'menyw yn pwdu: arlliw croen golau',
    '🙎🏼‍♀' => 'menyw yn pwdu: arlliw croen canolig-golau',
    '🙎🏽‍♀' => 'menyw yn pwdu: arlliw croen canolog',
    '🙎🏾‍♀' => 'menyw yn pwdu: arlliw croen canolig-tywyll',
    '🙎🏿‍♀' => 'menyw yn pwdu: arlliw croen tywyll',
    '🙅🏻‍♂' => 'dyn yn ystumio nad yw’n iawn: arlliw croen golau',
    '🙅🏼‍♂' => 'dyn yn ystumio nad yw’n iawn: arlliw croen canolig-golau',
    '🙅🏽‍♂' => 'dyn yn ystumio nad yw’n iawn: arlliw croen canolog',
    '🙅🏾‍♂' => 'dyn yn ystumio nad yw’n iawn: arlliw croen canolig-tywyll',
    '🙅🏿‍♂' => 'dyn yn ystumio nad yw’n iawn: arlliw croen tywyll',
    '🙅🏻‍♀' => 'menyw yn ystumio nad yw’n iawn: arlliw croen golau',
    '🙅🏼‍♀' => 'menyw yn ystumio nad yw’n iawn: arlliw croen canolig-golau',
    '🙅🏽‍♀' => 'menyw yn ystumio nad yw’n iawn: arlliw croen canolog',
    '🙅🏾‍♀' => 'menyw yn ystumio nad yw’n iawn: arlliw croen canolig-tywyll',
    '🙅🏿‍♀' => 'menyw yn ystumio nad yw’n iawn: arlliw croen tywyll',
    '🙆🏻‍♂' => 'dyn yn ystumio iawn: arlliw croen golau',
    '🙆🏼‍♂' => 'dyn yn ystumio iawn: arlliw croen canolig-golau',
    '🙆🏽‍♂' => 'dyn yn ystumio iawn: arlliw croen canolog',
    '🙆🏾‍♂' => 'dyn yn ystumio iawn: arlliw croen canolig-tywyll',
    '🙆🏿‍♂' => 'dyn yn ystumio iawn: arlliw croen tywyll',
    '🙆🏻‍♀' => 'menyw yn ystumio iawn: arlliw croen golau',
    '🙆🏼‍♀' => 'menyw yn ystumio iawn: arlliw croen canolig-golau',
    '🙆🏽‍♀' => 'menyw yn ystumio iawn: arlliw croen canolog',
    '🙆🏾‍♀' => 'menyw yn ystumio iawn: arlliw croen canolig-tywyll',
    '🙆🏿‍♀' => 'menyw yn ystumio iawn: arlliw croen tywyll',
    '💁🏻‍♂' => 'dyn yn gwyro ei law: arlliw croen golau',
    '💁🏼‍♂' => 'dyn yn gwyro ei law: arlliw croen canolig-golau',
    '💁🏽‍♂' => 'dyn yn gwyro ei law: arlliw croen canolog',
    '💁🏾‍♂' => 'dyn yn gwyro ei law: arlliw croen canolig-tywyll',
    '💁🏿‍♂' => 'dyn yn gwyro ei law: arlliw croen tywyll',
    '💁🏻‍♀' => 'menyw yn gwyro ei llaw: arlliw croen golau',
    '💁🏼‍♀' => 'menyw yn gwyro ei llaw: arlliw croen canolig-golau',
    '💁🏽‍♀' => 'menyw yn gwyro ei llaw: arlliw croen canolog',
    '💁🏾‍♀' => 'menyw yn gwyro ei llaw: arlliw croen canolig-tywyll',
    '💁🏿‍♀' => 'menyw yn gwyro ei llaw: arlliw croen tywyll',
    '🙋🏻‍♂' => 'dyn yn codi ei law: arlliw croen golau',
    '🙋🏼‍♂' => 'dyn yn codi ei law: arlliw croen canolig-golau',
    '🙋🏽‍♂' => 'dyn yn codi ei law: arlliw croen canolog',
    '🙋🏾‍♂' => 'dyn yn codi ei law: arlliw croen canolig-tywyll',
    '🙋🏿‍♂' => 'dyn yn codi ei law: arlliw croen tywyll',
    '🙋🏻‍♀' => 'menyw yn codi ei llaw: arlliw croen golau',
    '🙋🏼‍♀' => 'menyw yn codi ei llaw: arlliw croen canolig-golau',
    '🙋🏽‍♀' => 'menyw yn codi ei llaw: arlliw croen canolog',
    '🙋🏾‍♀' => 'menyw yn codi ei llaw: arlliw croen canolig-tywyll',
    '🙋🏿‍♀' => 'menyw yn codi ei llaw: arlliw croen tywyll',
    '🧏🏻‍♂' => 'dyn byddar: arlliw croen golau',
    '🧏🏼‍♂' => 'dyn byddar: arlliw croen canolig-golau',
    '🧏🏽‍♂' => 'dyn byddar: arlliw croen canolog',
    '🧏🏾‍♂' => 'dyn byddar: arlliw croen canolig-tywyll',
    '🧏🏿‍♂' => 'dyn byddar: arlliw croen tywyll',
    '🧏🏻‍♀' => 'menyw fyddar: arlliw croen golau',
    '🧏🏼‍♀' => 'menyw fyddar: arlliw croen canolig-golau',
    '🧏🏽‍♀' => 'menyw fyddar: arlliw croen canolog',
    '🧏🏾‍♀' => 'menyw fyddar: arlliw croen canolig-tywyll',
    '🧏🏿‍♀' => 'menyw fyddar: arlliw croen tywyll',
    '🙇🏻‍♂' => 'dyn yn ymgrymu’n isel: arlliw croen golau',
    '🙇🏼‍♂' => 'dyn yn ymgrymu’n isel: arlliw croen canolig-golau',
    '🙇🏽‍♂' => 'dyn yn ymgrymu’n isel: arlliw croen canolog',
    '🙇🏾‍♂' => 'dyn yn ymgrymu’n isel: arlliw croen canolig-tywyll',
    '🙇🏿‍♂' => 'dyn yn ymgrymu’n isel: arlliw croen tywyll',
    '🙇🏻‍♀' => 'menyw yn ymgrymu’n isel: arlliw croen golau',
    '🙇🏼‍♀' => 'menyw yn ymgrymu’n isel: arlliw croen canolig-golau',
    '🙇🏽‍♀' => 'menyw yn ymgrymu’n isel: arlliw croen canolog',
    '🙇🏾‍♀' => 'menyw yn ymgrymu’n isel: arlliw croen canolig-tywyll',
    '🙇🏿‍♀' => 'menyw yn ymgrymu’n isel: arlliw croen tywyll',
    '🤦🏻‍♂' => 'dyn yn codi cledr i’w wyneb: arlliw croen golau',
    '🤦🏼‍♂' => 'dyn yn codi cledr i’w wyneb: arlliw croen canolig-golau',
    '🤦🏽‍♂' => 'dyn yn codi cledr i’w wyneb: arlliw croen canolog',
    '🤦🏾‍♂' => 'dyn yn codi cledr i’w wyneb: arlliw croen canolig-tywyll',
    '🤦🏿‍♂' => 'dyn yn codi cledr i’w wyneb: arlliw croen tywyll',
    '🤦🏻‍♀' => 'menyw yn codi cledr i’w wyneb: arlliw croen golau',
    '🤦🏼‍♀' => 'menyw yn codi cledr i’w wyneb: arlliw croen canolig-golau',
    '🤦🏽‍♀' => 'menyw yn codi cledr i’w wyneb: arlliw croen canolog',
    '🤦🏾‍♀' => 'menyw yn codi cledr i’w wyneb: arlliw croen canolig-tywyll',
    '🤦🏿‍♀' => 'menyw yn codi cledr i’w wyneb: arlliw croen tywyll',
    '🤷🏻‍♂' => 'dyn yn codi gwar: arlliw croen golau',
    '🤷🏼‍♂' => 'dyn yn codi gwar: arlliw croen canolig-golau',
    '🤷🏽‍♂' => 'dyn yn codi gwar: arlliw croen canolog',
    '🤷🏾‍♂' => 'dyn yn codi gwar: arlliw croen canolig-tywyll',
    '🤷🏿‍♂' => 'dyn yn codi gwar: arlliw croen tywyll',
    '🤷🏻‍♀' => 'menyw yn codi gwar: arlliw croen golau',
    '🤷🏼‍♀' => 'menyw yn codi gwar: arlliw croen canolig-golau',
    '🤷🏽‍♀' => 'menyw yn codi gwar: arlliw croen canolog',
    '🤷🏾‍♀' => 'menyw yn codi gwar: arlliw croen canolig-tywyll',
    '🤷🏿‍♀' => 'menyw yn codi gwar: arlliw croen tywyll',
    '🧑🏻‍⚕' => 'gweithiwr iechyd: arlliw croen golau',
    '🧑🏼‍⚕' => 'gweithiwr iechyd: arlliw croen canolig-golau',
    '🧑🏽‍⚕' => 'gweithiwr iechyd: arlliw croen canolog',
    '🧑🏾‍⚕' => 'gweithiwr iechyd: arlliw croen canolig-tywyll',
    '🧑🏿‍⚕' => 'gweithiwr iechyd: arlliw croen tywyll',
    '👨🏻‍⚕' => 'gweithiwr iechyd gwrywaidd: arlliw croen golau',
    '👨🏼‍⚕' => 'gweithiwr iechyd gwrywaidd: arlliw croen canolig-golau',
    '👨🏽‍⚕' => 'gweithiwr iechyd gwrywaidd: arlliw croen canolog',
    '👨🏾‍⚕' => 'gweithiwr iechyd gwrywaidd: arlliw croen canolig-tywyll',
    '👨🏿‍⚕' => 'gweithiwr iechyd gwrywaidd: arlliw croen tywyll',
    '👩🏻‍⚕' => 'gweithiwr iechyd benywaidd: arlliw croen golau',
    '👩🏼‍⚕' => 'gweithiwr iechyd benywaidd: arlliw croen canolig-golau',
    '👩🏽‍⚕' => 'gweithiwr iechyd benywaidd: arlliw croen canolog',
    '👩🏾‍⚕' => 'gweithiwr iechyd benywaidd: arlliw croen canolig-tywyll',
    '👩🏿‍⚕' => 'gweithiwr iechyd benywaidd: arlliw croen tywyll',
    '🧑🏻‍🎓' => 'person sy’n astudio: arlliw croen golau',
    '🧑🏼‍🎓' => 'person sy’n astudio: arlliw croen canolig-golau',
    '🧑🏽‍🎓' => 'person sy’n astudio: arlliw croen canolog',
    '🧑🏾‍🎓' => 'person sy’n astudio: arlliw croen canolig-tywyll',
    '🧑🏿‍🎓' => 'person sy’n astudio: arlliw croen tywyll',
    '👨🏻‍🎓' => 'myfyriwr: arlliw croen golau',
    '👨🏼‍🎓' => 'myfyriwr: arlliw croen canolig-golau',
    '👨🏽‍🎓' => 'myfyriwr: arlliw croen canolog',
    '👨🏾‍🎓' => 'myfyriwr: arlliw croen canolig-tywyll',
    '👨🏿‍🎓' => 'myfyriwr: arlliw croen tywyll',
    '👩🏻‍🎓' => 'myfyrwraig: arlliw croen golau',
    '👩🏼‍🎓' => 'myfyrwraig: arlliw croen canolig-golau',
    '👩🏽‍🎓' => 'myfyrwraig: arlliw croen canolog',
    '👩🏾‍🎓' => 'myfyrwraig: arlliw croen canolig-tywyll',
    '👩🏿‍🎓' => 'myfyrwraig: arlliw croen tywyll',
    '🧑🏻‍🏫' => 'person sy’n addysgu: arlliw croen golau',
    '🧑🏼‍🏫' => 'person sy’n addysgu: arlliw croen canolig-golau',
    '🧑🏽‍🏫' => 'person sy’n addysgu: arlliw croen canolog',
    '🧑🏾‍🏫' => 'person sy’n addysgu: arlliw croen canolig-tywyll',
    '🧑🏿‍🏫' => 'person sy’n addysgu: arlliw croen tywyll',
    '👨🏻‍🏫' => 'athro: arlliw croen golau',
    '👨🏼‍🏫' => 'athro: arlliw croen canolig-golau',
    '👨🏽‍🏫' => 'athro: arlliw croen canolog',
    '👨🏾‍🏫' => 'athro: arlliw croen canolig-tywyll',
    '👨🏿‍🏫' => 'athro: arlliw croen tywyll',
    '👩🏻‍🏫' => 'athrawes: arlliw croen golau',
    '👩🏼‍🏫' => 'athrawes: arlliw croen canolig-golau',
    '👩🏽‍🏫' => 'athrawes: arlliw croen canolog',
    '👩🏾‍🏫' => 'athrawes: arlliw croen canolig-tywyll',
    '👩🏿‍🏫' => 'athrawes: arlliw croen tywyll',
    '🧑🏻‍⚖' => 'person sy’n barnu: arlliw croen golau',
    '🧑🏼‍⚖' => 'person sy’n barnu: arlliw croen canolig-golau',
    '🧑🏽‍⚖' => 'person sy’n barnu: arlliw croen canolog',
    '🧑🏾‍⚖' => 'person sy’n barnu: arlliw croen canolig-tywyll',
    '🧑🏿‍⚖' => 'person sy’n barnu: arlliw croen tywyll',
    '👨🏻‍⚖' => 'barnwr: arlliw croen golau',
    '👨🏼‍⚖' => 'barnwr: arlliw croen canolig-golau',
    '👨🏽‍⚖' => 'barnwr: arlliw croen canolog',
    '👨🏾‍⚖' => 'barnwr: arlliw croen canolig-tywyll',
    '👨🏿‍⚖' => 'barnwr: arlliw croen tywyll',
    '👩🏻‍⚖' => 'barnwres: arlliw croen golau',
    '👩🏼‍⚖' => 'barnwres: arlliw croen canolig-golau',
    '👩🏽‍⚖' => 'barnwres: arlliw croen canolog',
    '👩🏾‍⚖' => 'barnwres: arlliw croen canolig-tywyll',
    '👩🏿‍⚖' => 'barnwres: arlliw croen tywyll',
    '🧑🏻‍🌾' => 'person sy’n ffermio: arlliw croen golau',
    '🧑🏼‍🌾' => 'person sy’n ffermio: arlliw croen canolig-golau',
    '🧑🏽‍🌾' => 'person sy’n ffermio: arlliw croen canolog',
    '🧑🏾‍🌾' => 'person sy’n ffermio: arlliw croen canolig-tywyll',
    '🧑🏿‍🌾' => 'person sy’n ffermio: arlliw croen tywyll',
    '👨🏻‍🌾' => 'ffermwr: arlliw croen golau',
    '👨🏼‍🌾' => 'ffermwr: arlliw croen canolig-golau',
    '👨🏽‍🌾' => 'ffermwr: arlliw croen canolog',
    '👨🏾‍🌾' => 'ffermwr: arlliw croen canolig-tywyll',
    '👨🏿‍🌾' => 'ffermwr: arlliw croen tywyll',
    '👩🏻‍🌾' => 'ffarmwraig: arlliw croen golau',
    '👩🏼‍🌾' => 'ffarmwraig: arlliw croen canolig-golau',
    '👩🏽‍🌾' => 'ffarmwraig: arlliw croen canolog',
    '👩🏾‍🌾' => 'ffarmwraig: arlliw croen canolig-tywyll',
    '👩🏿‍🌾' => 'ffarmwraig: arlliw croen tywyll',
    '🧑🏻‍🍳' => 'person sy’n coginio: arlliw croen golau',
    '🧑🏼‍🍳' => 'person sy’n coginio: arlliw croen canolig-golau',
    '🧑🏽‍🍳' => 'person sy’n coginio: arlliw croen canolog',
    '🧑🏾‍🍳' => 'person sy’n coginio: arlliw croen canolig-tywyll',
    '🧑🏿‍🍳' => 'person sy’n coginio: arlliw croen tywyll',
    '👨🏻‍🍳' => 'cogydd: arlliw croen golau',
    '👨🏼‍🍳' => 'cogydd: arlliw croen canolig-golau',
    '👨🏽‍🍳' => 'cogydd: arlliw croen canolog',
    '👨🏾‍🍳' => 'cogydd: arlliw croen canolig-tywyll',
    '👨🏿‍🍳' => 'cogydd: arlliw croen tywyll',
    '👩🏻‍🍳' => 'cogyddes: arlliw croen golau',
    '👩🏼‍🍳' => 'cogyddes: arlliw croen canolig-golau',
    '👩🏽‍🍳' => 'cogyddes: arlliw croen canolog',
    '👩🏾‍🍳' => 'cogyddes: arlliw croen canolig-tywyll',
    '👩🏿‍🍳' => 'cogyddes: arlliw croen tywyll',
    '🧑🏻‍🔧' => 'mecanig: arlliw croen golau',
    '🧑🏼‍🔧' => 'mecanig: arlliw croen canolig-golau',
    '🧑🏽‍🔧' => 'mecanig: arlliw croen canolog',
    '🧑🏾‍🔧' => 'mecanig: arlliw croen canolig-tywyll',
    '🧑🏿‍🔧' => 'mecanig: arlliw croen tywyll',
    '👨🏻‍🔧' => 'peiriannydd gwrywaidd: arlliw croen golau',
    '👨🏼‍🔧' => 'peiriannydd gwrywaidd: arlliw croen canolig-golau',
    '👨🏽‍🔧' => 'peiriannydd gwrywaidd: arlliw croen canolog',
    '👨🏾‍🔧' => 'peiriannydd gwrywaidd: arlliw croen canolig-tywyll',
    '👨🏿‍🔧' => 'peiriannydd gwrywaidd: arlliw croen tywyll',
    '👩🏻‍🔧' => 'peiriannydd benywaidd: arlliw croen golau',
    '👩🏼‍🔧' => 'peiriannydd benywaidd: arlliw croen canolig-golau',
    '👩🏽‍🔧' => 'peiriannydd benywaidd: arlliw croen canolog',
    '👩🏾‍🔧' => 'peiriannydd benywaidd: arlliw croen canolig-tywyll',
    '👩🏿‍🔧' => 'peiriannydd benywaidd: arlliw croen tywyll',
    '🧑🏻‍🏭' => 'person sy’n gweithio mewn ffatri: arlliw croen golau',
    '🧑🏼‍🏭' => 'person sy’n gweithio mewn ffatri: arlliw croen canolig-golau',
    '🧑🏽‍🏭' => 'person sy’n gweithio mewn ffatri: arlliw croen canolog',
    '🧑🏾‍🏭' => 'person sy’n gweithio mewn ffatri: arlliw croen canolig-tywyll',
    '🧑🏿‍🏭' => 'person sy’n gweithio mewn ffatri: arlliw croen tywyll',
    '👨🏻‍🏭' => 'gweithiwr ffatri: arlliw croen golau',
    '👨🏼‍🏭' => 'gweithiwr ffatri: arlliw croen canolig-golau',
    '👨🏽‍🏭' => 'gweithiwr ffatri: arlliw croen canolog',
    '👨🏾‍🏭' => 'gweithiwr ffatri: arlliw croen canolig-tywyll',
    '👨🏿‍🏭' => 'gweithiwr ffatri: arlliw croen tywyll',
    '👩🏻‍🏭' => 'gweithwraig ffatri: arlliw croen golau',
    '👩🏼‍🏭' => 'gweithwraig ffatri: arlliw croen canolig-golau',
    '👩🏽‍🏭' => 'gweithwraig ffatri: arlliw croen canolog',
    '👩🏾‍🏭' => 'gweithwraig ffatri: arlliw croen canolig-tywyll',
    '👩🏿‍🏭' => 'gweithwraig ffatri: arlliw croen tywyll',
    '🧑🏻‍💼' => 'gweithiwr swyddfa: arlliw croen golau',
    '🧑🏼‍💼' => 'gweithiwr swyddfa: arlliw croen canolig-golau',
    '🧑🏽‍💼' => 'gweithiwr swyddfa: arlliw croen canolog',
    '🧑🏾‍💼' => 'gweithiwr swyddfa: arlliw croen canolig-tywyll',
    '🧑🏿‍💼' => 'gweithiwr swyddfa: arlliw croen tywyll',
    '👨🏻‍💼' => 'gweithiwr swyddfa gwrywaidd: arlliw croen golau',
    '👨🏼‍💼' => 'gweithiwr swyddfa gwrywaidd: arlliw croen canolig-golau',
    '👨🏽‍💼' => 'gweithiwr swyddfa gwrywaidd: arlliw croen canolog',
    '👨🏾‍💼' => 'gweithiwr swyddfa gwrywaidd: arlliw croen canolig-tywyll',
    '👨🏿‍💼' => 'gweithiwr swyddfa gwrywaidd: arlliw croen tywyll',
    '👩🏻‍💼' => 'gweithiwr swyddfa benywaidd: arlliw croen golau',
    '👩🏼‍💼' => 'gweithiwr swyddfa benywaidd: arlliw croen canolig-golau',
    '👩🏽‍💼' => 'gweithiwr swyddfa benywaidd: arlliw croen canolog',
    '👩🏾‍💼' => 'gweithiwr swyddfa benywaidd: arlliw croen canolig-tywyll',
    '👩🏿‍💼' => 'gweithiwr swyddfa benywaidd: arlliw croen tywyll',
    '🧑🏻‍🔬' => 'person sy’n ymwneud â gwyddoniaeth: arlliw croen golau',
    '🧑🏼‍🔬' => 'person sy’n ymwneud â gwyddoniaeth: arlliw croen canolig-golau',
    '🧑🏽‍🔬' => 'person sy’n ymwneud â gwyddoniaeth: arlliw croen canolog',
    '🧑🏾‍🔬' => 'person sy’n ymwneud â gwyddoniaeth: arlliw croen canolig-tywyll',
    '🧑🏿‍🔬' => 'person sy’n ymwneud â gwyddoniaeth: arlliw croen tywyll',
    '👨🏻‍🔬' => 'gwyddonydd: arlliw croen golau',
    '👨🏼‍🔬' => 'gwyddonydd: arlliw croen canolig-golau',
    '👨🏽‍🔬' => 'gwyddonydd: arlliw croen canolog',
    '👨🏾‍🔬' => 'gwyddonydd: arlliw croen canolig-tywyll',
    '👨🏿‍🔬' => 'gwyddonydd: arlliw croen tywyll',
    '👩🏻‍🔬' => 'gwyddonwraig: arlliw croen golau',
    '👩🏼‍🔬' => 'gwyddonwraig: arlliw croen canolig-golau',
    '👩🏽‍🔬' => 'gwyddonwraig: arlliw croen canolog',
    '👩🏾‍🔬' => 'gwyddonwraig: arlliw croen canolig-tywyll',
    '👩🏿‍🔬' => 'gwyddonwraig: arlliw croen tywyll',
    '🧑🏻‍💻' => 'technolegydd: arlliw croen golau',
    '🧑🏼‍💻' => 'technolegydd: arlliw croen canolig-golau',
    '🧑🏽‍💻' => 'technolegydd: arlliw croen canolog',
    '🧑🏾‍💻' => 'technolegydd: arlliw croen canolig-tywyll',
    '🧑🏿‍💻' => 'technolegydd: arlliw croen tywyll',
    '👨🏻‍💻' => 'technolegwr: arlliw croen golau',
    '👨🏼‍💻' => 'technolegwr: arlliw croen canolig-golau',
    '👨🏽‍💻' => 'technolegwr: arlliw croen canolog',
    '👨🏾‍💻' => 'technolegwr: arlliw croen canolig-tywyll',
    '👨🏿‍💻' => 'technolegwr: arlliw croen tywyll',
    '👩🏻‍💻' => 'technolegwraig: arlliw croen golau',
    '👩🏼‍💻' => 'technolegwraig: arlliw croen canolig-golau',
    '👩🏽‍💻' => 'technolegwraig: arlliw croen canolog',
    '👩🏾‍💻' => 'technolegwraig: arlliw croen canolig-tywyll',
    '👩🏿‍💻' => 'technolegwraig: arlliw croen tywyll',
    '🧑🏻‍🎤' => 'person sy’n canu: arlliw croen golau',
    '🧑🏼‍🎤' => 'person sy’n canu: arlliw croen canolig-golau',
    '🧑🏽‍🎤' => 'person sy’n canu: arlliw croen canolog',
    '🧑🏾‍🎤' => 'person sy’n canu: arlliw croen canolig-tywyll',
    '🧑🏿‍🎤' => 'person sy’n canu: arlliw croen tywyll',
    '👨🏻‍🎤' => 'cantor: arlliw croen golau',
    '👨🏼‍🎤' => 'cantor: arlliw croen canolig-golau',
    '👨🏽‍🎤' => 'cantor: arlliw croen canolog',
    '👨🏾‍🎤' => 'cantor: arlliw croen canolig-tywyll',
    '👨🏿‍🎤' => 'cantor: arlliw croen tywyll',
    '👩🏻‍🎤' => 'cantores: arlliw croen golau',
    '👩🏼‍🎤' => 'cantores: arlliw croen canolig-golau',
    '👩🏽‍🎤' => 'cantores: arlliw croen canolog',
    '👩🏾‍🎤' => 'cantores: arlliw croen canolig-tywyll',
    '👩🏿‍🎤' => 'cantores: arlliw croen tywyll',
    '🧑🏻‍🎨' => 'artist: arlliw croen golau',
    '🧑🏼‍🎨' => 'artist: arlliw croen canolig-golau',
    '🧑🏽‍🎨' => 'artist: arlliw croen canolog',
    '🧑🏾‍🎨' => 'artist: arlliw croen canolig-tywyll',
    '🧑🏿‍🎨' => 'artist: arlliw croen tywyll',
    '👨🏻‍🎨' => 'arlunydd: arlliw croen golau',
    '👨🏼‍🎨' => 'arlunydd: arlliw croen canolig-golau',
    '👨🏽‍🎨' => 'arlunydd: arlliw croen canolog',
    '👨🏾‍🎨' => 'arlunydd: arlliw croen canolig-tywyll',
    '👨🏿‍🎨' => 'arlunydd: arlliw croen tywyll',
    '👩🏻‍🎨' => 'arlunwraig: arlliw croen golau',
    '👩🏼‍🎨' => 'arlunwraig: arlliw croen canolig-golau',
    '👩🏽‍🎨' => 'arlunwraig: arlliw croen canolog',
    '👩🏾‍🎨' => 'arlunwraig: arlliw croen canolig-tywyll',
    '👩🏿‍🎨' => 'arlunwraig: arlliw croen tywyll',
    '🧑🏻‍✈' => 'peilot: arlliw croen golau',
    '🧑🏼‍✈' => 'peilot: arlliw croen canolig-golau',
    '🧑🏽‍✈' => 'peilot: arlliw croen canolog',
    '🧑🏾‍✈' => 'peilot: arlliw croen canolig-tywyll',
    '🧑🏿‍✈' => 'peilot: arlliw croen tywyll',
    '👨🏻‍✈' => 'peilot gwrywaidd: arlliw croen golau',
    '👨🏼‍✈' => 'peilot gwrywaidd: arlliw croen canolig-golau',
    '👨🏽‍✈' => 'peilot gwrywaidd: arlliw croen canolog',
    '👨🏾‍✈' => 'peilot gwrywaidd: arlliw croen canolig-tywyll',
    '👨🏿‍✈' => 'peilot gwrywaidd: arlliw croen tywyll',
    '👩🏻‍✈' => 'peilot benywaidd: arlliw croen golau',
    '👩🏼‍✈' => 'peilot benywaidd: arlliw croen canolig-golau',
    '👩🏽‍✈' => 'peilot benywaidd: arlliw croen canolog',
    '👩🏾‍✈' => 'peilot benywaidd: arlliw croen canolig-tywyll',
    '👩🏿‍✈' => 'peilot benywaidd: arlliw croen tywyll',
    '🧑🏻‍🚀' => 'gofod-deithiwr: arlliw croen golau',
    '🧑🏼‍🚀' => 'gofod-deithiwr: arlliw croen canolig-golau',
    '🧑🏽‍🚀' => 'gofod-deithiwr: arlliw croen canolog',
    '🧑🏾‍🚀' => 'gofod-deithiwr: arlliw croen canolig-tywyll',
    '🧑🏿‍🚀' => 'gofod-deithiwr: arlliw croen tywyll',
    '👨🏻‍🚀' => 'gofodwr: arlliw croen golau',
    '👨🏼‍🚀' => 'gofodwr: arlliw croen canolig-golau',
    '👨🏽‍🚀' => 'gofodwr: arlliw croen canolog',
    '👨🏾‍🚀' => 'gofodwr: arlliw croen canolig-tywyll',
    '👨🏿‍🚀' => 'gofodwr: arlliw croen tywyll',
    '👩🏻‍🚀' => 'gofodwraig: arlliw croen golau',
    '👩🏼‍🚀' => 'gofodwraig: arlliw croen canolig-golau',
    '👩🏽‍🚀' => 'gofodwraig: arlliw croen canolog',
    '👩🏾‍🚀' => 'gofodwraig: arlliw croen canolig-tywyll',
    '👩🏿‍🚀' => 'gofodwraig: arlliw croen tywyll',
    '🧑🏻‍🚒' => 'diffoddwr tân: arlliw croen golau',
    '🧑🏼‍🚒' => 'diffoddwr tân: arlliw croen canolig-golau',
    '🧑🏽‍🚒' => 'diffoddwr tân: arlliw croen canolog',
    '🧑🏾‍🚒' => 'diffoddwr tân: arlliw croen canolig-tywyll',
    '🧑🏿‍🚒' => 'diffoddwr tân: arlliw croen tywyll',
    '👨🏻‍🚒' => 'dyn tân: arlliw croen golau',
    '👨🏼‍🚒' => 'dyn tân: arlliw croen canolig-golau',
    '👨🏽‍🚒' => 'dyn tân: arlliw croen canolog',
    '👨🏾‍🚒' => 'dyn tân: arlliw croen canolig-tywyll',
    '👨🏿‍🚒' => 'dyn tân: arlliw croen tywyll',
    '👩🏻‍🚒' => 'menyw tân: arlliw croen golau',
    '👩🏼‍🚒' => 'menyw tân: arlliw croen canolig-golau',
    '👩🏽‍🚒' => 'menyw tân: arlliw croen canolog',
    '👩🏾‍🚒' => 'menyw tân: arlliw croen canolig-tywyll',
    '👩🏿‍🚒' => 'menyw tân: arlliw croen tywyll',
    '👮🏻‍♂' => 'swyddog heddlu gwrywaidd: arlliw croen golau',
    '👮🏼‍♂' => 'swyddog heddlu gwrywaidd: arlliw croen canolig-golau',
    '👮🏽‍♂' => 'swyddog heddlu gwrywaidd: arlliw croen canolog',
    '👮🏾‍♂' => 'swyddog heddlu gwrywaidd: arlliw croen canolig-tywyll',
    '👮🏿‍♂' => 'swyddog heddlu gwrywaidd: arlliw croen tywyll',
    '👮🏻‍♀' => 'swyddog heddlu benywaidd: arlliw croen golau',
    '👮🏼‍♀' => 'swyddog heddlu benywaidd: arlliw croen canolig-golau',
    '👮🏽‍♀' => 'swyddog heddlu benywaidd: arlliw croen canolog',
    '👮🏾‍♀' => 'swyddog heddlu benywaidd: arlliw croen canolig-tywyll',
    '👮🏿‍♀' => 'swyddog heddlu benywaidd: arlliw croen tywyll',
    '🕵🏻‍♂' => 'ditectif gwrywaidd: arlliw croen golau',
    '🕵🏼‍♂' => 'ditectif gwrywaidd: arlliw croen canolig-golau',
    '🕵🏽‍♂' => 'ditectif gwrywaidd: arlliw croen canolog',
    '🕵🏾‍♂' => 'ditectif gwrywaidd: arlliw croen canolig-tywyll',
    '🕵🏿‍♂' => 'ditectif gwrywaidd: arlliw croen tywyll',
    '🕵🏻‍♀' => 'ditectif benywaidd: arlliw croen golau',
    '🕵🏼‍♀' => 'ditectif benywaidd: arlliw croen canolig-golau',
    '🕵🏽‍♀' => 'ditectif benywaidd: arlliw croen canolog',
    '🕵🏾‍♀' => 'ditectif benywaidd: arlliw croen canolig-tywyll',
    '🕵🏿‍♀' => 'ditectif benywaidd: arlliw croen tywyll',
    '💂🏻‍♂' => 'gwarchodydd gwrywaidd: arlliw croen golau',
    '💂🏼‍♂' => 'gwarchodydd gwrywaidd: arlliw croen canolig-golau',
    '💂🏽‍♂' => 'gwarchodydd gwrywaidd: arlliw croen canolog',
    '💂🏾‍♂' => 'gwarchodydd gwrywaidd: arlliw croen canolig-tywyll',
    '💂🏿‍♂' => 'gwarchodydd gwrywaidd: arlliw croen tywyll',
    '💂🏻‍♀' => 'gwarchodydd benywaidd: arlliw croen golau',
    '💂🏼‍♀' => 'gwarchodydd benywaidd: arlliw croen canolig-golau',
    '💂🏽‍♀' => 'gwarchodydd benywaidd: arlliw croen canolog',
    '💂🏾‍♀' => 'gwarchodydd benywaidd: arlliw croen canolig-tywyll',
    '💂🏿‍♀' => 'gwarchodydd benywaidd: arlliw croen tywyll',
    '👷🏻‍♂' => 'gweithiwr adeiladu gwrywaidd: arlliw croen golau',
    '👷🏼‍♂' => 'gweithiwr adeiladu gwrywaidd: arlliw croen canolig-golau',
    '👷🏽‍♂' => 'gweithiwr adeiladu gwrywaidd: arlliw croen canolog',
    '👷🏾‍♂' => 'gweithiwr adeiladu gwrywaidd: arlliw croen canolig-tywyll',
    '👷🏿‍♂' => 'gweithiwr adeiladu gwrywaidd: arlliw croen tywyll',
    '👷🏻‍♀' => 'gweithiwr adeiladu benywaidd: arlliw croen golau',
    '👷🏼‍♀' => 'gweithiwr adeiladu benywaidd: arlliw croen canolig-golau',
    '👷🏽‍♀' => 'gweithiwr adeiladu benywaidd: arlliw croen canolog',
    '👷🏾‍♀' => 'gweithiwr adeiladu benywaidd: arlliw croen canolig-tywyll',
    '👷🏿‍♀' => 'gweithiwr adeiladu benywaidd: arlliw croen tywyll',
    '👳🏻‍♂' => 'dyn â thwrban: arlliw croen golau',
    '👳🏼‍♂' => 'dyn â thwrban: arlliw croen canolig-golau',
    '👳🏽‍♂' => 'dyn â thwrban: arlliw croen canolog',
    '👳🏾‍♂' => 'dyn â thwrban: arlliw croen canolig-tywyll',
    '👳🏿‍♂' => 'dyn â thwrban: arlliw croen tywyll',
    '👳🏻‍♀' => 'menyw â thwrban: arlliw croen golau',
    '👳🏼‍♀' => 'menyw â thwrban: arlliw croen canolig-golau',
    '👳🏽‍♀' => 'menyw â thwrban: arlliw croen canolog',
    '👳🏾‍♀' => 'menyw â thwrban: arlliw croen canolig-tywyll',
    '👳🏿‍♀' => 'menyw â thwrban: arlliw croen tywyll',
    '🤵🏻‍♂' => 'dyn mewn siaced ginio: arlliw croen golau',
    '🤵🏼‍♂' => 'dyn mewn siaced ginio: arlliw croen canolig-golau',
    '🤵🏽‍♂' => 'dyn mewn siaced ginio: arlliw croen canolog',
    '🤵🏾‍♂' => 'dyn mewn siaced ginio: arlliw croen canolig-tywyll',
    '🤵🏿‍♂' => 'dyn mewn siaced ginio: arlliw croen tywyll',
    '🤵🏻‍♀' => 'menyw mewn siaced ginio: arlliw croen golau',
    '🤵🏼‍♀' => 'menyw mewn siaced ginio: arlliw croen canolig-golau',
    '🤵🏽‍♀' => 'menyw mewn siaced ginio: arlliw croen canolog',
    '🤵🏾‍♀' => 'menyw mewn siaced ginio: arlliw croen canolig-tywyll',
    '🤵🏿‍♀' => 'menyw mewn siaced ginio: arlliw croen tywyll',
    '👰🏻‍♂' => 'dyn yn gwisgo llen: arlliw croen golau',
    '👰🏼‍♂' => 'dyn yn gwisgo llen: arlliw croen canolig-golau',
    '👰🏽‍♂' => 'dyn yn gwisgo llen: arlliw croen canolog',
    '👰🏾‍♂' => 'dyn yn gwisgo llen: arlliw croen canolig-tywyll',
    '👰🏿‍♂' => 'dyn yn gwisgo llen: arlliw croen tywyll',
    '👰🏻‍♀' => 'menyw yn gwisgo llen: arlliw croen golau',
    '👰🏼‍♀' => 'menyw yn gwisgo llen: arlliw croen canolig-golau',
    '👰🏽‍♀' => 'menyw yn gwisgo llen: arlliw croen canolog',
    '👰🏾‍♀' => 'menyw yn gwisgo llen: arlliw croen canolig-tywyll',
    '👰🏿‍♀' => 'menyw yn gwisgo llen: arlliw croen tywyll',
    '👩🏻‍🍼' => 'menyw yn bwydo babi: arlliw croen golau',
    '👩🏼‍🍼' => 'menyw yn bwydo babi: arlliw croen canolig-golau',
    '👩🏽‍🍼' => 'menyw yn bwydo babi: arlliw croen canolog',
    '👩🏾‍🍼' => 'menyw yn bwydo babi: arlliw croen canolig-tywyll',
    '👩🏿‍🍼' => 'menyw yn bwydo babi: arlliw croen tywyll',
    '👨🏻‍🍼' => 'dyn yn bwydo babi: arlliw croen golau',
    '👨🏼‍🍼' => 'dyn yn bwydo babi: arlliw croen canolig-golau',
    '👨🏽‍🍼' => 'dyn yn bwydo babi: arlliw croen canolog',
    '👨🏾‍🍼' => 'dyn yn bwydo babi: arlliw croen canolig-tywyll',
    '👨🏿‍🍼' => 'dyn yn bwydo babi: arlliw croen tywyll',
    '🧑🏻‍🍼' => 'person yn bwydo babi: arlliw croen golau',
    '🧑🏼‍🍼' => 'person yn bwydo babi: arlliw croen canolig-golau',
    '🧑🏽‍🍼' => 'person yn bwydo babi: arlliw croen canolog',
    '🧑🏾‍🍼' => 'person yn bwydo babi: arlliw croen canolig-tywyll',
    '🧑🏿‍🍼' => 'person yn bwydo babi: arlliw croen tywyll',
    '🧑🏻‍🎄' => 'mx claus: arlliw croen golau',
    '🧑🏼‍🎄' => 'mx claus: arlliw croen canolig-golau',
    '🧑🏽‍🎄' => 'mx claus: arlliw croen canolog',
    '🧑🏾‍🎄' => 'mx claus: arlliw croen canolig-tywyll',
    '🧑🏿‍🎄' => 'mx claus: arlliw croen tywyll',
    '🦸🏻‍♂' => 'archarwr gwrywaidd: arlliw croen golau',
    '🦸🏼‍♂' => 'archarwr gwrywaidd: arlliw croen canolig-golau',
    '🦸🏽‍♂' => 'archarwr gwrywaidd: arlliw croen canolog',
    '🦸🏾‍♂' => 'archarwr gwrywaidd: arlliw croen canolig-tywyll',
    '🦸🏿‍♂' => 'archarwr gwrywaidd: arlliw croen tywyll',
    '🦸🏻‍♀' => 'archarwr benywaidd: arlliw croen golau',
    '🦸🏼‍♀' => 'archarwr benywaidd: arlliw croen canolig-golau',
    '🦸🏽‍♀' => 'archarwr benywaidd: arlliw croen canolog',
    '🦸🏾‍♀' => 'archarwr benywaidd: arlliw croen canolig-tywyll',
    '🦸🏿‍♀' => 'archarwr benywaidd: arlliw croen tywyll',
    '🦹🏻‍♂' => 'archleidr gwrywaidd: arlliw croen golau',
    '🦹🏼‍♂' => 'archleidr gwrywaidd: arlliw croen canolig-golau',
    '🦹🏽‍♂' => 'archleidr gwrywaidd: arlliw croen canolog',
    '🦹🏾‍♂' => 'archleidr gwrywaidd: arlliw croen canolig-tywyll',
    '🦹🏿‍♂' => 'archleidr gwrywaidd: arlliw croen tywyll',
    '🦹🏻‍♀' => 'archleidr benywaidd: arlliw croen golau',
    '🦹🏼‍♀' => 'archleidr benywaidd: arlliw croen canolig-golau',
    '🦹🏽‍♀' => 'archleidr benywaidd: arlliw croen canolog',
    '🦹🏾‍♀' => 'archleidr benywaidd: arlliw croen canolig-tywyll',
    '🦹🏿‍♀' => 'archleidr benywaidd: arlliw croen tywyll',
    '🧙🏻‍♂' => 'dewin gwrywaidd: arlliw croen golau',
    '🧙🏼‍♂' => 'dewin gwrywaidd: arlliw croen canolig-golau',
    '🧙🏽‍♂' => 'dewin gwrywaidd: arlliw croen canolog',
    '🧙🏾‍♂' => 'dewin gwrywaidd: arlliw croen canolig-tywyll',
    '🧙🏿‍♂' => 'dewin gwrywaidd: arlliw croen tywyll',
    '🧙🏻‍♀' => 'dewin benywaidd: arlliw croen golau',
    '🧙🏼‍♀' => 'dewin benywaidd: arlliw croen canolig-golau',
    '🧙🏽‍♀' => 'dewin benywaidd: arlliw croen canolog',
    '🧙🏾‍♀' => 'dewin benywaidd: arlliw croen canolig-tywyll',
    '🧙🏿‍♀' => 'dewin benywaidd: arlliw croen tywyll',
    '🧚🏻‍♂' => 'tylwythen teg: arlliw croen golau',
    '🧚🏼‍♂' => 'tylwythen teg: arlliw croen canolig-golau',
    '🧚🏽‍♂' => 'tylwythen teg: arlliw croen canolog',
    '🧚🏾‍♂' => 'tylwythen teg: arlliw croen canolig-tywyll',
    '🧚🏿‍♂' => 'tylwythen teg: arlliw croen tywyll',
    '🧚🏻‍♀' => 'tylwythen deg: arlliw croen golau',
    '🧚🏼‍♀' => 'tylwythen deg: arlliw croen canolig-golau',
    '🧚🏽‍♀' => 'tylwythen deg: arlliw croen canolog',
    '🧚🏾‍♀' => 'tylwythen deg: arlliw croen canolig-tywyll',
    '🧚🏿‍♀' => 'tylwythen deg: arlliw croen tywyll',
    '🧛🏻‍♂' => 'fampir gwrywaidd: arlliw croen golau',
    '🧛🏼‍♂' => 'fampir gwrywaidd: arlliw croen canolig-golau',
    '🧛🏽‍♂' => 'fampir gwrywaidd: arlliw croen canolog',
    '🧛🏾‍♂' => 'fampir gwrywaidd: arlliw croen canolig-tywyll',
    '🧛🏿‍♂' => 'fampir gwrywaidd: arlliw croen tywyll',
    '🧛🏻‍♀' => 'fampir benywaidd: arlliw croen golau',
    '🧛🏼‍♀' => 'fampir benywaidd: arlliw croen canolig-golau',
    '🧛🏽‍♀' => 'fampir benywaidd: arlliw croen canolog',
    '🧛🏾‍♀' => 'fampir benywaidd: arlliw croen canolig-tywyll',
    '🧛🏿‍♀' => 'fampir benywaidd: arlliw croen tywyll',
    '🧜🏻‍♂' => 'morwas: arlliw croen golau',
    '🧜🏼‍♂' => 'morwas: arlliw croen canolig-golau',
    '🧜🏽‍♂' => 'morwas: arlliw croen canolog',
    '🧜🏾‍♂' => 'morwas: arlliw croen canolig-tywyll',
    '🧜🏿‍♂' => 'morwas: arlliw croen tywyll',
    '🧜🏻‍♀' => 'môr-forwyn: arlliw croen golau',
    '🧜🏼‍♀' => 'môr-forwyn: arlliw croen canolig-golau',
    '🧜🏽‍♀' => 'môr-forwyn: arlliw croen canolog',
    '🧜🏾‍♀' => 'môr-forwyn: arlliw croen canolig-tywyll',
    '🧜🏿‍♀' => 'môr-forwyn: arlliw croen tywyll',
    '🧝🏻‍♂' => 'coblyn gwrwywaidd: arlliw croen golau',
    '🧝🏼‍♂' => 'coblyn gwrwywaidd: arlliw croen canolig-golau',
    '🧝🏽‍♂' => 'coblyn gwrwywaidd: arlliw croen canolog',
    '🧝🏾‍♂' => 'coblyn gwrwywaidd: arlliw croen canolig-tywyll',
    '🧝🏿‍♂' => 'coblyn gwrwywaidd: arlliw croen tywyll',
    '🧝🏻‍♀' => 'coblyn benywaidd: arlliw croen golau',
    '🧝🏼‍♀' => 'coblyn benywaidd: arlliw croen canolig-golau',
    '🧝🏽‍♀' => 'coblyn benywaidd: arlliw croen canolog',
    '🧝🏾‍♀' => 'coblyn benywaidd: arlliw croen canolig-tywyll',
    '🧝🏿‍♀' => 'coblyn benywaidd: arlliw croen tywyll',
    '💆🏻‍♂' => 'dyn yn derbyn tyluniad i’w wyneb: arlliw croen golau',
    '💆🏼‍♂' => 'dyn yn derbyn tyluniad i’w wyneb: arlliw croen canolig-golau',
    '💆🏽‍♂' => 'dyn yn derbyn tyluniad i’w wyneb: arlliw croen canolog',
    '💆🏾‍♂' => 'dyn yn derbyn tyluniad i’w wyneb: arlliw croen canolig-tywyll',
    '💆🏿‍♂' => 'dyn yn derbyn tyluniad i’w wyneb: arlliw croen tywyll',
    '💆🏻‍♀' => 'menyw yn derbyn tyluniad i’w wyneb: arlliw croen golau',
    '💆🏼‍♀' => 'menyw yn derbyn tyluniad i’w wyneb: arlliw croen canolig-golau',
    '💆🏽‍♀' => 'menyw yn derbyn tyluniad i’w wyneb: arlliw croen canolog',
    '💆🏾‍♀' => 'menyw yn derbyn tyluniad i’w wyneb: arlliw croen canolig-tywyll',
    '💆🏿‍♀' => 'menyw yn derbyn tyluniad i’w wyneb: arlliw croen tywyll',
    '💇🏻‍♂' => 'dyn yn cael ei wallt wedi’u torri: arlliw croen golau',
    '💇🏼‍♂' => 'dyn yn cael ei wallt wedi’u torri: arlliw croen canolig-golau',
    '💇🏽‍♂' => 'dyn yn cael ei wallt wedi’u torri: arlliw croen canolog',
    '💇🏾‍♂' => 'dyn yn cael ei wallt wedi’u torri: arlliw croen canolig-tywyll',
    '💇🏿‍♂' => 'dyn yn cael ei wallt wedi’u torri: arlliw croen tywyll',
    '💇🏻‍♀' => 'menyw yn cael ei gwallt wedi’u torri: arlliw croen golau',
    '💇🏼‍♀' => 'menyw yn cael ei gwallt wedi’u torri: arlliw croen canolig-golau',
    '💇🏽‍♀' => 'menyw yn cael ei gwallt wedi’u torri: arlliw croen canolog',
    '💇🏾‍♀' => 'menyw yn cael ei gwallt wedi’u torri: arlliw croen canolig-tywyll',
    '💇🏿‍♀' => 'menyw yn cael ei gwallt wedi’u torri: arlliw croen tywyll',
    '🚶🏻‍♂' => 'dyn yn cerdded: arlliw croen golau',
    '🚶🏼‍♂' => 'dyn yn cerdded: arlliw croen canolig-golau',
    '🚶🏽‍♂' => 'dyn yn cerdded: arlliw croen canolog',
    '🚶🏾‍♂' => 'dyn yn cerdded: arlliw croen canolig-tywyll',
    '🚶🏿‍♂' => 'dyn yn cerdded: arlliw croen tywyll',
    '🚶🏻‍♀' => 'menyw yn cerdded: arlliw croen golau',
    '🚶🏼‍♀' => 'menyw yn cerdded: arlliw croen canolig-golau',
    '🚶🏽‍♀' => 'menyw yn cerdded: arlliw croen canolog',
    '🚶🏾‍♀' => 'menyw yn cerdded: arlliw croen canolig-tywyll',
    '🚶🏿‍♀' => 'menyw yn cerdded: arlliw croen tywyll',
    '🚶🏻‍➡' => 'person yn cerdded: arlliw croen golau, wynebu i’r dde',
    '🚶🏼‍➡' => 'person yn cerdded: arlliw croen canolig-golau, wynebu i’r dde',
    '🚶🏽‍➡' => 'person yn cerdded: arlliw croen canolog, wynebu i’r dde',
    '🚶🏾‍➡' => 'person yn cerdded: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🚶🏿‍➡' => 'person yn cerdded: arlliw croen tywyll, wynebu i’r dde',
    '🧍🏻‍♂' => 'dyn yn sefyll: arlliw croen golau',
    '🧍🏼‍♂' => 'dyn yn sefyll: arlliw croen canolig-golau',
    '🧍🏽‍♂' => 'dyn yn sefyll: arlliw croen canolog',
    '🧍🏾‍♂' => 'dyn yn sefyll: arlliw croen canolig-tywyll',
    '🧍🏿‍♂' => 'dyn yn sefyll: arlliw croen tywyll',
    '🧍🏻‍♀' => 'menyw yn sefyll: arlliw croen golau',
    '🧍🏼‍♀' => 'menyw yn sefyll: arlliw croen canolig-golau',
    '🧍🏽‍♀' => 'menyw yn sefyll: arlliw croen canolog',
    '🧍🏾‍♀' => 'menyw yn sefyll: arlliw croen canolig-tywyll',
    '🧍🏿‍♀' => 'menyw yn sefyll: arlliw croen tywyll',
    '🧎🏻‍♂' => 'dyn yn penlinio: arlliw croen golau',
    '🧎🏼‍♂' => 'dyn yn penlinio: arlliw croen canolig-golau',
    '🧎🏽‍♂' => 'dyn yn penlinio: arlliw croen canolog',
    '🧎🏾‍♂' => 'dyn yn penlinio: arlliw croen canolig-tywyll',
    '🧎🏿‍♂' => 'dyn yn penlinio: arlliw croen tywyll',
    '🧎🏻‍♀' => 'menyw yn penlinio: arlliw croen golau',
    '🧎🏼‍♀' => 'menyw yn penlinio: arlliw croen canolig-golau',
    '🧎🏽‍♀' => 'menyw yn penlinio: arlliw croen canolog',
    '🧎🏾‍♀' => 'menyw yn penlinio: arlliw croen canolig-tywyll',
    '🧎🏿‍♀' => 'menyw yn penlinio: arlliw croen tywyll',
    '🧎🏻‍➡' => 'person yn penlinio: arlliw croen golau, wynebu i’r dde',
    '🧎🏼‍➡' => 'person yn penlinio: arlliw croen canolig-golau, wynebu i’r dde',
    '🧎🏽‍➡' => 'person yn penlinio: arlliw croen canolog, wynebu i’r dde',
    '🧎🏾‍➡' => 'person yn penlinio: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🧎🏿‍➡' => 'person yn penlinio: arlliw croen tywyll, wynebu i’r dde',
    '🧑🏻‍🦯' => 'person â ffon gerdded: arlliw croen golau',
    '🧑🏼‍🦯' => 'person â ffon gerdded: arlliw croen canolig-golau',
    '🧑🏽‍🦯' => 'person â ffon gerdded: arlliw croen canolog',
    '🧑🏾‍🦯' => 'person â ffon gerdded: arlliw croen canolig-tywyll',
    '🧑🏿‍🦯' => 'person â ffon gerdded: arlliw croen tywyll',
    '👨🏻‍🦯' => 'dyn â ffon wen: arlliw croen golau',
    '👨🏼‍🦯' => 'dyn â ffon wen: arlliw croen canolig-golau',
    '👨🏽‍🦯' => 'dyn â ffon wen: arlliw croen canolog',
    '👨🏾‍🦯' => 'dyn â ffon wen: arlliw croen canolig-tywyll',
    '👨🏿‍🦯' => 'dyn â ffon wen: arlliw croen tywyll',
    '👩🏻‍🦯' => 'menyw â ffon wen: arlliw croen golau',
    '👩🏼‍🦯' => 'menyw â ffon wen: arlliw croen canolig-golau',
    '👩🏽‍🦯' => 'menyw â ffon wen: arlliw croen canolog',
    '👩🏾‍🦯' => 'menyw â ffon wen: arlliw croen canolig-tywyll',
    '👩🏿‍🦯' => 'menyw â ffon wen: arlliw croen tywyll',
    '🧑🏻‍🦼' => 'person mewn cadair olwyn drydan: arlliw croen golau',
    '🧑🏼‍🦼' => 'person mewn cadair olwyn drydan: arlliw croen canolig-golau',
    '🧑🏽‍🦼' => 'person mewn cadair olwyn drydan: arlliw croen canolog',
    '🧑🏾‍🦼' => 'person mewn cadair olwyn drydan: arlliw croen canolig-tywyll',
    '🧑🏿‍🦼' => 'person mewn cadair olwyn drydan: arlliw croen tywyll',
    '👨🏻‍🦼' => 'dyn mewn cadair olwyn fodur: arlliw croen golau',
    '👨🏼‍🦼' => 'dyn mewn cadair olwyn fodur: arlliw croen canolig-golau',
    '👨🏽‍🦼' => 'dyn mewn cadair olwyn fodur: arlliw croen canolog',
    '👨🏾‍🦼' => 'dyn mewn cadair olwyn fodur: arlliw croen canolig-tywyll',
    '👨🏿‍🦼' => 'dyn mewn cadair olwyn fodur: arlliw croen tywyll',
    '👩🏻‍🦼' => 'menyw mewn cadair olwyn fodur: arlliw croen golau',
    '👩🏼‍🦼' => 'menyw mewn cadair olwyn fodur: arlliw croen canolig-golau',
    '👩🏽‍🦼' => 'menyw mewn cadair olwyn fodur: arlliw croen canolog',
    '👩🏾‍🦼' => 'menyw mewn cadair olwyn fodur: arlliw croen canolig-tywyll',
    '👩🏿‍🦼' => 'menyw mewn cadair olwyn fodur: arlliw croen tywyll',
    '🧑🏻‍🦽' => 'person mewn cadair olwyn â llaw: arlliw croen golau',
    '🧑🏼‍🦽' => 'person mewn cadair olwyn â llaw: arlliw croen canolig-golau',
    '🧑🏽‍🦽' => 'person mewn cadair olwyn â llaw: arlliw croen canolog',
    '🧑🏾‍🦽' => 'person mewn cadair olwyn â llaw: arlliw croen canolig-tywyll',
    '🧑🏿‍🦽' => 'person mewn cadair olwyn â llaw: arlliw croen tywyll',
    '👨🏻‍🦽' => 'dyn mewn cadair olwyn: arlliw croen golau',
    '👨🏼‍🦽' => 'dyn mewn cadair olwyn: arlliw croen canolig-golau',
    '👨🏽‍🦽' => 'dyn mewn cadair olwyn: arlliw croen canolog',
    '👨🏾‍🦽' => 'dyn mewn cadair olwyn: arlliw croen canolig-tywyll',
    '👨🏿‍🦽' => 'dyn mewn cadair olwyn: arlliw croen tywyll',
    '👩🏻‍🦽' => 'menyw mewn cadair olwyn: arlliw croen golau',
    '👩🏼‍🦽' => 'menyw mewn cadair olwyn: arlliw croen canolig-golau',
    '👩🏽‍🦽' => 'menyw mewn cadair olwyn: arlliw croen canolog',
    '👩🏾‍🦽' => 'menyw mewn cadair olwyn: arlliw croen canolig-tywyll',
    '👩🏿‍🦽' => 'menyw mewn cadair olwyn: arlliw croen tywyll',
    '🏃🏻‍♂' => 'dyn yn rhedeg: arlliw croen golau',
    '🏃🏼‍♂' => 'dyn yn rhedeg: arlliw croen canolig-golau',
    '🏃🏽‍♂' => 'dyn yn rhedeg: arlliw croen canolog',
    '🏃🏾‍♂' => 'dyn yn rhedeg: arlliw croen canolig-tywyll',
    '🏃🏿‍♂' => 'dyn yn rhedeg: arlliw croen tywyll',
    '🏃🏻‍♀' => 'menyw yn rhedeg: arlliw croen golau',
    '🏃🏼‍♀' => 'menyw yn rhedeg: arlliw croen canolig-golau',
    '🏃🏽‍♀' => 'menyw yn rhedeg: arlliw croen canolog',
    '🏃🏾‍♀' => 'menyw yn rhedeg: arlliw croen canolig-tywyll',
    '🏃🏿‍♀' => 'menyw yn rhedeg: arlliw croen tywyll',
    '🏃🏻‍➡' => 'person yn rhedeg: arlliw croen golau, wynebu i’r dde',
    '🏃🏼‍➡' => 'person yn rhedeg: arlliw croen canolig-golau, wynebu i’r dde',
    '🏃🏽‍➡' => 'person yn rhedeg: arlliw croen canolog, wynebu i’r dde',
    '🏃🏾‍➡' => 'person yn rhedeg: arlliw croen canolig-tywyll, wynebu i’r dde',
    '🏃🏿‍➡' => 'person yn rhedeg: arlliw croen tywyll, wynebu i’r dde',
    '👯🏻‍♀' => 'menyw mewn parti: arlliw croen golau',
    '👯🏼‍♀' => 'menyw mewn parti: arlliw croen canolig-golau',
    '👯🏽‍♀' => 'menyw mewn parti: arlliw croen canolog',
    '👯🏾‍♀' => 'menyw mewn parti: arlliw croen canolig-tywyll',
    '👯🏿‍♀' => 'menyw mewn parti: arlliw croen tywyll',
    '👯🏻‍♂' => 'dyn mewn parti: arlliw croen golau',
    '👯🏼‍♂' => 'dyn mewn parti: arlliw croen canolig-golau',
    '👯🏽‍♂' => 'dyn mewn parti: arlliw croen canolog',
    '👯🏾‍♂' => 'dyn mewn parti: arlliw croen canolig-tywyll',
    '👯🏿‍♂' => 'dyn mewn parti: arlliw croen tywyll',
    '🧖🏻‍♂' => 'dyn mewn ystafell llawn stêm: arlliw croen golau',
    '🧖🏼‍♂' => 'dyn mewn ystafell llawn stêm: arlliw croen canolig-golau',
    '🧖🏽‍♂' => 'dyn mewn ystafell llawn stêm: arlliw croen canolog',
    '🧖🏾‍♂' => 'dyn mewn ystafell llawn stêm: arlliw croen canolig-tywyll',
    '🧖🏿‍♂' => 'dyn mewn ystafell llawn stêm: arlliw croen tywyll',
    '🧖🏻‍♀' => 'menyw mewn ystafell llawn stêm: arlliw croen golau',
    '🧖🏼‍♀' => 'menyw mewn ystafell llawn stêm: arlliw croen canolig-golau',
    '🧖🏽‍♀' => 'menyw mewn ystafell llawn stêm: arlliw croen canolog',
    '🧖🏾‍♀' => 'menyw mewn ystafell llawn stêm: arlliw croen canolig-tywyll',
    '🧖🏿‍♀' => 'menyw mewn ystafell llawn stêm: arlliw croen tywyll',
    '🧗🏻‍♂' => 'dyn yn dringo: arlliw croen golau',
    '🧗🏼‍♂' => 'dyn yn dringo: arlliw croen canolig-golau',
    '🧗🏽‍♂' => 'dyn yn dringo: arlliw croen canolog',
    '🧗🏾‍♂' => 'dyn yn dringo: arlliw croen canolig-tywyll',
    '🧗🏿‍♂' => 'dyn yn dringo: arlliw croen tywyll',
    '🧗🏻‍♀' => 'menyw yn dringo: arlliw croen golau',
    '🧗🏼‍♀' => 'menyw yn dringo: arlliw croen canolig-golau',
    '🧗🏽‍♀' => 'menyw yn dringo: arlliw croen canolog',
    '🧗🏾‍♀' => 'menyw yn dringo: arlliw croen canolig-tywyll',
    '🧗🏿‍♀' => 'menyw yn dringo: arlliw croen tywyll',
    '🏌🏻‍♂' => 'dyn yn chwarae golff: arlliw croen golau',
    '🏌🏼‍♂' => 'dyn yn chwarae golff: arlliw croen canolig-golau',
    '🏌🏽‍♂' => 'dyn yn chwarae golff: arlliw croen canolog',
    '🏌🏾‍♂' => 'dyn yn chwarae golff: arlliw croen canolig-tywyll',
    '🏌🏿‍♂' => 'dyn yn chwarae golff: arlliw croen tywyll',
    '🏌🏻‍♀' => 'menyw yn chwarae golff: arlliw croen golau',
    '🏌🏼‍♀' => 'menyw yn chwarae golff: arlliw croen canolig-golau',
    '🏌🏽‍♀' => 'menyw yn chwarae golff: arlliw croen canolog',
    '🏌🏾‍♀' => 'menyw yn chwarae golff: arlliw croen canolig-tywyll',
    '🏌🏿‍♀' => 'menyw yn chwarae golff: arlliw croen tywyll',
    '🏄🏻‍♂' => 'dyn yn syrffio: arlliw croen golau',
    '🏄🏼‍♂' => 'dyn yn syrffio: arlliw croen canolig-golau',
    '🏄🏽‍♂' => 'dyn yn syrffio: arlliw croen canolog',
    '🏄🏾‍♂' => 'dyn yn syrffio: arlliw croen canolig-tywyll',
    '🏄🏿‍♂' => 'dyn yn syrffio: arlliw croen tywyll',
    '🏄🏻‍♀' => 'menyw yn syrffio: arlliw croen golau',
    '🏄🏼‍♀' => 'menyw yn syrffio: arlliw croen canolig-golau',
    '🏄🏽‍♀' => 'menyw yn syrffio: arlliw croen canolog',
    '🏄🏾‍♀' => 'menyw yn syrffio: arlliw croen canolig-tywyll',
    '🏄🏿‍♀' => 'menyw yn syrffio: arlliw croen tywyll',
    '🚣🏻‍♂' => 'dyn yn rhwyfo cwch: arlliw croen golau',
    '🚣🏼‍♂' => 'dyn yn rhwyfo cwch: arlliw croen canolig-golau',
    '🚣🏽‍♂' => 'dyn yn rhwyfo cwch: arlliw croen canolog',
    '🚣🏾‍♂' => 'dyn yn rhwyfo cwch: arlliw croen canolig-tywyll',
    '🚣🏿‍♂' => 'dyn yn rhwyfo cwch: arlliw croen tywyll',
    '🚣🏻‍♀' => 'menyw yn rhwyfo cwch: arlliw croen golau',
    '🚣🏼‍♀' => 'menyw yn rhwyfo cwch: arlliw croen canolig-golau',
    '🚣🏽‍♀' => 'menyw yn rhwyfo cwch: arlliw croen canolog',
    '🚣🏾‍♀' => 'menyw yn rhwyfo cwch: arlliw croen canolig-tywyll',
    '🚣🏿‍♀' => 'menyw yn rhwyfo cwch: arlliw croen tywyll',
    '🏊🏻‍♂' => 'dyn yn nofio: arlliw croen golau',
    '🏊🏼‍♂' => 'dyn yn nofio: arlliw croen canolig-golau',
    '🏊🏽‍♂' => 'dyn yn nofio: arlliw croen canolog',
    '🏊🏾‍♂' => 'dyn yn nofio: arlliw croen canolig-tywyll',
    '🏊🏿‍♂' => 'dyn yn nofio: arlliw croen tywyll',
    '🏊🏻‍♀' => 'menyw yn nofio: arlliw croen golau',
    '🏊🏼‍♀' => 'menyw yn nofio: arlliw croen canolig-golau',
    '🏊🏽‍♀' => 'menyw yn nofio: arlliw croen canolog',
    '🏊🏾‍♀' => 'menyw yn nofio: arlliw croen canolig-tywyll',
    '🏊🏿‍♀' => 'menyw yn nofio: arlliw croen tywyll',
    '⛹🏻‍♂' => 'dyn â phêl: arlliw croen golau',
    '⛹🏼‍♂' => 'dyn â phêl: arlliw croen canolig-golau',
    '⛹🏽‍♂' => 'dyn â phêl: arlliw croen canolog',
    '⛹🏾‍♂' => 'dyn â phêl: arlliw croen canolig-tywyll',
    '⛹🏿‍♂' => 'dyn â phêl: arlliw croen tywyll',
    '⛹🏻‍♀' => 'menyw â phêl: arlliw croen golau',
    '⛹🏼‍♀' => 'menyw â phêl: arlliw croen canolig-golau',
    '⛹🏽‍♀' => 'menyw â phêl: arlliw croen canolog',
    '⛹🏾‍♀' => 'menyw â phêl: arlliw croen canolig-tywyll',
    '⛹🏿‍♀' => 'menyw â phêl: arlliw croen tywyll',
    '🏋🏻‍♂' => 'dyn yn codi pwysau: arlliw croen golau',
    '🏋🏼‍♂' => 'dyn yn codi pwysau: arlliw croen canolig-golau',
    '🏋🏽‍♂' => 'dyn yn codi pwysau: arlliw croen canolog',
    '🏋🏾‍♂' => 'dyn yn codi pwysau: arlliw croen canolig-tywyll',
    '🏋🏿‍♂' => 'dyn yn codi pwysau: arlliw croen tywyll',
    '🏋🏻‍♀' => 'menyw yn codi pwysau: arlliw croen golau',
    '🏋🏼‍♀' => 'menyw yn codi pwysau: arlliw croen canolig-golau',
    '🏋🏽‍♀' => 'menyw yn codi pwysau: arlliw croen canolog',
    '🏋🏾‍♀' => 'menyw yn codi pwysau: arlliw croen canolig-tywyll',
    '🏋🏿‍♀' => 'menyw yn codi pwysau: arlliw croen tywyll',
    '🚴🏻‍♂' => 'dyn yn beicio: arlliw croen golau',
    '🚴🏼‍♂' => 'dyn yn beicio: arlliw croen canolig-golau',
    '🚴🏽‍♂' => 'dyn yn beicio: arlliw croen canolog',
    '🚴🏾‍♂' => 'dyn yn beicio: arlliw croen canolig-tywyll',
    '🚴🏿‍♂' => 'dyn yn beicio: arlliw croen tywyll',
    '🚴🏻‍♀' => 'menyw yn beicio: arlliw croen golau',
    '🚴🏼‍♀' => 'menyw yn beicio: arlliw croen canolig-golau',
    '🚴🏽‍♀' => 'menyw yn beicio: arlliw croen canolog',
    '🚴🏾‍♀' => 'menyw yn beicio: arlliw croen canolig-tywyll',
    '🚴🏿‍♀' => 'menyw yn beicio: arlliw croen tywyll',
    '🚵🏻‍♂' => 'dyn yn beicio mynydd: arlliw croen golau',
    '🚵🏼‍♂' => 'dyn yn beicio mynydd: arlliw croen canolig-golau',
    '🚵🏽‍♂' => 'dyn yn beicio mynydd: arlliw croen canolog',
    '🚵🏾‍♂' => 'dyn yn beicio mynydd: arlliw croen canolig-tywyll',
    '🚵🏿‍♂' => 'dyn yn beicio mynydd: arlliw croen tywyll',
    '🚵🏻‍♀' => 'menyw yn beicio mynydd: arlliw croen golau',
    '🚵🏼‍♀' => 'menyw yn beicio mynydd: arlliw croen canolig-golau',
    '🚵🏽‍♀' => 'menyw yn beicio mynydd: arlliw croen canolog',
    '🚵🏾‍♀' => 'menyw yn beicio mynydd: arlliw croen canolig-tywyll',
    '🚵🏿‍♀' => 'menyw yn beicio mynydd: arlliw croen tywyll',
    '🤸🏻‍♂' => 'dyn yn gwneud olwyn dro: arlliw croen golau',
    '🤸🏼‍♂' => 'dyn yn gwneud olwyn dro: arlliw croen canolig-golau',
    '🤸🏽‍♂' => 'dyn yn gwneud olwyn dro: arlliw croen canolog',
    '🤸🏾‍♂' => 'dyn yn gwneud olwyn dro: arlliw croen canolig-tywyll',
    '🤸🏿‍♂' => 'dyn yn gwneud olwyn dro: arlliw croen tywyll',
    '🤸🏻‍♀' => 'menyw yn gwneud olwyn dro: arlliw croen golau',
    '🤸🏼‍♀' => 'menyw yn gwneud olwyn dro: arlliw croen canolig-golau',
    '🤸🏽‍♀' => 'menyw yn gwneud olwyn dro: arlliw croen canolog',
    '🤸🏾‍♀' => 'menyw yn gwneud olwyn dro: arlliw croen canolig-tywyll',
    '🤸🏿‍♀' => 'menyw yn gwneud olwyn dro: arlliw croen tywyll',
    '🤼🏻‍♀' => 'menywod yn reslo: arlliw croen golau',
    '🤼🏼‍♀' => 'menywod yn reslo: arlliw croen canolig-golau',
    '🤼🏽‍♀' => 'menywod yn reslo: arlliw croen canolog',
    '🤼🏾‍♀' => 'menywod yn reslo: arlliw croen canolig-tywyll',
    '🤼🏿‍♀' => 'menywod yn reslo: arlliw croen tywyll',
    '🤼🏻‍♂' => 'dynion yn reslo: arlliw croen golau',
    '🤼🏼‍♂' => 'dynion yn reslo: arlliw croen canolig-golau',
    '🤼🏽‍♂' => 'dynion yn reslo: arlliw croen canolog',
    '🤼🏾‍♂' => 'dynion yn reslo: arlliw croen canolig-tywyll',
    '🤼🏿‍♂' => 'dynion yn reslo: arlliw croen tywyll',
    '🤽🏻‍♂' => 'dyn yn chwarae polo dŵr: arlliw croen golau',
    '🤽🏼‍♂' => 'dyn yn chwarae polo dŵr: arlliw croen canolig-golau',
    '🤽🏽‍♂' => 'dyn yn chwarae polo dŵr: arlliw croen canolog',
    '🤽🏾‍♂' => 'dyn yn chwarae polo dŵr: arlliw croen canolig-tywyll',
    '🤽🏿‍♂' => 'dyn yn chwarae polo dŵr: arlliw croen tywyll',
    '🤽🏻‍♀' => 'menyw yn chwarae polo dŵr: arlliw croen golau',
    '🤽🏼‍♀' => 'menyw yn chwarae polo dŵr: arlliw croen canolig-golau',
    '🤽🏽‍♀' => 'menyw yn chwarae polo dŵr: arlliw croen canolog',
    '🤽🏾‍♀' => 'menyw yn chwarae polo dŵr: arlliw croen canolig-tywyll',
    '🤽🏿‍♀' => 'menyw yn chwarae polo dŵr: arlliw croen tywyll',
    '🤾🏻‍♂' => 'dyn yn chwarae pêl law: arlliw croen golau',
    '🤾🏼‍♂' => 'dyn yn chwarae pêl law: arlliw croen canolig-golau',
    '🤾🏽‍♂' => 'dyn yn chwarae pêl law: arlliw croen canolog',
    '🤾🏾‍♂' => 'dyn yn chwarae pêl law: arlliw croen canolig-tywyll',
    '🤾🏿‍♂' => 'dyn yn chwarae pêl law: arlliw croen tywyll',
    '🤾🏻‍♀' => 'menyw yn chwarae pêl law: arlliw croen golau',
    '🤾🏼‍♀' => 'menyw yn chwarae pêl law: arlliw croen canolig-golau',
    '🤾🏽‍♀' => 'menyw yn chwarae pêl law: arlliw croen canolog',
    '🤾🏾‍♀' => 'menyw yn chwarae pêl law: arlliw croen canolig-tywyll',
    '🤾🏿‍♀' => 'menyw yn chwarae pêl law: arlliw croen tywyll',
    '🤹🏻‍♂' => 'dyn yn jyglo: arlliw croen golau',
    '🤹🏼‍♂' => 'dyn yn jyglo: arlliw croen canolig-golau',
    '🤹🏽‍♂' => 'dyn yn jyglo: arlliw croen canolog',
    '🤹🏾‍♂' => 'dyn yn jyglo: arlliw croen canolig-tywyll',
    '🤹🏿‍♂' => 'dyn yn jyglo: arlliw croen tywyll',
    '🤹🏻‍♀' => 'menyw yn jyglo: arlliw croen golau',
    '🤹🏼‍♀' => 'menyw yn jyglo: arlliw croen canolig-golau',
    '🤹🏽‍♀' => 'menyw yn jyglo: arlliw croen canolog',
    '🤹🏾‍♀' => 'menyw yn jyglo: arlliw croen canolig-tywyll',
    '🤹🏿‍♀' => 'menyw yn jyglo: arlliw croen tywyll',
    '🧘🏻‍♂' => 'dyn mewn ystum lingroes: arlliw croen golau',
    '🧘🏼‍♂' => 'dyn mewn ystum lingroes: arlliw croen canolig-golau',
    '🧘🏽‍♂' => 'dyn mewn ystum lingroes: arlliw croen canolog',
    '🧘🏾‍♂' => 'dyn mewn ystum lingroes: arlliw croen canolig-tywyll',
    '🧘🏿‍♂' => 'dyn mewn ystum lingroes: arlliw croen tywyll',
    '🧘🏻‍♀' => 'menyw mewn ystum lingroes: arlliw croen golau',
    '🧘🏼‍♀' => 'menyw mewn ystum lingroes: arlliw croen canolig-golau',
    '🧘🏽‍♀' => 'menyw mewn ystum lingroes: arlliw croen canolog',
    '🧘🏾‍♀' => 'menyw mewn ystum lingroes: arlliw croen canolig-tywyll',
    '🧘🏿‍♀' => 'menyw mewn ystum lingroes: arlliw croen tywyll',
    '🧑‍🦰' => 'person: gwallt coch',
    '🧑‍🦱' => 'person: gwallt cyrliog',
    '🧑‍🦳' => 'person: gwallt gwyn',
    '🧑‍🦲' => 'person: moel',
    '👨‍🦰' => 'dyn: gwallt coch',
    '👨‍🦱' => 'dyn: gwallt cyrliog',
    '👨‍🦳' => 'dyn: gwallt gwyn',
    '👨‍🦲' => 'dyn: moel',
    '👩‍🦰' => 'menyw: gwallt coch',
    '👩‍🦱' => 'menyw: gwallt cyrliog',
    '👩‍🦳' => 'menyw: gwallt gwyn',
    '👩‍🦲' => 'menyw: moel',
    '🚶‍➡' => 'person yn cerdded: wynebu i’r dde',
    '🧎‍➡' => 'person yn penlinio: wynebu i’r dde',
    '🏃‍➡' => 'person yn rhedeg: wynebu i’r dde',
    '👨‍👦' => 'teulu: dyn, bachgen',
    '👨‍👧' => 'teulu: dyn, merch',
    '👩‍👦' => 'teulu: menyw, bachgen',
    '👩‍👧' => 'teulu: menyw, merch',
    '😶‍🌫' => 'wyneb mewn cymylau',
    '😮‍💨' => 'wyneb anadlu allan',
    '🙂‍↕' => 'pen yn ysgwyd i fyny ac i lawr',
    '😵‍💫' => 'wyneb â llygaid troellog',
    '❤‍🔥' => 'calon ar dân',
    '❤‍🩹' => 'trwsio calon',
    '👁‍🗨' => 'llygad mewn cwmwl',
    '🧔‍♂' => 'dyn: barf',
    '👱‍♂' => 'dyn â gwallt golau',
    '🧔‍♀' => 'menyw: barf',
    '👱‍♀' => 'menyw â gwallt golau',
    '🙍‍♂' => 'dyn yn gwgu',
    '🙍‍♀' => 'menyw yn gwgu',
    '🙎‍♂' => 'dyn yn pwdu',
    '🙎‍♀' => 'menyw yn pwdu',
    '🙅‍♂' => 'dyn yn ystumio nad yw’n iawn',
    '🙅‍♀' => 'menyw yn ystumio nad yw’n iawn',
    '🙆‍♂' => 'dyn yn ystumio iawn',
    '🙆‍♀' => 'menyw yn ystumio iawn',
    '💁‍♂' => 'dyn yn gwyro ei law',
    '💁‍♀' => 'menyw yn gwyro ei llaw',
    '🙋‍♂' => 'dyn yn codi ei law',
    '🙋‍♀' => 'menyw yn codi ei llaw',
    '🧏‍♂' => 'dyn byddar',
    '🧏‍♀' => 'menyw fyddar',
    '🙇‍♂' => 'dyn yn ymgrymu’n isel',
    '🙇‍♀' => 'menyw yn ymgrymu’n isel',
    '🤦‍♂' => 'dyn yn codi cledr i’w wyneb',
    '🤦‍♀' => 'menyw yn codi cledr i’w wyneb',
    '🤷‍♂' => 'dyn yn codi gwar',
    '🤷‍♀' => 'menyw yn codi gwar',
    '🧑‍⚕' => 'gweithiwr iechyd',
    '👨‍⚕' => 'gweithiwr iechyd gwrywaidd',
    '👩‍⚕' => 'gweithiwr iechyd benywaidd',
    '🧑‍🎓' => 'person sy’n astudio',
    '👨‍🎓' => 'myfyriwr',
    '👩‍🎓' => 'myfyrwraig',
    '🧑‍🏫' => 'person sy’n addysgu',
    '👨‍🏫' => 'athro',
    '👩‍🏫' => 'athrawes',
    '🧑‍⚖' => 'person sy’n barnu',
    '👨‍⚖' => 'barnwr',
    '👩‍⚖' => 'barnwres',
    '🧑‍🌾' => 'person sy’n ffermio',
    '👨‍🌾' => 'ffermwr',
    '👩‍🌾' => 'ffarmwraig',
    '🧑‍🍳' => 'person sy’n coginio',
    '👨‍🍳' => 'cogydd',
    '👩‍🍳' => 'cogyddes',
    '🧑‍🔧' => 'mecanig',
    '👨‍🔧' => 'peiriannydd gwrywaidd',
    '👩‍🔧' => 'peiriannydd benywaidd',
    '🧑‍🏭' => 'person sy’n gweithio mewn ffatri',
    '👨‍🏭' => 'gweithiwr ffatri',
    '👩‍🏭' => 'gweithwraig ffatri',
    '🧑‍💼' => 'gweithiwr swyddfa',
    '👨‍💼' => 'gweithiwr swyddfa gwrywaidd',
    '👩‍💼' => 'gweithiwr swyddfa benywaidd',
    '🧑‍🔬' => 'person sy’n ymwneud â gwyddoniaeth',
    '👨‍🔬' => 'gwyddonydd',
    '👩‍🔬' => 'gwyddonwraig',
    '🧑‍💻' => 'technolegydd',
    '👨‍💻' => 'technolegwr',
    '👩‍💻' => 'technolegwraig',
    '🧑‍🎤' => 'person sy’n canu',
    '👨‍🎤' => 'cantor',
    '👩‍🎤' => 'cantores',
    '🧑‍🎨' => 'artist',
    '👨‍🎨' => 'arlunydd',
    '👩‍🎨' => 'arlunwraig',
    '🧑‍✈' => 'peilot',
    '👨‍✈' => 'peilot gwrywaidd',
    '👩‍✈' => 'peilot benywaidd',
    '🧑‍🚀' => 'gofod-deithiwr',
    '👨‍🚀' => 'gofodwr',
    '👩‍🚀' => 'gofodwraig',
    '🧑‍🚒' => 'diffoddwr tân',
    '👨‍🚒' => 'dyn tân',
    '👩‍🚒' => 'menyw tân',
    '👮‍♂' => 'swyddog heddlu gwrywaidd',
    '👮‍♀' => 'swyddog heddlu benywaidd',
    '🕵‍♂' => 'ditectif gwrywaidd',
    '🕵‍♀' => 'ditectif benywaidd',
    '💂‍♂' => 'gwarchodydd gwrywaidd',
    '💂‍♀' => 'gwarchodydd benywaidd',
    '👷‍♂' => 'gweithiwr adeiladu gwrywaidd',
    '👷‍♀' => 'gweithiwr adeiladu benywaidd',
    '👳‍♂' => 'dyn â thwrban',
    '👳‍♀' => 'menyw â thwrban',
    '🤵‍♂' => 'dyn mewn siaced ginio',
    '🤵‍♀' => 'menyw mewn siaced ginio',
    '👰‍♂' => 'dyn yn gwisgo llen',
    '👰‍♀' => 'menyw yn gwisgo llen',
    '👩‍🍼' => 'menyw yn bwydo babi',
    '👨‍🍼' => 'dyn yn bwydo babi',
    '🧑‍🍼' => 'person yn bwydo babi',
    '🧑‍🎄' => 'mx claus',
    '🦸‍♂' => 'archarwr gwrywaidd',
    '🦸‍♀' => 'archarwr benywaidd',
    '🦹‍♂' => 'archleidr gwrywaidd',
    '🦹‍♀' => 'archleidr benywaidd',
    '🧙‍♂' => 'dewin gwrywaidd',
    '🧙‍♀' => 'dewin benywaidd',
    '🧚‍♂' => 'tylwythen teg',
    '🧚‍♀' => 'tylwythen deg',
    '🧛‍♂' => 'fampir gwrywaidd',
    '🧛‍♀' => 'fampir benywaidd',
    '🧜‍♂' => 'morwas',
    '🧜‍♀' => 'môr-forwyn',
    '🧝‍♂' => 'coblyn gwrwywaidd',
    '🧝‍♀' => 'coblyn benywaidd',
    '🧞‍♂' => 'genie gwrywaidd',
    '🧞‍♀' => 'genie benywaidd',
    '🧟‍♂' => 'sombi gwrywaidd',
    '🧟‍♀' => 'sombi benywaidd',
    '💆‍♂' => 'dyn yn derbyn tyluniad i’w wyneb',
    '💆‍♀' => 'menyw yn derbyn tyluniad i’w wyneb',
    '💇‍♂' => 'dyn yn cael ei wallt wedi’u torri',
    '💇‍♀' => 'menyw yn cael ei gwallt wedi’u torri',
    '🚶‍♂' => 'dyn yn cerdded',
    '🚶‍♀' => 'menyw yn cerdded',
    '🧍‍♂' => 'dyn yn sefyll',
    '🧍‍♀' => 'menyw yn sefyll',
    '🧎‍♂' => 'dyn yn penlinio',
    '🧎‍♀' => 'menyw yn penlinio',
    '🧑‍🦯' => 'person â ffon gerdded',
    '👨‍🦯' => 'dyn â ffon wen',
    '👩‍🦯' => 'menyw â ffon wen',
    '🧑‍🦼' => 'person mewn cadair olwyn drydan',
    '👨‍🦼' => 'dyn mewn cadair olwyn fodur',
    '👩‍🦼' => 'menyw mewn cadair olwyn fodur',
    '🧑‍🦽' => 'person mewn cadair olwyn â llaw',
    '👨‍🦽' => 'dyn mewn cadair olwyn',
    '👩‍🦽' => 'menyw mewn cadair olwyn',
    '🏃‍♂' => 'dyn yn rhedeg',
    '🏃‍♀' => 'menyw yn rhedeg',
    '🧑‍🩰' => 'dawnsiwr/dawnswraig bale',
    '👯‍♂' => 'dyn mewn parti',
    '👯‍♀' => 'menyw mewn parti',
    '🧖‍♂' => 'dyn mewn ystafell llawn stêm',
    '🧖‍♀' => 'menyw mewn ystafell llawn stêm',
    '🧗‍♂' => 'dyn yn dringo',
    '🧗‍♀' => 'menyw yn dringo',
    '🏌‍♂' => 'dyn yn chwarae golff',
    '🏌‍♀' => 'menyw yn chwarae golff',
    '🏄‍♂' => 'dyn yn syrffio',
    '🏄‍♀' => 'menyw yn syrffio',
    '🚣‍♂' => 'dyn yn rhwyfo cwch',
    '🚣‍♀' => 'menyw yn rhwyfo cwch',
    '🏊‍♂' => 'dyn yn nofio',
    '🏊‍♀' => 'menyw yn nofio',
    '⛹‍♂' => 'dyn â phêl',
    '⛹‍♀' => 'menyw â phêl',
    '🏋‍♂' => 'dyn yn codi pwysau',
    '🏋‍♀' => 'menyw yn codi pwysau',
    '🚴‍♂' => 'dyn yn beicio',
    '🚴‍♀' => 'menyw yn beicio',
    '🚵‍♂' => 'dyn yn beicio mynydd',
    '🚵‍♀' => 'menyw yn beicio mynydd',
    '🤸‍♂' => 'dyn yn gwneud olwyn dro',
    '🤸‍♀' => 'menyw yn gwneud olwyn dro',
    '🤼‍♂' => 'dynion yn reslo',
    '🤼‍♀' => 'menywod yn reslo',
    '🤽‍♂' => 'dyn yn chwarae polo dŵr',
    '🤽‍♀' => 'menyw yn chwarae polo dŵr',
    '🤾‍♂' => 'dyn yn chwarae pêl law',
    '🤾‍♀' => 'menyw yn chwarae pêl law',
    '🤹‍♂' => 'dyn yn jyglo',
    '🤹‍♀' => 'menyw yn jyglo',
    '🧘‍♂' => 'dyn mewn ystum lingroes',
    '🧘‍♀' => 'menyw mewn ystum lingroes',
    '🧑‍🧒' => 'teulu: oedolyn, plentyn',
    '🐕‍🦺' => 'ci cymorth',
    '🐈‍⬛' => 'cath ddu',
    '🐻‍❄' => 'arth wen',
    '🐦‍⬛' => 'aderyn du',
    '🐦‍🔥' => 'ffenics',
    '🍋‍🟩' => 'leim',
    '🍄‍🟫' => 'madarch brown',
    '⛓‍💥' => 'cadwyn wedi torri',
    '🏳‍🌈' => 'baner enfys',
    '🏳‍⚧' => 'baner las, pinc a gwyn',
    '🏴‍☠' => 'baner môr-leidr',
    '👋🏻' => 'llaw yn chwifio: arlliw croen golau',
    '👋🏼' => 'llaw yn chwifio: arlliw croen canolig-golau',
    '👋🏽' => 'llaw yn chwifio: arlliw croen canolog',
    '👋🏾' => 'llaw yn chwifio: arlliw croen canolig-tywyll',
    '👋🏿' => 'llaw yn chwifio: arlliw croen tywyll',
    '🤚🏻' => 'cefn llaw wedi’i chodi: arlliw croen golau',
    '🤚🏼' => 'cefn llaw wedi’i chodi: arlliw croen canolig-golau',
    '🤚🏽' => 'cefn llaw wedi’i chodi: arlliw croen canolog',
    '🤚🏾' => 'cefn llaw wedi’i chodi: arlliw croen canolig-tywyll',
    '🤚🏿' => 'cefn llaw wedi’i chodi: arlliw croen tywyll',
    '🖐🏻' => 'llaw wedi ei chodi â bysedd wedi eu lledu: arlliw croen golau',
    '🖐🏼' => 'llaw wedi ei chodi â bysedd wedi eu lledu: arlliw croen canolig-golau',
    '🖐🏽' => 'llaw wedi ei chodi â bysedd wedi eu lledu: arlliw croen canolog',
    '🖐🏾' => 'llaw wedi ei chodi â bysedd wedi eu lledu: arlliw croen canolig-tywyll',
    '🖐🏿' => 'llaw wedi ei chodi â bysedd wedi eu lledu: arlliw croen tywyll',
    '✋🏻' => 'llaw wedi codi: arlliw croen golau',
    '✋🏼' => 'llaw wedi codi: arlliw croen canolig-golau',
    '✋🏽' => 'llaw wedi codi: arlliw croen canolog',
    '✋🏾' => 'llaw wedi codi: arlliw croen canolig-tywyll',
    '✋🏿' => 'llaw wedi codi: arlliw croen tywyll',
    '🖖🏻' => 'saliwt fulcanaidd: arlliw croen golau',
    '🖖🏼' => 'saliwt fulcanaidd: arlliw croen canolig-golau',
    '🖖🏽' => 'saliwt fulcanaidd: arlliw croen canolog',
    '🖖🏾' => 'saliwt fulcanaidd: arlliw croen canolig-tywyll',
    '🖖🏿' => 'saliwt fulcanaidd: arlliw croen tywyll',
    '🫱🏻' => 'llaw i’r dde: arlliw croen golau',
    '🫱🏼' => 'llaw i’r dde: arlliw croen canolig-golau',
    '🫱🏽' => 'llaw i’r dde: arlliw croen canolog',
    '🫱🏾' => 'llaw i’r dde: arlliw croen canolig-tywyll',
    '🫱🏿' => 'llaw i’r dde: arlliw croen tywyll',
    '🫲🏻' => 'llaw i’r chwith: arlliw croen golau',
    '🫲🏼' => 'llaw i’r chwith: arlliw croen canolig-golau',
    '🫲🏽' => 'llaw i’r chwith: arlliw croen canolog',
    '🫲🏾' => 'llaw i’r chwith: arlliw croen canolig-tywyll',
    '🫲🏿' => 'llaw i’r chwith: arlliw croen tywyll',
    '🫳🏻' => 'llaw palmwydd i lawr: arlliw croen golau',
    '🫳🏼' => 'llaw palmwydd i lawr: arlliw croen canolig-golau',
    '🫳🏽' => 'llaw palmwydd i lawr: arlliw croen canolog',
    '🫳🏾' => 'llaw palmwydd i lawr: arlliw croen canolig-tywyll',
    '🫳🏿' => 'llaw palmwydd i lawr: arlliw croen tywyll',
    '🫴🏻' => 'llaw palmwydd i fyny: arlliw croen golau',
    '🫴🏼' => 'llaw palmwydd i fyny: arlliw croen canolig-golau',
    '🫴🏽' => 'llaw palmwydd i fyny: arlliw croen canolog',
    '🫴🏾' => 'llaw palmwydd i fyny: arlliw croen canolig-tywyll',
    '🫴🏿' => 'llaw palmwydd i fyny: arlliw croen tywyll',
    '🫷🏻' => 'llaw yn gwthio i’r chwith: arlliw croen golau',
    '🫷🏼' => 'llaw yn gwthio i’r chwith: arlliw croen canolig-golau',
    '🫷🏽' => 'llaw yn gwthio i’r chwith: arlliw croen canolog',
    '🫷🏾' => 'llaw yn gwthio i’r chwith: arlliw croen canolig-tywyll',
    '🫷🏿' => 'llaw yn gwthio i’r chwith: arlliw croen tywyll',
    '🫸🏻' => 'llaw yn gwthio i’r dde: arlliw croen golau',
    '🫸🏼' => 'llaw yn gwthio i’r dde: arlliw croen canolig-golau',
    '🫸🏽' => 'llaw yn gwthio i’r dde: arlliw croen canolog',
    '🫸🏾' => 'llaw yn gwthio i’r dde: arlliw croen canolig-tywyll',
    '🫸🏿' => 'llaw yn gwthio i’r dde: arlliw croen tywyll',
    '👌🏻' => 'llaw ocê: arlliw croen golau',
    '👌🏼' => 'llaw ocê: arlliw croen canolig-golau',
    '👌🏽' => 'llaw ocê: arlliw croen canolog',
    '👌🏾' => 'llaw ocê: arlliw croen canolig-tywyll',
    '👌🏿' => 'llaw ocê: arlliw croen tywyll',
    '🤌🏻' => 'bysedd wedi’u pinsio: arlliw croen golau',
    '🤌🏼' => 'bysedd wedi’u pinsio: arlliw croen canolig-golau',
    '🤌🏽' => 'bysedd wedi’u pinsio: arlliw croen canolog',
    '🤌🏾' => 'bysedd wedi’u pinsio: arlliw croen canolig-tywyll',
    '🤌🏿' => 'bysedd wedi’u pinsio: arlliw croen tywyll',
    '🤏🏻' => 'bysedd yn pinshio: arlliw croen golau',
    '🤏🏼' => 'bysedd yn pinshio: arlliw croen canolig-golau',
    '🤏🏽' => 'bysedd yn pinshio: arlliw croen canolog',
    '🤏🏾' => 'bysedd yn pinshio: arlliw croen canolig-tywyll',
    '🤏🏿' => 'bysedd yn pinshio: arlliw croen tywyll',
    '✌🏻' => 'llaw fuddugol: arlliw croen golau',
    '✌🏼' => 'llaw fuddugol: arlliw croen canolig-golau',
    '✌🏽' => 'llaw fuddugol: arlliw croen canolog',
    '✌🏾' => 'llaw fuddugol: arlliw croen canolig-tywyll',
    '✌🏿' => 'llaw fuddugol: arlliw croen tywyll',
    '🤞🏻' => 'bysedd wedi’u croesi: arlliw croen golau',
    '🤞🏼' => 'bysedd wedi’u croesi: arlliw croen canolig-golau',
    '🤞🏽' => 'bysedd wedi’u croesi: arlliw croen canolog',
    '🤞🏾' => 'bysedd wedi’u croesi: arlliw croen canolig-tywyll',
    '🤞🏿' => 'bysedd wedi’u croesi: arlliw croen tywyll',
    '🫰🏻' => 'llaw gyda bys mynegai a bawd wedi’u croesi: arlliw croen golau',
    '🫰🏼' => 'llaw gyda bys mynegai a bawd wedi’u croesi: arlliw croen canolig-golau',
    '🫰🏽' => 'llaw gyda bys mynegai a bawd wedi’u croesi: arlliw croen canolog',
    '🫰🏾' => 'llaw gyda bys mynegai a bawd wedi’u croesi: arlliw croen canolig-tywyll',
    '🫰🏿' => 'llaw gyda bys mynegai a bawd wedi’u croesi: arlliw croen tywyll',
    '🤟🏻' => 'arwydd caru ti: arlliw croen golau',
    '🤟🏼' => 'arwydd caru ti: arlliw croen canolig-golau',
    '🤟🏽' => 'arwydd caru ti: arlliw croen canolog',
    '🤟🏾' => 'arwydd caru ti: arlliw croen canolig-tywyll',
    '🤟🏿' => 'arwydd caru ti: arlliw croen tywyll',
    '🤘🏻' => 'arwydd y cyrn: arlliw croen golau',
    '🤘🏼' => 'arwydd y cyrn: arlliw croen canolig-golau',
    '🤘🏽' => 'arwydd y cyrn: arlliw croen canolog',
    '🤘🏾' => 'arwydd y cyrn: arlliw croen canolig-tywyll',
    '🤘🏿' => 'arwydd y cyrn: arlliw croen tywyll',
    '🤙🏻' => 'llaw ffonia fi: arlliw croen golau',
    '🤙🏼' => 'llaw ffonia fi: arlliw croen canolig-golau',
    '🤙🏽' => 'llaw ffonia fi: arlliw croen canolog',
    '🤙🏾' => 'llaw ffonia fi: arlliw croen canolig-tywyll',
    '🤙🏿' => 'llaw ffonia fi: arlliw croen tywyll',
    '👈🏻' => 'mynegfys yr wrthlaw yn pwyntio i’r chwith: arlliw croen golau',
    '👈🏼' => 'mynegfys yr wrthlaw yn pwyntio i’r chwith: arlliw croen canolig-golau',
    '👈🏽' => 'mynegfys yr wrthlaw yn pwyntio i’r chwith: arlliw croen canolog',
    '👈🏾' => 'mynegfys yr wrthlaw yn pwyntio i’r chwith: arlliw croen canolig-tywyll',
    '👈🏿' => 'mynegfys yr wrthlaw yn pwyntio i’r chwith: arlliw croen tywyll',
    '👉🏻' => 'mynegfys yr wrthlaw yn pwyntio i’r dde: arlliw croen golau',
    '👉🏼' => 'mynegfys yr wrthlaw yn pwyntio i’r dde: arlliw croen canolig-golau',
    '👉🏽' => 'mynegfys yr wrthlaw yn pwyntio i’r dde: arlliw croen canolog',
    '👉🏾' => 'mynegfys yr wrthlaw yn pwyntio i’r dde: arlliw croen canolig-tywyll',
    '👉🏿' => 'mynegfys yr wrthlaw yn pwyntio i’r dde: arlliw croen tywyll',
    '👆🏻' => 'mynegfys yr wrthlaw yn pwyntio i fyny: arlliw croen golau',
    '👆🏼' => 'mynegfys yr wrthlaw yn pwyntio i fyny: arlliw croen canolig-golau',
    '👆🏽' => 'mynegfys yr wrthlaw yn pwyntio i fyny: arlliw croen canolog',
    '👆🏾' => 'mynegfys yr wrthlaw yn pwyntio i fyny: arlliw croen canolig-tywyll',
    '👆🏿' => 'mynegfys yr wrthlaw yn pwyntio i fyny: arlliw croen tywyll',
    '🖕🏻' => 'bys canol: arlliw croen golau',
    '🖕🏼' => 'bys canol: arlliw croen canolig-golau',
    '🖕🏽' => 'bys canol: arlliw croen canolog',
    '🖕🏾' => 'bys canol: arlliw croen canolig-tywyll',
    '🖕🏿' => 'bys canol: arlliw croen tywyll',
    '👇🏻' => 'mynegfys yr wrthlaw yn pwyntio i lawr: arlliw croen golau',
    '👇🏼' => 'mynegfys yr wrthlaw yn pwyntio i lawr: arlliw croen canolig-golau',
    '👇🏽' => 'mynegfys yr wrthlaw yn pwyntio i lawr: arlliw croen canolog',
    '👇🏾' => 'mynegfys yr wrthlaw yn pwyntio i lawr: arlliw croen canolig-tywyll',
    '👇🏿' => 'mynegfys yr wrthlaw yn pwyntio i lawr: arlliw croen tywyll',
    '☝🏻' => 'mynegfys yn pwyntio i fyny: arlliw croen golau',
    '☝🏼' => 'mynegfys yn pwyntio i fyny: arlliw croen canolig-golau',
    '☝🏽' => 'mynegfys yn pwyntio i fyny: arlliw croen canolog',
    '☝🏾' => 'mynegfys yn pwyntio i fyny: arlliw croen canolig-tywyll',
    '☝🏿' => 'mynegfys yn pwyntio i fyny: arlliw croen tywyll',
    '🫵🏻' => 'bys mynegai yn pwyntio at y gwyliwr: arlliw croen golau',
    '🫵🏼' => 'bys mynegai yn pwyntio at y gwyliwr: arlliw croen canolig-golau',
    '🫵🏽' => 'bys mynegai yn pwyntio at y gwyliwr: arlliw croen canolog',
    '🫵🏾' => 'bys mynegai yn pwyntio at y gwyliwr: arlliw croen canolig-tywyll',
    '🫵🏿' => 'bys mynegai yn pwyntio at y gwyliwr: arlliw croen tywyll',
    '👍🏻' => 'bys bawd i fyny: arlliw croen golau',
    '👍🏼' => 'bys bawd i fyny: arlliw croen canolig-golau',
    '👍🏽' => 'bys bawd i fyny: arlliw croen canolog',
    '👍🏾' => 'bys bawd i fyny: arlliw croen canolig-tywyll',
    '👍🏿' => 'bys bawd i fyny: arlliw croen tywyll',
    '👎🏻' => 'bys bawd i lawr: arlliw croen golau',
    '👎🏼' => 'bys bawd i lawr: arlliw croen canolig-golau',
    '👎🏽' => 'bys bawd i lawr: arlliw croen canolog',
    '👎🏾' => 'bys bawd i lawr: arlliw croen canolig-tywyll',
    '👎🏿' => 'bys bawd i lawr: arlliw croen tywyll',
    '✊🏻' => 'dwrn wedi codi: arlliw croen golau',
    '✊🏼' => 'dwrn wedi codi: arlliw croen canolig-golau',
    '✊🏽' => 'dwrn wedi codi: arlliw croen canolog',
    '✊🏾' => 'dwrn wedi codi: arlliw croen canolig-tywyll',
    '✊🏿' => 'dwrn wedi codi: arlliw croen tywyll',
    '👊🏻' => 'dwrn yn agosáu: arlliw croen golau',
    '👊🏼' => 'dwrn yn agosáu: arlliw croen canolig-golau',
    '👊🏽' => 'dwrn yn agosáu: arlliw croen canolog',
    '👊🏾' => 'dwrn yn agosáu: arlliw croen canolig-tywyll',
    '👊🏿' => 'dwrn yn agosáu: arlliw croen tywyll',
    '🤛🏻' => 'dwrn tua’r chwith: arlliw croen golau',
    '🤛🏼' => 'dwrn tua’r chwith: arlliw croen canolig-golau',
    '🤛🏽' => 'dwrn tua’r chwith: arlliw croen canolog',
    '🤛🏾' => 'dwrn tua’r chwith: arlliw croen canolig-tywyll',
    '🤛🏿' => 'dwrn tua’r chwith: arlliw croen tywyll',
    '🤜🏻' => 'dwrn tua’r dde: arlliw croen golau',
    '🤜🏼' => 'dwrn tua’r dde: arlliw croen canolig-golau',
    '🤜🏽' => 'dwrn tua’r dde: arlliw croen canolog',
    '🤜🏾' => 'dwrn tua’r dde: arlliw croen canolig-tywyll',
    '🤜🏿' => 'dwrn tua’r dde: arlliw croen tywyll',
    '👏🏻' => 'dwylo yn curo: arlliw croen golau',
    '👏🏼' => 'dwylo yn curo: arlliw croen canolig-golau',
    '👏🏽' => 'dwylo yn curo: arlliw croen canolog',
    '👏🏾' => 'dwylo yn curo: arlliw croen canolig-tywyll',
    '👏🏿' => 'dwylo yn curo: arlliw croen tywyll',
    '🙌🏻' => 'person yn codi dwylo: arlliw croen golau',
    '🙌🏼' => 'person yn codi dwylo: arlliw croen canolig-golau',
    '🙌🏽' => 'person yn codi dwylo: arlliw croen canolog',
    '🙌🏾' => 'person yn codi dwylo: arlliw croen canolig-tywyll',
    '🙌🏿' => 'person yn codi dwylo: arlliw croen tywyll',
    '🫶🏻' => 'dwylo calon: arlliw croen golau',
    '🫶🏼' => 'dwylo calon: arlliw croen canolig-golau',
    '🫶🏽' => 'dwylo calon: arlliw croen canolog',
    '🫶🏾' => 'dwylo calon: arlliw croen canolig-tywyll',
    '🫶🏿' => 'dwylo calon: arlliw croen tywyll',
    '👐🏻' => 'dwylo agored: arlliw croen golau',
    '👐🏼' => 'dwylo agored: arlliw croen canolig-golau',
    '👐🏽' => 'dwylo agored: arlliw croen canolog',
    '👐🏾' => 'dwylo agored: arlliw croen canolig-tywyll',
    '👐🏿' => 'dwylo agored: arlliw croen tywyll',
    '🤲🏻' => 'cledrau dwylo yn yr awyr gyda’u gilydd: arlliw croen golau',
    '🤲🏼' => 'cledrau dwylo yn yr awyr gyda’u gilydd: arlliw croen canolig-golau',
    '🤲🏽' => 'cledrau dwylo yn yr awyr gyda’u gilydd: arlliw croen canolog',
    '🤲🏾' => 'cledrau dwylo yn yr awyr gyda’u gilydd: arlliw croen canolig-tywyll',
    '🤲🏿' => 'cledrau dwylo yn yr awyr gyda’u gilydd: arlliw croen tywyll',
    '🤝🏻' => 'ysgwyd dwylo: arlliw croen golau',
    '🤝🏼' => 'ysgwyd dwylo: arlliw croen canolig-golau',
    '🤝🏽' => 'ysgwyd dwylo: arlliw croen canolog',
    '🤝🏾' => 'ysgwyd dwylo: arlliw croen canolig-tywyll',
    '🤝🏿' => 'ysgwyd dwylo: arlliw croen tywyll',
    '🙏🏻' => 'dwylo wedi plygu: arlliw croen golau',
    '🙏🏼' => 'dwylo wedi plygu: arlliw croen canolig-golau',
    '🙏🏽' => 'dwylo wedi plygu: arlliw croen canolog',
    '🙏🏾' => 'dwylo wedi plygu: arlliw croen canolig-tywyll',
    '🙏🏿' => 'dwylo wedi plygu: arlliw croen tywyll',
    '✍🏻' => 'dwylo yn ysgrifennu: arlliw croen golau',
    '✍🏼' => 'dwylo yn ysgrifennu: arlliw croen canolig-golau',
    '✍🏽' => 'dwylo yn ysgrifennu: arlliw croen canolog',
    '✍🏾' => 'dwylo yn ysgrifennu: arlliw croen canolig-tywyll',
    '✍🏿' => 'dwylo yn ysgrifennu: arlliw croen tywyll',
    '💅🏻' => 'farnais ewinedd: arlliw croen golau',
    '💅🏼' => 'farnais ewinedd: arlliw croen canolig-golau',
    '💅🏽' => 'farnais ewinedd: arlliw croen canolog',
    '💅🏾' => 'farnais ewinedd: arlliw croen canolig-tywyll',
    '💅🏿' => 'farnais ewinedd: arlliw croen tywyll',
    '🤳🏻' => 'hunlun: arlliw croen golau',
    '🤳🏼' => 'hunlun: arlliw croen canolig-golau',
    '🤳🏽' => 'hunlun: arlliw croen canolog',
    '🤳🏾' => 'hunlun: arlliw croen canolig-tywyll',
    '🤳🏿' => 'hunlun: arlliw croen tywyll',
    '💪🏻' => 'cyhyrau deuben wedi eu hystwytho: arlliw croen golau',
    '💪🏼' => 'cyhyrau deuben wedi eu hystwytho: arlliw croen canolig-golau',
    '💪🏽' => 'cyhyrau deuben wedi eu hystwytho: arlliw croen canolog',
    '💪🏾' => 'cyhyrau deuben wedi eu hystwytho: arlliw croen canolig-tywyll',
    '💪🏿' => 'cyhyrau deuben wedi eu hystwytho: arlliw croen tywyll',
    '🦵🏻' => 'coes: arlliw croen golau',
    '🦵🏼' => 'coes: arlliw croen canolig-golau',
    '🦵🏽' => 'coes: arlliw croen canolog',
    '🦵🏾' => 'coes: arlliw croen canolig-tywyll',
    '🦵🏿' => 'coes: arlliw croen tywyll',
    '🦶🏻' => 'troed: arlliw croen golau',
    '🦶🏼' => 'troed: arlliw croen canolig-golau',
    '🦶🏽' => 'troed: arlliw croen canolog',
    '🦶🏾' => 'troed: arlliw croen canolig-tywyll',
    '🦶🏿' => 'troed: arlliw croen tywyll',
    '👂🏻' => 'clust: arlliw croen golau',
    '👂🏼' => 'clust: arlliw croen canolig-golau',
    '👂🏽' => 'clust: arlliw croen canolog',
    '👂🏾' => 'clust: arlliw croen canolig-tywyll',
    '👂🏿' => 'clust: arlliw croen tywyll',
    '🦻🏻' => 'clust gyda chymorth clyw: arlliw croen golau',
    '🦻🏼' => 'clust gyda chymorth clyw: arlliw croen canolig-golau',
    '🦻🏽' => 'clust gyda chymorth clyw: arlliw croen canolog',
    '🦻🏾' => 'clust gyda chymorth clyw: arlliw croen canolig-tywyll',
    '🦻🏿' => 'clust gyda chymorth clyw: arlliw croen tywyll',
    '👃🏻' => 'trwyn: arlliw croen golau',
    '👃🏼' => 'trwyn: arlliw croen canolig-golau',
    '👃🏽' => 'trwyn: arlliw croen canolog',
    '👃🏾' => 'trwyn: arlliw croen canolig-tywyll',
    '👃🏿' => 'trwyn: arlliw croen tywyll',
    '👶🏻' => 'babi: arlliw croen golau',
    '👶🏼' => 'babi: arlliw croen canolig-golau',
    '👶🏽' => 'babi: arlliw croen canolog',
    '👶🏾' => 'babi: arlliw croen canolig-tywyll',
    '👶🏿' => 'babi: arlliw croen tywyll',
    '🧒🏻' => 'plentyn: arlliw croen golau',
    '🧒🏼' => 'plentyn: arlliw croen canolig-golau',
    '🧒🏽' => 'plentyn: arlliw croen canolog',
    '🧒🏾' => 'plentyn: arlliw croen canolig-tywyll',
    '🧒🏿' => 'plentyn: arlliw croen tywyll',
    '👦🏻' => 'bachgen: arlliw croen golau',
    '👦🏼' => 'bachgen: arlliw croen canolig-golau',
    '👦🏽' => 'bachgen: arlliw croen canolog',
    '👦🏾' => 'bachgen: arlliw croen canolig-tywyll',
    '👦🏿' => 'bachgen: arlliw croen tywyll',
    '👧🏻' => 'merch: arlliw croen golau',
    '👧🏼' => 'merch: arlliw croen canolig-golau',
    '👧🏽' => 'merch: arlliw croen canolog',
    '👧🏾' => 'merch: arlliw croen canolig-tywyll',
    '👧🏿' => 'merch: arlliw croen tywyll',
    '🧑🏻' => 'person: arlliw croen golau',
    '🧑🏼' => 'person: arlliw croen canolig-golau',
    '🧑🏽' => 'person: arlliw croen canolog',
    '🧑🏾' => 'person: arlliw croen canolig-tywyll',
    '🧑🏿' => 'person: arlliw croen tywyll',
    '👱🏻' => 'person â gwallt golau: arlliw croen golau',
    '👱🏼' => 'person â gwallt golau: arlliw croen canolig-golau',
    '👱🏽' => 'person â gwallt golau: arlliw croen canolog',
    '👱🏾' => 'person â gwallt golau: arlliw croen canolig-tywyll',
    '👱🏿' => 'person â gwallt golau: arlliw croen tywyll',
    '👨🏻' => 'dyn: arlliw croen golau',
    '👨🏼' => 'dyn: arlliw croen canolig-golau',
    '👨🏽' => 'dyn: arlliw croen canolog',
    '👨🏾' => 'dyn: arlliw croen canolig-tywyll',
    '👨🏿' => 'dyn: arlliw croen tywyll',
    '🧔🏻' => 'person: arlliw croen golau, barf',
    '🧔🏼' => 'person: arlliw croen canolig-golau, barf',
    '🧔🏽' => 'person: arlliw croen canolog, barf',
    '🧔🏾' => 'person: arlliw croen canolig-tywyll, barf',
    '🧔🏿' => 'person: arlliw croen tywyll, barf',
    '👩🏻' => 'menyw: arlliw croen golau',
    '👩🏼' => 'menyw: arlliw croen canolig-golau',
    '👩🏽' => 'menyw: arlliw croen canolog',
    '👩🏾' => 'menyw: arlliw croen canolig-tywyll',
    '👩🏿' => 'menyw: arlliw croen tywyll',
    '🧓🏻' => 'oedolyn oedranus: arlliw croen golau',
    '🧓🏼' => 'oedolyn oedranus: arlliw croen canolig-golau',
    '🧓🏽' => 'oedolyn oedranus: arlliw croen canolog',
    '🧓🏾' => 'oedolyn oedranus: arlliw croen canolig-tywyll',
    '🧓🏿' => 'oedolyn oedranus: arlliw croen tywyll',
    '👴🏻' => 'hen ddyn: arlliw croen golau',
    '👴🏼' => 'hen ddyn: arlliw croen canolig-golau',
    '👴🏽' => 'hen ddyn: arlliw croen canolog',
    '👴🏾' => 'hen ddyn: arlliw croen canolig-tywyll',
    '👴🏿' => 'hen ddyn: arlliw croen tywyll',
    '👵🏻' => 'hen fenyw: arlliw croen golau',
    '👵🏼' => 'hen fenyw: arlliw croen canolig-golau',
    '👵🏽' => 'hen fenyw: arlliw croen canolog',
    '👵🏾' => 'hen fenyw: arlliw croen canolig-tywyll',
    '👵🏿' => 'hen fenyw: arlliw croen tywyll',
    '🙍🏻' => 'person yn gwgu: arlliw croen golau',
    '🙍🏼' => 'person yn gwgu: arlliw croen canolig-golau',
    '🙍🏽' => 'person yn gwgu: arlliw croen canolog',
    '🙍🏾' => 'person yn gwgu: arlliw croen canolig-tywyll',
    '🙍🏿' => 'person yn gwgu: arlliw croen tywyll',
    '🙎🏻' => 'person yn pwdu: arlliw croen golau',
    '🙎🏼' => 'person yn pwdu: arlliw croen canolig-golau',
    '🙎🏽' => 'person yn pwdu: arlliw croen canolog',
    '🙎🏾' => 'person yn pwdu: arlliw croen canolig-tywyll',
    '🙎🏿' => 'person yn pwdu: arlliw croen tywyll',
    '🙅🏻' => 'person yn ystumio nad yw’n iawn: arlliw croen golau',
    '🙅🏼' => 'person yn ystumio nad yw’n iawn: arlliw croen canolig-golau',
    '🙅🏽' => 'person yn ystumio nad yw’n iawn: arlliw croen canolog',
    '🙅🏾' => 'person yn ystumio nad yw’n iawn: arlliw croen canolig-tywyll',
    '🙅🏿' => 'person yn ystumio nad yw’n iawn: arlliw croen tywyll',
    '🙆🏻' => 'person yn ystumio iawn: arlliw croen golau',
    '🙆🏼' => 'person yn ystumio iawn: arlliw croen canolig-golau',
    '🙆🏽' => 'person yn ystumio iawn: arlliw croen canolog',
    '🙆🏾' => 'person yn ystumio iawn: arlliw croen canolig-tywyll',
    '🙆🏿' => 'person yn ystumio iawn: arlliw croen tywyll',
    '💁🏻' => 'person yn gwyro llaw: arlliw croen golau',
    '💁🏼' => 'person yn gwyro llaw: arlliw croen canolig-golau',
    '💁🏽' => 'person yn gwyro llaw: arlliw croen canolog',
    '💁🏾' => 'person yn gwyro llaw: arlliw croen canolig-tywyll',
    '💁🏿' => 'person yn gwyro llaw: arlliw croen tywyll',
    '🙋🏻' => 'person yn codi llaw: arlliw croen golau',
    '🙋🏼' => 'person yn codi llaw: arlliw croen canolig-golau',
    '🙋🏽' => 'person yn codi llaw: arlliw croen canolog',
    '🙋🏾' => 'person yn codi llaw: arlliw croen canolig-tywyll',
    '🙋🏿' => 'person yn codi llaw: arlliw croen tywyll',
    '🧏🏻' => 'person byddar: arlliw croen golau',
    '🧏🏼' => 'person byddar: arlliw croen canolig-golau',
    '🧏🏽' => 'person byddar: arlliw croen canolog',
    '🧏🏾' => 'person byddar: arlliw croen canolig-tywyll',
    '🧏🏿' => 'person byddar: arlliw croen tywyll',
    '🙇🏻' => 'person yn ymgrymu: arlliw croen golau',
    '🙇🏼' => 'person yn ymgrymu: arlliw croen canolig-golau',
    '🙇🏽' => 'person yn ymgrymu: arlliw croen canolog',
    '🙇🏾' => 'person yn ymgrymu: arlliw croen canolig-tywyll',
    '🙇🏿' => 'person yn ymgrymu: arlliw croen tywyll',
    '🤦🏻' => 'cledr i’r wyneb: arlliw croen golau',
    '🤦🏼' => 'cledr i’r wyneb: arlliw croen canolig-golau',
    '🤦🏽' => 'cledr i’r wyneb: arlliw croen canolog',
    '🤦🏾' => 'cledr i’r wyneb: arlliw croen canolig-tywyll',
    '🤦🏿' => 'cledr i’r wyneb: arlliw croen tywyll',
    '🤷🏻' => 'codi gwar: arlliw croen golau',
    '🤷🏼' => 'codi gwar: arlliw croen canolig-golau',
    '🤷🏽' => 'codi gwar: arlliw croen canolog',
    '🤷🏾' => 'codi gwar: arlliw croen canolig-tywyll',
    '🤷🏿' => 'codi gwar: arlliw croen tywyll',
    '👮🏻' => 'heddwas: arlliw croen golau',
    '👮🏼' => 'heddwas: arlliw croen canolig-golau',
    '👮🏽' => 'heddwas: arlliw croen canolog',
    '👮🏾' => 'heddwas: arlliw croen canolig-tywyll',
    '👮🏿' => 'heddwas: arlliw croen tywyll',
    '🕵🏻' => 'ditectif: arlliw croen golau',
    '🕵🏼' => 'ditectif: arlliw croen canolig-golau',
    '🕵🏽' => 'ditectif: arlliw croen canolog',
    '🕵🏾' => 'ditectif: arlliw croen canolig-tywyll',
    '🕵🏿' => 'ditectif: arlliw croen tywyll',
    '💂🏻' => 'gwarchodfilwr: arlliw croen golau',
    '💂🏼' => 'gwarchodfilwr: arlliw croen canolig-golau',
    '💂🏽' => 'gwarchodfilwr: arlliw croen canolog',
    '💂🏾' => 'gwarchodfilwr: arlliw croen canolig-tywyll',
    '💂🏿' => 'gwarchodfilwr: arlliw croen tywyll',
    '🥷🏻' => 'ninja: arlliw croen golau',
    '🥷🏼' => 'ninja: arlliw croen canolig-golau',
    '🥷🏽' => 'ninja: arlliw croen canolog',
    '🥷🏾' => 'ninja: arlliw croen canolig-tywyll',
    '🥷🏿' => 'ninja: arlliw croen tywyll',
    '👷🏻' => 'adeiladwr: arlliw croen golau',
    '👷🏼' => 'adeiladwr: arlliw croen canolig-golau',
    '👷🏽' => 'adeiladwr: arlliw croen canolog',
    '👷🏾' => 'adeiladwr: arlliw croen canolig-tywyll',
    '👷🏿' => 'adeiladwr: arlliw croen tywyll',
    '🫅🏻' => 'person â choron: arlliw croen golau',
    '🫅🏼' => 'person â choron: arlliw croen canolig-golau',
    '🫅🏽' => 'person â choron: arlliw croen canolog',
    '🫅🏾' => 'person â choron: arlliw croen canolig-tywyll',
    '🫅🏿' => 'person â choron: arlliw croen tywyll',
    '🤴🏻' => 'tywysog: arlliw croen golau',
    '🤴🏼' => 'tywysog: arlliw croen canolig-golau',
    '🤴🏽' => 'tywysog: arlliw croen canolog',
    '🤴🏾' => 'tywysog: arlliw croen canolig-tywyll',
    '🤴🏿' => 'tywysog: arlliw croen tywyll',
    '👸🏻' => 'tywysoges: arlliw croen golau',
    '👸🏼' => 'tywysoges: arlliw croen canolig-golau',
    '👸🏽' => 'tywysoges: arlliw croen canolog',
    '👸🏾' => 'tywysoges: arlliw croen canolig-tywyll',
    '👸🏿' => 'tywysoges: arlliw croen tywyll',
    '👳🏻' => 'person yn gwisgo twrban: arlliw croen golau',
    '👳🏼' => 'person yn gwisgo twrban: arlliw croen canolig-golau',
    '👳🏽' => 'person yn gwisgo twrban: arlliw croen canolog',
    '👳🏾' => 'person yn gwisgo twrban: arlliw croen canolig-tywyll',
    '👳🏿' => 'person yn gwisgo twrban: arlliw croen tywyll',
    '👲🏻' => 'dyn â chap Tsieineaidd: arlliw croen golau',
    '👲🏼' => 'dyn â chap Tsieineaidd: arlliw croen canolig-golau',
    '👲🏽' => 'dyn â chap Tsieineaidd: arlliw croen canolog',
    '👲🏾' => 'dyn â chap Tsieineaidd: arlliw croen canolig-tywyll',
    '👲🏿' => 'dyn â chap Tsieineaidd: arlliw croen tywyll',
    '🧕🏻' => 'menyw â phensgarff: arlliw croen golau',
    '🧕🏼' => 'menyw â phensgarff: arlliw croen canolig-golau',
    '🧕🏽' => 'menyw â phensgarff: arlliw croen canolog',
    '🧕🏾' => 'menyw â phensgarff: arlliw croen canolig-tywyll',
    '🧕🏿' => 'menyw â phensgarff: arlliw croen tywyll',
    '🤵🏻' => 'person mewn siaced ginio: arlliw croen golau',
    '🤵🏼' => 'person mewn siaced ginio: arlliw croen canolig-golau',
    '🤵🏽' => 'person mewn siaced ginio: arlliw croen canolog',
    '🤵🏾' => 'person mewn siaced ginio: arlliw croen canolig-tywyll',
    '🤵🏿' => 'person mewn siaced ginio: arlliw croen tywyll',
    '👰🏻' => 'person yn gwisgo llen: arlliw croen golau',
    '👰🏼' => 'person yn gwisgo llen: arlliw croen canolig-golau',
    '👰🏽' => 'person yn gwisgo llen: arlliw croen canolog',
    '👰🏾' => 'person yn gwisgo llen: arlliw croen canolig-tywyll',
    '👰🏿' => 'person yn gwisgo llen: arlliw croen tywyll',
    '🤰🏻' => 'menyw feichiog: arlliw croen golau',
    '🤰🏼' => 'menyw feichiog: arlliw croen canolig-golau',
    '🤰🏽' => 'menyw feichiog: arlliw croen canolog',
    '🤰🏾' => 'menyw feichiog: arlliw croen canolig-tywyll',
    '🤰🏿' => 'menyw feichiog: arlliw croen tywyll',
    '🫃🏻' => 'dyn beichiog: arlliw croen golau',
    '🫃🏼' => 'dyn beichiog: arlliw croen canolig-golau',
    '🫃🏽' => 'dyn beichiog: arlliw croen canolog',
    '🫃🏾' => 'dyn beichiog: arlliw croen canolig-tywyll',
    '🫃🏿' => 'dyn beichiog: arlliw croen tywyll',
    '🫄🏻' => 'person beichiog: arlliw croen golau',
    '🫄🏼' => 'person beichiog: arlliw croen canolig-golau',
    '🫄🏽' => 'person beichiog: arlliw croen canolog',
    '🫄🏾' => 'person beichiog: arlliw croen canolig-tywyll',
    '🫄🏿' => 'person beichiog: arlliw croen tywyll',
    '🤱🏻' => 'bwydo o’r fron: arlliw croen golau',
    '🤱🏼' => 'bwydo o’r fron: arlliw croen canolig-golau',
    '🤱🏽' => 'bwydo o’r fron: arlliw croen canolog',
    '🤱🏾' => 'bwydo o’r fron: arlliw croen canolig-tywyll',
    '🤱🏿' => 'bwydo o’r fron: arlliw croen tywyll',
    '👼🏻' => 'babi angel: arlliw croen golau',
    '👼🏼' => 'babi angel: arlliw croen canolig-golau',
    '👼🏽' => 'babi angel: arlliw croen canolog',
    '👼🏾' => 'babi angel: arlliw croen canolig-tywyll',
    '👼🏿' => 'babi angel: arlliw croen tywyll',
    '🎅🏻' => 'Siôn Corn: arlliw croen golau',
    '🎅🏼' => 'Siôn Corn: arlliw croen canolig-golau',
    '🎅🏽' => 'Siôn Corn: arlliw croen canolog',
    '🎅🏾' => 'Siôn Corn: arlliw croen canolig-tywyll',
    '🎅🏿' => 'Siôn Corn: arlliw croen tywyll',
    '🤶🏻' => 'Siân Corn: arlliw croen golau',
    '🤶🏼' => 'Siân Corn: arlliw croen canolig-golau',
    '🤶🏽' => 'Siân Corn: arlliw croen canolog',
    '🤶🏾' => 'Siân Corn: arlliw croen canolig-tywyll',
    '🤶🏿' => 'Siân Corn: arlliw croen tywyll',
    '🦸🏻' => 'archarwr: arlliw croen golau',
    '🦸🏼' => 'archarwr: arlliw croen canolig-golau',
    '🦸🏽' => 'archarwr: arlliw croen canolog',
    '🦸🏾' => 'archarwr: arlliw croen canolig-tywyll',
    '🦸🏿' => 'archarwr: arlliw croen tywyll',
    '🦹🏻' => 'archleidr: arlliw croen golau',
    '🦹🏼' => 'archleidr: arlliw croen canolig-golau',
    '🦹🏽' => 'archleidr: arlliw croen canolog',
    '🦹🏾' => 'archleidr: arlliw croen canolig-tywyll',
    '🦹🏿' => 'archleidr: arlliw croen tywyll',
    '🧙🏻' => 'dewin: arlliw croen golau',
    '🧙🏼' => 'dewin: arlliw croen canolig-golau',
    '🧙🏽' => 'dewin: arlliw croen canolog',
    '🧙🏾' => 'dewin: arlliw croen canolig-tywyll',
    '🧙🏿' => 'dewin: arlliw croen tywyll',
    '🧚🏻' => 'tylwyth teg: arlliw croen golau',
    '🧚🏼' => 'tylwyth teg: arlliw croen canolig-golau',
    '🧚🏽' => 'tylwyth teg: arlliw croen canolog',
    '🧚🏾' => 'tylwyth teg: arlliw croen canolig-tywyll',
    '🧚🏿' => 'tylwyth teg: arlliw croen tywyll',
    '🧛🏻' => 'fampir: arlliw croen golau',
    '🧛🏼' => 'fampir: arlliw croen canolig-golau',
    '🧛🏽' => 'fampir: arlliw croen canolog',
    '🧛🏾' => 'fampir: arlliw croen canolig-tywyll',
    '🧛🏿' => 'fampir: arlliw croen tywyll',
    '🧜🏻' => 'môrberson: arlliw croen golau',
    '🧜🏼' => 'môrberson: arlliw croen canolig-golau',
    '🧜🏽' => 'môrberson: arlliw croen canolog',
    '🧜🏾' => 'môrberson: arlliw croen canolig-tywyll',
    '🧜🏿' => 'môrberson: arlliw croen tywyll',
    '🧝🏻' => 'coblyn: arlliw croen golau',
    '🧝🏼' => 'coblyn: arlliw croen canolig-golau',
    '🧝🏽' => 'coblyn: arlliw croen canolog',
    '🧝🏾' => 'coblyn: arlliw croen canolig-tywyll',
    '🧝🏿' => 'coblyn: arlliw croen tywyll',
    '💆🏻' => 'person yn derbyn tyluniad: arlliw croen golau',
    '💆🏼' => 'person yn derbyn tyluniad: arlliw croen canolig-golau',
    '💆🏽' => 'person yn derbyn tyluniad: arlliw croen canolog',
    '💆🏾' => 'person yn derbyn tyluniad: arlliw croen canolig-tywyll',
    '💆🏿' => 'person yn derbyn tyluniad: arlliw croen tywyll',
    '💇🏻' => 'person yn cael ei wallt wedi’u torri: arlliw croen golau',
    '💇🏼' => 'person yn cael ei wallt wedi’u torri: arlliw croen canolig-golau',
    '💇🏽' => 'person yn cael ei wallt wedi’u torri: arlliw croen canolog',
    '💇🏾' => 'person yn cael ei wallt wedi’u torri: arlliw croen canolig-tywyll',
    '💇🏿' => 'person yn cael ei wallt wedi’u torri: arlliw croen tywyll',
    '🚶🏻' => 'person yn cerdded: arlliw croen golau',
    '🚶🏼' => 'person yn cerdded: arlliw croen canolig-golau',
    '🚶🏽' => 'person yn cerdded: arlliw croen canolog',
    '🚶🏾' => 'person yn cerdded: arlliw croen canolig-tywyll',
    '🚶🏿' => 'person yn cerdded: arlliw croen tywyll',
    '🧍🏻' => 'person yn sefyll: arlliw croen golau',
    '🧍🏼' => 'person yn sefyll: arlliw croen canolig-golau',
    '🧍🏽' => 'person yn sefyll: arlliw croen canolog',
    '🧍🏾' => 'person yn sefyll: arlliw croen canolig-tywyll',
    '🧍🏿' => 'person yn sefyll: arlliw croen tywyll',
    '🧎🏻' => 'person yn penlinio: arlliw croen golau',
    '🧎🏼' => 'person yn penlinio: arlliw croen canolig-golau',
    '🧎🏽' => 'person yn penlinio: arlliw croen canolog',
    '🧎🏾' => 'person yn penlinio: arlliw croen canolig-tywyll',
    '🧎🏿' => 'person yn penlinio: arlliw croen tywyll',
    '🏃🏻' => 'person yn rhedeg: arlliw croen golau',
    '🏃🏼' => 'person yn rhedeg: arlliw croen canolig-golau',
    '🏃🏽' => 'person yn rhedeg: arlliw croen canolog',
    '🏃🏾' => 'person yn rhedeg: arlliw croen canolig-tywyll',
    '🏃🏿' => 'person yn rhedeg: arlliw croen tywyll',
    '💃🏻' => 'menyw yn dawnsio: arlliw croen golau',
    '💃🏼' => 'menyw yn dawnsio: arlliw croen canolig-golau',
    '💃🏽' => 'menyw yn dawnsio: arlliw croen canolog',
    '💃🏾' => 'menyw yn dawnsio: arlliw croen canolig-tywyll',
    '💃🏿' => 'menyw yn dawnsio: arlliw croen tywyll',
    '🕺🏻' => 'dyn yn dawnsio: arlliw croen golau',
    '🕺🏼' => 'dyn yn dawnsio: arlliw croen canolig-golau',
    '🕺🏽' => 'dyn yn dawnsio: arlliw croen canolog',
    '🕺🏾' => 'dyn yn dawnsio: arlliw croen canolig-tywyll',
    '🕺🏿' => 'dyn yn dawnsio: arlliw croen tywyll',
    '🕴🏻' => 'dyn mewn gwisg fusnes yn ymddyrchafu: arlliw croen golau',
    '🕴🏼' => 'dyn mewn gwisg fusnes yn ymddyrchafu: arlliw croen canolig-golau',
    '🕴🏽' => 'dyn mewn gwisg fusnes yn ymddyrchafu: arlliw croen canolog',
    '🕴🏾' => 'dyn mewn gwisg fusnes yn ymddyrchafu: arlliw croen canolig-tywyll',
    '🕴🏿' => 'dyn mewn gwisg fusnes yn ymddyrchafu: arlliw croen tywyll',
    '👯🏻' => 'pobl mewn parti: arlliw croen golau',
    '👯🏼' => 'pobl mewn parti: arlliw croen canolig-golau',
    '👯🏽' => 'pobl mewn parti: arlliw croen canolog',
    '👯🏾' => 'pobl mewn parti: arlliw croen canolig-tywyll',
    '👯🏿' => 'pobl mewn parti: arlliw croen tywyll',
    '🧖🏻' => 'person mewn ystafell llawn stêm: arlliw croen golau',
    '🧖🏼' => 'person mewn ystafell llawn stêm: arlliw croen canolig-golau',
    '🧖🏽' => 'person mewn ystafell llawn stêm: arlliw croen canolog',
    '🧖🏾' => 'person mewn ystafell llawn stêm: arlliw croen canolig-tywyll',
    '🧖🏿' => 'person mewn ystafell llawn stêm: arlliw croen tywyll',
    '🧗🏻' => 'person yn dringo: arlliw croen golau',
    '🧗🏼' => 'person yn dringo: arlliw croen canolig-golau',
    '🧗🏽' => 'person yn dringo: arlliw croen canolog',
    '🧗🏾' => 'person yn dringo: arlliw croen canolig-tywyll',
    '🧗🏿' => 'person yn dringo: arlliw croen tywyll',
    '🏇🏻' => 'rasio ceffylau: arlliw croen golau',
    '🏇🏼' => 'rasio ceffylau: arlliw croen canolig-golau',
    '🏇🏽' => 'rasio ceffylau: arlliw croen canolog',
    '🏇🏾' => 'rasio ceffylau: arlliw croen canolig-tywyll',
    '🏇🏿' => 'rasio ceffylau: arlliw croen tywyll',
    '🏂🏻' => 'eirafyrddiwr: arlliw croen golau',
    '🏂🏼' => 'eirafyrddiwr: arlliw croen canolig-golau',
    '🏂🏽' => 'eirafyrddiwr: arlliw croen canolog',
    '🏂🏾' => 'eirafyrddiwr: arlliw croen canolig-tywyll',
    '🏂🏿' => 'eirafyrddiwr: arlliw croen tywyll',
    '🏌🏻' => 'person yn chwarae golff: arlliw croen golau',
    '🏌🏼' => 'person yn chwarae golff: arlliw croen canolig-golau',
    '🏌🏽' => 'person yn chwarae golff: arlliw croen canolog',
    '🏌🏾' => 'person yn chwarae golff: arlliw croen canolig-tywyll',
    '🏌🏿' => 'person yn chwarae golff: arlliw croen tywyll',
    '🏄🏻' => 'person yn syrffio: arlliw croen golau',
    '🏄🏼' => 'person yn syrffio: arlliw croen canolig-golau',
    '🏄🏽' => 'person yn syrffio: arlliw croen canolog',
    '🏄🏾' => 'person yn syrffio: arlliw croen canolig-tywyll',
    '🏄🏿' => 'person yn syrffio: arlliw croen tywyll',
    '🚣🏻' => 'person yn rhwyfo cwch: arlliw croen golau',
    '🚣🏼' => 'person yn rhwyfo cwch: arlliw croen canolig-golau',
    '🚣🏽' => 'person yn rhwyfo cwch: arlliw croen canolog',
    '🚣🏾' => 'person yn rhwyfo cwch: arlliw croen canolig-tywyll',
    '🚣🏿' => 'person yn rhwyfo cwch: arlliw croen tywyll',
    '🏊🏻' => 'person yn nofio: arlliw croen golau',
    '🏊🏼' => 'person yn nofio: arlliw croen canolig-golau',
    '🏊🏽' => 'person yn nofio: arlliw croen canolog',
    '🏊🏾' => 'person yn nofio: arlliw croen canolig-tywyll',
    '🏊🏿' => 'person yn nofio: arlliw croen tywyll',
    '⛹🏻' => 'person â phêl: arlliw croen golau',
    '⛹🏼' => 'person â phêl: arlliw croen canolig-golau',
    '⛹🏽' => 'person â phêl: arlliw croen canolog',
    '⛹🏾' => 'person â phêl: arlliw croen canolig-tywyll',
    '⛹🏿' => 'person â phêl: arlliw croen tywyll',
    '🏋🏻' => 'person yn codi pwysau: arlliw croen golau',
    '🏋🏼' => 'person yn codi pwysau: arlliw croen canolig-golau',
    '🏋🏽' => 'person yn codi pwysau: arlliw croen canolog',
    '🏋🏾' => 'person yn codi pwysau: arlliw croen canolig-tywyll',
    '🏋🏿' => 'person yn codi pwysau: arlliw croen tywyll',
    '🚴🏻' => 'person yn beicio: arlliw croen golau',
    '🚴🏼' => 'person yn beicio: arlliw croen canolig-golau',
    '🚴🏽' => 'person yn beicio: arlliw croen canolog',
    '🚴🏾' => 'person yn beicio: arlliw croen canolig-tywyll',
    '🚴🏿' => 'person yn beicio: arlliw croen tywyll',
    '🚵🏻' => 'person yn beicio mynydd: arlliw croen golau',
    '🚵🏼' => 'person yn beicio mynydd: arlliw croen canolig-golau',
    '🚵🏽' => 'person yn beicio mynydd: arlliw croen canolog',
    '🚵🏾' => 'person yn beicio mynydd: arlliw croen canolig-tywyll',
    '🚵🏿' => 'person yn beicio mynydd: arlliw croen tywyll',
    '🤸🏻' => 'olwyn droi: arlliw croen golau',
    '🤸🏼' => 'olwyn droi: arlliw croen canolig-golau',
    '🤸🏽' => 'olwyn droi: arlliw croen canolog',
    '🤸🏾' => 'olwyn droi: arlliw croen canolig-tywyll',
    '🤸🏿' => 'olwyn droi: arlliw croen tywyll',
    '🤼🏻' => 'taflwyr codwm: arlliw croen golau',
    '🤼🏼' => 'taflwyr codwm: arlliw croen canolig-golau',
    '🤼🏽' => 'taflwyr codwm: arlliw croen canolog',
    '🤼🏾' => 'taflwyr codwm: arlliw croen canolig-tywyll',
    '🤼🏿' => 'taflwyr codwm: arlliw croen tywyll',
    '🤽🏻' => 'polo dŵr: arlliw croen golau',
    '🤽🏼' => 'polo dŵr: arlliw croen canolig-golau',
    '🤽🏽' => 'polo dŵr: arlliw croen canolog',
    '🤽🏾' => 'polo dŵr: arlliw croen canolig-tywyll',
    '🤽🏿' => 'polo dŵr: arlliw croen tywyll',
    '🤾🏻' => 'pêl-law: arlliw croen golau',
    '🤾🏼' => 'pêl-law: arlliw croen canolig-golau',
    '🤾🏽' => 'pêl-law: arlliw croen canolog',
    '🤾🏾' => 'pêl-law: arlliw croen canolig-tywyll',
    '🤾🏿' => 'pêl-law: arlliw croen tywyll',
    '🤹🏻' => 'jyglo: arlliw croen golau',
    '🤹🏼' => 'jyglo: arlliw croen canolig-golau',
    '🤹🏽' => 'jyglo: arlliw croen canolog',
    '🤹🏾' => 'jyglo: arlliw croen canolig-tywyll',
    '🤹🏿' => 'jyglo: arlliw croen tywyll',
    '🧘🏻' => 'person mewn ystum lingroes: arlliw croen golau',
    '🧘🏼' => 'person mewn ystum lingroes: arlliw croen canolig-golau',
    '🧘🏽' => 'person mewn ystum lingroes: arlliw croen canolog',
    '🧘🏾' => 'person mewn ystum lingroes: arlliw croen canolig-tywyll',
    '🧘🏿' => 'person mewn ystum lingroes: arlliw croen tywyll',
    '🛀🏻' => 'person mewn bath: arlliw croen golau',
    '🛀🏼' => 'person mewn bath: arlliw croen canolig-golau',
    '🛀🏽' => 'person mewn bath: arlliw croen canolog',
    '🛀🏾' => 'person mewn bath: arlliw croen canolig-tywyll',
    '🛀🏿' => 'person mewn bath: arlliw croen tywyll',
    '🛌🏻' => 'person mewn gwely: arlliw croen golau',
    '🛌🏼' => 'person mewn gwely: arlliw croen canolig-golau',
    '🛌🏽' => 'person mewn gwely: arlliw croen canolog',
    '🛌🏾' => 'person mewn gwely: arlliw croen canolig-tywyll',
    '🛌🏿' => 'person mewn gwely: arlliw croen tywyll',
    '👭🏻' => 'dwy fenyw yn dal dwylo: arlliw croen golau',
    '👭🏼' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-golau',
    '👭🏽' => 'dwy fenyw yn dal dwylo: arlliw croen canolog',
    '👭🏾' => 'dwy fenyw yn dal dwylo: arlliw croen canolig-tywyll',
    '👭🏿' => 'dwy fenyw yn dal dwylo: arlliw croen tywyll',
    '👫🏻' => 'dyn a menyw yn dal dwylo: arlliw croen golau',
    '👫🏼' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-golau',
    '👫🏽' => 'dyn a menyw yn dal dwylo: arlliw croen canolog',
    '👫🏾' => 'dyn a menyw yn dal dwylo: arlliw croen canolig-tywyll',
    '👫🏿' => 'dyn a menyw yn dal dwylo: arlliw croen tywyll',
    '👬🏻' => 'dau ddyn yn dal dwylo: arlliw croen golau',
    '👬🏼' => 'dau ddyn yn dal dwylo: arlliw croen canolig-golau',
    '👬🏽' => 'dau ddyn yn dal dwylo: arlliw croen canolog',
    '👬🏾' => 'dau ddyn yn dal dwylo: arlliw croen canolig-tywyll',
    '👬🏿' => 'dau ddyn yn dal dwylo: arlliw croen tywyll',
    '💏🏻' => 'cusan: arlliw croen golau',
    '💏🏼' => 'cusan: arlliw croen canolig-golau',
    '💏🏽' => 'cusan: arlliw croen canolog',
    '💏🏾' => 'cusan: arlliw croen canolig-tywyll',
    '💏🏿' => 'cusan: arlliw croen tywyll',
    '💑🏻' => 'pâr a chalon: arlliw croen golau',
    '💑🏼' => 'pâr a chalon: arlliw croen canolig-golau',
    '💑🏽' => 'pâr a chalon: arlliw croen canolog',
    '💑🏾' => 'pâr a chalon: arlliw croen canolig-tywyll',
    '💑🏿' => 'pâr a chalon: arlliw croen tywyll',
    '🇦🇨' => 'baner: Ynys Ascension',
    '🇦🇩' => 'baner: Andorra',
    '🇦🇪' => 'baner: Emiradau Arabaidd Unedig',
    '🇦🇫' => 'baner: Afghanistan',
    '🇦🇬' => 'baner: Antigua a Barbuda',
    '🇦🇮' => 'baner: Anguilla',
    '🇦🇱' => 'baner: Albania',
    '🇦🇲' => 'baner: Armenia',
    '🇦🇴' => 'baner: Angola',
    '🇦🇶' => 'baner: Antarctica',
    '🇦🇷' => 'baner: Yr Ariannin',
    '🇦🇸' => 'baner: Samoa America',
    '🇦🇹' => 'baner: Awstria',
    '🇦🇺' => 'baner: Awstralia',
    '🇦🇼' => 'baner: Aruba',
    '🇦🇽' => 'baner: Ynysoedd Åland',
    '🇦🇿' => 'baner: Aserbaijan',
    '🇧🇦' => 'baner: Bosnia a Herzegovina',
    '🇧🇧' => 'baner: Barbados',
    '🇧🇩' => 'baner: Bangladesh',
    '🇧🇪' => 'baner: Gwlad Belg',
    '🇧🇫' => 'baner: Burkina Faso',
    '🇧🇬' => 'baner: Bwlgaria',
    '🇧🇭' => 'baner: Bahrain',
    '🇧🇮' => 'baner: Burundi',
    '🇧🇯' => 'baner: Benin',
    '🇧🇱' => 'baner: Saint Barthélemy',
    '🇧🇲' => 'baner: Bermuda',
    '🇧🇳' => 'baner: Brunei',
    '🇧🇴' => 'baner: Bolifia',
    '🇧🇶' => 'baner: Antilles yr Iseldiroedd',
    '🇧🇷' => 'baner: Brasil',
    '🇧🇸' => 'baner: Y Bahamas',
    '🇧🇹' => 'baner: Bhutan',
    '🇧🇻' => 'baner: Ynys Bouvet',
    '🇧🇼' => 'baner: Botswana',
    '🇧🇾' => 'baner: Belarws',
    '🇧🇿' => 'baner: Belize',
    '🇨🇦' => 'baner: Canada',
    '🇨🇨' => 'baner: Ynysoedd Cocos (Keeling)',
    '🇨🇩' => 'baner: Y Congo - Kinshasa',
    '🇨🇫' => 'baner: Gweriniaeth Canolbarth Affrica',
    '🇨🇬' => 'baner: Y Congo - Brazzaville',
    '🇨🇭' => 'baner: Y Swistir',
    '🇨🇮' => 'baner: Côte d’Ivoire',
    '🇨🇰' => 'baner: Ynysoedd Cook',
    '🇨🇱' => 'baner: Chile',
    '🇨🇲' => 'baner: Camerŵn',
    '🇨🇳' => 'baner: Tsieina',
    '🇨🇴' => 'baner: Colombia',
    '🇨🇵' => 'baner: Ynys Clipperton',
    '🇨🇶' => 'baner: Sarc',
    '🇨🇷' => 'baner: Costa Rica',
    '🇨🇺' => 'baner: Ciwba',
    '🇨🇻' => 'baner: Cabo Verde',
    '🇨🇼' => 'baner: Curaçao',
    '🇨🇽' => 'baner: Ynys y Nadolig',
    '🇨🇾' => 'baner: Cyprus',
    '🇨🇿' => 'baner: Tsiecia',
    '🇩🇪' => 'baner: Yr Almaen',
    '🇩🇬' => 'baner: Diego Garcia',
    '🇩🇯' => 'baner: Djibouti',
    '🇩🇰' => 'baner: Denmarc',
    '🇩🇲' => 'baner: Dominica',
    '🇩🇴' => 'baner: Gweriniaeth Dominica',
    '🇩🇿' => 'baner: Algeria',
    '🇪🇦' => 'baner: Ceuta a Melilla',
    '🇪🇨' => 'baner: Ecuador',
    '🇪🇪' => 'baner: Estonia',
    '🇪🇬' => 'baner: Yr Aifft',
    '🇪🇭' => 'baner: Gorllewin Sahara',
    '🇪🇷' => 'baner: Eritrea',
    '🇪🇸' => 'baner: Sbaen',
    '🇪🇹' => 'baner: Ethiopia',
    '🇪🇺' => 'baner: Yr Undeb Ewropeaidd',
    '🇫🇮' => 'baner: Y Ffindir',
    '🇫🇯' => 'baner: Fiji',
    '🇫🇰' => 'baner: Ynysoedd y Falkland/Malvinas',
    '🇫🇲' => 'baner: Micronesia',
    '🇫🇴' => 'baner: Ynysoedd Ffaro',
    '🇫🇷' => 'baner: Ffrainc',
    '🇬🇦' => 'baner: Gabon',
    '🇬🇧' => 'baner: Y Deyrnas Unedig',
    '🇬🇩' => 'baner: Grenada',
    '🇬🇪' => 'baner: Georgia',
    '🇬🇫' => 'baner: Guyane Ffrengig',
    '🇬🇬' => 'baner: Ynys y Garn',
    '🇬🇭' => 'baner: Ghana',
    '🇬🇮' => 'baner: Gibraltar',
    '🇬🇱' => 'baner: Yr Ynys Las',
    '🇬🇲' => 'baner: Gambia',
    '🇬🇳' => 'baner: Gini',
    '🇬🇵' => 'baner: Guadeloupe',
    '🇬🇶' => 'baner: Gini Gyhydeddol',
    '🇬🇷' => 'baner: Gwlad Groeg',
    '🇬🇸' => 'baner: De Georgia ac Ynysoedd Sandwich y De',
    '🇬🇹' => 'baner: Guatemala',
    '🇬🇺' => 'baner: Guam',
    '🇬🇼' => 'baner: Guiné-Bissau',
    '🇬🇾' => 'baner: Guyana',
    '🇭🇰' => 'baner: Hong Kong SAR Tsieina',
    '🇭🇲' => 'baner: Ynys Heard ac Ynysoedd McDonald',
    '🇭🇳' => 'baner: Honduras',
    '🇭🇷' => 'baner: Croatia',
    '🇭🇹' => 'baner: Haiti',
    '🇭🇺' => 'baner: Hwngari',
    '🇮🇨' => 'baner: Yr Ynysoedd Dedwydd',
    '🇮🇩' => 'baner: Indonesia',
    '🇮🇪' => 'baner: Iwerddon',
    '🇮🇱' => 'baner: Israel',
    '🇮🇲' => 'baner: Ynys Manaw',
    '🇮🇳' => 'baner: India',
    '🇮🇴' => 'baner: Tiriogaeth Brydeinig Cefnfor India',
    '🇮🇶' => 'baner: Irac',
    '🇮🇷' => 'baner: Iran',
    '🇮🇸' => 'baner: Gwlad yr Iâ',
    '🇮🇹' => 'baner: Yr Eidal',
    '🇯🇪' => 'baner: Jersey',
    '🇯🇲' => 'baner: Jamaica',
    '🇯🇴' => 'baner: Gwlad Iorddonen',
    '🇯🇵' => 'baner: Japan',
    '🇰🇪' => 'baner: Kenya',
    '🇰🇬' => 'baner: Kyrgyzstan',
    '🇰🇭' => 'baner: Cambodia',
    '🇰🇮' => 'baner: Kiribati',
    '🇰🇲' => 'baner: Comoros',
    '🇰🇳' => 'baner: Saint Kitts a Nevis',
    '🇰🇵' => 'baner: Gogledd Corea',
    '🇰🇷' => 'baner: De Corea',
    '🇰🇼' => 'baner: Kuwait',
    '🇰🇾' => 'baner: Ynysoedd Cayman',
    '🇰🇿' => 'baner: Kazakhstan',
    '🇱🇦' => 'baner: Laos',
    '🇱🇧' => 'baner: Libanus',
    '🇱🇨' => 'baner: Saint Lucia',
    '🇱🇮' => 'baner: Liechtenstein',
    '🇱🇰' => 'baner: Sri Lanka',
    '🇱🇷' => 'baner: Liberia',
    '🇱🇸' => 'baner: Lesotho',
    '🇱🇹' => 'baner: Lithwania',
    '🇱🇺' => 'baner: Lwcsembwrg',
    '🇱🇻' => 'baner: Latfia',
    '🇱🇾' => 'baner: Libya',
    '🇲🇦' => 'baner: Moroco',
    '🇲🇨' => 'baner: Monaco',
    '🇲🇩' => 'baner: Moldofa',
    '🇲🇪' => 'baner: Montenegro',
    '🇲🇫' => 'baner: Saint Martin',
    '🇲🇬' => 'baner: Madagascar',
    '🇲🇭' => 'baner: Ynysoedd Marshall',
    '🇲🇰' => 'baner: Gogledd Macedonia',
    '🇲🇱' => 'baner: Mali',
    '🇲🇲' => 'baner: Myanmar (Burma)',
    '🇲🇳' => 'baner: Mongolia',
    '🇲🇴' => 'baner: Macau SAR Tsieina',
    '🇲🇵' => 'baner: Ynysoedd Gogledd Mariana',
    '🇲🇶' => 'baner: Martinique',
    '🇲🇷' => 'baner: Mauritania',
    '🇲🇸' => 'baner: Montserrat',
    '🇲🇹' => 'baner: Malta',
    '🇲🇺' => 'baner: Mauritius',
    '🇲🇻' => 'baner: Y Maldives',
    '🇲🇼' => 'baner: Malawi',
    '🇲🇽' => 'baner: Mecsico',
    '🇲🇾' => 'baner: Malaysia',
    '🇲🇿' => 'baner: Mozambique',
    '🇳🇦' => 'baner: Namibia',
    '🇳🇨' => 'baner: Caledonia Newydd',
    '🇳🇪' => 'baner: Niger',
    '🇳🇫' => 'baner: Ynys Norfolk',
    '🇳🇬' => 'baner: Nigeria',
    '🇳🇮' => 'baner: Nicaragua',
    '🇳🇱' => 'baner: Yr Iseldiroedd',
    '🇳🇴' => 'baner: Norwy',
    '🇳🇵' => 'baner: Nepal',
    '🇳🇷' => 'baner: Nauru',
    '🇳🇺' => 'baner: Niue',
    '🇳🇿' => 'baner: Seland Newydd',
    '🇴🇲' => 'baner: Oman',
    '🇵🇦' => 'baner: Panama',
    '🇵🇪' => 'baner: Periw',
    '🇵🇫' => 'baner: Polynesia Ffrengig',
    '🇵🇬' => 'baner: Papua Guinea Newydd',
    '🇵🇭' => 'baner: Y Philipinau',
    '🇵🇰' => 'baner: Pacistan',
    '🇵🇱' => 'baner: Gwlad Pwyl',
    '🇵🇲' => 'baner: Saint-Pierre-et-Miquelon',
    '🇵🇳' => 'baner: Ynysoedd Pitcairn',
    '🇵🇷' => 'baner: Puerto Rico',
    '🇵🇸' => 'baner: Tiriogaethau Palesteinaidd',
    '🇵🇹' => 'baner: Portiwgal',
    '🇵🇼' => 'baner: Palau',
    '🇵🇾' => 'baner: Paraguay',
    '🇶🇦' => 'baner: Qatar',
    '🇷🇪' => 'baner: Réunion',
    '🇷🇴' => 'baner: Rwmania',
    '🇷🇸' => 'baner: Serbia',
    '🇷🇺' => 'baner: Rwsia',
    '🇷🇼' => 'baner: Rwanda',
    '🇸🇦' => 'baner: Saudi Arabia',
    '🇸🇧' => 'baner: Ynysoedd Solomon',
    '🇸🇨' => 'baner: Seychelles',
    '🇸🇩' => 'baner: Swdan',
    '🇸🇪' => 'baner: Sweden',
    '🇸🇬' => 'baner: Singapore',
    '🇸🇭' => 'baner: Saint Helena',
    '🇸🇮' => 'baner: Slofenia',
    '🇸🇯' => 'baner: Svalbard a Jan Mayen',
    '🇸🇰' => 'baner: Slofacia',
    '🇸🇱' => 'baner: Sierra Leone',
    '🇸🇲' => 'baner: San Marino',
    '🇸🇳' => 'baner: Senegal',
    '🇸🇴' => 'baner: Somalia',
    '🇸🇷' => 'baner: Suriname',
    '🇸🇸' => 'baner: De Swdan',
    '🇸🇹' => 'baner: São Tomé a Príncipe',
    '🇸🇻' => 'baner: El Salvador',
    '🇸🇽' => 'baner: Sint Maarten',
    '🇸🇾' => 'baner: Syria',
    '🇸🇿' => 'baner: Eswatini',
    '🇹🇦' => 'baner: Tristan da Cunha',
    '🇹🇨' => 'baner: Ynysoedd Turks a Caicos',
    '🇹🇩' => 'baner: Tsiad',
    '🇹🇫' => 'baner: Tiroedd Deheuol ac Antarctig Ffrainc',
    '🇹🇬' => 'baner: Togo',
    '🇹🇭' => 'baner: Gwlad Thai',
    '🇹🇯' => 'baner: Tajicistan',
    '🇹🇰' => 'baner: Tokelau',
    '🇹🇱' => 'baner: Timor-Leste',
    '🇹🇲' => 'baner: Tyrcmenistan',
    '🇹🇳' => 'baner: Tiwnisia',
    '🇹🇴' => 'baner: Tonga',
    '🇹🇷' => 'baner: Twrci',
    '🇹🇹' => 'baner: Trinidad a Tobago',
    '🇹🇻' => 'baner: Tuvalu',
    '🇹🇼' => 'baner: Taiwan',
    '🇹🇿' => 'baner: Tanzania',
    '🇺🇦' => 'baner: Wcráin',
    '🇺🇬' => 'baner: Uganda',
    '🇺🇲' => 'baner: Ynysoedd Pellennig UDA',
    '🇺🇳' => 'baner: Y Cenhedloedd Unedig',
    '🇺🇸' => 'baner: Yr Unol Daleithiau',
    '🇺🇾' => 'baner: Uruguay',
    '🇺🇿' => 'baner: Uzbekistan',
    '🇻🇦' => 'baner: Y Fatican',
    '🇻🇨' => 'baner: Saint Vincent a’r Grenadines',
    '🇻🇪' => 'baner: Venezuela',
    '🇻🇬' => 'baner: Ynysoedd Gwyryf Prydain',
    '🇻🇮' => 'baner: Ynysoedd Gwyryf yr Unol Daleithiau',
    '🇻🇳' => 'baner: Fietnam',
    '🇻🇺' => 'baner: Vanuatu',
    '🇼🇫' => 'baner: Wallis a Futuna',
    '🇼🇸' => 'baner: Samoa',
    '🇽🇰' => 'baner: Kosovo',
    '🇾🇪' => 'baner: Yemen',
    '🇾🇹' => 'baner: Mayotte',
    '🇿🇦' => 'baner: De Affrica',
    '🇿🇲' => 'baner: Zambia',
    '🇿🇼' => 'baner: Zimbabwe',
    '🔟' => 'gorchudd bysell: 10',
    '🏻' => 'arlliw croen golau',
    '🏼' => 'arlliw croen canolig-golau',
    '🏽' => 'arlliw croen canolog',
    '🏾' => 'arlliw croen canolig-tywyll',
    '🏿' => 'arlliw croen tywyll',
    '😀' => 'wyneb yn gwenu â cheg agored',
    '😃' => 'wyneb yn gwenu â cheg agored a llygaid mawr',
    '😄' => 'wyneb yn gwenu â cheg agored a gwên yn y llygaid',
    '😁' => 'wyneb yn lledwenu â gwên yn y llygaid',
    '😆' => 'wyneb yn gwenu â cheg agored a llygaid ynghau',
    '😅' => 'wyneb yn gwenu â cheg agored a chwys',
    '🤣' => 'rholio ar y llawr yn chwerthin',
    '😂' => 'wyneb â dagrau hapusrwydd',
    '🙂' => 'wyneb ag ychydig o wên arni',
    '🙃' => 'wyneb â’i ben i waered',
    '🫠' => 'wyneb toddi',
    '😉' => 'llygaid yn wincio',
    '😊' => 'wyneb yn gwenu â gwên yn y llygaid',
    '😇' => 'wyneb yn gwenu ag eurgylch',
    '🥰' => 'wyneb yn gwenu â thair calon',
    '😍' => 'wyneb yn gwenu â chalonnau yn y llygaid',
    '🤩' => 'wyneb â ser yn y llygaid',
    '😘' => 'wyneb yn chwythu cusan',
    '😗' => 'wyneb yn rhoi cusan',
    '☺' => 'wyneb yn gwenu',
    '😚' => 'wyneb yn rhoi cusan â llygaid ynghau',
    '😙' => 'wyneb yn rhoi cusan â gwên yn y llygaid',
    '🥲' => 'wyneb yn gwenu gyda deugryn',
    '😋' => 'wyneb yn blasu bwyd blasus',
    '😛' => 'wyneb â thafod yng ngolwg',
    '😜' => 'wyneb â thafod yng ngolwg a llygaid yn wincio',
    '🤪' => 'wyneb penwan',
    '😝' => 'wyneb â thafod yng ngolwg a llygaid ynghau',
    '🤑' => 'wyneb symbol arian',
    '🤗' => 'wyneb yn rhoi cwtsh',
    '🤭' => 'wyneb gyda llaw dros y geg',
    '🫢' => 'wyneb gyda llygaid agored a llaw dros geg',
    '🫣' => 'wyneb gyda llygad sy’n sbïo',
    '🤫' => 'wyneb hisht',
    '🤔' => 'wyneb yn meddwl',
    '🫡' => 'wyneb saliwt',
    '🤐' => 'wyneb â sip dros y geg',
    '🤨' => 'wyneb gydag ael wedi codi',
    '😐' => 'wyneb niwtral',
    '😑' => 'wyneb difynegiant',
    '😶' => 'wyneb heb geg',
    '🫥' => 'wyneb llinell dotiog',
    '😏' => 'wyneb yn cilwenu',
    '😒' => 'wyneb ddi-ddifyr',
    '🙄' => 'wyneb â llygaid yn rholio',
    '😬' => 'wyneb ag ystum',
    '🤥' => 'wyneb celwydd',
    '🫨' => 'wyneb sydd ysgwyd',
    '😌' => 'wyneb o ryddhad',
    '😔' => 'wyneb synfyfyriol',
    '😪' => 'wyneb cysglyd',
    '🤤' => 'wyneb glafoerio',
    '😴' => 'wyneb yn cysgu',
    '🫩' => 'wyneb gyda bagiau dan y llygaid',
    '😷' => 'wyneb â mwgwd meddygol',
    '🤒' => 'wyneb â thermomedr',
    '🤕' => 'wyneb â rhwymyn i’r pen',
    '🤢' => 'wyneb chwydlyd',
    '🤮' => 'wyneb yn chwydu',
    '🤧' => 'wyneb tisian',
    '🥵' => 'wyneb poeth',
    '🥶' => 'wyneb oer',
    '🥴' => 'wyneb meddw',
    '😵' => 'wyneb wedi llorio',
    '🤯' => 'pen yn ffrwydro',
    '🤠' => 'wyneb het cowboi',
    '🥳' => 'wyneb yn partïo',
    '🥸' => 'wyneb mewn cuddwisg',
    '😎' => 'wyneb yn gwenu â sbectol haul',
    '🤓' => 'wyneb clyfar',
    '🧐' => 'wyneb gyda monocl',
    '😕' => 'wyneb cymysglyd',
    '🫤' => 'wyneb â cheg letraws',
    '😟' => 'wyneb gofidio',
    '🙁' => 'wyneb â pheth gwg arni',
    '☹' => 'wyneb gwgus',
    '😮' => 'wyneb â cheg agored',
    '😯' => 'wyneb distewi',
    '😲' => 'wyneb wedi rhyfeddu',
    '😳' => 'wyneb yn gwrido',
    '🫪' => 'wyneb wedi ystumio',
    '🥺' => 'wyneb yn pledio',
    '🥹' => 'wyneb yn dal dagrau yn ôl',
    '😦' => 'wyneb gwgus â cheg agored',
    '😧' => 'wyneb dirboen',
    '😨' => 'wyneb ofnus',
    '😰' => 'wyneb â cheg agored a chwys o ofid',
    '😥' => 'wyneb siomedig ond â rhyddhad',
    '😢' => 'wyneb yn crio',
    '😭' => 'wyneb yn beichio crio',
    '😱' => 'wyneb yn sgrechian ag ofn',
    '😖' => 'wyneb dryslyd',
    '😣' => 'wyneb dyfal',
    '😞' => 'wyneb siomedig',
    '😓' => 'wyneb yn chwysu o ofid',
    '😩' => 'wyneb lluddedig',
    '😫' => 'wyneb blinedig',
    '🥱' => 'wyneb yn dylyfu gên',
    '😤' => 'wyneb â stêm yn dod o’r trwyn',
    '😡' => 'wyneb pwdu',
    '😠' => 'wyneb dig',
    '🤬' => 'wyneb â symbolau dros y ceg',
    '😈' => 'wyneb yn gwenu â chyrn',
    '👿' => 'wyneb dig â chyrn',
    '💀' => 'penglog',
    '☠' => 'penglog ac esgyrn croes',
    '💩' => 'pentwr o faw',
    '🤡' => 'wyneb clown',
    '👹' => 'anghenfil',
    '👺' => 'bwgan',
    '👻' => 'ysbryd',
    '👽' => 'estron',
    '👾' => 'anghenfil estron',
    '🤖' => 'wyneb robot',
    '😺' => 'wyneb cath yn gwenu â cheg agored',
    '😸' => 'wyneb cath yn gwenu â cheg agored a gwên yn y llygaid',
    '😹' => 'wyneb cath â dagrau o hapusrwydd',
    '😻' => 'cath yn gwenu â chalonnau yn y llygaid',
    '😼' => 'wyneb cath â gwên ar gam',
    '😽' => 'wyneb cath yn cusanu â llygaid ynghau',
    '🙀' => 'wyneb cath luddedig',
    '😿' => 'wyneb cath yn crio',
    '😾' => 'wyneb cath yn pwdu',
    '🙈' => 'mwnci gweld dim drwg',
    '🙉' => 'clywed dim drwg',
    '🙊' => 'siarad dim drwg',
    '💌' => 'llythyr caru',
    '💘' => 'calon â saeth trwyddi',
    '💝' => 'calon â rhuban',
    '💖' => 'calon yn disgleirio',
    '💗' => 'calon yn tyfu',
    '💓' => 'calon yn curo',
    '💞' => 'calonnau yn troelli',
    '💕' => 'dwy galon',
    '💟' => 'addurn calon',
    '❣' => 'ebychiad trwm galon',
    '💔' => 'calon wedi torri',
    '❤' => 'calon goch',
    '🩷' => 'calon binc',
    '🧡' => 'calon oren',
    '💛' => 'calon felen',
    '💚' => 'calon werdd',
    '💙' => 'calon las',
    '🩵' => 'calon las golau',
    '💜' => 'calon borffor',
    '🤎' => 'calon frown',
    '🖤' => 'calon ddu',
    '🩶' => 'calon lwyd',
    '🤍' => 'calon wen',
    '💋' => 'ôl cusan',
    '💯' => 'cant o bwyntiau',
    '💢' => 'symbol dicter',
    '🫯' => 'cwmwl ymladd',
    '💥' => 'trawiad',
    '💫' => 'penysgafn',
    '💦' => 'defnynnau chwys',
    '💨' => 'rhuthro',
    '🕳' => 'twll',
    '💬' => 'balŵn deialog',
    '🗨' => 'swigen siarad i’r chwith',
    '🗯' => 'swigen ddig i’r dde',
    '💭' => 'cwmwl meddwl',
    '💤' => 'zzz',
    '👋' => 'llaw yn chwifio',
    '🤚' => 'cefn llaw wedi’i chodi',
    '🖐' => 'llaw wedi ei chodi â bysedd wedi eu lledu',
    '✋' => 'llaw wedi codi',
    '🖖' => 'saliwt fulcanaidd',
    '🫱' => 'llaw i’r dde',
    '🫲' => 'llaw i’r chwith',
    '🫳' => 'llaw palmwydd i lawr',
    '🫴' => 'llaw palmwydd i fyny',
    '🫷' => 'llaw yn gwthio i’r chwith',
    '🫸' => 'llaw yn gwthio i’r dde',
    '👌' => 'llaw ocê',
    '🤌' => 'bysedd wedi’u pinsio',
    '🤏' => 'bysedd yn pinshio',
    '✌' => 'llaw fuddugol',
    '🤞' => 'bysedd wedi’u croesi',
    '🫰' => 'llaw gyda bys mynegai a bawd wedi’u croesi',
    '🤟' => 'arwydd caru ti',
    '🤘' => 'arwydd y cyrn',
    '🤙' => 'llaw ffonia fi',
    '👈' => 'mynegfys yr wrthlaw yn pwyntio i’r chwith',
    '👉' => 'mynegfys yr wrthlaw yn pwyntio i’r dde',
    '👆' => 'mynegfys yr wrthlaw yn pwyntio i fyny',
    '🖕' => 'bys canol',
    '👇' => 'mynegfys yr wrthlaw yn pwyntio i lawr',
    '☝' => 'mynegfys yn pwyntio i fyny',
    '🫵' => 'bys mynegai yn pwyntio at y gwyliwr',
    '👍' => 'bys bawd i fyny',
    '👎' => 'bys bawd i lawr',
    '✊' => 'dwrn wedi codi',
    '👊' => 'dwrn yn agosáu',
    '🤛' => 'dwrn tua’r chwith',
    '🤜' => 'dwrn tua’r dde',
    '👏' => 'dwylo yn curo',
    '🙌' => 'person yn codi dwylo',
    '🫶' => 'dwylo calon',
    '👐' => 'dwylo agored',
    '🤲' => 'cledrau dwylo yn yr awyr gyda’u gilydd',
    '🤝' => 'ysgwyd dwylo',
    '🙏' => 'dwylo wedi plygu',
    '✍' => 'dwylo yn ysgrifennu',
    '💅' => 'farnais ewinedd',
    '🤳' => 'hunlun',
    '💪' => 'cyhyrau deuben wedi eu hystwytho',
    '🦾' => 'braich fecanyddol',
    '🦿' => 'coes fecanyddol',
    '🦵' => 'coes',
    '🦶' => 'troed',
    '👂' => 'clust',
    '🦻' => 'clust gyda chymorth clyw',
    '👃' => 'trwyn',
    '🧠' => 'ymennydd',
    '🫀' => 'Y galon',
    '🫁' => 'Yr ysgyfaint',
    '🦷' => 'dant',
    '🦴' => 'asgwrn',
    '👀' => 'llygaid',
    '👁' => 'llygad',
    '👅' => 'tafod',
    '👄' => 'ceg',
    '🫦' => 'brathu gwefus',
    '👶' => 'babi',
    '🧒' => 'plentyn',
    '👦' => 'bachgen',
    '👧' => 'merch',
    '🧑' => 'person',
    '👱' => 'person â gwallt golau',
    '👨' => 'dyn',
    '🧔' => 'person: barf',
    '👩' => 'menyw',
    '🧓' => 'oedolyn oedranus',
    '👴' => 'hen ddyn',
    '👵' => 'hen fenyw',
    '🙍' => 'person yn gwgu',
    '🙎' => 'person yn pwdu',
    '🙅' => 'person yn ystumio nad yw’n iawn',
    '🙆' => 'person yn ystumio iawn',
    '💁' => 'person yn gwyro llaw',
    '🙋' => 'person yn codi llaw',
    '🧏' => 'person byddar',
    '🙇' => 'person yn ymgrymu',
    '🤦' => 'cledr i’r wyneb',
    '🤷' => 'codi gwar',
    '👮' => 'heddwas',
    '🕵' => 'ditectif',
    '💂' => 'gwarchodfilwr',
    '🥷' => 'ninja',
    '👷' => 'adeiladwr',
    '🫅' => 'person â choron',
    '🤴' => 'tywysog',
    '👸' => 'tywysoges',
    '👳' => 'person yn gwisgo twrban',
    '👲' => 'dyn â chap Tsieineaidd',
    '🧕' => 'menyw â phensgarff',
    '🤵' => 'person mewn siaced ginio',
    '👰' => 'person yn gwisgo llen',
    '🤰' => 'menyw feichiog',
    '🫃' => 'dyn beichiog',
    '🫄' => 'person beichiog',
    '🤱' => 'bwydo o’r fron',
    '👼' => 'babi angel',
    '🎅' => 'Siôn Corn',
    '🤶' => 'Siân Corn',
    '🦸' => 'archarwr',
    '🦹' => 'archleidr',
    '🧙' => 'dewin',
    '🧚' => 'tylwyth teg',
    '🧛' => 'fampir',
    '🧜' => 'môrberson',
    '🧝' => 'coblyn',
    '🧞' => 'genie',
    '🧟' => 'sombi',
    '🧌' => 'ellyll',
    '🫈' => 'creadur blewog',
    '💆' => 'person yn derbyn tyluniad',
    '💇' => 'person yn cael ei wallt wedi’u torri',
    '🚶' => 'person yn cerdded',
    '🧍' => 'person yn sefyll',
    '🧎' => 'person yn penlinio',
    '🏃' => 'person yn rhedeg',
    '💃' => 'menyw yn dawnsio',
    '🕺' => 'dyn yn dawnsio',
    '🕴' => 'dyn mewn gwisg fusnes yn ymddyrchafu',
    '👯' => 'pobl mewn parti',
    '🧖' => 'person mewn ystafell llawn stêm',
    '🧗' => 'person yn dringo',
    '🤺' => 'ffensiwr',
    '🏇' => 'rasio ceffylau',
    '⛷' => 'sgïwr',
    '🏂' => 'eirafyrddiwr',
    '🏌' => 'person yn chwarae golff',
    '🏄' => 'person yn syrffio',
    '🚣' => 'person yn rhwyfo cwch',
    '🏊' => 'person yn nofio',
    '⛹' => 'person â phêl',
    '🏋' => 'person yn codi pwysau',
    '🚴' => 'person yn beicio',
    '🚵' => 'person yn beicio mynydd',
    '🤸' => 'olwyn droi',
    '🤼' => 'taflwyr codwm',
    '🤽' => 'polo dŵr',
    '🤾' => 'pêl-law',
    '🤹' => 'jyglo',
    '🧘' => 'person mewn ystum lingroes',
    '🛀' => 'person mewn bath',
    '🛌' => 'person mewn gwely',
    '👭' => 'dwy fenyw yn dal dwylo',
    '👫' => 'dyn a menyw yn dal dwylo',
    '👬' => 'dau ddyn yn dal dwylo',
    '💏' => 'cusan',
    '💑' => 'pâr a chalon',
    '🗣' => 'pen yn siarad',
    '👤' => 'penddelw mewn silwét',
    '👥' => 'penddelwau mewn silwét',
    '🫂' => 'pobl yn cofleidio',
    '👪' => 'teulu',
    '👣' => 'olion traed',
    '🫆' => 'ôl bys',
    '🦰' => 'gwallt coch',
    '🦱' => 'gwallt cyrliog',
    '🦳' => 'gwallt gwyn',
    '🦲' => 'moel',
    '🐵' => 'wyneb mwnci',
    '🐒' => 'mwnci',
    '🦍' => 'gorila',
    '🦧' => 'orangwtan',
    '🐶' => 'wyneb ci',
    '🐕' => 'ci',
    '🦮' => 'ci tywys',
    '🐩' => 'pwdl',
    '🐺' => 'blaidd',
    '🦊' => 'llwynog',
    '🦝' => 'racŵn',
    '🐱' => 'wyneb cath',
    '🐈' => 'cath',
    '🦁' => 'wyneb llew',
    '🐯' => 'wyneb teigr',
    '🐅' => 'teigr',
    '🐆' => 'llewpard',
    '🐴' => 'wyneb ceffyl',
    '🫎' => 'elc',
    '🫏' => 'asyn',
    '🐎' => 'ceffyl',
    '🦄' => 'wyneb uncorn',
    '🦓' => 'sebra',
    '🦌' => 'carw',
    '🦬' => 'bual',
    '🐮' => 'wyneb buwch',
    '🐂' => 'ych',
    '🐃' => 'byfflo dwr',
    '🐄' => 'buwch',
    '🐷' => 'wyneb mochyn',
    '🐖' => 'mochyn',
    '🐗' => 'baedd',
    '🐽' => 'trwyn mochyn',
    '🐏' => 'hwrdd',
    '🐑' => 'dafad',
    '🐐' => 'gafr',
    '🐪' => 'camel',
    '🐫' => 'camel dau dwmpath',
    '🦙' => 'lama',
    '🦒' => 'jiráff',
    '🐘' => 'eliffant',
    '🦣' => 'mamoth',
    '🦏' => 'rhinoseros',
    '🦛' => 'afonfarch',
    '🐭' => 'wyneb llygoden',
    '🐁' => 'llygoden',
    '🐀' => 'llygoden fawr',
    '🐹' => 'wyneb bochdew',
    '🐰' => 'wyneb cwningen',
    '🐇' => 'cwningen',
    '🐿' => 'gwiwer resog',
    '🦫' => 'afanc',
    '🦔' => 'draenog',
    '🦇' => 'ystlum',
    '🐻' => 'wyneb arth',
    '🐨' => 'coala',
    '🐼' => 'wyneb panda',
    '🦥' => 'diogyn',
    '🦦' => 'dyfrgi',
    '🦨' => 'drewgi',
    '🦘' => 'cangarŵ',
    '🦡' => 'mochyn daear',
    '🐾' => 'olion pawen',
    '🦃' => 'twrci',
    '🐔' => 'iâr',
    '🐓' => 'ceiliog',
    '🐣' => 'deoriad cywion',
    '🐤' => 'cyw bach',
    '🐥' => 'cyw iâr yn blaen-wynebu',
    '🐦' => 'aderyn',
    '🐧' => 'pengwin',
    '🕊' => 'colomen',
    '🦅' => 'eryr',
    '🦆' => 'hwyaden',
    '🦢' => 'alarch',
    '🦉' => 'tylluan',
    '🦤' => 'dodo',
    '🪶' => 'pluen',
    '🦩' => 'fflamingo',
    '🦚' => 'paun',
    '🦜' => 'parot',
    '🪽' => 'adain',
    '🪿' => 'gwydd',
    '🐸' => 'broga',
    '🐊' => 'crocodeil',
    '🐢' => 'crwban y môr',
    '🦎' => 'madfall',
    '🐍' => 'neidr',
    '🐲' => 'wyneb draig',
    '🐉' => 'draig',
    '🦕' => 'sawropod',
    '🦖' => 'T-Rex',
    '🐳' => 'morfil yn chwythu dŵr',
    '🐋' => 'morfil',
    '🐬' => 'dolffin',
    '🫍' => 'orca',
    '🦭' => 'morlo',
    '🐟' => 'pysgodyn',
    '🐠' => 'pysgod trofannol',
    '🐡' => 'chwydd bysgodyn',
    '🦈' => 'siarc',
    '🐙' => 'octopws',
    '🐚' => 'cragen droellog',
    '🪸' => 'cwrel',
    '🪼' => 'slefren fôr',
    '🦀' => 'cranc',
    '🦞' => 'cimwch',
    '🦐' => 'berdysyn',
    '🦑' => 'ystifflog',
    '🦪' => 'wystrys',
    '🐌' => 'malwoden',
    '🦋' => 'pili-pala',
    '🐛' => 'pryf',
    '🐜' => 'morgrugyn',
    '🐝' => 'gwenynen',
    '🪲' => 'chwilen',
    '🐞' => 'chwilen y wraig',
    '🦗' => 'criciedyn',
    '🪳' => 'chwilen ddu',
    '🕷' => 'pry copyn',
    '🕸' => 'gwe pry cop',
    '🦂' => 'sgorpion',
    '🦟' => 'mosgito',
    '🪰' => 'pry',
    '🪱' => 'mwydyn',
    '🦠' => 'microb',
    '💐' => 'tusw',
    '🌸' => 'blodeuyn ceirios',
    '💮' => 'blodyn gwyn',
    '🪷' => 'lotws',
    '🏵' => 'rhosglwm',
    '🌹' => 'rhosyn',
    '🥀' => 'blodyn wedi gwiwo',
    '🌺' => 'hibisgws',
    '🌻' => 'blodyn haul',
    '🌼' => 'blodeuyn',
    '🌷' => 'tiwlip',
    '🪻' => 'hiasinth',
    '🌱' => 'eginblanhigyn',
    '🪴' => 'planhigyn mewn pot',
    '🌲' => 'bythwyrdd',
    '🌳' => 'coeden gollddail',
    '🌴' => 'palmwydden',
    '🌵' => 'cactws',
    '🌾' => 'ysgub o reis',
    '🌿' => 'llysieuyn',
    '☘' => 'samrog',
    '🍀' => 'meillionen pedair deilen',
    '🍁' => 'deilen masarnen',
    '🍂' => 'deilen yn cwympo',
    '🍃' => 'deilen yn crynu yn y gwynt',
    '🪹' => 'nyth gwag',
    '🪺' => 'nythu gydag wyau',
    '🍄' => 'madarch',
    '🪾' => 'coeden heb ddail',
    '🍇' => 'grawnwin',
    '🍈' => 'melon',
    '🍉' => 'melon dŵr',
    '🍊' => 'tanjerin',
    '🍋' => 'lemwn',
    '🍌' => 'banana',
    '🍍' => 'pinafal',
    '🥭' => 'mango',
    '🍎' => 'afal coch',
    '🍏' => 'afal gwyrdd',
    '🍐' => 'peren',
    '🍑' => 'eirinen wlanog',
    '🍒' => 'ceirios',
    '🍓' => 'mefus',
    '🫐' => 'llus',
    '🥝' => 'ffrwyth ciwi',
    '🍅' => 'tomato',
    '🫒' => 'olewydd',
    '🥥' => 'cneuen goco',
    '🥑' => 'afocado',
    '🍆' => 'ŵylyst',
    '🥔' => 'taten',
    '🥕' => 'moron',
    '🌽' => 'tywysen o gorn',
    '🌶' => 'pupur twym',
    '🫑' => 'pupryn',
    '🥒' => 'ciwcymber',
    '🥬' => 'gwyrdd deiliog',
    '🥦' => 'brocoli',
    '🧄' => 'garlleg',
    '🧅' => 'winwns',
    '🥜' => 'cnai ddaear',
    '🫘' => 'ffa',
    '🌰' => 'castan',
    '🫚' => 'gwraidd sinsir',
    '🫛' => 'pod pys',
    '🫜' => 'gwreiddlysieuyn',
    '🍞' => 'bara',
    '🥐' => 'croissant',
    '🥖' => 'ffon fara',
    '🫓' => 'Bara fflat',
    '🥨' => 'pretsel',
    '🥯' => 'bagel',
    '🥞' => 'crempogau',
    '🧇' => 'woffl',
    '🧀' => 'darn o gaws',
    '🍖' => 'cig ar yr asgwrn',
    '🍗' => 'coes o ffowls',
    '🥩' => 'toriad o gig',
    '🥓' => 'bacwn',
    '🍔' => 'hambyrgyr',
    '🍟' => 'sglodion',
    '🍕' => 'pitsa',
    '🌭' => 'selsigen mewn bynen',
    '🥪' => 'brechdan',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'bara gwastad wedi’i stwffio',
    '🧆' => 'ffalaffel',
    '🥚' => 'wy',
    '🍳' => 'coginio',
    '🥘' => 'padell fas o fwyd',
    '🍲' => 'llestr o fwyd',
    '🫕' => 'fondue',
    '🥣' => 'bowlen â llwy',
    '🥗' => 'salad gwyrdd',
    '🍿' => 'popgorn',
    '🧈' => 'menyn',
    '🧂' => 'halen',
    '🥫' => 'bwyd tun',
    '🍱' => 'bocs bento',
    '🍘' => 'cracer reis',
    '🍙' => 'pêl reis',
    '🍚' => 'reis wedi’i goginio',
    '🍛' => 'reis cyrri',
    '🍜' => 'bowlen yn stemio',
    '🍝' => 'sbageti',
    '🍠' => 'taten felys wedi’i rostio',
    '🍢' => 'oden',
    '🍣' => 'swshi',
    '🍤' => 'berdysyn wedi’i ffrio',
    '🍥' => 'cacen bysgod gyda chwyrlïad',
    '🥮' => 'cacen lleuad',
    '🍡' => 'dango',
    '🥟' => 'twmplen',
    '🥠' => 'bisgeden lwcus',
    '🥡' => 'bocs prydau parod',
    '🍦' => 'hufen iâ meddal',
    '🍧' => 'iâ wedi’i siafio',
    '🍨' => 'hufen iâ',
    '🍩' => 'toesen',
    '🍪' => 'bisgeden',
    '🎂' => 'cacen pen-blwydd',
    '🍰' => 'cacen fer',
    '🧁' => 'cacen cwpan',
    '🥧' => 'pei',
    '🍫' => 'bar o siocled',
    '🍬' => 'losin',
    '🍭' => 'lolipop',
    '🍮' => 'cwstard',
    '🍯' => 'pot mêl',
    '🍼' => 'botel babi',
    '🥛' => 'gwydraid o laeth',
    '☕' => 'diod boeth',
    '🫖' => 'tebot',
    '🍵' => 'cwpan te heb ddolen',
    '🍶' => 'sake',
    '🍾' => 'potel gyda chorcyn yn popian',
    '🍷' => 'gwydr gwin',
    '🍸' => 'gwydr coctel',
    '🍹' => 'diod drofannol',
    '🍺' => 'mwg cwrw',
    '🍻' => 'mygiau cwrw yn clincian',
    '🥂' => 'gwydrau yn tincian',
    '🥃' => 'tymbler',
    '🫗' => 'arllwys hylif',
    '🥤' => 'cwpan â gwellt yfed',
    '🧋' => 'te swigod',
    '🧃' => 'blwch diodydd',
    '🧉' => 'maté',
    '🧊' => 'ciwb iâ',
    '🥢' => 'gweill bwyta',
    '🍽' => 'fforc a chyllell gyda phlât',
    '🍴' => 'fforc a chyllell',
    '🥄' => 'llwy',
    '🔪' => 'cyllell cegin',
    '🫙' => 'jar',
    '🏺' => 'llestri',
    '🌍' => 'glôb yn dangos Ewrop-Affrica',
    '🌎' => 'glôb yn dangos yr Americas',
    '🌏' => 'glôb yn dangos Asia-Awstralia',
    '🌐' => 'glôb gyda meridianau',
    '🗺' => 'map o’r byd',
    '🗾' => 'map o Japan',
    '🧭' => 'cwmpawd',
    '🏔' => 'mynydd wedi’i orchuddio mewn eira',
    '⛰' => 'mynydd',
    '🛘' => 'tirlithriad',
    '🌋' => 'llosgfynydd',
    '🗻' => 'mynydd Fuji',
    '🏕' => 'gwersyllu',
    '🏖' => 'traeth ag ymbarél',
    '🏜' => 'anialwch',
    '🏝' => 'ynys anghyfannedd',
    '🏞' => 'parc cenedlaethol',
    '🏟' => 'stadiwm',
    '🏛' => 'adeilad clasurol',
    '🏗' => 'adeiladwaith adeilad',
    '🧱' => 'bricsen',
    '🪨' => 'carreg',
    '🪵' => 'pren',
    '🛖' => 'cwt',
    '🏘' => 'tai',
    '🏚' => 'tŷ gwag',
    '🏠' => 'tŷ',
    '🏡' => 'tŷ gyda gardd',
    '🏢' => 'adeilad o swyddfa',
    '🏣' => 'swyddfa bost Japaneaidd',
    '🏤' => 'swyddfa bost',
    '🏥' => 'ysbyty',
    '🏦' => 'banc',
    '🏨' => 'gwesty',
    '🏩' => 'gwesty cariad',
    '🏪' => 'siop gyfleus',
    '🏫' => 'ysgol',
    '🏬' => 'siop adrannol',
    '🏭' => 'ffatri',
    '🏯' => 'castell Japaneaidd',
    '🏰' => 'castell',
    '💒' => 'priodas',
    '🗼' => 'tŵr Tokyo',
    '🗽' => 'Cerflun Rhyddid',
    '⛪' => 'eglwys',
    '🕌' => 'mosg',
    '🛕' => 'teml hindwaidd',
    '🕍' => 'synagog',
    '⛩' => 'cysegrfa shinto',
    '🕋' => 'kaaba',
    '⛲' => 'ffynnon',
    '⛺' => 'pabell',
    '🌁' => 'niwlog',
    '🌃' => 'noson â sêr',
    '🏙' => 'dinaslun',
    '🌄' => 'codiad haul dros fynyddoedd',
    '🌅' => 'codiad haul',
    '🌆' => 'dinaslun cyfnos',
    '🌇' => 'machlud haul',
    '🌉' => 'pont gyda’r nos',
    '♨' => 'tarddelli poeth',
    '🎠' => 'ceffyl carwsél',
    '🛝' => 'sleid maes chwarae',
    '🎡' => 'olwyn fawr',
    '🎢' => 'cert sglefrio',
    '💈' => 'polyn barbwr',
    '🎪' => 'tent syrcas',
    '🚂' => 'locomotif',
    '🚃' => 'car rheilffordd',
    '🚄' => 'trên tra chyflym',
    '🚅' => 'trên tra chyflym gyda thrwyn fel bwled',
    '🚆' => 'trên',
    '🚇' => 'metro',
    '🚈' => 'rheilffordd ysgafn',
    '🚉' => 'gorsaf',
    '🚊' => 'tram',
    '🚝' => 'trên un gledren',
    '🚞' => 'rheilffordd fynydd',
    '🚋' => 'car tram',
    '🚌' => 'bws',
    '🚍' => 'bws yn dod i’ch cwrdd',
    '🚎' => 'bws trydan',
    '🚐' => 'bws mini',
    '🚑' => 'ambiwlans',
    '🚒' => 'peiriant tân',
    '🚓' => 'car yr heddlu',
    '🚔' => 'car heddlu sy’n dod i’ch cwrdd',
    '🚕' => 'tacsi',
    '🚖' => 'tacsi sy’n dod i’ch cwrdd',
    '🚗' => 'modur',
    '🚘' => 'modur sy’n dod i’ch cwrdd',
    '🚙' => 'cerbyd hamdden',
    '🛻' => 'lori pickup',
    '🚚' => 'lori dosbarthu',
    '🚛' => 'lori gymalog',
    '🚜' => 'tractor',
    '🏎' => 'car rasio',
    '🏍' => 'beic modur',
    '🛵' => 'sgwter modur',
    '🦽' => 'cadair olwyn heb beiriant',
    '🦼' => 'cadair olwyn â pheiriant',
    '🛺' => 'ricshio â pheiriant',
    '🚲' => 'beic',
    '🛴' => 'sgwter cicio',
    '🛹' => 'sgrialfwrdd',
    '🛼' => 'esgid sglefrio',
    '🚏' => 'arhosfan bws',
    '🛣' => 'traffordd',
    '🛤' => 'trac rheilffordd',
    '🛢' => 'drwm olew',
    '⛽' => 'pwmp tanwydd',
    '🛞' => 'olwyn',
    '🚨' => 'golau car yr heddlu',
    '🚥' => 'golau traffig llorweddol',
    '🚦' => 'golau traffig fertigol',
    '🛑' => 'arwydd stop',
    '🚧' => 'adeiladwaith',
    '⚓' => 'angor',
    '🛟' => 'bwi cylch',
    '⛵' => 'cwch hwylio',
    '🛶' => 'canŵ',
    '🚤' => 'cwch gwib',
    '🛳' => 'llong deithwyr',
    '⛴' => 'fferi',
    '🛥' => 'cwch modur',
    '🚢' => 'llong',
    '✈' => 'awyren',
    '🛩' => 'awyren fach',
    '🛫' => 'ymadawiad awyren',
    '🛬' => 'dyfodiad awyren',
    '🪂' => 'parasiwt',
    '💺' => 'sedd',
    '🚁' => 'hofrennydd',
    '🚟' => 'rheilffordd grog',
    '🚠' => 'rhaffbont fynydd',
    '🚡' => 'tramffordd awyrol',
    '🛰' => 'lloeren',
    '🚀' => 'roced',
    '🛸' => 'soser hedegog',
    '🛎' => 'porthor',
    '🧳' => 'bagiau',
    '⌛' => 'awrwydr',
    '⏳' => 'awrwydr gyda thywod yn llifo',
    '⌚' => 'oriawr',
    '⏰' => 'cloc larwm',
    '⏱' => 'stop wats',
    '⏲' => 'cloc ag amserydd',
    '🕰' => 'cloc silff ben tân',
    '🕛' => 'deuddeg o’r gloch',
    '🕧' => 'hanner awr wedi deuddeg',
    '🕐' => 'un o’r gloch',
    '🕜' => 'hanner awr wedi un',
    '🕑' => 'dau o’r gloch',
    '🕝' => 'hanner awr wedi dau',
    '🕒' => 'tri o’r gloch',
    '🕞' => 'hanner awr wedi tri',
    '🕓' => 'pedwar o’r gloch',
    '🕟' => 'hanner awr wedi pedwar',
    '🕔' => 'pump o’r gloch',
    '🕠' => 'hanner awr wedi pump',
    '🕕' => 'chwech o’r gloch',
    '🕡' => 'hanner awr wedi chwech',
    '🕖' => 'saith o’r gloch',
    '🕢' => 'hanner awr wedi saith',
    '🕗' => 'wyth o’r gloch',
    '🕣' => 'hanner awr wedi wyth',
    '🕘' => 'naw o’r gloch',
    '🕤' => 'hanner awr wedi naw',
    '🕙' => 'deg o’r gloch',
    '🕥' => 'hanner awr wedi deg',
    '🕚' => 'un ar ddeg o’r gloch',
    '🕦' => 'hanner awr wedi un ar ddeg',
    '🌑' => 'lleuad newydd',
    '🌒' => 'lleuad gilgant ar ei chynnydd',
    '🌓' => 'lleuad chwarter cyntaf',
    '🌔' => 'lleuad amgrwm ar ei chynnydd',
    '🌕' => 'lleuad lawn',
    '🌖' => 'lleuad amgrwm ar ei chil',
    '🌗' => 'lleuad chwarter olaf',
    '🌘' => 'lleuad cilgant ar ei chil',
    '🌙' => 'lleuad gilgant',
    '🌚' => 'wyneb lleuad newydd',
    '🌛' => 'lleuad chwarter cyntaf gydag wyneb',
    '🌜' => 'lleuad chwarter olaf gydag wyneb',
    '🌡' => 'thermomedr',
    '☀' => 'haul',
    '🌝' => 'lleuad lawn gydag wyneb',
    '🌞' => 'lleuad ag wyneb',
    '🪐' => 'planed cylchog',
    '⭐' => 'seren ganolig wen',
    '🌟' => 'seren yn tywynnu',
    '🌠' => 'seren wib',
    '🌌' => 'y llwybr llaethog',
    '☁' => 'cwmwl',
    '⛅' => 'haul tu ôl i gwmwl',
    '⛈' => 'cwmwl â mellt a glaw',
    '🌤' => 'haul tu ôl i gwmwl bach',
    '🌥' => 'haul tu ôl i gwmwl mawr',
    '🌦' => 'haul tu ôl i gwmwl gyda glaw',
    '🌧' => 'cwmwl gyda glaw',
    '🌨' => 'cwmwl gydag eira',
    '🌩' => 'cwmwl gyda mellt',
    '🌪' => 'corwynt',
    '🌫' => 'niwl',
    '🌬' => 'wyneb gwyntog',
    '🌀' => 'seiclon',
    '🌈' => 'enfys',
    '🌂' => 'ymbarél ar gau',
    '☂' => 'ymbarél',
    '☔' => 'ymbarél gyda glaw',
    '⛱' => 'ymbarél ar lawr',
    '⚡' => 'foltedd uchel',
    '❄' => 'pluen eira',
    '☃' => 'dyn eira',
    '⛄' => 'dyn eira heb eira',
    '☄' => 'comed',
    '🔥' => 'tân',
    '💧' => 'defnyn',
    '🌊' => 'ton ddŵr',
    '🎃' => 'jack-o-lantern',
    '🎄' => 'coeden nadolig',
    '🎆' => 'tân gwyllt',
    '🎇' => 'ffon wreichion',
    '🧨' => 'gwialen tân',
    '✨' => 'gwreichion',
    '🎈' => 'balŵn',
    '🎉' => 'popiwr parti',
    '🎊' => 'pelen gonffeti',
    '🎋' => 'coeden tanabata',
    '🎍' => 'addurn pinwydden',
    '🎎' => 'doliau Japaneaidd',
    '🎏' => 'baner y carp',
    '🎐' => 'clychsain wynt',
    '🎑' => 'seremoni’r lleuad',
    '🧧' => 'amlen goch',
    '🎀' => 'rhuban',
    '🎁' => 'anrheg wedi’i lapio',
    '🎗' => 'rhuban atgoffa',
    '🎟' => 'tocynnau mynediad',
    '🎫' => 'tocyn',
    '🎖' => 'medal filwrol',
    '🏆' => 'tlws',
    '🏅' => 'medal chwaraeon',
    '🥇' => 'medal aur',
    '🥈' => 'medal arian',
    '🥉' => 'medal efydd',
    '⚽' => 'pêl droed',
    '⚾' => 'pêl fas',
    '🥎' => 'pêl feddal',
    '🏀' => 'pêl fasged',
    '🏐' => 'pêl-foli',
    '🏈' => 'pêl droed Americanaidd',
    '🏉' => 'pêl rygbi',
    '🎾' => 'tenis',
    '🥏' => 'disg hedfan',
    '🎳' => 'bowlio',
    '🏏' => 'criced',
    '🏑' => 'hoci cae',
    '🏒' => 'cnap a ffon hoci iâ',
    '🥍' => 'lacrós',
    '🏓' => 'ping-pong',
    '🏸' => 'badminton',
    '🥊' => 'maneg bocsio',
    '🥋' => 'gwisg y crefftau ymladd',
    '🥅' => 'rhwyd gôl',
    '⛳' => 'baner mewn twll',
    '⛸' => 'sglefrio iâ',
    '🎣' => 'polyn pysgota',
    '🤿' => 'masg deifio',
    '🎽' => 'crys rhedeg',
    '🎿' => 'sgîs',
    '🛷' => 'sled',
    '🥌' => 'carreg cyrlio',
    '🎯' => 'ergyd uniongyrchol',
    '🪀' => 'io-io',
    '🪁' => 'barcud',
    '🔫' => 'pistol dŵr',
    '🎱' => 'biliards',
    '🔮' => 'pêl grisial',
    '🪄' => 'ffon hud',
    '🎮' => 'gêm fideo',
    '🕹' => 'ffon reoli',
    '🎰' => 'peiriant slot',
    '🎲' => 'dis',
    '🧩' => 'jig-so',
    '🧸' => 'tedi bêr',
    '🪅' => 'piñata',
    '🪩' => 'pêl ddrych',
    '🪆' => 'doliau sy’n nythu',
    '♠' => 'siwt rhofiau',
    '♥' => 'siwt calonnau',
    '♦' => 'siwt diemwntau',
    '♣' => 'siwt clybiau',
    '♟' => 'gwerinwr gwyddbwyll',
    '🃏' => 'cellweiriwr',
    '🀄' => 'draig goch mahjong',
    '🎴' => 'cardiau chwarae blodau',
    '🎭' => 'celfyddydau perfformiadol',
    '🖼' => 'ffrâm gyda llun',
    '🎨' => 'palet arlunydd',
    '🧵' => 'edafedd',
    '🪡' => 'nodwydd wnïo',
    '🧶' => 'edau',
    '🪢' => 'cwlwm',
    '👓' => 'sbectol',
    '🕶' => 'sbectol haul',
    '🥽' => 'gogls',
    '🥼' => 'cot lab',
    '🦺' => 'siaced ddiogelwch',
    '👔' => 'tei',
    '👕' => 'crys T',
    '👖' => 'jîns',
    '🧣' => 'scarff',
    '🧤' => 'menyg',
    '🧥' => 'côt',
    '🧦' => 'sanau',
    '👗' => 'ffrog',
    '👘' => 'cimono',
    '🥻' => 'sari',
    '🩱' => 'siwt nofio',
    '🩲' => 'trôns',
    '🩳' => 'siorts',
    '👙' => 'bicini',
    '👚' => 'dillad menywod',
    '🪭' => 'ffan llaw plyg',
    '👛' => 'pwrs',
    '👜' => 'bag llaw',
    '👝' => 'cwd',
    '🛍' => 'bagiau siopa',
    '🎒' => 'bag ysgol',
    '🩴' => 'sandal thong',
    '👞' => 'esgid dyn',
    '👟' => 'esgidiau rhedeg',
    '🥾' => 'esgid gerdded',
    '🥿' => 'esgid fflat',
    '👠' => 'esgidiau sodlau uchel',
    '👡' => 'sandal menyw',
    '🩰' => 'esgidiau bale',
    '👢' => 'esgid fenyw',
    '🪮' => 'pig gwallt',
    '👑' => 'coron',
    '👒' => 'het fenyw',
    '🎩' => 'het silc',
    '🎓' => 'cap graddio',
    '🧢' => 'cap pêl fas',
    '🪖' => 'helmed filitaraidd',
    '⛑' => 'helmed â chroes wen',
    '📿' => 'gleiniau gweddïo',
    '💄' => 'minlliw',
    '💍' => 'modrwy',
    '💎' => 'gemfaen',
    '🔇' => 'seinydd wedi’i ddiffodd',
    '🔈' => 'seinydd',
    '🔉' => 'seinydd ymlaen',
    '🔊' => 'seinydd uchel',
    '📢' => 'uchelseinydd',
    '📣' => 'megaffon',
    '📯' => 'corn bost',
    '🔔' => 'cloch',
    '🔕' => 'cloch a slaes',
    '🎼' => 'sgôr cerddorol',
    '🎵' => 'nodyn cerddorol',
    '🎶' => 'nodau cerddorol',
    '🎙' => 'meicroffon stiwdio',
    '🎚' => 'llithrydd lefel',
    '🎛' => 'dyrnau rheoli',
    '🎤' => 'meicroffon',
    '🎧' => 'clustffon',
    '📻' => 'radio',
    '🎷' => 'sacsoffon',
    '🎺' => 'trwmped',
    '🪊' => 'trombôn',
    '🪗' => 'acordion',
    '🎸' => 'gitâr',
    '🎹' => 'allweddell',
    '🎻' => 'ffidl',
    '🪕' => 'banjo',
    '🥁' => 'drwm',
    '🪘' => 'drwm hir',
    '🪇' => 'maracas',
    '🪈' => 'ffliwt',
    '🪉' => 'telyn',
    '📱' => 'ffôn symudol',
    '📲' => 'ffôn symudol â saeth',
    '☎' => 'ffôn',
    '📞' => 'derbynnydd ffôn',
    '📟' => 'peiriant galw',
    '📠' => 'peiriant ffacs',
    '🔋' => 'batri',
    '🪫' => 'batri isel',
    '🔌' => 'plwg trydanol',
    '💻' => 'cluniadur',
    '🖥' => 'cyfrifiadur',
    '🖨' => 'argraffydd',
    '⌨' => 'bysellfwrdd',
    '🖱' => 'llygoden gyfrifiadurol',
    '🖲' => 'pelen lwybro',
    '💽' => 'disg mini',
    '💾' => 'disg hyblyg',
    '💿' => 'disg optegol',
    '📀' => 'dvd',
    '🧮' => 'abacws',
    '🎥' => 'camera ffilm',
    '🎞' => 'fframiau ffilm',
    '📽' => 'taflunydd ffilm',
    '🎬' => 'clepiwr',
    '📺' => 'teledu',
    '📷' => 'camera',
    '📸' => 'camera â fflach',
    '📹' => 'camera fideo',
    '📼' => 'casét fideo',
    '🔍' => 'chwyddwydr yn wynebu’r chwith',
    '🔎' => 'chwyddwydr yn wynebu’r dde',
    '🕯' => 'cannwyll',
    '💡' => 'bwlb golau',
    '🔦' => 'tortsh',
    '🏮' => 'llusern bapur coch',
    '🪔' => 'lamp diya',
    '📔' => 'llyfr nodiadau gyda chlawr addurnol',
    '📕' => 'llyfr ynghau',
    '📖' => 'llyfr agored',
    '📗' => 'llyfr gwyrdd',
    '📘' => 'llyfr glas',
    '📙' => 'llyfr oren',
    '📚' => 'llyfrau',
    '📓' => 'llyfr nodiadau',
    '📒' => 'cyfriflyfr',
    '📃' => 'tudalen gyda chwrl',
    '📜' => 'sgrôl',
    '📄' => 'tudalen yn wynebu i fyny',
    '📰' => 'papur newydd',
    '🗞' => 'papur newydd wedi’i rolio',
    '📑' => 'tabiau nodau tudalen',
    '🔖' => 'nod tudalen',
    '🏷' => 'label',
    '🪙' => 'darn arian',
    '💰' => 'bag arian',
    '🪎' => 'cist drysor',
    '💴' => 'papur arian yen',
    '💵' => 'papur arian doler',
    '💶' => 'papur arian ewro',
    '💷' => 'papur arian punt',
    '💸' => 'arian gydag adenydd',
    '💳' => 'cerdyn credyd',
    '🧾' => 'derbynneb',
    '💹' => 'siart yn cynyddu â yen',
    '✉' => 'amlen',
    '📧' => 'e-bost',
    '📨' => 'amlen yn dyfod i mewn',
    '📩' => 'amlen gyda saeth',
    '📤' => 'hambwrdd blwch allan',
    '📥' => 'hambwrdd mewnflwch',
    '📦' => 'parsel',
    '📫' => 'blwch post caeedig gyda banner wedi’i chodi',
    '📪' => 'blwch post caeedig gyda banner wedi’i gostwng',
    '📬' => 'blwch post agored gyda banner wedi’i chodi',
    '📭' => 'blwch post agored gyda banner wedi’i gostwng',
    '📮' => 'blwch post',
    '🗳' => 'blwch pleidlais gyda phleidlais',
    '✏' => 'pensil',
    '✒' => 'nib du',
    '🖋' => 'ysgrifbin',
    '🖊' => 'beiro',
    '🖌' => 'brwsh paent',
    '🖍' => 'pensil lliw',
    '📝' => 'memo',
    '💼' => 'cas friff',
    '📁' => 'ffolder ffeiliau',
    '📂' => 'agor ffolder ffeiliau',
    '🗂' => 'rhanwyr mynegai cardiau',
    '📅' => 'calendr',
    '📆' => 'calendr rwygo',
    '🗒' => 'llyfr nodiadau troellog',
    '🗓' => 'calendr troellog',
    '📇' => 'mynegai cardiau',
    '📈' => 'siart yn cynyddu',
    '📉' => 'siart yn gostwng',
    '📊' => 'siart bar',
    '📋' => 'clipfwrdd',
    '📌' => 'pin',
    '📍' => 'pin crwn',
    '📎' => 'clip papur',
    '🖇' => 'clipiau papur wedi’u cysylltu',
    '📏' => 'pren mesur',
    '📐' => 'pren mesur trionglog',
    '✂' => 'siswrn',
    '🗃' => 'blwch ffeilio cardiau',
    '🗄' => 'ffeil gabinet',
    '🗑' => 'bin sbwriel',
    '🔒' => 'clô',
    '🔓' => 'clô agored',
    '🔏' => 'clô ac ysgrifbin',
    '🔐' => 'clô ynghau gydag allwedd',
    '🔑' => 'allwedd',
    '🗝' => 'hen allwedd',
    '🔨' => 'morthwyl',
    '🪓' => 'bwyell',
    '⛏' => 'caib',
    '⚒' => 'morthwyl a chaib',
    '🛠' => 'morthwyl a sbaner',
    '🗡' => 'dagr',
    '⚔' => 'cleddyfau wedi croesi',
    '💣' => 'bom',
    '🪃' => 'bwmerang',
    '🏹' => 'bwa saeth',
    '🛡' => 'tarian',
    '🪚' => 'llif gwaith coed',
    '🔧' => 'sbaner',
    '🪛' => 'sgriwdreifar',
    '🔩' => 'nyten a bollt',
    '⚙' => 'gêr',
    '🗜' => 'cywasgedd',
    '⚖' => 'clorian',
    '🦯' => 'ffon wen',
    '🔗' => 'dolen',
    '⛓' => 'cadwyni',
    '🪝' => 'bachyn',
    '🧰' => 'blwch offer',
    '🧲' => 'magnet',
    '🪜' => 'ysgol ddringo',
    '🪏' => 'rhaw',
    '⚗' => 'distyllydd',
    '🧪' => 'tiwb profi',
    '🧫' => 'dysgl petri',
    '🧬' => 'dna',
    '🔬' => 'microsgop',
    '🔭' => 'telesgop',
    '📡' => 'antena lloeren',
    '💉' => 'chwistrell',
    '🩸' => 'diferyn o waed',
    '💊' => 'pilsen',
    '🩹' => 'bandej glynu',
    '🩼' => 'bagl',
    '🩺' => 'stethosgop',
    '🩻' => 'pelydr-x',
    '🚪' => 'drws',
    '🛗' => 'lifft',
    '🪞' => 'drych',
    '🪟' => 'ffenestr',
    '🛏' => 'gwely',
    '🛋' => 'soffa a lamp',
    '🪑' => 'cadair',
    '🚽' => 'toiled',
    '🪠' => 'offeryn sugno',
    '🚿' => 'cawod',
    '🛁' => 'twba bath',
    '🪤' => 'trap llygod',
    '🪒' => 'rasel',
    '🧴' => 'potel hufen',
    '🧷' => 'pin diogelwch',
    '🧹' => 'ysgubell',
    '🧺' => 'basged',
    '🧻' => 'rholyn o bapur',
    '🪣' => 'bwced',
    '🧼' => 'sebon',
    '🫧' => 'swigod',
    '🪥' => 'brwsh dannedd',
    '🧽' => 'sbwng',
    '🧯' => 'diffoddydd tân',
    '🛒' => 'troli siopa',
    '🚬' => 'ysmygu',
    '⚰' => 'arch',
    '🪦' => 'carreg fedd',
    '⚱' => 'wrn angladd',
    '🧿' => 'amwled nazar',
    '🪬' => 'hamsa',
    '🗿' => 'moai',
    '🪧' => 'placard',
    '🪪' => 'cerdyn adnabod',
    '🏧' => 'arwydd peiriant codi arian',
    '🚮' => 'arwydd sbwriel mewn bin',
    '🚰' => 'dŵr yfed',
    '♿' => 'cadair olwyn',
    '🚹' => 'ystafell ymolchi i ddynion',
    '🚺' => 'ystafell ymolchi i fenywod',
    '🚻' => 'ystafell ymolchi',
    '🚼' => 'symbol babi',
    '🚾' => 'tŷ bach',
    '🛂' => 'arolygaeth pasbort',
    '🛃' => 'tollau',
    '🛄' => 'hawlio bagiau',
    '🛅' => 'bagiau wedi’u gadael',
    '⚠' => 'rhybudd',
    '🚸' => 'plant yn croesi',
    '⛔' => 'dim mynediad',
    '🚫' => 'wedi’i wahardd',
    '🚳' => 'dim beiciau',
    '🚭' => 'dim ysmygu',
    '🚯' => 'dim sbwriel',
    '🚱' => 'dŵr na ellir ei yfed',
    '🚷' => 'dim cerddwyr',
    '📵' => 'dim ffonau symudol',
    '🔞' => 'neb o dan un deg wyth oed',
    '☢' => 'ymbelydrol',
    '☣' => 'bioberyg',
    '⬆' => 'saeth i fyny',
    '↗' => 'saeth i fyny-dde',
    '➡' => 'saeth i’r dde',
    '↘' => 'saeth i lawr-dde',
    '⬇' => 'saeth i lawr',
    '↙' => 'saeth i lawr-chwith',
    '⬅' => 'saeth i’r chwith',
    '↖' => 'saeth i fyny-chwith',
    '↕' => 'saeth i fyny-lawr',
    '↔' => 'saeth chwith-dde',
    '↩' => 'saeth i’r dde yn troi i’r chwith',
    '↪' => 'saeth i’r chwith yn troi i’r dde',
    '⤴' => 'saeth i’r dde yn troi i fyny',
    '⤵' => 'saeth i’r dde yn troi i lawr',
    '🔃' => 'saethau clocwedd fertigol',
    '🔄' => 'botwm saethau gwrthglocwedd',
    '🔙' => 'saeth BACK',
    '🔚' => 'saeth END',
    '🔛' => 'saeth ON!',
    '🔜' => 'saeth SOON',
    '🔝' => 'saeth TOP',
    '🛐' => 'man addoli',
    '⚛' => 'symbol o atom',
    '🕉' => 'om',
    '✡' => 'seren Dafydd',
    '☸' => 'olwyn dharma',
    '☯' => 'yin yang',
    '✝' => 'croes ladin',
    '☦' => 'croes uniongred',
    '☪' => 'seren a chilgant',
    '☮' => 'symbol hedd',
    '🕎' => 'menorah',
    '🔯' => 'seren chwe ochr dotiog',
    '🪯' => 'khanda',
    '♈' => 'yr Hwrdd',
    '♉' => 'y Tarw',
    '♊' => 'yr Efeilliaid',
    '♋' => 'y Cranc',
    '♌' => 'y Llew',
    '♍' => 'y Forwyn',
    '♎' => 'y Fantol',
    '♏' => 'y Sgorpion',
    '♐' => 'y Saethydd',
    '♑' => 'yr Afr',
    '♒' => 'y Dyfrwr',
    '♓' => 'y Pysgod',
    '⛎' => 'ophiuchus',
    '🔀' => 'botwm cymysgu traciau',
    '🔁' => 'botwm ailadrodd',
    '🔂' => 'botwm ailadrodd sengl',
    '▶' => 'botwm chwarae',
    '⏩' => 'botwm blaenyrru cyflym',
    '⏭' => 'botwm trac nesaf',
    '⏯' => 'botwm chwarae neu saib',
    '◀' => 'botwm cildroi',
    '⏪' => 'botwm cildroi cyflym',
    '⏮' => 'botwm trac olaf',
    '🔼' => 'botwm i fyny',
    '⏫' => 'botwm i fyny cyflym',
    '🔽' => 'botwm i lawr',
    '⏬' => 'botwm i lawr cyflym',
    '⏸' => 'botwm saib',
    '⏹' => 'botwm stop',
    '⏺' => 'botwm recordio',
    '⏏' => 'botwm allfwrw',
    '🎦' => 'sinema',
    '🔅' => 'botwm pylu',
    '🔆' => 'botwm disglair',
    '📶' => 'barau antena',
    '🛜' => 'diwifr',
    '📳' => 'modd dirgryniad',
    '📴' => 'ffôn symudol wedi’i ddiffodd',
    '♀' => 'arwydd benyw',
    '♂' => 'arwydd gwrw',
    '⚧' => 'symbol trawsryweddol',
    '✖' => 'lluosi',
    '➕' => 'adio',
    '➖' => 'tynnu',
    '➗' => 'rhannu',
    '🟰' => 'arwydd hafal trwm',
    '♾' => 'anfeidredd',
    '‼' => 'ebychnod dwbl',
    '⁉' => 'marc cwestiwn ag ebychnod',
    '❓' => 'marc cwestiwn',
    '❔' => 'marc cwestiwn gwyn',
    '❕' => 'ebychnod gwyn',
    '❗' => 'ebychnod',
    '〰' => 'llinell donnog',
    '💱' => 'cyfnewid arian cyfredol',
    '💲' => 'arwydd doler drom',
    '⚕' => 'arwydd meddygol',
    '♻' => 'symbol ailgylchu',
    '⚜' => 'gellesgen',
    '🔱' => 'arwyddlun tryfer',
    '📛' => 'bathodyn enw',
    '🔰' => 'symbol Japaneaidd am ddechreuwr',
    '⭕' => 'cylch coch gwag',
    '✅' => 'marc tic gwyn trwm',
    '☑' => 'blwch pleidlais gyda thic',
    '✔' => 'marc tic trwm',
    '❌' => 'marc croes',
    '❎' => 'botwm croes',
    '➰' => 'dolen gyrliog',
    '➿' => 'dolen gyrliog ddwbl',
    '〽' => 'marc aryneilio rhannol',
    '✳' => 'asterics wyth pwynt',
    '✴' => 'seren wyth pwynt',
    '❇' => 'fflachiad',
    '™' => 'nod masnach',
    '🫟' => 'slempio',
    '🔠' => 'mewnbwn llythrennau mawr ladin',
    '🔡' => 'mewnbwn llythrennau bach lladin',
    '🔢' => 'mewnbwn rhifedd',
    '🔣' => 'mewnbwn symbylau',
    '🔤' => 'mewnbwn llythrennau lladin',
    '🅰' => 'botwm A (grwp gwaed)',
    '🆎' => 'botwm AB (grwp gwaed)',
    '🅱' => 'botwm B (grwp gwaed)',
    '🆑' => 'botwm CL',
    '🆒' => 'botwm COOL',
    '🆓' => 'botwm FREE',
    'ℹ' => 'gwybodaeth',
    '🆔' => 'botwm ID',
    'Ⓜ' => 'llythyren M mewn cylch',
    '🆕' => 'botwm NEW',
    '🆖' => 'botwm NG',
    '🅾' => 'botwm O (grwp gwaed)',
    '🆗' => 'botwm OK',
    '🅿' => 'botwm P',
    '🆘' => 'botwm SOS',
    '🆙' => 'botwm UP!',
    '🆚' => 'botwm VS',
    '🈁' => 'katakana koko mewn sgwâr',
    '🈂' => 'katakana sa mewn sgwâr',
    '🈷' => 'ideograff lleuad mewn sgwâr',
    '🈶' => 'ideograff bodoli mewn sgwâr',
    '🈯' => 'ideograff bys mewn sgwâr',
    '🉐' => 'ideograff mantais mewn cylch',
    '🈹' => 'ideograff rhannu mewn sgwâr',
    '🈚' => 'ideograff negyddiad mewn sgwâr',
    '🈲' => 'ideograff gwaharddiad mewn sgwâr',
    '🉑' => 'ideograff derbyn mewn cylch',
    '🈸' => 'ideograff cais mewn sgwâr',
    '🈴' => 'ideograff gyda’i gilydd mewn sgwâr',
    '🈳' => 'ideograff gwag mewn sgwâr',
    '㊗' => 'ideograff cyfarchion mewn cylch',
    '㊙' => 'ideograff cyfrinach mewn cylch',
    '🈺' => 'ideograff gweithredu mewn sgwâr',
    '🈵' => 'ideograff llawnder mewn sgwâr',
    '🔴' => 'cylch coch',
    '🟠' => 'cylch oren',
    '🟡' => 'cylch melyn',
    '🟢' => 'cylch gwyrdd',
    '🔵' => 'cylch glas',
    '🟣' => 'cylch piws',
    '🟤' => 'cylch brown',
    '⚫' => 'cylch du',
    '⚪' => 'cylch gwyn',
    '🟥' => 'sgwâr coch',
    '🟧' => 'sgwâr oren',
    '🟨' => 'sgwâr melyn',
    '🟩' => 'sgwâr gwyrdd',
    '🟦' => 'sgwâr glas',
    '🟪' => 'sgwâr piws',
    '🟫' => 'sgwâr brown',
    '⬛' => 'sgwâr mawr du',
    '⬜' => 'sgwâr mawr wyn',
    '◼' => 'sgwâr canolig du',
    '◻' => 'sgwâr canolig gwyn',
    '◾' => 'sgwâr canolig-bach du',
    '◽' => 'sgwâr canolig-bach gwyn',
    '▪' => 'sgwâr bach du',
    '▫' => 'sgwâr bach gwyn',
    '🔶' => 'diemwnt mawr oren',
    '🔷' => 'diemwnt mawr glas',
    '🔸' => 'diemwnt bach oren',
    '🔹' => 'diemwnt bach glas',
    '🔺' => 'triongl coch yn pwyntio tuag i fyny',
    '🔻' => 'triongl coch yn pwyntio tuag i lawr',
    '💠' => 'diemwnt â dot',
    '🔘' => 'botwm radio',
    '🔳' => 'botwm sgwâr gwyn',
    '🔲' => 'botwm sgwâr du',
    '🏁' => 'baner frith',
    '🚩' => 'baner drionglog',
    '🎌' => 'baneri wedi croesi',
    '🏴' => 'chwifio baner ddu',
    '🏳' => 'chwifio baner wen',
];
