<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'համբույր․ անձ անձ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'համբույր․ անձ անձ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'համբույր․ անձ անձ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'համբույր․ անձ անձ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'համբույր․ անձ անձ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'համբույր․ անձ անձ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'համբույր․ անձ անձ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'համբույր․ անձ անձ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'համբույր․ անձ անձ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'համբույր․ անձ անձ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'համբույր․ անձ անձ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'համբույր․ անձ անձ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'համբույր․ անձ անձ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'համբույր․ անձ անձ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'համբույր․ անձ անձ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'համբույր․ անձ անձ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'համբույր․ անձ անձ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'համբույր․ անձ անձ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'համբույր․ անձ անձ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'համբույր․ անձ անձ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏻‍❤‍💋‍👨🏻' => 'համբույր․ մարդ մարդ և բաց գույնի մաշկ',
    '👨🏻‍❤‍💋‍👨🏼' => 'համբույր․ մարդ մարդ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏻‍❤‍💋‍👨🏽' => 'համբույր․ մարդ մարդ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏻‍❤‍💋‍👨🏾' => 'համբույր․ մարդ մարդ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏻‍❤‍💋‍👨🏿' => 'համբույր․ մարդ մարդ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏼‍❤‍💋‍👨🏻' => 'համբույր․ մարդ մարդ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏼‍❤‍💋‍👨🏼' => 'համբույր․ մարդ մարդ և միջին բաց գույնի մաշկ',
    '👨🏼‍❤‍💋‍👨🏽' => 'համբույր․ մարդ մարդ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏼‍❤‍💋‍👨🏾' => 'համբույր․ մարդ մարդ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏼‍❤‍💋‍👨🏿' => 'համբույր․ մարդ մարդ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏽‍❤‍💋‍👨🏻' => 'համբույր․ մարդ մարդ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏽‍❤‍💋‍👨🏼' => 'համբույր․ մարդ մարդ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏽‍❤‍💋‍👨🏽' => 'համբույր․ մարդ մարդ և միջին գույնի մաշկ',
    '👨🏽‍❤‍💋‍👨🏾' => 'համբույր․ մարդ մարդ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏽‍❤‍💋‍👨🏿' => 'համբույր․ մարդ մարդ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏾‍❤‍💋‍👨🏻' => 'համբույր․ մարդ մարդ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏾‍❤‍💋‍👨🏼' => 'համբույր․ մարդ մարդ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏾‍❤‍💋‍👨🏽' => 'համբույր․ մարդ մարդ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏾‍❤‍💋‍👨🏾' => 'համբույր․ մարդ մարդ և միջին մուգ գույնի մաշկ',
    '👨🏾‍❤‍💋‍👨🏿' => 'համբույր․ մարդ մարդ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏿‍❤‍💋‍👨🏻' => 'համբույր․ մարդ մարդ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏿‍❤‍💋‍👨🏼' => 'համբույր․ մարդ մարդ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏿‍❤‍💋‍👨🏽' => 'համբույր․ մարդ մարդ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏿‍❤‍💋‍👨🏾' => 'համբույր․ մարդ մարդ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏿‍❤‍💋‍👨🏿' => 'համբույր․ մարդ մարդ և մուգ գույնի մաշկ',
    '👩🏻‍❤‍💋‍👨🏻' => 'համբույր․ կին մարդ և բաց գույնի մաշկ',
    '👩🏻‍❤‍💋‍👨🏼' => 'համբույր․ կին մարդ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏻‍❤‍💋‍👨🏽' => 'համբույր․ կին մարդ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏻‍❤‍💋‍👨🏾' => 'համբույր․ կին մարդ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍❤‍💋‍👨🏿' => 'համբույր․ կին մարդ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏼‍❤‍💋‍👨🏻' => 'համբույր․ կին մարդ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏼‍❤‍💋‍👨🏼' => 'համբույր․ կին մարդ և միջին բաց գույնի մաշկ',
    '👩🏼‍❤‍💋‍👨🏽' => 'համբույր․ կին մարդ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏼‍❤‍💋‍👨🏾' => 'համբույր․ կին մարդ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏼‍❤‍💋‍👨🏿' => 'համբույր․ կին մարդ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏽‍❤‍💋‍👨🏻' => 'համբույր․ կին մարդ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏽‍❤‍💋‍👨🏼' => 'համբույր․ կին մարդ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏽‍❤‍💋‍👨🏽' => 'համբույր․ կին մարդ և միջին գույնի մաշկ',
    '👩🏽‍❤‍💋‍👨🏾' => 'համբույր․ կին մարդ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏽‍❤‍💋‍👨🏿' => 'համբույր․ կին մարդ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏾‍❤‍💋‍👨🏻' => 'համբույր․ կին մարդ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏾‍❤‍💋‍👨🏼' => 'համբույր․ կին մարդ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏾‍❤‍💋‍👨🏽' => 'համբույր․ կին մարդ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏾‍❤‍💋‍👨🏾' => 'համբույր․ կին մարդ և միջին մուգ գույնի մաշկ',
    '👩🏾‍❤‍💋‍👨🏿' => 'համբույր․ կին մարդ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏿‍❤‍💋‍👨🏻' => 'համբույր․ կին մարդ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏿‍❤‍💋‍👨🏼' => 'համբույր․ կին մարդ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏿‍❤‍💋‍👨🏽' => 'համբույր․ կին մարդ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏿‍❤‍💋‍👨🏾' => 'համբույր․ կին մարդ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏿‍❤‍💋‍👨🏿' => 'համբույր․ կին մարդ և մուգ գույնի մաշկ',
    '👩🏻‍❤‍💋‍👩🏻' => 'համբույր․ կին կին և բաց գույնի մաշկ',
    '👩🏻‍❤‍💋‍👩🏼' => 'համբույր․ կին կին բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏻‍❤‍💋‍👩🏽' => 'համբույր․ կին կին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏻‍❤‍💋‍👩🏾' => 'համբույր․ կին կին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍❤‍💋‍👩🏿' => 'համբույր․ կին կին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏼‍❤‍💋‍👩🏻' => 'համբույր․ կին կին միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏼‍❤‍💋‍👩🏼' => 'համբույր․ կին կին և միջին բաց գույնի մաշկ',
    '👩🏼‍❤‍💋‍👩🏽' => 'համբույր․ կին կին միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏼‍❤‍💋‍👩🏾' => 'համբույր․ կին կին միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏼‍❤‍💋‍👩🏿' => 'համբույր․ կին կին միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏽‍❤‍💋‍👩🏻' => 'համբույր․ կին կին միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏽‍❤‍💋‍👩🏼' => 'համբույր․ կին կին միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏽‍❤‍💋‍👩🏽' => 'համբույր․ կին կին և միջին գույնի մաշկ',
    '👩🏽‍❤‍💋‍👩🏾' => 'համբույր․ կին կին միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏽‍❤‍💋‍👩🏿' => 'համբույր․ կին կին միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏾‍❤‍💋‍👩🏻' => 'համբույր․ կին կին միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏾‍❤‍💋‍👩🏼' => 'համբույր․ կին կին միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏾‍❤‍💋‍👩🏽' => 'համբույր․ կին կին միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏾‍❤‍💋‍👩🏾' => 'համբույր․ կին կին և միջին մուգ գույնի մաշկ',
    '👩🏾‍❤‍💋‍👩🏿' => 'համբույր․ կին կին միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏿‍❤‍💋‍👩🏻' => 'համբույր․ կին կին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏿‍❤‍💋‍👩🏼' => 'համբույր․ կին կին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏿‍❤‍💋‍👩🏽' => 'համբույր․ կին կին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏿‍❤‍💋‍👩🏾' => 'համբույր․ կին կին մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏿‍❤‍💋‍👩🏿' => 'համբույր․ կին կին և մուգ գույնի մաշկ',
    '🧑🏻‍🫯‍🧑🏼' => 'ըմբշամարտիկներ․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏻‍🫯‍🧑🏽' => 'ըմբշամարտիկներ․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏻‍🫯‍🧑🏾' => 'ըմբշամարտիկներ․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏻‍🫯‍🧑🏿' => 'ըմբշամարտիկներ․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏼‍🫯‍🧑🏻' => 'ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏼‍🫯‍🧑🏽' => 'ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏼‍🫯‍🧑🏾' => 'ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏼‍🫯‍🧑🏿' => 'ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏽‍🫯‍🧑🏻' => 'ըմբշամարտիկներ․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏽‍🫯‍🧑🏼' => 'ըմբշամարտիկներ․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏽‍🫯‍🧑🏾' => 'ըմբշամարտիկներ․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏽‍🫯‍🧑🏿' => 'ըմբշամարտիկներ․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏾‍🫯‍🧑🏻' => 'ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏾‍🫯‍🧑🏼' => 'ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏾‍🫯‍🧑🏽' => 'ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏾‍🫯‍🧑🏿' => 'ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏿‍🫯‍🧑🏻' => 'ըմբշամարտիկներ․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏿‍🫯‍🧑🏼' => 'ըմբշամարտիկներ․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏿‍🫯‍🧑🏽' => 'ըմբշամարտիկներ․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏿‍🫯‍🧑🏾' => 'ըմբշամարտիկներ․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏻‍❤‍🧑🏼' => 'սրտիկով զույգ․ անձ անձ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏻‍❤‍🧑🏽' => 'սրտիկով զույգ․ անձ անձ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏻‍❤‍🧑🏾' => 'սրտիկով զույգ․ անձ անձ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏻‍❤‍🧑🏿' => 'սրտիկով զույգ․ անձ անձ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏼‍❤‍🧑🏻' => 'սրտիկով զույգ․ անձ անձ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏼‍❤‍🧑🏽' => 'սրտիկով զույգ․ անձ անձ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏼‍❤‍🧑🏾' => 'սրտիկով զույգ․ անձ անձ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏼‍❤‍🧑🏿' => 'սրտիկով զույգ․ անձ անձ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏽‍❤‍🧑🏻' => 'սրտիկով զույգ․ անձ անձ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏽‍❤‍🧑🏼' => 'սրտիկով զույգ․ անձ անձ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏽‍❤‍🧑🏾' => 'սրտիկով զույգ․ անձ անձ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏽‍❤‍🧑🏿' => 'սրտիկով զույգ․ անձ անձ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏾‍❤‍🧑🏻' => 'սրտիկով զույգ․ անձ անձ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏾‍❤‍🧑🏼' => 'սրտիկով զույգ․ անձ անձ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏾‍❤‍🧑🏽' => 'սրտիկով զույգ․ անձ անձ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏾‍❤‍🧑🏿' => 'սրտիկով զույգ․ անձ անձ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏿‍❤‍🧑🏻' => 'սրտիկով զույգ․ անձ անձ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏿‍❤‍🧑🏼' => 'սրտիկով զույգ․ անձ անձ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏿‍❤‍🧑🏽' => 'սրտիկով զույգ․ անձ անձ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏿‍❤‍🧑🏾' => 'սրտիկով զույգ․ անձ անձ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏻‍🐰‍🧑🏼' => 'ճագարի ականջներով մարդիկ․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏻‍🐰‍🧑🏽' => 'ճագարի ականջներով մարդիկ․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏻‍🐰‍🧑🏾' => 'ճագարի ականջներով մարդիկ․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏻‍🐰‍🧑🏿' => 'ճագարի ականջներով մարդիկ․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏼‍🐰‍🧑🏻' => 'ճագարի ականջներով մարդիկ․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏼‍🐰‍🧑🏽' => 'ճագարի ականջներով մարդիկ․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏼‍🐰‍🧑🏾' => 'ճագարի ականջներով մարդիկ․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏼‍🐰‍🧑🏿' => 'ճագարի ականջներով մարդիկ․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏽‍🐰‍🧑🏻' => 'ճագարի ականջներով մարդիկ․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏽‍🐰‍🧑🏼' => 'ճագարի ականջներով մարդիկ․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏽‍🐰‍🧑🏾' => 'ճագարի ականջներով մարդիկ․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏽‍🐰‍🧑🏿' => 'ճագարի ականջներով մարդիկ․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏾‍🐰‍🧑🏻' => 'ճագարի ականջներով մարդիկ․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏾‍🐰‍🧑🏼' => 'ճագարի ականջներով մարդիկ․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏾‍🐰‍🧑🏽' => 'ճագարի ականջներով մարդիկ․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏾‍🐰‍🧑🏿' => 'ճագարի ականջներով մարդիկ․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏿‍🐰‍🧑🏻' => 'ճագարի ականջներով մարդիկ․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏿‍🐰‍🧑🏼' => 'ճագարի ականջներով մարդիկ․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏿‍🐰‍🧑🏽' => 'ճագարի ականջներով մարդիկ․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏿‍🐰‍🧑🏾' => 'ճագարի ականջներով մարդիկ․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏻‍🫯‍👨🏼' => 'տղամարդ ըմբշամարտիկներ․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏻‍🫯‍👨🏽' => 'տղամարդ ըմբշամարտիկներ․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏻‍🫯‍👨🏾' => 'տղամարդ ըմբշամարտիկներ․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏻‍🫯‍👨🏿' => 'տղամարդ ըմբշամարտիկներ․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏼‍🫯‍👨🏻' => 'տղամարդ ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏼‍🫯‍👨🏽' => 'տղամարդ ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏼‍🫯‍👨🏾' => 'տղամարդ ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏼‍🫯‍👨🏿' => 'տղամարդ ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏽‍🫯‍👨🏻' => 'տղամարդ ըմբշամարտիկներ․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏽‍🫯‍👨🏼' => 'տղամարդ ըմբշամարտիկներ․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏽‍🫯‍👨🏾' => 'տղամարդ ըմբշամարտիկներ․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏽‍🫯‍👨🏿' => 'տղամարդ ըմբշամարտիկներ․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏾‍🫯‍👨🏻' => 'տղամարդ ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏾‍🫯‍👨🏼' => 'տղամարդ ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏾‍🫯‍👨🏽' => 'տղամարդ ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏾‍🫯‍👨🏿' => 'տղամարդ ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏿‍🫯‍👨🏻' => 'տղամարդ ըմբշամարտիկներ․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏿‍🫯‍👨🏼' => 'տղամարդ ըմբշամարտիկներ․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏿‍🫯‍👨🏽' => 'տղամարդ ըմբշամարտիկներ․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏿‍🫯‍👨🏾' => 'տղամարդ ըմբշամարտիկներ․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏻‍❤‍👨🏻' => 'սրտիկով զույգ․ մարդ մարդ և բաց գույնի մաշկ',
    '👨🏻‍❤‍👨🏼' => 'սրտիկով զույգ․ մարդ մարդ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏻‍❤‍👨🏽' => 'սրտիկով զույգ․ մարդ մարդ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏻‍❤‍👨🏾' => 'սրտիկով զույգ․ մարդ մարդ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏻‍❤‍👨🏿' => 'սրտիկով զույգ․ մարդ մարդ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏼‍❤‍👨🏻' => 'սրտիկով զույգ․ մարդ մարդ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏼‍❤‍👨🏼' => 'սրտիկով զույգ․ մարդ մարդ և միջին բաց գույնի մաշկ',
    '👨🏼‍❤‍👨🏽' => 'սրտիկով զույգ․ մարդ մարդ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏼‍❤‍👨🏾' => 'սրտիկով զույգ․ մարդ մարդ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏼‍❤‍👨🏿' => 'սրտիկով զույգ․ մարդ մարդ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏽‍❤‍👨🏻' => 'սրտիկով զույգ․ մարդ մարդ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏽‍❤‍👨🏼' => 'սրտիկով զույգ․ մարդ մարդ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏽‍❤‍👨🏽' => 'սրտիկով զույգ․ մարդ մարդ և միջին գույնի մաշկ',
    '👨🏽‍❤‍👨🏾' => 'սրտիկով զույգ․ մարդ մարդ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏽‍❤‍👨🏿' => 'սրտիկով զույգ․ մարդ մարդ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏾‍❤‍👨🏻' => 'սրտիկով զույգ․ մարդ մարդ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏾‍❤‍👨🏼' => 'սրտիկով զույգ․ մարդ մարդ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏾‍❤‍👨🏽' => 'սրտիկով զույգ․ մարդ մարդ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏾‍❤‍👨🏾' => 'սրտիկով զույգ․ մարդ մարդ և միջին մուգ գույնի մաշկ',
    '👨🏾‍❤‍👨🏿' => 'սրտիկով զույգ․ մարդ մարդ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏿‍❤‍👨🏻' => 'սրտիկով զույգ․ մարդ մարդ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏿‍❤‍👨🏼' => 'սրտիկով զույգ․ մարդ մարդ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏿‍❤‍👨🏽' => 'սրտիկով զույգ․ մարդ մարդ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏿‍❤‍👨🏾' => 'սրտիկով զույգ․ մարդ մարդ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏿‍❤‍👨🏿' => 'սրտիկով զույգ․ մարդ մարդ և մուգ գույնի մաշկ',
    '👨🏻‍🐰‍👨🏼' => 'զվարճացող տղամարդիկ․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏻‍🐰‍👨🏽' => 'զվարճացող տղամարդիկ․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏻‍🐰‍👨🏾' => 'զվարճացող տղամարդիկ․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏻‍🐰‍👨🏿' => 'զվարճացող տղամարդիկ․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏼‍🐰‍👨🏻' => 'զվարճացող տղամարդիկ․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏼‍🐰‍👨🏽' => 'զվարճացող տղամարդիկ․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏼‍🐰‍👨🏾' => 'զվարճացող տղամարդիկ․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏼‍🐰‍👨🏿' => 'զվարճացող տղամարդիկ․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏽‍🐰‍👨🏻' => 'զվարճացող տղամարդիկ․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏽‍🐰‍👨🏼' => 'զվարճացող տղամարդիկ․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏽‍🐰‍👨🏾' => 'զվարճացող տղամարդիկ․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏽‍🐰‍👨🏿' => 'զվարճացող տղամարդիկ․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏾‍🐰‍👨🏻' => 'զվարճացող տղամարդիկ․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏾‍🐰‍👨🏼' => 'զվարճացող տղամարդիկ․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏾‍🐰‍👨🏽' => 'զվարճացող տղամարդիկ․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏾‍🐰‍👨🏿' => 'զվարճացող տղամարդիկ․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏿‍🐰‍👨🏻' => 'զվարճացող տղամարդիկ․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏿‍🐰‍👨🏼' => 'զվարճացող տղամարդիկ․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏿‍🐰‍👨🏽' => 'զվարճացող տղամարդիկ․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏿‍🐰‍👨🏾' => 'զվարճացող տղամարդիկ․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍🫯‍👩🏼' => 'կին ըմբշամարտիկներ․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏻‍🫯‍👩🏽' => 'կին ըմբշամարտիկներ․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏻‍🫯‍👩🏾' => 'կին ըմբշամարտիկներ․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍🫯‍👩🏿' => 'կին ըմբշամարտիկներ․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏼‍🫯‍👩🏻' => 'կին ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏼‍🫯‍👩🏽' => 'կին ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏼‍🫯‍👩🏾' => 'կին ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏼‍🫯‍👩🏿' => 'կին ըմբշամարտիկներ․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏽‍🫯‍👩🏻' => 'կին ըմբշամարտիկներ․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏽‍🫯‍👩🏼' => 'կին ըմբշամարտիկներ․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏽‍🫯‍👩🏾' => 'կին ըմբշամարտիկներ․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏽‍🫯‍👩🏿' => 'կին ըմբշամարտիկներ․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏾‍🫯‍👩🏻' => 'կին ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏾‍🫯‍👩🏼' => 'կին ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏾‍🫯‍👩🏽' => 'կին ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏾‍🫯‍👩🏿' => 'կին ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏿‍🫯‍👩🏻' => 'կին ըմբշամարտիկներ․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏿‍🫯‍👩🏼' => 'կին ըմբշամարտիկներ․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏿‍🫯‍👩🏽' => 'կին ըմբշամարտիկներ․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏿‍🫯‍👩🏾' => 'կին ըմբշամարտիկներ․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍❤‍👨🏻' => 'սրտիկով զույգ․ կին մարդ և բաց գույնի մաշկ',
    '👩🏻‍❤‍👨🏼' => 'սրտիկով զույգ․ կին մարդ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏻‍❤‍👨🏽' => 'սրտիկով զույգ․ կին մարդ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏻‍❤‍👨🏾' => 'սրտիկով զույգ․ կին մարդ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍❤‍👨🏿' => 'սրտիկով զույգ․ կին մարդ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏼‍❤‍👨🏻' => 'սրտիկով զույգ․ կին մարդ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏼‍❤‍👨🏼' => 'սրտիկով զույգ․ կին մարդ և միջին բաց գույնի մաշկ',
    '👩🏼‍❤‍👨🏽' => 'սրտիկով զույգ․ կին մարդ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏼‍❤‍👨🏾' => 'սրտիկով զույգ․ կին մարդ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏼‍❤‍👨🏿' => 'սրտիկով զույգ․ կին մարդ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏽‍❤‍👨🏻' => 'սրտիկով զույգ․ կին մարդ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏽‍❤‍👨🏼' => 'սրտիկով զույգ․ կին մարդ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏽‍❤‍👨🏽' => 'սրտիկով զույգ․ կին մարդ և միջին գույնի մաշկ',
    '👩🏽‍❤‍👨🏾' => 'սրտիկով զույգ․ կին մարդ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏽‍❤‍👨🏿' => 'սրտիկով զույգ․ կին մարդ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏾‍❤‍👨🏻' => 'սրտիկով զույգ․ կին մարդ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏾‍❤‍👨🏼' => 'սրտիկով զույգ․ կին մարդ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏾‍❤‍👨🏽' => 'սրտիկով զույգ․ կին մարդ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏾‍❤‍👨🏾' => 'սրտիկով զույգ․ կին մարդ և միջին մուգ գույնի մաշկ',
    '👩🏾‍❤‍👨🏿' => 'սրտիկով զույգ․ կին մարդ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏿‍❤‍👨🏻' => 'սրտիկով զույգ․ կին մարդ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏿‍❤‍👨🏼' => 'սրտիկով զույգ․ կին մարդ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏿‍❤‍👨🏽' => 'սրտիկով զույգ․ կին մարդ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏿‍❤‍👨🏾' => 'սրտիկով զույգ․ կին մարդ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏿‍❤‍👨🏿' => 'սրտիկով զույգ․ կին մարդ և մուգ գույնի մաշկ',
    '👩🏻‍❤‍👩🏻' => 'սրտիկով զույգ․ կին կին և բաց գույնի մաշկ',
    '👩🏻‍❤‍👩🏼' => 'սրտիկով զույգ․ կին կին բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏻‍❤‍👩🏽' => 'սրտիկով զույգ․ կին կին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏻‍❤‍👩🏾' => 'սրտիկով զույգ․ կին կին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍❤‍👩🏿' => 'սրտիկով զույգ․ կին կին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏼‍❤‍👩🏻' => 'սրտիկով զույգ․ կին կին միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏼‍❤‍👩🏼' => 'սրտիկով զույգ․ կին կին և միջին բաց գույնի մաշկ',
    '👩🏼‍❤‍👩🏽' => 'սրտիկով զույգ․ կին կին միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏼‍❤‍👩🏾' => 'սրտիկով զույգ․ կին կին միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏼‍❤‍👩🏿' => 'սրտիկով զույգ․ կին կին միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏽‍❤‍👩🏻' => 'սրտիկով զույգ․ կին կին միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏽‍❤‍👩🏼' => 'սրտիկով զույգ․ կին կին միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏽‍❤‍👩🏽' => 'սրտիկով զույգ․ կին կին և միջին գույնի մաշկ',
    '👩🏽‍❤‍👩🏾' => 'սրտիկով զույգ․ կին կին միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏽‍❤‍👩🏿' => 'սրտիկով զույգ․ կին կին միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏾‍❤‍👩🏻' => 'սրտիկով զույգ․ կին կին միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏾‍❤‍👩🏼' => 'սրտիկով զույգ․ կին կին միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏾‍❤‍👩🏽' => 'սրտիկով զույգ․ կին կին միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏾‍❤‍👩🏾' => 'սրտիկով զույգ․ կին կին և միջին մուգ գույնի մաշկ',
    '👩🏾‍❤‍👩🏿' => 'սրտիկով զույգ․ կին կին միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏿‍❤‍👩🏻' => 'սրտիկով զույգ․ կին կին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏿‍❤‍👩🏼' => 'սրտիկով զույգ․ կին կին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏿‍❤‍👩🏽' => 'սրտիկով զույգ․ կին կին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏿‍❤‍👩🏾' => 'սրտիկով զույգ․ կին կին մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏿‍❤‍👩🏿' => 'սրտիկով զույգ․ կին կին և մուգ գույնի մաշկ',
    '👩🏻‍🐰‍👩🏼' => 'զվարճացող կանայք․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏻‍🐰‍👩🏽' => 'զվարճացող կանայք․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏻‍🐰‍👩🏾' => 'զվարճացող կանայք․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍🐰‍👩🏿' => 'զվարճացող կանայք․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏼‍🐰‍👩🏻' => 'զվարճացող կանայք․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏼‍🐰‍👩🏽' => 'զվարճացող կանայք․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏼‍🐰‍👩🏾' => 'զվարճացող կանայք․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏼‍🐰‍👩🏿' => 'զվարճացող կանայք․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏽‍🐰‍👩🏻' => 'զվարճացող կանայք․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏽‍🐰‍👩🏼' => 'զվարճացող կանայք․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏽‍🐰‍👩🏾' => 'զվարճացող կանայք․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏽‍🐰‍👩🏿' => 'զվարճացող կանայք․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏾‍🐰‍👩🏻' => 'զվարճացող կանայք․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏾‍🐰‍👩🏼' => 'զվարճացող կանայք․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏾‍🐰‍👩🏽' => 'զվարճացող կանայք․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏾‍🐰‍👩🏿' => 'զվարճացող կանայք․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏿‍🐰‍👩🏻' => 'զվարճացող կանայք․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏿‍🐰‍👩🏼' => 'զվարճացող կանայք․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏿‍🐰‍👩🏽' => 'զվարճացող կանայք․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏿‍🐰‍👩🏾' => 'զվարճացող կանայք․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏻‍🤝‍🧑🏻' => 'իրար ձեռք բռնած մարդիկ․ բաց գույնի մաշկ',
    '🧑🏻‍🤝‍🧑🏼' => 'իրար ձեռք բռնած մարդիկ․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏻‍🤝‍🧑🏽' => 'իրար ձեռք բռնած մարդիկ․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏻‍🤝‍🧑🏾' => 'իրար ձեռք բռնած մարդիկ․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏻‍🤝‍🧑🏿' => 'իրար ձեռք բռնած մարդիկ․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏼‍🤝‍🧑🏻' => 'իրար ձեռք բռնած մարդիկ․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏼‍🤝‍🧑🏼' => 'իրար ձեռք բռնած մարդիկ․ միջին բաց գույնի մաշկ',
    '🧑🏼‍🤝‍🧑🏽' => 'իրար ձեռք բռնած մարդիկ․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏼‍🤝‍🧑🏾' => 'իրար ձեռք բռնած մարդիկ․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏼‍🤝‍🧑🏿' => 'իրար ձեռք բռնած մարդիկ․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏽‍🤝‍🧑🏻' => 'իրար ձեռք բռնած մարդիկ․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏽‍🤝‍🧑🏼' => 'իրար ձեռք բռնած մարդիկ․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏽‍🤝‍🧑🏽' => 'իրար ձեռք բռնած մարդիկ․ միջին գույնի մաշկ',
    '🧑🏽‍🤝‍🧑🏾' => 'իրար ձեռք բռնած մարդիկ․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏽‍🤝‍🧑🏿' => 'իրար ձեռք բռնած մարդիկ․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏾‍🤝‍🧑🏻' => 'իրար ձեռք բռնած մարդիկ․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏾‍🤝‍🧑🏼' => 'իրար ձեռք բռնած մարդիկ․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏾‍🤝‍🧑🏽' => 'իրար ձեռք բռնած մարդիկ․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏾‍🤝‍🧑🏾' => 'իրար ձեռք բռնած մարդիկ․ միջին մուգ գույնի մաշկ',
    '🧑🏾‍🤝‍🧑🏿' => 'իրար ձեռք բռնած մարդիկ․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '🧑🏿‍🤝‍🧑🏻' => 'իրար ձեռք բռնած մարդիկ․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🧑🏿‍🤝‍🧑🏼' => 'իրար ձեռք բռնած մարդիկ․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🧑🏿‍🤝‍🧑🏽' => 'իրար ձեռք բռնած մարդիկ․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🧑🏿‍🤝‍🧑🏾' => 'իրար ձեռք բռնած մարդիկ․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🧑🏿‍🤝‍🧑🏿' => 'իրար ձեռք բռնած մարդիկ․ մուգ գույնի մաշկ',
    '👩🏻‍🤝‍👩🏼' => 'իրար ձեռք բռնած կանայք․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏻‍🤝‍👩🏽' => 'իրար ձեռք բռնած կանայք․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏻‍🤝‍👩🏾' => 'իրար ձեռք բռնած կանայք․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍🤝‍👩🏿' => 'իրար ձեռք բռնած կանայք․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏼‍🤝‍👩🏻' => 'իրար ձեռք բռնած կանայք․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏼‍🤝‍👩🏽' => 'իրար ձեռք բռնած կանայք․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏼‍🤝‍👩🏾' => 'իրար ձեռք բռնած կանայք․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏼‍🤝‍👩🏿' => 'իրար ձեռք բռնած կանայք․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏽‍🤝‍👩🏻' => 'իրար ձեռք բռնած կանայք․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏽‍🤝‍👩🏼' => 'իրար ձեռք բռնած կանայք․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏽‍🤝‍👩🏾' => 'իրար ձեռք բռնած կանայք․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏽‍🤝‍👩🏿' => 'իրար ձեռք բռնած կանայք․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏾‍🤝‍👩🏻' => 'իրար ձեռք բռնած կանայք․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏾‍🤝‍👩🏼' => 'իրար ձեռք բռնած կանայք․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏾‍🤝‍👩🏽' => 'իրար ձեռք բռնած կանայք․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏾‍🤝‍👩🏿' => 'իրար ձեռք բռնած կանայք․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏿‍🤝‍👩🏻' => 'իրար ձեռք բռնած կանայք․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏿‍🤝‍👩🏼' => 'իրար ձեռք բռնած կանայք․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏿‍🤝‍👩🏽' => 'իրար ձեռք բռնած կանայք․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏿‍🤝‍👩🏾' => 'իրար ձեռք բռնած կանայք․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍🤝‍👨🏼' => 'իրար ձեռք բռնած կին ու տղամարդ․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏻‍🤝‍👨🏽' => 'իրար ձեռք բռնած կին ու տղամարդ․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏻‍🤝‍👨🏾' => 'իրար ձեռք բռնած կին ու տղամարդ․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏻‍🤝‍👨🏿' => 'իրար ձեռք բռնած կին ու տղամարդ․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏼‍🤝‍👨🏻' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏼‍🤝‍👨🏽' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏼‍🤝‍👨🏾' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏼‍🤝‍👨🏿' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏽‍🤝‍👨🏻' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏽‍🤝‍👨🏼' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏽‍🤝‍👨🏾' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩🏽‍🤝‍👨🏿' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏾‍🤝‍👨🏻' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏾‍🤝‍👨🏼' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏾‍🤝‍👨🏽' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏾‍🤝‍👨🏿' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👩🏿‍🤝‍👨🏻' => 'իրար ձեռք բռնած կին ու տղամարդ․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👩🏿‍🤝‍👨🏼' => 'իրար ձեռք բռնած կին ու տղամարդ․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👩🏿‍🤝‍👨🏽' => 'իրար ձեռք բռնած կին ու տղամարդ․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👩🏿‍🤝‍👨🏾' => 'իրար ձեռք բռնած կին ու տղամարդ․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏻‍🤝‍👨🏼' => 'իրար ձեռք բռնած տղամարդիկ․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏻‍🤝‍👨🏽' => 'իրար ձեռք բռնած տղամարդիկ․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏻‍🤝‍👨🏾' => 'իրար ձեռք բռնած տղամարդիկ․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏻‍🤝‍👨🏿' => 'իրար ձեռք բռնած տղամարդիկ․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏼‍🤝‍👨🏻' => 'իրար ձեռք բռնած տղամարդիկ․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏼‍🤝‍👨🏽' => 'իրար ձեռք բռնած տղամարդիկ․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏼‍🤝‍👨🏾' => 'իրար ձեռք բռնած տղամարդիկ․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏼‍🤝‍👨🏿' => 'իրար ձեռք բռնած տղամարդիկ․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏽‍🤝‍👨🏻' => 'իրար ձեռք բռնած տղամարդիկ․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏽‍🤝‍👨🏼' => 'իրար ձեռք բռնած տղամարդիկ․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏽‍🤝‍👨🏾' => 'իրար ձեռք բռնած տղամարդիկ․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👨🏽‍🤝‍👨🏿' => 'իրար ձեռք բռնած տղամարդիկ․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏾‍🤝‍👨🏻' => 'իրար ձեռք բռնած տղամարդիկ․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏾‍🤝‍👨🏼' => 'իրար ձեռք բռնած տղամարդիկ․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏾‍🤝‍👨🏽' => 'իրար ձեռք բռնած տղամարդիկ․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏾‍🤝‍👨🏿' => 'իրար ձեռք բռնած տղամարդիկ․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '👨🏿‍🤝‍👨🏻' => 'իրար ձեռք բռնած տղամարդիկ․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '👨🏿‍🤝‍👨🏼' => 'իրար ձեռք բռնած տղամարդիկ․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '👨🏿‍🤝‍👨🏽' => 'իրար ձեռք բռնած տղամարդիկ․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '👨🏿‍🤝‍👨🏾' => 'իրար ձեռք բռնած տղամարդիկ․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '👩‍❤‍💋‍👨' => 'համբույր․ կին և մարդ',
    '👨‍❤‍💋‍👨' => 'համբույր․ մարդ և մարդ',
    '👩‍❤‍💋‍👩' => 'համբույր․ կին և կին',
    '👨‍👩‍👧‍👦' => 'ընտանիք․ մարդ կին աղջիկ և տղա',
    '👨‍👩‍👦‍👦' => 'ընտանիք․ մարդ կին տղա և տղա',
    '👨‍👩‍👧‍👧' => 'ընտանիք․ մարդ կին աղջիկ և աղջիկ',
    '👨‍👨‍👧‍👦' => 'ընտանիք․ մարդ մարդ աղջիկ և տղա',
    '👨‍👨‍👦‍👦' => 'ընտանիք․ մարդ մարդ տղա և տղա',
    '👨‍👨‍👧‍👧' => 'ընտանիք․ մարդ մարդ աղջիկ և աղջիկ',
    '👩‍👩‍👧‍👦' => 'ընտանիք․ կին կին աղջիկ և տղա',
    '👩‍👩‍👦‍👦' => 'ընտանիք․ կին կին տղա և տղա',
    '👩‍👩‍👧‍👧' => 'ընտանիք․ կին կին աղջիկ և աղջիկ',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'դրոշ․ Անգլիա',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'դրոշ․ Շոտլանդիա',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'դրոշ․ Ուելս',
    '🧑‍🧑‍🧒‍🧒' => 'ընտանիք․ մեծահասակ, մեծահասակ, երեխա, երեխա',
    '🚶🏻‍♀‍➡' => 'քայլող կին․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏼‍♀‍➡' => 'քայլող կին․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏽‍♀‍➡' => 'քայլող կին․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏾‍♀‍➡' => 'քայլող կին․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏿‍♀‍➡' => 'քայլող կին․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏻‍♂‍➡' => 'քայլող տղամարդ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏼‍♂‍➡' => 'քայլող տղամարդ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏽‍♂‍➡' => 'քայլող տղամարդ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏾‍♂‍➡' => 'քայլող տղամարդ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏿‍♂‍➡' => 'քայլող տղամարդ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏻‍♀‍➡' => 'ծնկաչոք կին․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏼‍♀‍➡' => 'ծնկաչոք կին․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏽‍♀‍➡' => 'ծնկաչոք կին․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏾‍♀‍➡' => 'ծնկաչոք կին․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏿‍♀‍➡' => 'ծնկաչոք կին․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏻‍♂‍➡' => 'ծնկաչոք տղամարդ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏼‍♂‍➡' => 'ծնկաչոք տղամարդ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏽‍♂‍➡' => 'ծնկաչոք տղամարդ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏾‍♂‍➡' => 'ծնկաչոք տղամարդ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏿‍♂‍➡' => 'ծնկաչոք տղամարդ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏻‍🦯‍➡' => 'ձեռնափայտով անձ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏼‍🦯‍➡' => 'ձեռնափայտով անձ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏽‍🦯‍➡' => 'ձեռնափայտով անձ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏾‍🦯‍➡' => 'ձեռնափայտով անձ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏿‍🦯‍➡' => 'ձեռնափայտով անձ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👨🏻‍🦯‍➡' => 'ձեռնափայտով տղամարդ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '👨🏼‍🦯‍➡' => 'ձեռնափայտով տղամարդ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '👨🏽‍🦯‍➡' => 'ձեռնափայտով տղամարդ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '👨🏾‍🦯‍➡' => 'ձեռնափայտով տղամարդ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👨🏿‍🦯‍➡' => 'ձեռնափայտով տղամարդ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👩🏻‍🦯‍➡' => 'ձեռնափայտով կին․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '👩🏼‍🦯‍➡' => 'ձեռնափայտով կին․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '👩🏽‍🦯‍➡' => 'ձեռնափայտով կին․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '👩🏾‍🦯‍➡' => 'ձեռնափայտով կին․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👩🏿‍🦯‍➡' => 'ձեռնափայտով կին․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏻‍🦼‍➡' => 'մոտորասայլակով անձ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏼‍🦼‍➡' => 'մոտորասայլակով անձ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏽‍🦼‍➡' => 'մոտորասայլակով անձ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏾‍🦼‍➡' => 'մոտորասայլակով անձ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏿‍🦼‍➡' => 'մոտորասայլակով անձ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👨🏻‍🦼‍➡' => 'մոտորասայլակով տղամարդ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '👨🏼‍🦼‍➡' => 'մոտորասայլակով տղամարդ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '👨🏽‍🦼‍➡' => 'մոտորասայլակով տղամարդ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '👨🏾‍🦼‍➡' => 'մոտորասայլակով տղամարդ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👨🏿‍🦼‍➡' => 'մոտորասայլակով տղամարդ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👩🏻‍🦼‍➡' => 'մոտորասայլակով կին․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '👩🏼‍🦼‍➡' => 'մոտորասայլակով կին․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '👩🏽‍🦼‍➡' => 'մոտորասայլակով կին․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '👩🏾‍🦼‍➡' => 'մոտորասայլակով կին․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👩🏿‍🦼‍➡' => 'մոտորասայլակով կին․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏻‍🦽‍➡' => 'ձեռքով կառավարվող սայլակով անձ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏼‍🦽‍➡' => 'ձեռքով կառավարվող սայլակով անձ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏽‍🦽‍➡' => 'ձեռքով կառավարվող սայլակով անձ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏾‍🦽‍➡' => 'ձեռքով կառավարվող սայլակով անձ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏿‍🦽‍➡' => 'ձեռքով կառավարվող սայլակով անձ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👨🏻‍🦽‍➡' => 'անվասայլակով տղամարդ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '👨🏼‍🦽‍➡' => 'անվասայլակով տղամարդ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '👨🏽‍🦽‍➡' => 'անվասայլակով տղամարդ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '👨🏾‍🦽‍➡' => 'անվասայլակով տղամարդ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👨🏿‍🦽‍➡' => 'անվասայլակով տղամարդ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👩🏻‍🦽‍➡' => 'ձեռքով կառավարվող անվասայլակով կին․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '👩🏼‍🦽‍➡' => 'ձեռքով կառավարվող անվասայլակով կին․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '👩🏽‍🦽‍➡' => 'ձեռքով կառավարվող անվասայլակով կին․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '👩🏾‍🦽‍➡' => 'ձեռքով կառավարվող անվասայլակով կին․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👩🏿‍🦽‍➡' => 'ձեռքով կառավարվող անվասայլակով կին․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏻‍♀‍➡' => 'վազող կին․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏼‍♀‍➡' => 'վազող կին․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏽‍♀‍➡' => 'վազող կին․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏾‍♀‍➡' => 'վազող կին․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏿‍♀‍➡' => 'վազող կին․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏻‍♂‍➡' => 'վազող տղամարդ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏼‍♂‍➡' => 'վազող տղամարդ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏽‍♂‍➡' => 'վազող տղամարդ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏾‍♂‍➡' => 'վազող տղամարդ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏿‍♂‍➡' => 'վազող տղամարդ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🫱🏻‍🫲🏼' => 'ձեռքսեղմում․ բաց գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🫱🏻‍🫲🏽' => 'ձեռքսեղմում․ բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🫱🏻‍🫲🏾' => 'ձեռքսեղմում․ բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🫱🏻‍🫲🏿' => 'ձեռքսեղմում․ բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🫱🏼‍🫲🏻' => 'ձեռքսեղմում․ միջին բաց գույնի մաշկ և բաց գույնի մաշկ',
    '🫱🏼‍🫲🏽' => 'ձեռքսեղմում․ միջին բաց գույնի մաշկ և միջին գույնի մաշկ',
    '🫱🏼‍🫲🏾' => 'ձեռքսեղմում․ միջին բաց գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🫱🏼‍🫲🏿' => 'ձեռքսեղմում․ միջին բաց գույնի մաշկ և մուգ գույնի մաշկ',
    '🫱🏽‍🫲🏻' => 'ձեռքսեղմում․ միջին գույնի մաշկ և բաց գույնի մաշկ',
    '🫱🏽‍🫲🏼' => 'ձեռքսեղմում․ միջին գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🫱🏽‍🫲🏾' => 'ձեռքսեղմում․ միջին գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🫱🏽‍🫲🏿' => 'ձեռքսեղմում․ միջին գույնի մաշկ և մուգ գույնի մաշկ',
    '🫱🏾‍🫲🏻' => 'ձեռքսեղմում․ միջին մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🫱🏾‍🫲🏼' => 'ձեռքսեղմում․ միջին մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🫱🏾‍🫲🏽' => 'ձեռքսեղմում․ միջին մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🫱🏾‍🫲🏿' => 'ձեռքսեղմում․ միջին մուգ գույնի մաշկ և մուգ գույնի մաշկ',
    '🫱🏿‍🫲🏻' => 'ձեռքսեղմում․ մուգ գույնի մաշկ և բաց գույնի մաշկ',
    '🫱🏿‍🫲🏼' => 'ձեռքսեղմում․ մուգ գույնի մաշկ և միջին բաց գույնի մաշկ',
    '🫱🏿‍🫲🏽' => 'ձեռքսեղմում․ մուգ գույնի մաշկ և միջին գույնի մաշկ',
    '🫱🏿‍🫲🏾' => 'ձեռքսեղմում․ մուգ գույնի մաշկ և միջին մուգ գույնի մաշկ',
    '🚶‍♀‍➡' => 'քայլող կին․ դեմքով՝ աջ',
    '🚶‍♂‍➡' => 'քայլող տղամարդ․ դեմքով՝ աջ',
    '🧎‍♀‍➡' => 'ծնկաչոք կին․ դեմքով՝ աջ',
    '🧎‍♂‍➡' => 'ծնկաչոք տղամարդ․ դեմքով՝ աջ',
    '🧑‍🦯‍➡' => 'ձեռնափայտով անձ․ դեմքով՝ աջ',
    '👨‍🦯‍➡' => 'ձեռնափայտով տղամարդ․ դեմքով՝ աջ',
    '👩‍🦯‍➡' => 'ձեռնափայտով կին․ դեմքով՝ աջ',
    '🧑‍🦼‍➡' => 'մոտորասայլակով անձ․ դեմքով՝ աջ',
    '👨‍🦼‍➡' => 'մոտորասայլակով տղամարդ․ դեմքով՝ աջ',
    '👩‍🦼‍➡' => 'մոտորասայլակով կին․ դեմքով՝ աջ',
    '🧑‍🦽‍➡' => 'ձեռքով կառավարվող սայլակով անձ․ դեմքով՝ աջ',
    '👨‍🦽‍➡' => 'անվասայլակով տղամարդ․ դեմքով՝ աջ',
    '👩‍🦽‍➡' => 'ձեռքով կառավարվող անվասայլակով կին․ դեմքով՝ աջ',
    '🏃‍♀‍➡' => 'վազող կին․ դեմքով՝ աջ',
    '🏃‍♂‍➡' => 'վազող տղամարդ․ դեմքով՝ աջ',
    '👩‍❤‍👨' => 'սրտիկով զույգ․ կին և մարդ',
    '👨‍❤‍👨' => 'սրտիկով զույգ․ մարդ և մարդ',
    '👩‍❤‍👩' => 'սրտիկով զույգ․ կին և կին',
    '👨‍👩‍👦' => 'ընտանիք․ մարդ կին և տղա',
    '👨‍👩‍👧' => 'ընտանիք․ մարդ կին և աղջիկ',
    '👨‍👨‍👦' => 'ընտանիք․ մարդ մարդ և տղա',
    '👨‍👨‍👧' => 'ընտանիք․ մարդ մարդ և աղջիկ',
    '👩‍👩‍👦' => 'ընտանիք․ կին կին և տղա',
    '👩‍👩‍👧' => 'ընտանիք․ կին կին և աղջիկ',
    '👨‍👦‍👦' => 'ընտանիք․ մարդ տղա և տղա',
    '👨‍👧‍👦' => 'ընտանիք․ մարդ աղջիկ և տղա',
    '👨‍👧‍👧' => 'ընտանիք․ մարդ աղջիկ և աղջիկ',
    '👩‍👦‍👦' => 'ընտանիք․ կին տղա և տղա',
    '👩‍👧‍👦' => 'ընտանիք․ կին աղջիկ և տղա',
    '👩‍👧‍👧' => 'ընտանիք․ կին աղջիկ և աղջիկ',
    '🧑‍🤝‍🧑' => 'իրար ձեռք բռնած մարդիկ',
    '🧑‍🧑‍🧒' => 'ընտանիք․ մեծահասակ, մեծահասակ, երեխա',
    '🧑‍🧒‍🧒' => 'ընտանիք․ մեծահասակ, երեխա, երեխա',
    '🧑🏻‍🦰' => 'անձ․ բաց գույնի մաշկ և կարմրահեր',
    '🧑🏼‍🦰' => 'անձ․ միջին բաց գույնի մաշկ և կարմրահեր',
    '🧑🏽‍🦰' => 'անձ․ միջին գույնի մաշկ և կարմրահեր',
    '🧑🏾‍🦰' => 'անձ․ միջին մուգ գույնի մաշկ և կարմրահեր',
    '🧑🏿‍🦰' => 'անձ․ մուգ գույնի մաշկ և կարմրահեր',
    '🧑🏻‍🦱' => 'անձ․ բաց գույնի մաշկ և գանգրահեր',
    '🧑🏼‍🦱' => 'անձ․ միջին բաց գույնի մաշկ և գանգրահեր',
    '🧑🏽‍🦱' => 'անձ․ միջին գույնի մաշկ և գանգրահեր',
    '🧑🏾‍🦱' => 'անձ․ միջին մուգ գույնի մաշկ և գանգրահեր',
    '🧑🏿‍🦱' => 'անձ․ մուգ գույնի մաշկ և գանգրահեր',
    '🧑🏻‍🦳' => 'անձ․ բաց գույնի մաշկ և սպիտակահեր',
    '🧑🏼‍🦳' => 'անձ․ միջին բաց գույնի մաշկ և սպիտակահեր',
    '🧑🏽‍🦳' => 'անձ․ միջին գույնի մաշկ և սպիտակահեր',
    '🧑🏾‍🦳' => 'անձ․ միջին մուգ գույնի մաշկ և սպիտակահեր',
    '🧑🏿‍🦳' => 'անձ․ մուգ գույնի մաշկ և սպիտակահեր',
    '🧑🏻‍🦲' => 'անձ․ բաց գույնի մաշկ և ճաղատ',
    '🧑🏼‍🦲' => 'անձ․ միջին բաց գույնի մաշկ և ճաղատ',
    '🧑🏽‍🦲' => 'անձ․ միջին գույնի մաշկ և ճաղատ',
    '🧑🏾‍🦲' => 'անձ․ միջին մուգ գույնի մաշկ և ճաղատ',
    '🧑🏿‍🦲' => 'անձ․ մուգ գույնի մաշկ և ճաղատ',
    '🧑🏻‍🩰' => 'բալետ պարող․ բաց գույնի մաշկ',
    '🧑🏼‍🩰' => 'բալետ պարող․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🩰' => 'բալետ պարող․ միջին գույնի մաշկ',
    '🧑🏾‍🩰' => 'բալետ պարող․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🩰' => 'բալետ պարող․ մուգ գույնի մաշկ',
    '🧔🏻‍♂' => 'մորուքավոր տղամարդ․ բաց գույնի մաշկ',
    '🧔🏼‍♂' => 'մորուքավոր տղամարդ․ միջին բաց գույնի մաշկ',
    '🧔🏽‍♂' => 'մորուքավոր տղամարդ․ միջին գույնի մաշկ',
    '🧔🏾‍♂' => 'մորուքավոր տղամարդ․ միջին մուգ գույնի մաշկ',
    '🧔🏿‍♂' => 'մորուքավոր տղամարդ․ մուգ գույնի մաշկ',
    '👱🏻‍♂' => 'շիկահեր տղամարդ․ բաց գույնի մաշկ',
    '👱🏼‍♂' => 'շիկահեր տղամարդ․ միջին բաց գույնի մաշկ',
    '👱🏽‍♂' => 'շիկահեր տղամարդ․ միջին գույնի մաշկ',
    '👱🏾‍♂' => 'շիկահեր տղամարդ․ միջին մուգ գույնի մաշկ',
    '👱🏿‍♂' => 'շիկահեր տղամարդ․ մուգ գույնի մաշկ',
    '👨🏻‍🦰' => 'մարդ․ բաց գույնի մաշկ և կարմրահեր',
    '👨🏼‍🦰' => 'մարդ․ միջին բաց գույնի մաշկ և կարմրահեր',
    '👨🏽‍🦰' => 'մարդ․ միջին գույնի մաշկ և կարմրահեր',
    '👨🏾‍🦰' => 'մարդ․ միջին մուգ գույնի մաշկ և կարմրահեր',
    '👨🏿‍🦰' => 'մարդ․ մուգ գույնի մաշկ և կարմրահեր',
    '👨🏻‍🦱' => 'մարդ․ բաց գույնի մաշկ և գանգրահեր',
    '👨🏼‍🦱' => 'մարդ․ միջին բաց գույնի մաշկ և գանգրահեր',
    '👨🏽‍🦱' => 'մարդ․ միջին գույնի մաշկ և գանգրահեր',
    '👨🏾‍🦱' => 'մարդ․ միջին մուգ գույնի մաշկ և գանգրահեր',
    '👨🏿‍🦱' => 'մարդ․ մուգ գույնի մաշկ և գանգրահեր',
    '👨🏻‍🦳' => 'մարդ․ բաց գույնի մաշկ և սպիտակահեր',
    '👨🏼‍🦳' => 'մարդ․ միջին բաց գույնի մաշկ և սպիտակահեր',
    '👨🏽‍🦳' => 'մարդ․ միջին գույնի մաշկ և սպիտակահեր',
    '👨🏾‍🦳' => 'մարդ․ միջին մուգ գույնի մաշկ և սպիտակահեր',
    '👨🏿‍🦳' => 'մարդ․ մուգ գույնի մաշկ և սպիտակահեր',
    '👨🏻‍🦲' => 'մարդ․ բաց գույնի մաշկ և ճաղատ',
    '👨🏼‍🦲' => 'մարդ․ միջին բաց գույնի մաշկ և ճաղատ',
    '👨🏽‍🦲' => 'մարդ․ միջին գույնի մաշկ և ճաղատ',
    '👨🏾‍🦲' => 'մարդ․ միջին մուգ գույնի մաշկ և ճաղատ',
    '👨🏿‍🦲' => 'մարդ․ մուգ գույնի մաշկ և ճաղատ',
    '🧔🏻‍♀' => 'մորուքավոր կին․ բաց գույնի մաշկ',
    '🧔🏼‍♀' => 'մորուքավոր կին․ միջին բաց գույնի մաշկ',
    '🧔🏽‍♀' => 'մորուքավոր կին․ միջին գույնի մաշկ',
    '🧔🏾‍♀' => 'մորուքավոր կին․ միջին մուգ գույնի մաշկ',
    '🧔🏿‍♀' => 'մորուքավոր կին․ մուգ գույնի մաշկ',
    '👱🏻‍♀' => 'շիկահեր կին․ բաց գույնի մաշկ',
    '👱🏼‍♀' => 'շիկահեր կին․ միջին բաց գույնի մաշկ',
    '👱🏽‍♀' => 'շիկահեր կին․ միջին գույնի մաշկ',
    '👱🏾‍♀' => 'շիկահեր կին․ միջին մուգ գույնի մաշկ',
    '👱🏿‍♀' => 'շիկահեր կին․ մուգ գույնի մաշկ',
    '👩🏻‍🦰' => 'կին․ բաց գույնի մաշկ և կարմրահեր',
    '👩🏼‍🦰' => 'կին․ միջին բաց գույնի մաշկ և կարմրահեր',
    '👩🏽‍🦰' => 'կին․ միջին գույնի մաշկ և կարմրահեր',
    '👩🏾‍🦰' => 'կին․ միջին մուգ գույնի մաշկ և կարմրահեր',
    '👩🏿‍🦰' => 'կին․ մուգ գույնի մաշկ և կարմրահեր',
    '👩🏻‍🦱' => 'կին․ բաց գույնի մաշկ և գանգրահեր',
    '👩🏼‍🦱' => 'կին․ միջին բաց գույնի մաշկ և գանգրահեր',
    '👩🏽‍🦱' => 'կին․ միջին գույնի մաշկ և գանգրահեր',
    '👩🏾‍🦱' => 'կին․ միջին մուգ գույնի մաշկ և գանգրահեր',
    '👩🏿‍🦱' => 'կին․ մուգ գույնի մաշկ և գանգրահեր',
    '👩🏻‍🦳' => 'կին․ բաց գույնի մաշկ և սպիտակահեր',
    '👩🏼‍🦳' => 'կին․ միջին բաց գույնի մաշկ և սպիտակահեր',
    '👩🏽‍🦳' => 'կին․ միջին գույնի մաշկ և սպիտակահեր',
    '👩🏾‍🦳' => 'կին․ միջին մուգ գույնի մաշկ և սպիտակահեր',
    '👩🏿‍🦳' => 'կին․ մուգ գույնի մաշկ և սպիտակահեր',
    '👩🏻‍🦲' => 'կին․ բաց գույնի մաշկ և ճաղատ',
    '👩🏼‍🦲' => 'կին․ միջին բաց գույնի մաշկ և ճաղատ',
    '👩🏽‍🦲' => 'կին․ միջին գույնի մաշկ և ճաղատ',
    '👩🏾‍🦲' => 'կին․ միջին մուգ գույնի մաշկ և ճաղատ',
    '👩🏿‍🦲' => 'կին․ մուգ գույնի մաշկ և ճաղատ',
    '🙍🏻‍♂' => 'խոժոռված տղամարդ․ բաց գույնի մաշկ',
    '🙍🏼‍♂' => 'խոժոռված տղամարդ․ միջին բաց գույնի մաշկ',
    '🙍🏽‍♂' => 'խոժոռված տղամարդ․ միջին գույնի մաշկ',
    '🙍🏾‍♂' => 'խոժոռված տղամարդ․ միջին մուգ գույնի մաշկ',
    '🙍🏿‍♂' => 'խոժոռված տղամարդ․ մուգ գույնի մաշկ',
    '🙍🏻‍♀' => 'խոժոռված կին․ բաց գույնի մաշկ',
    '🙍🏼‍♀' => 'խոժոռված կին․ միջին բաց գույնի մաշկ',
    '🙍🏽‍♀' => 'խոժոռված կին․ միջին գույնի մաշկ',
    '🙍🏾‍♀' => 'խոժոռված կին․ միջին մուգ գույնի մաշկ',
    '🙍🏿‍♀' => 'խոժոռված կին․ մուգ գույնի մաշկ',
    '🙎🏻‍♂' => 'խռոված տղամարդ․ բաց գույնի մաշկ',
    '🙎🏼‍♂' => 'խռոված տղամարդ․ միջին բաց գույնի մաշկ',
    '🙎🏽‍♂' => 'խռոված տղամարդ․ միջին գույնի մաշկ',
    '🙎🏾‍♂' => 'խռոված տղամարդ․ միջին մուգ գույնի մաշկ',
    '🙎🏿‍♂' => 'խռոված տղամարդ․ մուգ գույնի մաշկ',
    '🙎🏻‍♀' => 'խռոված կին․ բաց գույնի մաշկ',
    '🙎🏼‍♀' => 'խռոված կին․ միջին բաց գույնի մաշկ',
    '🙎🏽‍♀' => 'խռոված կին․ միջին գույնի մաշկ',
    '🙎🏾‍♀' => 'խռոված կին․ միջին մուգ գույնի մաշկ',
    '🙎🏿‍♀' => 'խռոված կին․ մուգ գույնի մաշկ',
    '🙅🏻‍♂' => 'տղամարդը դեմ է․ բաց գույնի մաշկ',
    '🙅🏼‍♂' => 'տղամարդը դեմ է․ միջին բաց գույնի մաշկ',
    '🙅🏽‍♂' => 'տղամարդը դեմ է․ միջին գույնի մաշկ',
    '🙅🏾‍♂' => 'տղամարդը դեմ է․ միջին մուգ գույնի մաշկ',
    '🙅🏿‍♂' => 'տղամարդը դեմ է․ մուգ գույնի մաշկ',
    '🙅🏻‍♀' => 'կինը դեմ է․ բաց գույնի մաշկ',
    '🙅🏼‍♀' => 'կինը դեմ է․ միջին բաց գույնի մաշկ',
    '🙅🏽‍♀' => 'կինը դեմ է․ միջին գույնի մաշկ',
    '🙅🏾‍♀' => 'կինը դեմ է․ միջին մուգ գույնի մաշկ',
    '🙅🏿‍♀' => 'կինը դեմ է․ մուգ գույնի մաշկ',
    '🙆🏻‍♂' => 'տղամարդը կողմ է․ բաց գույնի մաշկ',
    '🙆🏼‍♂' => 'տղամարդը կողմ է․ միջին բաց գույնի մաշկ',
    '🙆🏽‍♂' => 'տղամարդը կողմ է․ միջին գույնի մաշկ',
    '🙆🏾‍♂' => 'տղամարդը կողմ է․ միջին մուգ գույնի մաշկ',
    '🙆🏿‍♂' => 'տղամարդը կողմ է․ մուգ գույնի մաշկ',
    '🙆🏻‍♀' => 'կինը կողմ է․ բաց գույնի մաշկ',
    '🙆🏼‍♀' => 'կինը կողմ է․ միջին բաց գույնի մաշկ',
    '🙆🏽‍♀' => 'կինը կողմ է․ միջին գույնի մաշկ',
    '🙆🏾‍♀' => 'կինը կողմ է․ միջին մուգ գույնի մաշկ',
    '🙆🏿‍♀' => 'կինը կողմ է․ մուգ գույնի մաշկ',
    '💁🏻‍♂' => 'տղամարդը բացում է իր մտադրությունները․ բաց գույնի մաշկ',
    '💁🏼‍♂' => 'տղամարդը բացում է իր մտադրությունները․ միջին բաց գույնի մաշկ',
    '💁🏽‍♂' => 'տղամարդը բացում է իր մտադրությունները․ միջին գույնի մաշկ',
    '💁🏾‍♂' => 'տղամարդը բացում է իր մտադրությունները․ միջին մուգ գույնի մաշկ',
    '💁🏿‍♂' => 'տղամարդը բացում է իր մտադրությունները․ մուգ գույնի մաշկ',
    '💁🏻‍♀' => 'կինը բացում է իր մտադրությունները․ բաց գույնի մաշկ',
    '💁🏼‍♀' => 'կինը բացում է իր մտադրությունները․ միջին բաց գույնի մաշկ',
    '💁🏽‍♀' => 'կինը բացում է իր մտադրությունները․ միջին գույնի մաշկ',
    '💁🏾‍♀' => 'կինը բացում է իր մտադրությունները․ միջին մուգ գույնի մաշկ',
    '💁🏿‍♀' => 'կինը բացում է իր մտադրությունները․ մուգ գույնի մաշկ',
    '🙋🏻‍♂' => 'ձեռքը բարձրացրած տղամարդ․ բաց գույնի մաշկ',
    '🙋🏼‍♂' => 'ձեռքը բարձրացրած տղամարդ․ միջին բաց գույնի մաշկ',
    '🙋🏽‍♂' => 'ձեռքը բարձրացրած տղամարդ․ միջին գույնի մաշկ',
    '🙋🏾‍♂' => 'ձեռքը բարձրացրած տղամարդ․ միջին մուգ գույնի մաշկ',
    '🙋🏿‍♂' => 'ձեռքը բարձրացրած տղամարդ․ մուգ գույնի մաշկ',
    '🙋🏻‍♀' => 'ձեռքը բարձրացրած կին․ բաց գույնի մաշկ',
    '🙋🏼‍♀' => 'ձեռքը բարձրացրած կին․ միջին բաց գույնի մաշկ',
    '🙋🏽‍♀' => 'ձեռքը բարձրացրած կին․ միջին գույնի մաշկ',
    '🙋🏾‍♀' => 'ձեռքը բարձրացրած կին․ միջին մուգ գույնի մաշկ',
    '🙋🏿‍♀' => 'ձեռքը բարձրացրած կին․ մուգ գույնի մաշկ',
    '🧏🏻‍♂' => 'խուլ տղամարդ․ բաց գույնի մաշկ',
    '🧏🏼‍♂' => 'խուլ տղամարդ․ միջին բաց գույնի մաշկ',
    '🧏🏽‍♂' => 'խուլ տղամարդ․ միջին գույնի մաշկ',
    '🧏🏾‍♂' => 'խուլ տղամարդ․ միջին մուգ գույնի մաշկ',
    '🧏🏿‍♂' => 'խուլ տղամարդ․ մուգ գույնի մաշկ',
    '🧏🏻‍♀' => 'խուլ կին․ բաց գույնի մաշկ',
    '🧏🏼‍♀' => 'խուլ կին․ միջին բաց գույնի մաշկ',
    '🧏🏽‍♀' => 'խուլ կին․ միջին գույնի մաշկ',
    '🧏🏾‍♀' => 'խուլ կին․ միջին մուգ գույնի մաշկ',
    '🧏🏿‍♀' => 'խուլ կին․ մուգ գույնի մաշկ',
    '🙇🏻‍♂' => 'խոնարհվող տղամարդ․ բաց գույնի մաշկ',
    '🙇🏼‍♂' => 'խոնարհվող տղամարդ․ միջին բաց գույնի մաշկ',
    '🙇🏽‍♂' => 'խոնարհվող տղամարդ․ միջին գույնի մաշկ',
    '🙇🏾‍♂' => 'խոնարհվող տղամարդ․ միջին մուգ գույնի մաշկ',
    '🙇🏿‍♂' => 'խոնարհվող տղամարդ․ մուգ գույնի մաշկ',
    '🙇🏻‍♀' => 'խոնարհվող կին․ բաց գույնի մաշկ',
    '🙇🏼‍♀' => 'խոնարհվող կին․ միջին բաց գույնի մաշկ',
    '🙇🏽‍♀' => 'խոնարհվող կին․ միջին գույնի մաշկ',
    '🙇🏾‍♀' => 'խոնարհվող կին․ միջին մուգ գույնի մաշկ',
    '🙇🏿‍♀' => 'խոնարհվող կին․ մուգ գույնի մաշկ',
    '🤦🏻‍♂' => 'տղամարդը կորցրել է խոսելու ունակությունը․ բաց գույնի մաշկ',
    '🤦🏼‍♂' => 'տղամարդը կորցրել է խոսելու ունակությունը․ միջին բաց գույնի մաշկ',
    '🤦🏽‍♂' => 'տղամարդը կորցրել է խոսելու ունակությունը․ միջին գույնի մաշկ',
    '🤦🏾‍♂' => 'տղամարդը կորցրել է խոսելու ունակությունը․ միջին մուգ գույնի մաշկ',
    '🤦🏿‍♂' => 'տղամարդը կորցրել է խոսելու ունակությունը․ մուգ գույնի մաշկ',
    '🤦🏻‍♀' => 'կինը կորցրել է խոսելու ունակությունը․ բաց գույնի մաշկ',
    '🤦🏼‍♀' => 'կինը կորցրել է խոսելու ունակությունը․ միջին բաց գույնի մաշկ',
    '🤦🏽‍♀' => 'կինը կորցրել է խոսելու ունակությունը․ միջին գույնի մաշկ',
    '🤦🏾‍♀' => 'կինը կորցրել է խոսելու ունակությունը․ միջին մուգ գույնի մաշկ',
    '🤦🏿‍♀' => 'կինը կորցրել է խոսելու ունակությունը․ մուգ գույնի մաշկ',
    '🤷🏻‍♂' => 'ուսերը թոթվող մարդ․ բաց գույնի մաշկ',
    '🤷🏼‍♂' => 'ուսերը թոթվող մարդ․ միջին բաց գույնի մաշկ',
    '🤷🏽‍♂' => 'ուսերը թոթվող մարդ․ միջին գույնի մաշկ',
    '🤷🏾‍♂' => 'ուսերը թոթվող մարդ․ միջին մուգ գույնի մաշկ',
    '🤷🏿‍♂' => 'ուսերը թոթվող մարդ․ մուգ գույնի մաշկ',
    '🤷🏻‍♀' => 'ուսերը թոթվող կին․ բաց գույնի մաշկ',
    '🤷🏼‍♀' => 'ուսերը թոթվող կին․ միջին բաց գույնի մաշկ',
    '🤷🏽‍♀' => 'ուսերը թոթվող կին․ միջին գույնի մաշկ',
    '🤷🏾‍♀' => 'ուսերը թոթվող կին․ միջին մուգ գույնի մաշկ',
    '🤷🏿‍♀' => 'ուսերը թոթվող կին․ մուգ գույնի մաշկ',
    '🧑🏻‍⚕' => 'բուժաշխատող․ բաց գույնի մաշկ',
    '🧑🏼‍⚕' => 'բուժաշխատող․ միջին բաց գույնի մաշկ',
    '🧑🏽‍⚕' => 'բուժաշխատող․ միջին գույնի մաշկ',
    '🧑🏾‍⚕' => 'բուժաշխատող․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍⚕' => 'բուժաշխատող․ մուգ գույնի մաշկ',
    '👨🏻‍⚕' => 'բժիշկ․ բաց գույնի մաշկ',
    '👨🏼‍⚕' => 'բժիշկ․ միջին բաց գույնի մաշկ',
    '👨🏽‍⚕' => 'բժիշկ․ միջին գույնի մաշկ',
    '👨🏾‍⚕' => 'բժիշկ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍⚕' => 'բժիշկ․ մուգ գույնի մաշկ',
    '👩🏻‍⚕' => 'բժշկուհի․ բաց գույնի մաշկ',
    '👩🏼‍⚕' => 'բժշկուհի․ միջին բաց գույնի մաշկ',
    '👩🏽‍⚕' => 'բժշկուհի․ միջին գույնի մաշկ',
    '👩🏾‍⚕' => 'բժշկուհի․ միջին մուգ գույնի մաշկ',
    '👩🏿‍⚕' => 'բժշկուհի․ մուգ գույնի մաշկ',
    '🧑🏻‍🎓' => 'ուսանող․ բաց գույնի մաշկ',
    '🧑🏼‍🎓' => 'ուսանող․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🎓' => 'ուսանող․ միջին գույնի մաշկ',
    '🧑🏾‍🎓' => 'ուսանող․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🎓' => 'ուսանող․ մուգ գույնի մաշկ',
    '👨🏻‍🎓' => 'ուսանող տղա․ բաց գույնի մաշկ',
    '👨🏼‍🎓' => 'ուսանող տղա․ միջին բաց գույնի մաշկ',
    '👨🏽‍🎓' => 'ուսանող տղա․ միջին գույնի մաշկ',
    '👨🏾‍🎓' => 'ուսանող տղա․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🎓' => 'ուսանող տղա․ մուգ գույնի մաշկ',
    '👩🏻‍🎓' => 'ուսանողուհի․ բաց գույնի մաշկ',
    '👩🏼‍🎓' => 'ուսանողուհի․ միջին բաց գույնի մաշկ',
    '👩🏽‍🎓' => 'ուսանողուհի․ միջին գույնի մաշկ',
    '👩🏾‍🎓' => 'ուսանողուհի․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🎓' => 'ուսանողուհի․ մուգ գույնի մաշկ',
    '🧑🏻‍🏫' => 'ուսուցիչ․ բաց գույնի մաշկ',
    '🧑🏼‍🏫' => 'ուսուցիչ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🏫' => 'ուսուցիչ․ միջին գույնի մաշկ',
    '🧑🏾‍🏫' => 'ուսուցիչ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🏫' => 'ուսուցիչ․ մուգ գույնի մաշկ',
    '👨🏻‍🏫' => 'տղամարդ ուսուցիչ․ բաց գույնի մաշկ',
    '👨🏼‍🏫' => 'տղամարդ ուսուցիչ․ միջին բաց գույնի մաշկ',
    '👨🏽‍🏫' => 'տղամարդ ուսուցիչ․ միջին գույնի մաշկ',
    '👨🏾‍🏫' => 'տղամարդ ուսուցիչ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🏫' => 'տղամարդ ուսուցիչ․ մուգ գույնի մաշկ',
    '👩🏻‍🏫' => 'ուսուցչուհի․ բաց գույնի մաշկ',
    '👩🏼‍🏫' => 'ուսուցչուհի․ միջին բաց գույնի մաշկ',
    '👩🏽‍🏫' => 'ուսուցչուհի․ միջին գույնի մաշկ',
    '👩🏾‍🏫' => 'ուսուցչուհի․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🏫' => 'ուսուցչուհի․ մուգ գույնի մաշկ',
    '🧑🏻‍⚖' => 'դատավոր․ բաց գույնի մաշկ',
    '🧑🏼‍⚖' => 'դատավոր․ միջին բաց գույնի մաշկ',
    '🧑🏽‍⚖' => 'դատավոր․ միջին գույնի մաշկ',
    '🧑🏾‍⚖' => 'դատավոր․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍⚖' => 'դատավոր․ մուգ գույնի մաշկ',
    '👨🏻‍⚖' => 'տղամարդ դատավոր․ բաց գույնի մաշկ',
    '👨🏼‍⚖' => 'տղամարդ դատավոր․ միջին բաց գույնի մաշկ',
    '👨🏽‍⚖' => 'տղամարդ դատավոր․ միջին գույնի մաշկ',
    '👨🏾‍⚖' => 'տղամարդ դատավոր․ միջին մուգ գույնի մաշկ',
    '👨🏿‍⚖' => 'տղամարդ դատավոր․ մուգ գույնի մաշկ',
    '👩🏻‍⚖' => 'կին դատավոր․ բաց գույնի մաշկ',
    '👩🏼‍⚖' => 'կին դատավոր․ միջին բաց գույնի մաշկ',
    '👩🏽‍⚖' => 'կին դատավոր․ միջին գույնի մաշկ',
    '👩🏾‍⚖' => 'կին դատավոր․ միջին մուգ գույնի մաշկ',
    '👩🏿‍⚖' => 'կին դատավոր․ մուգ գույնի մաշկ',
    '🧑🏻‍🌾' => 'ֆերմեր․ բաց գույնի մաշկ',
    '🧑🏼‍🌾' => 'ֆերմեր․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🌾' => 'ֆերմեր․ միջին գույնի մաշկ',
    '🧑🏾‍🌾' => 'ֆերմեր․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🌾' => 'ֆերմեր․ մուգ գույնի մաշկ',
    '👨🏻‍🌾' => 'տղամարդ ֆերմեր․ բաց գույնի մաշկ',
    '👨🏼‍🌾' => 'տղամարդ ֆերմեր․ միջին բաց գույնի մաշկ',
    '👨🏽‍🌾' => 'տղամարդ ֆերմեր․ միջին գույնի մաշկ',
    '👨🏾‍🌾' => 'տղամարդ ֆերմեր․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🌾' => 'տղամարդ ֆերմեր․ մուգ գույնի մաշկ',
    '👩🏻‍🌾' => 'կին ֆերմեր․ բաց գույնի մաշկ',
    '👩🏼‍🌾' => 'կին ֆերմեր․ միջին բաց գույնի մաշկ',
    '👩🏽‍🌾' => 'կին ֆերմեր․ միջին գույնի մաշկ',
    '👩🏾‍🌾' => 'կին ֆերմեր․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🌾' => 'կին ֆերմեր․ մուգ գույնի մաշկ',
    '🧑🏻‍🍳' => 'խոհարար․ բաց գույնի մաշկ',
    '🧑🏼‍🍳' => 'խոհարար․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🍳' => 'խոհարար․ միջին գույնի մաշկ',
    '🧑🏾‍🍳' => 'խոհարար․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🍳' => 'խոհարար․ մուգ գույնի մաշկ',
    '👨🏻‍🍳' => 'տղամարդ խոհարար․ բաց գույնի մաշկ',
    '👨🏼‍🍳' => 'տղամարդ խոհարար․ միջին բաց գույնի մաշկ',
    '👨🏽‍🍳' => 'տղամարդ խոհարար․ միջին գույնի մաշկ',
    '👨🏾‍🍳' => 'տղամարդ խոհարար․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🍳' => 'տղամարդ խոհարար․ մուգ գույնի մաշկ',
    '👩🏻‍🍳' => 'խոհարարուհի․ բաց գույնի մաշկ',
    '👩🏼‍🍳' => 'խոհարարուհի․ միջին բաց գույնի մաշկ',
    '👩🏽‍🍳' => 'խոհարարուհի․ միջին գույնի մաշկ',
    '👩🏾‍🍳' => 'խոհարարուհի․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🍳' => 'խոհարարուհի․ մուգ գույնի մաշկ',
    '🧑🏻‍🔧' => 'փականագործ․ բաց գույնի մաշկ',
    '🧑🏼‍🔧' => 'փականագործ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🔧' => 'փականագործ․ միջին գույնի մաշկ',
    '🧑🏾‍🔧' => 'փականագործ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🔧' => 'փականագործ․ մուգ գույնի մաշկ',
    '👨🏻‍🔧' => 'տղամարդ փականագործ․ բաց գույնի մաշկ',
    '👨🏼‍🔧' => 'տղամարդ փականագործ․ միջին բաց գույնի մաշկ',
    '👨🏽‍🔧' => 'տղամարդ փականագործ․ միջին գույնի մաշկ',
    '👨🏾‍🔧' => 'տղամարդ փականագործ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🔧' => 'տղամարդ փականագործ․ մուգ գույնի մաշկ',
    '👩🏻‍🔧' => 'կին փականագործ․ բաց գույնի մաշկ',
    '👩🏼‍🔧' => 'կին փականագործ․ միջին բաց գույնի մաշկ',
    '👩🏽‍🔧' => 'կին փականագործ․ միջին գույնի մաշկ',
    '👩🏾‍🔧' => 'կին փականագործ․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🔧' => 'կին փականագործ․ մուգ գույնի մաշկ',
    '🧑🏻‍🏭' => 'բանվոր․ բաց գույնի մաշկ',
    '🧑🏼‍🏭' => 'բանվոր․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🏭' => 'բանվոր․ միջին գույնի մաշկ',
    '🧑🏾‍🏭' => 'բանվոր․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🏭' => 'բանվոր․ մուգ գույնի մաշկ',
    '👨🏻‍🏭' => 'տղամարդ բանվոր․ բաց գույնի մաշկ',
    '👨🏼‍🏭' => 'տղամարդ բանվոր․ միջին բաց գույնի մաշկ',
    '👨🏽‍🏭' => 'տղամարդ բանվոր․ միջին գույնի մաշկ',
    '👨🏾‍🏭' => 'տղամարդ բանվոր․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🏭' => 'տղամարդ բանվոր․ մուգ գույնի մաշկ',
    '👩🏻‍🏭' => 'բանվորուհի․ բաց գույնի մաշկ',
    '👩🏼‍🏭' => 'բանվորուհի․ միջին բաց գույնի մաշկ',
    '👩🏽‍🏭' => 'բանվորուհի․ միջին գույնի մաշկ',
    '👩🏾‍🏭' => 'բանվորուհի․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🏭' => 'բանվորուհի․ մուգ գույնի մաշկ',
    '🧑🏻‍💼' => 'գրասենյակային աշխատող․ բաց գույնի մաշկ',
    '🧑🏼‍💼' => 'գրասենյակային աշխատող․ միջին բաց գույնի մաշկ',
    '🧑🏽‍💼' => 'գրասենյակային աշխատող․ միջին գույնի մաշկ',
    '🧑🏾‍💼' => 'գրասենյակային աշխատող․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍💼' => 'գրասենյակային աշխատող․ մուգ գույնի մաշկ',
    '👨🏻‍💼' => 'տղամարդ գրասենյակի աշխատող․ բաց գույնի մաշկ',
    '👨🏼‍💼' => 'տղամարդ գրասենյակի աշխատող․ միջին բաց գույնի մաշկ',
    '👨🏽‍💼' => 'տղամարդ գրասենյակի աշխատող․ միջին գույնի մաշկ',
    '👨🏾‍💼' => 'տղամարդ գրասենյակի աշխատող․ միջին մուգ գույնի մաշկ',
    '👨🏿‍💼' => 'տղամարդ գրասենյակի աշխատող․ մուգ գույնի մաշկ',
    '👩🏻‍💼' => 'կին գրասենյակի աշխատող․ բաց գույնի մաշկ',
    '👩🏼‍💼' => 'կին գրասենյակի աշխատող․ միջին բաց գույնի մաշկ',
    '👩🏽‍💼' => 'կին գրասենյակի աշխատող․ միջին գույնի մաշկ',
    '👩🏾‍💼' => 'կին գրասենյակի աշխատող․ միջին մուգ գույնի մաշկ',
    '👩🏿‍💼' => 'կին գրասենյակի աշխատող․ մուգ գույնի մաշկ',
    '🧑🏻‍🔬' => 'գիտնական․ բաց գույնի մաշկ',
    '🧑🏼‍🔬' => 'գիտնական․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🔬' => 'գիտնական․ միջին գույնի մաշկ',
    '🧑🏾‍🔬' => 'գիտնական․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🔬' => 'գիտնական․ մուգ գույնի մաշկ',
    '👨🏻‍🔬' => 'տղամարդ գիտնական․ բաց գույնի մաշկ',
    '👨🏼‍🔬' => 'տղամարդ գիտնական․ միջին բաց գույնի մաշկ',
    '👨🏽‍🔬' => 'տղամարդ գիտնական․ միջին գույնի մաշկ',
    '👨🏾‍🔬' => 'տղամարդ գիտնական․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🔬' => 'տղամարդ գիտնական․ մուգ գույնի մաշկ',
    '👩🏻‍🔬' => 'կին գիտնական․ բաց գույնի մաշկ',
    '👩🏼‍🔬' => 'կին գիտնական․ միջին բաց գույնի մաշկ',
    '👩🏽‍🔬' => 'կին գիտնական․ միջին գույնի մաշկ',
    '👩🏾‍🔬' => 'կին գիտնական․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🔬' => 'կին գիտնական․ մուգ գույնի մաշկ',
    '🧑🏻‍💻' => 'տեխնիկական մասնագետ․ բաց գույնի մաշկ',
    '🧑🏼‍💻' => 'տեխնիկական մասնագետ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍💻' => 'տեխնիկական մասնագետ․ միջին գույնի մաշկ',
    '🧑🏾‍💻' => 'տեխնիկական մասնագետ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍💻' => 'տեխնիկական մասնագետ․ մուգ գույնի մաշկ',
    '👨🏻‍💻' => 'տղամարդ ծրագրավորող․ բաց գույնի մաշկ',
    '👨🏼‍💻' => 'տղամարդ ծրագրավորող․ միջին բաց գույնի մաշկ',
    '👨🏽‍💻' => 'տղամարդ ծրագրավորող․ միջին գույնի մաշկ',
    '👨🏾‍💻' => 'տղամարդ ծրագրավորող․ միջին մուգ գույնի մաշկ',
    '👨🏿‍💻' => 'տղամարդ ծրագրավորող․ մուգ գույնի մաշկ',
    '👩🏻‍💻' => 'կին ծրագրավորող․ բաց գույնի մաշկ',
    '👩🏼‍💻' => 'կին ծրագրավորող․ միջին բաց գույնի մաշկ',
    '👩🏽‍💻' => 'կին ծրագրավորող․ միջին գույնի մաշկ',
    '👩🏾‍💻' => 'կին ծրագրավորող․ միջին մուգ գույնի մաշկ',
    '👩🏿‍💻' => 'կին ծրագրավորող․ մուգ գույնի մաշկ',
    '🧑🏻‍🎤' => 'երգիչ․ բաց գույնի մաշկ',
    '🧑🏼‍🎤' => 'երգիչ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🎤' => 'երգիչ․ միջին գույնի մաշկ',
    '🧑🏾‍🎤' => 'երգիչ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🎤' => 'երգիչ․ մուգ գույնի մաշկ',
    '👨🏻‍🎤' => 'տղամարդ երգիչ․ բաց գույնի մաշկ',
    '👨🏼‍🎤' => 'տղամարդ երգիչ․ միջին բաց գույնի մաշկ',
    '👨🏽‍🎤' => 'տղամարդ երգիչ․ միջին գույնի մաշկ',
    '👨🏾‍🎤' => 'տղամարդ երգիչ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🎤' => 'տղամարդ երգիչ․ մուգ գույնի մաշկ',
    '👩🏻‍🎤' => 'երգչուհի․ բաց գույնի մաշկ',
    '👩🏼‍🎤' => 'երգչուհի․ միջին բաց գույնի մաշկ',
    '👩🏽‍🎤' => 'երգչուհի․ միջին գույնի մաշկ',
    '👩🏾‍🎤' => 'երգչուհի․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🎤' => 'երգչուհի․ մուգ գույնի մաշկ',
    '🧑🏻‍🎨' => 'նկարիչ․ բաց գույնի մաշկ',
    '🧑🏼‍🎨' => 'նկարիչ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🎨' => 'նկարիչ․ միջին գույնի մաշկ',
    '🧑🏾‍🎨' => 'նկարիչ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🎨' => 'նկարիչ․ մուգ գույնի մաշկ',
    '👨🏻‍🎨' => 'տղամարդ նկարիչ․ բաց գույնի մաշկ',
    '👨🏼‍🎨' => 'տղամարդ նկարիչ․ միջին բաց գույնի մաշկ',
    '👨🏽‍🎨' => 'տղամարդ նկարիչ․ միջին գույնի մաշկ',
    '👨🏾‍🎨' => 'տղամարդ նկարիչ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🎨' => 'տղամարդ նկարիչ․ մուգ գույնի մաշկ',
    '👩🏻‍🎨' => 'նկարչուհի․ բաց գույնի մաշկ',
    '👩🏼‍🎨' => 'նկարչուհի․ միջին բաց գույնի մաշկ',
    '👩🏽‍🎨' => 'նկարչուհի․ միջին գույնի մաշկ',
    '👩🏾‍🎨' => 'նկարչուհի․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🎨' => 'նկարչուհի․ մուգ գույնի մաշկ',
    '🧑🏻‍✈' => 'օդաչու․ բաց գույնի մաշկ',
    '🧑🏼‍✈' => 'օդաչու․ միջին բաց գույնի մաշկ',
    '🧑🏽‍✈' => 'օդաչու․ միջին գույնի մաշկ',
    '🧑🏾‍✈' => 'օդաչու․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍✈' => 'օդաչու․ մուգ գույնի մաշկ',
    '👨🏻‍✈' => 'տղամարդ օդաչու․ բաց գույնի մաշկ',
    '👨🏼‍✈' => 'տղամարդ օդաչու․ միջին բաց գույնի մաշկ',
    '👨🏽‍✈' => 'տղամարդ օդաչու․ միջին գույնի մաշկ',
    '👨🏾‍✈' => 'տղամարդ օդաչու․ միջին մուգ գույնի մաշկ',
    '👨🏿‍✈' => 'տղամարդ օդաչու․ մուգ գույնի մաշկ',
    '👩🏻‍✈' => 'կին օդաչու․ բաց գույնի մաշկ',
    '👩🏼‍✈' => 'կին օդաչու․ միջին բաց գույնի մաշկ',
    '👩🏽‍✈' => 'կին օդաչու․ միջին գույնի մաշկ',
    '👩🏾‍✈' => 'կին օդաչու․ միջին մուգ գույնի մաշկ',
    '👩🏿‍✈' => 'կին օդաչու․ մուգ գույնի մաշկ',
    '🧑🏻‍🚀' => 'տիեզերագնաց․ բաց գույնի մաշկ',
    '🧑🏼‍🚀' => 'տիեզերագնաց․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🚀' => 'տիեզերագնաց․ միջին գույնի մաշկ',
    '🧑🏾‍🚀' => 'տիեզերագնաց․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🚀' => 'տիեզերագնաց․ մուգ գույնի մաշկ',
    '👨🏻‍🚀' => 'տղամարդ տիեզերագնաց․ բաց գույնի մաշկ',
    '👨🏼‍🚀' => 'տղամարդ տիեզերագնաց․ միջին բաց գույնի մաշկ',
    '👨🏽‍🚀' => 'տղամարդ տիեզերագնաց․ միջին գույնի մաշկ',
    '👨🏾‍🚀' => 'տղամարդ տիեզերագնաց․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🚀' => 'տղամարդ տիեզերագնաց․ մուգ գույնի մաշկ',
    '👩🏻‍🚀' => 'կին տիեզերագնաց․ բաց գույնի մաշկ',
    '👩🏼‍🚀' => 'կին տիեզերագնաց․ միջին բաց գույնի մաշկ',
    '👩🏽‍🚀' => 'կին տիեզերագնաց․ միջին գույնի մաշկ',
    '👩🏾‍🚀' => 'կին տիեզերագնաց․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🚀' => 'կին տիեզերագնաց․ մուգ գույնի մաշկ',
    '🧑🏻‍🚒' => 'հրշեջ․ բաց գույնի մաշկ',
    '🧑🏼‍🚒' => 'հրշեջ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🚒' => 'հրշեջ․ միջին գույնի մաշկ',
    '🧑🏾‍🚒' => 'հրշեջ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🚒' => 'հրշեջ․ մուգ գույնի մաշկ',
    '👨🏻‍🚒' => 'տղամարդ հրշեջ․ բաց գույնի մաշկ',
    '👨🏼‍🚒' => 'տղամարդ հրշեջ․ միջին բաց գույնի մաշկ',
    '👨🏽‍🚒' => 'տղամարդ հրշեջ․ միջին գույնի մաշկ',
    '👨🏾‍🚒' => 'տղամարդ հրշեջ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🚒' => 'տղամարդ հրշեջ․ մուգ գույնի մաշկ',
    '👩🏻‍🚒' => 'կին հրշեջ․ բաց գույնի մաշկ',
    '👩🏼‍🚒' => 'կին հրշեջ․ միջին բաց գույնի մաշկ',
    '👩🏽‍🚒' => 'կին հրշեջ․ միջին գույնի մաշկ',
    '👩🏾‍🚒' => 'կին հրշեջ․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🚒' => 'կին հրշեջ․ մուգ գույնի մաշկ',
    '👮🏻‍♂' => 'տղամարդ ոստիկան․ բաց գույնի մաշկ',
    '👮🏼‍♂' => 'տղամարդ ոստիկան․ միջին բաց գույնի մաշկ',
    '👮🏽‍♂' => 'տղամարդ ոստիկան․ միջին գույնի մաշկ',
    '👮🏾‍♂' => 'տղամարդ ոստիկան․ միջին մուգ գույնի մաշկ',
    '👮🏿‍♂' => 'տղամարդ ոստիկան․ մուգ գույնի մաշկ',
    '👮🏻‍♀' => 'կին ոստիկան․ բաց գույնի մաշկ',
    '👮🏼‍♀' => 'կին ոստիկան․ միջին բաց գույնի մաշկ',
    '👮🏽‍♀' => 'կին ոստիկան․ միջին գույնի մաշկ',
    '👮🏾‍♀' => 'կին ոստիկան․ միջին մուգ գույնի մաշկ',
    '👮🏿‍♀' => 'կին ոստիկան․ մուգ գույնի մաշկ',
    '🕵🏻‍♂' => 'տղամարդ խուզարկու․ բաց գույնի մաշկ',
    '🕵🏼‍♂' => 'տղամարդ խուզարկու․ միջին բաց գույնի մաշկ',
    '🕵🏽‍♂' => 'տղամարդ խուզարկու․ միջին գույնի մաշկ',
    '🕵🏾‍♂' => 'տղամարդ խուզարկու․ միջին մուգ գույնի մաշկ',
    '🕵🏿‍♂' => 'տղամարդ խուզարկու․ մուգ գույնի մաշկ',
    '🕵🏻‍♀' => 'կին խուզարկու․ բաց գույնի մաշկ',
    '🕵🏼‍♀' => 'կին խուզարկու․ միջին բաց գույնի մաշկ',
    '🕵🏽‍♀' => 'կին խուզարկու․ միջին գույնի մաշկ',
    '🕵🏾‍♀' => 'կին խուզարկու․ միջին մուգ գույնի մաշկ',
    '🕵🏿‍♀' => 'կին խուզարկու․ մուգ գույնի մաշկ',
    '💂🏻‍♂' => 'տղամարդ ժամապահ․ բաց գույնի մաշկ',
    '💂🏼‍♂' => 'տղամարդ ժամապահ․ միջին բաց գույնի մաշկ',
    '💂🏽‍♂' => 'տղամարդ ժամապահ․ միջին գույնի մաշկ',
    '💂🏾‍♂' => 'տղամարդ ժամապահ․ միջին մուգ գույնի մաշկ',
    '💂🏿‍♂' => 'տղամարդ ժամապահ․ մուգ գույնի մաշկ',
    '💂🏻‍♀' => 'կին ժամապահ․ բաց գույնի մաշկ',
    '💂🏼‍♀' => 'կին ժամապահ․ միջին բաց գույնի մաշկ',
    '💂🏽‍♀' => 'կին ժամապահ․ միջին գույնի մաշկ',
    '💂🏾‍♀' => 'կին ժամապահ․ միջին մուգ գույնի մաշկ',
    '💂🏿‍♀' => 'կին ժամապահ․ մուգ գույնի մաշկ',
    '👷🏻‍♂' => 'տղամարդ շինարար․ բաց գույնի մաշկ',
    '👷🏼‍♂' => 'տղամարդ շինարար․ միջին բաց գույնի մաշկ',
    '👷🏽‍♂' => 'տղամարդ շինարար․ միջին գույնի մաշկ',
    '👷🏾‍♂' => 'տղամարդ շինարար․ միջին մուգ գույնի մաշկ',
    '👷🏿‍♂' => 'տղամարդ շինարար․ մուգ գույնի մաշկ',
    '👷🏻‍♀' => 'կին շինարար․ բաց գույնի մաշկ',
    '👷🏼‍♀' => 'կին շինարար․ միջին բաց գույնի մաշկ',
    '👷🏽‍♀' => 'կին շինարար․ միջին գույնի մաշկ',
    '👷🏾‍♀' => 'կին շինարար․ միջին մուգ գույնի մաշկ',
    '👷🏿‍♀' => 'կին շինարար․ մուգ գույնի մաշկ',
    '👳🏻‍♂' => 'չալմայով տղամարդ․ բաց գույնի մաշկ',
    '👳🏼‍♂' => 'չալմայով տղամարդ․ միջին բաց գույնի մաշկ',
    '👳🏽‍♂' => 'չալմայով տղամարդ․ միջին գույնի մաշկ',
    '👳🏾‍♂' => 'չալմայով տղամարդ․ միջին մուգ գույնի մաշկ',
    '👳🏿‍♂' => 'չալմայով տղամարդ․ մուգ գույնի մաշկ',
    '👳🏻‍♀' => 'չալմայով կին․ բաց գույնի մաշկ',
    '👳🏼‍♀' => 'չալմայով կին․ միջին բաց գույնի մաշկ',
    '👳🏽‍♀' => 'չալմայով կին․ միջին գույնի մաշկ',
    '👳🏾‍♀' => 'չալմայով կին․ միջին մուգ գույնի մաշկ',
    '👳🏿‍♀' => 'չալմայով կին․ մուգ գույնի մաշկ',
    '🤵🏻‍♂' => 'սմոկինգով տղամարդ․ բաց գույնի մաշկ',
    '🤵🏼‍♂' => 'սմոկինգով տղամարդ․ միջին բաց գույնի մաշկ',
    '🤵🏽‍♂' => 'սմոկինգով տղամարդ․ միջին գույնի մաշկ',
    '🤵🏾‍♂' => 'սմոկինգով տղամարդ․ միջին մուգ գույնի մաշկ',
    '🤵🏿‍♂' => 'սմոկինգով տղամարդ․ մուգ գույնի մաշկ',
    '🤵🏻‍♀' => 'սմոկինգով կին․ բաց գույնի մաշկ',
    '🤵🏼‍♀' => 'սմոկինգով կին․ միջին բաց գույնի մաշկ',
    '🤵🏽‍♀' => 'սմոկինգով կին․ միջին գույնի մաշկ',
    '🤵🏾‍♀' => 'սմոկինգով կին․ միջին մուգ գույնի մաշկ',
    '🤵🏿‍♀' => 'սմոկինգով կին․ մուգ գույնի մաշկ',
    '👰🏻‍♂' => 'քողով տղամարդ․ բաց գույնի մաշկ',
    '👰🏼‍♂' => 'քողով տղամարդ․ միջին բաց գույնի մաշկ',
    '👰🏽‍♂' => 'քողով տղամարդ․ միջին գույնի մաշկ',
    '👰🏾‍♂' => 'քողով տղամարդ․ միջին մուգ գույնի մաշկ',
    '👰🏿‍♂' => 'քողով տղամարդ․ մուգ գույնի մաշկ',
    '👰🏻‍♀' => 'քողով կին․ բաց գույնի մաշկ',
    '👰🏼‍♀' => 'քողով կին․ միջին բաց գույնի մաշկ',
    '👰🏽‍♀' => 'քողով կին․ միջին գույնի մաշկ',
    '👰🏾‍♀' => 'քողով կին․ միջին մուգ գույնի մաշկ',
    '👰🏿‍♀' => 'քողով կին․ մուգ գույնի մաշկ',
    '👩🏻‍🍼' => 'երեխային կերակրող կին․ բաց գույնի մաշկ',
    '👩🏼‍🍼' => 'երեխային կերակրող կին․ միջին բաց գույնի մաշկ',
    '👩🏽‍🍼' => 'երեխային կերակրող կին․ միջին գույնի մաշկ',
    '👩🏾‍🍼' => 'երեխային կերակրող կին․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🍼' => 'երեխային կերակրող կին․ մուգ գույնի մաշկ',
    '👨🏻‍🍼' => 'երեխային կերակրող մարդ․ բաց գույնի մաշկ',
    '👨🏼‍🍼' => 'երեխային կերակրող մարդ․ միջին բաց գույնի մաշկ',
    '👨🏽‍🍼' => 'երեխային կերակրող մարդ․ միջին գույնի մաշկ',
    '👨🏾‍🍼' => 'երեխային կերակրող մարդ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🍼' => 'երեխային կերակրող մարդ․ մուգ գույնի մաշկ',
    '🧑🏻‍🍼' => 'երեխային կերակրող անձ․ բաց գույնի մաշկ',
    '🧑🏼‍🍼' => 'երեխային կերակրող անձ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🍼' => 'երեխային կերակրող անձ․ միջին գույնի մաշկ',
    '🧑🏾‍🍼' => 'երեխային կերակրող անձ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🍼' => 'երեխային կերակրող անձ․ մուգ գույնի մաշկ',
    '🧑🏻‍🎄' => 'Ձմեռ պապ․ բաց գույնի մաշկ',
    '🧑🏼‍🎄' => 'Ձմեռ պապ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🎄' => 'Ձմեռ պապ․ միջին գույնի մաշկ',
    '🧑🏾‍🎄' => 'Ձմեռ պապ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🎄' => 'Ձմեռ պապ․ մուգ գույնի մաշկ',
    '🦸🏻‍♂' => 'տղամարդ սուպերհերոս․ բաց գույնի մաշկ',
    '🦸🏼‍♂' => 'տղամարդ սուպերհերոս․ միջին բաց գույնի մաշկ',
    '🦸🏽‍♂' => 'տղամարդ սուպերհերոս․ միջին գույնի մաշկ',
    '🦸🏾‍♂' => 'տղամարդ սուպերհերոս․ միջին մուգ գույնի մաշկ',
    '🦸🏿‍♂' => 'տղամարդ սուպերհերոս․ մուգ գույնի մաշկ',
    '🦸🏻‍♀' => 'կին սուպերհերոս․ բաց գույնի մաշկ',
    '🦸🏼‍♀' => 'կին սուպերհերոս․ միջին բաց գույնի մաշկ',
    '🦸🏽‍♀' => 'կին սուպերհերոս․ միջին գույնի մաշկ',
    '🦸🏾‍♀' => 'կին սուպերհերոս․ միջին մուգ գույնի մաշկ',
    '🦸🏿‍♀' => 'կին սուպերհերոս․ մուգ գույնի մաշկ',
    '🦹🏻‍♂' => 'տղամարդ չարագործ․ բաց գույնի մաշկ',
    '🦹🏼‍♂' => 'տղամարդ չարագործ․ միջին բաց գույնի մաշկ',
    '🦹🏽‍♂' => 'տղամարդ չարագործ․ միջին գույնի մաշկ',
    '🦹🏾‍♂' => 'տղամարդ չարագործ․ միջին մուգ գույնի մաշկ',
    '🦹🏿‍♂' => 'տղամարդ չարագործ․ մուգ գույնի մաշկ',
    '🦹🏻‍♀' => 'կին չարագործ․ բաց գույնի մաշկ',
    '🦹🏼‍♀' => 'կին չարագործ․ միջին բաց գույնի մաշկ',
    '🦹🏽‍♀' => 'կին չարագործ․ միջին գույնի մաշկ',
    '🦹🏾‍♀' => 'կին չարագործ․ միջին մուգ գույնի մաշկ',
    '🦹🏿‍♀' => 'կին չարագործ․ մուգ գույնի մաշկ',
    '🧙🏻‍♂' => 'կախարդ․ բաց գույնի մաշկ',
    '🧙🏼‍♂' => 'կախարդ․ միջին բաց գույնի մաշկ',
    '🧙🏽‍♂' => 'կախարդ․ միջին գույնի մաշկ',
    '🧙🏾‍♂' => 'կախարդ․ միջին մուգ գույնի մաշկ',
    '🧙🏿‍♂' => 'կախարդ․ մուգ գույնի մաշկ',
    '🧙🏻‍♀' => 'կախարդուհի․ բաց գույնի մաշկ',
    '🧙🏼‍♀' => 'կախարդուհի․ միջին բաց գույնի մաշկ',
    '🧙🏽‍♀' => 'կախարդուհի․ միջին գույնի մաշկ',
    '🧙🏾‍♀' => 'կախարդուհի․ միջին մուգ գույնի մաշկ',
    '🧙🏿‍♀' => 'կախարդուհի․ մուգ գույնի մաշկ',
    '🧚🏻‍♂' => 'տղամարդ-փերի․ բաց գույնի մաշկ',
    '🧚🏼‍♂' => 'տղամարդ-փերի․ միջին բաց գույնի մաշկ',
    '🧚🏽‍♂' => 'տղամարդ-փերի․ միջին գույնի մաշկ',
    '🧚🏾‍♂' => 'տղամարդ-փերի․ միջին մուգ գույնի մաշկ',
    '🧚🏿‍♂' => 'տղամարդ-փերի․ մուգ գույնի մաշկ',
    '🧚🏻‍♀' => 'կին-փերի․ բաց գույնի մաշկ',
    '🧚🏼‍♀' => 'կին-փերի․ միջին բաց գույնի մաշկ',
    '🧚🏽‍♀' => 'կին-փերի․ միջին գույնի մաշկ',
    '🧚🏾‍♀' => 'կին-փերի․ միջին մուգ գույնի մաշկ',
    '🧚🏿‍♀' => 'կին-փերի․ մուգ գույնի մաշկ',
    '🧛🏻‍♂' => 'տղամարդ-վամպիր․ բաց գույնի մաշկ',
    '🧛🏼‍♂' => 'տղամարդ-վամպիր․ միջին բաց գույնի մաշկ',
    '🧛🏽‍♂' => 'տղամարդ-վամպիր․ միջին գույնի մաշկ',
    '🧛🏾‍♂' => 'տղամարդ-վամպիր․ միջին մուգ գույնի մաշկ',
    '🧛🏿‍♂' => 'տղամարդ-վամպիր․ մուգ գույնի մաշկ',
    '🧛🏻‍♀' => 'կին-վամպիր․ բաց գույնի մաշկ',
    '🧛🏼‍♀' => 'կին-վամպիր․ միջին բաց գույնի մաշկ',
    '🧛🏽‍♀' => 'կին-վամպիր․ միջին գույնի մաշկ',
    '🧛🏾‍♀' => 'կին-վամպիր․ միջին մուգ գույնի մաշկ',
    '🧛🏿‍♀' => 'կին-վամպիր․ մուգ գույնի մաշկ',
    '🧜🏻‍♂' => 'տրիտոն․ բաց գույնի մաշկ',
    '🧜🏼‍♂' => 'տրիտոն․ միջին բաց գույնի մաշկ',
    '🧜🏽‍♂' => 'տրիտոն․ միջին գույնի մաշկ',
    '🧜🏾‍♂' => 'տրիտոն․ միջին մուգ գույնի մաշկ',
    '🧜🏿‍♂' => 'տրիտոն․ մուգ գույնի մաշկ',
    '🧜🏻‍♀' => 'ջրահարս․ բաց գույնի մաշկ',
    '🧜🏼‍♀' => 'ջրահարս․ միջին բաց գույնի մաշկ',
    '🧜🏽‍♀' => 'ջրահարս․ միջին գույնի մաշկ',
    '🧜🏾‍♀' => 'ջրահարս․ միջին մուգ գույնի մաշկ',
    '🧜🏿‍♀' => 'ջրահարս․ մուգ գույնի մաշկ',
    '🧝🏻‍♂' => 'տղամարդ-էլֆ․ բաց գույնի մաշկ',
    '🧝🏼‍♂' => 'տղամարդ-էլֆ․ միջին բաց գույնի մաշկ',
    '🧝🏽‍♂' => 'տղամարդ-էլֆ․ միջին գույնի մաշկ',
    '🧝🏾‍♂' => 'տղամարդ-էլֆ․ միջին մուգ գույնի մաշկ',
    '🧝🏿‍♂' => 'տղամարդ-էլֆ․ մուգ գույնի մաշկ',
    '🧝🏻‍♀' => 'կին-էլֆ․ բաց գույնի մաշկ',
    '🧝🏼‍♀' => 'կին-էլֆ․ միջին բաց գույնի մաշկ',
    '🧝🏽‍♀' => 'կին-էլֆ․ միջին գույնի մաշկ',
    '🧝🏾‍♀' => 'կին-էլֆ․ միջին մուգ գույնի մաշկ',
    '🧝🏿‍♀' => 'կին-էլֆ․ մուգ գույնի մաշկ',
    '💆🏻‍♂' => 'տղամարդու դեմքը մերսում են․ բաց գույնի մաշկ',
    '💆🏼‍♂' => 'տղամարդու դեմքը մերսում են․ միջին բաց գույնի մաշկ',
    '💆🏽‍♂' => 'տղամարդու դեմքը մերսում են․ միջին գույնի մաշկ',
    '💆🏾‍♂' => 'տղամարդու դեմքը մերսում են․ միջին մուգ գույնի մաշկ',
    '💆🏿‍♂' => 'տղամարդու դեմքը մերսում են․ մուգ գույնի մաշկ',
    '💆🏻‍♀' => 'կնոջ դեմքը մերսում են․ բաց գույնի մաշկ',
    '💆🏼‍♀' => 'կնոջ դեմքը մերսում են․ միջին բաց գույնի մաշկ',
    '💆🏽‍♀' => 'կնոջ դեմքը մերսում են․ միջին գույնի մաշկ',
    '💆🏾‍♀' => 'կնոջ դեմքը մերսում են․ միջին մուգ գույնի մաշկ',
    '💆🏿‍♀' => 'կնոջ դեմքը մերսում են․ մուգ գույնի մաշկ',
    '💇🏻‍♂' => 'տղամարդու մազերը կտրում են․ բաց գույնի մաշկ',
    '💇🏼‍♂' => 'տղամարդու մազերը կտրում են․ միջին բաց գույնի մաշկ',
    '💇🏽‍♂' => 'տղամարդու մազերը կտրում են․ միջին գույնի մաշկ',
    '💇🏾‍♂' => 'տղամարդու մազերը կտրում են․ միջին մուգ գույնի մաշկ',
    '💇🏿‍♂' => 'տղամարդու մազերը կտրում են․ մուգ գույնի մաշկ',
    '💇🏻‍♀' => 'կնոջ մազերը կտրում են․ բաց գույնի մաշկ',
    '💇🏼‍♀' => 'կնոջ մազերը կտրում են․ միջին բաց գույնի մաշկ',
    '💇🏽‍♀' => 'կնոջ մազերը կտրում են․ միջին գույնի մաշկ',
    '💇🏾‍♀' => 'կնոջ մազերը կտրում են․ միջին մուգ գույնի մաշկ',
    '💇🏿‍♀' => 'կնոջ մազերը կտրում են․ մուգ գույնի մաշկ',
    '🚶🏻‍♂' => 'քայլող տղամարդ․ բաց գույնի մաշկ',
    '🚶🏼‍♂' => 'քայլող տղամարդ․ միջին բաց գույնի մաշկ',
    '🚶🏽‍♂' => 'քայլող տղամարդ․ միջին գույնի մաշկ',
    '🚶🏾‍♂' => 'քայլող տղամարդ․ միջին մուգ գույնի մաշկ',
    '🚶🏿‍♂' => 'քայլող տղամարդ․ մուգ գույնի մաշկ',
    '🚶🏻‍♀' => 'քայլող կին․ բաց գույնի մաշկ',
    '🚶🏼‍♀' => 'քայլող կին․ միջին բաց գույնի մաշկ',
    '🚶🏽‍♀' => 'քայլող կին․ միջին գույնի մաշկ',
    '🚶🏾‍♀' => 'քայլող կին․ միջին մուգ գույնի մաշկ',
    '🚶🏿‍♀' => 'քայլող կին․ մուգ գույնի մաշկ',
    '🚶🏻‍➡' => 'հետիոտն․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏼‍➡' => 'հետիոտն․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏽‍➡' => 'հետիոտն․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏾‍➡' => 'հետիոտն․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🚶🏿‍➡' => 'հետիոտն․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧍🏻‍♂' => 'կանգնած տղամարդ․ բաց գույնի մաշկ',
    '🧍🏼‍♂' => 'կանգնած տղամարդ․ միջին բաց գույնի մաշկ',
    '🧍🏽‍♂' => 'կանգնած տղամարդ․ միջին գույնի մաշկ',
    '🧍🏾‍♂' => 'կանգնած տղամարդ․ միջին մուգ գույնի մաշկ',
    '🧍🏿‍♂' => 'կանգնած տղամարդ․ մուգ գույնի մաշկ',
    '🧍🏻‍♀' => 'կանգնած կին․ բաց գույնի մաշկ',
    '🧍🏼‍♀' => 'կանգնած կին․ միջին բաց գույնի մաշկ',
    '🧍🏽‍♀' => 'կանգնած կին․ միջին գույնի մաշկ',
    '🧍🏾‍♀' => 'կանգնած կին․ միջին մուգ գույնի մաշկ',
    '🧍🏿‍♀' => 'կանգնած կին․ մուգ գույնի մաշկ',
    '🧎🏻‍♂' => 'ծնկաչոք տղամարդ․ բաց գույնի մաշկ',
    '🧎🏼‍♂' => 'ծնկաչոք տղամարդ․ միջին բաց գույնի մաշկ',
    '🧎🏽‍♂' => 'ծնկաչոք տղամարդ․ միջին գույնի մաշկ',
    '🧎🏾‍♂' => 'ծնկաչոք տղամարդ․ միջին մուգ գույնի մաշկ',
    '🧎🏿‍♂' => 'ծնկաչոք տղամարդ․ մուգ գույնի մաշկ',
    '🧎🏻‍♀' => 'ծնկաչոք կին․ բաց գույնի մաշկ',
    '🧎🏼‍♀' => 'ծնկաչոք կին․ միջին բաց գույնի մաշկ',
    '🧎🏽‍♀' => 'ծնկաչոք կին․ միջին գույնի մաշկ',
    '🧎🏾‍♀' => 'ծնկաչոք կին․ միջին մուգ գույնի մաշկ',
    '🧎🏿‍♀' => 'ծնկաչոք կին․ մուգ գույնի մաշկ',
    '🧎🏻‍➡' => 'ծնկաչոք անձ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏼‍➡' => 'ծնկաչոք անձ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏽‍➡' => 'ծնկաչոք անձ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏾‍➡' => 'ծնկաչոք անձ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧎🏿‍➡' => 'ծնկաչոք անձ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🧑🏻‍🦯' => 'ձեռնափայտով անձ․ բաց գույնի մաշկ',
    '🧑🏼‍🦯' => 'ձեռնափայտով անձ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🦯' => 'ձեռնափայտով անձ․ միջին գույնի մաշկ',
    '🧑🏾‍🦯' => 'ձեռնափայտով անձ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🦯' => 'ձեռնափայտով անձ․ մուգ գույնի մաշկ',
    '👨🏻‍🦯' => 'ձեռնափայտով տղամարդ․ բաց գույնի մաշկ',
    '👨🏼‍🦯' => 'ձեռնափայտով տղամարդ․ միջին բաց գույնի մաշկ',
    '👨🏽‍🦯' => 'ձեռնափայտով տղամարդ․ միջին գույնի մաշկ',
    '👨🏾‍🦯' => 'ձեռնափայտով տղամարդ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🦯' => 'ձեռնափայտով տղամարդ․ մուգ գույնի մաշկ',
    '👩🏻‍🦯' => 'ձեռնափայտով կին․ բաց գույնի մաշկ',
    '👩🏼‍🦯' => 'ձեռնափայտով կին․ միջին բաց գույնի մաշկ',
    '👩🏽‍🦯' => 'ձեռնափայտով կին․ միջին գույնի մաշկ',
    '👩🏾‍🦯' => 'ձեռնափայտով կին․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🦯' => 'ձեռնափայտով կին․ մուգ գույնի մաշկ',
    '🧑🏻‍🦼' => 'մոտորասայլակով անձ․ բաց գույնի մաշկ',
    '🧑🏼‍🦼' => 'մոտորասայլակով անձ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🦼' => 'մոտորասայլակով անձ․ միջին գույնի մաշկ',
    '🧑🏾‍🦼' => 'մոտորասայլակով անձ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🦼' => 'մոտորասայլակով անձ․ մուգ գույնի մաշկ',
    '👨🏻‍🦼' => 'մոտորասայլակով տղամարդ․ բաց գույնի մաշկ',
    '👨🏼‍🦼' => 'մոտորասայլակով տղամարդ․ միջին բաց գույնի մաշկ',
    '👨🏽‍🦼' => 'մոտորասայլակով տղամարդ․ միջին գույնի մաշկ',
    '👨🏾‍🦼' => 'մոտորասայլակով տղամարդ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🦼' => 'մոտորասայլակով տղամարդ․ մուգ գույնի մաշկ',
    '👩🏻‍🦼' => 'մոտորասայլակով կին․ բաց գույնի մաշկ',
    '👩🏼‍🦼' => 'մոտորասայլակով կին․ միջին բաց գույնի մաշկ',
    '👩🏽‍🦼' => 'մոտորասայլակով կին․ միջին գույնի մաշկ',
    '👩🏾‍🦼' => 'մոտորասայլակով կին․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🦼' => 'մոտորասայլակով կին․ մուգ գույնի մաշկ',
    '🧑🏻‍🦽' => 'ձեռքով կառավարվող սայլակով անձ․ բաց գույնի մաշկ',
    '🧑🏼‍🦽' => 'ձեռքով կառավարվող սայլակով անձ․ միջին բաց գույնի մաշկ',
    '🧑🏽‍🦽' => 'ձեռքով կառավարվող սայլակով անձ․ միջին գույնի մաշկ',
    '🧑🏾‍🦽' => 'ձեռքով կառավարվող սայլակով անձ․ միջին մուգ գույնի մաշկ',
    '🧑🏿‍🦽' => 'ձեռքով կառավարվող սայլակով անձ․ մուգ գույնի մաշկ',
    '👨🏻‍🦽' => 'անվասայլակով տղամարդ․ բաց գույնի մաշկ',
    '👨🏼‍🦽' => 'անվասայլակով տղամարդ․ միջին բաց գույնի մաշկ',
    '👨🏽‍🦽' => 'անվասայլակով տղամարդ․ միջին գույնի մաշկ',
    '👨🏾‍🦽' => 'անվասայլակով տղամարդ․ միջին մուգ գույնի մաշկ',
    '👨🏿‍🦽' => 'անվասայլակով տղամարդ․ մուգ գույնի մաշկ',
    '👩🏻‍🦽' => 'ձեռքով կառավարվող անվասայլակով կին․ բաց գույնի մաշկ',
    '👩🏼‍🦽' => 'ձեռքով կառավարվող անվասայլակով կին․ միջին բաց գույնի մաշկ',
    '👩🏽‍🦽' => 'ձեռքով կառավարվող անվասայլակով կին․ միջին գույնի մաշկ',
    '👩🏾‍🦽' => 'ձեռքով կառավարվող անվասայլակով կին․ միջին մուգ գույնի մաշկ',
    '👩🏿‍🦽' => 'ձեռքով կառավարվող անվասայլակով կին․ մուգ գույնի մաշկ',
    '🏃🏻‍♂' => 'վազող տղամարդ․ բաց գույնի մաշկ',
    '🏃🏼‍♂' => 'վազող տղամարդ․ միջին բաց գույնի մաշկ',
    '🏃🏽‍♂' => 'վազող տղամարդ․ միջին գույնի մաշկ',
    '🏃🏾‍♂' => 'վազող տղամարդ․ միջին մուգ գույնի մաշկ',
    '🏃🏿‍♂' => 'վազող տղամարդ․ մուգ գույնի մաշկ',
    '🏃🏻‍♀' => 'վազող կին․ բաց գույնի մաշկ',
    '🏃🏼‍♀' => 'վազող կին․ միջին բաց գույնի մաշկ',
    '🏃🏽‍♀' => 'վազող կին․ միջին գույնի մաշկ',
    '🏃🏾‍♀' => 'վազող կին․ միջին մուգ գույնի մաշկ',
    '🏃🏿‍♀' => 'վազող կին․ մուգ գույնի մաշկ',
    '🏃🏻‍➡' => 'վազող անձ․ բաց գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏼‍➡' => 'վազող անձ․ միջին բաց գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏽‍➡' => 'վազող անձ․ միջին գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏾‍➡' => 'վազող անձ․ միջին մուգ գույնի մաշկ և դեմքով՝ աջ',
    '🏃🏿‍➡' => 'վազող անձ․ մուգ գույնի մաշկ և դեմքով՝ աջ',
    '👯🏻‍♀' => 'զվարճացող կանայք․ բաց գույնի մաշկ',
    '👯🏼‍♀' => 'զվարճացող կանայք․ միջին բաց գույնի մաշկ',
    '👯🏽‍♀' => 'զվարճացող կանայք․ միջին գույնի մաշկ',
    '👯🏾‍♀' => 'զվարճացող կանայք․ միջին մուգ գույնի մաշկ',
    '👯🏿‍♀' => 'զվարճացող կանայք․ մուգ գույնի մաշկ',
    '👯🏻‍♂' => 'զվարճացող տղամարդիկ․ բաց գույնի մաշկ',
    '👯🏼‍♂' => 'զվարճացող տղամարդիկ․ միջին բաց գույնի մաշկ',
    '👯🏽‍♂' => 'զվարճացող տղամարդիկ․ միջին գույնի մաշկ',
    '👯🏾‍♂' => 'զվարճացող տղամարդիկ․ միջին մուգ գույնի մաշկ',
    '👯🏿‍♂' => 'զվարճացող տղամարդիկ․ մուգ գույնի մաշկ',
    '🧖🏻‍♂' => 'տղամարդ բաղնիքում․ բաց գույնի մաշկ',
    '🧖🏼‍♂' => 'տղամարդ բաղնիքում․ միջին բաց գույնի մաշկ',
    '🧖🏽‍♂' => 'տղամարդ բաղնիքում․ միջին գույնի մաշկ',
    '🧖🏾‍♂' => 'տղամարդ բաղնիքում․ միջին մուգ գույնի մաշկ',
    '🧖🏿‍♂' => 'տղամարդ բաղնիքում․ մուգ գույնի մաշկ',
    '🧖🏻‍♀' => 'կին բաղնիքում․ բաց գույնի մաշկ',
    '🧖🏼‍♀' => 'կին բաղնիքում․ միջին բաց գույնի մաշկ',
    '🧖🏽‍♀' => 'կին բաղնիքում․ միջին գույնի մաշկ',
    '🧖🏾‍♀' => 'կին բաղնիքում․ միջին մուգ գույնի մաշկ',
    '🧖🏿‍♀' => 'կին բաղնիքում․ մուգ գույնի մաշկ',
    '🧗🏻‍♂' => 'մագլցող տղամարդ․ բաց գույնի մաշկ',
    '🧗🏼‍♂' => 'մագլցող տղամարդ․ միջին բաց գույնի մաշկ',
    '🧗🏽‍♂' => 'մագլցող տղամարդ․ միջին գույնի մաշկ',
    '🧗🏾‍♂' => 'մագլցող տղամարդ․ միջին մուգ գույնի մաշկ',
    '🧗🏿‍♂' => 'մագլցող տղամարդ․ մուգ գույնի մաշկ',
    '🧗🏻‍♀' => 'մագլցող կին․ բաց գույնի մաշկ',
    '🧗🏼‍♀' => 'մագլցող կին․ միջին բաց գույնի մաշկ',
    '🧗🏽‍♀' => 'մագլցող կին․ միջին գույնի մաշկ',
    '🧗🏾‍♀' => 'մագլցող կին․ միջին մուգ գույնի մաշկ',
    '🧗🏿‍♀' => 'մագլցող կին․ մուգ գույնի մաշկ',
    '🏌🏻‍♂' => 'գոլֆ խաղացող տղամարդ․ բաց գույնի մաշկ',
    '🏌🏼‍♂' => 'գոլֆ խաղացող տղամարդ․ միջին բաց գույնի մաշկ',
    '🏌🏽‍♂' => 'գոլֆ խաղացող տղամարդ․ միջին գույնի մաշկ',
    '🏌🏾‍♂' => 'գոլֆ խաղացող տղամարդ․ միջին մուգ գույնի մաշկ',
    '🏌🏿‍♂' => 'գոլֆ խաղացող տղամարդ․ մուգ գույնի մաշկ',
    '🏌🏻‍♀' => 'գոլֆ խաղացող կին․ բաց գույնի մաշկ',
    '🏌🏼‍♀' => 'գոլֆ խաղացող կին․ միջին բաց գույնի մաշկ',
    '🏌🏽‍♀' => 'գոլֆ խաղացող կին․ միջին գույնի մաշկ',
    '🏌🏾‍♀' => 'գոլֆ խաղացող կին․ միջին մուգ գույնի մաշկ',
    '🏌🏿‍♀' => 'գոլֆ խաղացող կին․ մուգ գույնի մաշկ',
    '🏄🏻‍♂' => 'սերֆինգով զբաղվող տղամարդ․ բաց գույնի մաշկ',
    '🏄🏼‍♂' => 'սերֆինգով զբաղվող տղամարդ․ միջին բաց գույնի մաշկ',
    '🏄🏽‍♂' => 'սերֆինգով զբաղվող տղամարդ․ միջին գույնի մաշկ',
    '🏄🏾‍♂' => 'սերֆինգով զբաղվող տղամարդ․ միջին մուգ գույնի մաշկ',
    '🏄🏿‍♂' => 'սերֆինգով զբաղվող տղամարդ․ մուգ գույնի մաշկ',
    '🏄🏻‍♀' => 'սերֆինգով զբաղվող կին․ բաց գույնի մաշկ',
    '🏄🏼‍♀' => 'սերֆինգով զբաղվող կին․ միջին բաց գույնի մաշկ',
    '🏄🏽‍♀' => 'սերֆինգով զբաղվող կին․ միջին գույնի մաշկ',
    '🏄🏾‍♀' => 'սերֆինգով զբաղվող կին․ միջին մուգ գույնի մաշկ',
    '🏄🏿‍♀' => 'սերֆինգով զբաղվող կին․ մուգ գույնի մաշկ',
    '🚣🏻‍♂' => 'թիավարող տղամարդ․ բաց գույնի մաշկ',
    '🚣🏼‍♂' => 'թիավարող տղամարդ․ միջին բաց գույնի մաշկ',
    '🚣🏽‍♂' => 'թիավարող տղամարդ․ միջին գույնի մաշկ',
    '🚣🏾‍♂' => 'թիավարող տղամարդ․ միջին մուգ գույնի մաշկ',
    '🚣🏿‍♂' => 'թիավարող տղամարդ․ մուգ գույնի մաշկ',
    '🚣🏻‍♀' => 'թիավարող կին․ բաց գույնի մաշկ',
    '🚣🏼‍♀' => 'թիավարող կին․ միջին բաց գույնի մաշկ',
    '🚣🏽‍♀' => 'թիավարող կին․ միջին գույնի մաշկ',
    '🚣🏾‍♀' => 'թիավարող կին․ միջին մուգ գույնի մաշկ',
    '🚣🏿‍♀' => 'թիավարող կին․ մուգ գույնի մաշկ',
    '🏊🏻‍♂' => 'տղամարդ լողորդ․ բաց գույնի մաշկ',
    '🏊🏼‍♂' => 'տղամարդ լողորդ․ միջին բաց գույնի մաշկ',
    '🏊🏽‍♂' => 'տղամարդ լողորդ․ միջին գույնի մաշկ',
    '🏊🏾‍♂' => 'տղամարդ լողորդ․ միջին մուգ գույնի մաշկ',
    '🏊🏿‍♂' => 'տղամարդ լողորդ․ մուգ գույնի մաշկ',
    '🏊🏻‍♀' => 'լողորդուհի․ բաց գույնի մաշկ',
    '🏊🏼‍♀' => 'լողորդուհի․ միջին բաց գույնի մաշկ',
    '🏊🏽‍♀' => 'լողորդուհի․ միջին գույնի մաշկ',
    '🏊🏾‍♀' => 'լողորդուհի․ միջին մուգ գույնի մաշկ',
    '🏊🏿‍♀' => 'լողորդուհի․ մուգ գույնի մաշկ',
    '⛹🏻‍♂' => 'գնդակով տղամարդ․ բաց գույնի մաշկ',
    '⛹🏼‍♂' => 'գնդակով տղամարդ․ միջին բաց գույնի մաշկ',
    '⛹🏽‍♂' => 'գնդակով տղամարդ․ միջին գույնի մաշկ',
    '⛹🏾‍♂' => 'գնդակով տղամարդ․ միջին մուգ գույնի մաշկ',
    '⛹🏿‍♂' => 'գնդակով տղամարդ․ մուգ գույնի մաշկ',
    '⛹🏻‍♀' => 'գնդակով կին․ բաց գույնի մաշկ',
    '⛹🏼‍♀' => 'գնդակով կին․ միջին բաց գույնի մաշկ',
    '⛹🏽‍♀' => 'գնդակով կին․ միջին գույնի մաշկ',
    '⛹🏾‍♀' => 'գնդակով կին․ միջին մուգ գույնի մաշկ',
    '⛹🏿‍♀' => 'գնդակով կին․ մուգ գույնի մաշկ',
    '🏋🏻‍♂' => 'տղամարդ ծանրորդ․ բաց գույնի մաշկ',
    '🏋🏼‍♂' => 'տղամարդ ծանրորդ․ միջին բաց գույնի մաշկ',
    '🏋🏽‍♂' => 'տղամարդ ծանրորդ․ միջին գույնի մաշկ',
    '🏋🏾‍♂' => 'տղամարդ ծանրորդ․ միջին մուգ գույնի մաշկ',
    '🏋🏿‍♂' => 'տղամարդ ծանրորդ․ մուգ գույնի մաշկ',
    '🏋🏻‍♀' => 'ծանրորդուհի․ բաց գույնի մաշկ',
    '🏋🏼‍♀' => 'ծանրորդուհի․ միջին բաց գույնի մաշկ',
    '🏋🏽‍♀' => 'ծանրորդուհի․ միջին գույնի մաշկ',
    '🏋🏾‍♀' => 'ծանրորդուհի․ միջին մուգ գույնի մաշկ',
    '🏋🏿‍♀' => 'ծանրորդուհի․ մուգ գույնի մաշկ',
    '🚴🏻‍♂' => 'տղամարդ հեծանվորդ․ բաց գույնի մաշկ',
    '🚴🏼‍♂' => 'տղամարդ հեծանվորդ․ միջին բաց գույնի մաշկ',
    '🚴🏽‍♂' => 'տղամարդ հեծանվորդ․ միջին գույնի մաշկ',
    '🚴🏾‍♂' => 'տղամարդ հեծանվորդ․ միջին մուգ գույնի մաշկ',
    '🚴🏿‍♂' => 'տղամարդ հեծանվորդ․ մուգ գույնի մաշկ',
    '🚴🏻‍♀' => 'հեծանվորդուհի․ բաց գույնի մաշկ',
    '🚴🏼‍♀' => 'հեծանվորդուհի․ միջին բաց գույնի մաշկ',
    '🚴🏽‍♀' => 'հեծանվորդուհի․ միջին գույնի մաշկ',
    '🚴🏾‍♀' => 'հեծանվորդուհի․ միջին մուգ գույնի մաշկ',
    '🚴🏿‍♀' => 'հեծանվորդուհի․ մուգ գույնի մաշկ',
    '🚵🏻‍♂' => 'տղամարդ լեռնահեծանվորդ․ բաց գույնի մաշկ',
    '🚵🏼‍♂' => 'տղամարդ լեռնահեծանվորդ․ միջին բաց գույնի մաշկ',
    '🚵🏽‍♂' => 'տղամարդ լեռնահեծանվորդ․ միջին գույնի մաշկ',
    '🚵🏾‍♂' => 'տղամարդ լեռնահեծանվորդ․ միջին մուգ գույնի մաշկ',
    '🚵🏿‍♂' => 'տղամարդ լեռնահեծանվորդ․ մուգ գույնի մաշկ',
    '🚵🏻‍♀' => 'լեռնահեծանվորդուհի․ բաց գույնի մաշկ',
    '🚵🏼‍♀' => 'լեռնահեծանվորդուհի․ միջին բաց գույնի մաշկ',
    '🚵🏽‍♀' => 'լեռնահեծանվորդուհի․ միջին գույնի մաշկ',
    '🚵🏾‍♀' => 'լեռնահեծանվորդուհի․ միջին մուգ գույնի մաշկ',
    '🚵🏿‍♀' => 'լեռնահեծանվորդուհի․ մուգ գույնի մաշկ',
    '🤸🏻‍♂' => 'տղամարդ ակրոբատ․ բաց գույնի մաշկ',
    '🤸🏼‍♂' => 'տղամարդ ակրոբատ․ միջին բաց գույնի մաշկ',
    '🤸🏽‍♂' => 'տղամարդ ակրոբատ․ միջին գույնի մաշկ',
    '🤸🏾‍♂' => 'տղամարդ ակրոբատ․ միջին մուգ գույնի մաշկ',
    '🤸🏿‍♂' => 'տղամարդ ակրոբատ․ մուգ գույնի մաշկ',
    '🤸🏻‍♀' => 'կին ակրոբատ․ բաց գույնի մաշկ',
    '🤸🏼‍♀' => 'կին ակրոբատ․ միջին բաց գույնի մաշկ',
    '🤸🏽‍♀' => 'կին ակրոբատ․ միջին գույնի մաշկ',
    '🤸🏾‍♀' => 'կին ակրոբատ․ միջին մուգ գույնի մաշկ',
    '🤸🏿‍♀' => 'կին ակրոբատ․ մուգ գույնի մաշկ',
    '🤼🏻‍♀' => 'կին ըմբշամարտիկներ․ բաց գույնի մաշկ',
    '🤼🏼‍♀' => 'կին ըմբշամարտիկներ․ միջին բաց գույնի մաշկ',
    '🤼🏽‍♀' => 'կին ըմբշամարտիկներ․ միջին գույնի մաշկ',
    '🤼🏾‍♀' => 'կին ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ',
    '🤼🏿‍♀' => 'կին ըմբշամարտիկներ․ մուգ գույնի մաշկ',
    '🤼🏻‍♂' => 'տղամարդ ըմբշամարտիկներ․ բաց գույնի մաշկ',
    '🤼🏼‍♂' => 'տղամարդ ըմբշամարտիկներ․ միջին բաց գույնի մաշկ',
    '🤼🏽‍♂' => 'տղամարդ ըմբշամարտիկներ․ միջին գույնի մաշկ',
    '🤼🏾‍♂' => 'տղամարդ ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ',
    '🤼🏿‍♂' => 'տղամարդ ըմբշամարտիկներ․ մուգ գույնի մաշկ',
    '🤽🏻‍♂' => 'ջրային պոլո խաղացող տղամարդ․ բաց գույնի մաշկ',
    '🤽🏼‍♂' => 'ջրային պոլո խաղացող տղամարդ․ միջին բաց գույնի մաշկ',
    '🤽🏽‍♂' => 'ջրային պոլո խաղացող տղամարդ․ միջին գույնի մաշկ',
    '🤽🏾‍♂' => 'ջրային պոլո խաղացող տղամարդ․ միջին մուգ գույնի մաշկ',
    '🤽🏿‍♂' => 'ջրային պոլո խաղացող տղամարդ․ մուգ գույնի մաշկ',
    '🤽🏻‍♀' => 'ջրային պոլո խաղացող կին․ բաց գույնի մաշկ',
    '🤽🏼‍♀' => 'ջրային պոլո խաղացող կին․ միջին բաց գույնի մաշկ',
    '🤽🏽‍♀' => 'ջրային պոլո խաղացող կին․ միջին գույնի մաշկ',
    '🤽🏾‍♀' => 'ջրային պոլո խաղացող կին․ միջին մուգ գույնի մաշկ',
    '🤽🏿‍♀' => 'ջրային պոլո խաղացող կին․ մուգ գույնի մաշկ',
    '🤾🏻‍♂' => 'ձեռնագնդակ խաղացող տղամարդ․ բաց գույնի մաշկ',
    '🤾🏼‍♂' => 'ձեռնագնդակ խաղացող տղամարդ․ միջին բաց գույնի մաշկ',
    '🤾🏽‍♂' => 'ձեռնագնդակ խաղացող տղամարդ․ միջին գույնի մաշկ',
    '🤾🏾‍♂' => 'ձեռնագնդակ խաղացող տղամարդ․ միջին մուգ գույնի մաշկ',
    '🤾🏿‍♂' => 'ձեռնագնդակ խաղացող տղամարդ․ մուգ գույնի մաշկ',
    '🤾🏻‍♀' => 'ձեռնագնդակ խաղացող կին․ բաց գույնի մաշկ',
    '🤾🏼‍♀' => 'ձեռնագնդակ խաղացող կին․ միջին բաց գույնի մաշկ',
    '🤾🏽‍♀' => 'ձեռնագնդակ խաղացող կին․ միջին գույնի մաշկ',
    '🤾🏾‍♀' => 'ձեռնագնդակ խաղացող կին․ միջին մուգ գույնի մաշկ',
    '🤾🏿‍♀' => 'ձեռնագնդակ խաղացող կին․ մուգ գույնի մաշկ',
    '🤹🏻‍♂' => 'տղամարդ ձեռնածու․ բաց գույնի մաշկ',
    '🤹🏼‍♂' => 'տղամարդ ձեռնածու․ միջին բաց գույնի մաշկ',
    '🤹🏽‍♂' => 'տղամարդ ձեռնածու․ միջին գույնի մաշկ',
    '🤹🏾‍♂' => 'տղամարդ ձեռնածու․ միջին մուգ գույնի մաշկ',
    '🤹🏿‍♂' => 'տղամարդ ձեռնածու․ մուգ գույնի մաշկ',
    '🤹🏻‍♀' => 'կին ձեռնածու․ բաց գույնի մաշկ',
    '🤹🏼‍♀' => 'կին ձեռնածու․ միջին բաց գույնի մաշկ',
    '🤹🏽‍♀' => 'կին ձեռնածու․ միջին գույնի մաշկ',
    '🤹🏾‍♀' => 'կին ձեռնածու․ միջին մուգ գույնի մաշկ',
    '🤹🏿‍♀' => 'կին ձեռնածու․ մուգ գույնի մաշկ',
    '🧘🏻‍♂' => 'լոտոսի դիրքով նստած տղամարդ․ բաց գույնի մաշկ',
    '🧘🏼‍♂' => 'լոտոսի դիրքով նստած տղամարդ․ միջին բաց գույնի մաշկ',
    '🧘🏽‍♂' => 'լոտոսի դիրքով նստած տղամարդ․ միջին գույնի մաշկ',
    '🧘🏾‍♂' => 'լոտոսի դիրքով նստած տղամարդ․ միջին մուգ գույնի մաշկ',
    '🧘🏿‍♂' => 'լոտոսի դիրքով նստած տղամարդ․ մուգ գույնի մաշկ',
    '🧘🏻‍♀' => 'լոտոսի դիրքով նստած կին․ բաց գույնի մաշկ',
    '🧘🏼‍♀' => 'լոտոսի դիրքով նստած կին․ միջին բաց գույնի մաշկ',
    '🧘🏽‍♀' => 'լոտոսի դիրքով նստած կին․ միջին գույնի մաշկ',
    '🧘🏾‍♀' => 'լոտոսի դիրքով նստած կին․ միջին մուգ գույնի մաշկ',
    '🧘🏿‍♀' => 'լոտոսի դիրքով նստած կին․ մուգ գույնի մաշկ',
    '🧑‍🦰' => 'անձ․ կարմրահեր',
    '🧑‍🦱' => 'անձ․ գանգրահեր',
    '🧑‍🦳' => 'անձ․ սպիտակահեր',
    '🧑‍🦲' => 'անձ․ ճաղատ',
    '👨‍🦰' => 'մարդ․ կարմրահեր',
    '👨‍🦱' => 'մարդ․ գանգրահեր',
    '👨‍🦳' => 'մարդ․ սպիտակահեր',
    '👨‍🦲' => 'մարդ․ ճաղատ',
    '👩‍🦰' => 'կին․ կարմրահեր',
    '👩‍🦱' => 'կին․ գանգրահեր',
    '👩‍🦳' => 'կին․ սպիտակահեր',
    '👩‍🦲' => 'կին․ ճաղատ',
    '🚶‍➡' => 'հետիոտն․ դեմքով՝ աջ',
    '🧎‍➡' => 'ծնկաչոք անձ․ դեմքով՝ աջ',
    '🏃‍➡' => 'վազող անձ․ դեմքով՝ աջ',
    '👨‍👦' => 'ընտանիք․ մարդ և տղա',
    '👨‍👧' => 'ընտանիք․ մարդ և աղջիկ',
    '👩‍👦' => 'ընտանիք․ կին և տղա',
    '👩‍👧' => 'ընտանիք․ կին և աղջիկ',
    '😶‍🌫' => 'դեմք ամպերի մեջ',
    '😮‍💨' => 'արտաշնչող դեմք',
    '🙂‍↕' => 'ուղղաձիգ ճոճվող գլուխ',
    '😵‍💫' => 'պարուրաձև աչքերով դեմք',
    '❤‍🔥' => 'այրվող սիրտ',
    '❤‍🩹' => 'լավացող սիրտ',
    '👁‍🗨' => 'ականատեսի նշան',
    '🧔‍♂' => 'մորուքավոր տղամարդ',
    '👱‍♂' => 'շիկահեր տղամարդ',
    '🧔‍♀' => 'մորուքավոր կին',
    '👱‍♀' => 'շիկահեր կին',
    '🙍‍♂' => 'խոժոռված տղամարդ',
    '🙍‍♀' => 'խոժոռված կին',
    '🙎‍♂' => 'խռոված տղամարդ',
    '🙎‍♀' => 'խռոված կին',
    '🙅‍♂' => 'տղամարդը դեմ է',
    '🙅‍♀' => 'կինը դեմ է',
    '🙆‍♂' => 'տղամարդը կողմ է',
    '🙆‍♀' => 'կինը կողմ է',
    '💁‍♂' => 'տղամարդը բացում է իր մտադրությունները',
    '💁‍♀' => 'կինը բացում է իր մտադրությունները',
    '🙋‍♂' => 'ձեռքը բարձրացրած տղամարդ',
    '🙋‍♀' => 'ձեռքը բարձրացրած կին',
    '🧏‍♂' => 'խուլ տղամարդ',
    '🧏‍♀' => 'խուլ կին',
    '🙇‍♂' => 'խոնարհվող տղամարդ',
    '🙇‍♀' => 'խոնարհվող կին',
    '🤦‍♂' => 'տղամարդը կորցրել է խոսելու ունակությունը',
    '🤦‍♀' => 'կինը կորցրել է խոսելու ունակությունը',
    '🤷‍♂' => 'ուսերը թոթվող մարդ',
    '🤷‍♀' => 'ուսերը թոթվող կին',
    '🧑‍⚕' => 'բուժաշխատող',
    '👨‍⚕' => 'բժիշկ',
    '👩‍⚕' => 'բժշկուհի',
    '🧑‍🎓' => 'ուսանող',
    '👨‍🎓' => 'ուսանող տղա',
    '👩‍🎓' => 'ուսանողուհի',
    '🧑‍🏫' => 'ուսուցիչ',
    '👨‍🏫' => 'տղամարդ ուսուցիչ',
    '👩‍🏫' => 'ուսուցչուհի',
    '🧑‍⚖' => 'դատավոր',
    '👨‍⚖' => 'տղամարդ դատավոր',
    '👩‍⚖' => 'կին դատավոր',
    '🧑‍🌾' => 'ֆերմեր',
    '👨‍🌾' => 'տղամարդ ֆերմեր',
    '👩‍🌾' => 'կին ֆերմեր',
    '🧑‍🍳' => 'խոհարար',
    '👨‍🍳' => 'տղամարդ խոհարար',
    '👩‍🍳' => 'խոհարարուհի',
    '🧑‍🔧' => 'փականագործ',
    '👨‍🔧' => 'տղամարդ փականագործ',
    '👩‍🔧' => 'կին փականագործ',
    '🧑‍🏭' => 'բանվոր',
    '👨‍🏭' => 'տղամարդ բանվոր',
    '👩‍🏭' => 'բանվորուհի',
    '🧑‍💼' => 'գրասենյակային աշխատող',
    '👨‍💼' => 'տղամարդ գրասենյակի աշխատող',
    '👩‍💼' => 'կին գրասենյակի աշխատող',
    '🧑‍🔬' => 'գիտնական',
    '👨‍🔬' => 'տղամարդ գիտնական',
    '👩‍🔬' => 'կին գիտնական',
    '🧑‍💻' => 'տեխնիկական մասնագետ',
    '👨‍💻' => 'տղամարդ ծրագրավորող',
    '👩‍💻' => 'կին ծրագրավորող',
    '🧑‍🎤' => 'երգիչ',
    '👨‍🎤' => 'տղամարդ երգիչ',
    '👩‍🎤' => 'երգչուհի',
    '🧑‍🎨' => 'նկարիչ',
    '👨‍🎨' => 'տղամարդ նկարիչ',
    '👩‍🎨' => 'նկարչուհի',
    '🧑‍✈' => 'օդաչու',
    '👨‍✈' => 'տղամարդ օդաչու',
    '👩‍✈' => 'կին օդաչու',
    '🧑‍🚀' => 'տիեզերագնաց',
    '👨‍🚀' => 'տղամարդ տիեզերագնաց',
    '👩‍🚀' => 'կին տիեզերագնաց',
    '🧑‍🚒' => 'հրշեջ',
    '👨‍🚒' => 'տղամարդ հրշեջ',
    '👩‍🚒' => 'կին հրշեջ',
    '👮‍♂' => 'տղամարդ ոստիկան',
    '👮‍♀' => 'կին ոստիկան',
    '🕵‍♂' => 'տղամարդ խուզարկու',
    '🕵‍♀' => 'կին խուզարկու',
    '💂‍♂' => 'տղամարդ ժամապահ',
    '💂‍♀' => 'կին ժամապահ',
    '👷‍♂' => 'տղամարդ շինարար',
    '👷‍♀' => 'կին շինարար',
    '👳‍♂' => 'չալմայով տղամարդ',
    '👳‍♀' => 'չալմայով կին',
    '🤵‍♂' => 'սմոկինգով տղամարդ',
    '🤵‍♀' => 'սմոկինգով կին',
    '👰‍♂' => 'քողով տղամարդ',
    '👰‍♀' => 'քողով կին',
    '👩‍🍼' => 'երեխային կերակրող կին',
    '👨‍🍼' => 'երեխային կերակրող մարդ',
    '🧑‍🍼' => 'երեխային կերակրող անձ',
    '🧑‍🎄' => 'Ձմեռ պապ',
    '🦸‍♂' => 'տղամարդ սուպերհերոս',
    '🦸‍♀' => 'կին սուպերհերոս',
    '🦹‍♂' => 'տղամարդ չարագործ',
    '🦹‍♀' => 'կին չարագործ',
    '🧙‍♂' => 'կախարդ',
    '🧙‍♀' => 'կախարդուհի',
    '🧚‍♂' => 'տղամարդ-փերի',
    '🧚‍♀' => 'կին-փերի',
    '🧛‍♂' => 'տղամարդ-վամպիր',
    '🧛‍♀' => 'կին-վամպիր',
    '🧜‍♂' => 'տրիտոն',
    '🧜‍♀' => 'ջրահարս',
    '🧝‍♂' => 'տղամարդ-էլֆ',
    '🧝‍♀' => 'կին-էլֆ',
    '🧞‍♂' => 'տղամարդ ջին',
    '🧞‍♀' => 'կին ջին',
    '🧟‍♂' => 'տղամարդ զոմբի',
    '🧟‍♀' => 'կին զոմբի',
    '💆‍♂' => 'տղամարդու դեմքը մերսում են',
    '💆‍♀' => 'կնոջ դեմքը մերսում են',
    '💇‍♂' => 'տղամարդու մազերը կտրում են',
    '💇‍♀' => 'կնոջ մազերը կտրում են',
    '🚶‍♂' => 'քայլող տղամարդ',
    '🚶‍♀' => 'քայլող կին',
    '🧍‍♂' => 'կանգնած տղամարդ',
    '🧍‍♀' => 'կանգնած կին',
    '🧎‍♂' => 'ծնկաչոք տղամարդ',
    '🧎‍♀' => 'ծնկաչոք կին',
    '🧑‍🦯' => 'ձեռնափայտով անձ',
    '👨‍🦯' => 'ձեռնափայտով տղամարդ',
    '👩‍🦯' => 'ձեռնափայտով կին',
    '🧑‍🦼' => 'մոտորասայլակով անձ',
    '👨‍🦼' => 'մոտորասայլակով տղամարդ',
    '👩‍🦼' => 'մոտորասայլակով կին',
    '🧑‍🦽' => 'ձեռքով կառավարվող սայլակով անձ',
    '👨‍🦽' => 'անվասայլակով տղամարդ',
    '👩‍🦽' => 'ձեռքով կառավարվող անվասայլակով կին',
    '🏃‍♂' => 'վազող տղամարդ',
    '🏃‍♀' => 'վազող կին',
    '🧑‍🩰' => 'բալետ պարող',
    '👯‍♂' => 'զվարճացող տղամարդիկ',
    '👯‍♀' => 'զվարճացող կանայք',
    '🧖‍♂' => 'տղամարդ բաղնիքում',
    '🧖‍♀' => 'կին բաղնիքում',
    '🧗‍♂' => 'մագլցող տղամարդ',
    '🧗‍♀' => 'մագլցող կին',
    '🏌‍♂' => 'գոլֆ խաղացող տղամարդ',
    '🏌‍♀' => 'գոլֆ խաղացող կին',
    '🏄‍♂' => 'սերֆինգով զբաղվող տղամարդ',
    '🏄‍♀' => 'սերֆինգով զբաղվող կին',
    '🚣‍♂' => 'թիավարող տղամարդ',
    '🚣‍♀' => 'թիավարող կին',
    '🏊‍♂' => 'տղամարդ լողորդ',
    '🏊‍♀' => 'լողորդուհի',
    '⛹‍♂' => 'գնդակով տղամարդ',
    '⛹‍♀' => 'գնդակով կին',
    '🏋‍♂' => 'տղամարդ ծանրորդ',
    '🏋‍♀' => 'ծանրորդուհի',
    '🚴‍♂' => 'տղամարդ հեծանվորդ',
    '🚴‍♀' => 'հեծանվորդուհի',
    '🚵‍♂' => 'տղամարդ լեռնահեծանվորդ',
    '🚵‍♀' => 'լեռնահեծանվորդուհի',
    '🤸‍♂' => 'տղամարդ ակրոբատ',
    '🤸‍♀' => 'կին ակրոբատ',
    '🤼‍♂' => 'տղամարդ ըմբշամարտիկներ',
    '🤼‍♀' => 'կին ըմբշամարտիկներ',
    '🤽‍♂' => 'ջրային պոլո խաղացող տղամարդ',
    '🤽‍♀' => 'ջրային պոլո խաղացող կին',
    '🤾‍♂' => 'ձեռնագնդակ խաղացող տղամարդ',
    '🤾‍♀' => 'ձեռնագնդակ խաղացող կին',
    '🤹‍♂' => 'տղամարդ ձեռնածու',
    '🤹‍♀' => 'կին ձեռնածու',
    '🧘‍♂' => 'լոտոսի դիրքով նստած տղամարդ',
    '🧘‍♀' => 'լոտոսի դիրքով նստած կին',
    '🧑‍🧒' => 'ընտանիք․ մեծահասակ, երեխա',
    '🐕‍🦺' => 'ծառայողական շուն',
    '🐈‍⬛' => 'սև կատու',
    '🐻‍❄' => 'բևեռային արջ',
    '🐦‍⬛' => 'կեռնեխ',
    '🐦‍🔥' => 'փյունիկ',
    '🍋‍🟩' => 'լայմ',
    '🍄‍🟫' => 'շագանակագույն սունկ',
    '⛓‍💥' => 'կոտրված շղթա',
    '🏳‍🌈' => 'ծիածանով դրոշ',
    '🏳‍⚧' => 'տրանսգենդերի դրոշ',
    '🏴‍☠' => 'ծովահենների դրոշ',
    '👋🏻' => 'թափահարող ձեռք․ բաց գույնի մաշկ',
    '👋🏼' => 'թափահարող ձեռք․ միջին բաց գույնի մաշկ',
    '👋🏽' => 'թափահարող ձեռք․ միջին գույնի մաշկ',
    '👋🏾' => 'թափահարող ձեռք․ միջին մուգ գույնի մաշկ',
    '👋🏿' => 'թափահարող ձեռք․ մուգ գույնի մաշկ',
    '🤚🏻' => 'ձեռքի բարձրացրած ափ․ բաց գույնի մաշկ',
    '🤚🏼' => 'ձեռքի բարձրացրած ափ․ միջին բաց գույնի մաշկ',
    '🤚🏽' => 'ձեռքի բարձրացրած ափ․ միջին գույնի մաշկ',
    '🤚🏾' => 'ձեռքի բարձրացրած ափ․ միջին մուգ գույնի մաշկ',
    '🤚🏿' => 'ձեռքի բարձրացրած ափ․ մուգ գույնի մաշկ',
    '🖐🏻' => 'բացված մատներով բարձրացված ձեռք․ բաց գույնի մաշկ',
    '🖐🏼' => 'բացված մատներով բարձրացված ձեռք․ միջին բաց գույնի մաշկ',
    '🖐🏽' => 'բացված մատներով բարձրացված ձեռք․ միջին գույնի մաշկ',
    '🖐🏾' => 'բացված մատներով բարձրացված ձեռք․ միջին մուգ գույնի մաշկ',
    '🖐🏿' => 'բացված մատներով բարձրացված ձեռք․ մուգ գույնի մաշկ',
    '✋🏻' => 'բարձրացված ձեռք․ բաց գույնի մաշկ',
    '✋🏼' => 'բարձրացված ձեռք․ միջին բաց գույնի մաշկ',
    '✋🏽' => 'բարձրացված ձեռք․ միջին գույնի մաշկ',
    '✋🏾' => 'բարձրացված ձեռք․ միջին մուգ գույնի մաշկ',
    '✋🏿' => 'բարձրացված ձեռք․ մուգ գույնի մաշկ',
    '🖖🏻' => 'վուլկանցիների ողջույն․ բաց գույնի մաշկ',
    '🖖🏼' => 'վուլկանցիների ողջույն․ միջին բաց գույնի մաշկ',
    '🖖🏽' => 'վուլկանցիների ողջույն․ միջին գույնի մաշկ',
    '🖖🏾' => 'վուլկանցիների ողջույն․ միջին մուգ գույնի մաշկ',
    '🖖🏿' => 'վուլկանցիների ողջույն․ մուգ գույնի մաշկ',
    '🫱🏻' => 'աջակողմ ձեռք․ բաց գույնի մաշկ',
    '🫱🏼' => 'աջակողմ ձեռք․ միջին բաց գույնի մաշկ',
    '🫱🏽' => 'աջակողմ ձեռք․ միջին գույնի մաշկ',
    '🫱🏾' => 'աջակողմ ձեռք․ միջին մուգ գույնի մաշկ',
    '🫱🏿' => 'աջակողմ ձեռք․ մուգ գույնի մաշկ',
    '🫲🏻' => 'ձախակողմ ձեռք․ բաց գույնի մաշկ',
    '🫲🏼' => 'ձախակողմ ձեռք․ միջին բաց գույնի մաշկ',
    '🫲🏽' => 'ձախակողմ ձեռք․ միջին գույնի մաշկ',
    '🫲🏾' => 'ձախակողմ ձեռք․ միջին մուգ գույնի մաշկ',
    '🫲🏿' => 'ձախակողմ ձեռք․ մուգ գույնի մաշկ',
    '🫳🏻' => 'ձեռքը ափով ներքև․ բաց գույնի մաշկ',
    '🫳🏼' => 'ձեռքը ափով ներքև․ միջին բաց գույնի մաշկ',
    '🫳🏽' => 'ձեռքը ափով ներքև․ միջին գույնի մաշկ',
    '🫳🏾' => 'ձեռքը ափով ներքև․ միջին մուգ գույնի մաշկ',
    '🫳🏿' => 'ձեռքը ափով ներքև․ մուգ գույնի մաշկ',
    '🫴🏻' => 'ափը՝ վեր ձեռք․ բաց գույնի մաշկ',
    '🫴🏼' => 'ափը՝ վեր ձեռք․ միջին բաց գույնի մաշկ',
    '🫴🏽' => 'ափը՝ վեր ձեռք․ միջին գույնի մաշկ',
    '🫴🏾' => 'ափը՝ վեր ձեռք․ միջին մուգ գույնի մաշկ',
    '🫴🏿' => 'ափը՝ վեր ձեռք․ մուգ գույնի մաշկ',
    '🫷🏻' => 'դեպի ձախ հրող ձեռք․ բաց գույնի մաշկ',
    '🫷🏼' => 'դեպի ձախ հրող ձեռք․ միջին բաց գույնի մաշկ',
    '🫷🏽' => 'դեպի ձախ հրող ձեռք․ միջին գույնի մաշկ',
    '🫷🏾' => 'դեպի ձախ հրող ձեռք․ միջին մուգ գույնի մաշկ',
    '🫷🏿' => 'դեպի ձախ հրող ձեռք․ մուգ գույնի մաշկ',
    '🫸🏻' => 'դեպի աջ հրող ձեռք․ բաց գույնի մաշկ',
    '🫸🏼' => 'դեպի աջ հրող ձեռք․ միջին բաց գույնի մաշկ',
    '🫸🏽' => 'դեպի աջ հրող ձեռք․ միջին գույնի մաշկ',
    '🫸🏾' => 'դեպի աջ հրող ձեռք․ միջին մուգ գույնի մաշկ',
    '🫸🏿' => 'դեպի աջ հրող ձեռք․ մուգ գույնի մաշկ',
    '👌🏻' => 'ok ցույց տվող ձեռք․ բաց գույնի մաշկ',
    '👌🏼' => 'ok ցույց տվող ձեռք․ միջին բաց գույնի մաշկ',
    '👌🏽' => 'ok ցույց տվող ձեռք․ միջին գույնի մաշկ',
    '👌🏾' => 'ok ցույց տվող ձեռք․ միջին մուգ գույնի մաշկ',
    '👌🏿' => 'ok ցույց տվող ձեռք․ մուգ գույնի մաշկ',
    '🤌🏻' => 'պտղունց․ բաց գույնի մաշկ',
    '🤌🏼' => 'պտղունց․ միջին բաց գույնի մաշկ',
    '🤌🏽' => 'պտղունց․ միջին գույնի մաշկ',
    '🤌🏾' => 'պտղունց․ միջին մուգ գույնի մաշկ',
    '🤌🏿' => 'պտղունց․ մուգ գույնի մաշկ',
    '🤏🏻' => 'պտղունց ցույց տվող ձեռք․ բաց գույնի մաշկ',
    '🤏🏼' => 'պտղունց ցույց տվող ձեռք․ միջին բաց գույնի մաշկ',
    '🤏🏽' => 'պտղունց ցույց տվող ձեռք․ միջին գույնի մաշկ',
    '🤏🏾' => 'պտղունց ցույց տվող ձեռք․ միջին մուգ գույնի մաշկ',
    '🤏🏿' => 'պտղունց ցույց տվող ձեռք․ մուգ գույնի մաշկ',
    '✌🏻' => 'հաղթական ձեռք․ բաց գույնի մաշկ',
    '✌🏼' => 'հաղթական ձեռք․ միջին բաց գույնի մաշկ',
    '✌🏽' => 'հաղթական ձեռք․ միջին գույնի մաշկ',
    '✌🏾' => 'հաղթական ձեռք․ միջին մուգ գույնի մաշկ',
    '✌🏿' => 'հաղթական ձեռք․ մուգ գույնի մաշկ',
    '🤞🏻' => 'խաչած մատներ․ բաց գույնի մաշկ',
    '🤞🏼' => 'խաչած մատներ․ միջին բաց գույնի մաշկ',
    '🤞🏽' => 'խաչած մատներ․ միջին գույնի մաշկ',
    '🤞🏾' => 'խաչած մատներ․ միջին մուգ գույնի մաշկ',
    '🤞🏿' => 'խաչած մատներ․ մուգ գույնի մաշկ',
    '🫰🏻' => 'ցուցամատը եւ բութը խաչած ձեռք․ բաց գույնի մաշկ',
    '🫰🏼' => 'ցուցամատը եւ բութը խաչած ձեռք․ միջին բաց գույնի մաշկ',
    '🫰🏽' => 'ցուցամատը եւ բութը խաչած ձեռք․ միջին գույնի մաշկ',
    '🫰🏾' => 'ցուցամատը եւ բութը խաչած ձեռք․ միջին մուգ գույնի մաշկ',
    '🫰🏿' => 'ցուցամատը եւ բութը խաչած ձեռք․ մուգ գույնի մաշկ',
    '🤟🏻' => '«սիրում եմ քեզ» նշան․ բաց գույնի մաշկ',
    '🤟🏼' => '«սիրում եմ քեզ» նշան․ միջին բաց գույնի մաշկ',
    '🤟🏽' => '«սիրում եմ քեզ» նշան․ միջին գույնի մաշկ',
    '🤟🏾' => '«սիրում եմ քեզ» նշան․ միջին մուգ գույնի մաշկ',
    '🤟🏿' => '«սիրում եմ քեզ» նշան․ մուգ գույնի մաշկ',
    '🤘🏻' => 'եղջյուրների նշան․ բաց գույնի մաշկ',
    '🤘🏼' => 'եղջյուրների նշան․ միջին բաց գույնի մաշկ',
    '🤘🏽' => 'եղջյուրների նշան․ միջին գույնի մաշկ',
    '🤘🏾' => 'եղջյուրների նշան․ միջին մուգ գույնի մաշկ',
    '🤘🏿' => 'եղջյուրների նշան․ մուգ գույնի մաշկ',
    '🤙🏻' => 'զանգիր ինձ․ բաց գույնի մաշկ',
    '🤙🏼' => 'զանգիր ինձ․ միջին բաց գույնի մաշկ',
    '🤙🏽' => 'զանգիր ինձ․ միջին գույնի մաշկ',
    '🤙🏾' => 'զանգիր ինձ․ միջին մուգ գույնի մաշկ',
    '🤙🏿' => 'զանգիր ինձ․ մուգ գույնի մաշկ',
    '👈🏻' => 'դեպի ձախ ուղղված ցուցամատ․ բաց գույնի մաշկ',
    '👈🏼' => 'դեպի ձախ ուղղված ցուցամատ․ միջին բաց գույնի մաշկ',
    '👈🏽' => 'դեպի ձախ ուղղված ցուցամատ․ միջին գույնի մաշկ',
    '👈🏾' => 'դեպի ձախ ուղղված ցուցամատ․ միջին մուգ գույնի մաշկ',
    '👈🏿' => 'դեպի ձախ ուղղված ցուցամատ․ մուգ գույնի մաշկ',
    '👉🏻' => 'դեպի աջ ուղղված ցուցամատ․ բաց գույնի մաշկ',
    '👉🏼' => 'դեպի աջ ուղղված ցուցամատ․ միջին բաց գույնի մաշկ',
    '👉🏽' => 'դեպի աջ ուղղված ցուցամատ․ միջին գույնի մաշկ',
    '👉🏾' => 'դեպի աջ ուղղված ցուցամատ․ միջին մուգ գույնի մաշկ',
    '👉🏿' => 'դեպի աջ ուղղված ցուցամատ․ մուգ գույնի մաշկ',
    '👆🏻' => 'դեպի վեր ուղղված ցուցամատ․ բաց գույնի մաշկ',
    '👆🏼' => 'դեպի վեր ուղղված ցուցամատ․ միջին բաց գույնի մաշկ',
    '👆🏽' => 'դեպի վեր ուղղված ցուցամատ․ միջին գույնի մաշկ',
    '👆🏾' => 'դեպի վեր ուղղված ցուցամատ․ միջին մուգ գույնի մաշկ',
    '👆🏿' => 'դեպի վեր ուղղված ցուցամատ․ մուգ գույնի մաշկ',
    '🖕🏻' => 'միջնամատ․ բաց գույնի մաշկ',
    '🖕🏼' => 'միջնամատ․ միջին բաց գույնի մաշկ',
    '🖕🏽' => 'միջնամատ․ միջին գույնի մաշկ',
    '🖕🏾' => 'միջնամատ․ միջին մուգ գույնի մաշկ',
    '🖕🏿' => 'միջնամատ․ մուգ գույնի մաշկ',
    '👇🏻' => 'դեպի վար ուղղված ցուցամատ․ բաց գույնի մաշկ',
    '👇🏼' => 'դեպի վար ուղղված ցուցամատ․ միջին բաց գույնի մաշկ',
    '👇🏽' => 'դեպի վար ուղղված ցուցամատ․ միջին գույնի մաշկ',
    '👇🏾' => 'դեպի վար ուղղված ցուցամատ․ միջին մուգ գույնի մաշկ',
    '👇🏿' => 'դեպի վար ուղղված ցուցամատ․ մուգ գույնի մաշկ',
    '☝🏻' => 'վեր ուղղված ցուցամատ․ բաց գույնի մաշկ',
    '☝🏼' => 'վեր ուղղված ցուցամատ․ միջին բաց գույնի մաշկ',
    '☝🏽' => 'վեր ուղղված ցուցամատ․ միջին գույնի մաշկ',
    '☝🏾' => 'վեր ուղղված ցուցամատ․ միջին մուգ գույնի մաշկ',
    '☝🏿' => 'վեր ուղղված ցուցամատ․ մուգ գույնի մաշկ',
    '🫵🏻' => 'դիտողին ուղղված ցուցամատ․ բաց գույնի մաշկ',
    '🫵🏼' => 'դիտողին ուղղված ցուցամատ․ միջին բաց գույնի մաշկ',
    '🫵🏽' => 'դիտողին ուղղված ցուցամատ․ միջին գույնի մաշկ',
    '🫵🏾' => 'դիտողին ուղղված ցուցամատ․ միջին մուգ գույնի մաշկ',
    '🫵🏿' => 'դիտողին ուղղված ցուցամատ․ մուգ գույնի մաշկ',
    '👍🏻' => 'բութ մատը վեր․ բաց գույնի մաշկ',
    '👍🏼' => 'բութ մատը վեր․ միջին բաց գույնի մաշկ',
    '👍🏽' => 'բութ մատը վեր․ միջին գույնի մաշկ',
    '👍🏾' => 'բութ մատը վեր․ միջին մուգ գույնի մաշկ',
    '👍🏿' => 'բութ մատը վեր․ մուգ գույնի մաշկ',
    '👎🏻' => 'բութ մատը ներքև․ բաց գույնի մաշկ',
    '👎🏼' => 'բութ մատը ներքև․ միջին բաց գույնի մաշկ',
    '👎🏽' => 'բութ մատը ներքև․ միջին գույնի մաշկ',
    '👎🏾' => 'բութ մատը ներքև․ միջին մուգ գույնի մաշկ',
    '👎🏿' => 'բութ մատը ներքև․ մուգ գույնի մաշկ',
    '✊🏻' => 'բարձրացված բռունցք․ բաց գույնի մաշկ',
    '✊🏼' => 'բարձրացված բռունցք․ միջին բաց գույնի մաշկ',
    '✊🏽' => 'բարձրացված բռունցք․ միջին գույնի մաշկ',
    '✊🏾' => 'բարձրացված բռունցք․ միջին մուգ գույնի մաշկ',
    '✊🏿' => 'բարձրացված բռունցք․ մուգ գույնի մաշկ',
    '👊🏻' => 'հանդիպակաց բռունցք․ բաց գույնի մաշկ',
    '👊🏼' => 'հանդիպակաց բռունցք․ միջին բաց գույնի մաշկ',
    '👊🏽' => 'հանդիպակաց բռունցք․ միջին գույնի մաշկ',
    '👊🏾' => 'հանդիպակաց բռունցք․ միջին մուգ գույնի մաշկ',
    '👊🏿' => 'հանդիպակաց բռունցք․ մուգ գույնի մաշկ',
    '🤛🏻' => 'բռունցքը ձախ․ բաց գույնի մաշկ',
    '🤛🏼' => 'բռունցքը ձախ․ միջին բաց գույնի մաշկ',
    '🤛🏽' => 'բռունցքը ձախ․ միջին գույնի մաշկ',
    '🤛🏾' => 'բռունցքը ձախ․ միջին մուգ գույնի մաշկ',
    '🤛🏿' => 'բռունցքը ձախ․ մուգ գույնի մաշկ',
    '🤜🏻' => 'բռունցքը աջ․ բաց գույնի մաշկ',
    '🤜🏼' => 'բռունցքը աջ․ միջին բաց գույնի մաշկ',
    '🤜🏽' => 'բռունցքը աջ․ միջին գույնի մաշկ',
    '🤜🏾' => 'բռունցքը աջ․ միջին մուգ գույնի մաշկ',
    '🤜🏿' => 'բռունցքը աջ․ մուգ գույնի մաշկ',
    '👏🏻' => 'ծափահարող ձեռքեր․ բաց գույնի մաշկ',
    '👏🏼' => 'ծափահարող ձեռքեր․ միջին բաց գույնի մաշկ',
    '👏🏽' => 'ծափահարող ձեռքեր․ միջին գույնի մաշկ',
    '👏🏾' => 'ծափահարող ձեռքեր․ միջին մուգ գույնի մաշկ',
    '👏🏿' => 'ծափահարող ձեռքեր․ մուգ գույնի մաշկ',
    '🙌🏻' => 'բարձրացրած ձեռքեր․ բաց գույնի մաշկ',
    '🙌🏼' => 'բարձրացրած ձեռքեր․ միջին բաց գույնի մաշկ',
    '🙌🏽' => 'բարձրացրած ձեռքեր․ միջին գույնի մաշկ',
    '🙌🏾' => 'բարձրացրած ձեռքեր․ միջին մուգ գույնի մաշկ',
    '🙌🏿' => 'բարձրացրած ձեռքեր․ մուգ գույնի մաշկ',
    '🫶🏻' => 'սիրտ-ձեռքեր․ բաց գույնի մաշկ',
    '🫶🏼' => 'սիրտ-ձեռքեր․ միջին բաց գույնի մաշկ',
    '🫶🏽' => 'սիրտ-ձեռքեր․ միջին գույնի մաշկ',
    '🫶🏾' => 'սիրտ-ձեռքեր․ միջին մուգ գույնի մաշկ',
    '🫶🏿' => 'սիրտ-ձեռքեր․ մուգ գույնի մաշկ',
    '👐🏻' => 'բաց ձեռքեր․ բաց գույնի մաշկ',
    '👐🏼' => 'բաց ձեռքեր․ միջին բաց գույնի մաշկ',
    '👐🏽' => 'բաց ձեռքեր․ միջին գույնի մաշկ',
    '👐🏾' => 'բաց ձեռքեր․ միջին մուգ գույնի մաշկ',
    '👐🏿' => 'բաց ձեռքեր․ մուգ գույնի մաշկ',
    '🤲🏻' => 'ձեռքերի ափերը վեր․ բաց գույնի մաշկ',
    '🤲🏼' => 'ձեռքերի ափերը վեր․ միջին բաց գույնի մաշկ',
    '🤲🏽' => 'ձեռքերի ափերը վեր․ միջին գույնի մաշկ',
    '🤲🏾' => 'ձեռքերի ափերը վեր․ միջին մուգ գույնի մաշկ',
    '🤲🏿' => 'ձեռքերի ափերը վեր․ մուգ գույնի մաշկ',
    '🤝🏻' => 'ձեռքսեղմում․ բաց գույնի մաշկ',
    '🤝🏼' => 'ձեռքսեղմում․ միջին բաց գույնի մաշկ',
    '🤝🏽' => 'ձեռքսեղմում․ միջին գույնի մաշկ',
    '🤝🏾' => 'ձեռքսեղմում․ միջին մուգ գույնի մաշկ',
    '🤝🏿' => 'ձեռքսեղմում․ մուգ գույնի մաշկ',
    '🙏🏻' => 'ձեռքերի ափերը միացված․ բաց գույնի մաշկ',
    '🙏🏼' => 'ձեռքերի ափերը միացված․ միջին բաց գույնի մաշկ',
    '🙏🏽' => 'ձեռքերի ափերը միացված․ միջին գույնի մաշկ',
    '🙏🏾' => 'ձեռքերի ափերը միացված․ միջին մուգ գույնի մաշկ',
    '🙏🏿' => 'ձեռքերի ափերը միացված․ մուգ գույնի մաշկ',
    '✍🏻' => 'գրող ձեռք․ բաց գույնի մաշկ',
    '✍🏼' => 'գրող ձեռք․ միջին բաց գույնի մաշկ',
    '✍🏽' => 'գրող ձեռք․ միջին գույնի մաշկ',
    '✍🏾' => 'գրող ձեռք․ միջին մուգ գույնի մաշկ',
    '✍🏿' => 'գրող ձեռք․ մուգ գույնի մաշկ',
    '💅🏻' => 'եղունգների լաքապատում․ բաց գույնի մաշկ',
    '💅🏼' => 'եղունգների լաքապատում․ միջին բաց գույնի մաշկ',
    '💅🏽' => 'եղունգների լաքապատում․ միջին գույնի մաշկ',
    '💅🏾' => 'եղունգների լաքապատում․ միջին մուգ գույնի մաշկ',
    '💅🏿' => 'եղունգների լաքապատում․ մուգ գույնի մաշկ',
    '🤳🏻' => 'սելֆի․ բաց գույնի մաշկ',
    '🤳🏼' => 'սելֆի․ միջին բաց գույնի մաշկ',
    '🤳🏽' => 'սելֆի․ միջին գույնի մաշկ',
    '🤳🏾' => 'սելֆի․ միջին մուգ գույնի մաշկ',
    '🤳🏿' => 'սելֆի․ մուգ գույնի մաշկ',
    '💪🏻' => 'ձգված բիցեպս․ բաց գույնի մաշկ',
    '💪🏼' => 'ձգված բիցեպս․ միջին բաց գույնի մաշկ',
    '💪🏽' => 'ձգված բիցեպս․ միջին գույնի մաշկ',
    '💪🏾' => 'ձգված բիցեպս․ միջին մուգ գույնի մաշկ',
    '💪🏿' => 'ձգված բիցեպս․ մուգ գույնի մաշկ',
    '🦵🏻' => 'ոտք․ բաց գույնի մաշկ',
    '🦵🏼' => 'ոտք․ միջին բաց գույնի մաշկ',
    '🦵🏽' => 'ոտք․ միջին գույնի մաշկ',
    '🦵🏾' => 'ոտք․ միջին մուգ գույնի մաշկ',
    '🦵🏿' => 'ոտք․ մուգ գույնի մաշկ',
    '🦶🏻' => 'ոտնաթաթ․ բաց գույնի մաշկ',
    '🦶🏼' => 'ոտնաթաթ․ միջին բաց գույնի մաշկ',
    '🦶🏽' => 'ոտնաթաթ․ միջին գույնի մաշկ',
    '🦶🏾' => 'ոտնաթաթ․ միջին մուգ գույնի մաշկ',
    '🦶🏿' => 'ոտնաթաթ․ մուգ գույնի մաշկ',
    '👂🏻' => 'ականջ․ բաց գույնի մաշկ',
    '👂🏼' => 'ականջ․ միջին բաց գույնի մաշկ',
    '👂🏽' => 'ականջ․ միջին գույնի մաշկ',
    '👂🏾' => 'ականջ․ միջին մուգ գույնի մաշկ',
    '👂🏿' => 'ականջ․ մուգ գույնի մաշկ',
    '🦻🏻' => 'լսողական սարքով ականջ․ բաց գույնի մաշկ',
    '🦻🏼' => 'լսողական սարքով ականջ․ միջին բաց գույնի մաշկ',
    '🦻🏽' => 'լսողական սարքով ականջ․ միջին գույնի մաշկ',
    '🦻🏾' => 'լսողական սարքով ականջ․ միջին մուգ գույնի մաշկ',
    '🦻🏿' => 'լսողական սարքով ականջ․ մուգ գույնի մաշկ',
    '👃🏻' => 'քիթ․ բաց գույնի մաշկ',
    '👃🏼' => 'քիթ․ միջին բաց գույնի մաշկ',
    '👃🏽' => 'քիթ․ միջին գույնի մաշկ',
    '👃🏾' => 'քիթ․ միջին մուգ գույնի մաշկ',
    '👃🏿' => 'քիթ․ մուգ գույնի մաշկ',
    '👶🏻' => 'մանուկ․ բաց գույնի մաշկ',
    '👶🏼' => 'մանուկ․ միջին բաց գույնի մաշկ',
    '👶🏽' => 'մանուկ․ միջին գույնի մաշկ',
    '👶🏾' => 'մանուկ․ միջին մուգ գույնի մաշկ',
    '👶🏿' => 'մանուկ․ մուգ գույնի մաշկ',
    '🧒🏻' => 'երեխա․ բաց գույնի մաշկ',
    '🧒🏼' => 'երեխա․ միջին բաց գույնի մաշկ',
    '🧒🏽' => 'երեխա․ միջին գույնի մաշկ',
    '🧒🏾' => 'երեխա․ միջին մուգ գույնի մաշկ',
    '🧒🏿' => 'երեխա․ մուգ գույնի մաշկ',
    '👦🏻' => 'տղա․ բաց գույնի մաշկ',
    '👦🏼' => 'տղա․ միջին բաց գույնի մաշկ',
    '👦🏽' => 'տղա․ միջին գույնի մաշկ',
    '👦🏾' => 'տղա․ միջին մուգ գույնի մաշկ',
    '👦🏿' => 'տղա․ մուգ գույնի մաշկ',
    '👧🏻' => 'աղջիկ․ բաց գույնի մաշկ',
    '👧🏼' => 'աղջիկ․ միջին բաց գույնի մաշկ',
    '👧🏽' => 'աղջիկ․ միջին գույնի մաշկ',
    '👧🏾' => 'աղջիկ․ միջին մուգ գույնի մաշկ',
    '👧🏿' => 'աղջիկ․ մուգ գույնի մաշկ',
    '🧑🏻' => 'անձ․ բաց գույնի մաշկ',
    '🧑🏼' => 'անձ․ միջին բաց գույնի մաշկ',
    '🧑🏽' => 'անձ․ միջին գույնի մաշկ',
    '🧑🏾' => 'անձ․ միջին մուգ գույնի մաշկ',
    '🧑🏿' => 'անձ․ մուգ գույնի մաշկ',
    '👱🏻' => 'անձ․ բաց գույնի մաշկ և շիկահեր',
    '👱🏼' => 'անձ․ միջին բաց գույնի մաշկ և շիկահեր',
    '👱🏽' => 'անձ․ միջին գույնի մաշկ և շիկահեր',
    '👱🏾' => 'անձ․ միջին մուգ գույնի մաշկ և շիկահեր',
    '👱🏿' => 'անձ․ մուգ գույնի մաշկ և շիկահեր',
    '👨🏻' => 'մարդ․ բաց գույնի մաշկ',
    '👨🏼' => 'մարդ․ միջին բաց գույնի մաշկ',
    '👨🏽' => 'մարդ․ միջին գույնի մաշկ',
    '👨🏾' => 'մարդ․ միջին մուգ գույնի մաշկ',
    '👨🏿' => 'մարդ․ մուգ գույնի մաշկ',
    '🧔🏻' => 'անձ․ բաց գույնի մաշկ և մորուք',
    '🧔🏼' => 'անձ․ միջին բաց գույնի մաշկ և մորուք',
    '🧔🏽' => 'անձ․ միջին գույնի մաշկ և մորուք',
    '🧔🏾' => 'անձ․ միջին մուգ գույնի մաշկ և մորուք',
    '🧔🏿' => 'անձ․ մուգ գույնի մաշկ և մորուք',
    '👩🏻' => 'կին․ բաց գույնի մաշկ',
    '👩🏼' => 'կին․ միջին բաց գույնի մաշկ',
    '👩🏽' => 'կին․ միջին գույնի մաշկ',
    '👩🏾' => 'կին․ միջին մուգ գույնի մաշկ',
    '👩🏿' => 'կին․ մուգ գույնի մաշկ',
    '🧓🏻' => 'տարեց անձ․ բաց գույնի մաշկ',
    '🧓🏼' => 'տարեց անձ․ միջին բաց գույնի մաշկ',
    '🧓🏽' => 'տարեց անձ․ միջին գույնի մաշկ',
    '🧓🏾' => 'տարեց անձ․ միջին մուգ գույնի մաշկ',
    '🧓🏿' => 'տարեց անձ․ մուգ գույնի մաշկ',
    '👴🏻' => 'տարեց մարդ․ բաց գույնի մաշկ',
    '👴🏼' => 'տարեց մարդ․ միջին բաց գույնի մաշկ',
    '👴🏽' => 'տարեց մարդ․ միջին գույնի մաշկ',
    '👴🏾' => 'տարեց մարդ․ միջին մուգ գույնի մաշկ',
    '👴🏿' => 'տարեց մարդ․ մուգ գույնի մաշկ',
    '👵🏻' => 'տարեց կին․ բաց գույնի մաշկ',
    '👵🏼' => 'տարեց կին․ միջին բաց գույնի մաշկ',
    '👵🏽' => 'տարեց կին․ միջին գույնի մաշկ',
    '👵🏾' => 'տարեց կին․ միջին մուգ գույնի մաշկ',
    '👵🏿' => 'տարեց կին․ մուգ գույնի մաշկ',
    '🙍🏻' => 'խոժոռված դեմքով անձ․ բաց գույնի մաշկ',
    '🙍🏼' => 'խոժոռված դեմքով անձ․ միջին բաց գույնի մաշկ',
    '🙍🏽' => 'խոժոռված դեմքով անձ․ միջին գույնի մաշկ',
    '🙍🏾' => 'խոժոռված դեմքով անձ․ միջին մուգ գույնի մաշկ',
    '🙍🏿' => 'խոժոռված դեմքով անձ․ մուգ գույնի մաշկ',
    '🙎🏻' => 'դժգոհ անձ․ բաց գույնի մաշկ',
    '🙎🏼' => 'դժգոհ անձ․ միջին բաց գույնի մաշկ',
    '🙎🏽' => 'դժգոհ անձ․ միջին գույնի մաշկ',
    '🙎🏾' => 'դժգոհ անձ․ միջին մուգ գույնի մաշկ',
    '🙎🏿' => 'դժգոհ անձ․ մուգ գույնի մաշկ',
    '🙅🏻' => 'ՈՉ ակնարկող անձ․ բաց գույնի մաշկ',
    '🙅🏼' => 'ՈՉ ակնարկող անձ․ միջին բաց գույնի մաշկ',
    '🙅🏽' => 'ՈՉ ակնարկող անձ․ միջին գույնի մաշկ',
    '🙅🏾' => 'ՈՉ ակնարկող անձ․ միջին մուգ գույնի մաշկ',
    '🙅🏿' => 'ՈՉ ակնարկող անձ․ մուգ գույնի մաշկ',
    '🙆🏻' => 'ok ցույց տվող․ բաց գույնի մաշկ',
    '🙆🏼' => 'ok ցույց տվող․ միջին բաց գույնի մաշկ',
    '🙆🏽' => 'ok ցույց տվող․ միջին գույնի մաշկ',
    '🙆🏾' => 'ok ցույց տվող․ միջին մուգ գույնի մաշկ',
    '🙆🏿' => 'ok ցույց տվող․ մուգ գույնի մաշկ',
    '💁🏻' => 'ձեռքը թեքած անձ․ բաց գույնի մաշկ',
    '💁🏼' => 'ձեռքը թեքած անձ․ միջին բաց գույնի մաշկ',
    '💁🏽' => 'ձեռքը թեքած անձ․ միջին գույնի մաշկ',
    '💁🏾' => 'ձեռքը թեքած անձ․ միջին մուգ գույնի մաշկ',
    '💁🏿' => 'ձեռքը թեքած անձ․ մուգ գույնի մաշկ',
    '🙋🏻' => 'ձեռքը բարձրացրած անձ․ բաց գույնի մաշկ',
    '🙋🏼' => 'ձեռքը բարձրացրած անձ․ միջին բաց գույնի մաշկ',
    '🙋🏽' => 'ձեռքը բարձրացրած անձ․ միջին գույնի մաշկ',
    '🙋🏾' => 'ձեռքը բարձրացրած անձ․ միջին մուգ գույնի մաշկ',
    '🙋🏿' => 'ձեռքը բարձրացրած անձ․ մուգ գույնի մաշկ',
    '🧏🏻' => 'խուլ անձ․ բաց գույնի մաշկ',
    '🧏🏼' => 'խուլ անձ․ միջին բաց գույնի մաշկ',
    '🧏🏽' => 'խուլ անձ․ միջին գույնի մաշկ',
    '🧏🏾' => 'խուլ անձ․ միջին մուգ գույնի մաշկ',
    '🧏🏿' => 'խուլ անձ․ մուգ գույնի մաշկ',
    '🙇🏻' => 'խոնարհվող անձ․ բաց գույնի մաշկ',
    '🙇🏼' => 'խոնարհվող անձ․ միջին բաց գույնի մաշկ',
    '🙇🏽' => 'խոնարհվող անձ․ միջին գույնի մաշկ',
    '🙇🏾' => 'խոնարհվող անձ․ միջին մուգ գույնի մաշկ',
    '🙇🏿' => 'խոնարհվող անձ․ մուգ գույնի մաշկ',
    '🤦🏻' => 'դեմքն ափով ծածկած անձ․ բաց գույնի մաշկ',
    '🤦🏼' => 'դեմքն ափով ծածկած անձ․ միջին բաց գույնի մաշկ',
    '🤦🏽' => 'դեմքն ափով ծածկած անձ․ միջին գույնի մաշկ',
    '🤦🏾' => 'դեմքն ափով ծածկած անձ․ միջին մուգ գույնի մաշկ',
    '🤦🏿' => 'դեմքն ափով ծածկած անձ․ մուգ գույնի մաշկ',
    '🤷🏻' => 'ուսերը թոթվող անձ․ բաց գույնի մաշկ',
    '🤷🏼' => 'ուսերը թոթվող անձ․ միջին բաց գույնի մաշկ',
    '🤷🏽' => 'ուսերը թոթվող անձ․ միջին գույնի մաշկ',
    '🤷🏾' => 'ուսերը թոթվող անձ․ միջին մուգ գույնի մաշկ',
    '🤷🏿' => 'ուսերը թոթվող անձ․ մուգ գույնի մաշկ',
    '👮🏻' => 'ոստիկան․ բաց գույնի մաշկ',
    '👮🏼' => 'ոստիկան․ միջին բաց գույնի մաշկ',
    '👮🏽' => 'ոստիկան․ միջին գույնի մաշկ',
    '👮🏾' => 'ոստիկան․ միջին մուգ գույնի մաշկ',
    '👮🏿' => 'ոստիկան․ մուգ գույնի մաշկ',
    '🕵🏻' => 'խուզարկու․ բաց գույնի մաշկ',
    '🕵🏼' => 'խուզարկու․ միջին բաց գույնի մաշկ',
    '🕵🏽' => 'խուզարկու․ միջին գույնի մաշկ',
    '🕵🏾' => 'խուզարկու․ միջին մուգ գույնի մաշկ',
    '🕵🏿' => 'խուզարկու․ մուգ գույնի մաշկ',
    '💂🏻' => 'պահակազորային․ բաց գույնի մաշկ',
    '💂🏼' => 'պահակազորային․ միջին բաց գույնի մաշկ',
    '💂🏽' => 'պահակազորային․ միջին գույնի մաշկ',
    '💂🏾' => 'պահակազորային․ միջին մուգ գույնի մաշկ',
    '💂🏿' => 'պահակազորային․ մուգ գույնի մաշկ',
    '🥷🏻' => 'նինջա․ բաց գույնի մաշկ',
    '🥷🏼' => 'նինջա․ միջին բաց գույնի մաշկ',
    '🥷🏽' => 'նինջա․ միջին գույնի մաշկ',
    '🥷🏾' => 'նինջա․ միջին մուգ գույնի մաշկ',
    '🥷🏿' => 'նինջա․ մուգ գույնի մաշկ',
    '👷🏻' => 'շինարար․ բաց գույնի մաշկ',
    '👷🏼' => 'շինարար․ միջին բաց գույնի մաշկ',
    '👷🏽' => 'շինարար․ միջին գույնի մաշկ',
    '👷🏾' => 'շինարար․ միջին մուգ գույնի մաշկ',
    '👷🏿' => 'շինարար․ մուգ գույնի մաշկ',
    '🫅🏻' => 'թագով հանձ․ բաց գույնի մաշկ',
    '🫅🏼' => 'թագով հանձ․ միջին բաց գույնի մաշկ',
    '🫅🏽' => 'թագով հանձ․ միջին գույնի մաշկ',
    '🫅🏾' => 'թագով հանձ․ միջին մուգ գույնի մաշկ',
    '🫅🏿' => 'թագով հանձ․ մուգ գույնի մաշկ',
    '🤴🏻' => 'արքայազն․ բաց գույնի մաշկ',
    '🤴🏼' => 'արքայազն․ միջին բաց գույնի մաշկ',
    '🤴🏽' => 'արքայազն․ միջին գույնի մաշկ',
    '🤴🏾' => 'արքայազն․ միջին մուգ գույնի մաշկ',
    '🤴🏿' => 'արքայազն․ մուգ գույնի մաշկ',
    '👸🏻' => 'արքայադուստր․ բաց գույնի մաշկ',
    '👸🏼' => 'արքայադուստր․ միջին բաց գույնի մաշկ',
    '👸🏽' => 'արքայադուստր․ միջին գույնի մաշկ',
    '👸🏾' => 'արքայադուստր․ միջին մուգ գույնի մաշկ',
    '👸🏿' => 'արքայադուստր․ մուգ գույնի մաշկ',
    '👳🏻' => 'թյուրբանով անձ․ բաց գույնի մաշկ',
    '👳🏼' => 'թյուրբանով անձ․ միջին բաց գույնի մաշկ',
    '👳🏽' => 'թյուրբանով անձ․ միջին գույնի մաշկ',
    '👳🏾' => 'թյուրբանով անձ․ միջին մուգ գույնի մաշկ',
    '👳🏿' => 'թյուրբանով անձ․ մուգ գույնի մաշկ',
    '👲🏻' => 'թասակով անձ․ բաց գույնի մաշկ',
    '👲🏼' => 'թասակով անձ․ միջին բաց գույնի մաշկ',
    '👲🏽' => 'թասակով անձ․ միջին գույնի մաշկ',
    '👲🏾' => 'թասակով անձ․ միջին մուգ գույնի մաշկ',
    '👲🏿' => 'թասակով անձ․ մուգ գույնի մաշկ',
    '🧕🏻' => 'գլխաշորով կին․ բաց գույնի մաշկ',
    '🧕🏼' => 'գլխաշորով կին․ միջին բաց գույնի մաշկ',
    '🧕🏽' => 'գլխաշորով կին․ միջին գույնի մաշկ',
    '🧕🏾' => 'գլխաշորով կին․ միջին մուգ գույնի մաշկ',
    '🧕🏿' => 'գլխաշորով կին․ մուգ գույնի մաշկ',
    '🤵🏻' => 'սմոկինգով մարդ․ բաց գույնի մաշկ',
    '🤵🏼' => 'սմոկինգով մարդ․ միջին բաց գույնի մաշկ',
    '🤵🏽' => 'սմոկինգով մարդ․ միջին գույնի մաշկ',
    '🤵🏾' => 'սմոկինգով մարդ․ միջին մուգ գույնի մաշկ',
    '🤵🏿' => 'սմոկինգով մարդ․ մուգ գույնի մաշկ',
    '👰🏻' => 'քողով անձ․ բաց գույնի մաշկ',
    '👰🏼' => 'քողով անձ․ միջին բաց գույնի մաշկ',
    '👰🏽' => 'քողով անձ․ միջին գույնի մաշկ',
    '👰🏾' => 'քողով անձ․ միջին մուգ գույնի մաշկ',
    '👰🏿' => 'քողով անձ․ մուգ գույնի մաշկ',
    '🤰🏻' => 'հղի կին․ բաց գույնի մաշկ',
    '🤰🏼' => 'հղի կին․ միջին բաց գույնի մաշկ',
    '🤰🏽' => 'հղի կին․ միջին գույնի մաշկ',
    '🤰🏾' => 'հղի կին․ միջին մուգ գույնի մաշկ',
    '🤰🏿' => 'հղի կին․ մուգ գույնի մաշկ',
    '🫃🏻' => 'հղի տիկին․ բաց գույնի մաշկ',
    '🫃🏼' => 'հղի տիկին․ միջին բաց գույնի մաշկ',
    '🫃🏽' => 'հղի տիկին․ միջին գույնի մաշկ',
    '🫃🏾' => 'հղի տիկին․ միջին մուգ գույնի մաշկ',
    '🫃🏿' => 'հղի տիկին․ մուգ գույնի մաշկ',
    '🫄🏻' => 'հղի անձ․ բաց գույնի մաշկ',
    '🫄🏼' => 'հղի անձ․ միջին բաց գույնի մաշկ',
    '🫄🏽' => 'հղի անձ․ միջին գույնի մաշկ',
    '🫄🏾' => 'հղի անձ․ միջին մուգ գույնի մաշկ',
    '🫄🏿' => 'հղի անձ․ մուգ գույնի մաշկ',
    '🤱🏻' => 'կրծքով կերակրում․ բաց գույնի մաշկ',
    '🤱🏼' => 'կրծքով կերակրում․ միջին բաց գույնի մաշկ',
    '🤱🏽' => 'կրծքով կերակրում․ միջին գույնի մաշկ',
    '🤱🏾' => 'կրծքով կերակրում․ միջին մուգ գույնի մաշկ',
    '🤱🏿' => 'կրծքով կերակրում․ մուգ գույնի մաշկ',
    '👼🏻' => 'մանուկ-հրեշտակ․ բաց գույնի մաշկ',
    '👼🏼' => 'մանուկ-հրեշտակ․ միջին բաց գույնի մաշկ',
    '👼🏽' => 'մանուկ-հրեշտակ․ միջին գույնի մաշկ',
    '👼🏾' => 'մանուկ-հրեշտակ․ միջին մուգ գույնի մաշկ',
    '👼🏿' => 'մանուկ-հրեշտակ․ մուգ գույնի մաշկ',
    '🎅🏻' => 'Սանտա Կլաուս․ բաց գույնի մաշկ',
    '🎅🏼' => 'Սանտա Կլաուս․ միջին բաց գույնի մաշկ',
    '🎅🏽' => 'Սանտա Կլաուս․ միջին գույնի մաշկ',
    '🎅🏾' => 'Սանտա Կլաուս․ միջին մուգ գույնի մաշկ',
    '🎅🏿' => 'Սանտա Կլաուս․ մուգ գույնի մաշկ',
    '🤶🏻' => 'Ձմեռ տատ․ բաց գույնի մաշկ',
    '🤶🏼' => 'Ձմեռ տատ․ միջին բաց գույնի մաշկ',
    '🤶🏽' => 'Ձմեռ տատ․ միջին գույնի մաշկ',
    '🤶🏾' => 'Ձմեռ տատ․ միջին մուգ գույնի մաշկ',
    '🤶🏿' => 'Ձմեռ տատ․ մուգ գույնի մաշկ',
    '🦸🏻' => 'սուպերհերոս․ բաց գույնի մաշկ',
    '🦸🏼' => 'սուպերհերոս․ միջին բաց գույնի մաշկ',
    '🦸🏽' => 'սուպերհերոս․ միջին գույնի մաշկ',
    '🦸🏾' => 'սուպերհերոս․ միջին մուգ գույնի մաշկ',
    '🦸🏿' => 'սուպերհերոս․ մուգ գույնի մաշկ',
    '🦹🏻' => 'սուպերչարագործ․ բաց գույնի մաշկ',
    '🦹🏼' => 'սուպերչարագործ․ միջին բաց գույնի մաշկ',
    '🦹🏽' => 'սուպերչարագործ․ միջին գույնի մաշկ',
    '🦹🏾' => 'սուպերչարագործ․ միջին մուգ գույնի մաշկ',
    '🦹🏿' => 'սուպերչարագործ․ մուգ գույնի մաշկ',
    '🧙🏻' => 'մոգ․ բաց գույնի մաշկ',
    '🧙🏼' => 'մոգ․ միջին բաց գույնի մաշկ',
    '🧙🏽' => 'մոգ․ միջին գույնի մաշկ',
    '🧙🏾' => 'մոգ․ միջին մուգ գույնի մաշկ',
    '🧙🏿' => 'մոգ․ մուգ գույնի մաշկ',
    '🧚🏻' => 'փերի․ բաց գույնի մաշկ',
    '🧚🏼' => 'փերի․ միջին բաց գույնի մաշկ',
    '🧚🏽' => 'փերի․ միջին գույնի մաշկ',
    '🧚🏾' => 'փերի․ միջին մուգ գույնի մաշկ',
    '🧚🏿' => 'փերի․ մուգ գույնի մաշկ',
    '🧛🏻' => 'վամպիր․ բաց գույնի մաշկ',
    '🧛🏼' => 'վամպիր․ միջին բաց գույնի մաշկ',
    '🧛🏽' => 'վամպիր․ միջին գույնի մաշկ',
    '🧛🏾' => 'վամպիր․ միջին մուգ գույնի մաշկ',
    '🧛🏿' => 'վամպիր․ մուգ գույնի մաշկ',
    '🧜🏻' => 'մարդաձուկ․ բաց գույնի մաշկ',
    '🧜🏼' => 'մարդաձուկ․ միջին բաց գույնի մաշկ',
    '🧜🏽' => 'մարդաձուկ․ միջին գույնի մաշկ',
    '🧜🏾' => 'մարդաձուկ․ միջին մուգ գույնի մաշկ',
    '🧜🏿' => 'մարդաձուկ․ մուգ գույնի մաշկ',
    '🧝🏻' => 'էլֆ․ բաց գույնի մաշկ',
    '🧝🏼' => 'էլֆ․ միջին բաց գույնի մաշկ',
    '🧝🏽' => 'էլֆ․ միջին գույնի մաշկ',
    '🧝🏾' => 'էլֆ․ միջին մուգ գույնի մաշկ',
    '🧝🏿' => 'էլֆ․ մուգ գույնի մաշկ',
    '💆🏻' => 'մերսվող անձ․ բաց գույնի մաշկ',
    '💆🏼' => 'մերսվող անձ․ միջին բաց գույնի մաշկ',
    '💆🏽' => 'մերսվող անձ․ միջին գույնի մաշկ',
    '💆🏾' => 'մերսվող անձ․ միջին մուգ գույնի մաշկ',
    '💆🏿' => 'մերսվող անձ․ մուգ գույնի մաշկ',
    '💇🏻' => 'մազերը կտրող անձ․ բաց գույնի մաշկ',
    '💇🏼' => 'մազերը կտրող անձ․ միջին բաց գույնի մաշկ',
    '💇🏽' => 'մազերը կտրող անձ․ միջին գույնի մաշկ',
    '💇🏾' => 'մազերը կտրող անձ․ միջին մուգ գույնի մաշկ',
    '💇🏿' => 'մազերը կտրող անձ․ մուգ գույնի մաշկ',
    '🚶🏻' => 'հետիոտն․ բաց գույնի մաշկ',
    '🚶🏼' => 'հետիոտն․ միջին բաց գույնի մաշկ',
    '🚶🏽' => 'հետիոտն․ միջին գույնի մաշկ',
    '🚶🏾' => 'հետիոտն․ միջին մուգ գույնի մաշկ',
    '🚶🏿' => 'հետիոտն․ մուգ գույնի մաշկ',
    '🧍🏻' => 'կանգնած անձ․ բաց գույնի մաշկ',
    '🧍🏼' => 'կանգնած անձ․ միջին բաց գույնի մաշկ',
    '🧍🏽' => 'կանգնած անձ․ միջին գույնի մաշկ',
    '🧍🏾' => 'կանգնած անձ․ միջին մուգ գույնի մաշկ',
    '🧍🏿' => 'կանգնած անձ․ մուգ գույնի մաշկ',
    '🧎🏻' => 'ծնկաչոք անձ․ բաց գույնի մաշկ',
    '🧎🏼' => 'ծնկաչոք անձ․ միջին բաց գույնի մաշկ',
    '🧎🏽' => 'ծնկաչոք անձ․ միջին գույնի մաշկ',
    '🧎🏾' => 'ծնկաչոք անձ․ միջին մուգ գույնի մաշկ',
    '🧎🏿' => 'ծնկաչոք անձ․ մուգ գույնի մաշկ',
    '🏃🏻' => 'վազող անձ․ բաց գույնի մաշկ',
    '🏃🏼' => 'վազող անձ․ միջին բաց գույնի մաշկ',
    '🏃🏽' => 'վազող անձ․ միջին գույնի մաշկ',
    '🏃🏾' => 'վազող անձ․ միջին մուգ գույնի մաշկ',
    '🏃🏿' => 'վազող անձ․ մուգ գույնի մաշկ',
    '💃🏻' => 'պարուհի․ բաց գույնի մաշկ',
    '💃🏼' => 'պարուհի․ միջին բաց գույնի մաշկ',
    '💃🏽' => 'պարուհի․ միջին գույնի մաշկ',
    '💃🏾' => 'պարուհի․ միջին մուգ գույնի մաշկ',
    '💃🏿' => 'պարուհի․ մուգ գույնի մաշկ',
    '🕺🏻' => 'պարող մարդ․ բաց գույնի մաշկ',
    '🕺🏼' => 'պարող մարդ․ միջին բաց գույնի մաշկ',
    '🕺🏽' => 'պարող մարդ․ միջին գույնի մաշկ',
    '🕺🏾' => 'պարող մարդ․ միջին մուգ գույնի մաշկ',
    '🕺🏿' => 'պարող մարդ․ մուգ գույնի մաշկ',
    '🕴🏻' => 'կոստյումով ճախրող մարդ․ բաց գույնի մաշկ',
    '🕴🏼' => 'կոստյումով ճախրող մարդ․ միջին բաց գույնի մաշկ',
    '🕴🏽' => 'կոստյումով ճախրող մարդ․ միջին գույնի մաշկ',
    '🕴🏾' => 'կոստյումով ճախրող մարդ․ միջին մուգ գույնի մաշկ',
    '🕴🏿' => 'կոստյումով ճախրող մարդ․ մուգ գույնի մաշկ',
    '👯🏻' => 'ճագարի ականջներով մարդիկ․ բաց գույնի մաշկ',
    '👯🏼' => 'ճագարի ականջներով մարդիկ․ միջին բաց գույնի մաշկ',
    '👯🏽' => 'ճագարի ականջներով մարդիկ․ միջին գույնի մաշկ',
    '👯🏾' => 'ճագարի ականջներով մարդիկ․ միջին մուգ գույնի մաշկ',
    '👯🏿' => 'ճագարի ականջներով մարդիկ․ մուգ գույնի մաշկ',
    '🧖🏻' => 'մարդ բաղնիքում․ բաց գույնի մաշկ',
    '🧖🏼' => 'մարդ բաղնիքում․ միջին բաց գույնի մաշկ',
    '🧖🏽' => 'մարդ բաղնիքում․ միջին գույնի մաշկ',
    '🧖🏾' => 'մարդ բաղնիքում․ միջին մուգ գույնի մաշկ',
    '🧖🏿' => 'մարդ բաղնիքում․ մուգ գույնի մաշկ',
    '🧗🏻' => 'մագլցող անձ․ բաց գույնի մաշկ',
    '🧗🏼' => 'մագլցող անձ․ միջին բաց գույնի մաշկ',
    '🧗🏽' => 'մագլցող անձ․ միջին գույնի մաշկ',
    '🧗🏾' => 'մագլցող անձ․ միջին մուգ գույնի մաշկ',
    '🧗🏿' => 'մագլցող անձ․ մուգ գույնի մաշկ',
    '🏇🏻' => 'ձիարշավ․ բաց գույնի մաշկ',
    '🏇🏼' => 'ձիարշավ․ միջին բաց գույնի մաշկ',
    '🏇🏽' => 'ձիարշավ․ միջին գույնի մաշկ',
    '🏇🏾' => 'ձիարշավ․ միջին մուգ գույնի մաշկ',
    '🏇🏿' => 'ձիարշավ․ մուգ գույնի մաշկ',
    '🏂🏻' => 'սնոուբորդիստ․ բաց գույնի մաշկ',
    '🏂🏼' => 'սնոուբորդիստ․ միջին բաց գույնի մաշկ',
    '🏂🏽' => 'սնոուբորդիստ․ միջին գույնի մաշկ',
    '🏂🏾' => 'սնոուբորդիստ․ միջին մուգ գույնի մաշկ',
    '🏂🏿' => 'սնոուբորդիստ․ մուգ գույնի մաշկ',
    '🏌🏻' => 'գոլֆ խաղացող․ բաց գույնի մաշկ',
    '🏌🏼' => 'գոլֆ խաղացող․ միջին բաց գույնի մաշկ',
    '🏌🏽' => 'գոլֆ խաղացող․ միջին գույնի մաշկ',
    '🏌🏾' => 'գոլֆ խաղացող․ միջին մուգ գույնի մաշկ',
    '🏌🏿' => 'գոլֆ խաղացող․ մուգ գույնի մաշկ',
    '🏄🏻' => 'սերֆեր․ բաց գույնի մաշկ',
    '🏄🏼' => 'սերֆեր․ միջին բաց գույնի մաշկ',
    '🏄🏽' => 'սերֆեր․ միջին գույնի մաշկ',
    '🏄🏾' => 'սերֆեր․ միջին մուգ գույնի մաշկ',
    '🏄🏿' => 'սերֆեր․ մուգ գույնի մաշկ',
    '🚣🏻' => 'նավակ թիավարող անձ․ բաց գույնի մաշկ',
    '🚣🏼' => 'նավակ թիավարող անձ․ միջին բաց գույնի մաշկ',
    '🚣🏽' => 'նավակ թիավարող անձ․ միջին գույնի մաշկ',
    '🚣🏾' => 'նավակ թիավարող անձ․ միջին մուգ գույնի մաշկ',
    '🚣🏿' => 'նավակ թիավարող անձ․ մուգ գույնի մաշկ',
    '🏊🏻' => 'լողորդ․ բաց գույնի մաշկ',
    '🏊🏼' => 'լողորդ․ միջին բաց գույնի մաշկ',
    '🏊🏽' => 'լողորդ․ միջին գույնի մաշկ',
    '🏊🏾' => 'լողորդ․ միջին մուգ գույնի մաշկ',
    '🏊🏿' => 'լողորդ․ մուգ գույնի մաշկ',
    '⛹🏻' => 'գնդակով մարդ․ բաց գույնի մաշկ',
    '⛹🏼' => 'գնդակով մարդ․ միջին բաց գույնի մաշկ',
    '⛹🏽' => 'գնդակով մարդ․ միջին գույնի մաշկ',
    '⛹🏾' => 'գնդակով մարդ․ միջին մուգ գույնի մաշկ',
    '⛹🏿' => 'գնդակով մարդ․ մուգ գույնի մաշկ',
    '🏋🏻' => 'ծանրորդ․ բաց գույնի մաշկ',
    '🏋🏼' => 'ծանրորդ․ միջին բաց գույնի մաշկ',
    '🏋🏽' => 'ծանրորդ․ միջին գույնի մաշկ',
    '🏋🏾' => 'ծանրորդ․ միջին մուգ գույնի մաշկ',
    '🏋🏿' => 'ծանրորդ․ մուգ գույնի մաշկ',
    '🚴🏻' => 'հեծանվորդ․ բաց գույնի մաշկ',
    '🚴🏼' => 'հեծանվորդ․ միջին բաց գույնի մաշկ',
    '🚴🏽' => 'հեծանվորդ․ միջին գույնի մաշկ',
    '🚴🏾' => 'հեծանվորդ․ միջին մուգ գույնի մաշկ',
    '🚴🏿' => 'հեծանվորդ․ մուգ գույնի մաշկ',
    '🚵🏻' => 'լեռնահեծանվորդ․ բաց գույնի մաշկ',
    '🚵🏼' => 'լեռնահեծանվորդ․ միջին բաց գույնի մաշկ',
    '🚵🏽' => 'լեռնահեծանվորդ․ միջին գույնի մաշկ',
    '🚵🏾' => 'լեռնահեծանվորդ․ միջին մուգ գույնի մաշկ',
    '🚵🏿' => 'լեռնահեծանվորդ․ մուգ գույնի մաշկ',
    '🤸🏻' => 'ձեռնակոնծի կատարող անձ․ բաց գույնի մաշկ',
    '🤸🏼' => 'ձեռնակոնծի կատարող անձ․ միջին բաց գույնի մաշկ',
    '🤸🏽' => 'ձեռնակոնծի կատարող անձ․ միջին գույնի մաշկ',
    '🤸🏾' => 'ձեռնակոնծի կատարող անձ․ միջին մուգ գույնի մաշկ',
    '🤸🏿' => 'ձեռնակոնծի կատարող անձ․ մուգ գույնի մաշկ',
    '🤼🏻' => 'ըմբշամարտիկներ․ բաց գույնի մաշկ',
    '🤼🏼' => 'ըմբշամարտիկներ․ միջին բաց գույնի մաշկ',
    '🤼🏽' => 'ըմբշամարտիկներ․ միջին գույնի մաշկ',
    '🤼🏾' => 'ըմբշամարտիկներ․ միջին մուգ գույնի մաշկ',
    '🤼🏿' => 'ըմբշամարտիկներ․ մուգ գույնի մաշկ',
    '🤽🏻' => 'ջրագնդակ խաղացող անձ․ բաց գույնի մաշկ',
    '🤽🏼' => 'ջրագնդակ խաղացող անձ․ միջին բաց գույնի մաշկ',
    '🤽🏽' => 'ջրագնդակ խաղացող անձ․ միջին գույնի մաշկ',
    '🤽🏾' => 'ջրագնդակ խաղացող անձ․ միջին մուգ գույնի մաշկ',
    '🤽🏿' => 'ջրագնդակ խաղացող անձ․ մուգ գույնի մաշկ',
    '🤾🏻' => 'ձեռնագնդակ խաղացող անձ․ բաց գույնի մաշկ',
    '🤾🏼' => 'ձեռնագնդակ խաղացող անձ․ միջին բաց գույնի մաշկ',
    '🤾🏽' => 'ձեռնագնդակ խաղացող անձ․ միջին գույնի մաշկ',
    '🤾🏾' => 'ձեռնագնդակ խաղացող անձ․ միջին մուգ գույնի մաշկ',
    '🤾🏿' => 'ձեռնագնդակ խաղացող անձ․ մուգ գույնի մաշկ',
    '🤹🏻' => 'ձեռնածու․ բաց գույնի մաշկ',
    '🤹🏼' => 'ձեռնածու․ միջին բաց գույնի մաշկ',
    '🤹🏽' => 'ձեռնածու․ միջին գույնի մաշկ',
    '🤹🏾' => 'ձեռնածու․ միջին մուգ գույնի մաշկ',
    '🤹🏿' => 'ձեռնածու․ մուգ գույնի մաշկ',
    '🧘🏻' => 'լոտոսի դիրքով նստած մարդ․ բաց գույնի մաշկ',
    '🧘🏼' => 'լոտոսի դիրքով նստած մարդ․ միջին բաց գույնի մաշկ',
    '🧘🏽' => 'լոտոսի դիրքով նստած մարդ․ միջին գույնի մաշկ',
    '🧘🏾' => 'լոտոսի դիրքով նստած մարդ․ միջին մուգ գույնի մաշկ',
    '🧘🏿' => 'լոտոսի դիրքով նստած մարդ․ մուգ գույնի մաշկ',
    '🛀🏻' => 'լոգանք ընդունող անձ․ բաց գույնի մաշկ',
    '🛀🏼' => 'լոգանք ընդունող անձ․ միջին բաց գույնի մաշկ',
    '🛀🏽' => 'լոգանք ընդունող անձ․ միջին գույնի մաշկ',
    '🛀🏾' => 'լոգանք ընդունող անձ․ միջին մուգ գույնի մաշկ',
    '🛀🏿' => 'լոգանք ընդունող անձ․ մուգ գույնի մաշկ',
    '🛌🏻' => 'մահճակալին պառկած անձ․ բաց գույնի մաշկ',
    '🛌🏼' => 'մահճակալին պառկած անձ․ միջին բաց գույնի մաշկ',
    '🛌🏽' => 'մահճակալին պառկած անձ․ միջին գույնի մաշկ',
    '🛌🏾' => 'մահճակալին պառկած անձ․ միջին մուգ գույնի մաշկ',
    '🛌🏿' => 'մահճակալին պառկած անձ․ մուգ գույնի մաշկ',
    '👭🏻' => 'իրար ձեռք բռնած կանայք․ բաց գույնի մաշկ',
    '👭🏼' => 'իրար ձեռք բռնած կանայք․ միջին բաց գույնի մաշկ',
    '👭🏽' => 'իրար ձեռք բռնած կանայք․ միջին գույնի մաշկ',
    '👭🏾' => 'իրար ձեռք բռնած կանայք․ միջին մուգ գույնի մաշկ',
    '👭🏿' => 'իրար ձեռք բռնած կանայք․ մուգ գույնի մաշկ',
    '👫🏻' => 'իրար ձեռք բռնած կին ու տղամարդ․ բաց գույնի մաշկ',
    '👫🏼' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին բաց գույնի մաշկ',
    '👫🏽' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին գույնի մաշկ',
    '👫🏾' => 'իրար ձեռք բռնած կին ու տղամարդ․ միջին մուգ գույնի մաշկ',
    '👫🏿' => 'իրար ձեռք բռնած կին ու տղամարդ․ մուգ գույնի մաշկ',
    '👬🏻' => 'իրար ձեռք բռնած տղամարդիկ․ բաց գույնի մաշկ',
    '👬🏼' => 'իրար ձեռք բռնած տղամարդիկ․ միջին բաց գույնի մաշկ',
    '👬🏽' => 'իրար ձեռք բռնած տղամարդիկ․ միջին գույնի մաշկ',
    '👬🏾' => 'իրար ձեռք բռնած տղամարդիկ․ միջին մուգ գույնի մաշկ',
    '👬🏿' => 'իրար ձեռք բռնած տղամարդիկ․ մուգ գույնի մաշկ',
    '💏🏻' => 'համբույր․ բաց գույնի մաշկ',
    '💏🏼' => 'համբույր․ միջին բաց գույնի մաշկ',
    '💏🏽' => 'համբույր․ միջին գույնի մաշկ',
    '💏🏾' => 'համբույր․ միջին մուգ գույնի մաշկ',
    '💏🏿' => 'համբույր․ մուգ գույնի մաշկ',
    '💑🏻' => 'սրտիկով զույգ․ բաց գույնի մաշկ',
    '💑🏼' => 'սրտիկով զույգ․ միջին բաց գույնի մաշկ',
    '💑🏽' => 'սրտիկով զույգ․ միջին գույնի մաշկ',
    '💑🏾' => 'սրտիկով զույգ․ միջին մուգ գույնի մաշկ',
    '💑🏿' => 'սրտիկով զույգ․ մուգ գույնի մաշկ',
    '🇦🇨' => 'դրոշ․ Համբարձման կղզի',
    '🇦🇩' => 'դրոշ․ Անդորրա',
    '🇦🇪' => 'դրոշ․ Արաբական Միացյալ Էմիրություններ',
    '🇦🇫' => 'դրոշ․ Աֆղանստան',
    '🇦🇬' => 'դրոշ․ Անտիգուա և Բարբուդա',
    '🇦🇮' => 'դրոշ․ Անգուիլա',
    '🇦🇱' => 'դրոշ․ Ալբանիա',
    '🇦🇲' => 'դրոշ․ Հայաստան',
    '🇦🇴' => 'դրոշ․ Անգոլա',
    '🇦🇶' => 'դրոշ․ Անտարկտիդա',
    '🇦🇷' => 'դրոշ․ Արգենտինա',
    '🇦🇸' => 'դրոշ․ Ամերիկյան Սամոա',
    '🇦🇹' => 'դրոշ․ Ավստրիա',
    '🇦🇺' => 'դրոշ․ Ավստրալիա',
    '🇦🇼' => 'դրոշ․ Արուբա',
    '🇦🇽' => 'դրոշ․ Ալանդյան կղզիներ',
    '🇦🇿' => 'դրոշ․ Ադրբեջան',
    '🇧🇦' => 'դրոշ․ Բոսնիա և Հերցեգովինա',
    '🇧🇧' => 'դրոշ․ Բարբադոս',
    '🇧🇩' => 'դրոշ․ Բանգլադեշ',
    '🇧🇪' => 'դրոշ․ Բելգիա',
    '🇧🇫' => 'դրոշ․ Բուրկինա Ֆասո',
    '🇧🇬' => 'դրոշ․ Բուլղարիա',
    '🇧🇭' => 'դրոշ․ Բահրեյն',
    '🇧🇮' => 'դրոշ․ Բուրունդի',
    '🇧🇯' => 'դրոշ․ Բենին',
    '🇧🇱' => 'դրոշ․ Սուրբ Բարդուղիմեոս',
    '🇧🇲' => 'դրոշ․ Բերմուդներ',
    '🇧🇳' => 'դրոշ․ Բրունեյ',
    '🇧🇴' => 'դրոշ․ Բոլիվիա',
    '🇧🇶' => 'դրոշ․ Կարիբյան Նիդեռլանդներ',
    '🇧🇷' => 'դրոշ․ Բրազիլիա',
    '🇧🇸' => 'դրոշ․ Բահամյան կղզիներ',
    '🇧🇹' => 'դրոշ․ Բութան',
    '🇧🇻' => 'դրոշ․ Բուվե կղզի',
    '🇧🇼' => 'դրոշ․ Բոտսվանա',
    '🇧🇾' => 'դրոշ․ Բելառուս',
    '🇧🇿' => 'դրոշ․ Բելիզ',
    '🇨🇦' => 'դրոշ․ Կանադա',
    '🇨🇨' => 'դրոշ․ Կոկոսյան (Քիլինգ) կղզիներ',
    '🇨🇩' => 'դրոշ․ Կոնգո - Կինշասա',
    '🇨🇫' => 'դրոշ․ Կենտրոնական Աֆրիկյան Հանրապետություն',
    '🇨🇬' => 'դրոշ․ Կոնգո - Բրազավիլ',
    '🇨🇭' => 'դրոշ․ Շվեյցարիա',
    '🇨🇮' => 'դրոշ․ Կոտ դ՚Իվուար',
    '🇨🇰' => 'դրոշ․ Կուկի կղզիներ',
    '🇨🇱' => 'դրոշ․ Չիլի',
    '🇨🇲' => 'դրոշ․ Կամերուն',
    '🇨🇳' => 'դրոշ․ Չինաստան',
    '🇨🇴' => 'դրոշ․ Կոլումբիա',
    '🇨🇵' => 'դրոշ․ Քլիփերթոն կղզի',
    '🇨🇶' => 'դրոշ․ Սարկ կղզի',
    '🇨🇷' => 'դրոշ․ Կոստա Ռիկա',
    '🇨🇺' => 'դրոշ․ Կուբա',
    '🇨🇻' => 'դրոշ․ Կաբո Վերդե',
    '🇨🇼' => 'դրոշ․ Կյուրասաո',
    '🇨🇽' => 'դրոշ․ Սուրբ Ծննդյան կղզի',
    '🇨🇾' => 'դրոշ․ Կիպրոս',
    '🇨🇿' => 'դրոշ․ Չեխիա',
    '🇩🇪' => 'դրոշ․ Գերմանիա',
    '🇩🇬' => 'դրոշ․ Դիեգո Գարսիա',
    '🇩🇯' => 'դրոշ․ Ջիբութի',
    '🇩🇰' => 'դրոշ․ Դանիա',
    '🇩🇲' => 'դրոշ․ Դոմինիկա',
    '🇩🇴' => 'դրոշ․ Դոմինիկյան Հանրապետություն',
    '🇩🇿' => 'դրոշ․ Ալժիր',
    '🇪🇦' => 'դրոշ․ Սեուտա և Մելիլյա',
    '🇪🇨' => 'դրոշ․ Էկվադոր',
    '🇪🇪' => 'դրոշ․ Էստոնիա',
    '🇪🇬' => 'դրոշ․ Եգիպտոս',
    '🇪🇭' => 'դրոշ․ Արևմտյան Սահարա',
    '🇪🇷' => 'դրոշ․ Էրիթրեա',
    '🇪🇸' => 'դրոշ․ Իսպանիա',
    '🇪🇹' => 'դրոշ․ Եթովպիա',
    '🇪🇺' => 'դրոշ․ Եվրոպական Միություն',
    '🇫🇮' => 'դրոշ․ Ֆինլանդիա',
    '🇫🇯' => 'դրոշ․ Ֆիջի',
    '🇫🇰' => 'դրոշ․ Ֆոլքլենդյան կղզիներ',
    '🇫🇲' => 'դրոշ․ Միկրոնեզիա',
    '🇫🇴' => 'դրոշ․ Ֆարերյան կղզիներ',
    '🇫🇷' => 'դրոշ․ Ֆրանսիա',
    '🇬🇦' => 'դրոշ․ Գաբոն',
    '🇬🇧' => 'դրոշ․ Միացյալ Թագավորություն',
    '🇬🇩' => 'դրոշ․ Գրենադա',
    '🇬🇪' => 'դրոշ․ Վրաստան',
    '🇬🇫' => 'դրոշ․ Ֆրանսիական Գվիանա',
    '🇬🇬' => 'դրոշ․ Գերնսի',
    '🇬🇭' => 'դրոշ․ Գանա',
    '🇬🇮' => 'դրոշ․ Ջիբրալթար',
    '🇬🇱' => 'դրոշ․ Գրենլանդիա',
    '🇬🇲' => 'դրոշ․ Գամբիա',
    '🇬🇳' => 'դրոշ․ Գվինեա',
    '🇬🇵' => 'դրոշ․ Գվադելուպա',
    '🇬🇶' => 'դրոշ․ Հասարակածային Գվինեա',
    '🇬🇷' => 'դրոշ․ Հունաստան',
    '🇬🇸' => 'դրոշ․ Հարավային Ջորջիա և Հարավային Սենդվիչյան կղզիներ',
    '🇬🇹' => 'դրոշ․ Գվատեմալա',
    '🇬🇺' => 'դրոշ․ Գուամ',
    '🇬🇼' => 'դրոշ․ Գվինեա-Բիսաու',
    '🇬🇾' => 'դրոշ․ Գայանա',
    '🇭🇰' => 'դրոշ․ Հոնկոնգի ՀՎՇ',
    '🇭🇲' => 'դրոշ․ Հերդ կղզի և ՄակԴոնալդի կղզիներ',
    '🇭🇳' => 'դրոշ․ Հոնդուրաս',
    '🇭🇷' => 'դրոշ․ Խորվաթիա',
    '🇭🇹' => 'դրոշ․ Հայիթի',
    '🇭🇺' => 'դրոշ․ Հունգարիա',
    '🇮🇨' => 'դրոշ․ Կանարյան կղզիներ',
    '🇮🇩' => 'դրոշ․ Ինդոնեզիա',
    '🇮🇪' => 'դրոշ․ Իռլանդիա',
    '🇮🇱' => 'դրոշ․ Իսրայել',
    '🇮🇲' => 'դրոշ․ Մեն կղզի',
    '🇮🇳' => 'դրոշ․ Հնդկաստան',
    '🇮🇴' => 'դրոշ․ Բրիտանական տարածք Հնդկական Օվկիանոսում',
    '🇮🇶' => 'դրոշ․ Իրաք',
    '🇮🇷' => 'դրոշ․ Իրան',
    '🇮🇸' => 'դրոշ․ Իսլանդիա',
    '🇮🇹' => 'դրոշ․ Իտալիա',
    '🇯🇪' => 'դրոշ․ Ջերսի',
    '🇯🇲' => 'դրոշ․ Ճամայկա',
    '🇯🇴' => 'դրոշ․ Հորդանան',
    '🇯🇵' => 'դրոշ․ Ճապոնիա',
    '🇰🇪' => 'դրոշ․ Քենիա',
    '🇰🇬' => 'դրոշ․ Ղրղզստան',
    '🇰🇭' => 'դրոշ․ Կամբոջա',
    '🇰🇮' => 'դրոշ․ Կիրիբատի',
    '🇰🇲' => 'դրոշ․ Կոմորյան կղզիներ',
    '🇰🇳' => 'դրոշ․ Սենթ Քիտս և Նևիս',
    '🇰🇵' => 'դրոշ․ Հյուսիսային Կորեա',
    '🇰🇷' => 'դրոշ․ Հարավային Կորեա',
    '🇰🇼' => 'դրոշ․ Քուվեյթ',
    '🇰🇾' => 'դրոշ․ Կայմանյան կղզիներ',
    '🇰🇿' => 'դրոշ․ Ղազախստան',
    '🇱🇦' => 'դրոշ․ Լաոս',
    '🇱🇧' => 'դրոշ․ Լիբանան',
    '🇱🇨' => 'դրոշ․ Սենթ Լյուսիա',
    '🇱🇮' => 'դրոշ․ Լիխտենշտեյն',
    '🇱🇰' => 'դրոշ․ Շրի Լանկա',
    '🇱🇷' => 'դրոշ․ Լիբերիա',
    '🇱🇸' => 'դրոշ․ Լեսոտո',
    '🇱🇹' => 'դրոշ․ Լիտվա',
    '🇱🇺' => 'դրոշ․ Լյուքսեմբուրգ',
    '🇱🇻' => 'դրոշ․ Լատվիա',
    '🇱🇾' => 'դրոշ․ Լիբիա',
    '🇲🇦' => 'դրոշ․ Մարոկկո',
    '🇲🇨' => 'դրոշ․ Մոնակո',
    '🇲🇩' => 'դրոշ․ Մոլդովա',
    '🇲🇪' => 'դրոշ․ Չեռնոգորիա',
    '🇲🇫' => 'դրոշ․ Սեն Մարտեն',
    '🇲🇬' => 'դրոշ․ Մադագասկար',
    '🇲🇭' => 'դրոշ․ Մարշալյան կղզիներ',
    '🇲🇰' => 'դրոշ․ Հյուսիսային Մակեդոնիա',
    '🇲🇱' => 'դրոշ․ Մալի',
    '🇲🇲' => 'դրոշ․ Մյանմա (Բիրմա)',
    '🇲🇳' => 'դրոշ․ Մոնղոլիա',
    '🇲🇴' => 'դրոշ․ Չինաստանի Մակաո ՀՎՇ',
    '🇲🇵' => 'դրոշ․ Հյուսիսային Մարիանյան կղզիներ',
    '🇲🇶' => 'դրոշ․ Մարտինիկա',
    '🇲🇷' => 'դրոշ․ Մավրիտանիա',
    '🇲🇸' => 'դրոշ․ Մոնսեռատ',
    '🇲🇹' => 'դրոշ․ Մալթա',
    '🇲🇺' => 'դրոշ․ Մավրիկիոս',
    '🇲🇻' => 'դրոշ․ Մալդիվներ',
    '🇲🇼' => 'դրոշ․ Մալավի',
    '🇲🇽' => 'դրոշ․ Մեքսիկա',
    '🇲🇾' => 'դրոշ․ Մալայզիա',
    '🇲🇿' => 'դրոշ․ Մոզամբիկ',
    '🇳🇦' => 'դրոշ․ Նամիբիա',
    '🇳🇨' => 'դրոշ․ Նոր Կալեդոնիա',
    '🇳🇪' => 'դրոշ․ Նիգեր',
    '🇳🇫' => 'դրոշ․ Նորֆոլկ կղզի',
    '🇳🇬' => 'դրոշ․ Նիգերիա',
    '🇳🇮' => 'դրոշ․ Նիկարագուա',
    '🇳🇱' => 'դրոշ․ Նիդեռլանդներ',
    '🇳🇴' => 'դրոշ․ Նորվեգիա',
    '🇳🇵' => 'դրոշ․ Նեպալ',
    '🇳🇷' => 'դրոշ․ Նաուրու',
    '🇳🇺' => 'դրոշ․ Նիուե',
    '🇳🇿' => 'դրոշ․ Նոր Զելանդիա',
    '🇴🇲' => 'դրոշ․ Օման',
    '🇵🇦' => 'դրոշ․ Պանամա',
    '🇵🇪' => 'դրոշ․ Պերու',
    '🇵🇫' => 'դրոշ․ Ֆրանսիական Պոլինեզիա',
    '🇵🇬' => 'դրոշ․ Պապուա Նոր Գվինեա',
    '🇵🇭' => 'դրոշ․ Ֆիլիպիններ',
    '🇵🇰' => 'դրոշ․ Պակիստան',
    '🇵🇱' => 'դրոշ․ Լեհաստան',
    '🇵🇲' => 'դրոշ․ Սեն Պիեռ և Միքելոն',
    '🇵🇳' => 'դրոշ․ Պիտկեռն կղզիներ',
    '🇵🇷' => 'դրոշ․ Պուերտո Ռիկո',
    '🇵🇸' => 'դրոշ․ Պաղեստինյան տարածքներ',
    '🇵🇹' => 'դրոշ․ Պորտուգալիա',
    '🇵🇼' => 'դրոշ․ Պալաու',
    '🇵🇾' => 'դրոշ․ Պարագվայ',
    '🇶🇦' => 'դրոշ․ Կատար',
    '🇷🇪' => 'դրոշ․ Ռեյունիոն',
    '🇷🇴' => 'դրոշ․ Ռումինիա',
    '🇷🇸' => 'դրոշ․ Սերբիա',
    '🇷🇺' => 'դրոշ․ Ռուսաստան',
    '🇷🇼' => 'դրոշ․ Ռուանդա',
    '🇸🇦' => 'դրոշ․ Սաուդյան Արաբիա',
    '🇸🇧' => 'դրոշ․ Սողոմոնյան կղզիներ',
    '🇸🇨' => 'դրոշ․ Սեյշելներ',
    '🇸🇩' => 'դրոշ․ Սուդան',
    '🇸🇪' => 'դրոշ․ Շվեդիա',
    '🇸🇬' => 'դրոշ․ Սինգապուր',
    '🇸🇭' => 'դրոշ․ Սուրբ Հեղինեի կղզի',
    '🇸🇮' => 'դրոշ․ Սլովենիա',
    '🇸🇯' => 'դրոշ․ Սվալբարդ և Յան Մայեն',
    '🇸🇰' => 'դրոշ․ Սլովակիա',
    '🇸🇱' => 'դրոշ․ Սիեռա Լեոնե',
    '🇸🇲' => 'դրոշ․ Սան Մարինո',
    '🇸🇳' => 'դրոշ․ Սենեգալ',
    '🇸🇴' => 'դրոշ․ Սոմալի',
    '🇸🇷' => 'դրոշ․ Սուրինամ',
    '🇸🇸' => 'դրոշ․ Հարավային Սուդան',
    '🇸🇹' => 'դրոշ․ Սան Տոմե և Փրինսիպի',
    '🇸🇻' => 'դրոշ․ Սալվադոր',
    '🇸🇽' => 'դրոշ․ Սինտ Մարտեն',
    '🇸🇾' => 'դրոշ․ Սիրիա',
    '🇸🇿' => 'դրոշ․ Էսվատինի',
    '🇹🇦' => 'դրոշ․ Տրիստան դա Կունյա',
    '🇹🇨' => 'դրոշ․ Թըրքս և Կայկոս կղզիներ',
    '🇹🇩' => 'դրոշ․ Չադ',
    '🇹🇫' => 'դրոշ․ Ֆրանսիական Հարավային Տարածքներ',
    '🇹🇬' => 'դրոշ․ Տոգո',
    '🇹🇭' => 'դրոշ․ Թաիլանդ',
    '🇹🇯' => 'դրոշ․ Տաջիկստան',
    '🇹🇰' => 'դրոշ․ Տոկելաու',
    '🇹🇱' => 'դրոշ․ Թիմոր Լեշտի',
    '🇹🇲' => 'դրոշ․ Թուրքմենստան',
    '🇹🇳' => 'դրոշ․ Թունիս',
    '🇹🇴' => 'դրոշ․ Տոնգա',
    '🇹🇷' => 'դրոշ․ Թուրքիա',
    '🇹🇹' => 'դրոշ․ Տրինիդադ և Տոբագո',
    '🇹🇻' => 'դրոշ․ Տուվալու',
    '🇹🇼' => 'դրոշ․ Թայվան',
    '🇹🇿' => 'դրոշ․ Տանզանիա',
    '🇺🇦' => 'դրոշ․ Ուկրաինա',
    '🇺🇬' => 'դրոշ․ Ուգանդա',
    '🇺🇲' => 'դրոշ․ Արտաքին կղզիներ (ԱՄՆ)',
    '🇺🇳' => 'դրոշ․ Միավորված ազգերի կազմակերպություն',
    '🇺🇸' => 'դրոշ․ Միացյալ Նահանգներ',
    '🇺🇾' => 'դրոշ․ Ուրուգվայ',
    '🇺🇿' => 'դրոշ․ Ուզբեկստան',
    '🇻🇦' => 'դրոշ․ Վատիկան',
    '🇻🇨' => 'դրոշ․ Սենթ Վինսենթ և Գրենադիններ',
    '🇻🇪' => 'դրոշ․ Վենեսուելա',
    '🇻🇬' => 'դրոշ․ Բրիտանական Վիրջինյան կղզիներ',
    '🇻🇮' => 'դրոշ․ ԱՄՆ Վիրջինյան կղզիներ',
    '🇻🇳' => 'դրոշ․ Վիետնամ',
    '🇻🇺' => 'դրոշ․ Վանուատու',
    '🇼🇫' => 'դրոշ․ Ուոլիս և Ֆուտունա',
    '🇼🇸' => 'դրոշ․ Սամոա',
    '🇽🇰' => 'դրոշ․ Կոսովո',
    '🇾🇪' => 'դրոշ․ Եմեն',
    '🇾🇹' => 'դրոշ․ Մայոտ',
    '🇿🇦' => 'դրոշ․ Հարավաֆրիկյան Հանրապետություն',
    '🇿🇲' => 'դրոշ․ Զամբիա',
    '🇿🇼' => 'դրոշ․ Զիմբաբվե',
    '🔟' => 'ստեղն․ 10',
    '🏻' => 'բաց գույնի մաշկ',
    '🏼' => 'միջին բաց գույնի մաշկ',
    '🏽' => 'միջին գույնի մաշկ',
    '🏾' => 'միջին մուգ գույնի մաշկ',
    '🏿' => 'մուգ գույնի մաշկ',
    '😀' => 'ծիծաղող դեմք',
    '😃' => 'ժպտացող դեմք բաց բերանով',
    '😄' => 'ժպտացող աչքերով լայն ժպիտով դեմք',
    '😁' => 'ծիծաղող դեմք ժպտացող աչքերով',
    '😆' => 'աչքերը կկոցած լայն ժպիտով դեմք',
    '😅' => 'սառը քրտինքով լայն ժպիտով դեմք',
    '🤣' => 'ծիծաղից գլորվում է',
    '😂' => 'դեմք ուրախության արցունքներով',
    '🙂' => 'թեթևակի ժպտացող դեմք',
    '🙃' => 'գլխիվայր դեմք',
    '🫠' => 'հալչող դեմք',
    '😉' => 'աչքով անող դեմք',
    '😊' => 'ժպտացող դեմք ժպտացող աչքերով',
    '😇' => 'ժպտացող դեմք լուսապսակով',
    '🥰' => 'ժպտացող դեմք սրտիկներով',
    '😍' => 'ժպտացող դեմք սրտաձև աչքերով',
    '🤩' => 'աչքերում աստղեր',
    '😘' => 'համբույր ուղարկող դեմք',
    '😗' => 'համբուրող դեմք',
    '☺' => 'ժպտացող դեմք',
    '😚' => 'համբուրող դեմք փակ աչքերով',
    '😙' => 'համբուրող դեմք ժպտացող աչքերով',
    '🥲' => 'արցունքով ժպտացող դեմք',
    '😋' => 'համեղ ուտելիք վայելող դեմք',
    '😛' => 'լեզուն հանած դեմք',
    '😜' => 'լեզուն հանած և աչքով անող դեմք',
    '🤪' => 'խենթ դեմք',
    '😝' => 'լեզուն հանած և աչքերն ամուր փակած դեմք',
    '🤑' => 'թղթադրամը բերանին դեմք',
    '🤗' => 'գրկող դեմք',
    '🤭' => 'ձեռքը բերանին դեմք',
    '🫢' => 'բաց աչքերով դեմք եւ ձեռքով՝ բերանի վրա',
    '🫣' => 'ծկրակող աչքով դեմք',
    '🤫' => '«սուս» անող դեմք',
    '🤔' => 'մտածող դեմք',
    '🫡' => 'ողջունող դեմք',
    '🤐' => 'ճարմանդավոր բերանով դեմք',
    '🤨' => 'բարձրացրած հոնքով դեմք',
    '😐' => 'չեզոք դեմք',
    '😑' => 'անհույզ դեմք',
    '😶' => 'առանց բերանի դեմք',
    '🫥' => 'կետագծված դեմք',
    '😏' => 'կեղծ ժպտացող դեմք',
    '😒' => 'անտրամադիր դեմք',
    '🙄' => 'պտտվող աչքերով դեմք',
    '😬' => 'ծամածռվող դեմք',
    '🤥' => 'խաբող դեմք',
    '🫨' => 'ցնցվող դեմք',
    '😌' => 'թեթևացած դեմք',
    '😔' => 'մտածկոտ դեմք',
    '😪' => 'քնատ դեմք',
    '🤤' => 'փսլնքոտ դեմք',
    '😴' => 'քնած դեմք',
    '🫩' => 'աչքերի տակ պարկերով դեմք',
    '😷' => 'բժշկական դիմակով դեմք',
    '🤒' => 'ջերմաչափով դեմք',
    '🤕' => 'գլխակապով դեմք',
    '🤢' => 'սրտխառնոցով դեմք',
    '🤮' => 'փսխող դեմք',
    '🤧' => 'փռշտացող դեմք',
    '🥵' => 'շոգած դեմք',
    '🥶' => 'մրսած դեմք',
    '🥴' => 'թմրած դեմք',
    '😵' => 'գլխապտույտով դեմք',
    '🤯' => 'պայթող գլուխ',
    '🤠' => 'կովբոյի դեմք',
    '🥳' => 'խնջույքավոր դեմք',
    '🥸' => 'դիմակով դեմք',
    '😎' => 'ժպտացող դեմք արևային ակնոցով',
    '🤓' => 'խելոքի դեմք',
    '🧐' => 'մոնոկլով դեմք',
    '😕' => 'շփոթված դեմք',
    '🫤' => 'անկյունագծային բերանով դեմք',
    '😟' => 'մտահոգ դեմք',
    '🙁' => 'թեթևակի խոժոռված դեմք',
    '☹' => 'խոժոռված դեմք',
    '😮' => 'բաց բերանով դեմք',
    '😯' => 'սաստված դեմք',
    '😲' => 'ապշահար դեմք',
    '😳' => 'շիկնած դեմք',
    '🫪' => 'այլայլված դեմք',
    '🥺' => 'աղաչող դեմք',
    '🥹' => 'արցունքը զսպած դեմք',
    '😦' => 'բաց բերանով խոժոռված դեմք',
    '😧' => 'վշտահար դեմք',
    '😨' => 'վախեցած դեմք',
    '😰' => 'բաց բերանով և սառը քրտինքով դեմք',
    '😥' => 'տխուր, բայց թեթևացած դեմք',
    '😢' => 'արտասվող դեմք',
    '😭' => 'բարձրաձայն արտասվող դեմք',
    '😱' => 'վախից գոռացող դեմք',
    '😖' => 'ցնցված դեմք',
    '😣' => 'համառող դեմք',
    '😞' => 'հիասթափված դեմք',
    '😓' => 'սառը քրտինքով դեմք',
    '😩' => 'ուժասպառ դեմք',
    '😫' => 'հոգնած դեմք',
    '🥱' => 'հորանջող դեմք',
    '😤' => 'քթից գոլորշի հանող դեմք',
    '😡' => 'դժգոհ դեմք',
    '😠' => 'բարկացած դեմք',
    '🤬' => 'բերանի վրա նշանով դեմք',
    '😈' => 'ժպտացող դեմք եղջյուրներով',
    '👿' => 'զայրացած դեմք՝ պոզերով',
    '💀' => 'գանգ',
    '☠' => 'գանգ և խաչված ոսկորներ',
    '💩' => 'կեղտի կույտ',
    '🤡' => 'ծաղրածուի դեմք',
    '👹' => 'մարդակեր հսկա',
    '👺' => 'չար ոգի',
    '👻' => 'ուրվական',
    '👽' => 'այլմոլորակային',
    '👾' => 'այլմոլորակային հրեշ',
    '🤖' => 'ռոբոտ',
    '😺' => 'քմծիծաղող կատու',
    '😸' => 'քմծիծաղող կատու ժպտացող աչքերով',
    '😹' => 'ուրախության արցունքներով կատու',
    '😻' => 'ժպտացող կատվի դեմք սրտաձև աչքերով',
    '😼' => 'ծուռ ժպիտով կատու',
    '😽' => 'համբուրող կատու',
    '🙀' => 'հոգնած կատու',
    '😿' => 'լացող կատու',
    '😾' => 'դժգոհող կատու',
    '🙈' => 'չարություն չտեսնող կապիկ',
    '🙉' => 'չարություն չլսող կապիկ',
    '🙊' => 'չարություն չասող կապիկ',
    '💌' => 'սիրային նամակ',
    '💘' => 'նետահարված սիրտ',
    '💝' => 'ժապավենով սիրտ',
    '💖' => 'շողշողացող սիրտ',
    '💗' => 'աճող սիրտ',
    '💓' => 'բաբախող սիրտ',
    '💞' => 'պտտվող սրտեր',
    '💕' => 'երկու սիրտ',
    '💟' => 'սրտաձև նախշ',
    '❣' => 'սիրտ-բացականչություն',
    '💔' => 'կոտրված սիրտ',
    '❤' => 'կարմիր սիրտ',
    '🩷' => 'վարդագույն սիրտ',
    '🧡' => 'նարնջագույն սիրտ',
    '💛' => 'դեղին սիրտ',
    '💚' => 'կանաչ սիրտ',
    '💙' => 'կապույտ սիրտ',
    '🩵' => 'բաց կապույտ սիրտ',
    '💜' => 'մանուշակագույն սիրտ',
    '🤎' => 'դարչնագույն սիրտ',
    '🖤' => 'սև սիրտ',
    '🩶' => 'մոխրագույն սիրտ',
    '🤍' => 'սպիտակ սիրտ',
    '💋' => 'համբույրի հետք',
    '💯' => 'հարյուր միավոր',
    '💢' => 'զայրույթի նշան',
    '🫯' => 'կռվի ամպ',
    '💥' => 'բախում',
    '💫' => 'գլխապտույտ',
    '💦' => 'քրտինքի կաթիլներ',
    '💨' => 'սրընթաց փախուստ',
    '🕳' => 'անցք',
    '💬' => 'խոսքի ամպիկ',
    '🗨' => 'խոսքի ձախակողմյա ամպիկ',
    '🗯' => 'զայրույթի աջակողմյա ամպիկ',
    '💭' => 'մտքի ամպիկ',
    '💤' => 'խռռռ',
    '👋' => 'թափահարող ձեռք',
    '🤚' => 'ձեռքի բարձրացրած ափ',
    '🖐' => 'բացված մատներով բարձրացված ձեռք',
    '✋' => 'բարձրացված ձեռք',
    '🖖' => 'վուլկանցիների ողջույն',
    '🫱' => 'աջակողմ ձեռք',
    '🫲' => 'ձախակողմ ձեռք',
    '🫳' => 'ձեռքը ափով ներքև',
    '🫴' => 'ափը՝ վեր ձեռք',
    '🫷' => 'դեպի ձախ հրող ձեռք',
    '🫸' => 'դեպի աջ հրող ձեռք',
    '👌' => 'ok ցույց տվող ձեռք',
    '🤌' => 'պտղունց',
    '🤏' => 'պտղունց ցույց տվող ձեռք',
    '✌' => 'հաղթական ձեռք',
    '🤞' => 'խաչած մատներ',
    '🫰' => 'ցուցամատը եւ բութը խաչած ձեռք',
    '🤟' => '«սիրում եմ քեզ» նշան',
    '🤘' => 'եղջյուրների նշան',
    '🤙' => 'զանգիր ինձ',
    '👈' => 'դեպի ձախ ուղղված ցուցամատ',
    '👉' => 'դեպի աջ ուղղված ցուցամատ',
    '👆' => 'դեպի վեր ուղղված ցուցամատ',
    '🖕' => 'միջնամատ',
    '👇' => 'դեպի վար ուղղված ցուցամատ',
    '☝' => 'վեր ուղղված ցուցամատ',
    '🫵' => 'դիտողին ուղղված ցուցամատ',
    '👍' => 'բութ մատը վեր',
    '👎' => 'բութ մատը ներքև',
    '✊' => 'բարձրացված բռունցք',
    '👊' => 'հանդիպակաց բռունցք',
    '🤛' => 'բռունցքը ձախ',
    '🤜' => 'բռունցքը աջ',
    '👏' => 'ծափահարող ձեռքեր',
    '🙌' => 'բարձրացրած ձեռքեր',
    '🫶' => 'սիրտ-ձեռքեր',
    '👐' => 'բաց ձեռքեր',
    '🤲' => 'ձեռքերի ափերը վեր',
    '🤝' => 'ձեռքսեղմում',
    '🙏' => 'ձեռքերի ափերը միացված',
    '✍' => 'գրող ձեռք',
    '💅' => 'եղունգների լաքապատում',
    '🤳' => 'սելֆի',
    '💪' => 'ձգված բիցեպս',
    '🦾' => 'մեխանիկական ձեռք',
    '🦿' => 'մեխանիկական ոտք',
    '🦵' => 'ոտք',
    '🦶' => 'ոտնաթաթ',
    '👂' => 'ականջ',
    '🦻' => 'լսողական սարքով ականջ',
    '👃' => 'քիթ',
    '🧠' => 'ուղեղ',
    '🫀' => 'կազմաբանական սիրտ',
    '🫁' => 'թոքեր',
    '🦷' => 'ատամ',
    '🦴' => 'ոսկոր',
    '👀' => 'աչքեր',
    '👁' => 'աչք',
    '👅' => 'լեզու',
    '👄' => 'բերան',
    '🫦' => 'շուրթ կծել',
    '👶' => 'մանուկ',
    '🧒' => 'երեխա',
    '👦' => 'տղա',
    '👧' => 'աղջիկ',
    '🧑' => 'անձ',
    '👱' => 'անձ․ շիկահեր',
    '👨' => 'մարդ',
    '🧔' => 'անձ․ մորուք',
    '👩' => 'կին',
    '🧓' => 'տարեց անձ',
    '👴' => 'տարեց մարդ',
    '👵' => 'տարեց կին',
    '🙍' => 'խոժոռված դեմքով անձ',
    '🙎' => 'դժգոհ անձ',
    '🙅' => 'ՈՉ ակնարկող անձ',
    '🙆' => 'ok ցույց տվող',
    '💁' => 'ձեռքը թեքած անձ',
    '🙋' => 'ձեռքը բարձրացրած անձ',
    '🧏' => 'խուլ անձ',
    '🙇' => 'խոնարհվող անձ',
    '🤦' => 'դեմքն ափով ծածկած անձ',
    '🤷' => 'ուսերը թոթվող անձ',
    '👮' => 'ոստիկան',
    '🕵' => 'խուզարկու',
    '💂' => 'պահակազորային',
    '🥷' => 'նինջա',
    '👷' => 'շինարար',
    '🫅' => 'թագով հանձ',
    '🤴' => 'արքայազն',
    '👸' => 'արքայադուստր',
    '👳' => 'թյուրբանով անձ',
    '👲' => 'թասակով անձ',
    '🧕' => 'գլխաշորով կին',
    '🤵' => 'սմոկինգով մարդ',
    '👰' => 'քողով անձ',
    '🤰' => 'հղի կին',
    '🫃' => 'հղի տիկին',
    '🫄' => 'հղի անձ',
    '🤱' => 'կրծքով կերակրում',
    '👼' => 'մանուկ-հրեշտակ',
    '🎅' => 'Սանտա Կլաուս',
    '🤶' => 'Ձմեռ տատ',
    '🦸' => 'սուպերհերոս',
    '🦹' => 'սուպերչարագործ',
    '🧙' => 'մոգ',
    '🧚' => 'փերի',
    '🧛' => 'վամպիր',
    '🧜' => 'մարդաձուկ',
    '🧝' => 'էլֆ',
    '🧞' => 'ջին',
    '🧟' => 'զոմբի',
    '🧌' => 'տրոլլ',
    '🫈' => 'մազոտ արարած',
    '💆' => 'մերսվող անձ',
    '💇' => 'մազերը կտրող անձ',
    '🚶' => 'հետիոտն',
    '🧍' => 'կանգնած անձ',
    '🧎' => 'ծնկաչոք անձ',
    '🏃' => 'վազող անձ',
    '💃' => 'պարուհի',
    '🕺' => 'պարող մարդ',
    '🕴' => 'կոստյումով ճախրող մարդ',
    '👯' => 'ճագարի ականջներով մարդիկ',
    '🧖' => 'մարդ բաղնիքում',
    '🧗' => 'մագլցող անձ',
    '🤺' => 'սուսերամարտիկ',
    '🏇' => 'ձիարշավ',
    '⛷' => 'դահուկորդ',
    '🏂' => 'սնոուբորդիստ',
    '🏌' => 'գոլֆ խաղացող',
    '🏄' => 'սերֆեր',
    '🚣' => 'նավակ թիավարող անձ',
    '🏊' => 'լողորդ',
    '⛹' => 'գնդակով մարդ',
    '🏋' => 'ծանրորդ',
    '🚴' => 'հեծանվորդ',
    '🚵' => 'լեռնահեծանվորդ',
    '🤸' => 'ձեռնակոնծի կատարող անձ',
    '🤼' => 'ըմբշամարտիկներ',
    '🤽' => 'ջրագնդակ խաղացող անձ',
    '🤾' => 'ձեռնագնդակ խաղացող անձ',
    '🤹' => 'ձեռնածու',
    '🧘' => 'լոտոսի դիրքով նստած մարդ',
    '🛀' => 'լոգանք ընդունող անձ',
    '🛌' => 'մահճակալին պառկած անձ',
    '👭' => 'իրար ձեռք բռնած կանայք',
    '👫' => 'իրար ձեռք բռնած կին ու տղամարդ',
    '👬' => 'իրար ձեռք բռնած տղամարդիկ',
    '💏' => 'համբույր',
    '💑' => 'սրտիկով զույգ',
    '🗣' => 'խոսացող գլուխ',
    '👤' => 'ուրվագծված կիսանդրի',
    '👥' => 'ուրվագծված կիսանդրիներ',
    '🫂' => 'գրկախառնվող մարդիկ',
    '👪' => 'ընտանիք',
    '👣' => 'ոտնահետքեր',
    '🫆' => 'մատնահետք',
    '🦰' => 'կարմրահեր',
    '🦱' => 'գանգրահեր',
    '🦳' => 'սպիտակահեր',
    '🦲' => 'ճաղատ',
    '🐵' => 'կապիկի դեմք',
    '🐒' => 'կապիկ',
    '🦍' => 'գորիլա',
    '🦧' => 'օրանգուտան',
    '🐶' => 'շան մռութ',
    '🐕' => 'շուն',
    '🦮' => 'ուղեկցող շուն',
    '🐩' => 'պուդել',
    '🐺' => 'գայլ',
    '🦊' => 'աղվես',
    '🦝' => 'ջրարջ',
    '🐱' => 'կատվի մռութ',
    '🐈' => 'կատու',
    '🦁' => 'առյուծի մռութ',
    '🐯' => 'վագրի մռութ',
    '🐅' => 'վագր',
    '🐆' => 'ընձառյուծ',
    '🐴' => 'ձիու մռութ',
    '🫎' => 'որմզդեղն',
    '🫏' => 'էշ',
    '🐎' => 'ձի',
    '🦄' => 'միաեղջյուր',
    '🦓' => 'զեբր',
    '🦌' => 'եղնիկ',
    '🦬' => 'բիզոն',
    '🐮' => 'կովի մռութ',
    '🐂' => 'ցուլիկ',
    '🐃' => 'ջրագոմեշ',
    '🐄' => 'կով',
    '🐷' => 'խոզի մռութ',
    '🐖' => 'խոզ',
    '🐗' => 'վարազ',
    '🐽' => 'խոզի դունչ',
    '🐏' => 'արու ոչխար',
    '🐑' => 'մաքի',
    '🐐' => 'այծ',
    '🐪' => 'ուղտ',
    '🐫' => 'երկսապատավոր ուղտ',
    '🦙' => 'լամա',
    '🦒' => 'ընձուղտ',
    '🐘' => 'փիղ',
    '🦣' => 'մամոնտ',
    '🦏' => 'ռնգեղջյուր',
    '🦛' => 'գետաձի',
    '🐭' => 'մկան մռութ',
    '🐁' => 'մուկ',
    '🐀' => 'առնետ',
    '🐹' => 'գերմանամուկ',
    '🐰' => 'ճագարի մռութ',
    '🐇' => 'ճագար',
    '🐿' => 'շերտասկյուռ',
    '🦫' => 'կուղբ',
    '🦔' => 'ոզնի',
    '🦇' => 'չղջիկ',
    '🐻' => 'արջ',
    '🐨' => 'կոալա',
    '🐼' => 'պանդա',
    '🦥' => 'համրուկ',
    '🦦' => 'ջրասամույր',
    '🦨' => 'ժանտաքիս',
    '🦘' => 'ագեվազ',
    '🦡' => 'փորսուղ',
    '🐾' => 'թաթերի հետքեր',
    '🦃' => 'հնդկահավ',
    '🐔' => 'հավ',
    '🐓' => 'աքաղաղ',
    '🐣' => 'ձվից դուրս եկող ճուտիկ',
    '🐤' => 'ճուտիկ',
    '🐥' => 'դեմքով շրջված ճուտիկ',
    '🐦' => 'թռչուն',
    '🐧' => 'պինգվին',
    '🕊' => 'աղավնի',
    '🦅' => 'արծիվ',
    '🦆' => 'բադ',
    '🦢' => 'կարապ',
    '🦉' => 'բու',
    '🦤' => 'դոդո',
    '🪶' => 'փետուր',
    '🦩' => 'ֆլամինգո',
    '🦚' => 'սիրամարգ',
    '🦜' => 'թութակ',
    '🪽' => 'թև',
    '🪿' => 'սագ',
    '🐸' => 'գորտ',
    '🐊' => 'կոկորդիլոս',
    '🐢' => 'կրիա',
    '🦎' => 'մողես',
    '🐍' => 'օձ',
    '🐲' => 'վիշապի մռութ',
    '🐉' => 'վիշապ',
    '🦕' => 'զավրոպոդ',
    '🦖' => 'տիրանոզավր ռեքս',
    '🐳' => 'ջուր ցայտեցնող կետաձուկ',
    '🐋' => 'կետ',
    '🐬' => 'դելֆին',
    '🫍' => 'խոյադելֆին',
    '🦭' => 'փոկ',
    '🐟' => 'ձուկ',
    '🐠' => 'արևադարձային ձուկ',
    '🐡' => 'փքաձուկ',
    '🦈' => 'շնաձուկ',
    '🐙' => 'ութոտնուկ',
    '🐚' => 'պարուրաձև խխունջախեցի',
    '🪸' => 'բուստ',
    '🪼' => 'ծովամայր',
    '🦀' => 'խաչափառ',
    '🦞' => 'օմար',
    '🦐' => 'ծովախեցգետին',
    '🦑' => 'կաղամար',
    '🦪' => 'ոստրե',
    '🐌' => 'խխունջ',
    '🦋' => 'թիթեռ',
    '🐛' => 'միջատ',
    '🐜' => 'մրջյուն',
    '🐝' => 'մեղու',
    '🪲' => 'բզեզ',
    '🐞' => 'զատիկ',
    '🦗' => 'ծղրիդ',
    '🪳' => 'ուտիճ',
    '🕷' => 'սարդ',
    '🕸' => 'սարդոստայն',
    '🦂' => 'շագանակագույն կարիճ',
    '🦟' => 'մոծակ',
    '🪰' => 'ճանճ',
    '🪱' => 'որդ',
    '🦠' => 'մանրէ',
    '💐' => 'ծաղկեփունջ',
    '🌸' => 'բալենու ծաղիկ',
    '💮' => 'սպիտակ ծաղիկ',
    '🪷' => 'լոտոս',
    '🏵' => 'վարդանախշ',
    '🌹' => 'վարդ',
    '🥀' => 'թառամած ծաղիկ',
    '🌺' => 'բաղրջուկ',
    '🌻' => 'արևածաղիկ',
    '🌼' => 'ծաղիկ',
    '🌷' => 'կակաչ',
    '🪻' => 'հակինթ',
    '🌱' => 'ծիլ',
    '🪴' => 'թաղարով բույս',
    '🌲' => 'եղևնի',
    '🌳' => 'սաղարթավոր ծառ',
    '🌴' => 'արմավենի',
    '🌵' => 'կակտուս',
    '🌾' => 'բրնձի հասկեր',
    '🌿' => 'բույս',
    '☘' => 'երեքնուկ',
    '🍀' => 'քառատերև երեքնուկ',
    '🍁' => 'թխկու տերև',
    '🍂' => 'ընկած տերև',
    '🍃' => 'ճախրող տերևներ',
    '🪹' => 'դատարկ բույն',
    '🪺' => 'ձվերով բույն',
    '🍄' => 'սունկ',
    '🪾' => 'անտերեւ ծառ',
    '🍇' => 'խաղող',
    '🍈' => 'սեխ',
    '🍉' => 'ձմերուկ',
    '🍊' => 'մանդարին',
    '🍋' => 'կիտրոն',
    '🍌' => 'բանան',
    '🍍' => 'արքայախնձոր',
    '🥭' => 'մանգո',
    '🍎' => 'կարմիր խնձոր',
    '🍏' => 'կանաչ խնձոր',
    '🍐' => 'տանձ',
    '🍑' => 'դեղձ',
    '🍒' => 'բալ',
    '🍓' => 'ելակ',
    '🫐' => 'հապալաս',
    '🥝' => 'կիվի',
    '🍅' => 'լոլիկ',
    '🫒' => 'ձիթապտուղ',
    '🥥' => 'կոկոս',
    '🥑' => 'ավոկադո',
    '🍆' => 'սմբուկ',
    '🥔' => 'կարտոֆիլ',
    '🥕' => 'գազար',
    '🌽' => 'եգիպտացորեն',
    '🌶' => 'կծու պղպեղ',
    '🫑' => 'տաքդեղ',
    '🥒' => 'վարունգ',
    '🥬' => 'հազար',
    '🥦' => 'բրոկկոլի',
    '🧄' => 'սխտոր',
    '🧅' => 'սոխ',
    '🥜' => 'գետնանուշ',
    '🫘' => 'լոբի',
    '🌰' => 'շագանակ',
    '🫚' => 'կոճապղպեղի արմատ',
    '🫛' => 'սիսեռապատիճ',
    '🫜' => 'արմատապտուղ',
    '🍞' => 'հաց',
    '🥐' => 'կրուասան',
    '🥖' => 'բագետ հաց',
    '🫓' => 'լոշիկ',
    '🥨' => 'ոլորաբլիթ',
    '🥯' => 'բեյգլ',
    '🥞' => 'ձիթաբլիթ',
    '🧇' => 'վաֆլի',
    '🧀' => 'պանրի կտոր',
    '🍖' => 'ոսկորով միս',
    '🍗' => 'հավի բուդ',
    '🥩' => 'մսի կտոր',
    '🥓' => 'բեկոն',
    '🍔' => 'համբուրգեր',
    '🍟' => 'տապակած կարտոֆիլ',
    '🍕' => 'պիցցա',
    '🌭' => 'հոթդոգ',
    '🥪' => 'սենդվիչ',
    '🌮' => 'տակո',
    '🌯' => 'բուրիտո',
    '🫔' => 'տամալե',
    '🥙' => 'լցոնված լոշիկ',
    '🧆' => 'ֆալաֆել',
    '🥚' => 'ձու',
    '🍳' => 'եփում',
    '🥘' => 'տապակ',
    '🍲' => 'թասով ճաշ',
    '🫕' => 'ֆոնդյու',
    '🥣' => 'գդալով աման',
    '🥗' => 'աղցան',
    '🍿' => 'ադիբուդի',
    '🧈' => 'կարագ',
    '🧂' => 'աղ',
    '🥫' => 'պահածո',
    '🍱' => 'բենտո արկղ',
    '🍘' => 'բրնձի կրեկեր',
    '🍙' => 'բրնձի գնդիկ',
    '🍚' => 'եփած բրինձ',
    '🍛' => 'քարրիով բրինձ',
    '🍜' => 'տաք ապուր',
    '🍝' => 'սպագետի',
    '🍠' => 'բոված քաղցր կարտոֆիլ',
    '🍢' => 'օդեն',
    '🍣' => 'սուշի',
    '🍤' => 'տապակած ծովախեցգետին',
    '🍥' => 'ձկնային տորթ պտտանախշով',
    '🥮' => 'լուսնային թխվածք',
    '🍡' => 'դանգո',
    '🥟' => 'լցոնվածքներ',
    '🥠' => 'գուշակությունով բլիթ',
    '🥡' => 'դուրս հանելու տուփ',
    '🍦' => 'լցնովի պաղպաղակ',
    '🍧' => 'մանրացված սառույց',
    '🍨' => 'պաղպաղակ',
    '🍩' => 'դոնաթ',
    '🍪' => 'թխվածքաբլիթ',
    '🎂' => 'ծննդյան տորթ',
    '🍰' => 'տորթի կտոր',
    '🧁' => 'կեքս',
    '🥧' => 'կարկանդակ',
    '🍫' => 'շոկոլադե սալիկ',
    '🍬' => 'կոնֆետ',
    '🍭' => 'սառնաշաքար',
    '🍮' => 'պուդինգ',
    '🍯' => 'մեղրի կճուճ',
    '🍼' => 'մանկական շիշ',
    '🥛' => 'կաթով բաժակ',
    '☕' => 'տաք ըմպելիք',
    '🫖' => 'թեյնիկ',
    '🍵' => 'թեյի բաժակ առանց բռնակի',
    '🍶' => 'սակե',
    '🍾' => 'թռչող խցանով շիշ',
    '🍷' => 'գինու բաժակ',
    '🍸' => 'կոկտեյլի բաժակ',
    '🍹' => 'արևադարձային ընպելիք',
    '🍺' => 'գարեջրի գավաթ',
    '🍻' => 'զրնգացող գարեջրի գավաթներ',
    '🥂' => 'զնգացող բաժակներ',
    '🥃' => 'խոշոր բաժակ',
    '🫗' => 'հեղուկի լցում',
    '🥤' => 'ձողիկով բաժակ',
    '🧋' => 'պղպջակներով թեյ',
    '🧃' => 'խմիչքի տուփ',
    '🧉' => 'մատե',
    '🧊' => 'սառույց',
    '🥢' => 'փայտիկներ',
    '🍽' => 'պատառաքաղ և դանակ ափսեի հետ',
    '🍴' => 'պատառաքաղ և դանակ',
    '🥄' => 'գդալ',
    '🔪' => 'խոհանոցային դանակ',
    '🫙' => 'ապիկ',
    '🏺' => 'սափոր',
    '🌍' => 'Եվրոպան և Աֆրիկան պատկերող գլոբուս',
    '🌎' => 'Ամերիկաները պատկերող գլոբուս',
    '🌏' => 'Ասիան և Ավստրալիան պատկերող գլոբուս',
    '🌐' => 'միջօրեականներով գլոբուս',
    '🗺' => 'աշխարհի քարտեզ',
    '🗾' => 'Ճապոնիայի քարտեզը',
    '🧭' => 'կողմնացույց',
    '🏔' => 'ձյունածածկ գագաթով լեռ',
    '⛰' => 'լեռ',
    '🛘' => 'սողանք',
    '🌋' => 'հրաբուխ',
    '🗻' => 'Ֆուջի լեռ',
    '🏕' => 'ճամբար',
    '🏖' => 'լողափ հովանոցով',
    '🏜' => 'անապատ',
    '🏝' => 'անմարդաբնակ կղզի',
    '🏞' => 'ազգային զբոսայգի',
    '🏟' => 'մարզադաշտ',
    '🏛' => 'հունահռոմեական շինություն',
    '🏗' => 'շենքի կառուցում',
    '🧱' => 'աղյուս',
    '🪨' => 'քար',
    '🪵' => 'փայտ',
    '🛖' => 'հյուղակ',
    '🏘' => 'տներ',
    '🏚' => 'լքված շինություն',
    '🏠' => 'տուն',
    '🏡' => 'այգիով տուն',
    '🏢' => 'գրասենյակային շենք',
    '🏣' => 'ճապոնական փոստատուն',
    '🏤' => 'փոստատուն',
    '🏥' => 'հիվանդանոց',
    '🏦' => 'բանկ',
    '🏨' => 'հյուրանոց',
    '🏩' => 'սիրային հյուրանոց',
    '🏪' => 'շուրջօրյա խանութ',
    '🏫' => 'դպրոց',
    '🏬' => 'հանրախանութ',
    '🏭' => 'գործարան',
    '🏯' => 'ճապոնական դղյակ',
    '🏰' => 'դղյակ',
    '💒' => 'հարսանիք',
    '🗼' => 'Տոկիոյի աշտարակ',
    '🗽' => 'ազատության արձանը',
    '⛪' => 'եկեղեցի',
    '🕌' => 'մզկիթ',
    '🛕' => 'հինդուիստական տաճար',
    '🕍' => 'սինագոգ',
    '⛩' => 'սինտոյական տաճար',
    '🕋' => 'կաաբա',
    '⛲' => 'շատրվան',
    '⛺' => 'վրան',
    '🌁' => 'մառախլապատ',
    '🌃' => 'աստղազարդ գիշեր',
    '🏙' => 'քաղաքային պատկեր',
    '🌄' => 'արևածագը լեռներում',
    '🌅' => 'արևածագ',
    '🌆' => 'քաղաքային պատկեր մթնշաղին',
    '🌇' => 'մայրամուտ',
    '🌉' => 'կամուրջը գիշերով',
    '♨' => 'տաք աղբյուրներ',
    '🎠' => 'կարուսելի ձի',
    '🛝' => 'խաղահրապարակի սղարան',
    '🎡' => 'սատանայի անիվ',
    '🎢' => 'ամերիկյան բլուրներ',
    '💈' => 'վարսավիրանոցի հոլ',
    '🎪' => 'կրկեսի վրան',
    '🚂' => 'շոգեքարշ',
    '🚃' => 'երկաթուղային վագոն',
    '🚄' => 'ճեպընթաց գնացք',
    '🚅' => 'գերճեպընթաց գնացք',
    '🚆' => 'գնացք',
    '🚇' => 'մետրո',
    '🚈' => 'վերգետնյա մետրո',
    '🚉' => 'կայարան',
    '🚊' => 'տրամվայ',
    '🚝' => 'մոնոռելս',
    '🚞' => 'լեռնային երկաթուղի',
    '🚋' => 'տրամվայի վագոն',
    '🚌' => 'ավտոբուս',
    '🚍' => 'մոտեցող ավտոբուս',
    '🚎' => 'տրոլեյբուս',
    '🚐' => 'միկրոավտոբուս',
    '🚑' => 'շտապօգնության մեքենա',
    '🚒' => 'հրշեջ մեքենա',
    '🚓' => 'ոստիկանական մեքենա',
    '🚔' => 'մոտեցող ոստիկանական մեքենա',
    '🚕' => 'տաքսի',
    '🚖' => 'մոտեցող տաքսի',
    '🚗' => 'ավտոմեքենա',
    '🚘' => 'մոտեցող ավտոմեքենա',
    '🚙' => 'ավտոֆուրգոն',
    '🛻' => 'պիկապ',
    '🚚' => 'բեռնատար',
    '🚛' => 'կցորդով բեռնատար',
    '🚜' => 'տրակտոր',
    '🏎' => 'մրցարշավային մեքենա',
    '🏍' => 'մոտոցիկլետ',
    '🛵' => 'սկուտեր',
    '🦽' => 'ձեռքով կառավարվող անվասայլակ',
    '🦼' => 'մոտոսայլակ',
    '🛺' => 'ավտոռիկշա',
    '🚲' => 'հեծանիվ',
    '🛴' => 'ինքնագլոր',
    '🛹' => 'անվատախտակ',
    '🛼' => 'անվաչմուշկ',
    '🚏' => 'ավտոբուսի կանգառ',
    '🛣' => 'ավտոմայրուղի',
    '🛤' => 'երկաթուղի',
    '🛢' => 'նավթի տակառ',
    '⛽' => 'վառելիքի պոմպ',
    '🛞' => 'անիվ',
    '🚨' => 'ոստիկանական մեքենայի փարոս',
    '🚥' => 'հորիզոնական լուսացույց',
    '🚦' => 'ուղղաձիգ լուսացույց',
    '🛑' => 'կանգ նշան',
    '🚧' => 'շինարարություն',
    '⚓' => 'խարիսխ',
    '🛟' => 'փրկօղակ',
    '⛵' => 'առագաստանավ',
    '🛶' => 'կանոէ',
    '🚤' => 'արագընթաց նավակ',
    '🛳' => 'ուղևորատար նավ',
    '⛴' => 'լաստանավ',
    '🛥' => 'մոտորանավակ',
    '🚢' => 'նավ',
    '✈' => 'ինքնաթիռ',
    '🛩' => 'փոքր ինքնաթիռ',
    '🛫' => 'օդանավի մեկնում',
    '🛬' => 'օդանավի ժամանում',
    '🪂' => 'անկարգել',
    '💺' => 'նստատեղ',
    '🚁' => 'ուղղաթիռ',
    '🚟' => 'կախովի երկաթուղի',
    '🚠' => 'լեռնային ճոպանուղի',
    '🚡' => 'օդային տրամվայ',
    '🛰' => 'արբանյակ',
    '🚀' => 'հրթիռ',
    '🛸' => 'թռչող ափսե',
    '🛎' => 'հյուրանոցային զանգ',
    '🧳' => 'ուղեբեռ',
    '⌛' => 'ավազի ժամացույց',
    '⏳' => 'ավազի ժամացույց հոսող ավազով',
    '⌚' => 'ժամացույց',
    '⏰' => 'զարթուցիչ',
    '⏱' => 'վայրկյանաչափ',
    '⏲' => 'ժամաչափ',
    '🕰' => 'կրակարանի ժամացույց',
    '🕛' => 'ժամը տասներկուսը',
    '🕧' => 'տասներկուսն անց կես',
    '🕐' => 'ժամը մեկը',
    '🕜' => 'մեկն անց կես',
    '🕑' => 'ժամը երկուսը',
    '🕝' => 'երկուսն անց կես',
    '🕒' => 'ժամը երեքը',
    '🕞' => 'երեքն անց կես',
    '🕓' => 'ժամը չորսը',
    '🕟' => 'չորսն անց կես',
    '🕔' => 'ժամը հինգը',
    '🕠' => 'հինգն անց կես',
    '🕕' => 'ժամը վեցը',
    '🕡' => 'վեցն անց կես',
    '🕖' => 'ժամը յոթը',
    '🕢' => 'յոթն անց կես',
    '🕗' => 'ժամը ութը',
    '🕣' => 'ութն անց կես',
    '🕘' => 'ժամը ինը',
    '🕤' => 'ինն անց կես',
    '🕙' => 'ժամը տասը',
    '🕥' => 'տասն անց կես',
    '🕚' => 'ժամը տասնմեկը',
    '🕦' => 'տասնմեկն անց կես',
    '🌑' => 'նորալուսին',
    '🌒' => 'աճող մահիկ',
    '🌓' => 'լուսինն առաջին քառորդում',
    '🌔' => 'աճող ուռուցիկ լուսին',
    '🌕' => 'լիալուսին',
    '🌖' => 'նվազող ուռուցիկ լուսին',
    '🌗' => 'լուսինը երկրորդ քառորդում',
    '🌘' => 'նվազող մահիկ',
    '🌙' => 'մահիկ',
    '🌚' => 'դեմքով նորալուսին',
    '🌛' => 'լուսինն առաջին քառորդում դեմքով',
    '🌜' => 'լուսինը երկրորդ քառորդում դեմքով',
    '🌡' => 'ջերմաչափ',
    '☀' => 'արև',
    '🌝' => 'դեմքով լիալուսին',
    '🌞' => 'դեմքով արև',
    '🪐' => 'օղակներով մոլորակ',
    '⭐' => 'աստղ',
    '🌟' => 'փայլող աստղ',
    '🌠' => 'ընկնող աստղ',
    '🌌' => 'ծիր կաթին',
    '☁' => 'ամպ',
    '⛅' => 'արև ամպի հետևում',
    '⛈' => 'կայծակով և անձրևով ամպ',
    '🌤' => 'արև փոքր ամպի հետևում',
    '🌥' => 'արև մեծ ամպի հետևում',
    '🌦' => 'արև անձրևով ամպի հետևում',
    '🌧' => 'անձրևով ամպ',
    '🌨' => 'ձյունով ամպ',
    '🌩' => 'կայծակով ամպ',
    '🌪' => 'պտտահողմ',
    '🌫' => 'մառախուղ',
    '🌬' => 'քամու երես',
    '🌀' => 'ցիկլոն',
    '🌈' => 'ծիածան',
    '🌂' => 'փակ անձրևանոց',
    '☂' => 'անձրևանոց',
    '☔' => 'անձրևանոց անձրևի կաթիլներով',
    '⛱' => 'անձրևանոց գետնի վրա',
    '⚡' => 'բարձր լարում',
    '❄' => 'ձյան փաթիլ',
    '☃' => 'ձնեմարդ',
    '⛄' => 'ձնեմարդ առանց ձյան',
    '☄' => 'գիսաստղ',
    '🔥' => 'կրակ',
    '💧' => 'կաթիլ',
    '🌊' => 'ջրի ալիք',
    '🎃' => 'ջեքի լապտեր',
    '🎄' => 'տոնածառ',
    '🎆' => 'հրավառություն',
    '🎇' => 'բենգալյան կրակ',
    '🧨' => 'ճայթռուկ',
    '✨' => 'կայծեր',
    '🎈' => 'փուչիկ',
    '🎉' => 'ճայթուկ',
    '🎊' => 'կոնֆետի',
    '🎋' => 'տանաբատայի ծառ',
    '🎍' => 'սոճու զարդարանք',
    '🎎' => 'ճապոնական տիկնիկներ',
    '🎏' => 'կարպերի տեսքով նավադրոշ',
    '🎐' => 'քամու զանգակ',
    '🎑' => 'լուսնի դիտման ծես',
    '🧧' => 'կարմիր ծրար',
    '🎀' => 'ժապավեն',
    '🎁' => 'փաթեթավորված նվեր',
    '🎗' => 'հուշաժապավեն',
    '🎟' => 'մուտքի տոմս',
    '🎫' => 'տոմս',
    '🎖' => 'ռազմական մեդալ',
    '🏆' => 'գավաթ',
    '🏅' => 'մարզական մեդալ',
    '🥇' => 'ոսկե մեդալ',
    '🥈' => 'արծաթե մեդալ',
    '🥉' => 'բրոնզե մեդալ',
    '⚽' => 'ֆուտբոլի գնդակ',
    '⚾' => 'բեյսբոլ',
    '🥎' => 'սոֆթբոլ',
    '🏀' => 'բասկետբոլ',
    '🏐' => 'վոլեյբոլ',
    '🏈' => 'ամերիկյան ֆուտբոլի գնդակ',
    '🏉' => 'ռեգբիի գնդակ',
    '🎾' => 'թենիս',
    '🥏' => 'թռչող սկավառակ',
    '🎳' => 'բոուլինգ',
    '🏏' => 'կրիկետ',
    '🏑' => 'մականախաղ',
    '🏒' => 'սառույցի մականախաղ',
    '🥍' => 'լաքրոս',
    '🏓' => 'սեղանի թենիս',
    '🏸' => 'բադմինտոն',
    '🥊' => 'բռնցքամարտի ձեռնոց',
    '🥋' => 'մարտարվեստի համազգեստ',
    '🥅' => 'ֆուտբոլի դարպաս',
    '⛳' => 'գոլֆի դրոշակ',
    '⛸' => 'չմուշկ',
    '🎣' => 'կարթաձող',
    '🤿' => 'ջրադիմակ',
    '🎽' => 'վազքի շապիկ',
    '🎿' => 'դահուկներ',
    '🛷' => 'սահնակ',
    '🥌' => 'քըրլինգի քար',
    '🎯' => 'դիպուկ հարված',
    '🪀' => 'յո-յո',
    '🪁' => 'օդապարուկ',
    '🔫' => 'ջրային ատրժանակ',
    '🎱' => '8 գնդանոց բիլիարդ',
    '🔮' => 'բյուրեղյա գունդ',
    '🪄' => 'կախարդական փայտիկ',
    '🎮' => 'տեսախաղ',
    '🕹' => 'ջոյսթիք',
    '🎰' => 'խաղային սարք',
    '🎲' => 'զառ',
    '🧩' => 'խճաղաղի կտոր',
    '🧸' => 'փափուկ արջուկ',
    '🪅' => 'պինյատա',
    '🪩' => 'շողագունդ',
    '🪆' => 'մատրյոշկա',
    '♠' => 'ղառ',
    '♥' => 'սիրտ',
    '♦' => 'քյափ',
    '♣' => 'խաչ',
    '♟' => 'շախմատի զինվոր',
    '🃏' => 'ջոկեր',
    '🀄' => 'մաջոնգի կարմիր վիշապ',
    '🎴' => 'ծաղկի խաղաթղթեր',
    '🎭' => 'կատարողական արվեստ',
    '🖼' => 'շրջանակ նկարով',
    '🎨' => 'ներկապնակ',
    '🧵' => 'թել',
    '🪡' => 'ասեղ',
    '🧶' => 'մանվածք',
    '🪢' => 'հանգույց',
    '👓' => 'ակնոց',
    '🕶' => 'արևային ակնոց',
    '🥽' => 'պաշտպանիչ ակնոց',
    '🥼' => 'սպիտակ խալաթ',
    '🦺' => 'փրկաբաճկոն',
    '👔' => 'փողկապ',
    '👕' => 'սպորտային վերնաշապիկ',
    '👖' => 'ջինս',
    '🧣' => 'վզկապ',
    '🧤' => 'ձեռնոցներ',
    '🧥' => 'վերարկու',
    '🧦' => 'գուլպաներ',
    '👗' => 'զգեստ',
    '👘' => 'կիմոնո',
    '🥻' => 'սարի',
    '🩱' => 'միակտոր լողազգեստ',
    '🩲' => 'լողավարտիք',
    '🩳' => 'կարճավարտիք',
    '👙' => 'բիկինի',
    '👚' => 'կնոջ հագուստ',
    '🪭' => 'ձեռքի հովհար',
    '👛' => 'դրամապանակ',
    '👜' => 'ձեռքի պայուսակ',
    '👝' => 'պայուսակ',
    '🛍' => 'գնումների պայուսակ',
    '🎒' => 'ուսապարկ',
    '🩴' => 'ռետինե հողաթափեր',
    '👞' => 'տղամարդու կոշիկ',
    '👟' => 'վազքի կոշիկ',
    '🥾' => 'արշավային կոշիկ',
    '🥿' => 'տափակ կոշիկ',
    '👠' => 'բարձրակրունկ կոշիկ',
    '👡' => 'կնոջ սանդալ',
    '🩰' => 'բալետի կոշիկ',
    '👢' => 'կնոջ երկարաճիթք կոշիկ',
    '🪮' => 'սանրիկ',
    '👑' => 'թագ',
    '👒' => 'կնոջ գլխարկ',
    '🎩' => 'բարձր գլխարկ',
    '🎓' => 'շրջանավարտի գլխարկ',
    '🧢' => 'հովարով գլխարկ',
    '🪖' => 'զինվորական սաղավարտ',
    '⛑' => 'փրկարարի սաղավարտ',
    '📿' => 'վարդարան',
    '💄' => 'շրթներկ',
    '💍' => 'մատանի',
    '💎' => 'ակն',
    '🔇' => 'բարձրախոսն անջատված է',
    '🔈' => 'բարձրախոս',
    '🔉' => 'բարձրախոսը միացված է',
    '🔊' => 'բարձրախոսի ձայնը բարձր է',
    '📢' => 'մեծ բարձրախոս',
    '📣' => 'մեգաֆոն',
    '📯' => 'փոստային եղջյուր',
    '🔔' => 'զանգ',
    '🔕' => 'զանգակ շեղ գծիկով',
    '🎼' => 'սոլի բանալի',
    '🎵' => 'նոտա',
    '🎶' => 'նոտաներ',
    '🎙' => 'ստուդիայի խոսափող',
    '🎚' => 'ձայնի բարձրության սահոց',
    '🎛' => 'կառավարման կոճակներ',
    '🎤' => 'խոսափող',
    '🎧' => 'ականջակալ',
    '📻' => 'ռադիո',
    '🎷' => 'սաքսոֆոն',
    '🎺' => 'շեփոր',
    '🪊' => 'տրոմբոն',
    '🪗' => 'ակորդեոն',
    '🎸' => 'կիթառ',
    '🎹' => 'երաժշտական ստեղնաշար',
    '🎻' => 'ջութակ',
    '🪕' => 'բանջո',
    '🥁' => 'թմբուկ',
    '🪘' => 'կոնգա',
    '🪇' => 'մարակաս',
    '🪈' => 'սրինգ',
    '🪉' => 'տավիղ',
    '📱' => 'բջջային հեռախոս',
    '📲' => 'բջջային հեռախոս սլաքով',
    '☎' => 'հեռախոս',
    '📞' => 'հեռախոսի լսափող',
    '📟' => 'փեյջեր',
    '📠' => 'ֆաքսի մեքենա',
    '🔋' => 'մարտկոց',
    '🪫' => 'լիցքաթափված մարտկոց',
    '🔌' => 'էլեկտրական խրոց',
    '💻' => 'նոթբուք',
    '🖥' => 'սեղանի համակարգիչ',
    '🖨' => 'տպիչ',
    '⌨' => 'ստեղնաշար',
    '🖱' => 'համակարգչի մկնիկ',
    '🖲' => 'թրեքբոլ',
    '💽' => 'համակարգչային սկավառակ',
    '💾' => 'ճկուն սկավառակ',
    '💿' => 'օպտիկական սկավառակ',
    '📀' => 'DVD',
    '🧮' => 'համրիչ',
    '🎥' => 'կինոխցիկ',
    '🎞' => 'ժապավենի կադրեր',
    '📽' => 'ժապավենային պրոյեկտոր',
    '🎬' => 'կինոդուբլների համարացույց',
    '📺' => 'հեռուստացույց',
    '📷' => 'ֆոտոապարատ',
    '📸' => 'ֆոտոապարատ լուսաթարթիչով',
    '📹' => 'տեսախցիկ',
    '📼' => 'տեսաերիզ',
    '🔍' => 'ձախ ուղղված խոշորացույց',
    '🔎' => 'աջ ուղղված խոշորացույց',
    '🕯' => 'մոմ',
    '💡' => 'էլեկտրական լամպ',
    '🔦' => 'գրպանի լապտեր',
    '🏮' => 'թղթե կարմիր լապտեր',
    '🪔' => 'դիյա լամպ',
    '📔' => 'ձևավոր կազմով տետր',
    '📕' => 'փակ գիրք',
    '📖' => 'բաց գիրք',
    '📗' => 'կանաչ գիրք',
    '📘' => 'կապույտ գիրք',
    '📙' => 'նարնջագույն գիրք',
    '📚' => 'գրքեր',
    '📓' => 'տետր',
    '📒' => 'հաշվապահական մատյան',
    '📃' => 'ոլորված էջ',
    '📜' => 'գալարաթուղթ',
    '📄' => 'էջ',
    '📰' => 'լրագիր',
    '🗞' => 'կլորացրած լրագիր',
    '📑' => 'էջանիշ ներդիրներ',
    '🔖' => 'էջանիշ',
    '🏷' => 'պիտակ',
    '🪙' => 'մետաղադրամ',
    '💰' => 'փողի պարկ',
    '🪎' => 'գանձատուփ',
    '💴' => 'իեն թղթադրամ',
    '💵' => 'դոլար թղթադրամ',
    '💶' => 'եվրո թղթադրամ',
    '💷' => 'ֆունտ թղթադրամ',
    '💸' => 'փող թևերով',
    '💳' => 'պլաստիկ քարտ',
    '🧾' => 'անդորրագիր',
    '💹' => 'աճող դիագրամ իենով',
    '✉' => 'ծրար',
    '📧' => 'էլ․ նամակ',
    '📨' => 'ստացվող ծրար',
    '📩' => 'ծրար սլաքով',
    '📤' => 'ելքի արկղ',
    '📥' => 'մուտքի արկղ',
    '📦' => 'ծանրոց',
    '📫' => 'փակ փոստարկղ բարձրացված դրոշակով',
    '📪' => 'փակ փոստարկղ իջեցված դրոշակով',
    '📬' => 'բաց փոստարկղ բարձրացված դրոշակով',
    '📭' => 'բաց փոստարկղ իջեցված դրոշակով',
    '📮' => 'փոստատուփ',
    '🗳' => 'քվեատուփ քվեաթերթիկով',
    '✏' => 'մատիտ',
    '✒' => 'սև գրչածայր',
    '🖋' => 'ինքնահոս գրիչ',
    '🖊' => 'գրիչ',
    '🖌' => 'վրձին',
    '🖍' => 'յուղամատիտ',
    '📝' => 'հուշաթերթ',
    '💼' => 'պորտֆել',
    '📁' => 'թղթապանակ',
    '📂' => 'բաց թղթապանակ',
    '🗂' => 'քարտադարանի բաժանարարներ',
    '📅' => 'օրացույց',
    '📆' => 'պոկովի օրացույց',
    '🗒' => 'պարուրավոր նոթատետր',
    '🗓' => 'պարուրավոր օրացույց',
    '📇' => 'քարտադարան',
    '📈' => 'աճող գծապատկեր',
    '📉' => 'նվազող գծապատկեր',
    '📊' => 'գոտեձև գծապատկեր',
    '📋' => 'սեղմատախտակ',
    '📌' => 'քորոց',
    '📍' => 'գնդասեղ',
    '📎' => 'ամրակ',
    '🖇' => 'միացված ամրակներ',
    '📏' => 'քանոն',
    '📐' => 'եռանկյունի քանոն',
    '✂' => 'մկրատ',
    '🗃' => 'քարտադարանի արկղ',
    '🗄' => 'պահարան',
    '🗑' => 'աղբաման',
    '🔒' => 'կողպված',
    '🔓' => 'բաց կողպեք',
    '🔏' => 'կողպեք ինքնահոսով',
    '🔐' => 'փակ կողպեք բանալիով',
    '🔑' => 'բանալի',
    '🗝' => 'հին բանալի',
    '🔨' => 'մուրճ',
    '🪓' => 'կացին',
    '⛏' => 'քլունգ',
    '⚒' => 'մուրճեր',
    '🛠' => 'մուրճ և պտուտակաբանալի',
    '🗡' => 'դաշույն',
    '⚔' => 'խաչված սրեր',
    '💣' => 'ռումբ',
    '🪃' => 'բումերանգ',
    '🏹' => 'նետ ու աղեղ',
    '🛡' => 'վահան',
    '🪚' => 'սղոց',
    '🔧' => 'պտուտակաբանալի',
    '🪛' => 'պտուտակիչ',
    '🔩' => 'մանեկ ու հեղույս',
    '⚙' => 'ատամնանիվ',
    '🗜' => 'մամլակ',
    '⚖' => 'նժարավոր կշեռք',
    '🦯' => 'ձեռնափայտ',
    '🔗' => 'օղակ',
    '⛓' => 'շղթաներ',
    '🪝' => 'կեռ',
    '🧰' => 'գործիքների արկղ',
    '🧲' => 'մագնիս',
    '🪜' => 'սանդուղք',
    '🪏' => 'թիակ',
    '⚗' => 'թորիչ',
    '🧪' => 'փորձանոթ',
    '🧫' => 'Պետրիի պնակ',
    '🧬' => 'դնթ',
    '🔬' => 'մանրադիտակ',
    '🔭' => 'հեռադիտակ',
    '📡' => 'արբանյակային ալեհավաք',
    '💉' => 'ներարկիչ',
    '🩸' => 'արյան կաթիլ',
    '💊' => 'հաբ',
    '🩹' => 'սպեղանի',
    '🩼' => 'հենակ',
    '🩺' => 'ստեթոսկոպ',
    '🩻' => 'ռենտգենյան ճառագայթներ',
    '🚪' => 'դուռ',
    '🛗' => 'վերելակ',
    '🪞' => 'հայելի',
    '🪟' => 'պատուհան',
    '🛏' => 'մահճակալ',
    '🛋' => 'բազմոց և լամպ',
    '🪑' => 'աթոռ',
    '🚽' => 'զուգարանակոնք',
    '🪠' => 'վանտուզ',
    '🚿' => 'ցնցուղ',
    '🛁' => 'լոգարան',
    '🪤' => 'մկան թակարդ',
    '🪒' => 'ածելի',
    '🧴' => 'լոսիոնի շիշ',
    '🧷' => 'անվտանգ քորոց',
    '🧹' => 'ավել',
    '🧺' => 'զամբյուղ',
    '🧻' => 'թղթի գլան',
    '🪣' => 'դույլ',
    '🧼' => 'օճառ',
    '🫧' => 'պղպջակներ',
    '🪥' => 'ատամի խոզանակ',
    '🧽' => 'սպունգ',
    '🧯' => 'կրակմարիչ',
    '🛒' => 'գնումների զամբյուղ',
    '🚬' => 'ծխել',
    '⚰' => 'դագաղ',
    '🪦' => 'շիրմաքար',
    '⚱' => 'աճյունասափոր',
    '🧿' => 'աչքի ուլունք',
    '🪬' => 'հնգմատ',
    '🗿' => 'մոաի',
    '🪧' => 'պաստառ',
    '🪪' => 'նույնացուցիչ քարտ',
    '🏧' => 'բանկոմատի նշան',
    '🚮' => 'աղբամանի նշան',
    '🚰' => 'խմելու ջուր',
    '♿' => 'անվասայլակի նշան',
    '🚹' => 'տղամարդկանց զուգարան',
    '🚺' => 'կանանց զուգարան',
    '🚻' => 'ընդհանուր զուգարան',
    '🚼' => 'նորածնի նշան',
    '🚾' => 'զուգարան',
    '🛂' => 'անձնագրային ստուգում',
    '🛃' => 'մաքսատուն',
    '🛄' => 'ուղեբեռի վերաբերյալ բողոք',
    '🛅' => 'մոռացված ուղեբեռ',
    '⚠' => 'զգուշացում',
    '🚸' => 'անցնող երեխաներ',
    '⛔' => 'մուտք չկա',
    '🚫' => 'արգելված է',
    '🚳' => 'առանց հեծանիվների',
    '🚭' => 'չծխել',
    '🚯' => 'չաղտոտել',
    '🚱' => 'ոչ խմելու ջուր',
    '🚷' => 'հետիոտնների մուտքն արգելված է',
    '📵' => 'բջջային հեռախոսներն արգելվում են',
    '🔞' => 'տասնութից ցածր արգելվում է',
    '☢' => 'ռադիոակտիվ',
    '☣' => 'կենսաբանական վտանգ',
    '⬆' => 'վերև սլաք',
    '↗' => 'վերև աջ սլաք',
    '➡' => 'աջ սլաք',
    '↘' => 'ներքև աջ սլաք',
    '⬇' => 'ներքև սլաք',
    '↙' => 'ներքև ձախ սլաք',
    '⬅' => 'ձախ սլաք',
    '↖' => 'վերև ձախ սլաք',
    '↕' => 'վերև-ներքև սլաք',
    '↔' => 'ձախ-աջ սլաք',
    '↩' => 'աջ շրջադարձի սլաք',
    '↪' => 'ձախ շրջադարձի սլաք',
    '⤴' => 'ձախից վերև թեքվող սլաք',
    '⤵' => 'ձախից ներքև թեքվող սլաք',
    '🔃' => 'ժամասլաքի ուղղությամբ ուղղահայաց սլաքներ',
    '🔄' => 'ժամասլաքին հակառակ ուղղությամբ սլաքներով կոճակ',
    '🔙' => 'հետ գրությամբ սլաք',
    '🔚' => 'ՎԵՐՋ սլաք',
    '🔛' => 'միացված է գրությամբ սլաք',
    '🔜' => 'շուտով գրությամբ սլաք',
    '🔝' => 'վերև գրությամբ սլաք',
    '🛐' => 'աղոթատեղի',
    '⚛' => 'ատոմի նշան',
    '🕉' => 'օմ',
    '✡' => 'դավթի աստղ',
    '☸' => 'դհարմայի անիվ',
    '☯' => 'ին յան',
    '✝' => 'լատինական խաչ',
    '☦' => 'ուղղափառ խաչ',
    '☪' => 'աստղ և մահիկ',
    '☮' => 'խաղաղության նշան',
    '🕎' => 'մենորա',
    '🔯' => 'կետիկով վեցթևանի աստղ',
    '🪯' => 'քանդա',
    '♈' => 'Խոյ',
    '♉' => 'Ցուլ',
    '♊' => 'Երկվորյակներ',
    '♋' => 'Խեցգետին',
    '♌' => 'Առյուծ',
    '♍' => 'Կույս',
    '♎' => 'Կշեռք',
    '♏' => 'Կարիճ',
    '♐' => 'Աղեղնավոր',
    '♑' => 'Այծեղջյուր',
    '♒' => 'Ջրհոս',
    '♓' => 'Ձկներ',
    '⛎' => 'Օձակիր',
    '🔀' => 'խառնել կատարումները կոճակ',
    '🔁' => 'կրկնման կոճակ',
    '🔂' => 'կրկնել մեկ անգամ կոճակ',
    '▶' => 'նվագարկել կոճակ',
    '⏩' => 'արագ առաջ կոճակ',
    '⏭' => 'հաջորդ կատարումը կոճակ',
    '⏯' => 'նվագարկման կամ դադարի կոճակ',
    '◀' => 'հետադարձման կոճակ',
    '⏪' => 'արագ հետադարձել կոճակ',
    '⏮' => 'վերջին կատարումը կոճակ',
    '🔼' => 'վերև կոճակ',
    '⏫' => 'արագ վերև կոճակ',
    '🔽' => 'ներքև կոճակ',
    '⏬' => 'արագ ներքև կոճակ',
    '⏸' => 'դադարի կոճակ',
    '⏹' => 'կանգ կոճակ',
    '⏺' => 'ձայնագրման կոճակ',
    '⏏' => 'հանելու կոճակ',
    '🎦' => 'կինո',
    '🔅' => 'մթեցնելու կոճակ',
    '🔆' => 'պայծառեցնելու կոճակ',
    '📶' => 'անտենայի գծիկներ',
    '🛜' => 'անլար',
    '📳' => 'թրթռազանգի ռեժիմ',
    '📴' => 'բջջայինն անջատված է',
    '♀' => 'կնոջ նշան',
    '♂' => 'տղամարդու նշան',
    '⚧' => 'տրանսգենդերի նշան',
    '✖' => 'բազմապատկում',
    '➕' => 'գումարման նշան',
    '➖' => 'հանման նշան',
    '➗' => 'բաժանում',
    '🟰' => 'հավասարության թանձր նշան',
    '♾' => 'անվերջություն',
    '‼' => 'կրկնակի բացականչական նշան',
    '⁉' => 'բացականչական հարցական նշան',
    '❓' => 'հարցական նշան',
    '❔' => 'սպիտակ հարցական նշան',
    '❕' => 'սպիտակ բացականչական նշան',
    '❗' => 'բացականչական նշան',
    '〰' => 'ալիքաձև գծիկ',
    '💱' => 'տարադրամի փոխանակում',
    '💲' => 'դոլարի թավ նշան',
    '⚕' => 'բժշկության խորհրդանիշ',
    '♻' => 'վերամշակման նշան',
    '⚜' => 'թագավորական շուշան',
    '🔱' => 'եռաժանի խորհրդանշան',
    '📛' => 'բեյջ',
    '🔰' => 'սկսնակ լինելու ճապոնական նշան',
    '⭕' => 'կարմիր դատարկ շրջան',
    '✅' => 'ստուգանշանի կոճակ',
    '☑' => 'նշված վանդակ',
    '✔' => 'ստուգանշան',
    '❌' => 'խաչի նշան',
    '❎' => 'խաչի նշանով կոճակ',
    '➰' => 'ոլորուն հանգույց',
    '➿' => 'կրկնակի ոլորուն հանգույց',
    '〽' => 'իորիտեն',
    '✳' => 'ութ թևանի աստղանիշ',
    '✴' => 'ութ թևանի աստղ',
    '❇' => 'կայծիկ',
    '™' => 'ապրանքանիշ',
    '🫟' => 'ցայտ',
    '🔠' => 'լատինատառ մեծատառ ներածում',
    '🔡' => 'լատինատառ փոքրատառ ներածում',
    '🔢' => 'թվերի ներածում',
    '🔣' => 'նշանների ներածում',
    '🔤' => 'լատինատառ ներածում',
    '🅰' => 'էյ կոճակ',
    '🆎' => 'էյ-բի կոճակ',
    '🅱' => 'բի կոճակ',
    '🆑' => 'սի-էլ',
    '🆒' => 'ԶԻԼ բառը ուղղանկյունի մեջ',
    '🆓' => 'ԱՆՎՃԱՐ բառը ուղղանկյունի մեջ',
    'ℹ' => 'տեղեկատու',
    '🆔' => 'այ-դի',
    'Ⓜ' => 'էմ տառը շրջանակի մեջ',
    '🆕' => 'ՆՈՐ բառը ուղղանկյունի մեջ',
    '🆖' => 'էն-ջի',
    '🅾' => 'օ կոճակ',
    '🆗' => 'օքեյ',
    '🅿' => 'փի կոճակ',
    '🆘' => 'սոս',
    '🆙' => 'ափ կոճակ',
    '🆚' => 'վի-էս',
    '🈁' => 'կատականա կոկո',
    '🈂' => 'կատականա սա',
    '🈷' => 'լուսին գաղափարագիր',
    '🈶' => 'գոյ գաղափարագիր',
    '🈯' => 'մատ գաղափարագիր',
    '🉐' => 'առավելություն գաղափարագիր շրջանակի մեջ',
    '🈹' => 'բաժանել գաղափարագիր',
    '🈚' => 'ժխտում գաղափարագիր',
    '🈲' => 'արգելել գաղափարագիր',
    '🉑' => 'ընդունել գաղափարագիր շրջանակի մեջ',
    '🈸' => 'կիրառել գաղափարագիր',
    '🈴' => 'միասին գաղափարագիր',
    '🈳' => 'դատարկ գաղափարագիր',
    '㊗' => 'շնորհավորել գաղափարագիր շրջանակի մեջ',
    '㊙' => 'գաղտնի գաղափարագիր շրջանակի մեջ',
    '🈺' => 'աշխատում է գաղափարագիր',
    '🈵' => 'լիություն գաղափարագիր',
    '🔴' => 'կարմիր շրջան',
    '🟠' => 'նարնջագույն շրջան',
    '🟡' => 'դեղին շրջան',
    '🟢' => 'կանաչ շրջան',
    '🔵' => 'կապույտ շրջան',
    '🟣' => 'մանուշակագույն շրջան',
    '🟤' => 'դարչնագույն շրջան',
    '⚫' => 'սև շրջանակ',
    '⚪' => 'սպիտակ շրջան',
    '🟥' => 'կարմիր քառակուսի',
    '🟧' => 'նարնջագույն քառակուսի',
    '🟨' => 'դեղին քառակուսի',
    '🟩' => 'կանաչ քառակուսի',
    '🟦' => 'կապույտ քառակուսի',
    '🟪' => 'մանուշակագույն քառակուսի',
    '🟫' => 'շագանակագույն քառակուսի',
    '⬛' => 'սև մեծ քառակուսի',
    '⬜' => 'սպիտակ մեծ քառակուսի',
    '◼' => 'սև միջին չափի քառակուսի',
    '◻' => 'սպիտակ միջին չափի քառակուսի',
    '◾' => 'սև միջին-փոքր քառակուսի',
    '◽' => 'սպիտակ միջին-փոքր քառակուսի',
    '▪' => 'սև փոքր քառակուսի',
    '▫' => 'սպիտակ փոքր քառակուսի',
    '🔶' => 'նարնջագույն մեծ շեղանկյուն',
    '🔷' => 'կապույտ մեծ շեղանկյուն',
    '🔸' => 'նարնջագույն փոքր շեղանկյուն',
    '🔹' => 'կապույտ փոքր շեղանկյուն',
    '🔺' => 'կարմիր եռանկյուն ուղղված վերև',
    '🔻' => 'կարմիր եռանկյուն ուղղված ներքև',
    '💠' => 'կետով շեղանկյուն',
    '🔘' => 'կետակոճակ',
    '🔳' => 'սպիտակ քառակուսի կոճակ',
    '🔲' => 'սև քառակուսի կոճակ',
    '🏁' => 'վանդակավոր դրոշ',
    '🚩' => 'եռանկյունի դրոշ',
    '🎌' => 'խաչված դրոշակներ',
    '🏴' => 'ծածանվող սև դրոշ',
    '🏳' => 'ծածանվող սպիտակ դրոշ',
];
