<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'kus: volwassene, volwassene, lichte huidskleur, lichtgetinte huidskleur',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'kus: volwassene, volwassene, lichte huidskleur, getinte huidskleur',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'kus: volwassene, volwassene, lichte huidskleur, donkergetinte huidskleur',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'kus: volwassene, volwassene, lichte huidskleur, donkere huidskleur',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'kus: volwassene, volwassene, lichtgetinte huidskleur, lichte huidskleur',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'kus: volwassene, volwassene, lichtgetinte huidskleur, getinte huidskleur',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'kus: volwassene, volwassene, lichtgetinte huidskleur, donkergetinte huidskleur',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'kus: volwassene, volwassene, lichtgetinte huidskleur, donkere huidskleur',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'kus: volwassene, volwassene, getinte huidskleur, lichte huidskleur',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'kus: volwassene, volwassene, getinte huidskleur, lichtgetinte huidskleur',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'kus: volwassene, volwassene, getinte huidskleur, donkergetinte huidskleur',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'kus: volwassene, volwassene, getinte huidskleur, donkere huidskleur',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'kus: volwassene, volwassene, donkergetinte huidskleur, lichte huidskleur',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'kus: volwassene, volwassene, donkergetinte huidskleur, lichtgetinte huidskleur',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'kus: volwassene, volwassene, donkergetinte huidskleur, getinte huidskleur',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'kus: volwassene, volwassene, donkergetinte huidskleur, donkere huidskleur',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'kus: volwassene, volwassene, donkere huidskleur, lichte huidskleur',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'kus: volwassene, volwassene, donkere huidskleur, lichtgetinte huidskleur',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'kus: volwassene, volwassene, donkere huidskleur, getinte huidskleur',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'kus: volwassene, volwassene, donkere huidskleur, donkergetinte huidskleur',
    '👨🏻‍❤‍💋‍👨🏻' => 'kus: man, man, lichte huidskleur',
    '👨🏻‍❤‍💋‍👨🏼' => 'kus: man, man, lichte huidskleur, lichtgetinte huidskleur',
    '👨🏻‍❤‍💋‍👨🏽' => 'kus: man, man, lichte huidskleur, getinte huidskleur',
    '👨🏻‍❤‍💋‍👨🏾' => 'kus: man, man, lichte huidskleur, donkergetinte huidskleur',
    '👨🏻‍❤‍💋‍👨🏿' => 'kus: man, man, lichte huidskleur, donkere huidskleur',
    '👨🏼‍❤‍💋‍👨🏻' => 'kus: man, man, lichtgetinte huidskleur, lichte huidskleur',
    '👨🏼‍❤‍💋‍👨🏼' => 'kus: man, man, lichtgetinte huidskleur',
    '👨🏼‍❤‍💋‍👨🏽' => 'kus: man, man, lichtgetinte huidskleur, getinte huidskleur',
    '👨🏼‍❤‍💋‍👨🏾' => 'kus: man, man, lichtgetinte huidskleur, donkergetinte huidskleur',
    '👨🏼‍❤‍💋‍👨🏿' => 'kus: man, man, lichtgetinte huidskleur, donkere huidskleur',
    '👨🏽‍❤‍💋‍👨🏻' => 'kus: man, man, getinte huidskleur, lichte huidskleur',
    '👨🏽‍❤‍💋‍👨🏼' => 'kus: man, man, getinte huidskleur, lichtgetinte huidskleur',
    '👨🏽‍❤‍💋‍👨🏽' => 'kus: man, man, getinte huidskleur',
    '👨🏽‍❤‍💋‍👨🏾' => 'kus: man, man, getinte huidskleur, donkergetinte huidskleur',
    '👨🏽‍❤‍💋‍👨🏿' => 'kus: man, man, getinte huidskleur, donkere huidskleur',
    '👨🏾‍❤‍💋‍👨🏻' => 'kus: man, man, donkergetinte huidskleur, lichte huidskleur',
    '👨🏾‍❤‍💋‍👨🏼' => 'kus: man, man, donkergetinte huidskleur, lichtgetinte huidskleur',
    '👨🏾‍❤‍💋‍👨🏽' => 'kus: man, man, donkergetinte huidskleur, getinte huidskleur',
    '👨🏾‍❤‍💋‍👨🏾' => 'kus: man, man, donkergetinte huidskleur',
    '👨🏾‍❤‍💋‍👨🏿' => 'kus: man, man, donkergetinte huidskleur, donkere huidskleur',
    '👨🏿‍❤‍💋‍👨🏻' => 'kus: man, man, donkere huidskleur, lichte huidskleur',
    '👨🏿‍❤‍💋‍👨🏼' => 'kus: man, man, donkere huidskleur, lichtgetinte huidskleur',
    '👨🏿‍❤‍💋‍👨🏽' => 'kus: man, man, donkere huidskleur, getinte huidskleur',
    '👨🏿‍❤‍💋‍👨🏾' => 'kus: man, man, donkere huidskleur, donkergetinte huidskleur',
    '👨🏿‍❤‍💋‍👨🏿' => 'kus: man, man, donkere huidskleur',
    '👩🏻‍❤‍💋‍👨🏻' => 'kus: vrouw, man, lichte huidskleur',
    '👩🏻‍❤‍💋‍👨🏼' => 'kus: vrouw, man, lichte huidskleur, lichtgetinte huidskleur',
    '👩🏻‍❤‍💋‍👨🏽' => 'kus: vrouw, man, lichte huidskleur, getinte huidskleur',
    '👩🏻‍❤‍💋‍👨🏾' => 'kus: vrouw, man, lichte huidskleur, donkergetinte huidskleur',
    '👩🏻‍❤‍💋‍👨🏿' => 'kus: vrouw, man, lichte huidskleur, donkere huidskleur',
    '👩🏼‍❤‍💋‍👨🏻' => 'kus: vrouw, man, lichtgetinte huidskleur, lichte huidskleur',
    '👩🏼‍❤‍💋‍👨🏼' => 'kus: vrouw, man, lichtgetinte huidskleur',
    '👩🏼‍❤‍💋‍👨🏽' => 'kus: vrouw, man, lichtgetinte huidskleur, getinte huidskleur',
    '👩🏼‍❤‍💋‍👨🏾' => 'kus: vrouw, man, lichtgetinte huidskleur, donkergetinte huidskleur',
    '👩🏼‍❤‍💋‍👨🏿' => 'kus: vrouw, man, lichtgetinte huidskleur, donkere huidskleur',
    '👩🏽‍❤‍💋‍👨🏻' => 'kus: vrouw, man, getinte huidskleur, lichte huidskleur',
    '👩🏽‍❤‍💋‍👨🏼' => 'kus: vrouw, man, getinte huidskleur, lichtgetinte huidskleur',
    '👩🏽‍❤‍💋‍👨🏽' => 'kus: vrouw, man, getinte huidskleur',
    '👩🏽‍❤‍💋‍👨🏾' => 'kus: vrouw, man, getinte huidskleur, donkergetinte huidskleur',
    '👩🏽‍❤‍💋‍👨🏿' => 'kus: vrouw, man, getinte huidskleur, donkere huidskleur',
    '👩🏾‍❤‍💋‍👨🏻' => 'kus: vrouw, man, donkergetinte huidskleur, lichte huidskleur',
    '👩🏾‍❤‍💋‍👨🏼' => 'kus: vrouw, man, donkergetinte huidskleur, lichtgetinte huidskleur',
    '👩🏾‍❤‍💋‍👨🏽' => 'kus: vrouw, man, donkergetinte huidskleur, getinte huidskleur',
    '👩🏾‍❤‍💋‍👨🏾' => 'kus: vrouw, man, donkergetinte huidskleur',
    '👩🏾‍❤‍💋‍👨🏿' => 'kus: vrouw, man, donkergetinte huidskleur, donkere huidskleur',
    '👩🏿‍❤‍💋‍👨🏻' => 'kus: vrouw, man, donkere huidskleur, lichte huidskleur',
    '👩🏿‍❤‍💋‍👨🏼' => 'kus: vrouw, man, donkere huidskleur, lichtgetinte huidskleur',
    '👩🏿‍❤‍💋‍👨🏽' => 'kus: vrouw, man, donkere huidskleur, getinte huidskleur',
    '👩🏿‍❤‍💋‍👨🏾' => 'kus: vrouw, man, donkere huidskleur, donkergetinte huidskleur',
    '👩🏿‍❤‍💋‍👨🏿' => 'kus: vrouw, man, donkere huidskleur',
    '👩🏻‍❤‍💋‍👩🏻' => 'kus: vrouw, vrouw, lichte huidskleur',
    '👩🏻‍❤‍💋‍👩🏼' => 'kus: vrouw, vrouw, lichte huidskleur, lichtgetinte huidskleur',
    '👩🏻‍❤‍💋‍👩🏽' => 'kus: vrouw, vrouw, lichte huidskleur, getinte huidskleur',
    '👩🏻‍❤‍💋‍👩🏾' => 'kus: vrouw, vrouw, lichte huidskleur, donkergetinte huidskleur',
    '👩🏻‍❤‍💋‍👩🏿' => 'kus: vrouw, vrouw, lichte huidskleur, donkere huidskleur',
    '👩🏼‍❤‍💋‍👩🏻' => 'kus: vrouw, vrouw, lichtgetinte huidskleur, lichte huidskleur',
    '👩🏼‍❤‍💋‍👩🏼' => 'kus: vrouw, vrouw, lichtgetinte huidskleur',
    '👩🏼‍❤‍💋‍👩🏽' => 'kus: vrouw, vrouw, lichtgetinte huidskleur, getinte huidskleur',
    '👩🏼‍❤‍💋‍👩🏾' => 'kus: vrouw, vrouw, lichtgetinte huidskleur, donkergetinte huidskleur',
    '👩🏼‍❤‍💋‍👩🏿' => 'kus: vrouw, vrouw, lichtgetinte huidskleur, donkere huidskleur',
    '👩🏽‍❤‍💋‍👩🏻' => 'kus: vrouw, vrouw, getinte huidskleur, lichte huidskleur',
    '👩🏽‍❤‍💋‍👩🏼' => 'kus: vrouw, vrouw, getinte huidskleur, lichtgetinte huidskleur',
    '👩🏽‍❤‍💋‍👩🏽' => 'kus: vrouw, vrouw, getinte huidskleur',
    '👩🏽‍❤‍💋‍👩🏾' => 'kus: vrouw, vrouw, getinte huidskleur, donkergetinte huidskleur',
    '👩🏽‍❤‍💋‍👩🏿' => 'kus: vrouw, vrouw, getinte huidskleur, donkere huidskleur',
    '👩🏾‍❤‍💋‍👩🏻' => 'kus: vrouw, vrouw, donkergetinte huidskleur, lichte huidskleur',
    '👩🏾‍❤‍💋‍👩🏼' => 'kus: vrouw, vrouw, donkergetinte huidskleur, lichtgetinte huidskleur',
    '👩🏾‍❤‍💋‍👩🏽' => 'kus: vrouw, vrouw, donkergetinte huidskleur, getinte huidskleur',
    '👩🏾‍❤‍💋‍👩🏾' => 'kus: vrouw, vrouw, donkergetinte huidskleur',
    '👩🏾‍❤‍💋‍👩🏿' => 'kus: vrouw, vrouw, donkergetinte huidskleur, donkere huidskleur',
    '👩🏿‍❤‍💋‍👩🏻' => 'kus: vrouw, vrouw, donkere huidskleur, lichte huidskleur',
    '👩🏿‍❤‍💋‍👩🏼' => 'kus: vrouw, vrouw, donkere huidskleur, lichtgetinte huidskleur',
    '👩🏿‍❤‍💋‍👩🏽' => 'kus: vrouw, vrouw, donkere huidskleur, getinte huidskleur',
    '👩🏿‍❤‍💋‍👩🏾' => 'kus: vrouw, vrouw, donkere huidskleur, donkergetinte huidskleur',
    '👩🏿‍❤‍💋‍👩🏿' => 'kus: vrouw, vrouw, donkere huidskleur',
    '🧑🏻‍🫯‍🧑🏼' => 'personen die worstelen: lichte huidskleur, lichtgetinte huidskleur',
    '🧑🏻‍🫯‍🧑🏽' => 'personen die worstelen: lichte huidskleur, getinte huidskleur',
    '🧑🏻‍🫯‍🧑🏾' => 'personen die worstelen: lichte huidskleur, donkergetinte huidskleur',
    '🧑🏻‍🫯‍🧑🏿' => 'personen die worstelen: lichte huidskleur, donkere huidskleur',
    '🧑🏼‍🫯‍🧑🏻' => 'personen die worstelen: lichtgetinte huidskleur, lichte huidskleur',
    '🧑🏼‍🫯‍🧑🏽' => 'personen die worstelen: lichtgetinte huidskleur, getinte huidskleur',
    '🧑🏼‍🫯‍🧑🏾' => 'personen die worstelen: lichtgetinte huidskleur, donkergetinte huidskleur',
    '🧑🏼‍🫯‍🧑🏿' => 'personen die worstelen: lichtgetinte huidskleur, donkere huidskleur',
    '🧑🏽‍🫯‍🧑🏻' => 'personen die worstelen: getinte huidskleur, lichte huidskleur',
    '🧑🏽‍🫯‍🧑🏼' => 'personen die worstelen: getinte huidskleur, lichtgetinte huidskleur',
    '🧑🏽‍🫯‍🧑🏾' => 'personen die worstelen: getinte huidskleur, donkergetinte huidskleur',
    '🧑🏽‍🫯‍🧑🏿' => 'personen die worstelen: getinte huidskleur, donkere huidskleur',
    '🧑🏾‍🫯‍🧑🏻' => 'personen die worstelen: donkergetinte huidskleur, lichte huidskleur',
    '🧑🏾‍🫯‍🧑🏼' => 'personen die worstelen: donkergetinte huidskleur, lichtgetinte huidskleur',
    '🧑🏾‍🫯‍🧑🏽' => 'personen die worstelen: donkergetinte huidskleur, getinte huidskleur',
    '🧑🏾‍🫯‍🧑🏿' => 'personen die worstelen: donkergetinte huidskleur, donkere huidskleur',
    '🧑🏿‍🫯‍🧑🏻' => 'personen die worstelen: donkere huidskleur, lichte huidskleur',
    '🧑🏿‍🫯‍🧑🏼' => 'personen die worstelen: donkere huidskleur, lichtgetinte huidskleur',
    '🧑🏿‍🫯‍🧑🏽' => 'personen die worstelen: donkere huidskleur, getinte huidskleur',
    '🧑🏿‍🫯‍🧑🏾' => 'personen die worstelen: donkere huidskleur, donkergetinte huidskleur',
    '🧑🏻‍❤‍🧑🏼' => 'stel met hart: volwassene, volwassene, lichte huidskleur, lichtgetinte huidskleur',
    '🧑🏻‍❤‍🧑🏽' => 'stel met hart: volwassene, volwassene, lichte huidskleur, getinte huidskleur',
    '🧑🏻‍❤‍🧑🏾' => 'stel met hart: volwassene, volwassene, lichte huidskleur, donkergetinte huidskleur',
    '🧑🏻‍❤‍🧑🏿' => 'stel met hart: volwassene, volwassene, lichte huidskleur, donkere huidskleur',
    '🧑🏼‍❤‍🧑🏻' => 'stel met hart: volwassene, volwassene, lichtgetinte huidskleur, lichte huidskleur',
    '🧑🏼‍❤‍🧑🏽' => 'stel met hart: volwassene, volwassene, lichtgetinte huidskleur, getinte huidskleur',
    '🧑🏼‍❤‍🧑🏾' => 'stel met hart: volwassene, volwassene, lichtgetinte huidskleur, donkergetinte huidskleur',
    '🧑🏼‍❤‍🧑🏿' => 'stel met hart: volwassene, volwassene, lichtgetinte huidskleur, donkere huidskleur',
    '🧑🏽‍❤‍🧑🏻' => 'stel met hart: volwassene, volwassene, getinte huidskleur, lichte huidskleur',
    '🧑🏽‍❤‍🧑🏼' => 'stel met hart: volwassene, volwassene, getinte huidskleur, lichtgetinte huidskleur',
    '🧑🏽‍❤‍🧑🏾' => 'stel met hart: volwassene, volwassene, getinte huidskleur, donkergetinte huidskleur',
    '🧑🏽‍❤‍🧑🏿' => 'stel met hart: volwassene, volwassene, getinte huidskleur, donkere huidskleur',
    '🧑🏾‍❤‍🧑🏻' => 'stel met hart: volwassene, volwassene, donkergetinte huidskleur, lichte huidskleur',
    '🧑🏾‍❤‍🧑🏼' => 'stel met hart: volwassene, volwassene, donkergetinte huidskleur, lichtgetinte huidskleur',
    '🧑🏾‍❤‍🧑🏽' => 'stel met hart: volwassene, volwassene, donkergetinte huidskleur, getinte huidskleur',
    '🧑🏾‍❤‍🧑🏿' => 'stel met hart: volwassene, volwassene, donkergetinte huidskleur, donkere huidskleur',
    '🧑🏿‍❤‍🧑🏻' => 'stel met hart: volwassene, volwassene, donkere huidskleur, lichte huidskleur',
    '🧑🏿‍❤‍🧑🏼' => 'stel met hart: volwassene, volwassene, donkere huidskleur, lichtgetinte huidskleur',
    '🧑🏿‍❤‍🧑🏽' => 'stel met hart: volwassene, volwassene, donkere huidskleur, getinte huidskleur',
    '🧑🏿‍❤‍🧑🏾' => 'stel met hart: volwassene, volwassene, donkere huidskleur, donkergetinte huidskleur',
    '🧑🏻‍🐰‍🧑🏼' => 'mensen met konijnenoren: lichte huidskleur, lichtgetinte huidskleur',
    '🧑🏻‍🐰‍🧑🏽' => 'mensen met konijnenoren: lichte huidskleur, getinte huidskleur',
    '🧑🏻‍🐰‍🧑🏾' => 'mensen met konijnenoren: lichte huidskleur, donkergetinte huidskleur',
    '🧑🏻‍🐰‍🧑🏿' => 'mensen met konijnenoren: lichte huidskleur, donkere huidskleur',
    '🧑🏼‍🐰‍🧑🏻' => 'mensen met konijnenoren: lichtgetinte huidskleur, lichte huidskleur',
    '🧑🏼‍🐰‍🧑🏽' => 'mensen met konijnenoren: lichtgetinte huidskleur, getinte huidskleur',
    '🧑🏼‍🐰‍🧑🏾' => 'mensen met konijnenoren: lichtgetinte huidskleur, donkergetinte huidskleur',
    '🧑🏼‍🐰‍🧑🏿' => 'mensen met konijnenoren: lichtgetinte huidskleur, donkere huidskleur',
    '🧑🏽‍🐰‍🧑🏻' => 'mensen met konijnenoren: getinte huidskleur, lichte huidskleur',
    '🧑🏽‍🐰‍🧑🏼' => 'mensen met konijnenoren: getinte huidskleur, lichtgetinte huidskleur',
    '🧑🏽‍🐰‍🧑🏾' => 'mensen met konijnenoren: getinte huidskleur, donkergetinte huidskleur',
    '🧑🏽‍🐰‍🧑🏿' => 'mensen met konijnenoren: getinte huidskleur, donkere huidskleur',
    '🧑🏾‍🐰‍🧑🏻' => 'mensen met konijnenoren: donkergetinte huidskleur, lichte huidskleur',
    '🧑🏾‍🐰‍🧑🏼' => 'mensen met konijnenoren: donkergetinte huidskleur, lichtgetinte huidskleur',
    '🧑🏾‍🐰‍🧑🏽' => 'mensen met konijnenoren: donkergetinte huidskleur, getinte huidskleur',
    '🧑🏾‍🐰‍🧑🏿' => 'mensen met konijnenoren: donkergetinte huidskleur, donkere huidskleur',
    '🧑🏿‍🐰‍🧑🏻' => 'mensen met konijnenoren: donkere huidskleur, lichte huidskleur',
    '🧑🏿‍🐰‍🧑🏼' => 'mensen met konijnenoren: donkere huidskleur, lichtgetinte huidskleur',
    '🧑🏿‍🐰‍🧑🏽' => 'mensen met konijnenoren: donkere huidskleur, getinte huidskleur',
    '🧑🏿‍🐰‍🧑🏾' => 'mensen met konijnenoren: donkere huidskleur, donkergetinte huidskleur',
    '👨🏻‍🫯‍👨🏼' => 'worstelende mannen: lichte huidskleur, lichtgetinte huidskleur',
    '👨🏻‍🫯‍👨🏽' => 'worstelende mannen: lichte huidskleur, getinte huidskleur',
    '👨🏻‍🫯‍👨🏾' => 'worstelende mannen: lichte huidskleur, donkergetinte huidskleur',
    '👨🏻‍🫯‍👨🏿' => 'worstelende mannen: lichte huidskleur, donkere huidskleur',
    '👨🏼‍🫯‍👨🏻' => 'worstelende mannen: lichtgetinte huidskleur, lichte huidskleur',
    '👨🏼‍🫯‍👨🏽' => 'worstelende mannen: lichtgetinte huidskleur, getinte huidskleur',
    '👨🏼‍🫯‍👨🏾' => 'worstelende mannen: lichtgetinte huidskleur, donkergetinte huidskleur',
    '👨🏼‍🫯‍👨🏿' => 'worstelende mannen: lichtgetinte huidskleur, donkere huidskleur',
    '👨🏽‍🫯‍👨🏻' => 'worstelende mannen: getinte huidskleur, lichte huidskleur',
    '👨🏽‍🫯‍👨🏼' => 'worstelende mannen: getinte huidskleur, lichtgetinte huidskleur',
    '👨🏽‍🫯‍👨🏾' => 'worstelende mannen: getinte huidskleur, donkergetinte huidskleur',
    '👨🏽‍🫯‍👨🏿' => 'worstelende mannen: getinte huidskleur, donkere huidskleur',
    '👨🏾‍🫯‍👨🏻' => 'worstelende mannen: donkergetinte huidskleur, lichte huidskleur',
    '👨🏾‍🫯‍👨🏼' => 'worstelende mannen: donkergetinte huidskleur, lichtgetinte huidskleur',
    '👨🏾‍🫯‍👨🏽' => 'worstelende mannen: donkergetinte huidskleur, getinte huidskleur',
    '👨🏾‍🫯‍👨🏿' => 'worstelende mannen: donkergetinte huidskleur, donkere huidskleur',
    '👨🏿‍🫯‍👨🏻' => 'worstelende mannen: donkere huidskleur, lichte huidskleur',
    '👨🏿‍🫯‍👨🏼' => 'worstelende mannen: donkere huidskleur, lichtgetinte huidskleur',
    '👨🏿‍🫯‍👨🏽' => 'worstelende mannen: donkere huidskleur, getinte huidskleur',
    '👨🏿‍🫯‍👨🏾' => 'worstelende mannen: donkere huidskleur, donkergetinte huidskleur',
    '👨🏻‍❤‍👨🏻' => 'stel met hart: man, man, lichte huidskleur',
    '👨🏻‍❤‍👨🏼' => 'stel met hart: man, man, lichte huidskleur, lichtgetinte huidskleur',
    '👨🏻‍❤‍👨🏽' => 'stel met hart: man, man, lichte huidskleur, getinte huidskleur',
    '👨🏻‍❤‍👨🏾' => 'stel met hart: man, man, lichte huidskleur, donkergetinte huidskleur',
    '👨🏻‍❤‍👨🏿' => 'stel met hart: man, man, lichte huidskleur, donkere huidskleur',
    '👨🏼‍❤‍👨🏻' => 'stel met hart: man, man, lichtgetinte huidskleur, lichte huidskleur',
    '👨🏼‍❤‍👨🏼' => 'stel met hart: man, man, lichtgetinte huidskleur',
    '👨🏼‍❤‍👨🏽' => 'stel met hart: man, man, lichtgetinte huidskleur, getinte huidskleur',
    '👨🏼‍❤‍👨🏾' => 'stel met hart: man, man, lichtgetinte huidskleur, donkergetinte huidskleur',
    '👨🏼‍❤‍👨🏿' => 'stel met hart: man, man, lichtgetinte huidskleur, donkere huidskleur',
    '👨🏽‍❤‍👨🏻' => 'stel met hart: man, man, getinte huidskleur, lichte huidskleur',
    '👨🏽‍❤‍👨🏼' => 'stel met hart: man, man, getinte huidskleur, lichtgetinte huidskleur',
    '👨🏽‍❤‍👨🏽' => 'stel met hart: man, man, getinte huidskleur',
    '👨🏽‍❤‍👨🏾' => 'stel met hart: man, man, getinte huidskleur, donkergetinte huidskleur',
    '👨🏽‍❤‍👨🏿' => 'stel met hart: man, man, getinte huidskleur, donkere huidskleur',
    '👨🏾‍❤‍👨🏻' => 'stel met hart: man, man, donkergetinte huidskleur, lichte huidskleur',
    '👨🏾‍❤‍👨🏼' => 'stel met hart: man, man, donkergetinte huidskleur, lichtgetinte huidskleur',
    '👨🏾‍❤‍👨🏽' => 'stel met hart: man, man, donkergetinte huidskleur, getinte huidskleur',
    '👨🏾‍❤‍👨🏾' => 'stel met hart: man, man, donkergetinte huidskleur',
    '👨🏾‍❤‍👨🏿' => 'stel met hart: man, man, donkergetinte huidskleur, donkere huidskleur',
    '👨🏿‍❤‍👨🏻' => 'stel met hart: man, man, donkere huidskleur, lichte huidskleur',
    '👨🏿‍❤‍👨🏼' => 'stel met hart: man, man, donkere huidskleur, lichtgetinte huidskleur',
    '👨🏿‍❤‍👨🏽' => 'stel met hart: man, man, donkere huidskleur, getinte huidskleur',
    '👨🏿‍❤‍👨🏾' => 'stel met hart: man, man, donkere huidskleur, donkergetinte huidskleur',
    '👨🏿‍❤‍👨🏿' => 'stel met hart: man, man, donkere huidskleur',
    '👨🏻‍🐰‍👨🏼' => 'mannen met konijnenoren: lichte huidskleur, lichtgetinte huidskleur',
    '👨🏻‍🐰‍👨🏽' => 'mannen met konijnenoren: lichte huidskleur, getinte huidskleur',
    '👨🏻‍🐰‍👨🏾' => 'mannen met konijnenoren: lichte huidskleur, donkergetinte huidskleur',
    '👨🏻‍🐰‍👨🏿' => 'mannen met konijnenoren: lichte huidskleur, donkere huidskleur',
    '👨🏼‍🐰‍👨🏻' => 'mannen met konijnenoren: lichtgetinte huidskleur, lichte huidskleur',
    '👨🏼‍🐰‍👨🏽' => 'mannen met konijnenoren: lichtgetinte huidskleur, getinte huidskleur',
    '👨🏼‍🐰‍👨🏾' => 'mannen met konijnenoren: lichtgetinte huidskleur, donkergetinte huidskleur',
    '👨🏼‍🐰‍👨🏿' => 'mannen met konijnenoren: lichtgetinte huidskleur, donkere huidskleur',
    '👨🏽‍🐰‍👨🏻' => 'mannen met konijnenoren: getinte huidskleur, lichte huidskleur',
    '👨🏽‍🐰‍👨🏼' => 'mannen met konijnenoren: getinte huidskleur, lichtgetinte huidskleur',
    '👨🏽‍🐰‍👨🏾' => 'mannen met konijnenoren: getinte huidskleur, donkergetinte huidskleur',
    '👨🏽‍🐰‍👨🏿' => 'mannen met konijnenoren: getinte huidskleur, donkere huidskleur',
    '👨🏾‍🐰‍👨🏻' => 'mannen met konijnenoren: donkergetinte huidskleur, lichte huidskleur',
    '👨🏾‍🐰‍👨🏼' => 'mannen met konijnenoren: donkergetinte huidskleur, lichtgetinte huidskleur',
    '👨🏾‍🐰‍👨🏽' => 'mannen met konijnenoren: donkergetinte huidskleur, getinte huidskleur',
    '👨🏾‍🐰‍👨🏿' => 'mannen met konijnenoren: donkergetinte huidskleur, donkere huidskleur',
    '👨🏿‍🐰‍👨🏻' => 'mannen met konijnenoren: donkere huidskleur, lichte huidskleur',
    '👨🏿‍🐰‍👨🏼' => 'mannen met konijnenoren: donkere huidskleur, lichtgetinte huidskleur',
    '👨🏿‍🐰‍👨🏽' => 'mannen met konijnenoren: donkere huidskleur, getinte huidskleur',
    '👨🏿‍🐰‍👨🏾' => 'mannen met konijnenoren: donkere huidskleur, donkergetinte huidskleur',
    '👩🏻‍🫯‍👩🏼' => 'worstelende vrouwen: lichte huidskleur, lichtgetinte huidskleur',
    '👩🏻‍🫯‍👩🏽' => 'worstelende vrouwen: lichte huidskleur, getinte huidskleur',
    '👩🏻‍🫯‍👩🏾' => 'worstelende vrouwen: lichte huidskleur, donkergetinte huidskleur',
    '👩🏻‍🫯‍👩🏿' => 'worstelende vrouwen: lichte huidskleur, donkere huidskleur',
    '👩🏼‍🫯‍👩🏻' => 'worstelende vrouwen: lichtgetinte huidskleur, lichte huidskleur',
    '👩🏼‍🫯‍👩🏽' => 'worstelende vrouwen: lichtgetinte huidskleur, getinte huidskleur',
    '👩🏼‍🫯‍👩🏾' => 'worstelende vrouwen: lichtgetinte huidskleur, donkergetinte huidskleur',
    '👩🏼‍🫯‍👩🏿' => 'worstelende vrouwen: lichtgetinte huidskleur, donkere huidskleur',
    '👩🏽‍🫯‍👩🏻' => 'worstelende vrouwen: getinte huidskleur, lichte huidskleur',
    '👩🏽‍🫯‍👩🏼' => 'worstelende vrouwen: getinte huidskleur, lichtgetinte huidskleur',
    '👩🏽‍🫯‍👩🏾' => 'worstelende vrouwen: getinte huidskleur, donkergetinte huidskleur',
    '👩🏽‍🫯‍👩🏿' => 'worstelende vrouwen: getinte huidskleur, donkere huidskleur',
    '👩🏾‍🫯‍👩🏻' => 'worstelende vrouwen: donkergetinte huidskleur, lichte huidskleur',
    '👩🏾‍🫯‍👩🏼' => 'worstelende vrouwen: donkergetinte huidskleur, lichtgetinte huidskleur',
    '👩🏾‍🫯‍👩🏽' => 'worstelende vrouwen: donkergetinte huidskleur, getinte huidskleur',
    '👩🏾‍🫯‍👩🏿' => 'worstelende vrouwen: donkergetinte huidskleur, donkere huidskleur',
    '👩🏿‍🫯‍👩🏻' => 'worstelende vrouwen: donkere huidskleur, lichte huidskleur',
    '👩🏿‍🫯‍👩🏼' => 'worstelende vrouwen: donkere huidskleur, lichtgetinte huidskleur',
    '👩🏿‍🫯‍👩🏽' => 'worstelende vrouwen: donkere huidskleur, getinte huidskleur',
    '👩🏿‍🫯‍👩🏾' => 'worstelende vrouwen: donkere huidskleur, donkergetinte huidskleur',
    '👩🏻‍❤‍👨🏻' => 'stel met hart: vrouw, man, lichte huidskleur',
    '👩🏻‍❤‍👨🏼' => 'stel met hart: vrouw, man, lichte huidskleur, lichtgetinte huidskleur',
    '👩🏻‍❤‍👨🏽' => 'stel met hart: vrouw, man, lichte huidskleur, getinte huidskleur',
    '👩🏻‍❤‍👨🏾' => 'stel met hart: vrouw, man, lichte huidskleur, donkergetinte huidskleur',
    '👩🏻‍❤‍👨🏿' => 'stel met hart: vrouw, man, lichte huidskleur, donkere huidskleur',
    '👩🏼‍❤‍👨🏻' => 'stel met hart: vrouw, man, lichtgetinte huidskleur, lichte huidskleur',
    '👩🏼‍❤‍👨🏼' => 'stel met hart: vrouw, man, lichtgetinte huidskleur',
    '👩🏼‍❤‍👨🏽' => 'stel met hart: vrouw, man, lichtgetinte huidskleur, getinte huidskleur',
    '👩🏼‍❤‍👨🏾' => 'stel met hart: vrouw, man, lichtgetinte huidskleur, donkergetinte huidskleur',
    '👩🏼‍❤‍👨🏿' => 'stel met hart: vrouw, man, lichtgetinte huidskleur, donkere huidskleur',
    '👩🏽‍❤‍👨🏻' => 'stel met hart: vrouw, man, getinte huidskleur, lichte huidskleur',
    '👩🏽‍❤‍👨🏼' => 'stel met hart: vrouw, man, getinte huidskleur, lichtgetinte huidskleur',
    '👩🏽‍❤‍👨🏽' => 'stel met hart: vrouw, man, getinte huidskleur',
    '👩🏽‍❤‍👨🏾' => 'stel met hart: vrouw, man, getinte huidskleur, donkergetinte huidskleur',
    '👩🏽‍❤‍👨🏿' => 'stel met hart: vrouw, man, getinte huidskleur, donkere huidskleur',
    '👩🏾‍❤‍👨🏻' => 'stel met hart: vrouw, man, donkergetinte huidskleur, lichte huidskleur',
    '👩🏾‍❤‍👨🏼' => 'stel met hart: vrouw, man, donkergetinte huidskleur, lichtgetinte huidskleur',
    '👩🏾‍❤‍👨🏽' => 'stel met hart: vrouw, man, donkergetinte huidskleur, getinte huidskleur',
    '👩🏾‍❤‍👨🏾' => 'stel met hart: vrouw, man, donkergetinte huidskleur',
    '👩🏾‍❤‍👨🏿' => 'stel met hart: vrouw, man, donkergetinte huidskleur, donkere huidskleur',
    '👩🏿‍❤‍👨🏻' => 'stel met hart: vrouw, man, donkere huidskleur, lichte huidskleur',
    '👩🏿‍❤‍👨🏼' => 'stel met hart: vrouw, man, donkere huidskleur, lichtgetinte huidskleur',
    '👩🏿‍❤‍👨🏽' => 'stel met hart: vrouw, man, donkere huidskleur, getinte huidskleur',
    '👩🏿‍❤‍👨🏾' => 'stel met hart: vrouw, man, donkere huidskleur, donkergetinte huidskleur',
    '👩🏿‍❤‍👨🏿' => 'stel met hart: vrouw, man, donkere huidskleur',
    '👩🏻‍❤‍👩🏻' => 'stel met hart: vrouw, vrouw, lichte huidskleur',
    '👩🏻‍❤‍👩🏼' => 'stel met hart: vrouw, vrouw, lichte huidskleur, lichtgetinte huidskleur',
    '👩🏻‍❤‍👩🏽' => 'stel met hart: vrouw, vrouw, lichte huidskleur, getinte huidskleur',
    '👩🏻‍❤‍👩🏾' => 'stel met hart: vrouw, vrouw, lichte huidskleur, donkergetinte huidskleur',
    '👩🏻‍❤‍👩🏿' => 'stel met hart: vrouw, vrouw, lichte huidskleur, donkere huidskleur',
    '👩🏼‍❤‍👩🏻' => 'stel met hart: vrouw, vrouw, lichtgetinte huidskleur, lichte huidskleur',
    '👩🏼‍❤‍👩🏼' => 'stel met hart: vrouw, vrouw, lichtgetinte huidskleur',
    '👩🏼‍❤‍👩🏽' => 'stel met hart: vrouw, vrouw, lichtgetinte huidskleur, getinte huidskleur',
    '👩🏼‍❤‍👩🏾' => 'stel met hart: vrouw, vrouw, lichtgetinte huidskleur, donkergetinte huidskleur',
    '👩🏼‍❤‍👩🏿' => 'stel met hart: vrouw, vrouw, lichtgetinte huidskleur, donkere huidskleur',
    '👩🏽‍❤‍👩🏻' => 'stel met hart: vrouw, vrouw, getinte huidskleur, lichte huidskleur',
    '👩🏽‍❤‍👩🏼' => 'stel met hart: vrouw, vrouw, getinte huidskleur, lichtgetinte huidskleur',
    '👩🏽‍❤‍👩🏽' => 'stel met hart: vrouw, vrouw, getinte huidskleur',
    '👩🏽‍❤‍👩🏾' => 'stel met hart: vrouw, vrouw, getinte huidskleur, donkergetinte huidskleur',
    '👩🏽‍❤‍👩🏿' => 'stel met hart: vrouw, vrouw, getinte huidskleur, donkere huidskleur',
    '👩🏾‍❤‍👩🏻' => 'stel met hart: vrouw, vrouw, donkergetinte huidskleur, lichte huidskleur',
    '👩🏾‍❤‍👩🏼' => 'stel met hart: vrouw, vrouw, donkergetinte huidskleur, lichtgetinte huidskleur',
    '👩🏾‍❤‍👩🏽' => 'stel met hart: vrouw, vrouw, donkergetinte huidskleur, getinte huidskleur',
    '👩🏾‍❤‍👩🏾' => 'stel met hart: vrouw, vrouw, donkergetinte huidskleur',
    '👩🏾‍❤‍👩🏿' => 'stel met hart: vrouw, vrouw, donkergetinte huidskleur, donkere huidskleur',
    '👩🏿‍❤‍👩🏻' => 'stel met hart: vrouw, vrouw, donkere huidskleur, lichte huidskleur',
    '👩🏿‍❤‍👩🏼' => 'stel met hart: vrouw, vrouw, donkere huidskleur, lichtgetinte huidskleur',
    '👩🏿‍❤‍👩🏽' => 'stel met hart: vrouw, vrouw, donkere huidskleur, getinte huidskleur',
    '👩🏿‍❤‍👩🏾' => 'stel met hart: vrouw, vrouw, donkere huidskleur, donkergetinte huidskleur',
    '👩🏿‍❤‍👩🏿' => 'stel met hart: vrouw, vrouw, donkere huidskleur',
    '👩🏻‍🐰‍👩🏼' => 'vrouwen met konijnenoren: lichte huidskleur, lichtgetinte huidskleur',
    '👩🏻‍🐰‍👩🏽' => 'vrouwen met konijnenoren: lichte huidskleur, getinte huidskleur',
    '👩🏻‍🐰‍👩🏾' => 'vrouwen met konijnenoren: lichte huidskleur, donkergetinte huidskleur',
    '👩🏻‍🐰‍👩🏿' => 'vrouwen met konijnenoren: lichte huidskleur, donkere huidskleur',
    '👩🏼‍🐰‍👩🏻' => 'vrouwen met konijnenoren: lichtgetinte huidskleur, lichte huidskleur',
    '👩🏼‍🐰‍👩🏽' => 'vrouwen met konijnenoren: lichtgetinte huidskleur, getinte huidskleur',
    '👩🏼‍🐰‍👩🏾' => 'vrouwen met konijnenoren: lichtgetinte huidskleur, donkergetinte huidskleur',
    '👩🏼‍🐰‍👩🏿' => 'vrouwen met konijnenoren: lichtgetinte huidskleur, donkere huidskleur',
    '👩🏽‍🐰‍👩🏻' => 'vrouwen met konijnenoren: getinte huidskleur, lichte huidskleur',
    '👩🏽‍🐰‍👩🏼' => 'vrouwen met konijnenoren: getinte huidskleur, lichtgetinte huidskleur',
    '👩🏽‍🐰‍👩🏾' => 'vrouwen met konijnenoren: getinte huidskleur, donkergetinte huidskleur',
    '👩🏽‍🐰‍👩🏿' => 'vrouwen met konijnenoren: getinte huidskleur, donkere huidskleur',
    '👩🏾‍🐰‍👩🏻' => 'vrouwen met konijnenoren: donkergetinte huidskleur, lichte huidskleur',
    '👩🏾‍🐰‍👩🏼' => 'vrouwen met konijnenoren: donkergetinte huidskleur, lichtgetinte huidskleur',
    '👩🏾‍🐰‍👩🏽' => 'vrouwen met konijnenoren: donkergetinte huidskleur, getinte huidskleur',
    '👩🏾‍🐰‍👩🏿' => 'vrouwen met konijnenoren: donkergetinte huidskleur, donkere huidskleur',
    '👩🏿‍🐰‍👩🏻' => 'vrouwen met konijnenoren: donkere huidskleur, lichte huidskleur',
    '👩🏿‍🐰‍👩🏼' => 'vrouwen met konijnenoren: donkere huidskleur, lichtgetinte huidskleur',
    '👩🏿‍🐰‍👩🏽' => 'vrouwen met konijnenoren: donkere huidskleur, getinte huidskleur',
    '👩🏿‍🐰‍👩🏾' => 'vrouwen met konijnenoren: donkere huidskleur, donkergetinte huidskleur',
    '🧑🏻‍🤝‍🧑🏻' => 'personen hand in hand: lichte huidskleur',
    '🧑🏻‍🤝‍🧑🏼' => 'personen hand in hand: lichte huidskleur, lichtgetinte huidskleur',
    '🧑🏻‍🤝‍🧑🏽' => 'personen hand in hand: lichte huidskleur, getinte huidskleur',
    '🧑🏻‍🤝‍🧑🏾' => 'personen hand in hand: lichte huidskleur, donkergetinte huidskleur',
    '🧑🏻‍🤝‍🧑🏿' => 'personen hand in hand: lichte huidskleur, donkere huidskleur',
    '🧑🏼‍🤝‍🧑🏻' => 'personen hand in hand: lichtgetinte huidskleur, lichte huidskleur',
    '🧑🏼‍🤝‍🧑🏼' => 'personen hand in hand: lichtgetinte huidskleur',
    '🧑🏼‍🤝‍🧑🏽' => 'personen hand in hand: lichtgetinte huidskleur, getinte huidskleur',
    '🧑🏼‍🤝‍🧑🏾' => 'personen hand in hand: lichtgetinte huidskleur, donkergetinte huidskleur',
    '🧑🏼‍🤝‍🧑🏿' => 'personen hand in hand: lichtgetinte huidskleur, donkere huidskleur',
    '🧑🏽‍🤝‍🧑🏻' => 'personen hand in hand: getinte huidskleur, lichte huidskleur',
    '🧑🏽‍🤝‍🧑🏼' => 'personen hand in hand: getinte huidskleur, lichtgetinte huidskleur',
    '🧑🏽‍🤝‍🧑🏽' => 'personen hand in hand: getinte huidskleur',
    '🧑🏽‍🤝‍🧑🏾' => 'personen hand in hand: getinte huidskleur, donkergetinte huidskleur',
    '🧑🏽‍🤝‍🧑🏿' => 'personen hand in hand: getinte huidskleur, donkere huidskleur',
    '🧑🏾‍🤝‍🧑🏻' => 'personen hand in hand: donkergetinte huidskleur, lichte huidskleur',
    '🧑🏾‍🤝‍🧑🏼' => 'personen hand in hand: donkergetinte huidskleur, lichtgetinte huidskleur',
    '🧑🏾‍🤝‍🧑🏽' => 'personen hand in hand: donkergetinte huidskleur, getinte huidskleur',
    '🧑🏾‍🤝‍🧑🏾' => 'personen hand in hand: donkergetinte huidskleur',
    '🧑🏾‍🤝‍🧑🏿' => 'personen hand in hand: donkergetinte huidskleur, donkere huidskleur',
    '🧑🏿‍🤝‍🧑🏻' => 'personen hand in hand: donkere huidskleur, lichte huidskleur',
    '🧑🏿‍🤝‍🧑🏼' => 'personen hand in hand: donkere huidskleur, lichtgetinte huidskleur',
    '🧑🏿‍🤝‍🧑🏽' => 'personen hand in hand: donkere huidskleur, getinte huidskleur',
    '🧑🏿‍🤝‍🧑🏾' => 'personen hand in hand: donkere huidskleur, donkergetinte huidskleur',
    '🧑🏿‍🤝‍🧑🏿' => 'personen hand in hand: donkere huidskleur',
    '👩🏻‍🤝‍👩🏼' => 'vrouwen hand in hand: lichte huidskleur, lichtgetinte huidskleur',
    '👩🏻‍🤝‍👩🏽' => 'vrouwen hand in hand: lichte huidskleur, getinte huidskleur',
    '👩🏻‍🤝‍👩🏾' => 'vrouwen hand in hand: lichte huidskleur, donkergetinte huidskleur',
    '👩🏻‍🤝‍👩🏿' => 'vrouwen hand in hand: lichte huidskleur, donkere huidskleur',
    '👩🏼‍🤝‍👩🏻' => 'vrouwen hand in hand: lichtgetinte huidskleur, lichte huidskleur',
    '👩🏼‍🤝‍👩🏽' => 'vrouwen hand in hand: lichtgetinte huidskleur, getinte huidskleur',
    '👩🏼‍🤝‍👩🏾' => 'vrouwen hand in hand: lichtgetinte huidskleur, donkergetinte huidskleur',
    '👩🏼‍🤝‍👩🏿' => 'vrouwen hand in hand: lichtgetinte huidskleur, donkere huidskleur',
    '👩🏽‍🤝‍👩🏻' => 'vrouwen hand in hand: getinte huidskleur, lichte huidskleur',
    '👩🏽‍🤝‍👩🏼' => 'vrouwen hand in hand: getinte huidskleur, lichtgetinte huidskleur',
    '👩🏽‍🤝‍👩🏾' => 'vrouwen hand in hand: getinte huidskleur, donkergetinte huidskleur',
    '👩🏽‍🤝‍👩🏿' => 'vrouwen hand in hand: getinte huidskleur, donkere huidskleur',
    '👩🏾‍🤝‍👩🏻' => 'vrouwen hand in hand: donkergetinte huidskleur, lichte huidskleur',
    '👩🏾‍🤝‍👩🏼' => 'vrouwen hand in hand: donkergetinte huidskleur, lichtgetinte huidskleur',
    '👩🏾‍🤝‍👩🏽' => 'vrouwen hand in hand: donkergetinte huidskleur, getinte huidskleur',
    '👩🏾‍🤝‍👩🏿' => 'vrouwen hand in hand: donkergetinte huidskleur, donkere huidskleur',
    '👩🏿‍🤝‍👩🏻' => 'vrouwen hand in hand: donkere huidskleur, lichte huidskleur',
    '👩🏿‍🤝‍👩🏼' => 'vrouwen hand in hand: donkere huidskleur, lichtgetinte huidskleur',
    '👩🏿‍🤝‍👩🏽' => 'vrouwen hand in hand: donkere huidskleur, getinte huidskleur',
    '👩🏿‍🤝‍👩🏾' => 'vrouwen hand in hand: donkere huidskleur, donkergetinte huidskleur',
    '👩🏻‍🤝‍👨🏼' => 'man en vrouw hand in hand: lichte huidskleur, lichtgetinte huidskleur',
    '👩🏻‍🤝‍👨🏽' => 'man en vrouw hand in hand: lichte huidskleur, getinte huidskleur',
    '👩🏻‍🤝‍👨🏾' => 'man en vrouw hand in hand: lichte huidskleur, donkergetinte huidskleur',
    '👩🏻‍🤝‍👨🏿' => 'man en vrouw hand in hand: lichte huidskleur, donkere huidskleur',
    '👩🏼‍🤝‍👨🏻' => 'man en vrouw hand in hand: lichtgetinte huidskleur, lichte huidskleur',
    '👩🏼‍🤝‍👨🏽' => 'man en vrouw hand in hand: lichtgetinte huidskleur, getinte huidskleur',
    '👩🏼‍🤝‍👨🏾' => 'man en vrouw hand in hand: lichtgetinte huidskleur, donkergetinte huidskleur',
    '👩🏼‍🤝‍👨🏿' => 'man en vrouw hand in hand: lichtgetinte huidskleur, donkere huidskleur',
    '👩🏽‍🤝‍👨🏻' => 'man en vrouw hand in hand: getinte huidskleur, lichte huidskleur',
    '👩🏽‍🤝‍👨🏼' => 'man en vrouw hand in hand: getinte huidskleur, lichtgetinte huidskleur',
    '👩🏽‍🤝‍👨🏾' => 'man en vrouw hand in hand: getinte huidskleur, donkergetinte huidskleur',
    '👩🏽‍🤝‍👨🏿' => 'man en vrouw hand in hand: getinte huidskleur, donkere huidskleur',
    '👩🏾‍🤝‍👨🏻' => 'man en vrouw hand in hand: donkergetinte huidskleur, lichte huidskleur',
    '👩🏾‍🤝‍👨🏼' => 'man en vrouw hand in hand: donkergetinte huidskleur, lichtgetinte huidskleur',
    '👩🏾‍🤝‍👨🏽' => 'man en vrouw hand in hand: donkergetinte huidskleur, getinte huidskleur',
    '👩🏾‍🤝‍👨🏿' => 'man en vrouw hand in hand: donkergetinte huidskleur, donkere huidskleur',
    '👩🏿‍🤝‍👨🏻' => 'man en vrouw hand in hand: donkere huidskleur, lichte huidskleur',
    '👩🏿‍🤝‍👨🏼' => 'man en vrouw hand in hand: donkere huidskleur, lichtgetinte huidskleur',
    '👩🏿‍🤝‍👨🏽' => 'man en vrouw hand in hand: donkere huidskleur, getinte huidskleur',
    '👩🏿‍🤝‍👨🏾' => 'man en vrouw hand in hand: donkere huidskleur, donkergetinte huidskleur',
    '👨🏻‍🤝‍👨🏼' => 'mannen hand in hand: lichte huidskleur, lichtgetinte huidskleur',
    '👨🏻‍🤝‍👨🏽' => 'mannen hand in hand: lichte huidskleur, getinte huidskleur',
    '👨🏻‍🤝‍👨🏾' => 'mannen hand in hand: lichte huidskleur, donkergetinte huidskleur',
    '👨🏻‍🤝‍👨🏿' => 'mannen hand in hand: lichte huidskleur, donkere huidskleur',
    '👨🏼‍🤝‍👨🏻' => 'mannen hand in hand: lichtgetinte huidskleur, lichte huidskleur',
    '👨🏼‍🤝‍👨🏽' => 'mannen hand in hand: lichtgetinte huidskleur, getinte huidskleur',
    '👨🏼‍🤝‍👨🏾' => 'mannen hand in hand: lichtgetinte huidskleur, donkergetinte huidskleur',
    '👨🏼‍🤝‍👨🏿' => 'mannen hand in hand: lichtgetinte huidskleur, donkere huidskleur',
    '👨🏽‍🤝‍👨🏻' => 'mannen hand in hand: getinte huidskleur, lichte huidskleur',
    '👨🏽‍🤝‍👨🏼' => 'mannen hand in hand: getinte huidskleur, lichtgetinte huidskleur',
    '👨🏽‍🤝‍👨🏾' => 'mannen hand in hand: getinte huidskleur, donkergetinte huidskleur',
    '👨🏽‍🤝‍👨🏿' => 'mannen hand in hand: getinte huidskleur, donkere huidskleur',
    '👨🏾‍🤝‍👨🏻' => 'mannen hand in hand: donkergetinte huidskleur, lichte huidskleur',
    '👨🏾‍🤝‍👨🏼' => 'mannen hand in hand: donkergetinte huidskleur, lichtgetinte huidskleur',
    '👨🏾‍🤝‍👨🏽' => 'mannen hand in hand: donkergetinte huidskleur, getinte huidskleur',
    '👨🏾‍🤝‍👨🏿' => 'mannen hand in hand: donkergetinte huidskleur, donkere huidskleur',
    '👨🏿‍🤝‍👨🏻' => 'mannen hand in hand: donkere huidskleur, lichte huidskleur',
    '👨🏿‍🤝‍👨🏼' => 'mannen hand in hand: donkere huidskleur, lichtgetinte huidskleur',
    '👨🏿‍🤝‍👨🏽' => 'mannen hand in hand: donkere huidskleur, getinte huidskleur',
    '👨🏿‍🤝‍👨🏾' => 'mannen hand in hand: donkere huidskleur, donkergetinte huidskleur',
    '👩‍❤‍💋‍👨' => 'kus: vrouw, man',
    '👨‍❤‍💋‍👨' => 'kus: man, man',
    '👩‍❤‍💋‍👩' => 'kus: vrouw, vrouw',
    '👨‍👩‍👧‍👦' => 'gezin: man, vrouw, meisje, jongen',
    '👨‍👩‍👦‍👦' => 'gezin: man, vrouw, jongen, jongen',
    '👨‍👩‍👧‍👧' => 'gezin: man, vrouw, meisje, meisje',
    '👨‍👨‍👧‍👦' => 'gezin: man, man, meisje, jongen',
    '👨‍👨‍👦‍👦' => 'gezin: man, man, jongen, jongen',
    '👨‍👨‍👧‍👧' => 'gezin: man, man, meisje, meisje',
    '👩‍👩‍👧‍👦' => 'gezin: vrouw, vrouw, meisje, jongen',
    '👩‍👩‍👦‍👦' => 'gezin: vrouw, vrouw, jongen, jongen',
    '👩‍👩‍👧‍👧' => 'gezin: vrouw, vrouw, meisje, meisje',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'vlag: Engeland',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'vlag: Schotland',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'vlag: Wales',
    '🧑‍🧑‍🧒‍🧒' => 'gezin: volwassene, volwassene, kind, kind',
    '🚶🏻‍♀‍➡' => 'wandelende vrouw: lichte huidskleur, naar rechts gericht',
    '🚶🏼‍♀‍➡' => 'wandelende vrouw: lichtgetinte huidskleur, naar rechts gericht',
    '🚶🏽‍♀‍➡' => 'wandelende vrouw: getinte huidskleur, naar rechts gericht',
    '🚶🏾‍♀‍➡' => 'wandelende vrouw: donkergetinte huidskleur, naar rechts gericht',
    '🚶🏿‍♀‍➡' => 'wandelende vrouw: donkere huidskleur, naar rechts gericht',
    '🚶🏻‍♂‍➡' => 'wandelende man: lichte huidskleur, naar rechts gericht',
    '🚶🏼‍♂‍➡' => 'wandelende man: lichtgetinte huidskleur, naar rechts gericht',
    '🚶🏽‍♂‍➡' => 'wandelende man: getinte huidskleur, naar rechts gericht',
    '🚶🏾‍♂‍➡' => 'wandelende man: donkergetinte huidskleur, naar rechts gericht',
    '🚶🏿‍♂‍➡' => 'wandelende man: donkere huidskleur, naar rechts gericht',
    '🧎🏻‍♀‍➡' => 'knielende vrouw: lichte huidskleur, naar rechts gericht',
    '🧎🏼‍♀‍➡' => 'knielende vrouw: lichtgetinte huidskleur, naar rechts gericht',
    '🧎🏽‍♀‍➡' => 'knielende vrouw: getinte huidskleur, naar rechts gericht',
    '🧎🏾‍♀‍➡' => 'knielende vrouw: donkergetinte huidskleur, naar rechts gericht',
    '🧎🏿‍♀‍➡' => 'knielende vrouw: donkere huidskleur, naar rechts gericht',
    '🧎🏻‍♂‍➡' => 'knielende man: lichte huidskleur, naar rechts gericht',
    '🧎🏼‍♂‍➡' => 'knielende man: lichtgetinte huidskleur, naar rechts gericht',
    '🧎🏽‍♂‍➡' => 'knielende man: getinte huidskleur, naar rechts gericht',
    '🧎🏾‍♂‍➡' => 'knielende man: donkergetinte huidskleur, naar rechts gericht',
    '🧎🏿‍♂‍➡' => 'knielende man: donkere huidskleur, naar rechts gericht',
    '🧑🏻‍🦯‍➡' => 'persoon met taststok: lichte huidskleur, naar rechts gericht',
    '🧑🏼‍🦯‍➡' => 'persoon met taststok: lichtgetinte huidskleur, naar rechts gericht',
    '🧑🏽‍🦯‍➡' => 'persoon met taststok: getinte huidskleur, naar rechts gericht',
    '🧑🏾‍🦯‍➡' => 'persoon met taststok: donkergetinte huidskleur, naar rechts gericht',
    '🧑🏿‍🦯‍➡' => 'persoon met taststok: donkere huidskleur, naar rechts gericht',
    '👨🏻‍🦯‍➡' => 'man met taststok: lichte huidskleur, naar rechts gericht',
    '👨🏼‍🦯‍➡' => 'man met taststok: lichtgetinte huidskleur, naar rechts gericht',
    '👨🏽‍🦯‍➡' => 'man met taststok: getinte huidskleur, naar rechts gericht',
    '👨🏾‍🦯‍➡' => 'man met taststok: donkergetinte huidskleur, naar rechts gericht',
    '👨🏿‍🦯‍➡' => 'man met taststok: donkere huidskleur, naar rechts gericht',
    '👩🏻‍🦯‍➡' => 'vrouw met taststok: lichte huidskleur, naar rechts gericht',
    '👩🏼‍🦯‍➡' => 'vrouw met taststok: lichtgetinte huidskleur, naar rechts gericht',
    '👩🏽‍🦯‍➡' => 'vrouw met taststok: getinte huidskleur, naar rechts gericht',
    '👩🏾‍🦯‍➡' => 'vrouw met taststok: donkergetinte huidskleur, naar rechts gericht',
    '👩🏿‍🦯‍➡' => 'vrouw met taststok: donkere huidskleur, naar rechts gericht',
    '🧑🏻‍🦼‍➡' => 'persoon in elektrische rolstoel: lichte huidskleur, naar rechts gericht',
    '🧑🏼‍🦼‍➡' => 'persoon in elektrische rolstoel: lichtgetinte huidskleur, naar rechts gericht',
    '🧑🏽‍🦼‍➡' => 'persoon in elektrische rolstoel: getinte huidskleur, naar rechts gericht',
    '🧑🏾‍🦼‍➡' => 'persoon in elektrische rolstoel: donkergetinte huidskleur, naar rechts gericht',
    '🧑🏿‍🦼‍➡' => 'persoon in elektrische rolstoel: donkere huidskleur, naar rechts gericht',
    '👨🏻‍🦼‍➡' => 'man in elektrische rolstoel: lichte huidskleur, naar rechts gericht',
    '👨🏼‍🦼‍➡' => 'man in elektrische rolstoel: lichtgetinte huidskleur, naar rechts gericht',
    '👨🏽‍🦼‍➡' => 'man in elektrische rolstoel: getinte huidskleur, naar rechts gericht',
    '👨🏾‍🦼‍➡' => 'man in elektrische rolstoel: donkergetinte huidskleur, naar rechts gericht',
    '👨🏿‍🦼‍➡' => 'man in elektrische rolstoel: donkere huidskleur, naar rechts gericht',
    '👩🏻‍🦼‍➡' => 'vrouw in elektrische rolstoel: lichte huidskleur, naar rechts gericht',
    '👩🏼‍🦼‍➡' => 'vrouw in elektrische rolstoel: lichtgetinte huidskleur, naar rechts gericht',
    '👩🏽‍🦼‍➡' => 'vrouw in elektrische rolstoel: getinte huidskleur, naar rechts gericht',
    '👩🏾‍🦼‍➡' => 'vrouw in elektrische rolstoel: donkergetinte huidskleur, naar rechts gericht',
    '👩🏿‍🦼‍➡' => 'vrouw in elektrische rolstoel: donkere huidskleur, naar rechts gericht',
    '🧑🏻‍🦽‍➡' => 'persoon in rolstoel: lichte huidskleur, naar rechts gericht',
    '🧑🏼‍🦽‍➡' => 'persoon in rolstoel: lichtgetinte huidskleur, naar rechts gericht',
    '🧑🏽‍🦽‍➡' => 'persoon in rolstoel: getinte huidskleur, naar rechts gericht',
    '🧑🏾‍🦽‍➡' => 'persoon in rolstoel: donkergetinte huidskleur, naar rechts gericht',
    '🧑🏿‍🦽‍➡' => 'persoon in rolstoel: donkere huidskleur, naar rechts gericht',
    '👨🏻‍🦽‍➡' => 'man in rolstoel: lichte huidskleur, naar rechts gericht',
    '👨🏼‍🦽‍➡' => 'man in rolstoel: lichtgetinte huidskleur, naar rechts gericht',
    '👨🏽‍🦽‍➡' => 'man in rolstoel: getinte huidskleur, naar rechts gericht',
    '👨🏾‍🦽‍➡' => 'man in rolstoel: donkergetinte huidskleur, naar rechts gericht',
    '👨🏿‍🦽‍➡' => 'man in rolstoel: donkere huidskleur, naar rechts gericht',
    '👩🏻‍🦽‍➡' => 'vrouw in rolstoel: lichte huidskleur, naar rechts gericht',
    '👩🏼‍🦽‍➡' => 'vrouw in rolstoel: lichtgetinte huidskleur, naar rechts gericht',
    '👩🏽‍🦽‍➡' => 'vrouw in rolstoel: getinte huidskleur, naar rechts gericht',
    '👩🏾‍🦽‍➡' => 'vrouw in rolstoel: donkergetinte huidskleur, naar rechts gericht',
    '👩🏿‍🦽‍➡' => 'vrouw in rolstoel: donkere huidskleur, naar rechts gericht',
    '🏃🏻‍♀‍➡' => 'rennende vrouw: lichte huidskleur, naar rechts gericht',
    '🏃🏼‍♀‍➡' => 'rennende vrouw: lichtgetinte huidskleur, naar rechts gericht',
    '🏃🏽‍♀‍➡' => 'rennende vrouw: getinte huidskleur, naar rechts gericht',
    '🏃🏾‍♀‍➡' => 'rennende vrouw: donkergetinte huidskleur, naar rechts gericht',
    '🏃🏿‍♀‍➡' => 'rennende vrouw: donkere huidskleur, naar rechts gericht',
    '🏃🏻‍♂‍➡' => 'rennende man: lichte huidskleur, naar rechts gericht',
    '🏃🏼‍♂‍➡' => 'rennende man: lichtgetinte huidskleur, naar rechts gericht',
    '🏃🏽‍♂‍➡' => 'rennende man: getinte huidskleur, naar rechts gericht',
    '🏃🏾‍♂‍➡' => 'rennende man: donkergetinte huidskleur, naar rechts gericht',
    '🏃🏿‍♂‍➡' => 'rennende man: donkere huidskleur, naar rechts gericht',
    '🫱🏻‍🫲🏼' => 'handdruk: lichte huidskleur, lichtgetinte huidskleur',
    '🫱🏻‍🫲🏽' => 'handdruk: lichte huidskleur, getinte huidskleur',
    '🫱🏻‍🫲🏾' => 'handdruk: lichte huidskleur, donkergetinte huidskleur',
    '🫱🏻‍🫲🏿' => 'handdruk: lichte huidskleur, donkere huidskleur',
    '🫱🏼‍🫲🏻' => 'handdruk: lichtgetinte huidskleur, lichte huidskleur',
    '🫱🏼‍🫲🏽' => 'handdruk: lichtgetinte huidskleur, getinte huidskleur',
    '🫱🏼‍🫲🏾' => 'handdruk: lichtgetinte huidskleur, donkergetinte huidskleur',
    '🫱🏼‍🫲🏿' => 'handdruk: lichtgetinte huidskleur, donkere huidskleur',
    '🫱🏽‍🫲🏻' => 'handdruk: getinte huidskleur, lichte huidskleur',
    '🫱🏽‍🫲🏼' => 'handdruk: getinte huidskleur, lichtgetinte huidskleur',
    '🫱🏽‍🫲🏾' => 'handdruk: getinte huidskleur, donkergetinte huidskleur',
    '🫱🏽‍🫲🏿' => 'handdruk: getinte huidskleur, donkere huidskleur',
    '🫱🏾‍🫲🏻' => 'handdruk: donkergetinte huidskleur, lichte huidskleur',
    '🫱🏾‍🫲🏼' => 'handdruk: donkergetinte huidskleur, lichtgetinte huidskleur',
    '🫱🏾‍🫲🏽' => 'handdruk: donkergetinte huidskleur, getinte huidskleur',
    '🫱🏾‍🫲🏿' => 'handdruk: donkergetinte huidskleur, donkere huidskleur',
    '🫱🏿‍🫲🏻' => 'handdruk: donkere huidskleur, lichte huidskleur',
    '🫱🏿‍🫲🏼' => 'handdruk: donkere huidskleur, lichtgetinte huidskleur',
    '🫱🏿‍🫲🏽' => 'handdruk: donkere huidskleur, getinte huidskleur',
    '🫱🏿‍🫲🏾' => 'handdruk: donkere huidskleur, donkergetinte huidskleur',
    '🚶‍♀‍➡' => 'wandelende vrouw: naar rechts gericht',
    '🚶‍♂‍➡' => 'wandelende man: naar rechts gericht',
    '🧎‍♀‍➡' => 'knielende vrouw: naar rechts gericht',
    '🧎‍♂‍➡' => 'knielende man: naar rechts gericht',
    '🧑‍🦯‍➡' => 'persoon met taststok: naar rechts gericht',
    '👨‍🦯‍➡' => 'man met taststok: naar rechts gericht',
    '👩‍🦯‍➡' => 'vrouw met taststok: naar rechts gericht',
    '🧑‍🦼‍➡' => 'persoon in elektrische rolstoel: naar rechts gericht',
    '👨‍🦼‍➡' => 'man in elektrische rolstoel: naar rechts gericht',
    '👩‍🦼‍➡' => 'vrouw in elektrische rolstoel: naar rechts gericht',
    '🧑‍🦽‍➡' => 'persoon in rolstoel: naar rechts gericht',
    '👨‍🦽‍➡' => 'man in rolstoel: naar rechts gericht',
    '👩‍🦽‍➡' => 'vrouw in rolstoel: naar rechts gericht',
    '🏃‍♀‍➡' => 'rennende vrouw: naar rechts gericht',
    '🏃‍♂‍➡' => 'rennende man: naar rechts gericht',
    '👩‍❤‍👨' => 'stel met hart: vrouw, man',
    '👨‍❤‍👨' => 'stel met hart: man, man',
    '👩‍❤‍👩' => 'stel met hart: vrouw, vrouw',
    '👨‍👩‍👦' => 'gezin: man, vrouw, jongen',
    '👨‍👩‍👧' => 'gezin: man, vrouw, meisje',
    '👨‍👨‍👦' => 'gezin: man, man, jongen',
    '👨‍👨‍👧' => 'gezin: man, man, meisje',
    '👩‍👩‍👦' => 'gezin: vrouw, vrouw, jongen',
    '👩‍👩‍👧' => 'gezin: vrouw, vrouw, meisje',
    '👨‍👦‍👦' => 'gezin: man, jongen, jongen',
    '👨‍👧‍👦' => 'gezin: man, meisje, jongen',
    '👨‍👧‍👧' => 'gezin: man, meisje, meisje',
    '👩‍👦‍👦' => 'gezin: vrouw, jongen, jongen',
    '👩‍👧‍👦' => 'gezin: vrouw, meisje, jongen',
    '👩‍👧‍👧' => 'gezin: vrouw, meisje, meisje',
    '🧑‍🤝‍🧑' => 'personen hand in hand',
    '🧑‍🧑‍🧒' => 'gezin: volwassene, volwassene, kind',
    '🧑‍🧒‍🧒' => 'gezin: volwassene, kind, kind',
    '🧑🏻‍🦰' => 'volwassene: lichte huidskleur, rood haar',
    '🧑🏼‍🦰' => 'volwassene: lichtgetinte huidskleur, rood haar',
    '🧑🏽‍🦰' => 'volwassene: getinte huidskleur, rood haar',
    '🧑🏾‍🦰' => 'volwassene: donkergetinte huidskleur, rood haar',
    '🧑🏿‍🦰' => 'volwassene: donkere huidskleur, rood haar',
    '🧑🏻‍🦱' => 'volwassene: lichte huidskleur, krullend haar',
    '🧑🏼‍🦱' => 'volwassene: lichtgetinte huidskleur, krullend haar',
    '🧑🏽‍🦱' => 'volwassene: getinte huidskleur, krullend haar',
    '🧑🏾‍🦱' => 'volwassene: donkergetinte huidskleur, krullend haar',
    '🧑🏿‍🦱' => 'volwassene: donkere huidskleur, krullend haar',
    '🧑🏻‍🦳' => 'volwassene: lichte huidskleur, wit haar',
    '🧑🏼‍🦳' => 'volwassene: lichtgetinte huidskleur, wit haar',
    '🧑🏽‍🦳' => 'volwassene: getinte huidskleur, wit haar',
    '🧑🏾‍🦳' => 'volwassene: donkergetinte huidskleur, wit haar',
    '🧑🏿‍🦳' => 'volwassene: donkere huidskleur, wit haar',
    '🧑🏻‍🦲' => 'volwassene: lichte huidskleur, kaal',
    '🧑🏼‍🦲' => 'volwassene: lichtgetinte huidskleur, kaal',
    '🧑🏽‍🦲' => 'volwassene: getinte huidskleur, kaal',
    '🧑🏾‍🦲' => 'volwassene: donkergetinte huidskleur, kaal',
    '🧑🏿‍🦲' => 'volwassene: donkere huidskleur, kaal',
    '🧑🏻‍🩰' => 'balletdanser: lichte huidskleur',
    '🧑🏼‍🩰' => 'balletdanser: lichtgetinte huidskleur',
    '🧑🏽‍🩰' => 'balletdanser: getinte huidskleur',
    '🧑🏾‍🩰' => 'balletdanser: donkergetinte huidskleur',
    '🧑🏿‍🩰' => 'balletdanser: donkere huidskleur',
    '🧔🏻‍♂' => 'man: lichte huidskleur, baard',
    '🧔🏼‍♂' => 'man: lichtgetinte huidskleur, baard',
    '🧔🏽‍♂' => 'man: getinte huidskleur, baard',
    '🧔🏾‍♂' => 'man: donkergetinte huidskleur, baard',
    '🧔🏿‍♂' => 'man: donkere huidskleur, baard',
    '👱🏻‍♂' => 'man met blond haar: lichte huidskleur',
    '👱🏼‍♂' => 'man met blond haar: lichtgetinte huidskleur',
    '👱🏽‍♂' => 'man met blond haar: getinte huidskleur',
    '👱🏾‍♂' => 'man met blond haar: donkergetinte huidskleur',
    '👱🏿‍♂' => 'man met blond haar: donkere huidskleur',
    '👨🏻‍🦰' => 'man: lichte huidskleur, rood haar',
    '👨🏼‍🦰' => 'man: lichtgetinte huidskleur, rood haar',
    '👨🏽‍🦰' => 'man: getinte huidskleur, rood haar',
    '👨🏾‍🦰' => 'man: donkergetinte huidskleur, rood haar',
    '👨🏿‍🦰' => 'man: donkere huidskleur, rood haar',
    '👨🏻‍🦱' => 'man: lichte huidskleur, krullend haar',
    '👨🏼‍🦱' => 'man: lichtgetinte huidskleur, krullend haar',
    '👨🏽‍🦱' => 'man: getinte huidskleur, krullend haar',
    '👨🏾‍🦱' => 'man: donkergetinte huidskleur, krullend haar',
    '👨🏿‍🦱' => 'man: donkere huidskleur, krullend haar',
    '👨🏻‍🦳' => 'man: lichte huidskleur, wit haar',
    '👨🏼‍🦳' => 'man: lichtgetinte huidskleur, wit haar',
    '👨🏽‍🦳' => 'man: getinte huidskleur, wit haar',
    '👨🏾‍🦳' => 'man: donkergetinte huidskleur, wit haar',
    '👨🏿‍🦳' => 'man: donkere huidskleur, wit haar',
    '👨🏻‍🦲' => 'man: lichte huidskleur, kaal',
    '👨🏼‍🦲' => 'man: lichtgetinte huidskleur, kaal',
    '👨🏽‍🦲' => 'man: getinte huidskleur, kaal',
    '👨🏾‍🦲' => 'man: donkergetinte huidskleur, kaal',
    '👨🏿‍🦲' => 'man: donkere huidskleur, kaal',
    '🧔🏻‍♀' => 'vrouw: lichte huidskleur, baard',
    '🧔🏼‍♀' => 'vrouw: lichtgetinte huidskleur, baard',
    '🧔🏽‍♀' => 'vrouw: getinte huidskleur, baard',
    '🧔🏾‍♀' => 'vrouw: donkergetinte huidskleur, baard',
    '🧔🏿‍♀' => 'vrouw: donkere huidskleur, baard',
    '👱🏻‍♀' => 'vrouw met blond haar: lichte huidskleur',
    '👱🏼‍♀' => 'vrouw met blond haar: lichtgetinte huidskleur',
    '👱🏽‍♀' => 'vrouw met blond haar: getinte huidskleur',
    '👱🏾‍♀' => 'vrouw met blond haar: donkergetinte huidskleur',
    '👱🏿‍♀' => 'vrouw met blond haar: donkere huidskleur',
    '👩🏻‍🦰' => 'vrouw: lichte huidskleur, rood haar',
    '👩🏼‍🦰' => 'vrouw: lichtgetinte huidskleur, rood haar',
    '👩🏽‍🦰' => 'vrouw: getinte huidskleur, rood haar',
    '👩🏾‍🦰' => 'vrouw: donkergetinte huidskleur, rood haar',
    '👩🏿‍🦰' => 'vrouw: donkere huidskleur, rood haar',
    '👩🏻‍🦱' => 'vrouw: lichte huidskleur, krullend haar',
    '👩🏼‍🦱' => 'vrouw: lichtgetinte huidskleur, krullend haar',
    '👩🏽‍🦱' => 'vrouw: getinte huidskleur, krullend haar',
    '👩🏾‍🦱' => 'vrouw: donkergetinte huidskleur, krullend haar',
    '👩🏿‍🦱' => 'vrouw: donkere huidskleur, krullend haar',
    '👩🏻‍🦳' => 'vrouw: lichte huidskleur, wit haar',
    '👩🏼‍🦳' => 'vrouw: lichtgetinte huidskleur, wit haar',
    '👩🏽‍🦳' => 'vrouw: getinte huidskleur, wit haar',
    '👩🏾‍🦳' => 'vrouw: donkergetinte huidskleur, wit haar',
    '👩🏿‍🦳' => 'vrouw: donkere huidskleur, wit haar',
    '👩🏻‍🦲' => 'vrouw: lichte huidskleur, kaal',
    '👩🏼‍🦲' => 'vrouw: lichtgetinte huidskleur, kaal',
    '👩🏽‍🦲' => 'vrouw: getinte huidskleur, kaal',
    '👩🏾‍🦲' => 'vrouw: donkergetinte huidskleur, kaal',
    '👩🏿‍🦲' => 'vrouw: donkere huidskleur, kaal',
    '🙍🏻‍♂' => 'fronsende man: lichte huidskleur',
    '🙍🏼‍♂' => 'fronsende man: lichtgetinte huidskleur',
    '🙍🏽‍♂' => 'fronsende man: getinte huidskleur',
    '🙍🏾‍♂' => 'fronsende man: donkergetinte huidskleur',
    '🙍🏿‍♂' => 'fronsende man: donkere huidskleur',
    '🙍🏻‍♀' => 'fronsende vrouw: lichte huidskleur',
    '🙍🏼‍♀' => 'fronsende vrouw: lichtgetinte huidskleur',
    '🙍🏽‍♀' => 'fronsende vrouw: getinte huidskleur',
    '🙍🏾‍♀' => 'fronsende vrouw: donkergetinte huidskleur',
    '🙍🏿‍♀' => 'fronsende vrouw: donkere huidskleur',
    '🙎🏻‍♂' => 'pruilende man: lichte huidskleur',
    '🙎🏼‍♂' => 'pruilende man: lichtgetinte huidskleur',
    '🙎🏽‍♂' => 'pruilende man: getinte huidskleur',
    '🙎🏾‍♂' => 'pruilende man: donkergetinte huidskleur',
    '🙎🏿‍♂' => 'pruilende man: donkere huidskleur',
    '🙎🏻‍♀' => 'pruilende vrouw: lichte huidskleur',
    '🙎🏼‍♀' => 'pruilende vrouw: lichtgetinte huidskleur',
    '🙎🏽‍♀' => 'pruilende vrouw: getinte huidskleur',
    '🙎🏾‍♀' => 'pruilende vrouw: donkergetinte huidskleur',
    '🙎🏿‍♀' => 'pruilende vrouw: donkere huidskleur',
    '🙅🏻‍♂' => 'man die nee-gebaar maakt: lichte huidskleur',
    '🙅🏼‍♂' => 'man die nee-gebaar maakt: lichtgetinte huidskleur',
    '🙅🏽‍♂' => 'man die nee-gebaar maakt: getinte huidskleur',
    '🙅🏾‍♂' => 'man die nee-gebaar maakt: donkergetinte huidskleur',
    '🙅🏿‍♂' => 'man die nee-gebaar maakt: donkere huidskleur',
    '🙅🏻‍♀' => 'vrouw die nee-gebaar maakt: lichte huidskleur',
    '🙅🏼‍♀' => 'vrouw die nee-gebaar maakt: lichtgetinte huidskleur',
    '🙅🏽‍♀' => 'vrouw die nee-gebaar maakt: getinte huidskleur',
    '🙅🏾‍♀' => 'vrouw die nee-gebaar maakt: donkergetinte huidskleur',
    '🙅🏿‍♀' => 'vrouw die nee-gebaar maakt: donkere huidskleur',
    '🙆🏻‍♂' => 'man die OK-gebaar maakt: lichte huidskleur',
    '🙆🏼‍♂' => 'man die OK-gebaar maakt: lichtgetinte huidskleur',
    '🙆🏽‍♂' => 'man die OK-gebaar maakt: getinte huidskleur',
    '🙆🏾‍♂' => 'man die OK-gebaar maakt: donkergetinte huidskleur',
    '🙆🏿‍♂' => 'man die OK-gebaar maakt: donkere huidskleur',
    '🙆🏻‍♀' => 'vrouw die OK-gebaar maakt: lichte huidskleur',
    '🙆🏼‍♀' => 'vrouw die OK-gebaar maakt: lichtgetinte huidskleur',
    '🙆🏽‍♀' => 'vrouw die OK-gebaar maakt: getinte huidskleur',
    '🙆🏾‍♀' => 'vrouw die OK-gebaar maakt: donkergetinte huidskleur',
    '🙆🏿‍♀' => 'vrouw die OK-gebaar maakt: donkere huidskleur',
    '💁🏻‍♂' => 'man achter informatiebalie: lichte huidskleur',
    '💁🏼‍♂' => 'man achter informatiebalie: lichtgetinte huidskleur',
    '💁🏽‍♂' => 'man achter informatiebalie: getinte huidskleur',
    '💁🏾‍♂' => 'man achter informatiebalie: donkergetinte huidskleur',
    '💁🏿‍♂' => 'man achter informatiebalie: donkere huidskleur',
    '💁🏻‍♀' => 'vrouw achter informatiebalie: lichte huidskleur',
    '💁🏼‍♀' => 'vrouw achter informatiebalie: lichtgetinte huidskleur',
    '💁🏽‍♀' => 'vrouw achter informatiebalie: getinte huidskleur',
    '💁🏾‍♀' => 'vrouw achter informatiebalie: donkergetinte huidskleur',
    '💁🏿‍♀' => 'vrouw achter informatiebalie: donkere huidskleur',
    '🙋🏻‍♂' => 'man met opgeheven hand: lichte huidskleur',
    '🙋🏼‍♂' => 'man met opgeheven hand: lichtgetinte huidskleur',
    '🙋🏽‍♂' => 'man met opgeheven hand: getinte huidskleur',
    '🙋🏾‍♂' => 'man met opgeheven hand: donkergetinte huidskleur',
    '🙋🏿‍♂' => 'man met opgeheven hand: donkere huidskleur',
    '🙋🏻‍♀' => 'vrouw met opgeheven hand: lichte huidskleur',
    '🙋🏼‍♀' => 'vrouw met opgeheven hand: lichtgetinte huidskleur',
    '🙋🏽‍♀' => 'vrouw met opgeheven hand: getinte huidskleur',
    '🙋🏾‍♀' => 'vrouw met opgeheven hand: donkergetinte huidskleur',
    '🙋🏿‍♀' => 'vrouw met opgeheven hand: donkere huidskleur',
    '🧏🏻‍♂' => 'dove man: lichte huidskleur',
    '🧏🏼‍♂' => 'dove man: lichtgetinte huidskleur',
    '🧏🏽‍♂' => 'dove man: getinte huidskleur',
    '🧏🏾‍♂' => 'dove man: donkergetinte huidskleur',
    '🧏🏿‍♂' => 'dove man: donkere huidskleur',
    '🧏🏻‍♀' => 'dove vrouw: lichte huidskleur',
    '🧏🏼‍♀' => 'dove vrouw: lichtgetinte huidskleur',
    '🧏🏽‍♀' => 'dove vrouw: getinte huidskleur',
    '🧏🏾‍♀' => 'dove vrouw: donkergetinte huidskleur',
    '🧏🏿‍♀' => 'dove vrouw: donkere huidskleur',
    '🙇🏻‍♂' => 'buigende man: lichte huidskleur',
    '🙇🏼‍♂' => 'buigende man: lichtgetinte huidskleur',
    '🙇🏽‍♂' => 'buigende man: getinte huidskleur',
    '🙇🏾‍♂' => 'buigende man: donkergetinte huidskleur',
    '🙇🏿‍♂' => 'buigende man: donkere huidskleur',
    '🙇🏻‍♀' => 'buigende vrouw: lichte huidskleur',
    '🙇🏼‍♀' => 'buigende vrouw: lichtgetinte huidskleur',
    '🙇🏽‍♀' => 'buigende vrouw: getinte huidskleur',
    '🙇🏾‍♀' => 'buigende vrouw: donkergetinte huidskleur',
    '🙇🏿‍♀' => 'buigende vrouw: donkere huidskleur',
    '🤦🏻‍♂' => 'man die het gezicht met de hand bedekt: lichte huidskleur',
    '🤦🏼‍♂' => 'man die het gezicht met de hand bedekt: lichtgetinte huidskleur',
    '🤦🏽‍♂' => 'man die het gezicht met de hand bedekt: getinte huidskleur',
    '🤦🏾‍♂' => 'man die het gezicht met de hand bedekt: donkergetinte huidskleur',
    '🤦🏿‍♂' => 'man die het gezicht met de hand bedekt: donkere huidskleur',
    '🤦🏻‍♀' => 'vrouw die het gezicht met de hand bedekt: lichte huidskleur',
    '🤦🏼‍♀' => 'vrouw die het gezicht met de hand bedekt: lichtgetinte huidskleur',
    '🤦🏽‍♀' => 'vrouw die het gezicht met de hand bedekt: getinte huidskleur',
    '🤦🏾‍♀' => 'vrouw die het gezicht met de hand bedekt: donkergetinte huidskleur',
    '🤦🏿‍♀' => 'vrouw die het gezicht met de hand bedekt: donkere huidskleur',
    '🤷🏻‍♂' => 'man die schouders ophaalt: lichte huidskleur',
    '🤷🏼‍♂' => 'man die schouders ophaalt: lichtgetinte huidskleur',
    '🤷🏽‍♂' => 'man die schouders ophaalt: getinte huidskleur',
    '🤷🏾‍♂' => 'man die schouders ophaalt: donkergetinte huidskleur',
    '🤷🏿‍♂' => 'man die schouders ophaalt: donkere huidskleur',
    '🤷🏻‍♀' => 'vrouw die schouders ophaalt: lichte huidskleur',
    '🤷🏼‍♀' => 'vrouw die schouders ophaalt: lichtgetinte huidskleur',
    '🤷🏽‍♀' => 'vrouw die schouders ophaalt: getinte huidskleur',
    '🤷🏾‍♀' => 'vrouw die schouders ophaalt: donkergetinte huidskleur',
    '🤷🏿‍♀' => 'vrouw die schouders ophaalt: donkere huidskleur',
    '🧑🏻‍⚕' => 'gezondheidsmedewerker: lichte huidskleur',
    '🧑🏼‍⚕' => 'gezondheidsmedewerker: lichtgetinte huidskleur',
    '🧑🏽‍⚕' => 'gezondheidsmedewerker: getinte huidskleur',
    '🧑🏾‍⚕' => 'gezondheidsmedewerker: donkergetinte huidskleur',
    '🧑🏿‍⚕' => 'gezondheidsmedewerker: donkere huidskleur',
    '👨🏻‍⚕' => 'mannelijke gezondheidsmedewerker: lichte huidskleur',
    '👨🏼‍⚕' => 'mannelijke gezondheidsmedewerker: lichtgetinte huidskleur',
    '👨🏽‍⚕' => 'mannelijke gezondheidsmedewerker: getinte huidskleur',
    '👨🏾‍⚕' => 'mannelijke gezondheidsmedewerker: donkergetinte huidskleur',
    '👨🏿‍⚕' => 'mannelijke gezondheidsmedewerker: donkere huidskleur',
    '👩🏻‍⚕' => 'gezondheidsmedewerkster: lichte huidskleur',
    '👩🏼‍⚕' => 'gezondheidsmedewerkster: lichtgetinte huidskleur',
    '👩🏽‍⚕' => 'gezondheidsmedewerkster: getinte huidskleur',
    '👩🏾‍⚕' => 'gezondheidsmedewerkster: donkergetinte huidskleur',
    '👩🏿‍⚕' => 'gezondheidsmedewerkster: donkere huidskleur',
    '🧑🏻‍🎓' => 'student: lichte huidskleur',
    '🧑🏼‍🎓' => 'student: lichtgetinte huidskleur',
    '🧑🏽‍🎓' => 'student: getinte huidskleur',
    '🧑🏾‍🎓' => 'student: donkergetinte huidskleur',
    '🧑🏿‍🎓' => 'student: donkere huidskleur',
    '👨🏻‍🎓' => 'mannelijke student: lichte huidskleur',
    '👨🏼‍🎓' => 'mannelijke student: lichtgetinte huidskleur',
    '👨🏽‍🎓' => 'mannelijke student: getinte huidskleur',
    '👨🏾‍🎓' => 'mannelijke student: donkergetinte huidskleur',
    '👨🏿‍🎓' => 'mannelijke student: donkere huidskleur',
    '👩🏻‍🎓' => 'studente: lichte huidskleur',
    '👩🏼‍🎓' => 'studente: lichtgetinte huidskleur',
    '👩🏽‍🎓' => 'studente: getinte huidskleur',
    '👩🏾‍🎓' => 'studente: donkergetinte huidskleur',
    '👩🏿‍🎓' => 'studente: donkere huidskleur',
    '🧑🏻‍🏫' => 'docent: lichte huidskleur',
    '🧑🏼‍🏫' => 'docent: lichtgetinte huidskleur',
    '🧑🏽‍🏫' => 'docent: getinte huidskleur',
    '🧑🏾‍🏫' => 'docent: donkergetinte huidskleur',
    '🧑🏿‍🏫' => 'docent: donkere huidskleur',
    '👨🏻‍🏫' => 'mannelijke docent: lichte huidskleur',
    '👨🏼‍🏫' => 'mannelijke docent: lichtgetinte huidskleur',
    '👨🏽‍🏫' => 'mannelijke docent: getinte huidskleur',
    '👨🏾‍🏫' => 'mannelijke docent: donkergetinte huidskleur',
    '👨🏿‍🏫' => 'mannelijke docent: donkere huidskleur',
    '👩🏻‍🏫' => 'docente: lichte huidskleur',
    '👩🏼‍🏫' => 'docente: lichtgetinte huidskleur',
    '👩🏽‍🏫' => 'docente: getinte huidskleur',
    '👩🏾‍🏫' => 'docente: donkergetinte huidskleur',
    '👩🏿‍🏫' => 'docente: donkere huidskleur',
    '🧑🏻‍⚖' => 'rechter: lichte huidskleur',
    '🧑🏼‍⚖' => 'rechter: lichtgetinte huidskleur',
    '🧑🏽‍⚖' => 'rechter: getinte huidskleur',
    '🧑🏾‍⚖' => 'rechter: donkergetinte huidskleur',
    '🧑🏿‍⚖' => 'rechter: donkere huidskleur',
    '👨🏻‍⚖' => 'mannelijke rechter: lichte huidskleur',
    '👨🏼‍⚖' => 'mannelijke rechter: lichtgetinte huidskleur',
    '👨🏽‍⚖' => 'mannelijke rechter: getinte huidskleur',
    '👨🏾‍⚖' => 'mannelijke rechter: donkergetinte huidskleur',
    '👨🏿‍⚖' => 'mannelijke rechter: donkere huidskleur',
    '👩🏻‍⚖' => 'vrouwelijke rechter: lichte huidskleur',
    '👩🏼‍⚖' => 'vrouwelijke rechter: lichtgetinte huidskleur',
    '👩🏽‍⚖' => 'vrouwelijke rechter: getinte huidskleur',
    '👩🏾‍⚖' => 'vrouwelijke rechter: donkergetinte huidskleur',
    '👩🏿‍⚖' => 'vrouwelijke rechter: donkere huidskleur',
    '🧑🏻‍🌾' => 'boer: lichte huidskleur',
    '🧑🏼‍🌾' => 'boer: lichtgetinte huidskleur',
    '🧑🏽‍🌾' => 'boer: getinte huidskleur',
    '🧑🏾‍🌾' => 'boer: donkergetinte huidskleur',
    '🧑🏿‍🌾' => 'boer: donkere huidskleur',
    '👨🏻‍🌾' => 'mannelijke boer: lichte huidskleur',
    '👨🏼‍🌾' => 'mannelijke boer: lichtgetinte huidskleur',
    '👨🏽‍🌾' => 'mannelijke boer: getinte huidskleur',
    '👨🏾‍🌾' => 'mannelijke boer: donkergetinte huidskleur',
    '👨🏿‍🌾' => 'mannelijke boer: donkere huidskleur',
    '👩🏻‍🌾' => 'boerin: lichte huidskleur',
    '👩🏼‍🌾' => 'boerin: lichtgetinte huidskleur',
    '👩🏽‍🌾' => 'boerin: getinte huidskleur',
    '👩🏾‍🌾' => 'boerin: donkergetinte huidskleur',
    '👩🏿‍🌾' => 'boerin: donkere huidskleur',
    '🧑🏻‍🍳' => 'kok: lichte huidskleur',
    '🧑🏼‍🍳' => 'kok: lichtgetinte huidskleur',
    '🧑🏽‍🍳' => 'kok: getinte huidskleur',
    '🧑🏾‍🍳' => 'kok: donkergetinte huidskleur',
    '🧑🏿‍🍳' => 'kok: donkere huidskleur',
    '👨🏻‍🍳' => 'mannelijke kok: lichte huidskleur',
    '👨🏼‍🍳' => 'mannelijke kok: lichtgetinte huidskleur',
    '👨🏽‍🍳' => 'mannelijke kok: getinte huidskleur',
    '👨🏾‍🍳' => 'mannelijke kok: donkergetinte huidskleur',
    '👨🏿‍🍳' => 'mannelijke kok: donkere huidskleur',
    '👩🏻‍🍳' => 'kokkin: lichte huidskleur',
    '👩🏼‍🍳' => 'kokkin: lichtgetinte huidskleur',
    '👩🏽‍🍳' => 'kokkin: getinte huidskleur',
    '👩🏾‍🍳' => 'kokkin: donkergetinte huidskleur',
    '👩🏿‍🍳' => 'kokkin: donkere huidskleur',
    '🧑🏻‍🔧' => 'monteur: lichte huidskleur',
    '🧑🏼‍🔧' => 'monteur: lichtgetinte huidskleur',
    '🧑🏽‍🔧' => 'monteur: getinte huidskleur',
    '🧑🏾‍🔧' => 'monteur: donkergetinte huidskleur',
    '🧑🏿‍🔧' => 'monteur: donkere huidskleur',
    '👨🏻‍🔧' => 'mannelijke monteur: lichte huidskleur',
    '👨🏼‍🔧' => 'mannelijke monteur: lichtgetinte huidskleur',
    '👨🏽‍🔧' => 'mannelijke monteur: getinte huidskleur',
    '👨🏾‍🔧' => 'mannelijke monteur: donkergetinte huidskleur',
    '👨🏿‍🔧' => 'mannelijke monteur: donkere huidskleur',
    '👩🏻‍🔧' => 'monteuse: lichte huidskleur',
    '👩🏼‍🔧' => 'monteuse: lichtgetinte huidskleur',
    '👩🏽‍🔧' => 'monteuse: getinte huidskleur',
    '👩🏾‍🔧' => 'monteuse: donkergetinte huidskleur',
    '👩🏿‍🔧' => 'monteuse: donkere huidskleur',
    '🧑🏻‍🏭' => 'fabrieksarbeider: lichte huidskleur',
    '🧑🏼‍🏭' => 'fabrieksarbeider: lichtgetinte huidskleur',
    '🧑🏽‍🏭' => 'fabrieksarbeider: getinte huidskleur',
    '🧑🏾‍🏭' => 'fabrieksarbeider: donkergetinte huidskleur',
    '🧑🏿‍🏭' => 'fabrieksarbeider: donkere huidskleur',
    '👨🏻‍🏭' => 'mannelijke fabrieksarbeider: lichte huidskleur',
    '👨🏼‍🏭' => 'mannelijke fabrieksarbeider: lichtgetinte huidskleur',
    '👨🏽‍🏭' => 'mannelijke fabrieksarbeider: getinte huidskleur',
    '👨🏾‍🏭' => 'mannelijke fabrieksarbeider: donkergetinte huidskleur',
    '👨🏿‍🏭' => 'mannelijke fabrieksarbeider: donkere huidskleur',
    '👩🏻‍🏭' => 'fabrieksarbeidster: lichte huidskleur',
    '👩🏼‍🏭' => 'fabrieksarbeidster: lichtgetinte huidskleur',
    '👩🏽‍🏭' => 'fabrieksarbeidster: getinte huidskleur',
    '👩🏾‍🏭' => 'fabrieksarbeidster: donkergetinte huidskleur',
    '👩🏿‍🏭' => 'fabrieksarbeidster: donkere huidskleur',
    '🧑🏻‍💼' => 'kantoormedewerker: lichte huidskleur',
    '🧑🏼‍💼' => 'kantoormedewerker: lichtgetinte huidskleur',
    '🧑🏽‍💼' => 'kantoormedewerker: getinte huidskleur',
    '🧑🏾‍💼' => 'kantoormedewerker: donkergetinte huidskleur',
    '🧑🏿‍💼' => 'kantoormedewerker: donkere huidskleur',
    '👨🏻‍💼' => 'mannelijke kantoormedewerker: lichte huidskleur',
    '👨🏼‍💼' => 'mannelijke kantoormedewerker: lichtgetinte huidskleur',
    '👨🏽‍💼' => 'mannelijke kantoormedewerker: getinte huidskleur',
    '👨🏾‍💼' => 'mannelijke kantoormedewerker: donkergetinte huidskleur',
    '👨🏿‍💼' => 'mannelijke kantoormedewerker: donkere huidskleur',
    '👩🏻‍💼' => 'kantoormedewerkster: lichte huidskleur',
    '👩🏼‍💼' => 'kantoormedewerkster: lichtgetinte huidskleur',
    '👩🏽‍💼' => 'kantoormedewerkster: getinte huidskleur',
    '👩🏾‍💼' => 'kantoormedewerkster: donkergetinte huidskleur',
    '👩🏿‍💼' => 'kantoormedewerkster: donkere huidskleur',
    '🧑🏻‍🔬' => 'wetenschapper: lichte huidskleur',
    '🧑🏼‍🔬' => 'wetenschapper: lichtgetinte huidskleur',
    '🧑🏽‍🔬' => 'wetenschapper: getinte huidskleur',
    '🧑🏾‍🔬' => 'wetenschapper: donkergetinte huidskleur',
    '🧑🏿‍🔬' => 'wetenschapper: donkere huidskleur',
    '👨🏻‍🔬' => 'mannelijke wetenschapper: lichte huidskleur',
    '👨🏼‍🔬' => 'mannelijke wetenschapper: lichtgetinte huidskleur',
    '👨🏽‍🔬' => 'mannelijke wetenschapper: getinte huidskleur',
    '👨🏾‍🔬' => 'mannelijke wetenschapper: donkergetinte huidskleur',
    '👨🏿‍🔬' => 'mannelijke wetenschapper: donkere huidskleur',
    '👩🏻‍🔬' => 'wetenschapster: lichte huidskleur',
    '👩🏼‍🔬' => 'wetenschapster: lichtgetinte huidskleur',
    '👩🏽‍🔬' => 'wetenschapster: getinte huidskleur',
    '👩🏾‍🔬' => 'wetenschapster: donkergetinte huidskleur',
    '👩🏿‍🔬' => 'wetenschapster: donkere huidskleur',
    '🧑🏻‍💻' => 'technoloog: lichte huidskleur',
    '🧑🏼‍💻' => 'technoloog: lichtgetinte huidskleur',
    '🧑🏽‍💻' => 'technoloog: getinte huidskleur',
    '🧑🏾‍💻' => 'technoloog: donkergetinte huidskleur',
    '🧑🏿‍💻' => 'technoloog: donkere huidskleur',
    '👨🏻‍💻' => 'mannelijke technoloog: lichte huidskleur',
    '👨🏼‍💻' => 'mannelijke technoloog: lichtgetinte huidskleur',
    '👨🏽‍💻' => 'mannelijke technoloog: getinte huidskleur',
    '👨🏾‍💻' => 'mannelijke technoloog: donkergetinte huidskleur',
    '👨🏿‍💻' => 'mannelijke technoloog: donkere huidskleur',
    '👩🏻‍💻' => 'technologe: lichte huidskleur',
    '👩🏼‍💻' => 'technologe: lichtgetinte huidskleur',
    '👩🏽‍💻' => 'technologe: getinte huidskleur',
    '👩🏾‍💻' => 'technologe: donkergetinte huidskleur',
    '👩🏿‍💻' => 'technologe: donkere huidskleur',
    '🧑🏻‍🎤' => 'zanger: lichte huidskleur',
    '🧑🏼‍🎤' => 'zanger: lichtgetinte huidskleur',
    '🧑🏽‍🎤' => 'zanger: getinte huidskleur',
    '🧑🏾‍🎤' => 'zanger: donkergetinte huidskleur',
    '🧑🏿‍🎤' => 'zanger: donkere huidskleur',
    '👨🏻‍🎤' => 'mannelijke zanger: lichte huidskleur',
    '👨🏼‍🎤' => 'mannelijke zanger: lichtgetinte huidskleur',
    '👨🏽‍🎤' => 'mannelijke zanger: getinte huidskleur',
    '👨🏾‍🎤' => 'mannelijke zanger: donkergetinte huidskleur',
    '👨🏿‍🎤' => 'mannelijke zanger: donkere huidskleur',
    '👩🏻‍🎤' => 'zangeres: lichte huidskleur',
    '👩🏼‍🎤' => 'zangeres: lichtgetinte huidskleur',
    '👩🏽‍🎤' => 'zangeres: getinte huidskleur',
    '👩🏾‍🎤' => 'zangeres: donkergetinte huidskleur',
    '👩🏿‍🎤' => 'zangeres: donkere huidskleur',
    '🧑🏻‍🎨' => 'kunstenaar: lichte huidskleur',
    '🧑🏼‍🎨' => 'kunstenaar: lichtgetinte huidskleur',
    '🧑🏽‍🎨' => 'kunstenaar: getinte huidskleur',
    '🧑🏾‍🎨' => 'kunstenaar: donkergetinte huidskleur',
    '🧑🏿‍🎨' => 'kunstenaar: donkere huidskleur',
    '👨🏻‍🎨' => 'mannelijke kunstenaar: lichte huidskleur',
    '👨🏼‍🎨' => 'mannelijke kunstenaar: lichtgetinte huidskleur',
    '👨🏽‍🎨' => 'mannelijke kunstenaar: getinte huidskleur',
    '👨🏾‍🎨' => 'mannelijke kunstenaar: donkergetinte huidskleur',
    '👨🏿‍🎨' => 'mannelijke kunstenaar: donkere huidskleur',
    '👩🏻‍🎨' => 'kunstenares: lichte huidskleur',
    '👩🏼‍🎨' => 'kunstenares: lichtgetinte huidskleur',
    '👩🏽‍🎨' => 'kunstenares: getinte huidskleur',
    '👩🏾‍🎨' => 'kunstenares: donkergetinte huidskleur',
    '👩🏿‍🎨' => 'kunstenares: donkere huidskleur',
    '🧑🏻‍✈' => 'piloot: lichte huidskleur',
    '🧑🏼‍✈' => 'piloot: lichtgetinte huidskleur',
    '🧑🏽‍✈' => 'piloot: getinte huidskleur',
    '🧑🏾‍✈' => 'piloot: donkergetinte huidskleur',
    '🧑🏿‍✈' => 'piloot: donkere huidskleur',
    '👨🏻‍✈' => 'mannelijke piloot: lichte huidskleur',
    '👨🏼‍✈' => 'mannelijke piloot: lichtgetinte huidskleur',
    '👨🏽‍✈' => 'mannelijke piloot: getinte huidskleur',
    '👨🏾‍✈' => 'mannelijke piloot: donkergetinte huidskleur',
    '👨🏿‍✈' => 'mannelijke piloot: donkere huidskleur',
    '👩🏻‍✈' => 'pilote: lichte huidskleur',
    '👩🏼‍✈' => 'pilote: lichtgetinte huidskleur',
    '👩🏽‍✈' => 'pilote: getinte huidskleur',
    '👩🏾‍✈' => 'pilote: donkergetinte huidskleur',
    '👩🏿‍✈' => 'pilote: donkere huidskleur',
    '🧑🏻‍🚀' => 'astronaut: lichte huidskleur',
    '🧑🏼‍🚀' => 'astronaut: lichtgetinte huidskleur',
    '🧑🏽‍🚀' => 'astronaut: getinte huidskleur',
    '🧑🏾‍🚀' => 'astronaut: donkergetinte huidskleur',
    '🧑🏿‍🚀' => 'astronaut: donkere huidskleur',
    '👨🏻‍🚀' => 'mannelijke astronaut: lichte huidskleur',
    '👨🏼‍🚀' => 'mannelijke astronaut: lichtgetinte huidskleur',
    '👨🏽‍🚀' => 'mannelijke astronaut: getinte huidskleur',
    '👨🏾‍🚀' => 'mannelijke astronaut: donkergetinte huidskleur',
    '👨🏿‍🚀' => 'mannelijke astronaut: donkere huidskleur',
    '👩🏻‍🚀' => 'astronaute: lichte huidskleur',
    '👩🏼‍🚀' => 'astronaute: lichtgetinte huidskleur',
    '👩🏽‍🚀' => 'astronaute: getinte huidskleur',
    '👩🏾‍🚀' => 'astronaute: donkergetinte huidskleur',
    '👩🏿‍🚀' => 'astronaute: donkere huidskleur',
    '🧑🏻‍🚒' => 'brandweerman: lichte huidskleur',
    '🧑🏼‍🚒' => 'brandweerman: lichtgetinte huidskleur',
    '🧑🏽‍🚒' => 'brandweerman: getinte huidskleur',
    '🧑🏾‍🚒' => 'brandweerman: donkergetinte huidskleur',
    '🧑🏿‍🚒' => 'brandweerman: donkere huidskleur',
    '👨🏻‍🚒' => 'mannelijke brandweerman: lichte huidskleur',
    '👨🏼‍🚒' => 'mannelijke brandweerman: lichtgetinte huidskleur',
    '👨🏽‍🚒' => 'mannelijke brandweerman: getinte huidskleur',
    '👨🏾‍🚒' => 'mannelijke brandweerman: donkergetinte huidskleur',
    '👨🏿‍🚒' => 'mannelijke brandweerman: donkere huidskleur',
    '👩🏻‍🚒' => 'brandweervrouw: lichte huidskleur',
    '👩🏼‍🚒' => 'brandweervrouw: lichtgetinte huidskleur',
    '👩🏽‍🚒' => 'brandweervrouw: getinte huidskleur',
    '👩🏾‍🚒' => 'brandweervrouw: donkergetinte huidskleur',
    '👩🏿‍🚒' => 'brandweervrouw: donkere huidskleur',
    '👮🏻‍♂' => 'politieman: lichte huidskleur',
    '👮🏼‍♂' => 'politieman: lichtgetinte huidskleur',
    '👮🏽‍♂' => 'politieman: getinte huidskleur',
    '👮🏾‍♂' => 'politieman: donkergetinte huidskleur',
    '👮🏿‍♂' => 'politieman: donkere huidskleur',
    '👮🏻‍♀' => 'politievrouw: lichte huidskleur',
    '👮🏼‍♀' => 'politievrouw: lichtgetinte huidskleur',
    '👮🏽‍♀' => 'politievrouw: getinte huidskleur',
    '👮🏾‍♀' => 'politievrouw: donkergetinte huidskleur',
    '👮🏿‍♀' => 'politievrouw: donkere huidskleur',
    '🕵🏻‍♂' => 'mannelijke detective: lichte huidskleur',
    '🕵🏼‍♂' => 'mannelijke detective: lichtgetinte huidskleur',
    '🕵🏽‍♂' => 'mannelijke detective: getinte huidskleur',
    '🕵🏾‍♂' => 'mannelijke detective: donkergetinte huidskleur',
    '🕵🏿‍♂' => 'mannelijke detective: donkere huidskleur',
    '🕵🏻‍♀' => 'vrouwelijke detective: lichte huidskleur',
    '🕵🏼‍♀' => 'vrouwelijke detective: lichtgetinte huidskleur',
    '🕵🏽‍♀' => 'vrouwelijke detective: getinte huidskleur',
    '🕵🏾‍♀' => 'vrouwelijke detective: donkergetinte huidskleur',
    '🕵🏿‍♀' => 'vrouwelijke detective: donkere huidskleur',
    '💂🏻‍♂' => 'mannelijke wachter: lichte huidskleur',
    '💂🏼‍♂' => 'mannelijke wachter: lichtgetinte huidskleur',
    '💂🏽‍♂' => 'mannelijke wachter: getinte huidskleur',
    '💂🏾‍♂' => 'mannelijke wachter: donkergetinte huidskleur',
    '💂🏿‍♂' => 'mannelijke wachter: donkere huidskleur',
    '💂🏻‍♀' => 'vrouwelijke wachter: lichte huidskleur',
    '💂🏼‍♀' => 'vrouwelijke wachter: lichtgetinte huidskleur',
    '💂🏽‍♀' => 'vrouwelijke wachter: getinte huidskleur',
    '💂🏾‍♀' => 'vrouwelijke wachter: donkergetinte huidskleur',
    '💂🏿‍♀' => 'vrouwelijke wachter: donkere huidskleur',
    '👷🏻‍♂' => 'mannelijke bouwvakker: lichte huidskleur',
    '👷🏼‍♂' => 'mannelijke bouwvakker: lichtgetinte huidskleur',
    '👷🏽‍♂' => 'mannelijke bouwvakker: getinte huidskleur',
    '👷🏾‍♂' => 'mannelijke bouwvakker: donkergetinte huidskleur',
    '👷🏿‍♂' => 'mannelijke bouwvakker: donkere huidskleur',
    '👷🏻‍♀' => 'vrouwelijke bouwvakker: lichte huidskleur',
    '👷🏼‍♀' => 'vrouwelijke bouwvakker: lichtgetinte huidskleur',
    '👷🏽‍♀' => 'vrouwelijke bouwvakker: getinte huidskleur',
    '👷🏾‍♀' => 'vrouwelijke bouwvakker: donkergetinte huidskleur',
    '👷🏿‍♀' => 'vrouwelijke bouwvakker: donkere huidskleur',
    '👳🏻‍♂' => 'man met tulband: lichte huidskleur',
    '👳🏼‍♂' => 'man met tulband: lichtgetinte huidskleur',
    '👳🏽‍♂' => 'man met tulband: getinte huidskleur',
    '👳🏾‍♂' => 'man met tulband: donkergetinte huidskleur',
    '👳🏿‍♂' => 'man met tulband: donkere huidskleur',
    '👳🏻‍♀' => 'vrouw met tulband: lichte huidskleur',
    '👳🏼‍♀' => 'vrouw met tulband: lichtgetinte huidskleur',
    '👳🏽‍♀' => 'vrouw met tulband: getinte huidskleur',
    '👳🏾‍♀' => 'vrouw met tulband: donkergetinte huidskleur',
    '👳🏿‍♀' => 'vrouw met tulband: donkere huidskleur',
    '🤵🏻‍♂' => 'man in smoking: lichte huidskleur',
    '🤵🏼‍♂' => 'man in smoking: lichtgetinte huidskleur',
    '🤵🏽‍♂' => 'man in smoking: getinte huidskleur',
    '🤵🏾‍♂' => 'man in smoking: donkergetinte huidskleur',
    '🤵🏿‍♂' => 'man in smoking: donkere huidskleur',
    '🤵🏻‍♀' => 'vrouw in smoking: lichte huidskleur',
    '🤵🏼‍♀' => 'vrouw in smoking: lichtgetinte huidskleur',
    '🤵🏽‍♀' => 'vrouw in smoking: getinte huidskleur',
    '🤵🏾‍♀' => 'vrouw in smoking: donkergetinte huidskleur',
    '🤵🏿‍♀' => 'vrouw in smoking: donkere huidskleur',
    '👰🏻‍♂' => 'man met sluier: lichte huidskleur',
    '👰🏼‍♂' => 'man met sluier: lichtgetinte huidskleur',
    '👰🏽‍♂' => 'man met sluier: getinte huidskleur',
    '👰🏾‍♂' => 'man met sluier: donkergetinte huidskleur',
    '👰🏿‍♂' => 'man met sluier: donkere huidskleur',
    '👰🏻‍♀' => 'vrouw met sluier: lichte huidskleur',
    '👰🏼‍♀' => 'vrouw met sluier: lichtgetinte huidskleur',
    '👰🏽‍♀' => 'vrouw met sluier: getinte huidskleur',
    '👰🏾‍♀' => 'vrouw met sluier: donkergetinte huidskleur',
    '👰🏿‍♀' => 'vrouw met sluier: donkere huidskleur',
    '👩🏻‍🍼' => 'vrouw die een baby voedt: lichte huidskleur',
    '👩🏼‍🍼' => 'vrouw die een baby voedt: lichtgetinte huidskleur',
    '👩🏽‍🍼' => 'vrouw die een baby voedt: getinte huidskleur',
    '👩🏾‍🍼' => 'vrouw die een baby voedt: donkergetinte huidskleur',
    '👩🏿‍🍼' => 'vrouw die een baby voedt: donkere huidskleur',
    '👨🏻‍🍼' => 'man die een baby voedt: lichte huidskleur',
    '👨🏼‍🍼' => 'man die een baby voedt: lichtgetinte huidskleur',
    '👨🏽‍🍼' => 'man die een baby voedt: getinte huidskleur',
    '👨🏾‍🍼' => 'man die een baby voedt: donkergetinte huidskleur',
    '👨🏿‍🍼' => 'man die een baby voedt: donkere huidskleur',
    '🧑🏻‍🍼' => 'persoon die een baby voedt: lichte huidskleur',
    '🧑🏼‍🍼' => 'persoon die een baby voedt: lichtgetinte huidskleur',
    '🧑🏽‍🍼' => 'persoon die een baby voedt: getinte huidskleur',
    '🧑🏾‍🍼' => 'persoon die een baby voedt: donkergetinte huidskleur',
    '🧑🏿‍🍼' => 'persoon die een baby voedt: donkere huidskleur',
    '🧑🏻‍🎄' => 'kersttransgender: lichte huidskleur',
    '🧑🏼‍🎄' => 'kersttransgender: lichtgetinte huidskleur',
    '🧑🏽‍🎄' => 'kersttransgender: getinte huidskleur',
    '🧑🏾‍🎄' => 'kersttransgender: donkergetinte huidskleur',
    '🧑🏿‍🎄' => 'kersttransgender: donkere huidskleur',
    '🦸🏻‍♂' => 'mannelijke superheld: lichte huidskleur',
    '🦸🏼‍♂' => 'mannelijke superheld: lichtgetinte huidskleur',
    '🦸🏽‍♂' => 'mannelijke superheld: getinte huidskleur',
    '🦸🏾‍♂' => 'mannelijke superheld: donkergetinte huidskleur',
    '🦸🏿‍♂' => 'mannelijke superheld: donkere huidskleur',
    '🦸🏻‍♀' => 'vrouwelijke superheld: lichte huidskleur',
    '🦸🏼‍♀' => 'vrouwelijke superheld: lichtgetinte huidskleur',
    '🦸🏽‍♀' => 'vrouwelijke superheld: getinte huidskleur',
    '🦸🏾‍♀' => 'vrouwelijke superheld: donkergetinte huidskleur',
    '🦸🏿‍♀' => 'vrouwelijke superheld: donkere huidskleur',
    '🦹🏻‍♂' => 'mannelijke superschurk: lichte huidskleur',
    '🦹🏼‍♂' => 'mannelijke superschurk: lichtgetinte huidskleur',
    '🦹🏽‍♂' => 'mannelijke superschurk: getinte huidskleur',
    '🦹🏾‍♂' => 'mannelijke superschurk: donkergetinte huidskleur',
    '🦹🏿‍♂' => 'mannelijke superschurk: donkere huidskleur',
    '🦹🏻‍♀' => 'vrouwelijke superschurk: lichte huidskleur',
    '🦹🏼‍♀' => 'vrouwelijke superschurk: lichtgetinte huidskleur',
    '🦹🏽‍♀' => 'vrouwelijke superschurk: getinte huidskleur',
    '🦹🏾‍♀' => 'vrouwelijke superschurk: donkergetinte huidskleur',
    '🦹🏿‍♀' => 'vrouwelijke superschurk: donkere huidskleur',
    '🧙🏻‍♂' => 'mannelijke magiër: lichte huidskleur',
    '🧙🏼‍♂' => 'mannelijke magiër: lichtgetinte huidskleur',
    '🧙🏽‍♂' => 'mannelijke magiër: getinte huidskleur',
    '🧙🏾‍♂' => 'mannelijke magiër: donkergetinte huidskleur',
    '🧙🏿‍♂' => 'mannelijke magiër: donkere huidskleur',
    '🧙🏻‍♀' => 'vrouwelijke magiër: lichte huidskleur',
    '🧙🏼‍♀' => 'vrouwelijke magiër: lichtgetinte huidskleur',
    '🧙🏽‍♀' => 'vrouwelijke magiër: getinte huidskleur',
    '🧙🏾‍♀' => 'vrouwelijke magiër: donkergetinte huidskleur',
    '🧙🏿‍♀' => 'vrouwelijke magiër: donkere huidskleur',
    '🧚🏻‍♂' => 'mannelijk elfje: lichte huidskleur',
    '🧚🏼‍♂' => 'mannelijk elfje: lichtgetinte huidskleur',
    '🧚🏽‍♂' => 'mannelijk elfje: getinte huidskleur',
    '🧚🏾‍♂' => 'mannelijk elfje: donkergetinte huidskleur',
    '🧚🏿‍♂' => 'mannelijk elfje: donkere huidskleur',
    '🧚🏻‍♀' => 'vrouwelijk elfje: lichte huidskleur',
    '🧚🏼‍♀' => 'vrouwelijk elfje: lichtgetinte huidskleur',
    '🧚🏽‍♀' => 'vrouwelijk elfje: getinte huidskleur',
    '🧚🏾‍♀' => 'vrouwelijk elfje: donkergetinte huidskleur',
    '🧚🏿‍♀' => 'vrouwelijk elfje: donkere huidskleur',
    '🧛🏻‍♂' => 'mannelijke vampier: lichte huidskleur',
    '🧛🏼‍♂' => 'mannelijke vampier: lichtgetinte huidskleur',
    '🧛🏽‍♂' => 'mannelijke vampier: getinte huidskleur',
    '🧛🏾‍♂' => 'mannelijke vampier: donkergetinte huidskleur',
    '🧛🏿‍♂' => 'mannelijke vampier: donkere huidskleur',
    '🧛🏻‍♀' => 'vrouwelijke vampier: lichte huidskleur',
    '🧛🏼‍♀' => 'vrouwelijke vampier: lichtgetinte huidskleur',
    '🧛🏽‍♀' => 'vrouwelijke vampier: getinte huidskleur',
    '🧛🏾‍♀' => 'vrouwelijke vampier: donkergetinte huidskleur',
    '🧛🏿‍♀' => 'vrouwelijke vampier: donkere huidskleur',
    '🧜🏻‍♂' => 'zeemeerman: lichte huidskleur',
    '🧜🏼‍♂' => 'zeemeerman: lichtgetinte huidskleur',
    '🧜🏽‍♂' => 'zeemeerman: getinte huidskleur',
    '🧜🏾‍♂' => 'zeemeerman: donkergetinte huidskleur',
    '🧜🏿‍♂' => 'zeemeerman: donkere huidskleur',
    '🧜🏻‍♀' => 'sirene: lichte huidskleur',
    '🧜🏼‍♀' => 'sirene: lichtgetinte huidskleur',
    '🧜🏽‍♀' => 'sirene: getinte huidskleur',
    '🧜🏾‍♀' => 'sirene: donkergetinte huidskleur',
    '🧜🏿‍♀' => 'sirene: donkere huidskleur',
    '🧝🏻‍♂' => 'mannelijke elf: lichte huidskleur',
    '🧝🏼‍♂' => 'mannelijke elf: lichtgetinte huidskleur',
    '🧝🏽‍♂' => 'mannelijke elf: getinte huidskleur',
    '🧝🏾‍♂' => 'mannelijke elf: donkergetinte huidskleur',
    '🧝🏿‍♂' => 'mannelijke elf: donkere huidskleur',
    '🧝🏻‍♀' => 'vrouwelijke elf: lichte huidskleur',
    '🧝🏼‍♀' => 'vrouwelijke elf: lichtgetinte huidskleur',
    '🧝🏽‍♀' => 'vrouwelijke elf: getinte huidskleur',
    '🧝🏾‍♀' => 'vrouwelijke elf: donkergetinte huidskleur',
    '🧝🏿‍♀' => 'vrouwelijke elf: donkere huidskleur',
    '💆🏻‍♂' => 'man die hoofdmassage krijgt: lichte huidskleur',
    '💆🏼‍♂' => 'man die hoofdmassage krijgt: lichtgetinte huidskleur',
    '💆🏽‍♂' => 'man die hoofdmassage krijgt: getinte huidskleur',
    '💆🏾‍♂' => 'man die hoofdmassage krijgt: donkergetinte huidskleur',
    '💆🏿‍♂' => 'man die hoofdmassage krijgt: donkere huidskleur',
    '💆🏻‍♀' => 'vrouw die hoofdmassage krijgt: lichte huidskleur',
    '💆🏼‍♀' => 'vrouw die hoofdmassage krijgt: lichtgetinte huidskleur',
    '💆🏽‍♀' => 'vrouw die hoofdmassage krijgt: getinte huidskleur',
    '💆🏾‍♀' => 'vrouw die hoofdmassage krijgt: donkergetinte huidskleur',
    '💆🏿‍♀' => 'vrouw die hoofdmassage krijgt: donkere huidskleur',
    '💇🏻‍♂' => 'man die wordt geknipt: lichte huidskleur',
    '💇🏼‍♂' => 'man die wordt geknipt: lichtgetinte huidskleur',
    '💇🏽‍♂' => 'man die wordt geknipt: getinte huidskleur',
    '💇🏾‍♂' => 'man die wordt geknipt: donkergetinte huidskleur',
    '💇🏿‍♂' => 'man die wordt geknipt: donkere huidskleur',
    '💇🏻‍♀' => 'vrouw die wordt geknipt: lichte huidskleur',
    '💇🏼‍♀' => 'vrouw die wordt geknipt: lichtgetinte huidskleur',
    '💇🏽‍♀' => 'vrouw die wordt geknipt: getinte huidskleur',
    '💇🏾‍♀' => 'vrouw die wordt geknipt: donkergetinte huidskleur',
    '💇🏿‍♀' => 'vrouw die wordt geknipt: donkere huidskleur',
    '🚶🏻‍♂' => 'wandelende man: lichte huidskleur',
    '🚶🏼‍♂' => 'wandelende man: lichtgetinte huidskleur',
    '🚶🏽‍♂' => 'wandelende man: getinte huidskleur',
    '🚶🏾‍♂' => 'wandelende man: donkergetinte huidskleur',
    '🚶🏿‍♂' => 'wandelende man: donkere huidskleur',
    '🚶🏻‍♀' => 'wandelende vrouw: lichte huidskleur',
    '🚶🏼‍♀' => 'wandelende vrouw: lichtgetinte huidskleur',
    '🚶🏽‍♀' => 'wandelende vrouw: getinte huidskleur',
    '🚶🏾‍♀' => 'wandelende vrouw: donkergetinte huidskleur',
    '🚶🏿‍♀' => 'wandelende vrouw: donkere huidskleur',
    '🚶🏻‍➡' => 'voetganger: lichte huidskleur, naar rechts gericht',
    '🚶🏼‍➡' => 'voetganger: lichtgetinte huidskleur, naar rechts gericht',
    '🚶🏽‍➡' => 'voetganger: getinte huidskleur, naar rechts gericht',
    '🚶🏾‍➡' => 'voetganger: donkergetinte huidskleur, naar rechts gericht',
    '🚶🏿‍➡' => 'voetganger: donkere huidskleur, naar rechts gericht',
    '🧍🏻‍♂' => 'staande man: lichte huidskleur',
    '🧍🏼‍♂' => 'staande man: lichtgetinte huidskleur',
    '🧍🏽‍♂' => 'staande man: getinte huidskleur',
    '🧍🏾‍♂' => 'staande man: donkergetinte huidskleur',
    '🧍🏿‍♂' => 'staande man: donkere huidskleur',
    '🧍🏻‍♀' => 'staande vrouw: lichte huidskleur',
    '🧍🏼‍♀' => 'staande vrouw: lichtgetinte huidskleur',
    '🧍🏽‍♀' => 'staande vrouw: getinte huidskleur',
    '🧍🏾‍♀' => 'staande vrouw: donkergetinte huidskleur',
    '🧍🏿‍♀' => 'staande vrouw: donkere huidskleur',
    '🧎🏻‍♂' => 'knielende man: lichte huidskleur',
    '🧎🏼‍♂' => 'knielende man: lichtgetinte huidskleur',
    '🧎🏽‍♂' => 'knielende man: getinte huidskleur',
    '🧎🏾‍♂' => 'knielende man: donkergetinte huidskleur',
    '🧎🏿‍♂' => 'knielende man: donkere huidskleur',
    '🧎🏻‍♀' => 'knielende vrouw: lichte huidskleur',
    '🧎🏼‍♀' => 'knielende vrouw: lichtgetinte huidskleur',
    '🧎🏽‍♀' => 'knielende vrouw: getinte huidskleur',
    '🧎🏾‍♀' => 'knielende vrouw: donkergetinte huidskleur',
    '🧎🏿‍♀' => 'knielende vrouw: donkere huidskleur',
    '🧎🏻‍➡' => 'knielende persoon: lichte huidskleur, naar rechts gericht',
    '🧎🏼‍➡' => 'knielende persoon: lichtgetinte huidskleur, naar rechts gericht',
    '🧎🏽‍➡' => 'knielende persoon: getinte huidskleur, naar rechts gericht',
    '🧎🏾‍➡' => 'knielende persoon: donkergetinte huidskleur, naar rechts gericht',
    '🧎🏿‍➡' => 'knielende persoon: donkere huidskleur, naar rechts gericht',
    '🧑🏻‍🦯' => 'persoon met taststok: lichte huidskleur',
    '🧑🏼‍🦯' => 'persoon met taststok: lichtgetinte huidskleur',
    '🧑🏽‍🦯' => 'persoon met taststok: getinte huidskleur',
    '🧑🏾‍🦯' => 'persoon met taststok: donkergetinte huidskleur',
    '🧑🏿‍🦯' => 'persoon met taststok: donkere huidskleur',
    '👨🏻‍🦯' => 'man met taststok: lichte huidskleur',
    '👨🏼‍🦯' => 'man met taststok: lichtgetinte huidskleur',
    '👨🏽‍🦯' => 'man met taststok: getinte huidskleur',
    '👨🏾‍🦯' => 'man met taststok: donkergetinte huidskleur',
    '👨🏿‍🦯' => 'man met taststok: donkere huidskleur',
    '👩🏻‍🦯' => 'vrouw met taststok: lichte huidskleur',
    '👩🏼‍🦯' => 'vrouw met taststok: lichtgetinte huidskleur',
    '👩🏽‍🦯' => 'vrouw met taststok: getinte huidskleur',
    '👩🏾‍🦯' => 'vrouw met taststok: donkergetinte huidskleur',
    '👩🏿‍🦯' => 'vrouw met taststok: donkere huidskleur',
    '🧑🏻‍🦼' => 'persoon in elektrische rolstoel: lichte huidskleur',
    '🧑🏼‍🦼' => 'persoon in elektrische rolstoel: lichtgetinte huidskleur',
    '🧑🏽‍🦼' => 'persoon in elektrische rolstoel: getinte huidskleur',
    '🧑🏾‍🦼' => 'persoon in elektrische rolstoel: donkergetinte huidskleur',
    '🧑🏿‍🦼' => 'persoon in elektrische rolstoel: donkere huidskleur',
    '👨🏻‍🦼' => 'man in elektrische rolstoel: lichte huidskleur',
    '👨🏼‍🦼' => 'man in elektrische rolstoel: lichtgetinte huidskleur',
    '👨🏽‍🦼' => 'man in elektrische rolstoel: getinte huidskleur',
    '👨🏾‍🦼' => 'man in elektrische rolstoel: donkergetinte huidskleur',
    '👨🏿‍🦼' => 'man in elektrische rolstoel: donkere huidskleur',
    '👩🏻‍🦼' => 'vrouw in elektrische rolstoel: lichte huidskleur',
    '👩🏼‍🦼' => 'vrouw in elektrische rolstoel: lichtgetinte huidskleur',
    '👩🏽‍🦼' => 'vrouw in elektrische rolstoel: getinte huidskleur',
    '👩🏾‍🦼' => 'vrouw in elektrische rolstoel: donkergetinte huidskleur',
    '👩🏿‍🦼' => 'vrouw in elektrische rolstoel: donkere huidskleur',
    '🧑🏻‍🦽' => 'persoon in rolstoel: lichte huidskleur',
    '🧑🏼‍🦽' => 'persoon in rolstoel: lichtgetinte huidskleur',
    '🧑🏽‍🦽' => 'persoon in rolstoel: getinte huidskleur',
    '🧑🏾‍🦽' => 'persoon in rolstoel: donkergetinte huidskleur',
    '🧑🏿‍🦽' => 'persoon in rolstoel: donkere huidskleur',
    '👨🏻‍🦽' => 'man in rolstoel: lichte huidskleur',
    '👨🏼‍🦽' => 'man in rolstoel: lichtgetinte huidskleur',
    '👨🏽‍🦽' => 'man in rolstoel: getinte huidskleur',
    '👨🏾‍🦽' => 'man in rolstoel: donkergetinte huidskleur',
    '👨🏿‍🦽' => 'man in rolstoel: donkere huidskleur',
    '👩🏻‍🦽' => 'vrouw in rolstoel: lichte huidskleur',
    '👩🏼‍🦽' => 'vrouw in rolstoel: lichtgetinte huidskleur',
    '👩🏽‍🦽' => 'vrouw in rolstoel: getinte huidskleur',
    '👩🏾‍🦽' => 'vrouw in rolstoel: donkergetinte huidskleur',
    '👩🏿‍🦽' => 'vrouw in rolstoel: donkere huidskleur',
    '🏃🏻‍♂' => 'rennende man: lichte huidskleur',
    '🏃🏼‍♂' => 'rennende man: lichtgetinte huidskleur',
    '🏃🏽‍♂' => 'rennende man: getinte huidskleur',
    '🏃🏾‍♂' => 'rennende man: donkergetinte huidskleur',
    '🏃🏿‍♂' => 'rennende man: donkere huidskleur',
    '🏃🏻‍♀' => 'rennende vrouw: lichte huidskleur',
    '🏃🏼‍♀' => 'rennende vrouw: lichtgetinte huidskleur',
    '🏃🏽‍♀' => 'rennende vrouw: getinte huidskleur',
    '🏃🏾‍♀' => 'rennende vrouw: donkergetinte huidskleur',
    '🏃🏿‍♀' => 'rennende vrouw: donkere huidskleur',
    '🏃🏻‍➡' => 'hardloper: lichte huidskleur, naar rechts gericht',
    '🏃🏼‍➡' => 'hardloper: lichtgetinte huidskleur, naar rechts gericht',
    '🏃🏽‍➡' => 'hardloper: getinte huidskleur, naar rechts gericht',
    '🏃🏾‍➡' => 'hardloper: donkergetinte huidskleur, naar rechts gericht',
    '🏃🏿‍➡' => 'hardloper: donkere huidskleur, naar rechts gericht',
    '👯🏻‍♀' => 'vrouwen met konijnenoren: lichte huidskleur',
    '👯🏼‍♀' => 'vrouwen met konijnenoren: lichtgetinte huidskleur',
    '👯🏽‍♀' => 'vrouwen met konijnenoren: getinte huidskleur',
    '👯🏾‍♀' => 'vrouwen met konijnenoren: donkergetinte huidskleur',
    '👯🏿‍♀' => 'vrouwen met konijnenoren: donkere huidskleur',
    '👯🏻‍♂' => 'mannen met konijnenoren: lichte huidskleur',
    '👯🏼‍♂' => 'mannen met konijnenoren: lichtgetinte huidskleur',
    '👯🏽‍♂' => 'mannen met konijnenoren: getinte huidskleur',
    '👯🏾‍♂' => 'mannen met konijnenoren: donkergetinte huidskleur',
    '👯🏿‍♂' => 'mannen met konijnenoren: donkere huidskleur',
    '🧖🏻‍♂' => 'man in ruimte vol stoom: lichte huidskleur',
    '🧖🏼‍♂' => 'man in ruimte vol stoom: lichtgetinte huidskleur',
    '🧖🏽‍♂' => 'man in ruimte vol stoom: getinte huidskleur',
    '🧖🏾‍♂' => 'man in ruimte vol stoom: donkergetinte huidskleur',
    '🧖🏿‍♂' => 'man in ruimte vol stoom: donkere huidskleur',
    '🧖🏻‍♀' => 'vrouw in ruimte vol stoom: lichte huidskleur',
    '🧖🏼‍♀' => 'vrouw in ruimte vol stoom: lichtgetinte huidskleur',
    '🧖🏽‍♀' => 'vrouw in ruimte vol stoom: getinte huidskleur',
    '🧖🏾‍♀' => 'vrouw in ruimte vol stoom: donkergetinte huidskleur',
    '🧖🏿‍♀' => 'vrouw in ruimte vol stoom: donkere huidskleur',
    '🧗🏻‍♂' => 'klimmende man: lichte huidskleur',
    '🧗🏼‍♂' => 'klimmende man: lichtgetinte huidskleur',
    '🧗🏽‍♂' => 'klimmende man: getinte huidskleur',
    '🧗🏾‍♂' => 'klimmende man: donkergetinte huidskleur',
    '🧗🏿‍♂' => 'klimmende man: donkere huidskleur',
    '🧗🏻‍♀' => 'klimmende vrouw: lichte huidskleur',
    '🧗🏼‍♀' => 'klimmende vrouw: lichtgetinte huidskleur',
    '🧗🏽‍♀' => 'klimmende vrouw: getinte huidskleur',
    '🧗🏾‍♀' => 'klimmende vrouw: donkergetinte huidskleur',
    '🧗🏿‍♀' => 'klimmende vrouw: donkere huidskleur',
    '🏌🏻‍♂' => 'golfende man: lichte huidskleur',
    '🏌🏼‍♂' => 'golfende man: lichtgetinte huidskleur',
    '🏌🏽‍♂' => 'golfende man: getinte huidskleur',
    '🏌🏾‍♂' => 'golfende man: donkergetinte huidskleur',
    '🏌🏿‍♂' => 'golfende man: donkere huidskleur',
    '🏌🏻‍♀' => 'golfende vrouw: lichte huidskleur',
    '🏌🏼‍♀' => 'golfende vrouw: lichtgetinte huidskleur',
    '🏌🏽‍♀' => 'golfende vrouw: getinte huidskleur',
    '🏌🏾‍♀' => 'golfende vrouw: donkergetinte huidskleur',
    '🏌🏿‍♀' => 'golfende vrouw: donkere huidskleur',
    '🏄🏻‍♂' => 'mannelijke surfer: lichte huidskleur',
    '🏄🏼‍♂' => 'mannelijke surfer: lichtgetinte huidskleur',
    '🏄🏽‍♂' => 'mannelijke surfer: getinte huidskleur',
    '🏄🏾‍♂' => 'mannelijke surfer: donkergetinte huidskleur',
    '🏄🏿‍♂' => 'mannelijke surfer: donkere huidskleur',
    '🏄🏻‍♀' => 'vrouwelijke surfer: lichte huidskleur',
    '🏄🏼‍♀' => 'vrouwelijke surfer: lichtgetinte huidskleur',
    '🏄🏽‍♀' => 'vrouwelijke surfer: getinte huidskleur',
    '🏄🏾‍♀' => 'vrouwelijke surfer: donkergetinte huidskleur',
    '🏄🏿‍♀' => 'vrouwelijke surfer: donkere huidskleur',
    '🚣🏻‍♂' => 'man in roeiboot: lichte huidskleur',
    '🚣🏼‍♂' => 'man in roeiboot: lichtgetinte huidskleur',
    '🚣🏽‍♂' => 'man in roeiboot: getinte huidskleur',
    '🚣🏾‍♂' => 'man in roeiboot: donkergetinte huidskleur',
    '🚣🏿‍♂' => 'man in roeiboot: donkere huidskleur',
    '🚣🏻‍♀' => 'vrouw in roeiboot: lichte huidskleur',
    '🚣🏼‍♀' => 'vrouw in roeiboot: lichtgetinte huidskleur',
    '🚣🏽‍♀' => 'vrouw in roeiboot: getinte huidskleur',
    '🚣🏾‍♀' => 'vrouw in roeiboot: donkergetinte huidskleur',
    '🚣🏿‍♀' => 'vrouw in roeiboot: donkere huidskleur',
    '🏊🏻‍♂' => 'zwemmende man: lichte huidskleur',
    '🏊🏼‍♂' => 'zwemmende man: lichtgetinte huidskleur',
    '🏊🏽‍♂' => 'zwemmende man: getinte huidskleur',
    '🏊🏾‍♂' => 'zwemmende man: donkergetinte huidskleur',
    '🏊🏿‍♂' => 'zwemmende man: donkere huidskleur',
    '🏊🏻‍♀' => 'zwemmende vrouw: lichte huidskleur',
    '🏊🏼‍♀' => 'zwemmende vrouw: lichtgetinte huidskleur',
    '🏊🏽‍♀' => 'zwemmende vrouw: getinte huidskleur',
    '🏊🏾‍♀' => 'zwemmende vrouw: donkergetinte huidskleur',
    '🏊🏿‍♀' => 'zwemmende vrouw: donkere huidskleur',
    '⛹🏻‍♂' => 'basketballer: lichte huidskleur',
    '⛹🏼‍♂' => 'basketballer: lichtgetinte huidskleur',
    '⛹🏽‍♂' => 'basketballer: getinte huidskleur',
    '⛹🏾‍♂' => 'basketballer: donkergetinte huidskleur',
    '⛹🏿‍♂' => 'basketballer: donkere huidskleur',
    '⛹🏻‍♀' => 'basketbalster: lichte huidskleur',
    '⛹🏼‍♀' => 'basketbalster: lichtgetinte huidskleur',
    '⛹🏽‍♀' => 'basketbalster: getinte huidskleur',
    '⛹🏾‍♀' => 'basketbalster: donkergetinte huidskleur',
    '⛹🏿‍♀' => 'basketbalster: donkere huidskleur',
    '🏋🏻‍♂' => 'mannelijke gewichtheffer: lichte huidskleur',
    '🏋🏼‍♂' => 'mannelijke gewichtheffer: lichtgetinte huidskleur',
    '🏋🏽‍♂' => 'mannelijke gewichtheffer: getinte huidskleur',
    '🏋🏾‍♂' => 'mannelijke gewichtheffer: donkergetinte huidskleur',
    '🏋🏿‍♂' => 'mannelijke gewichtheffer: donkere huidskleur',
    '🏋🏻‍♀' => 'vrouwelijke gewichtheffer: lichte huidskleur',
    '🏋🏼‍♀' => 'vrouwelijke gewichtheffer: lichtgetinte huidskleur',
    '🏋🏽‍♀' => 'vrouwelijke gewichtheffer: getinte huidskleur',
    '🏋🏾‍♀' => 'vrouwelijke gewichtheffer: donkergetinte huidskleur',
    '🏋🏿‍♀' => 'vrouwelijke gewichtheffer: donkere huidskleur',
    '🚴🏻‍♂' => 'fietsende man: lichte huidskleur',
    '🚴🏼‍♂' => 'fietsende man: lichtgetinte huidskleur',
    '🚴🏽‍♂' => 'fietsende man: getinte huidskleur',
    '🚴🏾‍♂' => 'fietsende man: donkergetinte huidskleur',
    '🚴🏿‍♂' => 'fietsende man: donkere huidskleur',
    '🚴🏻‍♀' => 'fietsende vrouw: lichte huidskleur',
    '🚴🏼‍♀' => 'fietsende vrouw: lichtgetinte huidskleur',
    '🚴🏽‍♀' => 'fietsende vrouw: getinte huidskleur',
    '🚴🏾‍♀' => 'fietsende vrouw: donkergetinte huidskleur',
    '🚴🏿‍♀' => 'fietsende vrouw: donkere huidskleur',
    '🚵🏻‍♂' => 'man op mountainbike: lichte huidskleur',
    '🚵🏼‍♂' => 'man op mountainbike: lichtgetinte huidskleur',
    '🚵🏽‍♂' => 'man op mountainbike: getinte huidskleur',
    '🚵🏾‍♂' => 'man op mountainbike: donkergetinte huidskleur',
    '🚵🏿‍♂' => 'man op mountainbike: donkere huidskleur',
    '🚵🏻‍♀' => 'vrouw op mountainbike: lichte huidskleur',
    '🚵🏼‍♀' => 'vrouw op mountainbike: lichtgetinte huidskleur',
    '🚵🏽‍♀' => 'vrouw op mountainbike: getinte huidskleur',
    '🚵🏾‍♀' => 'vrouw op mountainbike: donkergetinte huidskleur',
    '🚵🏿‍♀' => 'vrouw op mountainbike: donkere huidskleur',
    '🤸🏻‍♂' => 'man die een radslag doet: lichte huidskleur',
    '🤸🏼‍♂' => 'man die een radslag doet: lichtgetinte huidskleur',
    '🤸🏽‍♂' => 'man die een radslag doet: getinte huidskleur',
    '🤸🏾‍♂' => 'man die een radslag doet: donkergetinte huidskleur',
    '🤸🏿‍♂' => 'man die een radslag doet: donkere huidskleur',
    '🤸🏻‍♀' => 'vrouw die een radslag doet: lichte huidskleur',
    '🤸🏼‍♀' => 'vrouw die een radslag doet: lichtgetinte huidskleur',
    '🤸🏽‍♀' => 'vrouw die een radslag doet: getinte huidskleur',
    '🤸🏾‍♀' => 'vrouw die een radslag doet: donkergetinte huidskleur',
    '🤸🏿‍♀' => 'vrouw die een radslag doet: donkere huidskleur',
    '🤼🏻‍♀' => 'worstelende vrouwen: lichte huidskleur',
    '🤼🏼‍♀' => 'worstelende vrouwen: lichtgetinte huidskleur',
    '🤼🏽‍♀' => 'worstelende vrouwen: getinte huidskleur',
    '🤼🏾‍♀' => 'worstelende vrouwen: donkergetinte huidskleur',
    '🤼🏿‍♀' => 'worstelende vrouwen: donkere huidskleur',
    '🤼🏻‍♂' => 'worstelende mannen: lichte huidskleur',
    '🤼🏼‍♂' => 'worstelende mannen: lichtgetinte huidskleur',
    '🤼🏽‍♂' => 'worstelende mannen: getinte huidskleur',
    '🤼🏾‍♂' => 'worstelende mannen: donkergetinte huidskleur',
    '🤼🏿‍♂' => 'worstelende mannen: donkere huidskleur',
    '🤽🏻‍♂' => 'man die waterpolo speelt: lichte huidskleur',
    '🤽🏼‍♂' => 'man die waterpolo speelt: lichtgetinte huidskleur',
    '🤽🏽‍♂' => 'man die waterpolo speelt: getinte huidskleur',
    '🤽🏾‍♂' => 'man die waterpolo speelt: donkergetinte huidskleur',
    '🤽🏿‍♂' => 'man die waterpolo speelt: donkere huidskleur',
    '🤽🏻‍♀' => 'vrouw die waterpolo speelt: lichte huidskleur',
    '🤽🏼‍♀' => 'vrouw die waterpolo speelt: lichtgetinte huidskleur',
    '🤽🏽‍♀' => 'vrouw die waterpolo speelt: getinte huidskleur',
    '🤽🏾‍♀' => 'vrouw die waterpolo speelt: donkergetinte huidskleur',
    '🤽🏿‍♀' => 'vrouw die waterpolo speelt: donkere huidskleur',
    '🤾🏻‍♂' => 'man die handbal speelt: lichte huidskleur',
    '🤾🏼‍♂' => 'man die handbal speelt: lichtgetinte huidskleur',
    '🤾🏽‍♂' => 'man die handbal speelt: getinte huidskleur',
    '🤾🏾‍♂' => 'man die handbal speelt: donkergetinte huidskleur',
    '🤾🏿‍♂' => 'man die handbal speelt: donkere huidskleur',
    '🤾🏻‍♀' => 'vrouw die handbal speelt: lichte huidskleur',
    '🤾🏼‍♀' => 'vrouw die handbal speelt: lichtgetinte huidskleur',
    '🤾🏽‍♀' => 'vrouw die handbal speelt: getinte huidskleur',
    '🤾🏾‍♀' => 'vrouw die handbal speelt: donkergetinte huidskleur',
    '🤾🏿‍♀' => 'vrouw die handbal speelt: donkere huidskleur',
    '🤹🏻‍♂' => 'man die jongleert: lichte huidskleur',
    '🤹🏼‍♂' => 'man die jongleert: lichtgetinte huidskleur',
    '🤹🏽‍♂' => 'man die jongleert: getinte huidskleur',
    '🤹🏾‍♂' => 'man die jongleert: donkergetinte huidskleur',
    '🤹🏿‍♂' => 'man die jongleert: donkere huidskleur',
    '🤹🏻‍♀' => 'vrouw die jongleert: lichte huidskleur',
    '🤹🏼‍♀' => 'vrouw die jongleert: lichtgetinte huidskleur',
    '🤹🏽‍♀' => 'vrouw die jongleert: getinte huidskleur',
    '🤹🏾‍♀' => 'vrouw die jongleert: donkergetinte huidskleur',
    '🤹🏿‍♀' => 'vrouw die jongleert: donkere huidskleur',
    '🧘🏻‍♂' => 'man in lotushouding: lichte huidskleur',
    '🧘🏼‍♂' => 'man in lotushouding: lichtgetinte huidskleur',
    '🧘🏽‍♂' => 'man in lotushouding: getinte huidskleur',
    '🧘🏾‍♂' => 'man in lotushouding: donkergetinte huidskleur',
    '🧘🏿‍♂' => 'man in lotushouding: donkere huidskleur',
    '🧘🏻‍♀' => 'vrouw in lotushouding: lichte huidskleur',
    '🧘🏼‍♀' => 'vrouw in lotushouding: lichtgetinte huidskleur',
    '🧘🏽‍♀' => 'vrouw in lotushouding: getinte huidskleur',
    '🧘🏾‍♀' => 'vrouw in lotushouding: donkergetinte huidskleur',
    '🧘🏿‍♀' => 'vrouw in lotushouding: donkere huidskleur',
    '🧑‍🦰' => 'volwassene: rood haar',
    '🧑‍🦱' => 'volwassene: krullend haar',
    '🧑‍🦳' => 'volwassene: wit haar',
    '🧑‍🦲' => 'volwassene: kaal',
    '👨‍🦰' => 'man: rood haar',
    '👨‍🦱' => 'man: krullend haar',
    '👨‍🦳' => 'man: wit haar',
    '👨‍🦲' => 'man: kaal',
    '👩‍🦰' => 'vrouw: rood haar',
    '👩‍🦱' => 'vrouw: krullend haar',
    '👩‍🦳' => 'vrouw: wit haar',
    '👩‍🦲' => 'vrouw: kaal',
    '🚶‍➡' => 'voetganger: naar rechts gericht',
    '🧎‍➡' => 'knielende persoon: naar rechts gericht',
    '🏃‍➡' => 'hardloper: naar rechts gericht',
    '👨‍👦' => 'gezin: man, jongen',
    '👨‍👧' => 'gezin: man, meisje',
    '👩‍👦' => 'gezin: vrouw, jongen',
    '👩‍👧' => 'gezin: vrouw, meisje',
    '😶‍🌫' => 'gezicht in de wolken',
    '😮‍💨' => 'gezicht dat uitademt',
    '🙂‍↕' => 'hoofd dat verticaal beweegt',
    '😵‍💫' => 'gezicht met spiraalvormige ogen',
    '❤‍🔥' => 'hart in vuur en vlam',
    '❤‍🩹' => 'helend hart',
    '👁‍🗨' => 'spraakballon met oog',
    '🧔‍♂' => 'man: baard',
    '👱‍♂' => 'man met blond haar',
    '🧔‍♀' => 'vrouw: baard',
    '👱‍♀' => 'vrouw met blond haar',
    '🙍‍♂' => 'fronsende man',
    '🙍‍♀' => 'fronsende vrouw',
    '🙎‍♂' => 'pruilende man',
    '🙎‍♀' => 'pruilende vrouw',
    '🙅‍♂' => 'man die nee-gebaar maakt',
    '🙅‍♀' => 'vrouw die nee-gebaar maakt',
    '🙆‍♂' => 'man die OK-gebaar maakt',
    '🙆‍♀' => 'vrouw die OK-gebaar maakt',
    '💁‍♂' => 'man achter informatiebalie',
    '💁‍♀' => 'vrouw achter informatiebalie',
    '🙋‍♂' => 'man met opgeheven hand',
    '🙋‍♀' => 'vrouw met opgeheven hand',
    '🧏‍♂' => 'dove man',
    '🧏‍♀' => 'dove vrouw',
    '🙇‍♂' => 'buigende man',
    '🙇‍♀' => 'buigende vrouw',
    '🤦‍♂' => 'man die het gezicht met de hand bedekt',
    '🤦‍♀' => 'vrouw die het gezicht met de hand bedekt',
    '🤷‍♂' => 'man die schouders ophaalt',
    '🤷‍♀' => 'vrouw die schouders ophaalt',
    '🧑‍⚕' => 'gezondheidsmedewerker',
    '👨‍⚕' => 'mannelijke gezondheidsmedewerker',
    '👩‍⚕' => 'gezondheidsmedewerkster',
    '🧑‍🎓' => 'student',
    '👨‍🎓' => 'mannelijke student',
    '👩‍🎓' => 'studente',
    '🧑‍🏫' => 'docent',
    '👨‍🏫' => 'mannelijke docent',
    '👩‍🏫' => 'docente',
    '🧑‍⚖' => 'rechter',
    '👨‍⚖' => 'mannelijke rechter',
    '👩‍⚖' => 'vrouwelijke rechter',
    '🧑‍🌾' => 'boer',
    '👨‍🌾' => 'mannelijke boer',
    '👩‍🌾' => 'boerin',
    '🧑‍🍳' => 'kok',
    '👨‍🍳' => 'mannelijke kok',
    '👩‍🍳' => 'kokkin',
    '🧑‍🔧' => 'monteur',
    '👨‍🔧' => 'mannelijke monteur',
    '👩‍🔧' => 'monteuse',
    '🧑‍🏭' => 'fabrieksarbeider',
    '👨‍🏭' => 'mannelijke fabrieksarbeider',
    '👩‍🏭' => 'fabrieksarbeidster',
    '🧑‍💼' => 'kantoormedewerker',
    '👨‍💼' => 'mannelijke kantoormedewerker',
    '👩‍💼' => 'kantoormedewerkster',
    '🧑‍🔬' => 'wetenschapper',
    '👨‍🔬' => 'mannelijke wetenschapper',
    '👩‍🔬' => 'wetenschapster',
    '🧑‍💻' => 'technoloog',
    '👨‍💻' => 'mannelijke technoloog',
    '👩‍💻' => 'technologe',
    '🧑‍🎤' => 'zanger',
    '👨‍🎤' => 'mannelijke zanger',
    '👩‍🎤' => 'zangeres',
    '🧑‍🎨' => 'kunstenaar',
    '👨‍🎨' => 'mannelijke kunstenaar',
    '👩‍🎨' => 'kunstenares',
    '🧑‍✈' => 'piloot',
    '👨‍✈' => 'mannelijke piloot',
    '👩‍✈' => 'pilote',
    '🧑‍🚀' => 'astronaut',
    '👨‍🚀' => 'mannelijke astronaut',
    '👩‍🚀' => 'astronaute',
    '🧑‍🚒' => 'brandweerman',
    '👨‍🚒' => 'mannelijke brandweerman',
    '👩‍🚒' => 'brandweervrouw',
    '👮‍♂' => 'politieman',
    '👮‍♀' => 'politievrouw',
    '🕵‍♂' => 'mannelijke detective',
    '🕵‍♀' => 'vrouwelijke detective',
    '💂‍♂' => 'mannelijke wachter',
    '💂‍♀' => 'vrouwelijke wachter',
    '👷‍♂' => 'mannelijke bouwvakker',
    '👷‍♀' => 'vrouwelijke bouwvakker',
    '👳‍♂' => 'man met tulband',
    '👳‍♀' => 'vrouw met tulband',
    '🤵‍♂' => 'man in smoking',
    '🤵‍♀' => 'vrouw in smoking',
    '👰‍♂' => 'man met sluier',
    '👰‍♀' => 'vrouw met sluier',
    '👩‍🍼' => 'vrouw die een baby voedt',
    '👨‍🍼' => 'man die een baby voedt',
    '🧑‍🍼' => 'persoon die een baby voedt',
    '🧑‍🎄' => 'kersttransgender',
    '🦸‍♂' => 'mannelijke superheld',
    '🦸‍♀' => 'vrouwelijke superheld',
    '🦹‍♂' => 'mannelijke superschurk',
    '🦹‍♀' => 'vrouwelijke superschurk',
    '🧙‍♂' => 'mannelijke magiër',
    '🧙‍♀' => 'vrouwelijke magiër',
    '🧚‍♂' => 'mannelijk elfje',
    '🧚‍♀' => 'vrouwelijk elfje',
    '🧛‍♂' => 'mannelijke vampier',
    '🧛‍♀' => 'vrouwelijke vampier',
    '🧜‍♂' => 'zeemeerman',
    '🧜‍♀' => 'sirene',
    '🧝‍♂' => 'mannelijke elf',
    '🧝‍♀' => 'vrouwelijke elf',
    '🧞‍♂' => 'mannelijke geest in de fles',
    '🧞‍♀' => 'vrouwelijke geest in de fles',
    '🧟‍♂' => 'mannelijke zombie',
    '🧟‍♀' => 'vrouwelijke zombie',
    '💆‍♂' => 'man die hoofdmassage krijgt',
    '💆‍♀' => 'vrouw die hoofdmassage krijgt',
    '💇‍♂' => 'man die wordt geknipt',
    '💇‍♀' => 'vrouw die wordt geknipt',
    '🚶‍♂' => 'wandelende man',
    '🚶‍♀' => 'wandelende vrouw',
    '🧍‍♂' => 'staande man',
    '🧍‍♀' => 'staande vrouw',
    '🧎‍♂' => 'knielende man',
    '🧎‍♀' => 'knielende vrouw',
    '🧑‍🦯' => 'persoon met taststok',
    '👨‍🦯' => 'man met taststok',
    '👩‍🦯' => 'vrouw met taststok',
    '🧑‍🦼' => 'persoon in elektrische rolstoel',
    '👨‍🦼' => 'man in elektrische rolstoel',
    '👩‍🦼' => 'vrouw in elektrische rolstoel',
    '🧑‍🦽' => 'persoon in rolstoel',
    '👨‍🦽' => 'man in rolstoel',
    '👩‍🦽' => 'vrouw in rolstoel',
    '🏃‍♂' => 'rennende man',
    '🏃‍♀' => 'rennende vrouw',
    '🧑‍🩰' => 'balletdanser',
    '👯‍♂' => 'mannen met konijnenoren',
    '👯‍♀' => 'vrouwen met konijnenoren',
    '🧖‍♂' => 'man in ruimte vol stoom',
    '🧖‍♀' => 'vrouw in ruimte vol stoom',
    '🧗‍♂' => 'klimmende man',
    '🧗‍♀' => 'klimmende vrouw',
    '🏌‍♂' => 'golfende man',
    '🏌‍♀' => 'golfende vrouw',
    '🏄‍♂' => 'mannelijke surfer',
    '🏄‍♀' => 'vrouwelijke surfer',
    '🚣‍♂' => 'man in roeiboot',
    '🚣‍♀' => 'vrouw in roeiboot',
    '🏊‍♂' => 'zwemmende man',
    '🏊‍♀' => 'zwemmende vrouw',
    '⛹‍♂' => 'basketballer',
    '⛹‍♀' => 'basketbalster',
    '🏋‍♂' => 'mannelijke gewichtheffer',
    '🏋‍♀' => 'vrouwelijke gewichtheffer',
    '🚴‍♂' => 'fietsende man',
    '🚴‍♀' => 'fietsende vrouw',
    '🚵‍♂' => 'man op mountainbike',
    '🚵‍♀' => 'vrouw op mountainbike',
    '🤸‍♂' => 'man die een radslag doet',
    '🤸‍♀' => 'vrouw die een radslag doet',
    '🤼‍♂' => 'worstelende mannen',
    '🤼‍♀' => 'worstelende vrouwen',
    '🤽‍♂' => 'man die waterpolo speelt',
    '🤽‍♀' => 'vrouw die waterpolo speelt',
    '🤾‍♂' => 'man die handbal speelt',
    '🤾‍♀' => 'vrouw die handbal speelt',
    '🤹‍♂' => 'man die jongleert',
    '🤹‍♀' => 'vrouw die jongleert',
    '🧘‍♂' => 'man in lotushouding',
    '🧘‍♀' => 'vrouw in lotushouding',
    '🧑‍🧒' => 'gezin: volwassene, kind',
    '🐕‍🦺' => 'assistentiehond',
    '🐈‍⬛' => 'zwarte kat',
    '🐻‍❄' => 'ijsbeer',
    '🐦‍⬛' => 'merel',
    '🐦‍🔥' => 'feniks',
    '🍋‍🟩' => 'limoen',
    '🍄‍🟫' => 'bruine paddestoel',
    '⛓‍💥' => 'gebroken ketting',
    '🏳‍🌈' => 'regenboogvlag',
    '🏳‍⚧' => 'transgendervlag',
    '🏴‍☠' => 'piratenvlag',
    '👋🏻' => 'zwaaiende hand: lichte huidskleur',
    '👋🏼' => 'zwaaiende hand: lichtgetinte huidskleur',
    '👋🏽' => 'zwaaiende hand: getinte huidskleur',
    '👋🏾' => 'zwaaiende hand: donkergetinte huidskleur',
    '👋🏿' => 'zwaaiende hand: donkere huidskleur',
    '🤚🏻' => 'achterkant van opgeheven hand: lichte huidskleur',
    '🤚🏼' => 'achterkant van opgeheven hand: lichtgetinte huidskleur',
    '🤚🏽' => 'achterkant van opgeheven hand: getinte huidskleur',
    '🤚🏾' => 'achterkant van opgeheven hand: donkergetinte huidskleur',
    '🤚🏿' => 'achterkant van opgeheven hand: donkere huidskleur',
    '🖐🏻' => 'opgeheven hand met uitgestoken vingers: lichte huidskleur',
    '🖐🏼' => 'opgeheven hand met uitgestoken vingers: lichtgetinte huidskleur',
    '🖐🏽' => 'opgeheven hand met uitgestoken vingers: getinte huidskleur',
    '🖐🏾' => 'opgeheven hand met uitgestoken vingers: donkergetinte huidskleur',
    '🖐🏿' => 'opgeheven hand met uitgestoken vingers: donkere huidskleur',
    '✋🏻' => 'opgeheven hand: lichte huidskleur',
    '✋🏼' => 'opgeheven hand: lichtgetinte huidskleur',
    '✋🏽' => 'opgeheven hand: getinte huidskleur',
    '✋🏾' => 'opgeheven hand: donkergetinte huidskleur',
    '✋🏿' => 'opgeheven hand: donkere huidskleur',
    '🖖🏻' => 'Vulcaanse groet: lichte huidskleur',
    '🖖🏼' => 'Vulcaanse groet: lichtgetinte huidskleur',
    '🖖🏽' => 'Vulcaanse groet: getinte huidskleur',
    '🖖🏾' => 'Vulcaanse groet: donkergetinte huidskleur',
    '🖖🏿' => 'Vulcaanse groet: donkere huidskleur',
    '🫱🏻' => 'hand naar rechts: lichte huidskleur',
    '🫱🏼' => 'hand naar rechts: lichtgetinte huidskleur',
    '🫱🏽' => 'hand naar rechts: getinte huidskleur',
    '🫱🏾' => 'hand naar rechts: donkergetinte huidskleur',
    '🫱🏿' => 'hand naar rechts: donkere huidskleur',
    '🫲🏻' => 'hand naar links: lichte huidskleur',
    '🫲🏼' => 'hand naar links: lichtgetinte huidskleur',
    '🫲🏽' => 'hand naar links: getinte huidskleur',
    '🫲🏾' => 'hand naar links: donkergetinte huidskleur',
    '🫲🏿' => 'hand naar links: donkere huidskleur',
    '🫳🏻' => 'handpalm omlaag: lichte huidskleur',
    '🫳🏼' => 'handpalm omlaag: lichtgetinte huidskleur',
    '🫳🏽' => 'handpalm omlaag: getinte huidskleur',
    '🫳🏾' => 'handpalm omlaag: donkergetinte huidskleur',
    '🫳🏿' => 'handpalm omlaag: donkere huidskleur',
    '🫴🏻' => 'handpalm omhoog: lichte huidskleur',
    '🫴🏼' => 'handpalm omhoog: lichtgetinte huidskleur',
    '🫴🏽' => 'handpalm omhoog: getinte huidskleur',
    '🫴🏾' => 'handpalm omhoog: donkergetinte huidskleur',
    '🫴🏿' => 'handpalm omhoog: donkere huidskleur',
    '🫷🏻' => 'hand die naar links duwt: lichte huidskleur',
    '🫷🏼' => 'hand die naar links duwt: lichtgetinte huidskleur',
    '🫷🏽' => 'hand die naar links duwt: getinte huidskleur',
    '🫷🏾' => 'hand die naar links duwt: donkergetinte huidskleur',
    '🫷🏿' => 'hand die naar links duwt: donkere huidskleur',
    '🫸🏻' => 'hand die naar rechts duwt: lichte huidskleur',
    '🫸🏼' => 'hand die naar rechts duwt: lichtgetinte huidskleur',
    '🫸🏽' => 'hand die naar rechts duwt: getinte huidskleur',
    '🫸🏾' => 'hand die naar rechts duwt: donkergetinte huidskleur',
    '🫸🏿' => 'hand die naar rechts duwt: donkere huidskleur',
    '👌🏻' => 'OK-handgebaar: lichte huidskleur',
    '👌🏼' => 'OK-handgebaar: lichtgetinte huidskleur',
    '👌🏽' => 'OK-handgebaar: getinte huidskleur',
    '👌🏾' => 'OK-handgebaar: donkergetinte huidskleur',
    '👌🏿' => 'OK-handgebaar: donkere huidskleur',
    '🤌🏻' => 'samengeknepen vingers: lichte huidskleur',
    '🤌🏼' => 'samengeknepen vingers: lichtgetinte huidskleur',
    '🤌🏽' => 'samengeknepen vingers: getinte huidskleur',
    '🤌🏾' => 'samengeknepen vingers: donkergetinte huidskleur',
    '🤌🏿' => 'samengeknepen vingers: donkere huidskleur',
    '🤏🏻' => 'hand met samengeknepen vingers: lichte huidskleur',
    '🤏🏼' => 'hand met samengeknepen vingers: lichtgetinte huidskleur',
    '🤏🏽' => 'hand met samengeknepen vingers: getinte huidskleur',
    '🤏🏾' => 'hand met samengeknepen vingers: donkergetinte huidskleur',
    '🤏🏿' => 'hand met samengeknepen vingers: donkere huidskleur',
    '✌🏻' => 'winnende hand: lichte huidskleur',
    '✌🏼' => 'winnende hand: lichtgetinte huidskleur',
    '✌🏽' => 'winnende hand: getinte huidskleur',
    '✌🏾' => 'winnende hand: donkergetinte huidskleur',
    '✌🏿' => 'winnende hand: donkere huidskleur',
    '🤞🏻' => 'gekruiste vingers: lichte huidskleur',
    '🤞🏼' => 'gekruiste vingers: lichtgetinte huidskleur',
    '🤞🏽' => 'gekruiste vingers: getinte huidskleur',
    '🤞🏾' => 'gekruiste vingers: donkergetinte huidskleur',
    '🤞🏿' => 'gekruiste vingers: donkere huidskleur',
    '🫰🏻' => 'hand met wijsvinger en duim gekruist: lichte huidskleur',
    '🫰🏼' => 'hand met wijsvinger en duim gekruist: lichtgetinte huidskleur',
    '🫰🏽' => 'hand met wijsvinger en duim gekruist: getinte huidskleur',
    '🫰🏾' => 'hand met wijsvinger en duim gekruist: donkergetinte huidskleur',
    '🫰🏿' => 'hand met wijsvinger en duim gekruist: donkere huidskleur',
    '🤟🏻' => 'ik-hou-van-je-gebaar: lichte huidskleur',
    '🤟🏼' => 'ik-hou-van-je-gebaar: lichtgetinte huidskleur',
    '🤟🏽' => 'ik-hou-van-je-gebaar: getinte huidskleur',
    '🤟🏾' => 'ik-hou-van-je-gebaar: donkergetinte huidskleur',
    '🤟🏿' => 'ik-hou-van-je-gebaar: donkere huidskleur',
    '🤘🏻' => 'duivelshorens: lichte huidskleur',
    '🤘🏼' => 'duivelshorens: lichtgetinte huidskleur',
    '🤘🏽' => 'duivelshorens: getinte huidskleur',
    '🤘🏾' => 'duivelshorens: donkergetinte huidskleur',
    '🤘🏿' => 'duivelshorens: donkere huidskleur',
    '🤙🏻' => 'bel me-gebaar: lichte huidskleur',
    '🤙🏼' => 'bel me-gebaar: lichtgetinte huidskleur',
    '🤙🏽' => 'bel me-gebaar: getinte huidskleur',
    '🤙🏾' => 'bel me-gebaar: donkergetinte huidskleur',
    '🤙🏿' => 'bel me-gebaar: donkere huidskleur',
    '👈🏻' => 'achterkant van hand met naar links wijzende wijsvinger: lichte huidskleur',
    '👈🏼' => 'achterkant van hand met naar links wijzende wijsvinger: lichtgetinte huidskleur',
    '👈🏽' => 'achterkant van hand met naar links wijzende wijsvinger: getinte huidskleur',
    '👈🏾' => 'achterkant van hand met naar links wijzende wijsvinger: donkergetinte huidskleur',
    '👈🏿' => 'achterkant van hand met naar links wijzende wijsvinger: donkere huidskleur',
    '👉🏻' => 'achterkant van hand met naar rechts wijzende wijsvinger: lichte huidskleur',
    '👉🏼' => 'achterkant van hand met naar rechts wijzende wijsvinger: lichtgetinte huidskleur',
    '👉🏽' => 'achterkant van hand met naar rechts wijzende wijsvinger: getinte huidskleur',
    '👉🏾' => 'achterkant van hand met naar rechts wijzende wijsvinger: donkergetinte huidskleur',
    '👉🏿' => 'achterkant van hand met naar rechts wijzende wijsvinger: donkere huidskleur',
    '👆🏻' => 'achterkant van hand met omhoog wijzende wijsvinger: lichte huidskleur',
    '👆🏼' => 'achterkant van hand met omhoog wijzende wijsvinger: lichtgetinte huidskleur',
    '👆🏽' => 'achterkant van hand met omhoog wijzende wijsvinger: getinte huidskleur',
    '👆🏾' => 'achterkant van hand met omhoog wijzende wijsvinger: donkergetinte huidskleur',
    '👆🏿' => 'achterkant van hand met omhoog wijzende wijsvinger: donkere huidskleur',
    '🖕🏻' => 'middelvinger: lichte huidskleur',
    '🖕🏼' => 'middelvinger: lichtgetinte huidskleur',
    '🖕🏽' => 'middelvinger: getinte huidskleur',
    '🖕🏾' => 'middelvinger: donkergetinte huidskleur',
    '🖕🏿' => 'middelvinger: donkere huidskleur',
    '👇🏻' => 'achterkant van hand met omlaag wijzende wijsvinger: lichte huidskleur',
    '👇🏼' => 'achterkant van hand met omlaag wijzende wijsvinger: lichtgetinte huidskleur',
    '👇🏽' => 'achterkant van hand met omlaag wijzende wijsvinger: getinte huidskleur',
    '👇🏾' => 'achterkant van hand met omlaag wijzende wijsvinger: donkergetinte huidskleur',
    '👇🏿' => 'achterkant van hand met omlaag wijzende wijsvinger: donkere huidskleur',
    '☝🏻' => 'omhoog wijzende wijsvinger: lichte huidskleur',
    '☝🏼' => 'omhoog wijzende wijsvinger: lichtgetinte huidskleur',
    '☝🏽' => 'omhoog wijzende wijsvinger: getinte huidskleur',
    '☝🏾' => 'omhoog wijzende wijsvinger: donkergetinte huidskleur',
    '☝🏿' => 'omhoog wijzende wijsvinger: donkere huidskleur',
    '🫵🏻' => 'wijsvinger die naar de kijker wijst: lichte huidskleur',
    '🫵🏼' => 'wijsvinger die naar de kijker wijst: lichtgetinte huidskleur',
    '🫵🏽' => 'wijsvinger die naar de kijker wijst: getinte huidskleur',
    '🫵🏾' => 'wijsvinger die naar de kijker wijst: donkergetinte huidskleur',
    '🫵🏿' => 'wijsvinger die naar de kijker wijst: donkere huidskleur',
    '👍🏻' => 'duim omhoog: lichte huidskleur',
    '👍🏼' => 'duim omhoog: lichtgetinte huidskleur',
    '👍🏽' => 'duim omhoog: getinte huidskleur',
    '👍🏾' => 'duim omhoog: donkergetinte huidskleur',
    '👍🏿' => 'duim omhoog: donkere huidskleur',
    '👎🏻' => 'duim omlaag: lichte huidskleur',
    '👎🏼' => 'duim omlaag: lichtgetinte huidskleur',
    '👎🏽' => 'duim omlaag: getinte huidskleur',
    '👎🏾' => 'duim omlaag: donkergetinte huidskleur',
    '👎🏿' => 'duim omlaag: donkere huidskleur',
    '✊🏻' => 'opgeheven vuist: lichte huidskleur',
    '✊🏼' => 'opgeheven vuist: lichtgetinte huidskleur',
    '✊🏽' => 'opgeheven vuist: getinte huidskleur',
    '✊🏾' => 'opgeheven vuist: donkergetinte huidskleur',
    '✊🏿' => 'opgeheven vuist: donkere huidskleur',
    '👊🏻' => 'stotende vuist: lichte huidskleur',
    '👊🏼' => 'stotende vuist: lichtgetinte huidskleur',
    '👊🏽' => 'stotende vuist: getinte huidskleur',
    '👊🏾' => 'stotende vuist: donkergetinte huidskleur',
    '👊🏿' => 'stotende vuist: donkere huidskleur',
    '🤛🏻' => 'naar links gerichte vuist: lichte huidskleur',
    '🤛🏼' => 'naar links gerichte vuist: lichtgetinte huidskleur',
    '🤛🏽' => 'naar links gerichte vuist: getinte huidskleur',
    '🤛🏾' => 'naar links gerichte vuist: donkergetinte huidskleur',
    '🤛🏿' => 'naar links gerichte vuist: donkere huidskleur',
    '🤜🏻' => 'naar rechts gerichte vuist: lichte huidskleur',
    '🤜🏼' => 'naar rechts gerichte vuist: lichtgetinte huidskleur',
    '🤜🏽' => 'naar rechts gerichte vuist: getinte huidskleur',
    '🤜🏾' => 'naar rechts gerichte vuist: donkergetinte huidskleur',
    '🤜🏿' => 'naar rechts gerichte vuist: donkere huidskleur',
    '👏🏻' => 'klappende handen: lichte huidskleur',
    '👏🏼' => 'klappende handen: lichtgetinte huidskleur',
    '👏🏽' => 'klappende handen: getinte huidskleur',
    '👏🏾' => 'klappende handen: donkergetinte huidskleur',
    '👏🏿' => 'klappende handen: donkere huidskleur',
    '🙌🏻' => 'juichend omhooggestoken handen: lichte huidskleur',
    '🙌🏼' => 'juichend omhooggestoken handen: lichtgetinte huidskleur',
    '🙌🏽' => 'juichend omhooggestoken handen: getinte huidskleur',
    '🙌🏾' => 'juichend omhooggestoken handen: donkergetinte huidskleur',
    '🙌🏿' => 'juichend omhooggestoken handen: donkere huidskleur',
    '🫶🏻' => 'handen in de vorm van een hart: lichte huidskleur',
    '🫶🏼' => 'handen in de vorm van een hart: lichtgetinte huidskleur',
    '🫶🏽' => 'handen in de vorm van een hart: getinte huidskleur',
    '🫶🏾' => 'handen in de vorm van een hart: donkergetinte huidskleur',
    '🫶🏿' => 'handen in de vorm van een hart: donkere huidskleur',
    '👐🏻' => 'open handen: lichte huidskleur',
    '👐🏼' => 'open handen: lichtgetinte huidskleur',
    '👐🏽' => 'open handen: getinte huidskleur',
    '👐🏾' => 'open handen: donkergetinte huidskleur',
    '👐🏿' => 'open handen: donkere huidskleur',
    '🤲🏻' => 'beide handpalmen omhoog: lichte huidskleur',
    '🤲🏼' => 'beide handpalmen omhoog: lichtgetinte huidskleur',
    '🤲🏽' => 'beide handpalmen omhoog: getinte huidskleur',
    '🤲🏾' => 'beide handpalmen omhoog: donkergetinte huidskleur',
    '🤲🏿' => 'beide handpalmen omhoog: donkere huidskleur',
    '🤝🏻' => 'handdruk: lichte huidskleur',
    '🤝🏼' => 'handdruk: lichtgetinte huidskleur',
    '🤝🏽' => 'handdruk: getinte huidskleur',
    '🤝🏾' => 'handdruk: donkergetinte huidskleur',
    '🤝🏿' => 'handdruk: donkere huidskleur',
    '🙏🏻' => 'gevouwen handen: lichte huidskleur',
    '🙏🏼' => 'gevouwen handen: lichtgetinte huidskleur',
    '🙏🏽' => 'gevouwen handen: getinte huidskleur',
    '🙏🏾' => 'gevouwen handen: donkergetinte huidskleur',
    '🙏🏿' => 'gevouwen handen: donkere huidskleur',
    '✍🏻' => 'schrijvende hand: lichte huidskleur',
    '✍🏼' => 'schrijvende hand: lichtgetinte huidskleur',
    '✍🏽' => 'schrijvende hand: getinte huidskleur',
    '✍🏾' => 'schrijvende hand: donkergetinte huidskleur',
    '✍🏿' => 'schrijvende hand: donkere huidskleur',
    '💅🏻' => 'nagellak: lichte huidskleur',
    '💅🏼' => 'nagellak: lichtgetinte huidskleur',
    '💅🏽' => 'nagellak: getinte huidskleur',
    '💅🏾' => 'nagellak: donkergetinte huidskleur',
    '💅🏿' => 'nagellak: donkere huidskleur',
    '🤳🏻' => 'selfie: lichte huidskleur',
    '🤳🏼' => 'selfie: lichtgetinte huidskleur',
    '🤳🏽' => 'selfie: getinte huidskleur',
    '🤳🏾' => 'selfie: donkergetinte huidskleur',
    '🤳🏿' => 'selfie: donkere huidskleur',
    '💪🏻' => 'spierballen: lichte huidskleur',
    '💪🏼' => 'spierballen: lichtgetinte huidskleur',
    '💪🏽' => 'spierballen: getinte huidskleur',
    '💪🏾' => 'spierballen: donkergetinte huidskleur',
    '💪🏿' => 'spierballen: donkere huidskleur',
    '🦵🏻' => 'been: lichte huidskleur',
    '🦵🏼' => 'been: lichtgetinte huidskleur',
    '🦵🏽' => 'been: getinte huidskleur',
    '🦵🏾' => 'been: donkergetinte huidskleur',
    '🦵🏿' => 'been: donkere huidskleur',
    '🦶🏻' => 'voet: lichte huidskleur',
    '🦶🏼' => 'voet: lichtgetinte huidskleur',
    '🦶🏽' => 'voet: getinte huidskleur',
    '🦶🏾' => 'voet: donkergetinte huidskleur',
    '🦶🏿' => 'voet: donkere huidskleur',
    '👂🏻' => 'oor: lichte huidskleur',
    '👂🏼' => 'oor: lichtgetinte huidskleur',
    '👂🏽' => 'oor: getinte huidskleur',
    '👂🏾' => 'oor: donkergetinte huidskleur',
    '👂🏿' => 'oor: donkere huidskleur',
    '🦻🏻' => 'oor met gehoorapparaat: lichte huidskleur',
    '🦻🏼' => 'oor met gehoorapparaat: lichtgetinte huidskleur',
    '🦻🏽' => 'oor met gehoorapparaat: getinte huidskleur',
    '🦻🏾' => 'oor met gehoorapparaat: donkergetinte huidskleur',
    '🦻🏿' => 'oor met gehoorapparaat: donkere huidskleur',
    '👃🏻' => 'neus: lichte huidskleur',
    '👃🏼' => 'neus: lichtgetinte huidskleur',
    '👃🏽' => 'neus: getinte huidskleur',
    '👃🏾' => 'neus: donkergetinte huidskleur',
    '👃🏿' => 'neus: donkere huidskleur',
    '👶🏻' => 'baby: lichte huidskleur',
    '👶🏼' => 'baby: lichtgetinte huidskleur',
    '👶🏽' => 'baby: getinte huidskleur',
    '👶🏾' => 'baby: donkergetinte huidskleur',
    '👶🏿' => 'baby: donkere huidskleur',
    '🧒🏻' => 'kind: lichte huidskleur',
    '🧒🏼' => 'kind: lichtgetinte huidskleur',
    '🧒🏽' => 'kind: getinte huidskleur',
    '🧒🏾' => 'kind: donkergetinte huidskleur',
    '🧒🏿' => 'kind: donkere huidskleur',
    '👦🏻' => 'jongen: lichte huidskleur',
    '👦🏼' => 'jongen: lichtgetinte huidskleur',
    '👦🏽' => 'jongen: getinte huidskleur',
    '👦🏾' => 'jongen: donkergetinte huidskleur',
    '👦🏿' => 'jongen: donkere huidskleur',
    '👧🏻' => 'meisje: lichte huidskleur',
    '👧🏼' => 'meisje: lichtgetinte huidskleur',
    '👧🏽' => 'meisje: getinte huidskleur',
    '👧🏾' => 'meisje: donkergetinte huidskleur',
    '👧🏿' => 'meisje: donkere huidskleur',
    '🧑🏻' => 'volwassene: lichte huidskleur',
    '🧑🏼' => 'volwassene: lichtgetinte huidskleur',
    '🧑🏽' => 'volwassene: getinte huidskleur',
    '🧑🏾' => 'volwassene: donkergetinte huidskleur',
    '🧑🏿' => 'volwassene: donkere huidskleur',
    '👱🏻' => 'persoon met blond haar: lichte huidskleur',
    '👱🏼' => 'persoon met blond haar: lichtgetinte huidskleur',
    '👱🏽' => 'persoon met blond haar: getinte huidskleur',
    '👱🏾' => 'persoon met blond haar: donkergetinte huidskleur',
    '👱🏿' => 'persoon met blond haar: donkere huidskleur',
    '👨🏻' => 'man: lichte huidskleur',
    '👨🏼' => 'man: lichtgetinte huidskleur',
    '👨🏽' => 'man: getinte huidskleur',
    '👨🏾' => 'man: donkergetinte huidskleur',
    '👨🏿' => 'man: donkere huidskleur',
    '🧔🏻' => 'persoon: lichte huidskleur, baard',
    '🧔🏼' => 'persoon: lichtgetinte huidskleur, baard',
    '🧔🏽' => 'persoon: getinte huidskleur, baard',
    '🧔🏾' => 'persoon: donkergetinte huidskleur, baard',
    '🧔🏿' => 'persoon: donkere huidskleur, baard',
    '👩🏻' => 'vrouw: lichte huidskleur',
    '👩🏼' => 'vrouw: lichtgetinte huidskleur',
    '👩🏽' => 'vrouw: getinte huidskleur',
    '👩🏾' => 'vrouw: donkergetinte huidskleur',
    '👩🏿' => 'vrouw: donkere huidskleur',
    '🧓🏻' => 'oudere persoon: lichte huidskleur',
    '🧓🏼' => 'oudere persoon: lichtgetinte huidskleur',
    '🧓🏽' => 'oudere persoon: getinte huidskleur',
    '🧓🏾' => 'oudere persoon: donkergetinte huidskleur',
    '🧓🏿' => 'oudere persoon: donkere huidskleur',
    '👴🏻' => 'oude man: lichte huidskleur',
    '👴🏼' => 'oude man: lichtgetinte huidskleur',
    '👴🏽' => 'oude man: getinte huidskleur',
    '👴🏾' => 'oude man: donkergetinte huidskleur',
    '👴🏿' => 'oude man: donkere huidskleur',
    '👵🏻' => 'oude vrouw: lichte huidskleur',
    '👵🏼' => 'oude vrouw: lichtgetinte huidskleur',
    '👵🏽' => 'oude vrouw: getinte huidskleur',
    '👵🏾' => 'oude vrouw: donkergetinte huidskleur',
    '👵🏿' => 'oude vrouw: donkere huidskleur',
    '🙍🏻' => 'fronsend persoon: lichte huidskleur',
    '🙍🏼' => 'fronsend persoon: lichtgetinte huidskleur',
    '🙍🏽' => 'fronsend persoon: getinte huidskleur',
    '🙍🏾' => 'fronsend persoon: donkergetinte huidskleur',
    '🙍🏿' => 'fronsend persoon: donkere huidskleur',
    '🙎🏻' => 'pruilend persoon: lichte huidskleur',
    '🙎🏼' => 'pruilend persoon: lichtgetinte huidskleur',
    '🙎🏽' => 'pruilend persoon: getinte huidskleur',
    '🙎🏾' => 'pruilend persoon: donkergetinte huidskleur',
    '🙎🏿' => 'pruilend persoon: donkere huidskleur',
    '🙅🏻' => 'persoon die nee-gebaar maakt: lichte huidskleur',
    '🙅🏼' => 'persoon die nee-gebaar maakt: lichtgetinte huidskleur',
    '🙅🏽' => 'persoon die nee-gebaar maakt: getinte huidskleur',
    '🙅🏾' => 'persoon die nee-gebaar maakt: donkergetinte huidskleur',
    '🙅🏿' => 'persoon die nee-gebaar maakt: donkere huidskleur',
    '🙆🏻' => 'persoon die OK-gebaar maakt: lichte huidskleur',
    '🙆🏼' => 'persoon die OK-gebaar maakt: lichtgetinte huidskleur',
    '🙆🏽' => 'persoon die OK-gebaar maakt: getinte huidskleur',
    '🙆🏾' => 'persoon die OK-gebaar maakt: donkergetinte huidskleur',
    '🙆🏿' => 'persoon die OK-gebaar maakt: donkere huidskleur',
    '💁🏻' => 'persoon achter informatiebalie: lichte huidskleur',
    '💁🏼' => 'persoon achter informatiebalie: lichtgetinte huidskleur',
    '💁🏽' => 'persoon achter informatiebalie: getinte huidskleur',
    '💁🏾' => 'persoon achter informatiebalie: donkergetinte huidskleur',
    '💁🏿' => 'persoon achter informatiebalie: donkere huidskleur',
    '🙋🏻' => 'persoon met opgeheven hand: lichte huidskleur',
    '🙋🏼' => 'persoon met opgeheven hand: lichtgetinte huidskleur',
    '🙋🏽' => 'persoon met opgeheven hand: getinte huidskleur',
    '🙋🏾' => 'persoon met opgeheven hand: donkergetinte huidskleur',
    '🙋🏿' => 'persoon met opgeheven hand: donkere huidskleur',
    '🧏🏻' => 'doof persoon: lichte huidskleur',
    '🧏🏼' => 'doof persoon: lichtgetinte huidskleur',
    '🧏🏽' => 'doof persoon: getinte huidskleur',
    '🧏🏾' => 'doof persoon: donkergetinte huidskleur',
    '🧏🏿' => 'doof persoon: donkere huidskleur',
    '🙇🏻' => 'buigende persoon: lichte huidskleur',
    '🙇🏼' => 'buigende persoon: lichtgetinte huidskleur',
    '🙇🏽' => 'buigende persoon: getinte huidskleur',
    '🙇🏾' => 'buigende persoon: donkergetinte huidskleur',
    '🙇🏿' => 'buigende persoon: donkere huidskleur',
    '🤦🏻' => 'persoon die het gezicht met de hand bedekt: lichte huidskleur',
    '🤦🏼' => 'persoon die het gezicht met de hand bedekt: lichtgetinte huidskleur',
    '🤦🏽' => 'persoon die het gezicht met de hand bedekt: getinte huidskleur',
    '🤦🏾' => 'persoon die het gezicht met de hand bedekt: donkergetinte huidskleur',
    '🤦🏿' => 'persoon die het gezicht met de hand bedekt: donkere huidskleur',
    '🤷🏻' => 'persoon die schouders ophaalt: lichte huidskleur',
    '🤷🏼' => 'persoon die schouders ophaalt: lichtgetinte huidskleur',
    '🤷🏽' => 'persoon die schouders ophaalt: getinte huidskleur',
    '🤷🏾' => 'persoon die schouders ophaalt: donkergetinte huidskleur',
    '🤷🏿' => 'persoon die schouders ophaalt: donkere huidskleur',
    '👮🏻' => 'politieagent: lichte huidskleur',
    '👮🏼' => 'politieagent: lichtgetinte huidskleur',
    '👮🏽' => 'politieagent: getinte huidskleur',
    '👮🏾' => 'politieagent: donkergetinte huidskleur',
    '👮🏿' => 'politieagent: donkere huidskleur',
    '🕵🏻' => 'detective: lichte huidskleur',
    '🕵🏼' => 'detective: lichtgetinte huidskleur',
    '🕵🏽' => 'detective: getinte huidskleur',
    '🕵🏾' => 'detective: donkergetinte huidskleur',
    '🕵🏿' => 'detective: donkere huidskleur',
    '💂🏻' => 'wachter: lichte huidskleur',
    '💂🏼' => 'wachter: lichtgetinte huidskleur',
    '💂🏽' => 'wachter: getinte huidskleur',
    '💂🏾' => 'wachter: donkergetinte huidskleur',
    '💂🏿' => 'wachter: donkere huidskleur',
    '🥷🏻' => 'ninja: lichte huidskleur',
    '🥷🏼' => 'ninja: lichtgetinte huidskleur',
    '🥷🏽' => 'ninja: getinte huidskleur',
    '🥷🏾' => 'ninja: donkergetinte huidskleur',
    '🥷🏿' => 'ninja: donkere huidskleur',
    '👷🏻' => 'bouwvakker: lichte huidskleur',
    '👷🏼' => 'bouwvakker: lichtgetinte huidskleur',
    '👷🏽' => 'bouwvakker: getinte huidskleur',
    '👷🏾' => 'bouwvakker: donkergetinte huidskleur',
    '👷🏿' => 'bouwvakker: donkere huidskleur',
    '🫅🏻' => 'persoon met kroon: lichte huidskleur',
    '🫅🏼' => 'persoon met kroon: lichtgetinte huidskleur',
    '🫅🏽' => 'persoon met kroon: getinte huidskleur',
    '🫅🏾' => 'persoon met kroon: donkergetinte huidskleur',
    '🫅🏿' => 'persoon met kroon: donkere huidskleur',
    '🤴🏻' => 'prins: lichte huidskleur',
    '🤴🏼' => 'prins: lichtgetinte huidskleur',
    '🤴🏽' => 'prins: getinte huidskleur',
    '🤴🏾' => 'prins: donkergetinte huidskleur',
    '🤴🏿' => 'prins: donkere huidskleur',
    '👸🏻' => 'prinses: lichte huidskleur',
    '👸🏼' => 'prinses: lichtgetinte huidskleur',
    '👸🏽' => 'prinses: getinte huidskleur',
    '👸🏾' => 'prinses: donkergetinte huidskleur',
    '👸🏿' => 'prinses: donkere huidskleur',
    '👳🏻' => 'persoon met tulband: lichte huidskleur',
    '👳🏼' => 'persoon met tulband: lichtgetinte huidskleur',
    '👳🏽' => 'persoon met tulband: getinte huidskleur',
    '👳🏾' => 'persoon met tulband: donkergetinte huidskleur',
    '👳🏿' => 'persoon met tulband: donkere huidskleur',
    '👲🏻' => 'man met Chinees petje: lichte huidskleur',
    '👲🏼' => 'man met Chinees petje: lichtgetinte huidskleur',
    '👲🏽' => 'man met Chinees petje: getinte huidskleur',
    '👲🏾' => 'man met Chinees petje: donkergetinte huidskleur',
    '👲🏿' => 'man met Chinees petje: donkere huidskleur',
    '🧕🏻' => 'vrouw met hoofddoek: lichte huidskleur',
    '🧕🏼' => 'vrouw met hoofddoek: lichtgetinte huidskleur',
    '🧕🏽' => 'vrouw met hoofddoek: getinte huidskleur',
    '🧕🏾' => 'vrouw met hoofddoek: donkergetinte huidskleur',
    '🧕🏿' => 'vrouw met hoofddoek: donkere huidskleur',
    '🤵🏻' => 'persoon in smoking: lichte huidskleur',
    '🤵🏼' => 'persoon in smoking: lichtgetinte huidskleur',
    '🤵🏽' => 'persoon in smoking: getinte huidskleur',
    '🤵🏾' => 'persoon in smoking: donkergetinte huidskleur',
    '🤵🏿' => 'persoon in smoking: donkere huidskleur',
    '👰🏻' => 'persoon met sluier: lichte huidskleur',
    '👰🏼' => 'persoon met sluier: lichtgetinte huidskleur',
    '👰🏽' => 'persoon met sluier: getinte huidskleur',
    '👰🏾' => 'persoon met sluier: donkergetinte huidskleur',
    '👰🏿' => 'persoon met sluier: donkere huidskleur',
    '🤰🏻' => 'zwangere vrouw: lichte huidskleur',
    '🤰🏼' => 'zwangere vrouw: lichtgetinte huidskleur',
    '🤰🏽' => 'zwangere vrouw: getinte huidskleur',
    '🤰🏾' => 'zwangere vrouw: donkergetinte huidskleur',
    '🤰🏿' => 'zwangere vrouw: donkere huidskleur',
    '🫃🏻' => 'zwangere man: lichte huidskleur',
    '🫃🏼' => 'zwangere man: lichtgetinte huidskleur',
    '🫃🏽' => 'zwangere man: getinte huidskleur',
    '🫃🏾' => 'zwangere man: donkergetinte huidskleur',
    '🫃🏿' => 'zwangere man: donkere huidskleur',
    '🫄🏻' => 'zwanger persoon: lichte huidskleur',
    '🫄🏼' => 'zwanger persoon: lichtgetinte huidskleur',
    '🫄🏽' => 'zwanger persoon: getinte huidskleur',
    '🫄🏾' => 'zwanger persoon: donkergetinte huidskleur',
    '🫄🏿' => 'zwanger persoon: donkere huidskleur',
    '🤱🏻' => 'borstvoeding: lichte huidskleur',
    '🤱🏼' => 'borstvoeding: lichtgetinte huidskleur',
    '🤱🏽' => 'borstvoeding: getinte huidskleur',
    '🤱🏾' => 'borstvoeding: donkergetinte huidskleur',
    '🤱🏿' => 'borstvoeding: donkere huidskleur',
    '👼🏻' => 'baby-engel: lichte huidskleur',
    '👼🏼' => 'baby-engel: lichtgetinte huidskleur',
    '👼🏽' => 'baby-engel: getinte huidskleur',
    '👼🏾' => 'baby-engel: donkergetinte huidskleur',
    '👼🏿' => 'baby-engel: donkere huidskleur',
    '🎅🏻' => 'kerstman: lichte huidskleur',
    '🎅🏼' => 'kerstman: lichtgetinte huidskleur',
    '🎅🏽' => 'kerstman: getinte huidskleur',
    '🎅🏾' => 'kerstman: donkergetinte huidskleur',
    '🎅🏿' => 'kerstman: donkere huidskleur',
    '🤶🏻' => 'kerstvrouw: lichte huidskleur',
    '🤶🏼' => 'kerstvrouw: lichtgetinte huidskleur',
    '🤶🏽' => 'kerstvrouw: getinte huidskleur',
    '🤶🏾' => 'kerstvrouw: donkergetinte huidskleur',
    '🤶🏿' => 'kerstvrouw: donkere huidskleur',
    '🦸🏻' => 'superheld: lichte huidskleur',
    '🦸🏼' => 'superheld: lichtgetinte huidskleur',
    '🦸🏽' => 'superheld: getinte huidskleur',
    '🦸🏾' => 'superheld: donkergetinte huidskleur',
    '🦸🏿' => 'superheld: donkere huidskleur',
    '🦹🏻' => 'superschurk: lichte huidskleur',
    '🦹🏼' => 'superschurk: lichtgetinte huidskleur',
    '🦹🏽' => 'superschurk: getinte huidskleur',
    '🦹🏾' => 'superschurk: donkergetinte huidskleur',
    '🦹🏿' => 'superschurk: donkere huidskleur',
    '🧙🏻' => 'magiër: lichte huidskleur',
    '🧙🏼' => 'magiër: lichtgetinte huidskleur',
    '🧙🏽' => 'magiër: getinte huidskleur',
    '🧙🏾' => 'magiër: donkergetinte huidskleur',
    '🧙🏿' => 'magiër: donkere huidskleur',
    '🧚🏻' => 'elfje: lichte huidskleur',
    '🧚🏼' => 'elfje: lichtgetinte huidskleur',
    '🧚🏽' => 'elfje: getinte huidskleur',
    '🧚🏾' => 'elfje: donkergetinte huidskleur',
    '🧚🏿' => 'elfje: donkere huidskleur',
    '🧛🏻' => 'vampier: lichte huidskleur',
    '🧛🏼' => 'vampier: lichtgetinte huidskleur',
    '🧛🏽' => 'vampier: getinte huidskleur',
    '🧛🏾' => 'vampier: donkergetinte huidskleur',
    '🧛🏿' => 'vampier: donkere huidskleur',
    '🧜🏻' => 'zeemeermin: lichte huidskleur',
    '🧜🏼' => 'zeemeermin: lichtgetinte huidskleur',
    '🧜🏽' => 'zeemeermin: getinte huidskleur',
    '🧜🏾' => 'zeemeermin: donkergetinte huidskleur',
    '🧜🏿' => 'zeemeermin: donkere huidskleur',
    '🧝🏻' => 'elf: lichte huidskleur',
    '🧝🏼' => 'elf: lichtgetinte huidskleur',
    '🧝🏽' => 'elf: getinte huidskleur',
    '🧝🏾' => 'elf: donkergetinte huidskleur',
    '🧝🏿' => 'elf: donkere huidskleur',
    '💆🏻' => 'persoon die hoofdmassage krijgt: lichte huidskleur',
    '💆🏼' => 'persoon die hoofdmassage krijgt: lichtgetinte huidskleur',
    '💆🏽' => 'persoon die hoofdmassage krijgt: getinte huidskleur',
    '💆🏾' => 'persoon die hoofdmassage krijgt: donkergetinte huidskleur',
    '💆🏿' => 'persoon die hoofdmassage krijgt: donkere huidskleur',
    '💇🏻' => 'persoon die wordt geknipt: lichte huidskleur',
    '💇🏼' => 'persoon die wordt geknipt: lichtgetinte huidskleur',
    '💇🏽' => 'persoon die wordt geknipt: getinte huidskleur',
    '💇🏾' => 'persoon die wordt geknipt: donkergetinte huidskleur',
    '💇🏿' => 'persoon die wordt geknipt: donkere huidskleur',
    '🚶🏻' => 'voetganger: lichte huidskleur',
    '🚶🏼' => 'voetganger: lichtgetinte huidskleur',
    '🚶🏽' => 'voetganger: getinte huidskleur',
    '🚶🏾' => 'voetganger: donkergetinte huidskleur',
    '🚶🏿' => 'voetganger: donkere huidskleur',
    '🧍🏻' => 'staande persoon: lichte huidskleur',
    '🧍🏼' => 'staande persoon: lichtgetinte huidskleur',
    '🧍🏽' => 'staande persoon: getinte huidskleur',
    '🧍🏾' => 'staande persoon: donkergetinte huidskleur',
    '🧍🏿' => 'staande persoon: donkere huidskleur',
    '🧎🏻' => 'knielende persoon: lichte huidskleur',
    '🧎🏼' => 'knielende persoon: lichtgetinte huidskleur',
    '🧎🏽' => 'knielende persoon: getinte huidskleur',
    '🧎🏾' => 'knielende persoon: donkergetinte huidskleur',
    '🧎🏿' => 'knielende persoon: donkere huidskleur',
    '🏃🏻' => 'hardloper: lichte huidskleur',
    '🏃🏼' => 'hardloper: lichtgetinte huidskleur',
    '🏃🏽' => 'hardloper: getinte huidskleur',
    '🏃🏾' => 'hardloper: donkergetinte huidskleur',
    '🏃🏿' => 'hardloper: donkere huidskleur',
    '💃🏻' => 'dansende vrouw: lichte huidskleur',
    '💃🏼' => 'dansende vrouw: lichtgetinte huidskleur',
    '💃🏽' => 'dansende vrouw: getinte huidskleur',
    '💃🏾' => 'dansende vrouw: donkergetinte huidskleur',
    '💃🏿' => 'dansende vrouw: donkere huidskleur',
    '🕺🏻' => 'dansende man: lichte huidskleur',
    '🕺🏼' => 'dansende man: lichtgetinte huidskleur',
    '🕺🏽' => 'dansende man: getinte huidskleur',
    '🕺🏾' => 'dansende man: donkergetinte huidskleur',
    '🕺🏿' => 'dansende man: donkere huidskleur',
    '🕴🏻' => 'zwevende man in pak: lichte huidskleur',
    '🕴🏼' => 'zwevende man in pak: lichtgetinte huidskleur',
    '🕴🏽' => 'zwevende man in pak: getinte huidskleur',
    '🕴🏾' => 'zwevende man in pak: donkergetinte huidskleur',
    '🕴🏿' => 'zwevende man in pak: donkere huidskleur',
    '👯🏻' => 'mensen met konijnenoren: lichte huidskleur',
    '👯🏼' => 'mensen met konijnenoren: lichtgetinte huidskleur',
    '👯🏽' => 'mensen met konijnenoren: getinte huidskleur',
    '👯🏾' => 'mensen met konijnenoren: donkergetinte huidskleur',
    '👯🏿' => 'mensen met konijnenoren: donkere huidskleur',
    '🧖🏻' => 'persoon in ruimte vol stoom: lichte huidskleur',
    '🧖🏼' => 'persoon in ruimte vol stoom: lichtgetinte huidskleur',
    '🧖🏽' => 'persoon in ruimte vol stoom: getinte huidskleur',
    '🧖🏾' => 'persoon in ruimte vol stoom: donkergetinte huidskleur',
    '🧖🏿' => 'persoon in ruimte vol stoom: donkere huidskleur',
    '🧗🏻' => 'klimmende persoon: lichte huidskleur',
    '🧗🏼' => 'klimmende persoon: lichtgetinte huidskleur',
    '🧗🏽' => 'klimmende persoon: getinte huidskleur',
    '🧗🏾' => 'klimmende persoon: donkergetinte huidskleur',
    '🧗🏿' => 'klimmende persoon: donkere huidskleur',
    '🏇🏻' => 'jockey op renpaard: lichte huidskleur',
    '🏇🏼' => 'jockey op renpaard: lichtgetinte huidskleur',
    '🏇🏽' => 'jockey op renpaard: getinte huidskleur',
    '🏇🏾' => 'jockey op renpaard: donkergetinte huidskleur',
    '🏇🏿' => 'jockey op renpaard: donkere huidskleur',
    '🏂🏻' => 'snowboarder: lichte huidskleur',
    '🏂🏼' => 'snowboarder: lichtgetinte huidskleur',
    '🏂🏽' => 'snowboarder: getinte huidskleur',
    '🏂🏾' => 'snowboarder: donkergetinte huidskleur',
    '🏂🏿' => 'snowboarder: donkere huidskleur',
    '🏌🏻' => 'golfer: lichte huidskleur',
    '🏌🏼' => 'golfer: lichtgetinte huidskleur',
    '🏌🏽' => 'golfer: getinte huidskleur',
    '🏌🏾' => 'golfer: donkergetinte huidskleur',
    '🏌🏿' => 'golfer: donkere huidskleur',
    '🏄🏻' => 'surfer: lichte huidskleur',
    '🏄🏼' => 'surfer: lichtgetinte huidskleur',
    '🏄🏽' => 'surfer: getinte huidskleur',
    '🏄🏾' => 'surfer: donkergetinte huidskleur',
    '🏄🏿' => 'surfer: donkere huidskleur',
    '🚣🏻' => 'persoon in roeiboot: lichte huidskleur',
    '🚣🏼' => 'persoon in roeiboot: lichtgetinte huidskleur',
    '🚣🏽' => 'persoon in roeiboot: getinte huidskleur',
    '🚣🏾' => 'persoon in roeiboot: donkergetinte huidskleur',
    '🚣🏿' => 'persoon in roeiboot: donkere huidskleur',
    '🏊🏻' => 'zwemmende persoon: lichte huidskleur',
    '🏊🏼' => 'zwemmende persoon: lichtgetinte huidskleur',
    '🏊🏽' => 'zwemmende persoon: getinte huidskleur',
    '🏊🏾' => 'zwemmende persoon: donkergetinte huidskleur',
    '🏊🏿' => 'zwemmende persoon: donkere huidskleur',
    '⛹🏻' => 'basketbalspeler: lichte huidskleur',
    '⛹🏼' => 'basketbalspeler: lichtgetinte huidskleur',
    '⛹🏽' => 'basketbalspeler: getinte huidskleur',
    '⛹🏾' => 'basketbalspeler: donkergetinte huidskleur',
    '⛹🏿' => 'basketbalspeler: donkere huidskleur',
    '🏋🏻' => 'gewichtheffer: lichte huidskleur',
    '🏋🏼' => 'gewichtheffer: lichtgetinte huidskleur',
    '🏋🏽' => 'gewichtheffer: getinte huidskleur',
    '🏋🏾' => 'gewichtheffer: donkergetinte huidskleur',
    '🏋🏿' => 'gewichtheffer: donkere huidskleur',
    '🚴🏻' => 'fietsende persoon: lichte huidskleur',
    '🚴🏼' => 'fietsende persoon: lichtgetinte huidskleur',
    '🚴🏽' => 'fietsende persoon: getinte huidskleur',
    '🚴🏾' => 'fietsende persoon: donkergetinte huidskleur',
    '🚴🏿' => 'fietsende persoon: donkere huidskleur',
    '🚵🏻' => 'persoon op mountainbike: lichte huidskleur',
    '🚵🏼' => 'persoon op mountainbike: lichtgetinte huidskleur',
    '🚵🏽' => 'persoon op mountainbike: getinte huidskleur',
    '🚵🏾' => 'persoon op mountainbike: donkergetinte huidskleur',
    '🚵🏿' => 'persoon op mountainbike: donkere huidskleur',
    '🤸🏻' => 'persoon die een radslag doet: lichte huidskleur',
    '🤸🏼' => 'persoon die een radslag doet: lichtgetinte huidskleur',
    '🤸🏽' => 'persoon die een radslag doet: getinte huidskleur',
    '🤸🏾' => 'persoon die een radslag doet: donkergetinte huidskleur',
    '🤸🏿' => 'persoon die een radslag doet: donkere huidskleur',
    '🤼🏻' => 'personen die worstelen: lichte huidskleur',
    '🤼🏼' => 'personen die worstelen: lichtgetinte huidskleur',
    '🤼🏽' => 'personen die worstelen: getinte huidskleur',
    '🤼🏾' => 'personen die worstelen: donkergetinte huidskleur',
    '🤼🏿' => 'personen die worstelen: donkere huidskleur',
    '🤽🏻' => 'persoon die waterpolo speelt: lichte huidskleur',
    '🤽🏼' => 'persoon die waterpolo speelt: lichtgetinte huidskleur',
    '🤽🏽' => 'persoon die waterpolo speelt: getinte huidskleur',
    '🤽🏾' => 'persoon die waterpolo speelt: donkergetinte huidskleur',
    '🤽🏿' => 'persoon die waterpolo speelt: donkere huidskleur',
    '🤾🏻' => 'persoon die handbal speelt: lichte huidskleur',
    '🤾🏼' => 'persoon die handbal speelt: lichtgetinte huidskleur',
    '🤾🏽' => 'persoon die handbal speelt: getinte huidskleur',
    '🤾🏾' => 'persoon die handbal speelt: donkergetinte huidskleur',
    '🤾🏿' => 'persoon die handbal speelt: donkere huidskleur',
    '🤹🏻' => 'persoon die jongleert: lichte huidskleur',
    '🤹🏼' => 'persoon die jongleert: lichtgetinte huidskleur',
    '🤹🏽' => 'persoon die jongleert: getinte huidskleur',
    '🤹🏾' => 'persoon die jongleert: donkergetinte huidskleur',
    '🤹🏿' => 'persoon die jongleert: donkere huidskleur',
    '🧘🏻' => 'persoon in lotushouding: lichte huidskleur',
    '🧘🏼' => 'persoon in lotushouding: lichtgetinte huidskleur',
    '🧘🏽' => 'persoon in lotushouding: getinte huidskleur',
    '🧘🏾' => 'persoon in lotushouding: donkergetinte huidskleur',
    '🧘🏿' => 'persoon in lotushouding: donkere huidskleur',
    '🛀🏻' => 'persoon in badkuip: lichte huidskleur',
    '🛀🏼' => 'persoon in badkuip: lichtgetinte huidskleur',
    '🛀🏽' => 'persoon in badkuip: getinte huidskleur',
    '🛀🏾' => 'persoon in badkuip: donkergetinte huidskleur',
    '🛀🏿' => 'persoon in badkuip: donkere huidskleur',
    '🛌🏻' => 'persoon in bed: lichte huidskleur',
    '🛌🏼' => 'persoon in bed: lichtgetinte huidskleur',
    '🛌🏽' => 'persoon in bed: getinte huidskleur',
    '🛌🏾' => 'persoon in bed: donkergetinte huidskleur',
    '🛌🏿' => 'persoon in bed: donkere huidskleur',
    '👭🏻' => 'vrouwen hand in hand: lichte huidskleur',
    '👭🏼' => 'vrouwen hand in hand: lichtgetinte huidskleur',
    '👭🏽' => 'vrouwen hand in hand: getinte huidskleur',
    '👭🏾' => 'vrouwen hand in hand: donkergetinte huidskleur',
    '👭🏿' => 'vrouwen hand in hand: donkere huidskleur',
    '👫🏻' => 'man en vrouw hand in hand: lichte huidskleur',
    '👫🏼' => 'man en vrouw hand in hand: lichtgetinte huidskleur',
    '👫🏽' => 'man en vrouw hand in hand: getinte huidskleur',
    '👫🏾' => 'man en vrouw hand in hand: donkergetinte huidskleur',
    '👫🏿' => 'man en vrouw hand in hand: donkere huidskleur',
    '👬🏻' => 'mannen hand in hand: lichte huidskleur',
    '👬🏼' => 'mannen hand in hand: lichtgetinte huidskleur',
    '👬🏽' => 'mannen hand in hand: getinte huidskleur',
    '👬🏾' => 'mannen hand in hand: donkergetinte huidskleur',
    '👬🏿' => 'mannen hand in hand: donkere huidskleur',
    '💏🏻' => 'kus: lichte huidskleur',
    '💏🏼' => 'kus: lichtgetinte huidskleur',
    '💏🏽' => 'kus: getinte huidskleur',
    '💏🏾' => 'kus: donkergetinte huidskleur',
    '💏🏿' => 'kus: donkere huidskleur',
    '💑🏻' => 'stel met hart: lichte huidskleur',
    '💑🏼' => 'stel met hart: lichtgetinte huidskleur',
    '💑🏽' => 'stel met hart: getinte huidskleur',
    '💑🏾' => 'stel met hart: donkergetinte huidskleur',
    '💑🏿' => 'stel met hart: donkere huidskleur',
    '🇦🇨' => 'vlag: Ascension',
    '🇦🇩' => 'vlag: Andorra',
    '🇦🇪' => 'vlag: Verenigde Arabische Emiraten',
    '🇦🇫' => 'vlag: Afghanistan',
    '🇦🇬' => 'vlag: Antigua en Barbuda',
    '🇦🇮' => 'vlag: Anguilla',
    '🇦🇱' => 'vlag: Albanië',
    '🇦🇲' => 'vlag: Armenië',
    '🇦🇴' => 'vlag: Angola',
    '🇦🇶' => 'vlag: Antarctica',
    '🇦🇷' => 'vlag: Argentinië',
    '🇦🇸' => 'vlag: Amerikaans-Samoa',
    '🇦🇹' => 'vlag: Oostenrijk',
    '🇦🇺' => 'vlag: Australië',
    '🇦🇼' => 'vlag: Aruba',
    '🇦🇽' => 'vlag: Åland',
    '🇦🇿' => 'vlag: Azerbeidzjan',
    '🇧🇦' => 'vlag: Bosnië en Herzegovina',
    '🇧🇧' => 'vlag: Barbados',
    '🇧🇩' => 'vlag: Bangladesh',
    '🇧🇪' => 'vlag: België',
    '🇧🇫' => 'vlag: Burkina Faso',
    '🇧🇬' => 'vlag: Bulgarije',
    '🇧🇭' => 'vlag: Bahrein',
    '🇧🇮' => 'vlag: Burundi',
    '🇧🇯' => 'vlag: Benin',
    '🇧🇱' => 'vlag: Saint-Barthélemy',
    '🇧🇲' => 'vlag: Bermuda',
    '🇧🇳' => 'vlag: Brunei',
    '🇧🇴' => 'vlag: Bolivia',
    '🇧🇶' => 'vlag: Caribisch Nederland',
    '🇧🇷' => 'vlag: Brazilië',
    '🇧🇸' => 'vlag: Bahama’s',
    '🇧🇹' => 'vlag: Bhutan',
    '🇧🇻' => 'vlag: Bouveteiland',
    '🇧🇼' => 'vlag: Botswana',
    '🇧🇾' => 'vlag: Belarus',
    '🇧🇿' => 'vlag: Belize',
    '🇨🇦' => 'vlag: Canada',
    '🇨🇨' => 'vlag: Cocoseilanden',
    '🇨🇩' => 'vlag: Congo-Kinshasa',
    '🇨🇫' => 'vlag: Centraal-Afrikaanse Republiek',
    '🇨🇬' => 'vlag: Congo-Brazzaville',
    '🇨🇭' => 'vlag: Zwitserland',
    '🇨🇮' => 'vlag: Ivoorkust',
    '🇨🇰' => 'vlag: Cookeilanden',
    '🇨🇱' => 'vlag: Chili',
    '🇨🇲' => 'vlag: Kameroen',
    '🇨🇳' => 'vlag: China',
    '🇨🇴' => 'vlag: Colombia',
    '🇨🇵' => 'vlag: Clipperton',
    '🇨🇶' => 'vlag: Sark',
    '🇨🇷' => 'vlag: Costa Rica',
    '🇨🇺' => 'vlag: Cuba',
    '🇨🇻' => 'vlag: Kaapverdië',
    '🇨🇼' => 'vlag: Curaçao',
    '🇨🇽' => 'vlag: Christmaseiland',
    '🇨🇾' => 'vlag: Cyprus',
    '🇨🇿' => 'vlag: Tsjechië',
    '🇩🇪' => 'vlag: Duitsland',
    '🇩🇬' => 'vlag: Diego Garcia',
    '🇩🇯' => 'vlag: Djibouti',
    '🇩🇰' => 'vlag: Denemarken',
    '🇩🇲' => 'vlag: Dominica',
    '🇩🇴' => 'vlag: Dominicaanse Republiek',
    '🇩🇿' => 'vlag: Algerije',
    '🇪🇦' => 'vlag: Ceuta en Melilla',
    '🇪🇨' => 'vlag: Ecuador',
    '🇪🇪' => 'vlag: Estland',
    '🇪🇬' => 'vlag: Egypte',
    '🇪🇭' => 'vlag: Westelijke Sahara',
    '🇪🇷' => 'vlag: Eritrea',
    '🇪🇸' => 'vlag: Spanje',
    '🇪🇹' => 'vlag: Ethiopië',
    '🇪🇺' => 'vlag: Europese Unie',
    '🇫🇮' => 'vlag: Finland',
    '🇫🇯' => 'vlag: Fiji',
    '🇫🇰' => 'vlag: Falklandeilanden',
    '🇫🇲' => 'vlag: Micronesia',
    '🇫🇴' => 'vlag: Faeröer',
    '🇫🇷' => 'vlag: Frankrijk',
    '🇬🇦' => 'vlag: Gabon',
    '🇬🇧' => 'vlag: Verenigd Koninkrijk',
    '🇬🇩' => 'vlag: Grenada',
    '🇬🇪' => 'vlag: Georgië',
    '🇬🇫' => 'vlag: Frans-Guyana',
    '🇬🇬' => 'vlag: Guernsey',
    '🇬🇭' => 'vlag: Ghana',
    '🇬🇮' => 'vlag: Gibraltar',
    '🇬🇱' => 'vlag: Groenland',
    '🇬🇲' => 'vlag: Gambia',
    '🇬🇳' => 'vlag: Guinee',
    '🇬🇵' => 'vlag: Guadeloupe',
    '🇬🇶' => 'vlag: Equatoriaal-Guinea',
    '🇬🇷' => 'vlag: Griekenland',
    '🇬🇸' => 'vlag: Zuid-Georgia en Zuidelijke Sandwicheilanden',
    '🇬🇹' => 'vlag: Guatemala',
    '🇬🇺' => 'vlag: Guam',
    '🇬🇼' => 'vlag: Guinee-Bissau',
    '🇬🇾' => 'vlag: Guyana',
    '🇭🇰' => 'vlag: Hongkong SAR van China',
    '🇭🇲' => 'vlag: Heard en McDonaldeilanden',
    '🇭🇳' => 'vlag: Honduras',
    '🇭🇷' => 'vlag: Kroatië',
    '🇭🇹' => 'vlag: Haïti',
    '🇭🇺' => 'vlag: Hongarije',
    '🇮🇨' => 'vlag: Canarische Eilanden',
    '🇮🇩' => 'vlag: Indonesië',
    '🇮🇪' => 'vlag: Ierland',
    '🇮🇱' => 'vlag: Israël',
    '🇮🇲' => 'vlag: Isle of Man',
    '🇮🇳' => 'vlag: India',
    '🇮🇴' => 'vlag: Brits Indische Oceaanterritorium',
    '🇮🇶' => 'vlag: Irak',
    '🇮🇷' => 'vlag: Iran',
    '🇮🇸' => 'vlag: IJsland',
    '🇮🇹' => 'vlag: Italië',
    '🇯🇪' => 'vlag: Jersey',
    '🇯🇲' => 'vlag: Jamaica',
    '🇯🇴' => 'vlag: Jordanië',
    '🇯🇵' => 'vlag: Japan',
    '🇰🇪' => 'vlag: Kenia',
    '🇰🇬' => 'vlag: Kirgizië',
    '🇰🇭' => 'vlag: Cambodja',
    '🇰🇮' => 'vlag: Kiribati',
    '🇰🇲' => 'vlag: Comoren',
    '🇰🇳' => 'vlag: Saint Kitts en Nevis',
    '🇰🇵' => 'vlag: Noord-Korea',
    '🇰🇷' => 'vlag: Zuid-Korea',
    '🇰🇼' => 'vlag: Koeweit',
    '🇰🇾' => 'vlag: Kaaimaneilanden',
    '🇰🇿' => 'vlag: Kazachstan',
    '🇱🇦' => 'vlag: Laos',
    '🇱🇧' => 'vlag: Libanon',
    '🇱🇨' => 'vlag: Saint Lucia',
    '🇱🇮' => 'vlag: Liechtenstein',
    '🇱🇰' => 'vlag: Sri Lanka',
    '🇱🇷' => 'vlag: Liberia',
    '🇱🇸' => 'vlag: Lesotho',
    '🇱🇹' => 'vlag: Litouwen',
    '🇱🇺' => 'vlag: Luxemburg',
    '🇱🇻' => 'vlag: Letland',
    '🇱🇾' => 'vlag: Libië',
    '🇲🇦' => 'vlag: Marokko',
    '🇲🇨' => 'vlag: Monaco',
    '🇲🇩' => 'vlag: Moldavië',
    '🇲🇪' => 'vlag: Montenegro',
    '🇲🇫' => 'vlag: Saint-Martin',
    '🇲🇬' => 'vlag: Madagaskar',
    '🇲🇭' => 'vlag: Marshalleilanden',
    '🇲🇰' => 'vlag: Noord-Macedonië',
    '🇲🇱' => 'vlag: Mali',
    '🇲🇲' => 'vlag: Myanmar (Birma)',
    '🇲🇳' => 'vlag: Mongolië',
    '🇲🇴' => 'vlag: Macau SAR van China',
    '🇲🇵' => 'vlag: Noordelijke Marianen',
    '🇲🇶' => 'vlag: Martinique',
    '🇲🇷' => 'vlag: Mauritanië',
    '🇲🇸' => 'vlag: Montserrat',
    '🇲🇹' => 'vlag: Malta',
    '🇲🇺' => 'vlag: Mauritius',
    '🇲🇻' => 'vlag: Maldiven',
    '🇲🇼' => 'vlag: Malawi',
    '🇲🇽' => 'vlag: Mexico',
    '🇲🇾' => 'vlag: Maleisië',
    '🇲🇿' => 'vlag: Mozambique',
    '🇳🇦' => 'vlag: Namibië',
    '🇳🇨' => 'vlag: Nieuw-Caledonië',
    '🇳🇪' => 'vlag: Niger',
    '🇳🇫' => 'vlag: Norfolk',
    '🇳🇬' => 'vlag: Nigeria',
    '🇳🇮' => 'vlag: Nicaragua',
    '🇳🇱' => 'vlag: Nederland',
    '🇳🇴' => 'vlag: Noorwegen',
    '🇳🇵' => 'vlag: Nepal',
    '🇳🇷' => 'vlag: Nauru',
    '🇳🇺' => 'vlag: Niue',
    '🇳🇿' => 'vlag: Nieuw-Zeeland',
    '🇴🇲' => 'vlag: Oman',
    '🇵🇦' => 'vlag: Panama',
    '🇵🇪' => 'vlag: Peru',
    '🇵🇫' => 'vlag: Frans-Polynesië',
    '🇵🇬' => 'vlag: Papoea-Nieuw-Guinea',
    '🇵🇭' => 'vlag: Filipijnen',
    '🇵🇰' => 'vlag: Pakistan',
    '🇵🇱' => 'vlag: Polen',
    '🇵🇲' => 'vlag: Saint-Pierre en Miquelon',
    '🇵🇳' => 'vlag: Pitcairneilanden',
    '🇵🇷' => 'vlag: Puerto Rico',
    '🇵🇸' => 'vlag: Palestijnse gebieden',
    '🇵🇹' => 'vlag: Portugal',
    '🇵🇼' => 'vlag: Palau',
    '🇵🇾' => 'vlag: Paraguay',
    '🇶🇦' => 'vlag: Qatar',
    '🇷🇪' => 'vlag: Réunion',
    '🇷🇴' => 'vlag: Roemenië',
    '🇷🇸' => 'vlag: Servië',
    '🇷🇺' => 'vlag: Rusland',
    '🇷🇼' => 'vlag: Rwanda',
    '🇸🇦' => 'vlag: Saoedi-Arabië',
    '🇸🇧' => 'vlag: Salomonseilanden',
    '🇸🇨' => 'vlag: Seychellen',
    '🇸🇩' => 'vlag: Soedan',
    '🇸🇪' => 'vlag: Zweden',
    '🇸🇬' => 'vlag: Singapore',
    '🇸🇭' => 'vlag: Sint-Helena',
    '🇸🇮' => 'vlag: Slovenië',
    '🇸🇯' => 'vlag: Spitsbergen en Jan Mayen',
    '🇸🇰' => 'vlag: Slowakije',
    '🇸🇱' => 'vlag: Sierra Leone',
    '🇸🇲' => 'vlag: San Marino',
    '🇸🇳' => 'vlag: Senegal',
    '🇸🇴' => 'vlag: Somalië',
    '🇸🇷' => 'vlag: Suriname',
    '🇸🇸' => 'vlag: Zuid-Soedan',
    '🇸🇹' => 'vlag: Sao Tomé en Principe',
    '🇸🇻' => 'vlag: El Salvador',
    '🇸🇽' => 'vlag: Sint-Maarten',
    '🇸🇾' => 'vlag: Syrië',
    '🇸🇿' => 'vlag: Eswatini',
    '🇹🇦' => 'vlag: Tristan da Cunha',
    '🇹🇨' => 'vlag: Turks- en Caicoseilanden',
    '🇹🇩' => 'vlag: Tsjaad',
    '🇹🇫' => 'vlag: Franse Gebieden in de zuidelijke Indische Oceaan',
    '🇹🇬' => 'vlag: Togo',
    '🇹🇭' => 'vlag: Thailand',
    '🇹🇯' => 'vlag: Tadzjikistan',
    '🇹🇰' => 'vlag: Tokelau',
    '🇹🇱' => 'vlag: Oost-Timor',
    '🇹🇲' => 'vlag: Turkmenistan',
    '🇹🇳' => 'vlag: Tunesië',
    '🇹🇴' => 'vlag: Tonga',
    '🇹🇷' => 'vlag: Turkije',
    '🇹🇹' => 'vlag: Trinidad en Tobago',
    '🇹🇻' => 'vlag: Tuvalu',
    '🇹🇼' => 'vlag: Taiwan',
    '🇹🇿' => 'vlag: Tanzania',
    '🇺🇦' => 'vlag: Oekraïne',
    '🇺🇬' => 'vlag: Oeganda',
    '🇺🇲' => 'vlag: Kleine afgelegen eilanden van de Verenigde Staten',
    '🇺🇳' => 'vlag: Verenigde Naties',
    '🇺🇸' => 'vlag: Verenigde Staten',
    '🇺🇾' => 'vlag: Uruguay',
    '🇺🇿' => 'vlag: Oezbekistan',
    '🇻🇦' => 'vlag: Vaticaanstad',
    '🇻🇨' => 'vlag: Saint Vincent en de Grenadines',
    '🇻🇪' => 'vlag: Venezuela',
    '🇻🇬' => 'vlag: Britse Maagdeneilanden',
    '🇻🇮' => 'vlag: Amerikaanse Maagdeneilanden',
    '🇻🇳' => 'vlag: Vietnam',
    '🇻🇺' => 'vlag: Vanuatu',
    '🇼🇫' => 'vlag: Wallis en Futuna',
    '🇼🇸' => 'vlag: Samoa',
    '🇽🇰' => 'vlag: Kosovo',
    '🇾🇪' => 'vlag: Jemen',
    '🇾🇹' => 'vlag: Mayotte',
    '🇿🇦' => 'vlag: Zuid-Afrika',
    '🇿🇲' => 'vlag: Zambia',
    '🇿🇼' => 'vlag: Zimbabwe',
    '🔟' => 'toets: 10',
    '🏻' => 'lichte huidskleur',
    '🏼' => 'lichtgetinte huidskleur',
    '🏽' => 'getinte huidskleur',
    '🏾' => 'donkergetinte huidskleur',
    '🏿' => 'donkere huidskleur',
    '😀' => 'grijnzend gezicht',
    '😃' => 'grijnzend gezicht met grote ogen',
    '😄' => 'grijnzend gezicht met lachende ogen',
    '😁' => 'stralend gezicht met lachende ogen',
    '😆' => 'grijnzend gezicht met stijf dichtgeknepen ogen',
    '😅' => 'grijnzend gezicht met zweetdruppels',
    '🤣' => 'gezicht dat op de grond rolt van het lachen',
    '😂' => 'gezicht met tranen van vreugde',
    '🙂' => 'enigszins lachend gezicht',
    '🙃' => 'omgekeerd gezicht',
    '🫠' => 'smeltend gezicht',
    '😉' => 'knipogend gezicht',
    '😊' => 'lachend gezicht met lachende ogen',
    '😇' => 'lachend gezicht met halo',
    '🥰' => 'lachend gezicht met hartjes',
    '😍' => 'lachend gezicht met hartvormige ogen',
    '🤩' => 'sterren in de ogen',
    '😘' => 'gezicht dat kus toeblaast',
    '😗' => 'kussend gezicht',
    '☺' => 'lachend gezicht',
    '😚' => 'kussend gezicht met gesloten ogen',
    '😙' => 'kussend gezicht met lachende ogen',
    '🥲' => 'lachend gezicht met traan',
    '😋' => 'lachend gezicht dat lippen likt',
    '😛' => 'gezicht met uitgestoken tong',
    '😜' => 'knipoog met uitgestoken tong',
    '🤪' => 'gek gezicht',
    '😝' => 'gezicht met uitgestoken tong en dichtgeknepen ogen',
    '🤑' => 'gezicht met geld in de mond',
    '🤗' => 'blij gezicht met uitgestoken handen',
    '🤭' => 'gezicht met hand over de mond',
    '🫢' => 'gezicht met open ogen en hand voor mond',
    '🫣' => 'gezicht met glurend oog',
    '🤫' => 'gezicht dat tot stilte maant',
    '🤔' => 'nadenkend gezicht',
    '🫡' => 'saluerend gezicht',
    '🤐' => 'gezicht met een rits als mond',
    '🤨' => 'gezicht met opgeheven wenkbrauw',
    '😐' => 'neutraal gezicht',
    '😑' => 'uitdrukkingsloos gezicht',
    '😶' => 'gezicht zonder mond',
    '🫥' => 'gezicht in stippellijn',
    '😏' => 'gniffelend gezicht',
    '😒' => 'chagrijnig gezicht',
    '🙄' => 'gezicht met rollende ogen',
    '😬' => 'gezicht met grimas',
    '🤥' => 'liegend gezicht',
    '🫨' => 'schuddend gezicht',
    '😌' => 'opgelucht gezicht',
    '😔' => 'peinzend gezicht',
    '😪' => 'slaperig gezicht',
    '🤤' => 'kwijlend gezicht',
    '😴' => 'slapend gezicht',
    '🫩' => 'gezicht met wallen onder de ogen',
    '😷' => 'gezicht met doktersmasker',
    '🤒' => 'gezicht met thermometer',
    '🤕' => 'gezicht met een verband om het hoofd',
    '🤢' => 'misselijk gezicht',
    '🤮' => 'brakend gezicht',
    '🤧' => 'niezend gezicht',
    '🥵' => 'heet gezicht',
    '🥶' => 'koud gezicht',
    '🥴' => 'wazig gezicht',
    '😵' => 'duizelig gezicht',
    '🤯' => 'ontploffend hoofd',
    '🤠' => 'gezicht met cowboyhoed',
    '🥳' => 'feestend gezicht',
    '🥸' => 'vermomd gezicht',
    '😎' => 'lachend gezicht met zonnebril',
    '🤓' => 'nerdgezicht',
    '🧐' => 'gezicht met monocle',
    '😕' => 'verward gezicht',
    '🫤' => 'gezicht met schuine mond',
    '😟' => 'bezorgd gezicht',
    '🙁' => 'licht fronsend gezicht',
    '☹' => 'fronsend gezicht',
    '😮' => 'gezicht met open mond',
    '😯' => 'verstomd gezicht',
    '😲' => 'verbaasd gezicht',
    '😳' => 'blozend gezicht',
    '🫪' => 'verwrongen gezicht',
    '🥺' => 'smekend gezicht',
    '🥹' => 'gezicht dat tranen tegenhoudt',
    '😦' => 'fronsend gezicht met open mond',
    '😧' => 'gekweld gezicht',
    '😨' => 'bang gezicht',
    '😰' => 'angstig gezicht met zweetdruppel',
    '😥' => 'teleurgesteld maar opgelucht gezicht',
    '😢' => 'huilend gezicht',
    '😭' => 'hard huilend gezicht',
    '😱' => 'angstig schreeuwend gezicht',
    '😖' => 'onthutst gezicht',
    '😣' => 'volhardend gezicht',
    '😞' => 'teleurgesteld gezicht',
    '😓' => 'neerslachtig gezicht met zweetdruppel',
    '😩' => 'moe gezicht',
    '😫' => 'vermoeid gezicht',
    '🥱' => 'gapend gezicht',
    '😤' => 'gezicht blazend van woede',
    '😡' => 'pruilend gezicht',
    '😠' => 'boos gezicht',
    '🤬' => 'gezicht met symbolen op mond',
    '😈' => 'lachend gezicht met hoorns',
    '👿' => 'boos gezicht met hoorns',
    '💀' => 'schedel',
    '☠' => 'doodshoofd met gekruiste beenderen',
    '💩' => 'drol',
    '🤡' => 'clownsgezicht',
    '👹' => 'boeman',
    '👺' => 'kobold',
    '👻' => 'spook',
    '👽' => 'buitenaards wezen',
    '👾' => 'buitenaards monster',
    '🤖' => 'robot',
    '😺' => 'grijnzende kat',
    '😸' => 'grijnzende kat met lachende ogen',
    '😹' => 'kat met tranen van vreugde',
    '😻' => 'lachende kat met hartvormige ogen',
    '😼' => 'gniffelende kat',
    '😽' => 'kussende kat',
    '🙀' => 'vermoeide kat',
    '😿' => 'huilende kat',
    '😾' => 'pruilende kat',
    '🙈' => 'geen kwaad zien',
    '🙉' => 'geen kwaad horen',
    '🙊' => 'geen kwaad spreken',
    '💌' => 'liefdesbrief',
    '💘' => 'hart met pijl',
    '💝' => 'hart met strik',
    '💖' => 'fonkelend hart',
    '💗' => 'groeiend hart',
    '💓' => 'kloppend hart',
    '💞' => 'ronddraaiende harten',
    '💕' => 'twee harten',
    '💟' => 'decoratief hart',
    '❣' => 'hart als uitroepteken',
    '💔' => 'gebroken hart',
    '❤' => 'rood hart',
    '🩷' => 'roze hart',
    '🧡' => 'oranje hart',
    '💛' => 'geel hart',
    '💚' => 'groen hart',
    '💙' => 'blauw hart',
    '🩵' => 'lichtblauw hart',
    '💜' => 'paars hart',
    '🤎' => 'bruin hart',
    '🖤' => 'zwart hart',
    '🩶' => 'grijs hart',
    '🤍' => 'wit hart',
    '💋' => 'lipafdruk',
    '💯' => 'maximumscore',
    '💢' => 'woedesymbool',
    '🫯' => 'vechtwolk',
    '💥' => 'botsing',
    '💫' => 'duizelig',
    '💦' => 'zweetdruppels',
    '💨' => 'wegrennen',
    '🕳' => 'gat',
    '💬' => 'spraakballon',
    '🗨' => 'spraakballon naar links',
    '🗯' => 'boze spraakballon naar rechts',
    '💭' => 'gedachteballon',
    '💤' => 'slaapsymbool',
    '👋' => 'zwaaiende hand',
    '🤚' => 'achterkant van opgeheven hand',
    '🖐' => 'opgeheven hand met uitgestoken vingers',
    '✋' => 'opgeheven hand',
    '🖖' => 'Vulcaanse groet',
    '🫱' => 'hand naar rechts',
    '🫲' => 'hand naar links',
    '🫳' => 'handpalm omlaag',
    '🫴' => 'handpalm omhoog',
    '🫷' => 'hand die naar links duwt',
    '🫸' => 'hand die naar rechts duwt',
    '👌' => 'OK-handgebaar',
    '🤌' => 'samengeknepen vingers',
    '🤏' => 'hand met samengeknepen vingers',
    '✌' => 'winnende hand',
    '🤞' => 'gekruiste vingers',
    '🫰' => 'hand met wijsvinger en duim gekruist',
    '🤟' => 'ik-hou-van-je-gebaar',
    '🤘' => 'duivelshorens',
    '🤙' => 'bel me-gebaar',
    '👈' => 'achterkant van hand met naar links wijzende wijsvinger',
    '👉' => 'achterkant van hand met naar rechts wijzende wijsvinger',
    '👆' => 'achterkant van hand met omhoog wijzende wijsvinger',
    '🖕' => 'middelvinger',
    '👇' => 'achterkant van hand met omlaag wijzende wijsvinger',
    '☝' => 'omhoog wijzende wijsvinger',
    '🫵' => 'wijsvinger die naar de kijker wijst',
    '👍' => 'duim omhoog',
    '👎' => 'duim omlaag',
    '✊' => 'opgeheven vuist',
    '👊' => 'stotende vuist',
    '🤛' => 'naar links gerichte vuist',
    '🤜' => 'naar rechts gerichte vuist',
    '👏' => 'klappende handen',
    '🙌' => 'juichend omhooggestoken handen',
    '🫶' => 'handen in de vorm van een hart',
    '👐' => 'open handen',
    '🤲' => 'beide handpalmen omhoog',
    '🤝' => 'handdruk',
    '🙏' => 'gevouwen handen',
    '✍' => 'schrijvende hand',
    '💅' => 'nagellak',
    '🤳' => 'selfie',
    '💪' => 'spierballen',
    '🦾' => 'armprothese',
    '🦿' => 'beenprothese',
    '🦵' => 'been',
    '🦶' => 'voet',
    '👂' => 'oor',
    '🦻' => 'oor met gehoorapparaat',
    '👃' => 'neus',
    '🧠' => 'brein',
    '🫀' => 'hart',
    '🫁' => 'longen',
    '🦷' => 'tand',
    '🦴' => 'bot',
    '👀' => 'ogen',
    '👁' => 'oog',
    '👅' => 'tong',
    '👄' => 'mond',
    '🫦' => 'mond die op lip bijt',
    '👶' => 'baby',
    '🧒' => 'kind',
    '👦' => 'jongen',
    '👧' => 'meisje',
    '🧑' => 'volwassene',
    '👱' => 'persoon met blond haar',
    '👨' => 'man',
    '🧔' => 'persoon: baard',
    '👩' => 'vrouw',
    '🧓' => 'oudere persoon',
    '👴' => 'oude man',
    '👵' => 'oude vrouw',
    '🙍' => 'fronsend persoon',
    '🙎' => 'pruilend persoon',
    '🙅' => 'persoon die nee-gebaar maakt',
    '🙆' => 'persoon die OK-gebaar maakt',
    '💁' => 'persoon achter informatiebalie',
    '🙋' => 'persoon met opgeheven hand',
    '🧏' => 'doof persoon',
    '🙇' => 'buigende persoon',
    '🤦' => 'persoon die het gezicht met de hand bedekt',
    '🤷' => 'persoon die schouders ophaalt',
    '👮' => 'politieagent',
    '🕵' => 'detective',
    '💂' => 'wachter',
    '🥷' => 'ninja',
    '👷' => 'bouwvakker',
    '🫅' => 'persoon met kroon',
    '🤴' => 'prins',
    '👸' => 'prinses',
    '👳' => 'persoon met tulband',
    '👲' => 'man met Chinees petje',
    '🧕' => 'vrouw met hoofddoek',
    '🤵' => 'persoon in smoking',
    '👰' => 'persoon met sluier',
    '🤰' => 'zwangere vrouw',
    '🫃' => 'zwangere man',
    '🫄' => 'zwanger persoon',
    '🤱' => 'borstvoeding',
    '👼' => 'baby-engel',
    '🎅' => 'kerstman',
    '🤶' => 'kerstvrouw',
    '🦸' => 'superheld',
    '🦹' => 'superschurk',
    '🧙' => 'magiër',
    '🧚' => 'elfje',
    '🧛' => 'vampier',
    '🧜' => 'zeemeermin',
    '🧝' => 'elf',
    '🧞' => 'geest in de fles',
    '🧟' => 'zombie',
    '🧌' => 'trol',
    '🫈' => 'harig wezen',
    '💆' => 'persoon die hoofdmassage krijgt',
    '💇' => 'persoon die wordt geknipt',
    '🚶' => 'voetganger',
    '🧍' => 'staande persoon',
    '🧎' => 'knielende persoon',
    '🏃' => 'hardloper',
    '💃' => 'dansende vrouw',
    '🕺' => 'dansende man',
    '🕴' => 'zwevende man in pak',
    '👯' => 'mensen met konijnenoren',
    '🧖' => 'persoon in ruimte vol stoom',
    '🧗' => 'klimmende persoon',
    '🤺' => 'schermer',
    '🏇' => 'jockey op renpaard',
    '⛷' => 'skiër',
    '🏂' => 'snowboarder',
    '🏌' => 'golfer',
    '🏄' => 'surfer',
    '🚣' => 'persoon in roeiboot',
    '🏊' => 'zwemmende persoon',
    '⛹' => 'basketbalspeler',
    '🏋' => 'gewichtheffer',
    '🚴' => 'fietsende persoon',
    '🚵' => 'persoon op mountainbike',
    '🤸' => 'persoon die een radslag doet',
    '🤼' => 'personen die worstelen',
    '🤽' => 'persoon die waterpolo speelt',
    '🤾' => 'persoon die handbal speelt',
    '🤹' => 'persoon die jongleert',
    '🧘' => 'persoon in lotushouding',
    '🛀' => 'persoon in badkuip',
    '🛌' => 'persoon in bed',
    '👭' => 'vrouwen hand in hand',
    '👫' => 'man en vrouw hand in hand',
    '👬' => 'mannen hand in hand',
    '💏' => 'kus',
    '💑' => 'stel met hart',
    '🗣' => 'silhouet van sprekend hoofd',
    '👤' => 'silhouet van persoon',
    '👥' => 'silhouet van twee personen',
    '🫂' => 'personen in een omhelzing',
    '👪' => 'gezin',
    '👣' => 'voetafdrukken',
    '🫆' => 'vingerafdruk',
    '🦰' => 'rood haar',
    '🦱' => 'krullend haar',
    '🦳' => 'wit haar',
    '🦲' => 'kaal',
    '🐵' => 'apengezicht',
    '🐒' => 'aap',
    '🦍' => 'gorilla',
    '🦧' => 'orang-oetang',
    '🐶' => 'hondengezicht',
    '🐕' => 'hond',
    '🦮' => 'blindengeleidehond',
    '🐩' => 'poedel',
    '🐺' => 'wolf',
    '🦊' => 'vos',
    '🦝' => 'wasbeer',
    '🐱' => 'kattengezicht',
    '🐈' => 'kat',
    '🦁' => 'leeuw',
    '🐯' => 'tijgergezicht',
    '🐅' => 'tijger',
    '🐆' => 'luipaard',
    '🐴' => 'paardengezicht',
    '🫎' => 'eland',
    '🫏' => 'ezel',
    '🐎' => 'paard',
    '🦄' => 'eenhoorn',
    '🦓' => 'zebra',
    '🦌' => 'hert',
    '🦬' => 'bizon',
    '🐮' => 'koeiengezicht',
    '🐂' => 'os',
    '🐃' => 'waterbuffel',
    '🐄' => 'koe',
    '🐷' => 'varkensgezicht',
    '🐖' => 'varken',
    '🐗' => 'zwijn',
    '🐽' => 'varkensneus',
    '🐏' => 'ram',
    '🐑' => 'ooi',
    '🐐' => 'geit',
    '🐪' => 'dromedaris',
    '🐫' => 'kameel',
    '🦙' => 'lama',
    '🦒' => 'giraffe',
    '🐘' => 'olifant',
    '🦣' => 'mammoet',
    '🦏' => 'neushoorn',
    '🦛' => 'nijlpaard',
    '🐭' => 'muizengezicht',
    '🐁' => 'muis',
    '🐀' => 'rat',
    '🐹' => 'hamster',
    '🐰' => 'konijnengezicht',
    '🐇' => 'konijn',
    '🐿' => 'eekhoorn',
    '🦫' => 'bever',
    '🦔' => 'egel',
    '🦇' => 'vleermuis',
    '🐻' => 'beer',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'luiaard',
    '🦦' => 'otter',
    '🦨' => 'stinkdier',
    '🦘' => 'kangoeroe',
    '🦡' => 'das',
    '🐾' => 'pootafdrukken',
    '🦃' => 'kalkoen',
    '🐔' => 'kip',
    '🐓' => 'haan',
    '🐣' => 'kuiken uit ei',
    '🐤' => 'kuikentje',
    '🐥' => 'naar voren kijkend kuikentje',
    '🐦' => 'vogel',
    '🐧' => 'pinguïn',
    '🕊' => 'duif',
    '🦅' => 'adelaar',
    '🦆' => 'eend',
    '🦢' => 'zwaan',
    '🦉' => 'uil',
    '🦤' => 'dodo',
    '🪶' => 'veer',
    '🦩' => 'flamingo',
    '🦚' => 'pauw',
    '🦜' => 'papegaai',
    '🪽' => 'vleugel',
    '🪿' => 'gans',
    '🐸' => 'kikker',
    '🐊' => 'krokodil',
    '🐢' => 'schildpad',
    '🦎' => 'hagedis',
    '🐍' => 'slang',
    '🐲' => 'drakengezicht',
    '🐉' => 'draak',
    '🦕' => 'sauropode',
    '🦖' => 'T-Rex',
    '🐳' => 'spuitende walvis',
    '🐋' => 'walvis',
    '🐬' => 'dolfijn',
    '🫍' => 'orka',
    '🦭' => 'zeehond',
    '🐟' => 'vis',
    '🐠' => 'tropische vis',
    '🐡' => 'kogelvis',
    '🦈' => 'haai',
    '🐙' => 'octopus',
    '🐚' => 'schelp',
    '🪸' => 'koraal',
    '🪼' => 'kwal',
    '🦀' => 'krab',
    '🦞' => 'kreeft',
    '🦐' => 'garnaal',
    '🦑' => 'inktvis',
    '🦪' => 'oester',
    '🐌' => 'slak',
    '🦋' => 'vlinder',
    '🐛' => 'insect',
    '🐜' => 'mier',
    '🐝' => 'honingbij',
    '🪲' => 'kever',
    '🐞' => 'lieveheersbeestje',
    '🦗' => 'krekel',
    '🪳' => 'kakkerlak',
    '🕷' => 'spin',
    '🕸' => 'spinnenweb',
    '🦂' => 'schorpioen',
    '🦟' => 'mug',
    '🪰' => 'vlieg',
    '🪱' => 'worm',
    '🦠' => 'microbe',
    '💐' => 'boeket',
    '🌸' => 'kersenbloesem',
    '💮' => 'witte bloem',
    '🪷' => 'lotus',
    '🏵' => 'rozet',
    '🌹' => 'roos',
    '🥀' => 'verwelkte bloem',
    '🌺' => 'hibiscus',
    '🌻' => 'zonnebloem',
    '🌼' => 'bloesem',
    '🌷' => 'tulp',
    '🪻' => 'hyacint',
    '🌱' => 'zaailing',
    '🪴' => 'potplant',
    '🌲' => 'naaldboom',
    '🌳' => 'loofboom',
    '🌴' => 'palmboom',
    '🌵' => 'cactus',
    '🌾' => 'rijstplant',
    '🌿' => 'kruid',
    '☘' => 'klavertjedrie',
    '🍀' => 'klavertjevier',
    '🍁' => 'esdoornblad',
    '🍂' => 'vallende bladeren',
    '🍃' => 'blad in de wind',
    '🪹' => 'leeg nest',
    '🪺' => 'nest met eieren',
    '🍄' => 'paddenstoel',
    '🪾' => 'boom zonder bladeren',
    '🍇' => 'druiven',
    '🍈' => 'meloen',
    '🍉' => 'watermeloen',
    '🍊' => 'mandarijn',
    '🍋' => 'citroen',
    '🍌' => 'banaan',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'rode appel',
    '🍏' => 'groene appel',
    '🍐' => 'peer',
    '🍑' => 'perzik',
    '🍒' => 'kersen',
    '🍓' => 'aardbei',
    '🫐' => 'bosbessen',
    '🥝' => 'kiwi',
    '🍅' => 'tomaat',
    '🫒' => 'olijf',
    '🥥' => 'kokosnoot',
    '🥑' => 'avocado',
    '🍆' => 'aubergine',
    '🥔' => 'aardappel',
    '🥕' => 'wortel',
    '🌽' => 'maïskolf',
    '🌶' => 'hete peper',
    '🫑' => 'paprika',
    '🥒' => 'komkommer',
    '🥬' => 'bladgroente',
    '🥦' => 'broccoli',
    '🧄' => 'knoflook',
    '🧅' => 'ui',
    '🥜' => 'pinda’s',
    '🫘' => 'bonen',
    '🌰' => 'kastanje',
    '🫚' => 'gemberwortel',
    '🫛' => 'erwtendop',
    '🫜' => 'knol',
    '🍞' => 'brood',
    '🥐' => 'croissant',
    '🥖' => 'stokbrood',
    '🫓' => 'platbrood',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'pannenkoeken',
    '🧇' => 'wafel',
    '🧀' => 'stuk kaas',
    '🍖' => 'vlees met bot',
    '🍗' => 'kippenpoot',
    '🥩' => 'vlees',
    '🥓' => 'bacon',
    '🍔' => 'hamburger',
    '🍟' => 'patat',
    '🍕' => 'pizzapunt',
    '🌭' => 'hotdog',
    '🥪' => 'boterham',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'gevuld pitabroodje',
    '🧆' => 'falafel',
    '🥚' => 'ei',
    '🍳' => 'koken',
    '🥘' => 'paellapan',
    '🍲' => 'stoofschotel',
    '🫕' => 'fondue',
    '🥣' => 'kom met lepel',
    '🥗' => 'groene salade',
    '🍿' => 'popcorn',
    '🧈' => 'boter',
    '🧂' => 'zout',
    '🥫' => 'blikvoedsel',
    '🍱' => 'bentobox',
    '🍘' => 'rijstwafel',
    '🍙' => 'rijstballetje',
    '🍚' => 'gekookte rijst',
    '🍛' => 'curry en rijst',
    '🍜' => 'dampende kom',
    '🍝' => 'spaghetti',
    '🍠' => 'gepofte zoete aardappel',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'gefrituurde garnaal',
    '🍥' => 'viskoekje met krul',
    '🥮' => 'maancake',
    '🍡' => 'dango',
    '🥟' => 'knoedel',
    '🥠' => 'gelukskoekje',
    '🥡' => 'afhaalmaaltijd',
    '🍦' => 'softijs',
    '🍧' => 'geschaafd ijs',
    '🍨' => 'ijs',
    '🍩' => 'donut',
    '🍪' => 'koekje',
    '🎂' => 'verjaardagstaart',
    '🍰' => 'cake',
    '🧁' => 'cupcake',
    '🥧' => 'taart',
    '🍫' => 'chocoladereep',
    '🍬' => 'snoep',
    '🍭' => 'lolly',
    '🍮' => 'vla',
    '🍯' => 'honingpot',
    '🍼' => 'babyflesje',
    '🥛' => 'glas melk',
    '☕' => 'warme drank',
    '🫖' => 'theepot',
    '🍵' => 'theekopje zonder oor',
    '🍶' => 'sake',
    '🍾' => 'fles met knallende kurk',
    '🍷' => 'wijnglas',
    '🍸' => 'cocktailglas',
    '🍹' => 'tropisch drankje',
    '🍺' => 'bierglas',
    '🍻' => 'klinkende bierglazen',
    '🥂' => 'klinkende glazen',
    '🥃' => 'tumblerglas',
    '🫗' => 'vloeistof uitgieten',
    '🥤' => 'beker met rietje',
    '🧋' => 'bubbelthee',
    '🧃' => 'pakje drinken',
    '🧉' => 'maté',
    '🧊' => 'ijsklontje',
    '🥢' => 'chopsticks',
    '🍽' => 'mes en vork met bord',
    '🍴' => 'mes en vork',
    '🥄' => 'lepel',
    '🔪' => 'keukenmes',
    '🫙' => 'pot',
    '🏺' => 'amfora',
    '🌍' => 'wereldbol met Europa-Afrika',
    '🌎' => 'wereldbol met Noord- en Zuid-Amerika',
    '🌏' => 'wereldbol met Azië-Australië',
    '🌐' => 'wereldbol met meridianen',
    '🗺' => 'wereldkaart',
    '🗾' => 'kaart van Japan',
    '🧭' => 'kompas',
    '🏔' => 'berg met besneeuwde toppen',
    '⛰' => 'berg',
    '🛘' => 'aardverschuiving',
    '🌋' => 'vulkaan',
    '🗻' => 'berg Fuji',
    '🏕' => 'kamperen',
    '🏖' => 'strand met parasol',
    '🏜' => 'woestijn',
    '🏝' => 'onbewoond eiland',
    '🏞' => 'nationaal park',
    '🏟' => 'stadion',
    '🏛' => 'klassiek gebouw',
    '🏗' => 'woningbouw',
    '🧱' => 'baksteen',
    '🪨' => 'rots',
    '🪵' => 'hout',
    '🛖' => 'hut',
    '🏘' => 'huizen',
    '🏚' => 'vervallen huis',
    '🏠' => 'huis',
    '🏡' => 'huis met tuin',
    '🏢' => 'kantoorgebouw',
    '🏣' => 'Japans postkantoor',
    '🏤' => 'postkantoor',
    '🏥' => 'ziekenhuis',
    '🏦' => 'bank',
    '🏨' => 'hotel',
    '🏩' => 'love-hotel',
    '🏪' => 'supermarkt',
    '🏫' => 'school',
    '🏬' => 'warenhuis',
    '🏭' => 'fabriek',
    '🏯' => 'Japans kasteel',
    '🏰' => 'kasteel',
    '💒' => 'bruiloft',
    '🗼' => 'Tokio-toren',
    '🗽' => 'vrijheidsbeeld',
    '⛪' => 'kerk',
    '🕌' => 'moskee',
    '🛕' => 'hindoetempel',
    '🕍' => 'synagoge',
    '⛩' => 'shinto-tempel',
    '🕋' => 'kaäba',
    '⛲' => 'fontein',
    '⛺' => 'tent',
    '🌁' => 'mistig',
    '🌃' => 'sterrenhemel',
    '🏙' => 'stadsgezicht',
    '🌄' => 'zonsopgang in de bergen',
    '🌅' => 'zonsopgang',
    '🌆' => 'stad bij schemering',
    '🌇' => 'zonsondergang',
    '🌉' => 'brug bij nacht',
    '♨' => 'warmwaterbronnen',
    '🎠' => 'draaimolenpaard',
    '🛝' => 'glijbaan',
    '🎡' => 'reuzenrad',
    '🎢' => 'achtbaan',
    '💈' => 'kapperspaal',
    '🎪' => 'circustent',
    '🚂' => 'locomotief',
    '🚃' => 'treinwagon',
    '🚄' => 'hogesnelheidstrein',
    '🚅' => 'hogesnelheidstrein met kogelneus',
    '🚆' => 'trein',
    '🚇' => 'metro',
    '🚈' => 'lightrail',
    '🚉' => 'treinstation',
    '🚊' => 'tram',
    '🚝' => 'monorail',
    '🚞' => 'bergspoor',
    '🚋' => 'tramwagon',
    '🚌' => 'bus',
    '🚍' => 'naderende bus',
    '🚎' => 'trolleybus',
    '🚐' => 'minibus',
    '🚑' => 'ambulance',
    '🚒' => 'brandweerauto',
    '🚓' => 'politieauto',
    '🚔' => 'naderende politieauto',
    '🚕' => 'taxi',
    '🚖' => 'naderende taxi',
    '🚗' => 'auto',
    '🚘' => 'naderende auto',
    '🚙' => 'SUV',
    '🛻' => 'pick-up',
    '🚚' => 'bestelbus',
    '🚛' => 'vrachtwagen',
    '🚜' => 'tractor',
    '🏎' => 'raceauto',
    '🏍' => 'motor',
    '🛵' => 'scooter',
    '🦽' => 'rolstoel',
    '🦼' => 'elektrische rolstoel',
    '🛺' => 'riksja',
    '🚲' => 'fiets',
    '🛴' => 'step',
    '🛹' => 'skateboard',
    '🛼' => 'rolschaats',
    '🚏' => 'bushalte',
    '🛣' => 'snelweg',
    '🛤' => 'treinspoor',
    '🛢' => 'olievat',
    '⛽' => 'benzinestation',
    '🛞' => 'wiel',
    '🚨' => 'zwaailicht van politieauto',
    '🚥' => 'horizontaal verkeerslicht',
    '🚦' => 'verticaal verkeerslicht',
    '🛑' => 'stopteken',
    '🚧' => 'bouwwerkzaamheden',
    '⚓' => 'anker',
    '🛟' => 'reddingsboei',
    '⛵' => 'zeilboot',
    '🛶' => 'kano',
    '🚤' => 'speedboot',
    '🛳' => 'passagiersschip',
    '⛴' => 'veerboot',
    '🛥' => 'motorboot',
    '🚢' => 'schip',
    '✈' => 'vliegtuig',
    '🛩' => 'vliegtuigje',
    '🛫' => 'vertrek van vliegtuig',
    '🛬' => 'aankomst van vliegtuig',
    '🪂' => 'parachute',
    '💺' => 'stoel',
    '🚁' => 'helikopter',
    '🚟' => 'zweeftrein',
    '🚠' => 'bergkabelbaan',
    '🚡' => 'kabelbaan',
    '🛰' => 'satelliet',
    '🚀' => 'raket',
    '🛸' => 'vliegende schotel',
    '🛎' => 'piccolobel',
    '🧳' => 'bagage',
    '⌛' => 'zandloper',
    '⏳' => 'zandloper met stromend zand',
    '⌚' => 'horloge',
    '⏰' => 'wekker',
    '⏱' => 'stopwatch',
    '⏲' => 'keukenwekker',
    '🕰' => 'klok',
    '🕛' => 'twaalf uur',
    '🕧' => 'half één',
    '🕐' => 'één uur',
    '🕜' => 'half twee',
    '🕑' => 'twee uur',
    '🕝' => 'half drie',
    '🕒' => 'drie uur',
    '🕞' => 'half vier',
    '🕓' => 'vier uur',
    '🕟' => 'half vijf',
    '🕔' => 'vijf uur',
    '🕠' => 'half zes',
    '🕕' => 'zes uur',
    '🕡' => 'half zeven',
    '🕖' => 'zeven uur',
    '🕢' => 'half acht',
    '🕗' => 'acht uur',
    '🕣' => 'half negen',
    '🕘' => 'negen uur',
    '🕤' => 'half tien',
    '🕙' => 'tien uur',
    '🕥' => 'half elf',
    '🕚' => 'elf uur',
    '🕦' => 'half twaalf',
    '🌑' => 'nieuwe maan',
    '🌒' => 'jonge maansikkel',
    '🌓' => 'maan in eerste kwartier',
    '🌔' => 'wassende maan',
    '🌕' => 'volle maan',
    '🌖' => 'afnemende maan',
    '🌗' => 'maan in laatste kwartier',
    '🌘' => 'asgrauwe maan',
    '🌙' => 'maansikkel',
    '🌚' => 'nieuwe maan met gezicht',
    '🌛' => 'maan met gezicht in eerste kwartier',
    '🌜' => 'maan met gezicht in laatste kwartier',
    '🌡' => 'thermometer',
    '☀' => 'zon',
    '🌝' => 'volle maan met gezicht',
    '🌞' => 'zon met gezicht',
    '🪐' => 'planeet met ringen',
    '⭐' => 'witte middelgrote ster',
    '🌟' => 'stralende ster',
    '🌠' => 'vallende ster',
    '🌌' => 'melkweg',
    '☁' => 'wolk',
    '⛅' => 'zon achter wolk',
    '⛈' => 'wolk met bliksem en regen',
    '🌤' => 'zon achter kleine wolk',
    '🌥' => 'zon achter grote wolk',
    '🌦' => 'zon achter regenwolk',
    '🌧' => 'wolk met regen',
    '🌨' => 'wolk met sneeuw',
    '🌩' => 'wolk met bliksem',
    '🌪' => 'tornado',
    '🌫' => 'mist',
    '🌬' => 'gezicht dat wind blaast',
    '🌀' => 'cycloon',
    '🌈' => 'regenboog',
    '🌂' => 'ingevouwen paraplu',
    '☂' => 'paraplu',
    '☔' => 'paraplu met regendruppels',
    '⛱' => 'strandparasol',
    '⚡' => 'hoog voltage',
    '❄' => 'sneeuwvlok',
    '☃' => 'sneeuwpop',
    '⛄' => 'sneeuwpop zonder sneeuwvlokken',
    '☄' => 'komeet',
    '🔥' => 'vuur',
    '💧' => 'druppel',
    '🌊' => 'golf',
    '🎃' => 'halloweenlantaarn',
    '🎄' => 'kerstboom',
    '🎆' => 'vuurwerk',
    '🎇' => 'sterretje',
    '🧨' => 'rotje',
    '✨' => 'sterretjes',
    '🎈' => 'ballon',
    '🎉' => 'feestknaller',
    '🎊' => 'confettibal',
    '🎋' => 'tanabataboom',
    '🎍' => 'dennenboomversiering',
    '🎎' => 'Japanse poppen',
    '🎏' => 'karperslinger',
    '🎐' => 'windorgel',
    '🎑' => 'maanobservatieceremonie',
    '🧧' => 'rode envelop',
    '🎀' => 'strik',
    '🎁' => 'ingepakt cadeau',
    '🎗' => 'bewustzijnslintje',
    '🎟' => 'entreekaartjes',
    '🎫' => 'ticket',
    '🎖' => 'militaire medaille',
    '🏆' => 'trofee',
    '🏅' => 'sportmedaille',
    '🥇' => 'medaille 1e plaats',
    '🥈' => 'medaille 2e plaats',
    '🥉' => 'medaille 3e plaats',
    '⚽' => 'voetbal',
    '⚾' => 'honkbal',
    '🥎' => 'softbal',
    '🏀' => 'basketbal',
    '🏐' => 'volleybal',
    '🏈' => 'american football',
    '🏉' => 'rugby',
    '🎾' => 'tennis',
    '🥏' => 'frisbee',
    '🎳' => 'bowlen',
    '🏏' => 'cricket',
    '🏑' => 'hockey',
    '🏒' => 'ijshockeystick en puck',
    '🥍' => 'lacrosse',
    '🏓' => 'pingpong',
    '🏸' => 'badminton',
    '🥊' => 'bokshandschoen',
    '🥋' => 'pak voor vechtsporten',
    '🥅' => 'doelnet',
    '⛳' => 'vlag in hole',
    '⛸' => 'schaats',
    '🎣' => 'vishengel',
    '🤿' => 'duikbril',
    '🎽' => 'hardloopshirt',
    '🎿' => 'ski’s',
    '🛷' => 'slee',
    '🥌' => 'curlingsteen',
    '🎯' => 'directe treffer',
    '🪀' => 'jojo',
    '🪁' => 'vlieger',
    '🔫' => 'waterpistool',
    '🎱' => 'biljart',
    '🔮' => 'kristallen bol',
    '🪄' => 'toverstok',
    '🎮' => 'videogame',
    '🕹' => 'joystick',
    '🎰' => 'fruitautomaat',
    '🎲' => 'dobbelsteen',
    '🧩' => 'puzzelstukje',
    '🧸' => 'teddybeer',
    '🪅' => 'piñata',
    '🪩' => 'spiegelbal',
    '🪆' => 'matroesjka',
    '♠' => 'schoppen',
    '♥' => 'harten',
    '♦' => 'ruiten',
    '♣' => 'klaveren',
    '♟' => 'pion',
    '🃏' => 'Jokerkaart',
    '🀄' => 'mahjong rode draak',
    '🎴' => 'speelkaarten',
    '🎭' => 'toneelkunsten',
    '🖼' => 'lijst met afbeelding',
    '🎨' => 'schilderspalet',
    '🧵' => 'garen',
    '🪡' => 'naald',
    '🧶' => 'wol',
    '🪢' => 'knoop',
    '👓' => 'bril',
    '🕶' => 'zonnebril',
    '🥽' => 'oogscherm',
    '🥼' => 'labjas',
    '🦺' => 'veiligheidsvest',
    '👔' => 'stropdas',
    '👕' => 'T-shirt',
    '👖' => 'spijkerbroek',
    '🧣' => 'sjaal',
    '🧤' => 'handschoenen',
    '🧥' => 'jas',
    '🧦' => 'sokken',
    '👗' => 'jurk',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'badpak',
    '🩲' => 'slip',
    '🩳' => 'korte broek',
    '👙' => 'bikini',
    '👚' => 'dameskleding',
    '🪭' => 'opvouwbare waaier',
    '👛' => 'portemonnee',
    '👜' => 'handtas',
    '👝' => 'tasje',
    '🛍' => 'boodschappentassen',
    '🎒' => 'schooltas',
    '🩴' => 'teenslipper',
    '👞' => 'herenschoen',
    '👟' => 'sportschoen',
    '🥾' => 'wandelschoen',
    '🥿' => 'platte schoen',
    '👠' => 'schoen met hoge hak',
    '👡' => 'damessandaal',
    '🩰' => 'balletschoenen',
    '👢' => 'dameslaars',
    '🪮' => 'haarkam',
    '👑' => 'kroon',
    '👒' => 'dameshoed',
    '🎩' => 'hoge hoed',
    '🎓' => 'academische baret',
    '🧢' => 'pet',
    '🪖' => 'legerhelm',
    '⛑' => 'helm van reddingswerker',
    '📿' => 'gebedssnoer',
    '💄' => 'lippenstift',
    '💍' => 'ring',
    '💎' => 'edelsteen',
    '🔇' => 'speaker uit',
    '🔈' => 'speaker',
    '🔉' => 'speaker aan',
    '🔊' => 'speaker luid',
    '📢' => 'luidspreker',
    '📣' => 'megafoon',
    '📯' => 'posthoorn',
    '🔔' => 'bel',
    '🔕' => 'doorgestreepte bel',
    '🎼' => 'notenschift',
    '🎵' => 'muzieknoot',
    '🎶' => 'muzieknoten',
    '🎙' => 'studiomicrofoon',
    '🎚' => 'schuifregelaar',
    '🎛' => 'controleknoppen',
    '🎤' => 'microfoon',
    '🎧' => 'hoofdtelefoon',
    '📻' => 'radio',
    '🎷' => 'saxofoon',
    '🎺' => 'trompet',
    '🪊' => 'trombone',
    '🪗' => 'accordeon',
    '🎸' => 'gitaar',
    '🎹' => 'piano',
    '🎻' => 'viool',
    '🪕' => 'banjo',
    '🥁' => 'trommel',
    '🪘' => 'hoge trom',
    '🪇' => 'sambaballen',
    '🪈' => 'fluit',
    '🪉' => 'harp',
    '📱' => 'mobiele telefoon',
    '📲' => 'mobiel met pijl',
    '☎' => 'telefoon',
    '📞' => 'telefoonhoorn',
    '📟' => 'pager',
    '📠' => 'fax',
    '🔋' => 'batterij',
    '🪫' => 'batterij bijna leeg',
    '🔌' => 'stekker',
    '💻' => 'laptop',
    '🖥' => 'desktop',
    '🖨' => 'printer',
    '⌨' => 'toetsenbord',
    '🖱' => 'computermuis',
    '🖲' => 'trackball',
    '💽' => 'harddisk',
    '💾' => 'floppydisk',
    '💿' => 'optische schijf',
    '📀' => 'dvd',
    '🧮' => 'abacus',
    '🎥' => 'filmcamera',
    '🎞' => 'filmframes',
    '📽' => 'filmprojector',
    '🎬' => 'klapbord',
    '📺' => 'tv',
    '📷' => 'camera',
    '📸' => 'camera met flitser',
    '📹' => 'videocamera',
    '📼' => 'videoband',
    '🔍' => 'vergrootglas naar links gericht',
    '🔎' => 'vergrootglas naar rechts gericht',
    '🕯' => 'kaars',
    '💡' => 'gloeilamp',
    '🔦' => 'zaklamp',
    '🏮' => 'rode papieren lantaarn',
    '🪔' => 'diya-lamp',
    '📔' => 'versierd schrift',
    '📕' => 'gesloten boek',
    '📖' => 'geopend boek',
    '📗' => 'groen boek',
    '📘' => 'blauw boek',
    '📙' => 'oranje boek',
    '📚' => 'boeken',
    '📓' => 'schrift',
    '📒' => 'grootboek',
    '📃' => 'omkrullende pagina',
    '📜' => 'rol',
    '📄' => 'pagina met bovenzijde omhoog',
    '📰' => 'krant',
    '🗞' => 'opgerolde krant',
    '📑' => 'bladwijzertabs',
    '🔖' => 'bladwijzer',
    '🏷' => 'label',
    '🪙' => 'munt',
    '💰' => 'zak met geld',
    '🪎' => 'schatkist',
    '💴' => 'yenbiljet',
    '💵' => 'dollarbiljet',
    '💶' => 'eurobiljet',
    '💷' => 'pondbiljet',
    '💸' => 'vliegend geld',
    '💳' => 'creditcard',
    '🧾' => 'kassabon',
    '💹' => 'stijgende grafiek met yenteken',
    '✉' => 'envelop',
    '📧' => 'e-mail',
    '📨' => 'inkomende post',
    '📩' => 'envelop met pijl',
    '📤' => 'postvak uit',
    '📥' => 'postvak in',
    '📦' => 'pakket',
    '📫' => 'gesloten brievenbus met vlaggetje omhoog',
    '📪' => 'gesloten brievenbus met vlaggetje omlaag',
    '📬' => 'open brievenbus met vlaggetje omhoog',
    '📭' => 'open brievenbus met vlaggetje omlaag',
    '📮' => 'brievenbus',
    '🗳' => 'stembus met stembiljet',
    '✏' => 'potlood',
    '✒' => 'kroontjespen met zwarte punt',
    '🖋' => 'vulpen',
    '🖊' => 'pen',
    '🖌' => 'kwast',
    '🖍' => 'krijtje',
    '📝' => 'memo',
    '💼' => 'aktentas',
    '📁' => 'bestandsmap',
    '📂' => 'geopende map',
    '🗂' => 'tabbladen',
    '📅' => 'kalender',
    '📆' => 'scheurkalender',
    '🗒' => 'schrijfblok met spiraal',
    '🗓' => 'kalender met spiraal',
    '📇' => 'kaartindex',
    '📈' => 'stijgende trend',
    '📉' => 'dalende trend',
    '📊' => 'staafdiagram',
    '📋' => 'klembord',
    '📌' => 'punaise',
    '📍' => 'ronde speld',
    '📎' => 'paperclip',
    '🖇' => 'twee paperclips aan elkaar',
    '📏' => 'liniaal',
    '📐' => 'geodriehoek',
    '✂' => 'schaar',
    '🗃' => 'kaartenbak',
    '🗄' => 'archiefkast',
    '🗑' => 'prullenmand',
    '🔒' => 'slot',
    '🔓' => 'geopend hangslot',
    '🔏' => 'slot met pen',
    '🔐' => 'gesloten slot met sleutel',
    '🔑' => 'sleutel',
    '🗝' => 'oude sleutel',
    '🔨' => 'hamer',
    '🪓' => 'bijl',
    '⛏' => 'pikhouweel',
    '⚒' => 'twee hamers',
    '🛠' => 'hamer en moersleutel',
    '🗡' => 'dolk',
    '⚔' => 'gekruiste zwaarden',
    '💣' => 'bom',
    '🪃' => 'boemerang',
    '🏹' => 'pijl en boog',
    '🛡' => 'schild',
    '🪚' => 'houtzaag',
    '🔧' => 'moersleutel',
    '🪛' => 'schroevendraaier',
    '🔩' => 'bout en moer',
    '⚙' => 'tandwiel',
    '🗜' => 'lijmklem',
    '⚖' => 'weegschaal',
    '🦯' => 'taststok',
    '🔗' => 'schakels',
    '⛓' => 'kettingen',
    '🪝' => 'haak',
    '🧰' => 'gereedschapskist',
    '🧲' => 'magneet',
    '🪜' => 'ladder',
    '🪏' => 'schop',
    '⚗' => 'distilleerkolf',
    '🧪' => 'reageerbuis',
    '🧫' => 'petrischaal',
    '🧬' => 'DNA',
    '🔬' => 'microscoop',
    '🔭' => 'telescoop',
    '📡' => 'satellietschotel',
    '💉' => 'injectiespuit',
    '🩸' => 'bloeddruppel',
    '💊' => 'pil',
    '🩹' => 'pleister',
    '🩼' => 'kruk',
    '🩺' => 'stethoscoop',
    '🩻' => 'röntgenfoto',
    '🚪' => 'deur',
    '🛗' => 'lift',
    '🪞' => 'spiegel',
    '🪟' => 'raam',
    '🛏' => 'bed',
    '🛋' => 'bank en lamp',
    '🪑' => 'hoge stoel',
    '🚽' => 'toilet',
    '🪠' => 'ontstopper',
    '🚿' => 'douche',
    '🛁' => 'badkuip',
    '🪤' => 'muizenval',
    '🪒' => 'scheermes',
    '🧴' => 'lotionfles',
    '🧷' => 'veiligheidsspeld',
    '🧹' => 'bezem',
    '🧺' => 'mand',
    '🧻' => 'rol papier',
    '🪣' => 'emmer',
    '🧼' => 'zeep',
    '🫧' => 'zeepbellen',
    '🪥' => 'tandenborstel',
    '🧽' => 'spons',
    '🧯' => 'brandblusapparaat',
    '🛒' => 'winkelwagen',
    '🚬' => 'sigaret',
    '⚰' => 'doodskist',
    '🪦' => 'grafsteen',
    '⚱' => 'urn',
    '🧿' => 'Nazar-amulet',
    '🪬' => 'hamsa',
    '🗿' => 'moai-beeld',
    '🪧' => 'plakkaat',
    '🪪' => 'legitimatiebewijs',
    '🏧' => 'pinautomaat',
    '🚮' => 'prullenbaksymbool',
    '🚰' => 'drinkwater',
    '♿' => 'rolstoelsymbool',
    '🚹' => 'herentoilet',
    '🚺' => 'damestoilet',
    '🚻' => 'toiletten',
    '🚼' => 'babysymbool',
    '🚾' => 'wc',
    '🛂' => 'paspoortcontrole',
    '🛃' => 'douane',
    '🛄' => 'bagage afhalen',
    '🛅' => 'bagagekluis',
    '⚠' => 'waarschuwing',
    '🚸' => 'overstekende kinderen',
    '⛔' => 'geen toegang',
    '🚫' => 'verboden',
    '🚳' => 'geen fietsen',
    '🚭' => 'niet roken',
    '🚯' => 'geen afval weggooien',
    '🚱' => 'geen drinkwater',
    '🚷' => 'geen voetgangers',
    '📵' => 'geen mobiele telefoon',
    '🔞' => 'niemand onder de 18',
    '☢' => 'radioactief',
    '☣' => 'biologisch gevaar',
    '⬆' => 'pijl omhoog',
    '↗' => 'pijl rechtsomhoog',
    '➡' => 'pijl naar rechts',
    '↘' => 'pijl rechtsomlaag',
    '⬇' => 'pijl omlaag',
    '↙' => 'pijl linksomlaag',
    '⬅' => 'pijl naar links',
    '↖' => 'pijl linksomhoog',
    '↕' => 'pijl omhoog en omlaag',
    '↔' => 'pijl naar links en rechts',
    '↩' => 'pijl naar rechts die naar links draait',
    '↪' => 'pijl naar links die naar rechts draait',
    '⤴' => 'pijl naar rechts die omhoog draait',
    '⤵' => 'pijl naar rechts die omlaag draait',
    '🔃' => 'verticale pijlen met de klok mee',
    '🔄' => 'pijlen tegen de klok in',
    '🔙' => 'BACK-pijl',
    '🔚' => 'END-pijl',
    '🔛' => 'ON!-pijl',
    '🔜' => 'SOON-pijl',
    '🔝' => 'TOP-pijl',
    '🛐' => 'gebedsruimte',
    '⚛' => 'atoomsymbool',
    '🕉' => 'om-symbool',
    '✡' => 'davidster',
    '☸' => 'wiel van dharma',
    '☯' => 'yin en yang',
    '✝' => 'christelijk kruis',
    '☦' => 'russisch kruis',
    '☪' => 'wassende maan en ster',
    '☮' => 'vredessymbool',
    '🕎' => 'menora',
    '🔯' => 'zespuntige ster',
    '🪯' => 'khanda',
    '♈' => 'ram (sterrenbeeld)',
    '♉' => 'stier (sterrenbeeld)',
    '♊' => 'tweelingen (sterrenbeeld)',
    '♋' => 'kreeft (sterrenbeeld)',
    '♌' => 'leeuw (sterrenbeeld)',
    '♍' => 'maagd (sterrenbeeld)',
    '♎' => 'weegschaal (sterrenbeeld)',
    '♏' => 'schorpioen (sterrenbeeld)',
    '♐' => 'boogschutter (sterrenbeeld)',
    '♑' => 'steenbok (sterrenbeeld)',
    '♒' => 'waterman (sterrenbeeld)',
    '♓' => 'vissen (sterrenbeeld)',
    '⛎' => 'slangendrager (sterrenbeeld)',
    '🔀' => 'knop voor shuffle',
    '🔁' => 'knop voor herhalen',
    '🔂' => 'knop voor één herhalen',
    '▶' => 'knop voor afspelen',
    '⏩' => 'knop voor snel vooruitspoelen',
    '⏭' => 'knop voor volgende nummer',
    '⏯' => 'knop voor afspelen of pauzeren',
    '◀' => 'knop voor terugspoelen',
    '⏪' => 'knop voor versneld terugspoelen',
    '⏮' => 'knop voor vorige nummer',
    '🔼' => 'knop voor omhoog',
    '⏫' => 'knop voor versneld omhoog',
    '🔽' => 'knop voor omlaag',
    '⏬' => 'knop voor versneld omlaag',
    '⏸' => 'pauzeknop',
    '⏹' => 'knop voor stoppen',
    '⏺' => 'knop voor opnemen',
    '⏏' => 'knop voor uitwerpen',
    '🎦' => 'knop voor filmen',
    '🔅' => 'knop voor lagere helderheid',
    '🔆' => 'knop voor hogere helderheid',
    '📶' => 'mobiel signaal',
    '🛜' => 'draadloos',
    '📳' => 'trilstand',
    '📴' => 'telefoon uit',
    '♀' => 'vrouwelijkheidssymbool',
    '♂' => 'mannelijkheidssymbool',
    '⚧' => 'transgendersymbool',
    '✖' => 'vermenigvuldigen',
    '➕' => 'plus',
    '➖' => 'min',
    '➗' => 'delen',
    '🟰' => 'vetgedrukt gelijkteken',
    '♾' => 'oneindig',
    '‼' => 'dubbel uitroepteken',
    '⁉' => 'uitroepteken en vraagteken',
    '❓' => 'rood vraagteken',
    '❔' => 'wit vraagteken',
    '❕' => 'wit uitroepteken',
    '❗' => 'rood uitroepteken',
    '〰' => 'golvend streepje',
    '💱' => 'geld wisselen',
    '💲' => 'vetgedrukt dollarteken',
    '⚕' => 'esculaap',
    '♻' => 'recycling-symbool',
    '⚜' => 'fleur de lis',
    '🔱' => 'drietand-symbool',
    '📛' => 'naamkaartje',
    '🔰' => 'Japans symbool voor beginner',
    '⭕' => 'lege rode cirkel',
    '✅' => 'knop voor vinkje',
    '☑' => 'vinkje in vak',
    '✔' => 'vinkje',
    '❌' => 'kruisteken',
    '❎' => 'knop voor kruis',
    '➰' => 'gekrulde lus',
    '➿' => 'dubbele gekrulde lus',
    '〽' => 'rolwisselingsmarkering',
    '✳' => 'achtpuntige asterisk',
    '✴' => 'achtpuntige ster',
    '❇' => 'sprankeling',
    '™' => 'handelsmerksymbool',
    '🫟' => 'Gespat',
    '🔠' => 'hoofdletters',
    '🔡' => 'kleine letters',
    '🔢' => 'cijfers',
    '🔣' => 'symbolen',
    '🔤' => 'Latijns alfabet',
    '🅰' => 'bloedgroep A',
    '🆎' => 'bloedgroep AB',
    '🅱' => 'bloedgroep B',
    '🆑' => 'CL-knop',
    '🆒' => 'COOL-knop',
    '🆓' => 'FREE-knop',
    'ℹ' => 'informatie',
    '🆔' => 'ID-knop',
    'Ⓜ' => 'M in cirkel',
    '🆕' => 'NEW-knop',
    '🆖' => 'NG-knop',
    '🅾' => 'bloedgroep O',
    '🆗' => 'OK-knop',
    '🅿' => 'P-knop',
    '🆘' => 'SOS-knop',
    '🆙' => 'UP!-knop',
    '🆚' => 'VS-knop',
    '🈁' => 'Japans teken voor ‘hier’',
    '🈂' => 'Japans teken voor ‘dienstenheffing’',
    '🈷' => 'Japans teken voor ‘maandelijks bedrag’',
    '🈶' => 'Japans teken voor ‘niet gratis’',
    '🈯' => 'Japans teken voor ‘gereserveerd’',
    '🉐' => 'Japans teken voor ‘koopje’',
    '🈹' => 'Japans teken voor ‘korting’',
    '🈚' => 'Japans teken voor ‘gratis’',
    '🈲' => 'Japans teken voor ‘verboden’',
    '🉑' => 'Japans teken voor ‘acceptabel’',
    '🈸' => 'Japans teken voor ‘toepassing’',
    '🈴' => 'Japans teken voor ‘voldoende (cijfer)‘',
    '🈳' => 'Japans teken voor ‘plaats vrij’',
    '㊗' => 'Japans teken voor ‘gefeliciteerd’',
    '㊙' => 'Japans teken voor ‘geheim’',
    '🈺' => 'Japans teken voor ‘geopend’',
    '🈵' => 'Japans teken voor ‘vol, geen plaats’',
    '🔴' => 'rode cirkel',
    '🟠' => 'oranje cirkel',
    '🟡' => 'gele cirkel',
    '🟢' => 'groene cirkel',
    '🔵' => 'blauwe cirkel',
    '🟣' => 'paarse cirkel',
    '🟤' => 'bruine cirkel',
    '⚫' => 'zwarte cirkel',
    '⚪' => 'witte cirkel',
    '🟥' => 'rood vierkant',
    '🟧' => 'oranje vierkant',
    '🟨' => 'geel vierkant',
    '🟩' => 'groen vierkant',
    '🟦' => 'blauw vierkant',
    '🟪' => 'paars vierkant',
    '🟫' => 'bruin vierkant',
    '⬛' => 'groot zwart vierkant',
    '⬜' => 'groot wit vierkant',
    '◼' => 'middelgroot zwart vierkant',
    '◻' => 'middelgroot wit vierkant',
    '◾' => 'klein tot middelgroot zwart vierkant',
    '◽' => 'klein tot middelgroot wit vierkant',
    '▪' => 'klein zwart vierkant',
    '▫' => 'klein wit vierkant',
    '🔶' => 'grote oranje ruit',
    '🔷' => 'grote blauwe ruit',
    '🔸' => 'kleine oranje ruit',
    '🔹' => 'kleine blauwe ruit',
    '🔺' => 'rode omhoogwijzende driehoek',
    '🔻' => 'rode omlaagwijzende driehoek',
    '💠' => 'ruitvorm met stip erin',
    '🔘' => 'keuzerondje',
    '🔳' => 'witte vierkante knop',
    '🔲' => 'zwarte vierkante knop',
    '🏁' => 'geblokte vlag',
    '🚩' => 'driehoekige vlag',
    '🎌' => 'gekruiste vlaggen',
    '🏴' => 'zwarte vlag',
    '🏳' => 'witte vlag',
];
