<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'чупту: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏻‍❤‍💋‍👨🏻' => 'чупту: арҫын арҫын сӑран ҫутӑ тӗсӗ',
    '👨🏻‍❤‍💋‍👨🏼' => 'чупту: арҫын арҫын сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏻‍❤‍💋‍👨🏽' => 'чупту: арҫын арҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏻‍❤‍💋‍👨🏾' => 'чупту: арҫын арҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏻‍❤‍💋‍👨🏿' => 'чупту: арҫын арҫын сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏼‍❤‍💋‍👨🏻' => 'чупту: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👨🏼‍❤‍💋‍👨🏼' => 'чупту: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏼‍❤‍💋‍👨🏽' => 'чупту: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏼‍❤‍💋‍👨🏾' => 'чупту: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏼‍❤‍💋‍👨🏿' => 'чупту: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏽‍❤‍💋‍👨🏻' => 'чупту: арҫын арҫын сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏽‍❤‍💋‍👨🏼' => 'чупту: арҫын арҫын сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍❤‍💋‍👨🏽' => 'чупту: арҫын арҫын сӑран вӑтам тонӗ',
    '👨🏽‍❤‍💋‍👨🏾' => 'чупту: арҫын арҫын сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏽‍❤‍💋‍👨🏿' => 'чупту: арҫын арҫын сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👨🏾‍❤‍💋‍👨🏻' => 'чупту: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏾‍❤‍💋‍👨🏼' => 'чупту: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏾‍❤‍💋‍👨🏽' => 'чупту: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏾‍❤‍💋‍👨🏾' => 'чупту: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ',
    '👨🏾‍❤‍💋‍👨🏿' => 'чупту: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👨🏿‍❤‍💋‍👨🏻' => 'чупту: арҫын арҫын сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏿‍❤‍💋‍👨🏼' => 'чупту: арҫын арҫын сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏿‍❤‍💋‍👨🏽' => 'чупту: арҫын арҫын сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏿‍❤‍💋‍👨🏾' => 'чупту: арҫын арҫын сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍❤‍💋‍👨🏿' => 'чупту: арҫын арҫын сӑран тӗксӗм тонӗ',
    '👩🏻‍❤‍💋‍👨🏻' => 'чупту: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ',
    '👩🏻‍❤‍💋‍👨🏼' => 'чупту: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏻‍❤‍💋‍👨🏽' => 'чупту: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏻‍❤‍💋‍👨🏾' => 'чупту: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍❤‍💋‍👨🏿' => 'чупту: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏼‍❤‍💋‍👨🏻' => 'чупту: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👩🏼‍❤‍💋‍👨🏼' => 'чупту: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏼‍❤‍💋‍👨🏽' => 'чупту: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏼‍❤‍💋‍👨🏾' => 'чупту: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏼‍❤‍💋‍👨🏿' => 'чупту: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏽‍❤‍💋‍👨🏻' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏽‍❤‍💋‍👨🏼' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍❤‍💋‍👨🏽' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тонӗ',
    '👩🏽‍❤‍💋‍👨🏾' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏽‍❤‍💋‍👨🏿' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👩🏾‍❤‍💋‍👨🏻' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏾‍❤‍💋‍👨🏼' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏾‍❤‍💋‍👨🏽' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏾‍❤‍💋‍👨🏾' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ',
    '👩🏾‍❤‍💋‍👨🏿' => 'чупту: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👩🏿‍❤‍💋‍👨🏻' => 'чупту: хӗрарӑм арҫын сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏿‍❤‍💋‍👨🏼' => 'чупту: хӗрарӑм арҫын сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏿‍❤‍💋‍👨🏽' => 'чупту: хӗрарӑм арҫын сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏿‍❤‍💋‍👨🏾' => 'чупту: хӗрарӑм арҫын сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍❤‍💋‍👨🏿' => 'чупту: хӗрарӑм арҫын сӑран тӗксӗм тонӗ',
    '👩🏻‍❤‍💋‍👩🏻' => 'чупту: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ',
    '👩🏻‍❤‍💋‍👩🏼' => 'чупту: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏻‍❤‍💋‍👩🏽' => 'чупту: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏻‍❤‍💋‍👩🏾' => 'чупту: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍❤‍💋‍👩🏿' => 'чупту: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏼‍❤‍💋‍👩🏻' => 'чупту: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👩🏼‍❤‍💋‍👩🏼' => 'чупту: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏼‍❤‍💋‍👩🏽' => 'чупту: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏼‍❤‍💋‍👩🏾' => 'чупту: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏼‍❤‍💋‍👩🏿' => 'чупту: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏽‍❤‍💋‍👩🏻' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏽‍❤‍💋‍👩🏼' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍❤‍💋‍👩🏽' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ',
    '👩🏽‍❤‍💋‍👩🏾' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏽‍❤‍💋‍👩🏿' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👩🏾‍❤‍💋‍👩🏻' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏾‍❤‍💋‍👩🏼' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏾‍❤‍💋‍👩🏽' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏾‍❤‍💋‍👩🏾' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ',
    '👩🏾‍❤‍💋‍👩🏿' => 'чупту: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👩🏿‍❤‍💋‍👩🏻' => 'чупту: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏿‍❤‍💋‍👩🏼' => 'чупту: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏿‍❤‍💋‍👩🏽' => 'чупту: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏿‍❤‍💋‍👩🏾' => 'чупту: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍❤‍💋‍👩🏿' => 'чупту: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ',
    '🧑🏻‍🫯‍🧑🏼' => 'кӗрешӳҫӗсем: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏻‍🫯‍🧑🏽' => 'кӗрешӳҫӗсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏻‍🫯‍🧑🏾' => 'кӗрешӳҫӗсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏻‍🫯‍🧑🏿' => 'кӗрешӳҫӗсем: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏼‍🫯‍🧑🏻' => 'кӗрешӳҫӗсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🫯‍🧑🏽' => 'кӗрешӳҫӗсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏼‍🫯‍🧑🏾' => 'кӗрешӳҫӗсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏼‍🫯‍🧑🏿' => 'кӗрешӳҫӗсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏽‍🫯‍🧑🏻' => 'кӗрешӳҫӗсем: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏽‍🫯‍🧑🏼' => 'кӗрешӳҫӗсем: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🫯‍🧑🏾' => 'кӗрешӳҫӗсем: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏽‍🫯‍🧑🏿' => 'кӗрешӳҫӗсем: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏾‍🫯‍🧑🏻' => 'кӗрешӳҫӗсем: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏾‍🫯‍🧑🏼' => 'кӗрешӳҫӗсем: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏾‍🫯‍🧑🏽' => 'кӗрешӳҫӗсем: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏾‍🫯‍🧑🏿' => 'кӗрешӳҫӗсем: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏿‍🫯‍🧑🏻' => 'кӗрешӳҫӗсем: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏿‍🫯‍🧑🏼' => 'кӗрешӳҫӗсем: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏿‍🫯‍🧑🏽' => 'кӗрешӳҫӗсем: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏿‍🫯‍🧑🏾' => 'кӗрешӳҫӗсем: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏻‍❤‍🧑🏼' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏻‍❤‍🧑🏽' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏻‍❤‍🧑🏾' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏻‍❤‍🧑🏿' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏼‍❤‍🧑🏻' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍❤‍🧑🏽' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏼‍❤‍🧑🏾' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏼‍❤‍🧑🏿' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏽‍❤‍🧑🏻' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏽‍❤‍🧑🏼' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍❤‍🧑🏾' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏽‍❤‍🧑🏿' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏾‍❤‍🧑🏻' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏾‍❤‍🧑🏼' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏾‍❤‍🧑🏽' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏾‍❤‍🧑🏿' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏿‍❤‍🧑🏻' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏿‍❤‍🧑🏼' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏿‍❤‍🧑🏽' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏿‍❤‍🧑🏾' => 'юратса пӑрахнӑ мӑшӑр: ҫитӗннӗ ҫын ҫитӗннӗ ҫын сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏻‍🐰‍🧑🏼' => 'мулкач хӑлхаллӑ ҫынсем: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏻‍🐰‍🧑🏽' => 'мулкач хӑлхаллӑ ҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏻‍🐰‍🧑🏾' => 'мулкач хӑлхаллӑ ҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏻‍🐰‍🧑🏿' => 'мулкач хӑлхаллӑ ҫынсем: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏼‍🐰‍🧑🏻' => 'мулкач хӑлхаллӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🐰‍🧑🏽' => 'мулкач хӑлхаллӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏼‍🐰‍🧑🏾' => 'мулкач хӑлхаллӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏼‍🐰‍🧑🏿' => 'мулкач хӑлхаллӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏽‍🐰‍🧑🏻' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏽‍🐰‍🧑🏼' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🐰‍🧑🏾' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏽‍🐰‍🧑🏿' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏾‍🐰‍🧑🏻' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏾‍🐰‍🧑🏼' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏾‍🐰‍🧑🏽' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏾‍🐰‍🧑🏿' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏿‍🐰‍🧑🏻' => 'мулкач хӑлхаллӑ ҫынсем: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏿‍🐰‍🧑🏼' => 'мулкач хӑлхаллӑ ҫынсем: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏿‍🐰‍🧑🏽' => 'мулкач хӑлхаллӑ ҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏿‍🐰‍🧑🏾' => 'мулкач хӑлхаллӑ ҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏻‍🫯‍👨🏼' => 'кӗрешӳҫӗ арҫынсем: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏻‍🫯‍👨🏽' => 'кӗрешӳҫӗ арҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏻‍🫯‍👨🏾' => 'кӗрешӳҫӗ арҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏻‍🫯‍👨🏿' => 'кӗрешӳҫӗ арҫынсем: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏼‍🫯‍👨🏻' => 'кӗрешӳҫӗ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🫯‍👨🏽' => 'кӗрешӳҫӗ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏼‍🫯‍👨🏾' => 'кӗрешӳҫӗ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏼‍🫯‍👨🏿' => 'кӗрешӳҫӗ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏽‍🫯‍👨🏻' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏽‍🫯‍👨🏼' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🫯‍👨🏾' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏽‍🫯‍👨🏿' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👨🏾‍🫯‍👨🏻' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏾‍🫯‍👨🏼' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏾‍🫯‍👨🏽' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏾‍🫯‍👨🏿' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👨🏿‍🫯‍👨🏻' => 'кӗрешӳҫӗ арҫынсем: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏿‍🫯‍👨🏼' => 'кӗрешӳҫӗ арҫынсем: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏿‍🫯‍👨🏽' => 'кӗрешӳҫӗ арҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏿‍🫯‍👨🏾' => 'кӗрешӳҫӗ арҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏻‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран ҫутӑ тӗсӗ',
    '👨🏻‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏻‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏻‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏻‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏼‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👨🏼‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏼‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏼‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏼‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏽‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏽‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тонӗ',
    '👨🏽‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏽‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👨🏾‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏾‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏾‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏾‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ',
    '👨🏾‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👨🏿‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏿‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏿‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏿‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын сӑран тӗксӗм тонӗ',
    '👨🏻‍🐰‍👨🏼' => 'мулкач хӑлхаллӑ арҫынсем: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏻‍🐰‍👨🏽' => 'мулкач хӑлхаллӑ арҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏻‍🐰‍👨🏾' => 'мулкач хӑлхаллӑ арҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏻‍🐰‍👨🏿' => 'мулкач хӑлхаллӑ арҫынсем: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏼‍🐰‍👨🏻' => 'мулкач хӑлхаллӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🐰‍👨🏽' => 'мулкач хӑлхаллӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏼‍🐰‍👨🏾' => 'мулкач хӑлхаллӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏼‍🐰‍👨🏿' => 'мулкач хӑлхаллӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏽‍🐰‍👨🏻' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏽‍🐰‍👨🏼' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🐰‍👨🏾' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏽‍🐰‍👨🏿' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👨🏾‍🐰‍👨🏻' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏾‍🐰‍👨🏼' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏾‍🐰‍👨🏽' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏾‍🐰‍👨🏿' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👨🏿‍🐰‍👨🏻' => 'мулкач хӑлхаллӑ арҫынсем: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏿‍🐰‍👨🏼' => 'мулкач хӑлхаллӑ арҫынсем: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏿‍🐰‍👨🏽' => 'мулкач хӑлхаллӑ арҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏿‍🐰‍👨🏾' => 'мулкач хӑлхаллӑ арҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍🫯‍👩🏼' => 'хӗрарӑм кӗрешӗвӗ: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏻‍🫯‍👩🏽' => 'хӗрарӑм кӗрешӗвӗ: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏻‍🫯‍👩🏾' => 'хӗрарӑм кӗрешӗвӗ: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍🫯‍👩🏿' => 'хӗрарӑм кӗрешӗвӗ: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏼‍🫯‍👩🏻' => 'хӗрарӑм кӗрешӗвӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🫯‍👩🏽' => 'хӗрарӑм кӗрешӗвӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏼‍🫯‍👩🏾' => 'хӗрарӑм кӗрешӗвӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏼‍🫯‍👩🏿' => 'хӗрарӑм кӗрешӗвӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏽‍🫯‍👩🏻' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏽‍🫯‍👩🏼' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🫯‍👩🏾' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏽‍🫯‍👩🏿' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👩🏾‍🫯‍👩🏻' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏾‍🫯‍👩🏼' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏾‍🫯‍👩🏽' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏾‍🫯‍👩🏿' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👩🏿‍🫯‍👩🏻' => 'хӗрарӑм кӗрешӗвӗ: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏿‍🫯‍👩🏼' => 'хӗрарӑм кӗрешӗвӗ: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏿‍🫯‍👩🏽' => 'хӗрарӑм кӗрешӗвӗ: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏿‍🫯‍👩🏾' => 'хӗрарӑм кӗрешӗвӗ: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ',
    '👩🏻‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏻‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏻‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏼‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👩🏼‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏼‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏼‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏼‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏽‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏽‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тонӗ',
    '👩🏽‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏽‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👩🏾‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏾‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏾‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏾‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ',
    '👩🏾‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👩🏿‍❤‍👨🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏿‍❤‍👨🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏿‍❤‍👨🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏿‍❤‍👨🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍❤‍👨🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын сӑран тӗксӗм тонӗ',
    '👩🏻‍❤‍👩🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ',
    '👩🏻‍❤‍👩🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏻‍❤‍👩🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏻‍❤‍👩🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍❤‍👩🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏼‍❤‍👩🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👩🏼‍❤‍👩🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏼‍❤‍👩🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏼‍❤‍👩🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏼‍❤‍👩🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏽‍❤‍👩🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏽‍❤‍👩🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍❤‍👩🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ',
    '👩🏽‍❤‍👩🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏽‍❤‍👩🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👩🏾‍❤‍👩🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏾‍❤‍👩🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏾‍❤‍👩🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏾‍❤‍👩🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ',
    '👩🏾‍❤‍👩🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👩🏿‍❤‍👩🏻' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏿‍❤‍👩🏼' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏿‍❤‍👩🏽' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏿‍❤‍👩🏾' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍❤‍👩🏿' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм сӑран тӗксӗм тонӗ',
    '👩🏻‍🐰‍👩🏼' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏻‍🐰‍👩🏽' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏻‍🐰‍👩🏾' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍🐰‍👩🏿' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏼‍🐰‍👩🏻' => 'мулкач хӑлхаллӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🐰‍👩🏽' => 'мулкач хӑлхаллӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏼‍🐰‍👩🏾' => 'мулкач хӑлхаллӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏼‍🐰‍👩🏿' => 'мулкач хӑлхаллӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏽‍🐰‍👩🏻' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏽‍🐰‍👩🏼' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🐰‍👩🏾' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏽‍🐰‍👩🏿' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👩🏾‍🐰‍👩🏻' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏾‍🐰‍👩🏼' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏾‍🐰‍👩🏽' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏾‍🐰‍👩🏿' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👩🏿‍🐰‍👩🏻' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏿‍🐰‍👩🏼' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏿‍🐰‍👩🏽' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏿‍🐰‍👩🏾' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏻‍🤝‍🧑🏻' => 'алӑран тытнӑ ҫынсем: сӑран ҫутӑ тӗсӗ',
    '🧑🏻‍🤝‍🧑🏼' => 'алӑран тытнӑ ҫынсем: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏻‍🤝‍🧑🏽' => 'алӑран тытнӑ ҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏻‍🤝‍🧑🏾' => 'алӑран тытнӑ ҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏻‍🤝‍🧑🏿' => 'алӑран тытнӑ ҫынсем: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏼‍🤝‍🧑🏻' => 'алӑран тытнӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🤝‍🧑🏼' => 'алӑран тытнӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏼‍🤝‍🧑🏽' => 'алӑран тытнӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🧑🏼‍🤝‍🧑🏾' => 'алӑран тытнӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏼‍🤝‍🧑🏿' => 'алӑран тытнӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🧑🏽‍🤝‍🧑🏻' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏽‍🤝‍🧑🏼' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🤝‍🧑🏽' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тонӗ',
    '🧑🏽‍🤝‍🧑🏾' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏽‍🤝‍🧑🏿' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏾‍🤝‍🧑🏻' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏾‍🤝‍🧑🏼' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏾‍🤝‍🧑🏽' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏾‍🤝‍🧑🏾' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏾‍🤝‍🧑🏿' => 'алӑран тытнӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '🧑🏿‍🤝‍🧑🏻' => 'алӑран тытнӑ ҫынсем: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🧑🏿‍🤝‍🧑🏼' => 'алӑран тытнӑ ҫынсем: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏿‍🤝‍🧑🏽' => 'алӑран тытнӑ ҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🧑🏿‍🤝‍🧑🏾' => 'алӑран тытнӑ ҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🤝‍🧑🏿' => 'алӑран тытнӑ ҫынсем: сӑран тӗксӗм тонӗ',
    '👩🏻‍🤝‍👩🏼' => 'алӑран тытнӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏻‍🤝‍👩🏽' => 'алӑран тытнӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏻‍🤝‍👩🏾' => 'алӑран тытнӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍🤝‍👩🏿' => 'алӑран тытнӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏼‍🤝‍👩🏻' => 'алӑран тытнӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🤝‍👩🏽' => 'алӑран тытнӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏼‍🤝‍👩🏾' => 'алӑран тытнӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏼‍🤝‍👩🏿' => 'алӑран тытнӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏽‍🤝‍👩🏻' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏽‍🤝‍👩🏼' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🤝‍👩🏾' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏽‍🤝‍👩🏿' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👩🏾‍🤝‍👩🏻' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏾‍🤝‍👩🏼' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏾‍🤝‍👩🏽' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏾‍🤝‍👩🏿' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👩🏿‍🤝‍👩🏻' => 'алӑран тытнӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏿‍🤝‍👩🏼' => 'алӑран тытнӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏿‍🤝‍👩🏽' => 'алӑран тытнӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏿‍🤝‍👩🏾' => 'алӑран тытнӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍🤝‍👨🏼' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏻‍🤝‍👨🏽' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏻‍🤝‍👨🏾' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏻‍🤝‍👨🏿' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏼‍🤝‍👨🏻' => 'арҫынпа хӗрарӑм алӑран тытать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🤝‍👨🏽' => 'арҫынпа хӗрарӑм алӑран тытать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👩🏼‍🤝‍👨🏾' => 'арҫынпа хӗрарӑм алӑран тытать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏼‍🤝‍👨🏿' => 'арҫынпа хӗрарӑм алӑран тытать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👩🏽‍🤝‍👨🏻' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏽‍🤝‍👨🏼' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🤝‍👨🏾' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩🏽‍🤝‍👨🏿' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👩🏾‍🤝‍👨🏻' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏾‍🤝‍👨🏼' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏾‍🤝‍👨🏽' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏾‍🤝‍👨🏿' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👩🏿‍🤝‍👨🏻' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👩🏿‍🤝‍👨🏼' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏿‍🤝‍👨🏽' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👩🏿‍🤝‍👨🏾' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏻‍🤝‍👨🏼' => 'алӑран тытнӑ арҫынсем: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏻‍🤝‍👨🏽' => 'алӑран тытнӑ арҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏻‍🤝‍👨🏾' => 'алӑран тытнӑ арҫынсем: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏻‍🤝‍👨🏿' => 'алӑран тытнӑ арҫынсем: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏼‍🤝‍👨🏻' => 'алӑран тытнӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🤝‍👨🏽' => 'алӑран тытнӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '👨🏼‍🤝‍👨🏾' => 'алӑран тытнӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏼‍🤝‍👨🏿' => 'алӑран тытнӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '👨🏽‍🤝‍👨🏻' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏽‍🤝‍👨🏼' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🤝‍👨🏾' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👨🏽‍🤝‍👨🏿' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '👨🏾‍🤝‍👨🏻' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏾‍🤝‍👨🏼' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏾‍🤝‍👨🏽' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏾‍🤝‍👨🏿' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '👨🏿‍🤝‍👨🏻' => 'алӑран тытнӑ арҫынсем: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '👨🏿‍🤝‍👨🏼' => 'алӑран тытнӑ арҫынсем: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏿‍🤝‍👨🏽' => 'алӑран тытнӑ арҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '👨🏿‍🤝‍👨🏾' => 'алӑран тытнӑ арҫынсем: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '👩‍❤‍💋‍👨' => 'чупту: хӗрарӑм арҫын',
    '👨‍❤‍💋‍👨' => 'чупту: арҫын арҫын',
    '👩‍❤‍💋‍👩' => 'чупту: хӗрарӑм хӗрарӑм',
    '👨‍👩‍👧‍👦' => 'ҫемье: арҫын хӗрарӑм хӗрача арçын ача',
    '👨‍👩‍👦‍👦' => 'ҫемье: арҫын хӗрарӑм арçын ача арçын ача',
    '👨‍👩‍👧‍👧' => 'ҫемье: арҫын хӗрарӑм хӗрача хӗрача',
    '👨‍👨‍👧‍👦' => 'ҫемье: арҫын арҫын хӗрача арçын ача',
    '👨‍👨‍👦‍👦' => 'ҫемье: арҫын арҫын арçын ача арçын ача',
    '👨‍👨‍👧‍👧' => 'ҫемье: арҫын арҫын хӗрача хӗрача',
    '👩‍👩‍👧‍👦' => 'ҫемье: хӗрарӑм хӗрарӑм хӗрача арçын ача',
    '👩‍👩‍👦‍👦' => 'ҫемье: хӗрарӑм хӗрарӑм арçын ача арçын ача',
    '👩‍👩‍👧‍👧' => 'ҫемье: хӗрарӑм хӗрарӑм хӗрача хӗрача',
    '🧑‍🧑‍🧒‍🧒' => 'ҫемье: икӗ асли тата икӗ ача',
    '🚶🏻‍♀‍➡' => 'хӗрарӑм килет: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🚶🏼‍♀‍➡' => 'хӗрарӑм килет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🚶🏽‍♀‍➡' => 'хӗрарӑм килет: сӑран вӑтам тонӗ сылтӑмалла',
    '🚶🏾‍♀‍➡' => 'хӗрарӑм килет: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🚶🏿‍♀‍➡' => 'хӗрарӑм килет: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🚶🏻‍♂‍➡' => 'арҫын килет: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🚶🏼‍♂‍➡' => 'арҫын килет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🚶🏽‍♂‍➡' => 'арҫын килет: сӑран вӑтам тонӗ сылтӑмалла',
    '🚶🏾‍♂‍➡' => 'арҫын килет: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🚶🏿‍♂‍➡' => 'арҫын килет: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🧎🏻‍♀‍➡' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🧎🏼‍♀‍➡' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🧎🏽‍♀‍➡' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: сӑран вӑтам тонӗ сылтӑмалла',
    '🧎🏾‍♀‍➡' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🧎🏿‍♀‍➡' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🧎🏻‍♂‍➡' => 'арҫын чӗркуҫҫи ҫинче: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🧎🏼‍♂‍➡' => 'арҫын чӗркуҫҫи ҫинче: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🧎🏽‍♂‍➡' => 'арҫын чӗркуҫҫи ҫинче: сӑран вӑтам тонӗ сылтӑмалла',
    '🧎🏾‍♂‍➡' => 'арҫын чӗркуҫҫи ҫинче: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🧎🏿‍♂‍➡' => 'арҫын чӗркуҫҫи ҫинче: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🧑🏻‍🦯‍➡' => 'шурӑ туялӑ ҫын: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🧑🏼‍🦯‍➡' => 'шурӑ туялӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🧑🏽‍🦯‍➡' => 'шурӑ туялӑ ҫын: сӑран вӑтам тонӗ сылтӑмалла',
    '🧑🏾‍🦯‍➡' => 'шурӑ туялӑ ҫын: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🧑🏿‍🦯‍➡' => 'шурӑ туялӑ ҫын: сӑран тӗксӗм тонӗ сылтӑмалла',
    '👨🏻‍🦯‍➡' => 'утмалли туя: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '👨🏼‍🦯‍➡' => 'утмалли туя: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '👨🏽‍🦯‍➡' => 'утмалли туя: сӑран вӑтам тонӗ сылтӑмалла',
    '👨🏾‍🦯‍➡' => 'утмалли туя: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '👨🏿‍🦯‍➡' => 'утмалли туя: сӑран тӗксӗм тонӗ сылтӑмалла',
    '👩🏻‍🦯‍➡' => 'шур патаклӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '👩🏼‍🦯‍➡' => 'шур патаклӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '👩🏽‍🦯‍➡' => 'шур патаклӑ хӗрарӑм: сӑран вӑтам тонӗ сылтӑмалла',
    '👩🏾‍🦯‍➡' => 'шур патаклӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '👩🏿‍🦯‍➡' => 'шур патаклӑ хӗрарӑм: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🧑🏻‍🦼‍➡' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🧑🏼‍🦼‍➡' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🧑🏽‍🦼‍➡' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: сӑран вӑтам тонӗ сылтӑмалла',
    '🧑🏾‍🦼‍➡' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🧑🏿‍🦼‍➡' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: сӑран тӗксӗм тонӗ сылтӑмалла',
    '👨🏻‍🦼‍➡' => 'электричество кресли-коляска тӑхӑннӑ арҫын: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '👨🏼‍🦼‍➡' => 'электричество кресли-коляска тӑхӑннӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '👨🏽‍🦼‍➡' => 'электричество кресли-коляска тӑхӑннӑ арҫын: сӑран вӑтам тонӗ сылтӑмалла',
    '👨🏾‍🦼‍➡' => 'электричество кресли-коляска тӑхӑннӑ арҫын: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '👨🏿‍🦼‍➡' => 'электричество кресли-коляска тӑхӑннӑ арҫын: сӑран тӗксӗм тонӗ сылтӑмалла',
    '👩🏻‍🦼‍➡' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '👩🏼‍🦼‍➡' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '👩🏽‍🦼‍➡' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: сӑран вӑтам тонӗ сылтӑмалла',
    '👩🏾‍🦼‍➡' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '👩🏿‍🦼‍➡' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🧑🏻‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🧑🏼‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🧑🏽‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: сӑран вӑтам тонӗ сылтӑмалла',
    '🧑🏾‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🧑🏿‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: сӑран тӗксӗм тонӗ сылтӑмалла',
    '👨🏻‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '👨🏼‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '👨🏽‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: сӑран вӑтам тонӗ сылтӑмалла',
    '👨🏾‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '👨🏿‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: сӑран тӗксӗм тонӗ сылтӑмалла',
    '👩🏻‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '👩🏼‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '👩🏽‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: сӑран вӑтам тонӗ сылтӑмалла',
    '👩🏾‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '👩🏿‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🏃🏻‍♀‍➡' => 'чупакан хӗрарӑм: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🏃🏼‍♀‍➡' => 'чупакан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🏃🏽‍♀‍➡' => 'чупакан хӗрарӑм: сӑран вӑтам тонӗ сылтӑмалла',
    '🏃🏾‍♀‍➡' => 'чупакан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🏃🏿‍♀‍➡' => 'чупакан хӗрарӑм: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🏃🏻‍♂‍➡' => 'арҫын чупать: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🏃🏼‍♂‍➡' => 'арҫын чупать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🏃🏽‍♂‍➡' => 'арҫын чупать: сӑран вӑтам тонӗ сылтӑмалла',
    '🏃🏾‍♂‍➡' => 'арҫын чупать: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🏃🏿‍♂‍➡' => 'арҫын чупать: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🫱🏻‍🫲🏼' => 'алӑ тытни: сӑран ҫутӑ тӗсӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫱🏻‍🫲🏽' => 'алӑ тытни: сӑран ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🫱🏻‍🫲🏾' => 'алӑ тытни: сӑран ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🫱🏻‍🫲🏿' => 'алӑ тытни: сӑран ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🫱🏼‍🫲🏻' => 'алӑ тытни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран ҫутӑ тӗсӗ',
    '🫱🏼‍🫲🏽' => 'алӑ тытни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тонӗ',
    '🫱🏼‍🫲🏾' => 'алӑ тытни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран вӑтам тӗксӗм тонӗ',
    '🫱🏼‍🫲🏿' => 'алӑ тытни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сӑран тӗксӗм тонӗ',
    '🫱🏽‍🫲🏻' => 'алӑ тытни: сӑран вӑтам тонӗ сӑран ҫутӑ тӗсӗ',
    '🫱🏽‍🫲🏼' => 'алӑ тытни: сӑран вӑтам тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫱🏽‍🫲🏾' => 'алӑ тытни: сӑран вӑтам тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🫱🏽‍🫲🏿' => 'алӑ тытни: сӑран вӑтам тонӗ сӑран тӗксӗм тонӗ',
    '🫱🏾‍🫲🏻' => 'алӑ тытни: сӑран вӑтам тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🫱🏾‍🫲🏼' => 'алӑ тытни: сӑран вӑтам тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫱🏾‍🫲🏽' => 'алӑ тытни: сӑран вӑтам тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🫱🏾‍🫲🏿' => 'алӑ тытни: сӑран вӑтам тӗксӗм тонӗ сӑран тӗксӗм тонӗ',
    '🫱🏿‍🫲🏻' => 'алӑ тытни: сӑран тӗксӗм тонӗ сӑран ҫутӑ тӗсӗ',
    '🫱🏿‍🫲🏼' => 'алӑ тытни: сӑран тӗксӗм тонӗ ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫱🏿‍🫲🏽' => 'алӑ тытни: сӑран тӗксӗм тонӗ сӑран вӑтам тонӗ',
    '🫱🏿‍🫲🏾' => 'алӑ тытни: сӑран тӗксӗм тонӗ сӑран вӑтам тӗксӗм тонӗ',
    '🚶‍♀‍➡' => 'хӗрарӑм килет: сылтӑмалла',
    '🚶‍♂‍➡' => 'арҫын килет: сылтӑмалла',
    '🧎‍♀‍➡' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: сылтӑмалла',
    '🧎‍♂‍➡' => 'арҫын чӗркуҫҫи ҫинче: сылтӑмалла',
    '🧑‍🦯‍➡' => 'шурӑ туялӑ ҫын: сылтӑмалла',
    '👨‍🦯‍➡' => 'утмалли туя: сылтӑмалла',
    '👩‍🦯‍➡' => 'шур патаклӑ хӗрарӑм: сылтӑмалла',
    '🧑‍🦼‍➡' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: сылтӑмалла',
    '👨‍🦼‍➡' => 'электричество кресли-коляска тӑхӑннӑ арҫын: сылтӑмалла',
    '👩‍🦼‍➡' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: сылтӑмалла',
    '🧑‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: сылтӑмалла',
    '👨‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: сылтӑмалла',
    '👩‍🦽‍➡' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: сылтӑмалла',
    '🏃‍♀‍➡' => 'чупакан хӗрарӑм: сылтӑмалла',
    '🏃‍♂‍➡' => 'арҫын чупать: сылтӑмалла',
    '👩‍❤‍👨' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм арҫын',
    '👨‍❤‍👨' => 'юратса пӑрахнӑ мӑшӑр: арҫын арҫын',
    '👩‍❤‍👩' => 'юратса пӑрахнӑ мӑшӑр: хӗрарӑм хӗрарӑм',
    '👨‍👩‍👦' => 'ҫемье: арҫын хӗрарӑм арçын ача',
    '👨‍👩‍👧' => 'ҫемье: арҫын хӗрарӑм хӗрача',
    '👨‍👨‍👦' => 'ҫемье: арҫын арҫын арçын ача',
    '👨‍👨‍👧' => 'ҫемье: арҫын арҫын хӗрача',
    '👩‍👩‍👦' => 'ҫемье: хӗрарӑм хӗрарӑм арçын ача',
    '👩‍👩‍👧' => 'ҫемье: хӗрарӑм хӗрарӑм хӗрача',
    '👨‍👦‍👦' => 'ҫемье: арҫын арçын ача арçын ача',
    '👨‍👧‍👦' => 'ҫемье: арҫын хӗрача арçын ача',
    '👨‍👧‍👧' => 'ҫемье: арҫын хӗрача хӗрача',
    '👩‍👦‍👦' => 'ҫемье: хӗрарӑм арçын ача арçын ача',
    '👩‍👧‍👦' => 'ҫемье: хӗрарӑм хӗрача арçын ача',
    '👩‍👧‍👧' => 'ҫемье: хӗрарӑм хӗрача хӗрача',
    '🧑‍🤝‍🧑' => 'алӑран тытнӑ ҫынсем',
    '🧑‍🧑‍🧒' => 'ҫемье: икӗ асли тата ача',
    '🧑‍🧒‍🧒' => 'ҫемье: ҫитӗннӗ тата икӗ ача',
    '🧑🏻‍🦰' => 'ҫитӗннӗ ҫын: сӑран ҫутӑ тӗсӗ хӗрлӗ ҫӳҫ',
    '🧑🏼‍🦰' => 'ҫитӗннӗ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ хӗрлӗ ҫӳҫ',
    '🧑🏽‍🦰' => 'ҫитӗннӗ ҫын: сӑран вӑтам тонӗ хӗрлӗ ҫӳҫ',
    '🧑🏾‍🦰' => 'ҫитӗннӗ ҫын: сӑран вӑтам тӗксӗм тонӗ хӗрлӗ ҫӳҫ',
    '🧑🏿‍🦰' => 'ҫитӗннӗ ҫын: сӑран тӗксӗм тонӗ хӗрлӗ ҫӳҫ',
    '🧑🏻‍🦱' => 'ҫитӗннӗ ҫын: сӑран ҫутӑ тӗсӗ явӑнчӑк ҫӳҫ',
    '🧑🏼‍🦱' => 'ҫитӗннӗ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ явӑнчӑк ҫӳҫ',
    '🧑🏽‍🦱' => 'ҫитӗннӗ ҫын: сӑран вӑтам тонӗ явӑнчӑк ҫӳҫ',
    '🧑🏾‍🦱' => 'ҫитӗннӗ ҫын: сӑран вӑтам тӗксӗм тонӗ явӑнчӑк ҫӳҫ',
    '🧑🏿‍🦱' => 'ҫитӗннӗ ҫын: сӑран тӗксӗм тонӗ явӑнчӑк ҫӳҫ',
    '🧑🏻‍🦳' => 'ҫитӗннӗ ҫын: сӑран ҫутӑ тӗсӗ шурӑ ҫӳҫ',
    '🧑🏼‍🦳' => 'ҫитӗннӗ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ шурӑ ҫӳҫ',
    '🧑🏽‍🦳' => 'ҫитӗннӗ ҫын: сӑран вӑтам тонӗ шурӑ ҫӳҫ',
    '🧑🏾‍🦳' => 'ҫитӗннӗ ҫын: сӑран вӑтам тӗксӗм тонӗ шурӑ ҫӳҫ',
    '🧑🏿‍🦳' => 'ҫитӗннӗ ҫын: сӑран тӗксӗм тонӗ шурӑ ҫӳҫ',
    '🧑🏻‍🦲' => 'ҫитӗннӗ ҫын: сӑран ҫутӑ тӗсӗ кукша пуҫ',
    '🧑🏼‍🦲' => 'ҫитӗннӗ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ кукша пуҫ',
    '🧑🏽‍🦲' => 'ҫитӗннӗ ҫын: сӑран вӑтам тонӗ кукша пуҫ',
    '🧑🏾‍🦲' => 'ҫитӗннӗ ҫын: сӑран вӑтам тӗксӗм тонӗ кукша пуҫ',
    '🧑🏿‍🦲' => 'ҫитӗннӗ ҫын: сӑран тӗксӗм тонӗ кукша пуҫ',
    '🧑🏻‍🩰' => 'балет ташӑҫи: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🩰' => 'балет ташӑҫи: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🩰' => 'балет ташӑҫи: сӑран вӑтам тонӗ',
    '🧑🏾‍🩰' => 'балет ташӑҫи: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🩰' => 'балет ташӑҫи: сӑран тӗксӗм тонӗ',
    '🧔🏻‍♂' => 'сухаллӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '🧔🏼‍♂' => 'сухаллӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧔🏽‍♂' => 'сухаллӑ арҫын: сӑран вӑтам тонӗ',
    '🧔🏾‍♂' => 'сухаллӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧔🏿‍♂' => 'сухаллӑ арҫын: сӑран тӗксӗм тонӗ',
    '👱🏻‍♂' => 'сарӑ ҫын: сӑран ҫутӑ тӗсӗ',
    '👱🏼‍♂' => 'сарӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👱🏽‍♂' => 'сарӑ ҫын: сӑран вӑтам тонӗ',
    '👱🏾‍♂' => 'сарӑ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👱🏿‍♂' => 'сарӑ ҫын: сӑран тӗксӗм тонӗ',
    '👨🏻‍🦰' => 'арҫын: сӑран ҫутӑ тӗсӗ хӗрлӗ ҫӳҫ',
    '👨🏼‍🦰' => 'арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ хӗрлӗ ҫӳҫ',
    '👨🏽‍🦰' => 'арҫын: сӑран вӑтам тонӗ хӗрлӗ ҫӳҫ',
    '👨🏾‍🦰' => 'арҫын: сӑран вӑтам тӗксӗм тонӗ хӗрлӗ ҫӳҫ',
    '👨🏿‍🦰' => 'арҫын: сӑран тӗксӗм тонӗ хӗрлӗ ҫӳҫ',
    '👨🏻‍🦱' => 'арҫын: сӑран ҫутӑ тӗсӗ явӑнчӑк ҫӳҫ',
    '👨🏼‍🦱' => 'арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ явӑнчӑк ҫӳҫ',
    '👨🏽‍🦱' => 'арҫын: сӑран вӑтам тонӗ явӑнчӑк ҫӳҫ',
    '👨🏾‍🦱' => 'арҫын: сӑран вӑтам тӗксӗм тонӗ явӑнчӑк ҫӳҫ',
    '👨🏿‍🦱' => 'арҫын: сӑран тӗксӗм тонӗ явӑнчӑк ҫӳҫ',
    '👨🏻‍🦳' => 'арҫын: сӑран ҫутӑ тӗсӗ шурӑ ҫӳҫ',
    '👨🏼‍🦳' => 'арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ шурӑ ҫӳҫ',
    '👨🏽‍🦳' => 'арҫын: сӑран вӑтам тонӗ шурӑ ҫӳҫ',
    '👨🏾‍🦳' => 'арҫын: сӑран вӑтам тӗксӗм тонӗ шурӑ ҫӳҫ',
    '👨🏿‍🦳' => 'арҫын: сӑран тӗксӗм тонӗ шурӑ ҫӳҫ',
    '👨🏻‍🦲' => 'арҫын: сӑран ҫутӑ тӗсӗ кукша пуҫ',
    '👨🏼‍🦲' => 'арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ кукша пуҫ',
    '👨🏽‍🦲' => 'арҫын: сӑран вӑтам тонӗ кукша пуҫ',
    '👨🏾‍🦲' => 'арҫын: сӑран вӑтам тӗксӗм тонӗ кукша пуҫ',
    '👨🏿‍🦲' => 'арҫын: сӑран тӗксӗм тонӗ кукша пуҫ',
    '🧔🏻‍♀' => 'сухаллӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧔🏼‍♀' => 'сухаллӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧔🏽‍♀' => 'сухаллӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '🧔🏾‍♀' => 'сухаллӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧔🏿‍♀' => 'сухаллӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '👱🏻‍♀' => 'сарӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👱🏼‍♀' => 'сарӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👱🏽‍♀' => 'сарӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '👱🏾‍♀' => 'сарӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👱🏿‍♀' => 'сарӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '👩🏻‍🦰' => 'хӗрарӑм: сӑран ҫутӑ тӗсӗ хӗрлӗ ҫӳҫ',
    '👩🏼‍🦰' => 'хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ хӗрлӗ ҫӳҫ',
    '👩🏽‍🦰' => 'хӗрарӑм: сӑран вӑтам тонӗ хӗрлӗ ҫӳҫ',
    '👩🏾‍🦰' => 'хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ хӗрлӗ ҫӳҫ',
    '👩🏿‍🦰' => 'хӗрарӑм: сӑран тӗксӗм тонӗ хӗрлӗ ҫӳҫ',
    '👩🏻‍🦱' => 'хӗрарӑм: сӑран ҫутӑ тӗсӗ явӑнчӑк ҫӳҫ',
    '👩🏼‍🦱' => 'хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ явӑнчӑк ҫӳҫ',
    '👩🏽‍🦱' => 'хӗрарӑм: сӑран вӑтам тонӗ явӑнчӑк ҫӳҫ',
    '👩🏾‍🦱' => 'хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ явӑнчӑк ҫӳҫ',
    '👩🏿‍🦱' => 'хӗрарӑм: сӑран тӗксӗм тонӗ явӑнчӑк ҫӳҫ',
    '👩🏻‍🦳' => 'хӗрарӑм: сӑран ҫутӑ тӗсӗ шурӑ ҫӳҫ',
    '👩🏼‍🦳' => 'хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ шурӑ ҫӳҫ',
    '👩🏽‍🦳' => 'хӗрарӑм: сӑран вӑтам тонӗ шурӑ ҫӳҫ',
    '👩🏾‍🦳' => 'хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ шурӑ ҫӳҫ',
    '👩🏿‍🦳' => 'хӗрарӑм: сӑран тӗксӗм тонӗ шурӑ ҫӳҫ',
    '👩🏻‍🦲' => 'хӗрарӑм: сӑран ҫутӑ тӗсӗ кукша пуҫ',
    '👩🏼‍🦲' => 'хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ кукша пуҫ',
    '👩🏽‍🦲' => 'хӗрарӑм: сӑран вӑтам тонӗ кукша пуҫ',
    '👩🏾‍🦲' => 'хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ кукша пуҫ',
    '👩🏿‍🦲' => 'хӗрарӑм: сӑран тӗксӗм тонӗ кукша пуҫ',
    '🙍🏻‍♂' => 'тӗксӗмленнӗ арҫын: сӑран ҫутӑ тӗсӗ',
    '🙍🏼‍♂' => 'тӗксӗмленнӗ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙍🏽‍♂' => 'тӗксӗмленнӗ арҫын: сӑран вӑтам тонӗ',
    '🙍🏾‍♂' => 'тӗксӗмленнӗ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🙍🏿‍♂' => 'тӗксӗмленнӗ арҫын: сӑран тӗксӗм тонӗ',
    '🙍🏻‍♀' => 'тӗксӗмленнӗ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🙍🏼‍♀' => 'тӗксӗмленнӗ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙍🏽‍♀' => 'тӗксӗмленнӗ хӗрарӑм: сӑран вӑтам тонӗ',
    '🙍🏾‍♀' => 'тӗксӗмленнӗ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🙍🏿‍♀' => 'тӗксӗмленнӗ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🙎🏻‍♂' => 'кӳреннӗ арҫын: сӑран ҫутӑ тӗсӗ',
    '🙎🏼‍♂' => 'кӳреннӗ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙎🏽‍♂' => 'кӳреннӗ арҫын: сӑран вӑтам тонӗ',
    '🙎🏾‍♂' => 'кӳреннӗ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🙎🏿‍♂' => 'кӳреннӗ арҫын: сӑран тӗксӗм тонӗ',
    '🙎🏻‍♀' => 'кӳреннӗ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🙎🏼‍♀' => 'кӳреннӗ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙎🏽‍♀' => 'кӳреннӗ хӗрарӑм: сӑран вӑтам тонӗ',
    '🙎🏾‍♀' => 'кӳреннӗ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🙎🏿‍♀' => 'кӳреннӗ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🙅🏻‍♂' => 'арҫын "ҪУК" тесе алӑ сулать: сӑран ҫутӑ тӗсӗ',
    '🙅🏼‍♂' => 'арҫын "ҪУК" тесе алӑ сулать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙅🏽‍♂' => 'арҫын "ҪУК" тесе алӑ сулать: сӑран вӑтам тонӗ',
    '🙅🏾‍♂' => 'арҫын "ҪУК" тесе алӑ сулать: сӑран вӑтам тӗксӗм тонӗ',
    '🙅🏿‍♂' => 'арҫын "ҪУК" тесе алӑ сулать: сӑран тӗксӗм тонӗ',
    '🙅🏻‍♀' => 'хӗрарӑм "ҪУК"тесе алӑ сулать: сӑран ҫутӑ тӗсӗ',
    '🙅🏼‍♀' => 'хӗрарӑм "ҪУК"тесе алӑ сулать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙅🏽‍♀' => 'хӗрарӑм "ҪУК"тесе алӑ сулать: сӑран вӑтам тонӗ',
    '🙅🏾‍♀' => 'хӗрарӑм "ҪУК"тесе алӑ сулать: сӑран вӑтам тӗксӗм тонӗ',
    '🙅🏿‍♀' => 'хӗрарӑм "ҪУК"тесе алӑ сулать: сӑран тӗксӗм тонӗ',
    '🙆🏻‍♂' => 'арҫын "Ҫапла" тесе алӑ сулать: сӑран ҫутӑ тӗсӗ',
    '🙆🏼‍♂' => 'арҫын "Ҫапла" тесе алӑ сулать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙆🏽‍♂' => 'арҫын "Ҫапла" тесе алӑ сулать: сӑран вӑтам тонӗ',
    '🙆🏾‍♂' => 'арҫын "Ҫапла" тесе алӑ сулать: сӑран вӑтам тӗксӗм тонӗ',
    '🙆🏿‍♂' => 'арҫын "Ҫапла" тесе алӑ сулать: сӑран тӗксӗм тонӗ',
    '🙆🏻‍♀' => 'хӗрарӑм "Ҫапла" тесе алӑ сулать: сӑран ҫутӑ тӗсӗ',
    '🙆🏼‍♀' => 'хӗрарӑм "Ҫапла" тесе алӑ сулать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙆🏽‍♀' => 'хӗрарӑм "Ҫапла" тесе алӑ сулать: сӑран вӑтам тонӗ',
    '🙆🏾‍♀' => 'хӗрарӑм "Ҫапла" тесе алӑ сулать: сӑран вӑтам тӗксӗм тонӗ',
    '🙆🏿‍♀' => 'хӗрарӑм "Ҫапла" тесе алӑ сулать: сӑран тӗксӗм тонӗ',
    '💁🏻‍♂' => 'арҫын алӑ тӑсать: сӑран ҫутӑ тӗсӗ',
    '💁🏼‍♂' => 'арҫын алӑ тӑсать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💁🏽‍♂' => 'арҫын алӑ тӑсать: сӑран вӑтам тонӗ',
    '💁🏾‍♂' => 'арҫын алӑ тӑсать: сӑран вӑтам тӗксӗм тонӗ',
    '💁🏿‍♂' => 'арҫын алӑ тӑсать: сӑран тӗксӗм тонӗ',
    '💁🏻‍♀' => 'хӗрарӑм алӑ тӑсать: сӑран ҫутӑ тӗсӗ',
    '💁🏼‍♀' => 'хӗрарӑм алӑ тӑсать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💁🏽‍♀' => 'хӗрарӑм алӑ тӑсать: сӑран вӑтам тонӗ',
    '💁🏾‍♀' => 'хӗрарӑм алӑ тӑсать: сӑран вӑтам тӗксӗм тонӗ',
    '💁🏿‍♀' => 'хӗрарӑм алӑ тӑсать: сӑран тӗксӗм тонӗ',
    '🙋🏻‍♂' => 'ҫӗкленӗ арҫын: сӑран ҫутӑ тӗсӗ',
    '🙋🏼‍♂' => 'ҫӗкленӗ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙋🏽‍♂' => 'ҫӗкленӗ арҫын: сӑран вӑтам тонӗ',
    '🙋🏾‍♂' => 'ҫӗкленӗ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🙋🏿‍♂' => 'ҫӗкленӗ арҫын: сӑран тӗксӗм тонӗ',
    '🙋🏻‍♀' => 'хӗрарӑм аллине ҫӗклет: сӑран ҫутӑ тӗсӗ',
    '🙋🏼‍♀' => 'хӗрарӑм аллине ҫӗклет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙋🏽‍♀' => 'хӗрарӑм аллине ҫӗклет: сӑран вӑтам тонӗ',
    '🙋🏾‍♀' => 'хӗрарӑм аллине ҫӗклет: сӑран вӑтам тӗксӗм тонӗ',
    '🙋🏿‍♀' => 'хӗрарӑм аллине ҫӗклет: сӑран тӗксӗм тонӗ',
    '🧏🏻‍♂' => 'хӑлхасӑр арҫын: сӑран ҫутӑ тӗсӗ',
    '🧏🏼‍♂' => 'хӑлхасӑр арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧏🏽‍♂' => 'хӑлхасӑр арҫын: сӑран вӑтам тонӗ',
    '🧏🏾‍♂' => 'хӑлхасӑр арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧏🏿‍♂' => 'хӑлхасӑр арҫын: сӑран тӗксӗм тонӗ',
    '🧏🏻‍♀' => 'хӑлхасӑр хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧏🏼‍♀' => 'хӑлхасӑр хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧏🏽‍♀' => 'хӑлхасӑр хӗрарӑм: сӑран вӑтам тонӗ',
    '🧏🏾‍♀' => 'хӑлхасӑр хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧏🏿‍♀' => 'хӑлхасӑр хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🙇🏻‍♂' => 'арҫын пуҫ таять: сӑран ҫутӑ тӗсӗ',
    '🙇🏼‍♂' => 'арҫын пуҫ таять: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙇🏽‍♂' => 'арҫын пуҫ таять: сӑран вӑтам тонӗ',
    '🙇🏾‍♂' => 'арҫын пуҫ таять: сӑран вӑтам тӗксӗм тонӗ',
    '🙇🏿‍♂' => 'арҫын пуҫ таять: сӑран тӗксӗм тонӗ',
    '🙇🏻‍♀' => 'хӗрарӑм пуҫ таять: сӑран ҫутӑ тӗсӗ',
    '🙇🏼‍♀' => 'хӗрарӑм пуҫ таять: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙇🏽‍♀' => 'хӗрарӑм пуҫ таять: сӑран вӑтам тонӗ',
    '🙇🏾‍♀' => 'хӗрарӑм пуҫ таять: сӑран вӑтам тӗксӗм тонӗ',
    '🙇🏿‍♀' => 'хӗрарӑм пуҫ таять: сӑран тӗксӗм тонӗ',
    '🤦🏻‍♂' => 'арҫын сӑмах пултарулӑхне ҫухатрӗ: сӑран ҫутӑ тӗсӗ',
    '🤦🏼‍♂' => 'арҫын сӑмах пултарулӑхне ҫухатрӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤦🏽‍♂' => 'арҫын сӑмах пултарулӑхне ҫухатрӗ: сӑран вӑтам тонӗ',
    '🤦🏾‍♂' => 'арҫын сӑмах пултарулӑхне ҫухатрӗ: сӑран вӑтам тӗксӗм тонӗ',
    '🤦🏿‍♂' => 'арҫын сӑмах пултарулӑхне ҫухатрӗ: сӑран тӗксӗм тонӗ',
    '🤦🏻‍♀' => 'хӗрарӑм сӑмах пултарулӑхне ҫухатрӗ: сӑран ҫутӑ тӗсӗ',
    '🤦🏼‍♀' => 'хӗрарӑм сӑмах пултарулӑхне ҫухатрӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤦🏽‍♀' => 'хӗрарӑм сӑмах пултарулӑхне ҫухатрӗ: сӑран вӑтам тонӗ',
    '🤦🏾‍♀' => 'хӗрарӑм сӑмах пултарулӑхне ҫухатрӗ: сӑран вӑтам тӗксӗм тонӗ',
    '🤦🏿‍♀' => 'хӗрарӑм сӑмах пултарулӑхне ҫухатрӗ: сӑран тӗксӗм тонӗ',
    '🤷🏻‍♂' => 'арҫын хулпуҫҫисене сиктерет: сӑран ҫутӑ тӗсӗ',
    '🤷🏼‍♂' => 'арҫын хулпуҫҫисене сиктерет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤷🏽‍♂' => 'арҫын хулпуҫҫисене сиктерет: сӑран вӑтам тонӗ',
    '🤷🏾‍♂' => 'арҫын хулпуҫҫисене сиктерет: сӑран вӑтам тӗксӗм тонӗ',
    '🤷🏿‍♂' => 'арҫын хулпуҫҫисене сиктерет: сӑран тӗксӗм тонӗ',
    '🤷🏻‍♀' => 'хӗрарӑм хулпуҫҫисене сиктеркелет: сӑран ҫутӑ тӗсӗ',
    '🤷🏼‍♀' => 'хӗрарӑм хулпуҫҫисене сиктеркелет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤷🏽‍♀' => 'хӗрарӑм хулпуҫҫисене сиктеркелет: сӑран вӑтам тонӗ',
    '🤷🏾‍♀' => 'хӗрарӑм хулпуҫҫисене сиктеркелет: сӑран вӑтам тӗксӗм тонӗ',
    '🤷🏿‍♀' => 'хӗрарӑм хулпуҫҫисене сиктеркелет: сӑран тӗксӗм тонӗ',
    '🧑🏻‍⚕' => 'медицина работникӗ: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍⚕' => 'медицина работникӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍⚕' => 'медицина работникӗ: сӑран вӑтам тонӗ',
    '🧑🏾‍⚕' => 'медицина работникӗ: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍⚕' => 'медицина работникӗ: сӑран тӗксӗм тонӗ',
    '👨🏻‍⚕' => 'врач: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍⚕' => 'врач: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍⚕' => 'врач: сӑран вӑтам тонӗ',
    '👨🏾‍⚕' => 'врач: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍⚕' => 'врач: сӑран тӗксӗм тонӗ',
    '👩🏻‍⚕' => 'хӗрарӑм-медицина ӗҫекенӗ: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍⚕' => 'хӗрарӑм-медицина ӗҫекенӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍⚕' => 'хӗрарӑм-медицина ӗҫекенӗ: сӑран вӑтам тонӗ',
    '👩🏾‍⚕' => 'хӗрарӑм-медицина ӗҫекенӗ: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍⚕' => 'хӗрарӑм-медицина ӗҫекенӗ: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🎓' => 'вӗренекен: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🎓' => 'вӗренекен: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🎓' => 'вӗренекен: сӑран вӑтам тонӗ',
    '🧑🏾‍🎓' => 'вӗренекен: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🎓' => 'вӗренекен: сӑран тӗксӗм тонӗ',
    '👨🏻‍🎓' => 'студент: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🎓' => 'студент: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🎓' => 'студент: сӑран вӑтам тонӗ',
    '👨🏾‍🎓' => 'студент: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🎓' => 'студент: сӑран тӗксӗм тонӗ',
    '👩🏻‍🎓' => 'хӗрарӑм-студентка: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🎓' => 'хӗрарӑм-студентка: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🎓' => 'хӗрарӑм-студентка: сӑран вӑтам тонӗ',
    '👩🏾‍🎓' => 'хӗрарӑм-студентка: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🎓' => 'хӗрарӑм-студентка: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🏫' => 'педагог: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🏫' => 'педагог: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🏫' => 'педагог: сӑран вӑтам тонӗ',
    '🧑🏾‍🏫' => 'педагог: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🏫' => 'педагог: сӑран тӗксӗм тонӗ',
    '👨🏻‍🏫' => 'учитель: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🏫' => 'учитель: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🏫' => 'учитель: сӑран вӑтам тонӗ',
    '👨🏾‍🏫' => 'учитель: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🏫' => 'учитель: сӑран тӗксӗм тонӗ',
    '👩🏻‍🏫' => 'учительница: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🏫' => 'учительница: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🏫' => 'учительница: сӑран вӑтам тонӗ',
    '👩🏾‍🏫' => 'учительница: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🏫' => 'учительница: сӑран тӗксӗм тонӗ',
    '🧑🏻‍⚖' => 'судья: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍⚖' => 'судья: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍⚖' => 'судья: сӑран вӑтам тонӗ',
    '🧑🏾‍⚖' => 'судья: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍⚖' => 'судья: сӑран тӗксӗм тонӗ',
    '👨🏻‍⚖' => 'арҫын-судья: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍⚖' => 'арҫын-судья: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍⚖' => 'арҫын-судья: сӑран вӑтам тонӗ',
    '👨🏾‍⚖' => 'арҫын-судья: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍⚖' => 'арҫын-судья: сӑран тӗксӗм тонӗ',
    '👩🏻‍⚖' => 'хӗрарӑм-судья: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍⚖' => 'хӗрарӑм-судья: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍⚖' => 'хӗрарӑм-судья: сӑран вӑтам тонӗ',
    '👩🏾‍⚖' => 'хӗрарӑм-судья: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍⚖' => 'хӗрарӑм-судья: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🌾' => 'фермер: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🌾' => 'фермер: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🌾' => 'фермер: сӑран вӑтам тонӗ',
    '🧑🏾‍🌾' => 'фермер: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🌾' => 'фермер: сӑран тӗксӗм тонӗ',
    '👨🏻‍🌾' => 'фермер арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🌾' => 'фермер арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🌾' => 'фермер арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🌾' => 'фермер арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🌾' => 'фермер арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🌾' => 'фермер хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🌾' => 'фермер хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🌾' => 'фермер хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🌾' => 'фермер хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🌾' => 'фермер хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🍳' => 'повар: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🍳' => 'повар: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🍳' => 'повар: сӑран вӑтам тонӗ',
    '🧑🏾‍🍳' => 'повар: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🍳' => 'повар: сӑран тӗксӗм тонӗ',
    '👨🏻‍🍳' => 'повар арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🍳' => 'повар арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🍳' => 'повар арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🍳' => 'повар арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🍳' => 'повар арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🍳' => 'апат пӗҫерекен хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🍳' => 'апат пӗҫерекен хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🍳' => 'апат пӗҫерекен хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🍳' => 'апат пӗҫерекен хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🍳' => 'апат пӗҫерекен хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🔧' => 'механик: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🔧' => 'механик: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🔧' => 'механик: сӑран вӑтам тонӗ',
    '🧑🏾‍🔧' => 'механик: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🔧' => 'механик: сӑран тӗксӗм тонӗ',
    '👨🏻‍🔧' => 'механик арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🔧' => 'механик арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🔧' => 'механик арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🔧' => 'механик арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🔧' => 'механик арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🔧' => 'механик хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🔧' => 'механик хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🔧' => 'механик хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🔧' => 'механик хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🔧' => 'механик хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🏭' => 'рабочи: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🏭' => 'рабочи: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🏭' => 'рабочи: сӑран вӑтам тонӗ',
    '🧑🏾‍🏭' => 'рабочи: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🏭' => 'рабочи: сӑран тӗксӗм тонӗ',
    '👨🏻‍🏭' => 'арҫын-рабочи: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🏭' => 'арҫын-рабочи: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🏭' => 'арҫын-рабочи: сӑран вӑтам тонӗ',
    '👨🏾‍🏭' => 'арҫын-рабочи: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🏭' => 'арҫын-рабочи: сӑран тӗксӗм тонӗ',
    '👩🏻‍🏭' => 'фабрикара ӗҫлекен хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🏭' => 'фабрикара ӗҫлекен хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🏭' => 'фабрикара ӗҫлекен хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🏭' => 'фабрикара ӗҫлекен хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🏭' => 'фабрикара ӗҫлекен хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍💼' => 'офис работникӗ: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍💼' => 'офис работникӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍💼' => 'офис работникӗ: сӑран вӑтам тонӗ',
    '🧑🏾‍💼' => 'офис работникӗ: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍💼' => 'офис работникӗ: сӑран тӗксӗм тонӗ',
    '👨🏻‍💼' => 'офис работникӗ-арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍💼' => 'офис работникӗ-арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍💼' => 'офис работникӗ-арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍💼' => 'офис работникӗ-арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍💼' => 'офис работникӗ-арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍💼' => 'хӗрарӑм-офис работникӗ: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍💼' => 'хӗрарӑм-офис работникӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍💼' => 'хӗрарӑм-офис работникӗ: сӑран вӑтам тонӗ',
    '👩🏾‍💼' => 'хӗрарӑм-офис работникӗ: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍💼' => 'хӗрарӑм-офис работникӗ: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🔬' => 'ученӑй: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🔬' => 'ученӑй: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🔬' => 'ученӑй: сӑран вӑтам тонӗ',
    '🧑🏾‍🔬' => 'ученӑй: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🔬' => 'ученӑй: сӑран тӗксӗм тонӗ',
    '👨🏻‍🔬' => 'ученӑй арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🔬' => 'ученӑй арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🔬' => 'ученӑй арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🔬' => 'ученӑй арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🔬' => 'ученӑй арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🔬' => 'ученӑй хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🔬' => 'ученӑй хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🔬' => 'ученӑй хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🔬' => 'ученӑй хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🔬' => 'ученӑй хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍💻' => 'инженер: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍💻' => 'инженер: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍💻' => 'инженер: сӑран вӑтам тонӗ',
    '🧑🏾‍💻' => 'инженер: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍💻' => 'инженер: сӑран тӗксӗм тонӗ',
    '👨🏻‍💻' => 'инженер арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍💻' => 'инженер арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍💻' => 'инженер арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍💻' => 'инженер арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍💻' => 'инженер арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍💻' => 'технолог хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍💻' => 'технолог хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍💻' => 'технолог хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍💻' => 'технолог хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍💻' => 'технолог хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🎤' => 'юрӑҫӑ: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🎤' => 'юрӑҫӑ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🎤' => 'юрӑҫӑ: сӑран вӑтам тонӗ',
    '🧑🏾‍🎤' => 'юрӑҫӑ: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🎤' => 'юрӑҫӑ: сӑран тӗксӗм тонӗ',
    '👨🏻‍🎤' => 'юрӑҫӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🎤' => 'юрӑҫӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🎤' => 'юрӑҫӑ арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🎤' => 'юрӑҫӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🎤' => 'юрӑҫӑ арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🎤' => 'юрӑҫӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🎤' => 'юрӑҫӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🎤' => 'юрӑҫӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🎤' => 'юрӑҫӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🎤' => 'юрӑҫӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🎨' => 'художник: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🎨' => 'художник: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🎨' => 'художник: сӑран вӑтам тонӗ',
    '🧑🏾‍🎨' => 'художник: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🎨' => 'художник: сӑран тӗксӗм тонӗ',
    '👨🏻‍🎨' => 'художник арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🎨' => 'художник арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🎨' => 'художник арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🎨' => 'художник арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🎨' => 'художник арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🎨' => 'художница: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🎨' => 'художница: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🎨' => 'художница: сӑран вӑтам тонӗ',
    '👩🏾‍🎨' => 'художница: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🎨' => 'художница: сӑран тӗксӗм тонӗ',
    '🧑🏻‍✈' => 'пилот: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍✈' => 'пилот: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍✈' => 'пилот: сӑран вӑтам тонӗ',
    '🧑🏾‍✈' => 'пилот: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍✈' => 'пилот: сӑран тӗксӗм тонӗ',
    '👨🏻‍✈' => 'пилот арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍✈' => 'пилот арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍✈' => 'пилот арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍✈' => 'пилот арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍✈' => 'пилот арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍✈' => 'пилот хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍✈' => 'пилот хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍✈' => 'пилот хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍✈' => 'пилот хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍✈' => 'пилот хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🚀' => 'космонавт: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🚀' => 'космонавт: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🚀' => 'космонавт: сӑран вӑтам тонӗ',
    '🧑🏾‍🚀' => 'космонавт: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🚀' => 'космонавт: сӑран тӗксӗм тонӗ',
    '👨🏻‍🚀' => 'космонавт арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🚀' => 'космонавт арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🚀' => 'космонавт арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🚀' => 'космонавт арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🚀' => 'космонавт арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🚀' => 'космонавт хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🚀' => 'космонавт хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🚀' => 'космонавт хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🚀' => 'космонавт хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🚀' => 'космонавт хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🚒' => 'пушар: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🚒' => 'пушар: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🚒' => 'пушар: сӑран вӑтам тонӗ',
    '🧑🏾‍🚒' => 'пушар: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🚒' => 'пушар: сӑран тӗксӗм тонӗ',
    '👨🏻‍🚒' => 'пушар арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🚒' => 'пушар арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🚒' => 'пушар арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🚒' => 'пушар арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🚒' => 'пушар арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🚒' => 'пушартан хӑтаракан хӗрарӑмӗ: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🚒' => 'пушартан хӑтаракан хӗрарӑмӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🚒' => 'пушартан хӑтаракан хӗрарӑмӗ: сӑран вӑтам тонӗ',
    '👩🏾‍🚒' => 'пушартан хӑтаракан хӗрарӑмӗ: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🚒' => 'пушартан хӑтаракан хӗрарӑмӗ: сӑран тӗксӗм тонӗ',
    '👮🏻‍♂' => 'полицейски арҫын: сӑран ҫутӑ тӗсӗ',
    '👮🏼‍♂' => 'полицейски арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👮🏽‍♂' => 'полицейски арҫын: сӑран вӑтам тонӗ',
    '👮🏾‍♂' => 'полицейски арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👮🏿‍♂' => 'полицейски арҫын: сӑран тӗксӗм тонӗ',
    '👮🏻‍♀' => 'полицейски хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👮🏼‍♀' => 'полицейски хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👮🏽‍♀' => 'полицейски хӗрарӑм: сӑран вӑтам тонӗ',
    '👮🏾‍♀' => 'полицейски хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👮🏿‍♀' => 'полицейски хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🕵🏻‍♂' => 'арҫын-детектив: сӑран ҫутӑ тӗсӗ',
    '🕵🏼‍♂' => 'арҫын-детектив: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🕵🏽‍♂' => 'арҫын-детектив: сӑран вӑтам тонӗ',
    '🕵🏾‍♂' => 'арҫын-детектив: сӑран вӑтам тӗксӗм тонӗ',
    '🕵🏿‍♂' => 'арҫын-детектив: сӑран тӗксӗм тонӗ',
    '🕵🏻‍♀' => 'детектив хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🕵🏼‍♀' => 'детектив хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🕵🏽‍♀' => 'детектив хӗрарӑм: сӑран вӑтам тонӗ',
    '🕵🏾‍♀' => 'детектив хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🕵🏿‍♀' => 'детектив хӗрарӑм: сӑран тӗксӗм тонӗ',
    '💂🏻‍♂' => 'гвардеец арҫын: сӑран ҫутӑ тӗсӗ',
    '💂🏼‍♂' => 'гвардеец арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💂🏽‍♂' => 'гвардеец арҫын: сӑран вӑтам тонӗ',
    '💂🏾‍♂' => 'гвардеец арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '💂🏿‍♂' => 'гвардеец арҫын: сӑран тӗксӗм тонӗ',
    '💂🏻‍♀' => 'сыхлакан хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '💂🏼‍♀' => 'сыхлакан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💂🏽‍♀' => 'сыхлакан хӗрарӑм: сӑран вӑтам тонӗ',
    '💂🏾‍♀' => 'сыхлакан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '💂🏿‍♀' => 'сыхлакан хӗрарӑм: сӑран тӗксӗм тонӗ',
    '👷🏻‍♂' => 'строитель арҫын: сӑран ҫутӑ тӗсӗ',
    '👷🏼‍♂' => 'строитель арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👷🏽‍♂' => 'строитель арҫын: сӑран вӑтам тонӗ',
    '👷🏾‍♂' => 'строитель арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👷🏿‍♂' => 'строитель арҫын: сӑран тӗксӗм тонӗ',
    '👷🏻‍♀' => 'ҫуртсем тӑвакан хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👷🏼‍♀' => 'ҫуртсем тӑвакан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👷🏽‍♀' => 'ҫуртсем тӑвакан хӗрарӑм: сӑран вӑтам тонӗ',
    '👷🏾‍♀' => 'ҫуртсем тӑвакан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👷🏿‍♀' => 'ҫуртсем тӑвакан хӗрарӑм: сӑран тӗксӗм тонӗ',
    '👳🏻‍♂' => 'тюрбанлӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '👳🏼‍♂' => 'тюрбанлӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👳🏽‍♂' => 'тюрбанлӑ арҫын: сӑран вӑтам тонӗ',
    '👳🏾‍♂' => 'тюрбанлӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👳🏿‍♂' => 'тюрбанлӑ арҫын: сӑран тӗксӗм тонӗ',
    '👳🏻‍♀' => 'пуҫне тюрбан ҫыхнӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👳🏼‍♀' => 'пуҫне тюрбан ҫыхнӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👳🏽‍♀' => 'пуҫне тюрбан ҫыхнӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '👳🏾‍♀' => 'пуҫне тюрбан ҫыхнӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👳🏿‍♀' => 'пуҫне тюрбан ҫыхнӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🤵🏻‍♂' => 'смокинглӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '🤵🏼‍♂' => 'смокинглӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤵🏽‍♂' => 'смокинглӑ арҫын: сӑран вӑтам тонӗ',
    '🤵🏾‍♂' => 'смокинглӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🤵🏿‍♂' => 'смокинглӑ арҫын: сӑран тӗксӗм тонӗ',
    '🤵🏻‍♀' => 'смокинглӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🤵🏼‍♀' => 'смокинглӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤵🏽‍♀' => 'смокинглӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '🤵🏾‍♀' => 'смокинглӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🤵🏿‍♀' => 'смокинглӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '👰🏻‍♂' => 'фат тӑхӑннӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '👰🏼‍♂' => 'фат тӑхӑннӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👰🏽‍♂' => 'фат тӑхӑннӑ арҫын: сӑран вӑтам тонӗ',
    '👰🏾‍♂' => 'фат тӑхӑннӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👰🏿‍♂' => 'фат тӑхӑннӑ арҫын: сӑран тӗксӗм тонӗ',
    '👰🏻‍♀' => 'вуальпа витӗннӗ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👰🏼‍♀' => 'вуальпа витӗннӗ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👰🏽‍♀' => 'вуальпа витӗннӗ хӗрарӑм: сӑран вӑтам тонӗ',
    '👰🏾‍♀' => 'вуальпа витӗннӗ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👰🏿‍♀' => 'вуальпа витӗннӗ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '👩🏻‍🍼' => 'хӗрарӑм ачана апатлантарать: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🍼' => 'хӗрарӑм ачана апатлантарать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🍼' => 'хӗрарӑм ачана апатлантарать: сӑран вӑтам тонӗ',
    '👩🏾‍🍼' => 'хӗрарӑм ачана апатлантарать: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🍼' => 'хӗрарӑм ачана апатлантарать: сӑран тӗксӗм тонӗ',
    '👨🏻‍🍼' => 'тӑрантаракан арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🍼' => 'тӑрантаракан арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🍼' => 'тӑрантаракан арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🍼' => 'тӑрантаракан арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🍼' => 'тӑрантаракан арҫын: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🍼' => 'тӑрантаракан ҫын: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🍼' => 'тӑрантаракан ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🍼' => 'тӑрантаракан ҫын: сӑран вӑтам тонӗ',
    '🧑🏾‍🍼' => 'тӑрантаракан ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🍼' => 'тӑрантаракан ҫын: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🎄' => 'Санта: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🎄' => 'Санта: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🎄' => 'Санта: сӑран вӑтам тонӗ',
    '🧑🏾‍🎄' => 'Санта: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🎄' => 'Санта: сӑран тӗксӗм тонӗ',
    '🦸🏻‍♂' => 'супергер арҫын: сӑран ҫутӑ тӗсӗ',
    '🦸🏼‍♂' => 'супергер арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🦸🏽‍♂' => 'супергер арҫын: сӑран вӑтам тонӗ',
    '🦸🏾‍♂' => 'супергер арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🦸🏿‍♂' => 'супергер арҫын: сӑран тӗксӗм тонӗ',
    '🦸🏻‍♀' => 'патӑр хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🦸🏼‍♀' => 'патӑр хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🦸🏽‍♀' => 'патӑр хӗрарӑм: сӑран вӑтам тонӗ',
    '🦸🏾‍♀' => 'патӑр хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🦸🏿‍♀' => 'патӑр хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🦹🏻‍♂' => 'йӗксӗк арҫын: сӑран ҫутӑ тӗсӗ',
    '🦹🏼‍♂' => 'йӗксӗк арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🦹🏽‍♂' => 'йӗксӗк арҫын: сӑран вӑтам тонӗ',
    '🦹🏾‍♂' => 'йӗксӗк арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🦹🏿‍♂' => 'йӗксӗк арҫын: сӑран тӗксӗм тонӗ',
    '🦹🏻‍♀' => 'хӑруш усал хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🦹🏼‍♀' => 'хӑруш усал хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🦹🏽‍♀' => 'хӑруш усал хӗрарӑм: сӑран вӑтам тонӗ',
    '🦹🏾‍♀' => 'хӑруш усал хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🦹🏿‍♀' => 'хӑруш усал хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧙🏻‍♂' => 'асамҫӑ: сӑран ҫутӑ тӗсӗ',
    '🧙🏼‍♂' => 'асамҫӑ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧙🏽‍♂' => 'асамҫӑ: сӑран вӑтам тонӗ',
    '🧙🏾‍♂' => 'асамҫӑ: сӑран вӑтам тӗксӗм тонӗ',
    '🧙🏿‍♂' => 'асамҫӑ: сӑран тӗксӗм тонӗ',
    '🧙🏻‍♀' => 'хӗрарӑм тухатмӑш: сӑран ҫутӑ тӗсӗ',
    '🧙🏼‍♀' => 'хӗрарӑм тухатмӑш: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧙🏽‍♀' => 'хӗрарӑм тухатмӑш: сӑран вӑтам тонӗ',
    '🧙🏾‍♀' => 'хӗрарӑм тухатмӑш: сӑран вӑтам тӗксӗм тонӗ',
    '🧙🏿‍♀' => 'хӗрарӑм тухатмӑш: сӑран тӗксӗм тонӗ',
    '🧚🏻‍♂' => 'фея арҫын: сӑран ҫутӑ тӗсӗ',
    '🧚🏼‍♂' => 'фея арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧚🏽‍♂' => 'фея арҫын: сӑран вӑтам тонӗ',
    '🧚🏾‍♂' => 'фея арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧚🏿‍♂' => 'фея арҫын: сӑран тӗксӗм тонӗ',
    '🧚🏻‍♀' => 'фея хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧚🏼‍♀' => 'фея хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧚🏽‍♀' => 'фея хӗрарӑм: сӑран вӑтам тонӗ',
    '🧚🏾‍♀' => 'фея хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧚🏿‍♀' => 'фея хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧛🏻‍♂' => 'арҫын-вампир: сӑран ҫутӑ тӗсӗ',
    '🧛🏼‍♂' => 'арҫын-вампир: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧛🏽‍♂' => 'арҫын-вампир: сӑран вӑтам тонӗ',
    '🧛🏾‍♂' => 'арҫын-вампир: сӑран вӑтам тӗксӗм тонӗ',
    '🧛🏿‍♂' => 'арҫын-вампир: сӑран тӗксӗм тонӗ',
    '🧛🏻‍♀' => 'хӗрарӑм-вампир: сӑран ҫутӑ тӗсӗ',
    '🧛🏼‍♀' => 'хӗрарӑм-вампир: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧛🏽‍♀' => 'хӗрарӑм-вампир: сӑран вӑтам тонӗ',
    '🧛🏾‍♀' => 'хӗрарӑм-вампир: сӑран вӑтам тӗксӗм тонӗ',
    '🧛🏿‍♀' => 'хӗрарӑм-вампир: сӑран тӗксӗм тонӗ',
    '🧜🏻‍♂' => 'тритон: сӑран ҫутӑ тӗсӗ',
    '🧜🏼‍♂' => 'тритон: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧜🏽‍♂' => 'тритон: сӑран вӑтам тонӗ',
    '🧜🏾‍♂' => 'тритон: сӑран вӑтам тӗксӗм тонӗ',
    '🧜🏿‍♂' => 'тритон: сӑран тӗксӗм тонӗ',
    '🧜🏻‍♀' => 'вутӑш хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧜🏼‍♀' => 'вутӑш хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧜🏽‍♀' => 'вутӑш хӗрарӑм: сӑран вӑтам тонӗ',
    '🧜🏾‍♀' => 'вутӑш хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧜🏿‍♀' => 'вутӑш хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧝🏻‍♂' => 'эльф арҫын: сӑран ҫутӑ тӗсӗ',
    '🧝🏼‍♂' => 'эльф арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧝🏽‍♂' => 'эльф арҫын: сӑран вӑтам тонӗ',
    '🧝🏾‍♂' => 'эльф арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧝🏿‍♂' => 'эльф арҫын: сӑран тӗксӗм тонӗ',
    '🧝🏻‍♀' => 'эльф хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧝🏼‍♀' => 'эльф хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧝🏽‍♀' => 'эльф хӗрарӑм: сӑран вӑтам тонӗ',
    '🧝🏾‍♀' => 'эльф хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧝🏿‍♀' => 'эльф хӗрарӑм: сӑран тӗксӗм тонӗ',
    '💆🏻‍♂' => 'арҫын питне массӑлать: сӑран ҫутӑ тӗсӗ',
    '💆🏼‍♂' => 'арҫын питне массӑлать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💆🏽‍♂' => 'арҫын питне массӑлать: сӑран вӑтам тонӗ',
    '💆🏾‍♂' => 'арҫын питне массӑлать: сӑран вӑтам тӗксӗм тонӗ',
    '💆🏿‍♂' => 'арҫын питне массӑлать: сӑран тӗксӗм тонӗ',
    '💆🏻‍♀' => 'хӗрарӑма массаж тӑваҫҫӗ: сӑран ҫутӑ тӗсӗ',
    '💆🏼‍♀' => 'хӗрарӑма массаж тӑваҫҫӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💆🏽‍♀' => 'хӗрарӑма массаж тӑваҫҫӗ: сӑран вӑтам тонӗ',
    '💆🏾‍♀' => 'хӗрарӑма массаж тӑваҫҫӗ: сӑран вӑтам тӗксӗм тонӗ',
    '💆🏿‍♀' => 'хӗрарӑма массаж тӑваҫҫӗ: сӑран тӗксӗм тонӗ',
    '💇🏻‍♂' => 'парикмахер арҫын: сӑран ҫутӑ тӗсӗ',
    '💇🏼‍♂' => 'парикмахер арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💇🏽‍♂' => 'парикмахер арҫын: сӑран вӑтам тонӗ',
    '💇🏾‍♂' => 'парикмахер арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '💇🏿‍♂' => 'парикмахер арҫын: сӑран тӗксӗм тонӗ',
    '💇🏻‍♀' => 'хӗрарӑм ҫӳҫне кастарать: сӑран ҫутӑ тӗсӗ',
    '💇🏼‍♀' => 'хӗрарӑм ҫӳҫне кастарать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💇🏽‍♀' => 'хӗрарӑм ҫӳҫне кастарать: сӑран вӑтам тонӗ',
    '💇🏾‍♀' => 'хӗрарӑм ҫӳҫне кастарать: сӑран вӑтам тӗксӗм тонӗ',
    '💇🏿‍♀' => 'хӗрарӑм ҫӳҫне кастарать: сӑран тӗксӗм тонӗ',
    '🚶🏻‍♂' => 'арҫын килет: сӑран ҫутӑ тӗсӗ',
    '🚶🏼‍♂' => 'арҫын килет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚶🏽‍♂' => 'арҫын килет: сӑран вӑтам тонӗ',
    '🚶🏾‍♂' => 'арҫын килет: сӑран вӑтам тӗксӗм тонӗ',
    '🚶🏿‍♂' => 'арҫын килет: сӑран тӗксӗм тонӗ',
    '🚶🏻‍♀' => 'хӗрарӑм килет: сӑран ҫутӑ тӗсӗ',
    '🚶🏼‍♀' => 'хӗрарӑм килет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚶🏽‍♀' => 'хӗрарӑм килет: сӑран вӑтам тонӗ',
    '🚶🏾‍♀' => 'хӗрарӑм килет: сӑран вӑтам тӗксӗм тонӗ',
    '🚶🏿‍♀' => 'хӗрарӑм килет: сӑран тӗксӗм тонӗ',
    '🚶🏻‍➡' => 'ҫын килет: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🚶🏼‍➡' => 'ҫын килет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🚶🏽‍➡' => 'ҫын килет: сӑран вӑтам тонӗ сылтӑмалла',
    '🚶🏾‍➡' => 'ҫын килет: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🚶🏿‍➡' => 'ҫын килет: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🧍🏻‍♂' => 'арҫын тӑрать: сӑран ҫутӑ тӗсӗ',
    '🧍🏼‍♂' => 'арҫын тӑрать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧍🏽‍♂' => 'арҫын тӑрать: сӑран вӑтам тонӗ',
    '🧍🏾‍♂' => 'арҫын тӑрать: сӑран вӑтам тӗксӗм тонӗ',
    '🧍🏿‍♂' => 'арҫын тӑрать: сӑран тӗксӗм тонӗ',
    '🧍🏻‍♀' => 'хӗрарӑм тӑрать: сӑран ҫутӑ тӗсӗ',
    '🧍🏼‍♀' => 'хӗрарӑм тӑрать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧍🏽‍♀' => 'хӗрарӑм тӑрать: сӑран вӑтам тонӗ',
    '🧍🏾‍♀' => 'хӗрарӑм тӑрать: сӑран вӑтам тӗксӗм тонӗ',
    '🧍🏿‍♀' => 'хӗрарӑм тӑрать: сӑран тӗксӗм тонӗ',
    '🧎🏻‍♂' => 'арҫын чӗркуҫҫи ҫинче: сӑран ҫутӑ тӗсӗ',
    '🧎🏼‍♂' => 'арҫын чӗркуҫҫи ҫинче: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧎🏽‍♂' => 'арҫын чӗркуҫҫи ҫинче: сӑран вӑтам тонӗ',
    '🧎🏾‍♂' => 'арҫын чӗркуҫҫи ҫинче: сӑран вӑтам тӗксӗм тонӗ',
    '🧎🏿‍♂' => 'арҫын чӗркуҫҫи ҫинче: сӑран тӗксӗм тонӗ',
    '🧎🏻‍♀' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧎🏼‍♀' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧎🏽‍♀' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: сӑран вӑтам тонӗ',
    '🧎🏾‍♀' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧎🏿‍♀' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧎🏻‍➡' => 'чӗркуҫленсе ларнӑ ҫын: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🧎🏼‍➡' => 'чӗркуҫленсе ларнӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🧎🏽‍➡' => 'чӗркуҫленсе ларнӑ ҫын: сӑран вӑтам тонӗ сылтӑмалла',
    '🧎🏾‍➡' => 'чӗркуҫленсе ларнӑ ҫын: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🧎🏿‍➡' => 'чӗркуҫленсе ларнӑ ҫын: сӑран тӗксӗм тонӗ сылтӑмалла',
    '🧑🏻‍🦯' => 'шурӑ туялӑ ҫын: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🦯' => 'шурӑ туялӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🦯' => 'шурӑ туялӑ ҫын: сӑран вӑтам тонӗ',
    '🧑🏾‍🦯' => 'шурӑ туялӑ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🦯' => 'шурӑ туялӑ ҫын: сӑран тӗксӗм тонӗ',
    '👨🏻‍🦯' => 'утмалли туя: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🦯' => 'утмалли туя: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🦯' => 'утмалли туя: сӑран вӑтам тонӗ',
    '👨🏾‍🦯' => 'утмалли туя: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🦯' => 'утмалли туя: сӑран тӗксӗм тонӗ',
    '👩🏻‍🦯' => 'шур патаклӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🦯' => 'шур патаклӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🦯' => 'шур патаклӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🦯' => 'шур патаклӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🦯' => 'шур патаклӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🦼' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🦼' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🦼' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: сӑран вӑтам тонӗ',
    '🧑🏾‍🦼' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🦼' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын: сӑран тӗксӗм тонӗ',
    '👨🏻‍🦼' => 'электричество кресли-коляска тӑхӑннӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🦼' => 'электричество кресли-коляска тӑхӑннӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🦼' => 'электричество кресли-коляска тӑхӑннӑ арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🦼' => 'электричество кресли-коляска тӑхӑннӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🦼' => 'электричество кресли-коляска тӑхӑннӑ арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🦼' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🦼' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🦼' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🦼' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🦼' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑🏻‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: сӑран ҫутӑ тӗсӗ',
    '🧑🏼‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: сӑран вӑтам тонӗ',
    '🧑🏾‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын: сӑран тӗксӗм тонӗ',
    '👨🏻‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: сӑран вӑтам тонӗ',
    '👨🏾‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын: сӑран тӗксӗм тонӗ',
    '👩🏻‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🏃🏻‍♂' => 'арҫын чупать: сӑран ҫутӑ тӗсӗ',
    '🏃🏼‍♂' => 'арҫын чупать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏃🏽‍♂' => 'арҫын чупать: сӑран вӑтам тонӗ',
    '🏃🏾‍♂' => 'арҫын чупать: сӑран вӑтам тӗксӗм тонӗ',
    '🏃🏿‍♂' => 'арҫын чупать: сӑран тӗксӗм тонӗ',
    '🏃🏻‍♀' => 'чупакан хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🏃🏼‍♀' => 'чупакан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏃🏽‍♀' => 'чупакан хӗрарӑм: сӑран вӑтам тонӗ',
    '🏃🏾‍♀' => 'чупакан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🏃🏿‍♀' => 'чупакан хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🏃🏻‍➡' => 'ҫын чупать: сӑран ҫутӑ тӗсӗ сылтӑмалла',
    '🏃🏼‍➡' => 'ҫын чупать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ сылтӑмалла',
    '🏃🏽‍➡' => 'ҫын чупать: сӑран вӑтам тонӗ сылтӑмалла',
    '🏃🏾‍➡' => 'ҫын чупать: сӑран вӑтам тӗксӗм тонӗ сылтӑмалла',
    '🏃🏿‍➡' => 'ҫын чупать: сӑран тӗксӗм тонӗ сылтӑмалла',
    '👯🏻‍♀' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ',
    '👯🏼‍♀' => 'мулкач хӑлхаллӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👯🏽‍♀' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тонӗ',
    '👯🏾‍♀' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ',
    '👯🏿‍♀' => 'мулкач хӑлхаллӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ',
    '👯🏻‍♂' => 'мулкач хӑлхаллӑ арҫынсем: сӑран ҫутӑ тӗсӗ',
    '👯🏼‍♂' => 'мулкач хӑлхаллӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👯🏽‍♂' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тонӗ',
    '👯🏾‍♂' => 'мулкач хӑлхаллӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ',
    '👯🏿‍♂' => 'мулкач хӑлхаллӑ арҫынсем: сӑран тӗксӗм тонӗ',
    '🧖🏻‍♂' => 'мунча арҫын: сӑран ҫутӑ тӗсӗ',
    '🧖🏼‍♂' => 'мунча арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧖🏽‍♂' => 'мунча арҫын: сӑран вӑтам тонӗ',
    '🧖🏾‍♂' => 'мунча арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧖🏿‍♂' => 'мунча арҫын: сӑран тӗксӗм тонӗ',
    '🧖🏻‍♀' => 'пӑчӑ пӳлӗмре хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧖🏼‍♀' => 'пӑчӑ пӳлӗмре хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧖🏽‍♀' => 'пӑчӑ пӳлӗмре хӗрарӑм: сӑран вӑтам тонӗ',
    '🧖🏾‍♀' => 'пӑчӑ пӳлӗмре хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧖🏿‍♀' => 'пӑчӑ пӳлӗмре хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧗🏻‍♂' => 'арҫын чул хысакӗ тӑрӑх хӑпарать: сӑран ҫутӑ тӗсӗ',
    '🧗🏼‍♂' => 'арҫын чул хысакӗ тӑрӑх хӑпарать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧗🏽‍♂' => 'арҫын чул хысакӗ тӑрӑх хӑпарать: сӑран вӑтам тонӗ',
    '🧗🏾‍♂' => 'арҫын чул хысакӗ тӑрӑх хӑпарать: сӑран вӑтам тӗксӗм тонӗ',
    '🧗🏿‍♂' => 'арҫын чул хысакӗ тӑрӑх хӑпарать: сӑран тӗксӗм тонӗ',
    '🧗🏻‍♀' => 'ту ҫине хӑпаракан хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧗🏼‍♀' => 'ту ҫине хӑпаракан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧗🏽‍♀' => 'ту ҫине хӑпаракан хӗрарӑм: сӑран вӑтам тонӗ',
    '🧗🏾‍♀' => 'ту ҫине хӑпаракан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧗🏿‍♀' => 'ту ҫине хӑпаракан хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🏌🏻‍♂' => 'арҫын гольф калать: сӑран ҫутӑ тӗсӗ',
    '🏌🏼‍♂' => 'арҫын гольф калать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏌🏽‍♂' => 'арҫын гольф калать: сӑран вӑтам тонӗ',
    '🏌🏾‍♂' => 'арҫын гольф калать: сӑран вӑтам тӗксӗм тонӗ',
    '🏌🏿‍♂' => 'арҫын гольф калать: сӑран тӗксӗм тонӗ',
    '🏌🏻‍♀' => 'хӗрарӑм гольф вылять: сӑран ҫутӑ тӗсӗ',
    '🏌🏼‍♀' => 'хӗрарӑм гольф вылять: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏌🏽‍♀' => 'хӗрарӑм гольф вылять: сӑран вӑтам тонӗ',
    '🏌🏾‍♀' => 'хӗрарӑм гольф вылять: сӑран вӑтам тӗксӗм тонӗ',
    '🏌🏿‍♀' => 'хӗрарӑм гольф вылять: сӑран тӗксӗм тонӗ',
    '🏄🏻‍♂' => 'серфингист: сӑран ҫутӑ тӗсӗ',
    '🏄🏼‍♂' => 'серфингист: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏄🏽‍♂' => 'серфингист: сӑран вӑтам тонӗ',
    '🏄🏾‍♂' => 'серфингист: сӑран вӑтам тӗксӗм тонӗ',
    '🏄🏿‍♂' => 'серфингист: сӑран тӗксӗм тонӗ',
    '🏄🏻‍♀' => 'серфингист хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🏄🏼‍♀' => 'серфингист хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏄🏽‍♀' => 'серфингист хӗрарӑм: сӑран вӑтам тонӗ',
    '🏄🏾‍♀' => 'серфингист хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🏄🏿‍♀' => 'серфингист хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🚣🏻‍♂' => 'кӗсменҫӗ: сӑран ҫутӑ тӗсӗ',
    '🚣🏼‍♂' => 'кӗсменҫӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚣🏽‍♂' => 'кӗсменҫӗ: сӑран вӑтам тонӗ',
    '🚣🏾‍♂' => 'кӗсменҫӗ: сӑран вӑтам тӗксӗм тонӗ',
    '🚣🏿‍♂' => 'кӗсменҫӗ: сӑран тӗксӗм тонӗ',
    '🚣🏻‍♀' => 'кӗсменҫӗ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🚣🏼‍♀' => 'кӗсменҫӗ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚣🏽‍♀' => 'кӗсменҫӗ хӗрарӑм: сӑран вӑтам тонӗ',
    '🚣🏾‍♀' => 'кӗсменҫӗ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🚣🏿‍♀' => 'кӗсменҫӗ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🏊🏻‍♂' => 'ишекен: сӑран ҫутӑ тӗсӗ',
    '🏊🏼‍♂' => 'ишекен: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏊🏽‍♂' => 'ишекен: сӑран вӑтам тонӗ',
    '🏊🏾‍♂' => 'ишекен: сӑран вӑтам тӗксӗм тонӗ',
    '🏊🏿‍♂' => 'ишекен: сӑран тӗксӗм тонӗ',
    '🏊🏻‍♀' => 'хӗрарӑм ишет: сӑран ҫутӑ тӗсӗ',
    '🏊🏼‍♀' => 'хӗрарӑм ишет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏊🏽‍♀' => 'хӗрарӑм ишет: сӑран вӑтам тонӗ',
    '🏊🏾‍♀' => 'хӗрарӑм ишет: сӑран вӑтам тӗксӗм тонӗ',
    '🏊🏿‍♀' => 'хӗрарӑм ишет: сӑран тӗксӗм тонӗ',
    '⛹🏻‍♂' => 'мечӗклӗ арҫын: сӑран ҫутӑ тӗсӗ',
    '⛹🏼‍♂' => 'мечӗклӗ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '⛹🏽‍♂' => 'мечӗклӗ арҫын: сӑран вӑтам тонӗ',
    '⛹🏾‍♂' => 'мечӗклӗ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '⛹🏿‍♂' => 'мечӗклӗ арҫын: сӑран тӗксӗм тонӗ',
    '⛹🏻‍♀' => 'тупӑ сиктерекен хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '⛹🏼‍♀' => 'тупӑ сиктерекен хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '⛹🏽‍♀' => 'тупӑ сиктерекен хӗрарӑм: сӑран вӑтам тонӗ',
    '⛹🏾‍♀' => 'тупӑ сиктерекен хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '⛹🏿‍♀' => 'тупӑ сиктерекен хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🏋🏻‍♂' => 'штангӑллӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '🏋🏼‍♂' => 'штангӑллӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏋🏽‍♂' => 'штангӑллӑ арҫын: сӑран вӑтам тонӗ',
    '🏋🏾‍♂' => 'штангӑллӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🏋🏿‍♂' => 'штангӑллӑ арҫын: сӑран тӗксӗм тонӗ',
    '🏋🏻‍♀' => 'йывӑр ҫӗклекен хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🏋🏼‍♀' => 'йывӑр ҫӗклекен хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏋🏽‍♀' => 'йывӑр ҫӗклекен хӗрарӑм: сӑран вӑтам тонӗ',
    '🏋🏾‍♀' => 'йывӑр ҫӗклекен хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🏋🏿‍♀' => 'йывӑр ҫӗклекен хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🚴🏻‍♂' => 'велосипедлӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '🚴🏼‍♂' => 'велосипедлӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚴🏽‍♂' => 'велосипедлӑ арҫын: сӑран вӑтам тонӗ',
    '🚴🏾‍♂' => 'велосипедлӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🚴🏿‍♂' => 'велосипедлӑ арҫын: сӑран тӗксӗм тонӗ',
    '🚴🏻‍♀' => 'велосипедлӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🚴🏼‍♀' => 'велосипедлӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚴🏽‍♀' => 'велосипедлӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '🚴🏾‍♀' => 'велосипедлӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🚴🏿‍♀' => 'велосипедлӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🚵🏻‍♂' => 'ту ҫинчи велосипедпа арҫын: сӑран ҫутӑ тӗсӗ',
    '🚵🏼‍♂' => 'ту ҫинчи велосипедпа арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚵🏽‍♂' => 'ту ҫинчи велосипедпа арҫын: сӑран вӑтам тонӗ',
    '🚵🏾‍♂' => 'ту ҫинчи велосипедпа арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🚵🏿‍♂' => 'ту ҫинчи велосипедпа арҫын: сӑран тӗксӗм тонӗ',
    '🚵🏻‍♀' => 'хӗрарӑм ту ҫинчи велосипедпа ярӑнать: сӑран ҫутӑ тӗсӗ',
    '🚵🏼‍♀' => 'хӗрарӑм ту ҫинчи велосипедпа ярӑнать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚵🏽‍♀' => 'хӗрарӑм ту ҫинчи велосипедпа ярӑнать: сӑран вӑтам тонӗ',
    '🚵🏾‍♀' => 'хӗрарӑм ту ҫинчи велосипедпа ярӑнать: сӑран вӑтам тӗксӗм тонӗ',
    '🚵🏿‍♀' => 'хӗрарӑм ту ҫинчи велосипедпа ярӑнать: сӑран тӗксӗм тонӗ',
    '🤸🏻‍♂' => 'акробат: сӑран ҫутӑ тӗсӗ',
    '🤸🏼‍♂' => 'акробат: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤸🏽‍♂' => 'акробат: сӑран вӑтам тонӗ',
    '🤸🏾‍♂' => 'акробат: сӑран вӑтам тӗксӗм тонӗ',
    '🤸🏿‍♂' => 'акробат: сӑран тӗксӗм тонӗ',
    '🤸🏻‍♀' => 'кустӑрма туса кӑтартакан хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🤸🏼‍♀' => 'кустӑрма туса кӑтартакан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤸🏽‍♀' => 'кустӑрма туса кӑтартакан хӗрарӑм: сӑран вӑтам тонӗ',
    '🤸🏾‍♀' => 'кустӑрма туса кӑтартакан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🤸🏿‍♀' => 'кустӑрма туса кӑтартакан хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🤼🏻‍♀' => 'хӗрарӑм кӗрешӗвӗ: сӑран ҫутӑ тӗсӗ',
    '🤼🏼‍♀' => 'хӗрарӑм кӗрешӗвӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤼🏽‍♀' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тонӗ',
    '🤼🏾‍♀' => 'хӗрарӑм кӗрешӗвӗ: сӑран вӑтам тӗксӗм тонӗ',
    '🤼🏿‍♀' => 'хӗрарӑм кӗрешӗвӗ: сӑран тӗксӗм тонӗ',
    '🤼🏻‍♂' => 'кӗрешӳҫӗ арҫынсем: сӑран ҫутӑ тӗсӗ',
    '🤼🏼‍♂' => 'кӗрешӳҫӗ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤼🏽‍♂' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тонӗ',
    '🤼🏾‍♂' => 'кӗрешӳҫӗ арҫынсем: сӑран вӑтам тӗксӗм тонӗ',
    '🤼🏿‍♂' => 'кӗрешӳҫӗ арҫынсем: сӑран тӗксӗм тонӗ',
    '🤽🏻‍♂' => 'арҫын шыв урай вылять: сӑран ҫутӑ тӗсӗ',
    '🤽🏼‍♂' => 'арҫын шыв урай вылять: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤽🏽‍♂' => 'арҫын шыв урай вылять: сӑран вӑтам тонӗ',
    '🤽🏾‍♂' => 'арҫын шыв урай вылять: сӑран вӑтам тӗксӗм тонӗ',
    '🤽🏿‍♂' => 'арҫын шыв урай вылять: сӑран тӗксӗм тонӗ',
    '🤽🏻‍♀' => 'шывра тупӑпӑ вылякан хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🤽🏼‍♀' => 'шывра тупӑпӑ вылякан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤽🏽‍♀' => 'шывра тупӑпӑ вылякан хӗрарӑм: сӑран вӑтам тонӗ',
    '🤽🏾‍♀' => 'шывра тупӑпӑ вылякан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🤽🏿‍♀' => 'шывра тупӑпӑ вылякан хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🤾🏻‍♂' => 'гандболист: сӑран ҫутӑ тӗсӗ',
    '🤾🏼‍♂' => 'гандболист: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤾🏽‍♂' => 'гандболист: сӑран вӑтам тонӗ',
    '🤾🏾‍♂' => 'гандболист: сӑран вӑтам тӗксӗм тонӗ',
    '🤾🏿‍♂' => 'гандболист: сӑран тӗксӗм тонӗ',
    '🤾🏻‍♀' => 'хӗрарӑм гандболла вылять: сӑран ҫутӑ тӗсӗ',
    '🤾🏼‍♀' => 'хӗрарӑм гандболла вылять: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤾🏽‍♀' => 'хӗрарӑм гандболла вылять: сӑран вӑтам тонӗ',
    '🤾🏾‍♀' => 'хӗрарӑм гандболла вылять: сӑран вӑтам тӗксӗм тонӗ',
    '🤾🏿‍♀' => 'хӗрарӑм гандболла вылять: сӑран тӗксӗм тонӗ',
    '🤹🏻‍♂' => 'жонглер арҫын: сӑран ҫутӑ тӗсӗ',
    '🤹🏼‍♂' => 'жонглер арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤹🏽‍♂' => 'жонглер арҫын: сӑран вӑтам тонӗ',
    '🤹🏾‍♂' => 'жонглер арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🤹🏿‍♂' => 'жонглер арҫын: сӑран тӗксӗм тонӗ',
    '🤹🏻‍♀' => 'хӗрарӑм жонглировка тӑвать: сӑран ҫутӑ тӗсӗ',
    '🤹🏼‍♀' => 'хӗрарӑм жонглировка тӑвать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤹🏽‍♀' => 'хӗрарӑм жонглировка тӑвать: сӑран вӑтам тонӗ',
    '🤹🏾‍♀' => 'хӗрарӑм жонглировка тӑвать: сӑран вӑтам тӗксӗм тонӗ',
    '🤹🏿‍♀' => 'хӗрарӑм жонглировка тӑвать: сӑран тӗксӗм тонӗ',
    '🧘🏻‍♂' => 'лотос пек ларакан арҫын: сӑран ҫутӑ тӗсӗ',
    '🧘🏼‍♂' => 'лотос пек ларакан арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧘🏽‍♂' => 'лотос пек ларакан арҫын: сӑран вӑтам тонӗ',
    '🧘🏾‍♂' => 'лотос пек ларакан арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧘🏿‍♂' => 'лотос пек ларакан арҫын: сӑран тӗксӗм тонӗ',
    '🧘🏻‍♀' => 'лотос пек ларакан хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧘🏼‍♀' => 'лотос пек ларакан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧘🏽‍♀' => 'лотос пек ларакан хӗрарӑм: сӑран вӑтам тонӗ',
    '🧘🏾‍♀' => 'лотос пек ларакан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧘🏿‍♀' => 'лотос пек ларакан хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧑‍🦰' => 'ҫитӗннӗ ҫын: хӗрлӗ ҫӳҫ',
    '🧑‍🦱' => 'ҫитӗннӗ ҫын: явӑнчӑк ҫӳҫ',
    '🧑‍🦳' => 'ҫитӗннӗ ҫын: шурӑ ҫӳҫ',
    '🧑‍🦲' => 'ҫитӗннӗ ҫын: кукша пуҫ',
    '👨‍🦰' => 'арҫын: хӗрлӗ ҫӳҫ',
    '👨‍🦱' => 'арҫын: явӑнчӑк ҫӳҫ',
    '👨‍🦳' => 'арҫын: шурӑ ҫӳҫ',
    '👨‍🦲' => 'арҫын: кукша пуҫ',
    '👩‍🦰' => 'хӗрарӑм: хӗрлӗ ҫӳҫ',
    '👩‍🦱' => 'хӗрарӑм: явӑнчӑк ҫӳҫ',
    '👩‍🦳' => 'хӗрарӑм: шурӑ ҫӳҫ',
    '👩‍🦲' => 'хӗрарӑм: кукша пуҫ',
    '🚶‍➡' => 'ҫын килет: сылтӑмалла',
    '🧎‍➡' => 'чӗркуҫленсе ларнӑ ҫын: сылтӑмалла',
    '🏃‍➡' => 'ҫын чупать: сылтӑмалла',
    '👨‍👦' => 'ҫемье: арҫын арçын ача',
    '👨‍👧' => 'ҫемье: арҫын хӗрача',
    '👩‍👦' => 'ҫемье: хӗрарӑм арçын ача',
    '👩‍👧' => 'ҫемье: хӗрарӑм хӗрача',
    '😶‍🌫' => 'пӗлӗтлӗ пит',
    '😮‍💨' => 'сывлать',
    '🙂‍↕' => 'килӗшӳллӗн пуҫне сулкалать',
    '😵‍💫' => 'ӑнран кайни',
    '❤‍🔥' => 'ҫунакан чӗре',
    '❤‍🩹' => 'тӳрленекен чӗре',
    '👁‍🗨' => 'свидетель значокӗ',
    '🧔‍♂' => 'сухаллӑ арҫын',
    '👱‍♂' => 'сарӑ ҫын',
    '🧔‍♀' => 'сухаллӑ хӗрарӑм',
    '👱‍♀' => 'сарӑ хӗрарӑм',
    '🙍‍♂' => 'тӗксӗмленнӗ арҫын',
    '🙍‍♀' => 'тӗксӗмленнӗ хӗрарӑм',
    '🙎‍♂' => 'кӳреннӗ арҫын',
    '🙎‍♀' => 'кӳреннӗ хӗрарӑм',
    '🙅‍♂' => 'арҫын "ҪУК" тесе алӑ сулать',
    '🙅‍♀' => 'хӗрарӑм "ҪУК"тесе алӑ сулать',
    '🙆‍♂' => 'арҫын "Ҫапла" тесе алӑ сулать',
    '🙆‍♀' => 'хӗрарӑм "Ҫапла" тесе алӑ сулать',
    '💁‍♂' => 'арҫын алӑ тӑсать',
    '💁‍♀' => 'хӗрарӑм алӑ тӑсать',
    '🙋‍♂' => 'ҫӗкленӗ арҫын',
    '🙋‍♀' => 'хӗрарӑм аллине ҫӗклет',
    '🧏‍♂' => 'хӑлхасӑр арҫын',
    '🧏‍♀' => 'хӑлхасӑр хӗрарӑм',
    '🙇‍♂' => 'арҫын пуҫ таять',
    '🙇‍♀' => 'хӗрарӑм пуҫ таять',
    '🤦‍♂' => 'арҫын сӑмах пултарулӑхне ҫухатрӗ',
    '🤦‍♀' => 'хӗрарӑм сӑмах пултарулӑхне ҫухатрӗ',
    '🤷‍♂' => 'арҫын хулпуҫҫисене сиктерет',
    '🤷‍♀' => 'хӗрарӑм хулпуҫҫисене сиктеркелет',
    '🧑‍⚕' => 'медицина работникӗ',
    '👨‍⚕' => 'врач',
    '👩‍⚕' => 'хӗрарӑм-медицина ӗҫекенӗ',
    '🧑‍🎓' => 'вӗренекен',
    '👨‍🎓' => 'студент',
    '👩‍🎓' => 'хӗрарӑм-студентка',
    '🧑‍🏫' => 'педагог',
    '👨‍🏫' => 'учитель',
    '👩‍🏫' => 'учительница',
    '🧑‍⚖' => 'судья',
    '👨‍⚖' => 'арҫын-судья',
    '👩‍⚖' => 'хӗрарӑм-судья',
    '🧑‍🌾' => 'фермер',
    '👨‍🌾' => 'фермер арҫын',
    '👩‍🌾' => 'фермер хӗрарӑм',
    '🧑‍🍳' => 'повар',
    '👨‍🍳' => 'повар арҫын',
    '👩‍🍳' => 'апат пӗҫерекен хӗрарӑм',
    '🧑‍🔧' => 'механик',
    '👨‍🔧' => 'механик арҫын',
    '👩‍🔧' => 'механик хӗрарӑм',
    '🧑‍🏭' => 'рабочи',
    '👨‍🏭' => 'арҫын-рабочи',
    '👩‍🏭' => 'фабрикара ӗҫлекен хӗрарӑм',
    '🧑‍💼' => 'офис работникӗ',
    '👨‍💼' => 'офис работникӗ-арҫын',
    '👩‍💼' => 'хӗрарӑм-офис работникӗ',
    '🧑‍🔬' => 'ученӑй',
    '👨‍🔬' => 'ученӑй арҫын',
    '👩‍🔬' => 'ученӑй хӗрарӑм',
    '🧑‍💻' => 'инженер',
    '👨‍💻' => 'инженер арҫын',
    '👩‍💻' => 'технолог хӗрарӑм',
    '🧑‍🎤' => 'юрӑҫӑ',
    '👨‍🎤' => 'юрӑҫӑ арҫын',
    '👩‍🎤' => 'юрӑҫӑ хӗрарӑм',
    '🧑‍🎨' => 'художник',
    '👨‍🎨' => 'художник арҫын',
    '👩‍🎨' => 'художница',
    '🧑‍✈' => 'пилот',
    '👨‍✈' => 'пилот арҫын',
    '👩‍✈' => 'пилот хӗрарӑм',
    '🧑‍🚀' => 'космонавт',
    '👨‍🚀' => 'космонавт арҫын',
    '👩‍🚀' => 'космонавт хӗрарӑм',
    '🧑‍🚒' => 'пушар',
    '👨‍🚒' => 'пушар арҫын',
    '👩‍🚒' => 'пушартан хӑтаракан хӗрарӑмӗ',
    '👮‍♂' => 'полицейски арҫын',
    '👮‍♀' => 'полицейски хӗрарӑм',
    '🕵‍♂' => 'арҫын-детектив',
    '🕵‍♀' => 'детектив хӗрарӑм',
    '💂‍♂' => 'гвардеец арҫын',
    '💂‍♀' => 'сыхлакан хӗрарӑм',
    '👷‍♂' => 'строитель арҫын',
    '👷‍♀' => 'ҫуртсем тӑвакан хӗрарӑм',
    '👳‍♂' => 'тюрбанлӑ арҫын',
    '👳‍♀' => 'пуҫне тюрбан ҫыхнӑ хӗрарӑм',
    '🤵‍♂' => 'смокинглӑ арҫын',
    '🤵‍♀' => 'смокинглӑ хӗрарӑм',
    '👰‍♂' => 'фат тӑхӑннӑ арҫын',
    '👰‍♀' => 'вуальпа витӗннӗ хӗрарӑм',
    '👩‍🍼' => 'хӗрарӑм ачана апатлантарать',
    '👨‍🍼' => 'тӑрантаракан арҫын',
    '🧑‍🍼' => 'тӑрантаракан ҫын',
    '🧑‍🎄' => 'Санта',
    '🦸‍♂' => 'супергер арҫын',
    '🦸‍♀' => 'патӑр хӗрарӑм',
    '🦹‍♂' => 'йӗксӗк арҫын',
    '🦹‍♀' => 'хӑруш усал хӗрарӑм',
    '🧙‍♂' => 'асамҫӑ',
    '🧙‍♀' => 'хӗрарӑм тухатмӑш',
    '🧚‍♂' => 'фея арҫын',
    '🧚‍♀' => 'фея хӗрарӑм',
    '🧛‍♂' => 'арҫын-вампир',
    '🧛‍♀' => 'хӗрарӑм-вампир',
    '🧜‍♂' => 'тритон',
    '🧜‍♀' => 'вутӑш хӗрарӑм',
    '🧝‍♂' => 'эльф арҫын',
    '🧝‍♀' => 'эльф хӗрарӑм',
    '🧞‍♂' => 'джинн арҫын',
    '🧞‍♀' => 'джинн хӗрарӑм',
    '🧟‍♂' => 'кӗрӳ арҫын',
    '🧟‍♀' => 'зомби хӗрарӑм',
    '💆‍♂' => 'арҫын питне массӑлать',
    '💆‍♀' => 'хӗрарӑма массаж тӑваҫҫӗ',
    '💇‍♂' => 'парикмахер арҫын',
    '💇‍♀' => 'хӗрарӑм ҫӳҫне кастарать',
    '🚶‍♂' => 'арҫын килет',
    '🚶‍♀' => 'хӗрарӑм килет',
    '🧍‍♂' => 'арҫын тӑрать',
    '🧍‍♀' => 'хӗрарӑм тӑрать',
    '🧎‍♂' => 'арҫын чӗркуҫҫи ҫинче',
    '🧎‍♀' => 'чӗркуҫҫи ҫинче тӑракан хӗрарӑм',
    '🧑‍🦯' => 'шурӑ туялӑ ҫын',
    '👨‍🦯' => 'утмалли туя',
    '👩‍🦯' => 'шур патаклӑ хӗрарӑм',
    '🧑‍🦼' => 'моторлӑ кресло-коляска тӑхӑннӑ ҫын',
    '👨‍🦼' => 'электричество кресли-коляска тӑхӑннӑ арҫын',
    '👩‍🦼' => 'инвалид кресли ҫинче моторлӑ хӗрарӑм',
    '🧑‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ ҫын',
    '👨‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ арҫын',
    '👩‍🦽' => 'алă привочĕ кресло-коляска тӑхӑннӑ хӗрарӑм',
    '🏃‍♂' => 'арҫын чупать',
    '🏃‍♀' => 'чупакан хӗрарӑм',
    '🧑‍🩰' => 'балет ташӑҫи',
    '👯‍♂' => 'мулкач хӑлхаллӑ арҫынсем',
    '👯‍♀' => 'мулкач хӑлхаллӑ хӗрарӑмсем',
    '🧖‍♂' => 'мунча арҫын',
    '🧖‍♀' => 'пӑчӑ пӳлӗмре хӗрарӑм',
    '🧗‍♂' => 'арҫын чул хысакӗ тӑрӑх хӑпарать',
    '🧗‍♀' => 'ту ҫине хӑпаракан хӗрарӑм',
    '🏌‍♂' => 'арҫын гольф калать',
    '🏌‍♀' => 'хӗрарӑм гольф вылять',
    '🏄‍♂' => 'серфингист',
    '🏄‍♀' => 'серфингист хӗрарӑм',
    '🚣‍♂' => 'кӗсменҫӗ',
    '🚣‍♀' => 'кӗсменҫӗ хӗрарӑм',
    '🏊‍♂' => 'ишекен',
    '🏊‍♀' => 'хӗрарӑм ишет',
    '⛹‍♂' => 'мечӗклӗ арҫын',
    '⛹‍♀' => 'тупӑ сиктерекен хӗрарӑм',
    '🏋‍♂' => 'штангӑллӑ арҫын',
    '🏋‍♀' => 'йывӑр ҫӗклекен хӗрарӑм',
    '🚴‍♂' => 'велосипедлӑ арҫын',
    '🚴‍♀' => 'велосипедлӑ хӗрарӑм',
    '🚵‍♂' => 'ту ҫинчи велосипедпа арҫын',
    '🚵‍♀' => 'хӗрарӑм ту ҫинчи велосипедпа ярӑнать',
    '🤸‍♂' => 'акробат',
    '🤸‍♀' => 'кустӑрма туса кӑтартакан хӗрарӑм',
    '🤼‍♂' => 'кӗрешӳҫӗ арҫынсем',
    '🤼‍♀' => 'хӗрарӑм кӗрешӗвӗ',
    '🤽‍♂' => 'арҫын шыв урай вылять',
    '🤽‍♀' => 'шывра тупӑпӑ вылякан хӗрарӑм',
    '🤾‍♂' => 'гандболист',
    '🤾‍♀' => 'хӗрарӑм гандболла вылять',
    '🤹‍♂' => 'жонглер арҫын',
    '🤹‍♀' => 'хӗрарӑм жонглировка тӑвать',
    '🧘‍♂' => 'лотос пек ларакан арҫын',
    '🧘‍♀' => 'лотос пек ларакан хӗрарӑм',
    '🧑‍🧒' => 'ҫемье: ҫитӗннӗ те ача',
    '🐕‍🦺' => 'служба йытти',
    '🐈‍⬛' => 'хура кушак',
    '🐻‍❄' => 'шурӑ упа пуҫӗ',
    '🐦‍⬛' => 'хура кайӑк',
    '🐦‍🔥' => 'фениикс',
    '🍋‍🟩' => 'лайм',
    '🍄‍🟫' => 'хӑмӑр кӑмпа',
    '⛓‍💥' => 'татӑлнӑ сӑнчӑр',
    '🏳‍🌈' => 'асамат кӗперӗ ялавӗ',
    '🏳‍⚧' => 'трансгендер ялавӗ',
    '🏴‍☠' => 'пират ялавӗ',
    '👋🏻' => 'аллипе сулать: сӑран ҫутӑ тӗсӗ',
    '👋🏼' => 'аллипе сулать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👋🏽' => 'аллипе сулать: сӑран вӑтам тонӗ',
    '👋🏾' => 'аллипе сулать: сӑран вӑтам тӗксӗм тонӗ',
    '👋🏿' => 'аллипе сулать: сӑран тӗксӗм тонӗ',
    '🤚🏻' => 'ҫӗкленӗ алӑ: сӑран ҫутӑ тӗсӗ',
    '🤚🏼' => 'ҫӗкленӗ алӑ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤚🏽' => 'ҫӗкленӗ алӑ: сӑран вӑтам тонӗ',
    '🤚🏾' => 'ҫӗкленӗ алӑ: сӑран вӑтам тӗксӗм тонӗ',
    '🤚🏿' => 'ҫӗкленӗ алӑ: сӑран тӗксӗм тонӗ',
    '🖐🏻' => 'карнӑ ал тупанӗ: сӑран ҫутӑ тӗсӗ',
    '🖐🏼' => 'карнӑ ал тупанӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🖐🏽' => 'карнӑ ал тупанӗ: сӑран вӑтам тонӗ',
    '🖐🏾' => 'карнӑ ал тупанӗ: сӑран вӑтам тӗксӗм тонӗ',
    '🖐🏿' => 'карнӑ ал тупанӗ: сӑран тӗксӗм тонӗ',
    '✋🏻' => 'ҫӗкленӗ ал тупанӗ: сӑран ҫутӑ тӗсӗ',
    '✋🏼' => 'ҫӗкленӗ ал тупанӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '✋🏽' => 'ҫӗкленӗ ал тупанӗ: сӑран вӑтам тонӗ',
    '✋🏾' => 'ҫӗкленӗ ал тупанӗ: сӑран вӑтам тӗксӗм тонӗ',
    '✋🏿' => 'ҫӗкленӗ ал тупанӗ: сӑран тӗксӗм тонӗ',
    '🖖🏻' => 'вулкан салючӗ: сӑран ҫутӑ тӗсӗ',
    '🖖🏼' => 'вулкан салючӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🖖🏽' => 'вулкан салючӗ: сӑран вӑтам тонӗ',
    '🖖🏾' => 'вулкан салючӗ: сӑран вӑтам тӗксӗм тонӗ',
    '🖖🏿' => 'вулкан салючӗ: сӑран тӗксӗм тонӗ',
    '🫱🏻' => 'алӑ сылтӑмалла: сӑран ҫутӑ тӗсӗ',
    '🫱🏼' => 'алӑ сылтӑмалла: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫱🏽' => 'алӑ сылтӑмалла: сӑран вӑтам тонӗ',
    '🫱🏾' => 'алӑ сылтӑмалла: сӑран вӑтам тӗксӗм тонӗ',
    '🫱🏿' => 'алӑ сылтӑмалла: сӑран тӗксӗм тонӗ',
    '🫲🏻' => 'алӑ сулахаялла: сӑран ҫутӑ тӗсӗ',
    '🫲🏼' => 'алӑ сулахаялла: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫲🏽' => 'алӑ сулахаялла: сӑран вӑтам тонӗ',
    '🫲🏾' => 'алӑ сулахаялла: сӑран вӑтам тӗксӗм тонӗ',
    '🫲🏿' => 'алӑ сулахаялла: сӑран тӗксӗм тонӗ',
    '🫳🏻' => 'алтупанӗпе аялалла: сӑран ҫутӑ тӗсӗ',
    '🫳🏼' => 'алтупанӗпе аялалла: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫳🏽' => 'алтупанӗпе аялалла: сӑран вӑтам тонӗ',
    '🫳🏾' => 'алтупанӗпе аялалла: сӑран вӑтам тӗксӗм тонӗ',
    '🫳🏿' => 'алтупанӗпе аялалла: сӑран тӗксӗм тонӗ',
    '🫴🏻' => 'алтупанӗпе ҫӳлелле: сӑран ҫутӑ тӗсӗ',
    '🫴🏼' => 'алтупанӗпе ҫӳлелле: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫴🏽' => 'алтупанӗпе ҫӳлелле: сӑран вӑтам тонӗ',
    '🫴🏾' => 'алтупанӗпе ҫӳлелле: сӑран вӑтам тӗксӗм тонӗ',
    '🫴🏿' => 'алтупанӗпе ҫӳлелле: сӑран тӗксӗм тонӗ',
    '🫷🏻' => 'алтупанӗпе сулахаялла: сӑран ҫутӑ тӗсӗ',
    '🫷🏼' => 'алтупанӗпе сулахаялла: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫷🏽' => 'алтупанӗпе сулахаялла: сӑран вӑтам тонӗ',
    '🫷🏾' => 'алтупанӗпе сулахаялла: сӑран вӑтам тӗксӗм тонӗ',
    '🫷🏿' => 'алтупанӗпе сулахаялла: сӑран тӗксӗм тонӗ',
    '🫸🏻' => 'алтупанӗпе сылтӑмалла: сӑран ҫутӑ тӗсӗ',
    '🫸🏼' => 'алтупанӗпе сылтӑмалла: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫸🏽' => 'алтупанӗпе сылтӑмалла: сӑран вӑтам тонӗ',
    '🫸🏾' => 'алтупанӗпе сылтӑмалла: сӑран вӑтам тӗксӗм тонӗ',
    '🫸🏿' => 'алтупанӗпе сылтӑмалла: сӑран тӗксӗм тонӗ',
    '👌🏻' => '"пурте аван"тесе алӑ сулни: сӑран ҫутӑ тӗсӗ',
    '👌🏼' => '"пурте аван"тесе алӑ сулни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👌🏽' => '"пурте аван"тесе алӑ сулни: сӑран вӑтам тонӗ',
    '👌🏾' => '"пурте аван"тесе алӑ сулни: сӑран вӑтам тӗксӗм тонӗ',
    '👌🏿' => '"пурте аван"тесе алӑ сулни: сӑран тӗксӗм тонӗ',
    '🤌🏻' => 'пӗр чӗптӗм: сӑран ҫутӑ тӗсӗ',
    '🤌🏼' => 'пӗр чӗптӗм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤌🏽' => 'пӗр чӗптӗм: сӑран вӑтам тонӗ',
    '🤌🏾' => 'пӗр чӗптӗм: сӑран вӑтам тӗксӗм тонӗ',
    '🤌🏿' => 'пӗр чӗптӗм: сӑран тӗксӗм тонӗ',
    '🤏🏻' => '"сахал"алӑ сулни: сӑран ҫутӑ тӗсӗ',
    '🤏🏼' => '"сахал"алӑ сулни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤏🏽' => '"сахал"алӑ сулни: сӑран вӑтам тонӗ',
    '🤏🏾' => '"сахал"алӑ сулни: сӑран вӑтам тӗксӗм тонӗ',
    '🤏🏿' => '"сахал"алӑ сулни: сӑран тӗксӗм тонӗ',
    '✌🏻' => 'V алӑ сулни: сӑран ҫутӑ тӗсӗ',
    '✌🏼' => 'V алӑ сулни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '✌🏽' => 'V алӑ сулни: сӑран вӑтам тонӗ',
    '✌🏾' => 'V алӑ сулни: сӑран вӑтам тӗксӗм тонӗ',
    '✌🏿' => 'V алӑ сулни: сӑран тӗксӗм тонӗ',
    '🤞🏻' => 'хӗреслӗ пӳрнесем: сӑран ҫутӑ тӗсӗ',
    '🤞🏼' => 'хӗреслӗ пӳрнесем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤞🏽' => 'хӗреслӗ пӳрнесем: сӑран вӑтам тонӗ',
    '🤞🏾' => 'хӗреслӗ пӳрнесем: сӑран вӑтам тӗксӗм тонӗ',
    '🤞🏿' => 'хӗреслӗ пӳрнесем: сӑран тӗксӗм тонӗ',
    '🫰🏻' => '"укҫа" паллă: сӑран ҫутӑ тӗсӗ',
    '🫰🏼' => '"укҫа" паллă: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫰🏽' => '"укҫа" паллă: сӑран вӑтам тонӗ',
    '🫰🏾' => '"укҫа" паллă: сӑран вӑтам тӗксӗм тонӗ',
    '🫰🏿' => '"укҫа" паллă: сӑран тӗксӗм тонӗ',
    '🤟🏻' => 'эпӗ-сана-юрататӑп: сӑран ҫутӑ тӗсӗ',
    '🤟🏼' => 'эпӗ-сана-юрататӑп: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤟🏽' => 'эпӗ-сана-юрататӑп: сӑран вӑтам тонӗ',
    '🤟🏾' => 'эпӗ-сана-юрататӑп: сӑран вӑтам тӗксӗм тонӗ',
    '🤟🏿' => 'эпӗ-сана-юрататӑп: сӑран тӗксӗм тонӗ',
    '🤘🏻' => 'рокер алӑпа сулни: сӑран ҫутӑ тӗсӗ',
    '🤘🏼' => 'рокер алӑпа сулни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤘🏽' => 'рокер алӑпа сулни: сӑран вӑтам тонӗ',
    '🤘🏾' => 'рокер алӑпа сулни: сӑран вӑтам тӗксӗм тонӗ',
    '🤘🏿' => 'рокер алӑпа сулни: сӑран тӗксӗм тонӗ',
    '🤙🏻' => '"шӑнкӑртаттар-ха мана" паллă: сӑран ҫутӑ тӗсӗ',
    '🤙🏼' => '"шӑнкӑртаттар-ха мана" паллă: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤙🏽' => '"шӑнкӑртаттар-ха мана" паллă: сӑран вӑтам тонӗ',
    '🤙🏾' => '"шӑнкӑртаттар-ха мана" паллă: сӑран вӑтам тӗксӗм тонӗ',
    '🤙🏿' => '"шӑнкӑртаттар-ха мана" паллă: сӑран тӗксӗм тонӗ',
    '👈🏻' => 'сулахаялла кӑтартакан пӳрне: сӑран ҫутӑ тӗсӗ',
    '👈🏼' => 'сулахаялла кӑтартакан пӳрне: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👈🏽' => 'сулахаялла кӑтартакан пӳрне: сӑран вӑтам тонӗ',
    '👈🏾' => 'сулахаялла кӑтартакан пӳрне: сӑран вӑтам тӗксӗм тонӗ',
    '👈🏿' => 'сулахаялла кӑтартакан пӳрне: сӑран тӗксӗм тонӗ',
    '👉🏻' => 'сылтӑмалла кӑтартакан пӳрне: сӑран ҫутӑ тӗсӗ',
    '👉🏼' => 'сылтӑмалла кӑтартакан пӳрне: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👉🏽' => 'сылтӑмалла кӑтартакан пӳрне: сӑран вӑтам тонӗ',
    '👉🏾' => 'сылтӑмалла кӑтартакан пӳрне: сӑран вӑтам тӗксӗм тонӗ',
    '👉🏿' => 'сылтӑмалла кӑтартакан пӳрне: сӑран тӗксӗм тонӗ',
    '👆🏻' => 'пӳрнене ҫӳлелле кӑтарт: сӑран ҫутӑ тӗсӗ',
    '👆🏼' => 'пӳрнене ҫӳлелле кӑтарт: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👆🏽' => 'пӳрнене ҫӳлелле кӑтарт: сӑран вӑтам тонӗ',
    '👆🏾' => 'пӳрнене ҫӳлелле кӑтарт: сӑран вӑтам тӗксӗм тонӗ',
    '👆🏿' => 'пӳрнене ҫӳлелле кӑтарт: сӑран тӗксӗм тонӗ',
    '🖕🏻' => 'вӑта пӳрне: сӑран ҫутӑ тӗсӗ',
    '🖕🏼' => 'вӑта пӳрне: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🖕🏽' => 'вӑта пӳрне: сӑран вӑтам тонӗ',
    '🖕🏾' => 'вӑта пӳрне: сӑран вӑтам тӗксӗм тонӗ',
    '🖕🏿' => 'вӑта пӳрне: сӑран тӗксӗм тонӗ',
    '👇🏻' => 'пӳрнене аялалла кӑтарт: сӑран ҫутӑ тӗсӗ',
    '👇🏼' => 'пӳрнене аялалла кӑтарт: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👇🏽' => 'пӳрнене аялалла кӑтарт: сӑран вӑтам тонӗ',
    '👇🏾' => 'пӳрнене аялалла кӑтарт: сӑран вӑтам тӗксӗм тонӗ',
    '👇🏿' => 'пӳрнене аялалла кӑтарт: сӑран тӗксӗм тонӗ',
    '☝🏻' => 'шӗвӗр пӳрне ҫӳлелле: сӑран ҫутӑ тӗсӗ',
    '☝🏼' => 'шӗвӗр пӳрне ҫӳлелле: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '☝🏽' => 'шӗвӗр пӳрне ҫӳлелле: сӑран вӑтам тонӗ',
    '☝🏾' => 'шӗвӗр пӳрне ҫӳлелле: сӑран вӑтам тӗксӗм тонӗ',
    '☝🏿' => 'шӗвӗр пӳрне ҫӳлелле: сӑран тӗксӗм тонӗ',
    '🫵🏻' => 'шӗвӗр пӳрне: сӑран ҫутӑ тӗсӗ',
    '🫵🏼' => 'шӗвӗр пӳрне: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫵🏽' => 'шӗвӗр пӳрне: сӑран вӑтам тонӗ',
    '🫵🏾' => 'шӗвӗр пӳрне: сӑран вӑтам тӗксӗм тонӗ',
    '🫵🏿' => 'шӗвӗр пӳрне: сӑран тӗксӗм тонӗ',
    '👍🏻' => 'пуҫ пӳрне ҫӳлелле: сӑран ҫутӑ тӗсӗ',
    '👍🏼' => 'пуҫ пӳрне ҫӳлелле: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👍🏽' => 'пуҫ пӳрне ҫӳлелле: сӑран вӑтам тонӗ',
    '👍🏾' => 'пуҫ пӳрне ҫӳлелле: сӑран вӑтам тӗксӗм тонӗ',
    '👍🏿' => 'пуҫ пӳрне ҫӳлелле: сӑран тӗксӗм тонӗ',
    '👎🏻' => 'пуҫ пӳрне аялалла: сӑран ҫутӑ тӗсӗ',
    '👎🏼' => 'пуҫ пӳрне аялалла: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👎🏽' => 'пуҫ пӳрне аялалла: сӑран вӑтам тонӗ',
    '👎🏾' => 'пуҫ пӳрне аялалла: сӑран вӑтам тӗксӗм тонӗ',
    '👎🏿' => 'пуҫ пӳрне аялалла: сӑран тӗксӗм тонӗ',
    '✊🏻' => 'ҫӗкленӗ чышкӑ: сӑран ҫутӑ тӗсӗ',
    '✊🏼' => 'ҫӗкленӗ чышкӑ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '✊🏽' => 'ҫӗкленӗ чышкӑ: сӑран вӑтам тонӗ',
    '✊🏾' => 'ҫӗкленӗ чышкӑ: сӑран вӑтам тӗксӗм тонӗ',
    '✊🏿' => 'ҫӗкленӗ чышкӑ: сӑран тӗксӗм тонӗ',
    '👊🏻' => 'кулак: сӑран ҫутӑ тӗсӗ',
    '👊🏼' => 'кулак: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👊🏽' => 'кулак: сӑран вӑтам тонӗ',
    '👊🏾' => 'кулак: сӑран вӑтам тӗксӗм тонӗ',
    '👊🏿' => 'кулак: сӑран тӗксӗм тонӗ',
    '🤛🏻' => 'чышкӑ сулахаялла: сӑран ҫутӑ тӗсӗ',
    '🤛🏼' => 'чышкӑ сулахаялла: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤛🏽' => 'чышкӑ сулахаялла: сӑран вӑтам тонӗ',
    '🤛🏾' => 'чышкӑ сулахаялла: сӑран вӑтам тӗксӗм тонӗ',
    '🤛🏿' => 'чышкӑ сулахаялла: сӑран тӗксӗм тонӗ',
    '🤜🏻' => 'чышкӑ сылтӑмалла: сӑран ҫутӑ тӗсӗ',
    '🤜🏼' => 'чышкӑ сылтӑмалла: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤜🏽' => 'чышкӑ сылтӑмалла: сӑран вӑтам тонӗ',
    '🤜🏾' => 'чышкӑ сылтӑмалла: сӑран вӑтам тӗксӗм тонӗ',
    '🤜🏿' => 'чышкӑ сылтӑмалла: сӑран тӗксӗм тонӗ',
    '👏🏻' => 'алӑ ҫупни: сӑран ҫутӑ тӗсӗ',
    '👏🏼' => 'алӑ ҫупни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👏🏽' => 'алӑ ҫупни: сӑран вӑтам тонӗ',
    '👏🏾' => 'алӑ ҫупни: сӑран вӑтам тӗксӗм тонӗ',
    '👏🏿' => 'алӑ ҫупни: сӑран тӗксӗм тонӗ',
    '🙌🏻' => 'урра: сӑран ҫутӑ тӗсӗ',
    '🙌🏼' => 'урра: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙌🏽' => 'урра: сӑран вӑтам тонӗ',
    '🙌🏾' => 'урра: сӑран вӑтам тӗксӗм тонӗ',
    '🙌🏿' => 'урра: сӑран тӗксӗм тонӗ',
    '🫶🏻' => '"чӗре"аллипе сулни: сӑран ҫутӑ тӗсӗ',
    '🫶🏼' => '"чӗре"аллипе сулни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫶🏽' => '"чӗре"аллипе сулни: сӑран вӑтам тонӗ',
    '🫶🏾' => '"чӗре"аллипе сулни: сӑран вӑтам тӗксӗм тонӗ',
    '🫶🏿' => '"чӗре"аллипе сулни: сӑран тӗксӗм тонӗ',
    '👐🏻' => 'алтупанӗсем айккинелле: сӑран ҫутӑ тӗсӗ',
    '👐🏼' => 'алтупанӗсем айккинелле: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👐🏽' => 'алтупанӗсем айккинелле: сӑран вӑтам тонӗ',
    '👐🏾' => 'алтупанӗсем айккинелле: сӑран вӑтам тӗксӗм тонӗ',
    '👐🏿' => 'алтупанӗсем айккинелле: сӑран тӗксӗм тонӗ',
    '🤲🏻' => 'ывӑҫ тупанӗсем кимӗпе: сӑран ҫутӑ тӗсӗ',
    '🤲🏼' => 'ывӑҫ тупанӗсем кимӗпе: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤲🏽' => 'ывӑҫ тупанӗсем кимӗпе: сӑран вӑтам тонӗ',
    '🤲🏾' => 'ывӑҫ тупанӗсем кимӗпе: сӑран вӑтам тӗксӗм тонӗ',
    '🤲🏿' => 'ывӑҫ тупанӗсем кимӗпе: сӑран тӗксӗм тонӗ',
    '🤝🏻' => 'алӑ тытни: сӑран ҫутӑ тӗсӗ',
    '🤝🏼' => 'алӑ тытни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤝🏽' => 'алӑ тытни: сӑран вӑтам тонӗ',
    '🤝🏾' => 'алӑ тытни: сӑран вӑтам тӗксӗм тонӗ',
    '🤝🏿' => 'алӑ тытни: сӑран тӗксӗм тонӗ',
    '🙏🏻' => 'хуҫлатнӑ алӑсем: сӑран ҫутӑ тӗсӗ',
    '🙏🏼' => 'хуҫлатнӑ алӑсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙏🏽' => 'хуҫлатнӑ алӑсем: сӑран вӑтам тонӗ',
    '🙏🏾' => 'хуҫлатнӑ алӑсем: сӑран вӑтам тӗксӗм тонӗ',
    '🙏🏿' => 'хуҫлатнӑ алӑсем: сӑран тӗксӗм тонӗ',
    '✍🏻' => 'ҫыракан алӑ: сӑран ҫутӑ тӗсӗ',
    '✍🏼' => 'ҫыракан алӑ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '✍🏽' => 'ҫыракан алӑ: сӑран вӑтам тонӗ',
    '✍🏾' => 'ҫыракан алӑ: сӑран вӑтам тӗксӗм тонӗ',
    '✍🏿' => 'ҫыракан алӑ: сӑран тӗксӗм тонӗ',
    '💅🏻' => 'маникюр: сӑран ҫутӑ тӗсӗ',
    '💅🏼' => 'маникюр: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💅🏽' => 'маникюр: сӑран вӑтам тонӗ',
    '💅🏾' => 'маникюр: сӑран вӑтам тӗксӗм тонӗ',
    '💅🏿' => 'маникюр: сӑран тӗксӗм тонӗ',
    '🤳🏻' => 'селфи: сӑран ҫутӑ тӗсӗ',
    '🤳🏼' => 'селфи: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤳🏽' => 'селфи: сӑран вӑтам тонӗ',
    '🤳🏾' => 'селфи: сӑран вӑтам тӗксӗм тонӗ',
    '🤳🏿' => 'селфи: сӑран тӗксӗм тонӗ',
    '💪🏻' => 'бицепс: сӑран ҫутӑ тӗсӗ',
    '💪🏼' => 'бицепс: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💪🏽' => 'бицепс: сӑран вӑтам тонӗ',
    '💪🏾' => 'бицепс: сӑран вӑтам тӗксӗм тонӗ',
    '💪🏿' => 'бицепс: сӑран тӗксӗм тонӗ',
    '🦵🏻' => 'ура: сӑран ҫутӑ тӗсӗ',
    '🦵🏼' => 'ура: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🦵🏽' => 'ура: сӑран вӑтам тонӗ',
    '🦵🏾' => 'ура: сӑран вӑтам тӗксӗм тонӗ',
    '🦵🏿' => 'ура: сӑран тӗксӗм тонӗ',
    '🦶🏻' => 'пакӑлчак: сӑран ҫутӑ тӗсӗ',
    '🦶🏼' => 'пакӑлчак: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🦶🏽' => 'пакӑлчак: сӑран вӑтам тонӗ',
    '🦶🏾' => 'пакӑлчак: сӑран вӑтам тӗксӗм тонӗ',
    '🦶🏿' => 'пакӑлчак: сӑран тӗксӗм тонӗ',
    '👂🏻' => 'хӑлха: сӑран ҫутӑ тӗсӗ',
    '👂🏼' => 'хӑлха: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👂🏽' => 'хӑлха: сӑран вӑтам тонӗ',
    '👂🏾' => 'хӑлха: сӑран вӑтам тӗксӗм тонӗ',
    '👂🏿' => 'хӑлха: сӑран тӗксӗм тонӗ',
    '🦻🏻' => 'хӑлхи: сӑран ҫутӑ тӗсӗ',
    '🦻🏼' => 'хӑлхи: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🦻🏽' => 'хӑлхи: сӑран вӑтам тонӗ',
    '🦻🏾' => 'хӑлхи: сӑран вӑтам тӗксӗм тонӗ',
    '🦻🏿' => 'хӑлхи: сӑран тӗксӗм тонӗ',
    '👃🏻' => 'сӑмса: сӑран ҫутӑ тӗсӗ',
    '👃🏼' => 'сӑмса: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👃🏽' => 'сӑмса: сӑран вӑтам тонӗ',
    '👃🏾' => 'сӑмса: сӑран вӑтам тӗксӗм тонӗ',
    '👃🏿' => 'сӑмса: сӑран тӗксӗм тонӗ',
    '👶🏻' => 'пĕчĕк ача: сӑран ҫутӑ тӗсӗ',
    '👶🏼' => 'пĕчĕк ача: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👶🏽' => 'пĕчĕк ача: сӑран вӑтам тонӗ',
    '👶🏾' => 'пĕчĕк ача: сӑран вӑтам тӗксӗм тонӗ',
    '👶🏿' => 'пĕчĕк ача: сӑран тӗксӗм тонӗ',
    '🧒🏻' => 'ача: сӑран ҫутӑ тӗсӗ',
    '🧒🏼' => 'ача: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧒🏽' => 'ача: сӑран вӑтам тонӗ',
    '🧒🏾' => 'ача: сӑран вӑтам тӗксӗм тонӗ',
    '🧒🏿' => 'ача: сӑран тӗксӗм тонӗ',
    '👦🏻' => 'арçын ача: сӑран ҫутӑ тӗсӗ',
    '👦🏼' => 'арçын ача: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👦🏽' => 'арçын ача: сӑран вӑтам тонӗ',
    '👦🏾' => 'арçын ача: сӑран вӑтам тӗксӗм тонӗ',
    '👦🏿' => 'арçын ача: сӑран тӗксӗм тонӗ',
    '👧🏻' => 'хӗрача: сӑран ҫутӑ тӗсӗ',
    '👧🏼' => 'хӗрача: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👧🏽' => 'хӗрача: сӑран вӑтам тонӗ',
    '👧🏾' => 'хӗрача: сӑран вӑтам тӗксӗм тонӗ',
    '👧🏿' => 'хӗрача: сӑран тӗксӗм тонӗ',
    '🧑🏻' => 'ҫитӗннӗ ҫын: сӑран ҫутӑ тӗсӗ',
    '🧑🏼' => 'ҫитӗннӗ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧑🏽' => 'ҫитӗннӗ ҫын: сӑран вӑтам тонӗ',
    '🧑🏾' => 'ҫитӗннӗ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧑🏿' => 'ҫитӗннӗ ҫын: сӑран тӗксӗм тонӗ',
    '👱🏻' => 'сарӑ ҫӳҫлӗ ҫын: сӑран ҫутӑ тӗсӗ',
    '👱🏼' => 'сарӑ ҫӳҫлӗ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👱🏽' => 'сарӑ ҫӳҫлӗ ҫын: сӑран вӑтам тонӗ',
    '👱🏾' => 'сарӑ ҫӳҫлӗ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👱🏿' => 'сарӑ ҫӳҫлӗ ҫын: сӑран тӗксӗм тонӗ',
    '👨🏻' => 'арҫын: сӑран ҫутӑ тӗсӗ',
    '👨🏼' => 'арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👨🏽' => 'арҫын: сӑран вӑтам тонӗ',
    '👨🏾' => 'арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👨🏿' => 'арҫын: сӑран тӗксӗм тонӗ',
    '🧔🏻' => 'сухаллӑ ҫын: сӑран ҫутӑ тӗсӗ',
    '🧔🏼' => 'сухаллӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧔🏽' => 'сухаллӑ ҫын: сӑран вӑтам тонӗ',
    '🧔🏾' => 'сухаллӑ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧔🏿' => 'сухаллӑ ҫын: сӑран тӗксӗм тонӗ',
    '👩🏻' => 'хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👩🏼' => 'хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👩🏽' => 'хӗрарӑм: сӑран вӑтам тонӗ',
    '👩🏾' => 'хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👩🏿' => 'хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🧓🏻' => 'ватӑрах ҫын: сӑран ҫутӑ тӗсӗ',
    '🧓🏼' => 'ватӑрах ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧓🏽' => 'ватӑрах ҫын: сӑран вӑтам тонӗ',
    '🧓🏾' => 'ватӑрах ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧓🏿' => 'ватӑрах ҫын: сӑран тӗксӗм тонӗ',
    '👴🏻' => 'ватӑрах арҫын: сӑран ҫутӑ тӗсӗ',
    '👴🏼' => 'ватӑрах арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👴🏽' => 'ватӑрах арҫын: сӑран вӑтам тонӗ',
    '👴🏾' => 'ватӑрах арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👴🏿' => 'ватӑрах арҫын: сӑран тӗксӗм тонӗ',
    '👵🏻' => 'ватӑрах хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '👵🏼' => 'ватӑрах хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👵🏽' => 'ватӑрах хӗрарӑм: сӑран вӑтам тонӗ',
    '👵🏾' => 'ватӑрах хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '👵🏿' => 'ватӑрах хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🙍🏻' => 'тӗксӗмленнӗ ҫын: сӑран ҫутӑ тӗсӗ',
    '🙍🏼' => 'тӗксӗмленнӗ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙍🏽' => 'тӗксӗмленнӗ ҫын: сӑран вӑтам тонӗ',
    '🙍🏾' => 'тӗксӗмленнӗ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🙍🏿' => 'тӗксӗмленнӗ ҫын: сӑран тӗксӗм тонӗ',
    '🙎🏻' => 'кӳреннӗ ҫын: сӑран ҫутӑ тӗсӗ',
    '🙎🏼' => 'кӳреннӗ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙎🏽' => 'кӳреннӗ ҫын: сӑран вӑтам тонӗ',
    '🙎🏾' => 'кӳреннӗ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🙎🏿' => 'кӳреннӗ ҫын: сӑран тӗксӗм тонӗ',
    '🙅🏻' => 'ҫын "ҪУК" тесе алӑ сулать: сӑран ҫутӑ тӗсӗ',
    '🙅🏼' => 'ҫын "ҪУК" тесе алӑ сулать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙅🏽' => 'ҫын "ҪУК" тесе алӑ сулать: сӑран вӑтам тонӗ',
    '🙅🏾' => 'ҫын "ҪУК" тесе алӑ сулать: сӑран вӑтам тӗксӗм тонӗ',
    '🙅🏿' => 'ҫын "ҪУК" тесе алӑ сулать: сӑран тӗксӗм тонӗ',
    '🙆🏻' => 'ҫын "Ҫапла" тесе алӑ сулать: сӑран ҫутӑ тӗсӗ',
    '🙆🏼' => 'ҫын "Ҫапла" тесе алӑ сулать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙆🏽' => 'ҫын "Ҫапла" тесе алӑ сулать: сӑран вӑтам тонӗ',
    '🙆🏾' => 'ҫын "Ҫапла" тесе алӑ сулать: сӑран вӑтам тӗксӗм тонӗ',
    '🙆🏿' => 'ҫын "Ҫапла" тесе алӑ сулать: сӑран тӗксӗм тонӗ',
    '💁🏻' => 'ҫын алӑ туртать: сӑран ҫутӑ тӗсӗ',
    '💁🏼' => 'ҫын алӑ туртать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💁🏽' => 'ҫын алӑ туртать: сӑран вӑтам тонӗ',
    '💁🏾' => 'ҫын алӑ туртать: сӑран вӑтам тӗксӗм тонӗ',
    '💁🏿' => 'ҫын алӑ туртать: сӑран тӗксӗм тонӗ',
    '🙋🏻' => 'ҫӗкленӗ ҫын: сӑран ҫутӑ тӗсӗ',
    '🙋🏼' => 'ҫӗкленӗ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙋🏽' => 'ҫӗкленӗ ҫын: сӑран вӑтам тонӗ',
    '🙋🏾' => 'ҫӗкленӗ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🙋🏿' => 'ҫӗкленӗ ҫын: сӑран тӗксӗм тонӗ',
    '🧏🏻' => 'хӑлхасӑр ҫын: сӑран ҫутӑ тӗсӗ',
    '🧏🏼' => 'хӑлхасӑр ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧏🏽' => 'хӑлхасӑр ҫын: сӑран вӑтам тонӗ',
    '🧏🏾' => 'хӑлхасӑр ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧏🏿' => 'хӑлхасӑр ҫын: сӑран тӗксӗм тонӗ',
    '🙇🏻' => 'ҫын пуҫ таять: сӑран ҫутӑ тӗсӗ',
    '🙇🏼' => 'ҫын пуҫ таять: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🙇🏽' => 'ҫын пуҫ таять: сӑран вӑтам тонӗ',
    '🙇🏾' => 'ҫын пуҫ таять: сӑран вӑтам тӗксӗм тонӗ',
    '🙇🏿' => 'ҫын пуҫ таять: сӑран тӗксӗм тонӗ',
    '🤦🏻' => 'ҫын сӑмах пултарулӑхне ҫухатнӑ: сӑран ҫутӑ тӗсӗ',
    '🤦🏼' => 'ҫын сӑмах пултарулӑхне ҫухатнӑ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤦🏽' => 'ҫын сӑмах пултарулӑхне ҫухатнӑ: сӑран вӑтам тонӗ',
    '🤦🏾' => 'ҫын сӑмах пултарулӑхне ҫухатнӑ: сӑран вӑтам тӗксӗм тонӗ',
    '🤦🏿' => 'ҫын сӑмах пултарулӑхне ҫухатнӑ: сӑран тӗксӗм тонӗ',
    '🤷🏻' => 'ҫын хулпуҫҫийӗсене сиктерет: сӑран ҫутӑ тӗсӗ',
    '🤷🏼' => 'ҫын хулпуҫҫийӗсене сиктерет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤷🏽' => 'ҫын хулпуҫҫийӗсене сиктерет: сӑран вӑтам тонӗ',
    '🤷🏾' => 'ҫын хулпуҫҫийӗсене сиктерет: сӑран вӑтам тӗксӗм тонӗ',
    '🤷🏿' => 'ҫын хулпуҫҫийӗсене сиктерет: сӑран тӗксӗм тонӗ',
    '👮🏻' => 'полицейски: сӑран ҫутӑ тӗсӗ',
    '👮🏼' => 'полицейски: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👮🏽' => 'полицейски: сӑран вӑтам тонӗ',
    '👮🏾' => 'полицейски: сӑран вӑтам тӗксӗм тонӗ',
    '👮🏿' => 'полицейски: сӑран тӗксӗм тонӗ',
    '🕵🏻' => 'детектив: сӑран ҫутӑ тӗсӗ',
    '🕵🏼' => 'детектив: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🕵🏽' => 'детектив: сӑран вӑтам тонӗ',
    '🕵🏾' => 'детектив: сӑран вӑтам тӗксӗм тонӗ',
    '🕵🏿' => 'детектив: сӑран тӗксӗм тонӗ',
    '💂🏻' => 'гвардеец: сӑран ҫутӑ тӗсӗ',
    '💂🏼' => 'гвардеец: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💂🏽' => 'гвардеец: сӑран вӑтам тонӗ',
    '💂🏾' => 'гвардеец: сӑран вӑтам тӗксӗм тонӗ',
    '💂🏿' => 'гвардеец: сӑран тӗксӗм тонӗ',
    '🥷🏻' => 'ниндзя: сӑран ҫутӑ тӗсӗ',
    '🥷🏼' => 'ниндзя: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🥷🏽' => 'ниндзя: сӑран вӑтам тонӗ',
    '🥷🏾' => 'ниндзя: сӑран вӑтам тӗксӗм тонӗ',
    '🥷🏿' => 'ниндзя: сӑран тӗксӗм тонӗ',
    '👷🏻' => 'строительство: сӑран ҫутӑ тӗсӗ',
    '👷🏼' => 'строительство: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👷🏽' => 'строительство: сӑран вӑтам тонӗ',
    '👷🏾' => 'строительство: сӑран вӑтам тӗксӗм тонӗ',
    '👷🏿' => 'строительство: сӑран тӗксӗм тонӗ',
    '🫅🏻' => 'коронӑллӑ ҫын: сӑран ҫутӑ тӗсӗ',
    '🫅🏼' => 'коронӑллӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫅🏽' => 'коронӑллӑ ҫын: сӑран вӑтам тонӗ',
    '🫅🏾' => 'коронӑллӑ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🫅🏿' => 'коронӑллӑ ҫын: сӑран тӗксӗм тонӗ',
    '🤴🏻' => 'принц: сӑран ҫутӑ тӗсӗ',
    '🤴🏼' => 'принц: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤴🏽' => 'принц: сӑран вӑтам тонӗ',
    '🤴🏾' => 'принц: сӑран вӑтам тӗксӗм тонӗ',
    '🤴🏿' => 'принц: сӑран тӗксӗм тонӗ',
    '👸🏻' => 'принцесса: сӑран ҫутӑ тӗсӗ',
    '👸🏼' => 'принцесса: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👸🏽' => 'принцесса: сӑран вӑтам тонӗ',
    '👸🏾' => 'принцесса: сӑран вӑтам тӗксӗм тонӗ',
    '👸🏿' => 'принцесса: сӑран тӗксӗм тонӗ',
    '👳🏻' => 'тюрбанлӑ ҫын: сӑран ҫутӑ тӗсӗ',
    '👳🏼' => 'тюрбанлӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👳🏽' => 'тюрбанлӑ ҫын: сӑран вӑтам тонӗ',
    '👳🏾' => 'тюрбанлӑ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👳🏿' => 'тюрбанлӑ ҫын: сӑран тӗксӗм тонӗ',
    '👲🏻' => 'китай ҫӗлӗк тӑхӑннӑ арҫын: сӑран ҫутӑ тӗсӗ',
    '👲🏼' => 'китай ҫӗлӗк тӑхӑннӑ арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👲🏽' => 'китай ҫӗлӗк тӑхӑннӑ арҫын: сӑран вӑтам тонӗ',
    '👲🏾' => 'китай ҫӗлӗк тӑхӑннӑ арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '👲🏿' => 'китай ҫӗлӗк тӑхӑннӑ арҫын: сӑран тӗксӗм тонӗ',
    '🧕🏻' => 'пуҫне тутӑр ҫыхнӑ хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🧕🏼' => 'пуҫне тутӑр ҫыхнӑ хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧕🏽' => 'пуҫне тутӑр ҫыхнӑ хӗрарӑм: сӑран вӑтам тонӗ',
    '🧕🏾' => 'пуҫне тутӑр ҫыхнӑ хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🧕🏿' => 'пуҫне тутӑр ҫыхнӑ хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🤵🏻' => 'каччӑ: сӑран ҫутӑ тӗсӗ',
    '🤵🏼' => 'каччӑ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤵🏽' => 'каччӑ: сӑран вӑтам тонӗ',
    '🤵🏾' => 'каччӑ: сӑран вӑтам тӗксӗм тонӗ',
    '🤵🏿' => 'каччӑ: сӑран тӗксӗм тонӗ',
    '👰🏻' => 'ҫураҫнӑ хӗр: сӑран ҫутӑ тӗсӗ',
    '👰🏼' => 'ҫураҫнӑ хӗр: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👰🏽' => 'ҫураҫнӑ хӗр: сӑран вӑтам тонӗ',
    '👰🏾' => 'ҫураҫнӑ хӗр: сӑран вӑтам тӗксӗм тонӗ',
    '👰🏿' => 'ҫураҫнӑ хӗр: сӑран тӗксӗм тонӗ',
    '🤰🏻' => 'йывӑр хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '🤰🏼' => 'йывӑр хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤰🏽' => 'йывӑр хӗрарӑм: сӑран вӑтам тонӗ',
    '🤰🏾' => 'йывӑр хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '🤰🏿' => 'йывӑр хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🫃🏻' => 'арҫын кӳпчесе кайнӑ: сӑран ҫутӑ тӗсӗ',
    '🫃🏼' => 'арҫын кӳпчесе кайнӑ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫃🏽' => 'арҫын кӳпчесе кайнӑ: сӑран вӑтам тонӗ',
    '🫃🏾' => 'арҫын кӳпчесе кайнӑ: сӑран вӑтам тӗксӗм тонӗ',
    '🫃🏿' => 'арҫын кӳпчесе кайнӑ: сӑран тӗксӗм тонӗ',
    '🫄🏻' => 'йывӑр ҫын: сӑран ҫутӑ тӗсӗ',
    '🫄🏼' => 'йывӑр ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🫄🏽' => 'йывӑр ҫын: сӑран вӑтам тонӗ',
    '🫄🏾' => 'йывӑр ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🫄🏿' => 'йывӑр ҫын: сӑран тӗксӗм тонӗ',
    '🤱🏻' => 'кӑкӑр ӗмӗртни: сӑран ҫутӑ тӗсӗ',
    '🤱🏼' => 'кӑкӑр ӗмӗртни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤱🏽' => 'кӑкӑр ӗмӗртни: сӑран вӑтам тонӗ',
    '🤱🏾' => 'кӑкӑр ӗмӗртни: сӑран вӑтам тӗксӗм тонӗ',
    '🤱🏿' => 'кӑкӑр ӗмӗртни: сӑран тӗксӗм тонӗ',
    '👼🏻' => 'пирӗшти: сӑран ҫутӑ тӗсӗ',
    '👼🏼' => 'пирӗшти: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👼🏽' => 'пирӗшти: сӑран вӑтам тонӗ',
    '👼🏾' => 'пирӗшти: сӑран вӑтам тӗксӗм тонӗ',
    '👼🏿' => 'пирӗшти: сӑран тӗксӗм тонӗ',
    '🎅🏻' => 'Сант-Клаус: сӑран ҫутӑ тӗсӗ',
    '🎅🏼' => 'Сант-Клаус: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🎅🏽' => 'Сант-Клаус: сӑран вӑтам тонӗ',
    '🎅🏾' => 'Сант-Клаус: сӑран вӑтам тӗксӗм тонӗ',
    '🎅🏿' => 'Сант-Клаус: сӑран тӗксӗм тонӗ',
    '🤶🏻' => 'клаус миссис: сӑран ҫутӑ тӗсӗ',
    '🤶🏼' => 'клаус миссис: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤶🏽' => 'клаус миссис: сӑран вӑтам тонӗ',
    '🤶🏾' => 'клаус миссис: сӑран вӑтам тӗксӗм тонӗ',
    '🤶🏿' => 'клаус миссис: сӑран тӗксӗм тонӗ',
    '🦸🏻' => 'супергер: сӑран ҫутӑ тӗсӗ',
    '🦸🏼' => 'супергер: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🦸🏽' => 'супергер: сӑран вӑтам тонӗ',
    '🦸🏾' => 'супергер: сӑран вӑтам тӗксӗм тонӗ',
    '🦸🏿' => 'супергер: сӑран тӗксӗм тонӗ',
    '🦹🏻' => 'йӗксӗк: сӑран ҫутӑ тӗсӗ',
    '🦹🏼' => 'йӗксӗк: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🦹🏽' => 'йӗксӗк: сӑран вӑтам тонӗ',
    '🦹🏾' => 'йӗксӗк: сӑран вӑтам тӗксӗм тонӗ',
    '🦹🏿' => 'йӗксӗк: сӑран тӗксӗм тонӗ',
    '🧙🏻' => 'маг: сӑран ҫутӑ тӗсӗ',
    '🧙🏼' => 'маг: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧙🏽' => 'маг: сӑран вӑтам тонӗ',
    '🧙🏾' => 'маг: сӑран вӑтам тӗксӗм тонӗ',
    '🧙🏿' => 'маг: сӑран тӗксӗм тонӗ',
    '🧚🏻' => 'фея: сӑран ҫутӑ тӗсӗ',
    '🧚🏼' => 'фея: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧚🏽' => 'фея: сӑран вӑтам тонӗ',
    '🧚🏾' => 'фея: сӑран вӑтам тӗксӗм тонӗ',
    '🧚🏿' => 'фея: сӑран тӗксӗм тонӗ',
    '🧛🏻' => 'вампир: сӑран ҫутӑ тӗсӗ',
    '🧛🏼' => 'вампир: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧛🏽' => 'вампир: сӑран вӑтам тонӗ',
    '🧛🏾' => 'вампир: сӑран вӑтам тӗксӗм тонӗ',
    '🧛🏿' => 'вампир: сӑран тӗксӗм тонӗ',
    '🧜🏻' => 'вутӑш: сӑран ҫутӑ тӗсӗ',
    '🧜🏼' => 'вутӑш: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧜🏽' => 'вутӑш: сӑран вӑтам тонӗ',
    '🧜🏾' => 'вутӑш: сӑран вӑтам тӗксӗм тонӗ',
    '🧜🏿' => 'вутӑш: сӑран тӗксӗм тонӗ',
    '🧝🏻' => 'эльф: сӑран ҫутӑ тӗсӗ',
    '🧝🏼' => 'эльф: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧝🏽' => 'эльф: сӑран вӑтам тонӗ',
    '🧝🏾' => 'эльф: сӑран вӑтам тӗксӗм тонӗ',
    '🧝🏿' => 'эльф: сӑран тӗксӗм тонӗ',
    '💆🏻' => 'ҫынна пит массӑлаҫҫӗ: сӑран ҫутӑ тӗсӗ',
    '💆🏼' => 'ҫынна пит массӑлаҫҫӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💆🏽' => 'ҫынна пит массӑлаҫҫӗ: сӑран вӑтам тонӗ',
    '💆🏾' => 'ҫынна пит массӑлаҫҫӗ: сӑран вӑтам тӗксӗм тонӗ',
    '💆🏿' => 'ҫынна пит массӑлаҫҫӗ: сӑран тӗксӗм тонӗ',
    '💇🏻' => 'парикмахер ҫынни: сӑран ҫутӑ тӗсӗ',
    '💇🏼' => 'парикмахер ҫынни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💇🏽' => 'парикмахер ҫынни: сӑран вӑтам тонӗ',
    '💇🏾' => 'парикмахер ҫынни: сӑран вӑтам тӗксӗм тонӗ',
    '💇🏿' => 'парикмахер ҫынни: сӑран тӗксӗм тонӗ',
    '🚶🏻' => 'ҫын килет: сӑран ҫутӑ тӗсӗ',
    '🚶🏼' => 'ҫын килет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚶🏽' => 'ҫын килет: сӑран вӑтам тонӗ',
    '🚶🏾' => 'ҫын килет: сӑран вӑтам тӗксӗм тонӗ',
    '🚶🏿' => 'ҫын килет: сӑран тӗксӗм тонӗ',
    '🧍🏻' => 'ҫын тӑрать: сӑран ҫутӑ тӗсӗ',
    '🧍🏼' => 'ҫын тӑрать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧍🏽' => 'ҫын тӑрать: сӑран вӑтам тонӗ',
    '🧍🏾' => 'ҫын тӑрать: сӑран вӑтам тӗксӗм тонӗ',
    '🧍🏿' => 'ҫын тӑрать: сӑран тӗксӗм тонӗ',
    '🧎🏻' => 'чӗркуҫленсе ларнӑ ҫын: сӑран ҫутӑ тӗсӗ',
    '🧎🏼' => 'чӗркуҫленсе ларнӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧎🏽' => 'чӗркуҫленсе ларнӑ ҫын: сӑран вӑтам тонӗ',
    '🧎🏾' => 'чӗркуҫленсе ларнӑ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧎🏿' => 'чӗркуҫленсе ларнӑ ҫын: сӑран тӗксӗм тонӗ',
    '🏃🏻' => 'ҫын чупать: сӑран ҫутӑ тӗсӗ',
    '🏃🏼' => 'ҫын чупать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏃🏽' => 'ҫын чупать: сӑран вӑтам тонӗ',
    '🏃🏾' => 'ҫын чупать: сӑран вӑтам тӗксӗм тонӗ',
    '🏃🏿' => 'ҫын чупать: сӑран тӗксӗм тонӗ',
    '💃🏻' => 'ташлакан хӗрарӑм: сӑран ҫутӑ тӗсӗ',
    '💃🏼' => 'ташлакан хӗрарӑм: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💃🏽' => 'ташлакан хӗрарӑм: сӑран вӑтам тонӗ',
    '💃🏾' => 'ташлакан хӗрарӑм: сӑран вӑтам тӗксӗм тонӗ',
    '💃🏿' => 'ташлакан хӗрарӑм: сӑран тӗксӗм тонӗ',
    '🕺🏻' => 'ташлакан арҫын: сӑран ҫутӑ тӗсӗ',
    '🕺🏼' => 'ташлакан арҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🕺🏽' => 'ташлакан арҫын: сӑран вӑтам тонӗ',
    '🕺🏾' => 'ташлакан арҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🕺🏿' => 'ташлакан арҫын: сӑран тӗксӗм тонӗ',
    '🕴🏻' => 'сывлӑшра бизнесмен: сӑран ҫутӑ тӗсӗ',
    '🕴🏼' => 'сывлӑшра бизнесмен: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🕴🏽' => 'сывлӑшра бизнесмен: сӑран вӑтам тонӗ',
    '🕴🏾' => 'сывлӑшра бизнесмен: сӑран вӑтам тӗксӗм тонӗ',
    '🕴🏿' => 'сывлӑшра бизнесмен: сӑран тӗксӗм тонӗ',
    '👯🏻' => 'мулкач хӑлхаллӑ ҫынсем: сӑран ҫутӑ тӗсӗ',
    '👯🏼' => 'мулкач хӑлхаллӑ ҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👯🏽' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тонӗ',
    '👯🏾' => 'мулкач хӑлхаллӑ ҫынсем: сӑран вӑтам тӗксӗм тонӗ',
    '👯🏿' => 'мулкач хӑлхаллӑ ҫынсем: сӑран тӗксӗм тонӗ',
    '🧖🏻' => 'мунча ҫынни: сӑран ҫутӑ тӗсӗ',
    '🧖🏼' => 'мунча ҫынни: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧖🏽' => 'мунча ҫынни: сӑран вӑтам тонӗ',
    '🧖🏾' => 'мунча ҫынни: сӑран вӑтам тӗксӗм тонӗ',
    '🧖🏿' => 'мунча ҫынни: сӑран тӗксӗм тонӗ',
    '🧗🏻' => 'ҫын чул хысакӗ тӑрӑх хӑпарать: сӑран ҫутӑ тӗсӗ',
    '🧗🏼' => 'ҫын чул хысакӗ тӑрӑх хӑпарать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧗🏽' => 'ҫын чул хысакӗ тӑрӑх хӑпарать: сӑран вӑтам тонӗ',
    '🧗🏾' => 'ҫын чул хысакӗ тӑрӑх хӑпарать: сӑран вӑтам тӗксӗм тонӗ',
    '🧗🏿' => 'ҫын чул хысакӗ тӑрӑх хӑпарать: сӑран тӗксӗм тонӗ',
    '🏇🏻' => 'сиккелени: сӑран ҫутӑ тӗсӗ',
    '🏇🏼' => 'сиккелени: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏇🏽' => 'сиккелени: сӑран вӑтам тонӗ',
    '🏇🏾' => 'сиккелени: сӑран вӑтам тӗксӗм тонӗ',
    '🏇🏿' => 'сиккелени: сӑран тӗксӗм тонӗ',
    '🏂🏻' => 'сноубордист: сӑран ҫутӑ тӗсӗ',
    '🏂🏼' => 'сноубордист: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏂🏽' => 'сноубордист: сӑран вӑтам тонӗ',
    '🏂🏾' => 'сноубордист: сӑран вӑтам тӗксӗм тонӗ',
    '🏂🏿' => 'сноубордист: сӑран тӗксӗм тонӗ',
    '🏌🏻' => 'гольфист: сӑран ҫутӑ тӗсӗ',
    '🏌🏼' => 'гольфист: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏌🏽' => 'гольфист: сӑран вӑтам тонӗ',
    '🏌🏾' => 'гольфист: сӑран вӑтам тӗксӗм тонӗ',
    '🏌🏿' => 'гольфист: сӑран тӗксӗм тонӗ',
    '🏄🏻' => 'сефинг: сӑран ҫутӑ тӗсӗ',
    '🏄🏼' => 'сефинг: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏄🏽' => 'сефинг: сӑран вӑтам тонӗ',
    '🏄🏾' => 'сефинг: сӑран вӑтам тӗксӗм тонӗ',
    '🏄🏿' => 'сефинг: сӑран тӗксӗм тонӗ',
    '🚣🏻' => 'кӗсмен аври: сӑран ҫутӑ тӗсӗ',
    '🚣🏼' => 'кӗсмен аври: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚣🏽' => 'кӗсмен аври: сӑран вӑтам тонӗ',
    '🚣🏾' => 'кӗсмен аври: сӑран вӑтам тӗксӗм тонӗ',
    '🚣🏿' => 'кӗсмен аври: сӑран тӗксӗм тонӗ',
    '🏊🏻' => 'ишев: сӑран ҫутӑ тӗсӗ',
    '🏊🏼' => 'ишев: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏊🏽' => 'ишев: сӑран вӑтам тонӗ',
    '🏊🏾' => 'ишев: сӑран вӑтам тӗксӗм тонӗ',
    '🏊🏿' => 'ишев: сӑран тӗксӗм тонӗ',
    '⛹🏻' => 'баскетболист: сӑран ҫутӑ тӗсӗ',
    '⛹🏼' => 'баскетболист: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '⛹🏽' => 'баскетболист: сӑран вӑтам тонӗ',
    '⛹🏾' => 'баскетболист: сӑран вӑтам тӗксӗм тонӗ',
    '⛹🏿' => 'баскетболист: сӑран тӗксӗм тонӗ',
    '🏋🏻' => 'йывӑр атлет: сӑран ҫутӑ тӗсӗ',
    '🏋🏼' => 'йывӑр атлет: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏋🏽' => 'йывӑр атлет: сӑран вӑтам тонӗ',
    '🏋🏾' => 'йывӑр атлет: сӑран вӑтам тӗксӗм тонӗ',
    '🏋🏿' => 'йывӑр атлет: сӑран тӗксӗм тонӗ',
    '🚴🏻' => 'велосипедист: сӑран ҫутӑ тӗсӗ',
    '🚴🏼' => 'велосипедист: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚴🏽' => 'велосипедист: сӑран вӑтам тонӗ',
    '🚴🏾' => 'велосипедист: сӑран вӑтам тӗксӗм тонӗ',
    '🚴🏿' => 'велосипедист: сӑран тӗксӗм тонӗ',
    '🚵🏻' => 'ту ҫинчи велосипедлӑ ҫын: сӑран ҫутӑ тӗсӗ',
    '🚵🏼' => 'ту ҫинчи велосипедлӑ ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🚵🏽' => 'ту ҫинчи велосипедлӑ ҫын: сӑран вӑтам тонӗ',
    '🚵🏾' => 'ту ҫинчи велосипедлӑ ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🚵🏿' => 'ту ҫинчи велосипедлӑ ҫын: сӑран тӗксӗм тонӗ',
    '🤸🏻' => 'акробат трюкӗ: сӑран ҫутӑ тӗсӗ',
    '🤸🏼' => 'акробат трюкӗ: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤸🏽' => 'акробат трюкӗ: сӑран вӑтам тонӗ',
    '🤸🏾' => 'акробат трюкӗ: сӑран вӑтам тӗксӗм тонӗ',
    '🤸🏿' => 'акробат трюкӗ: сӑран тӗксӗм тонӗ',
    '🤼🏻' => 'кӗрешӳҫӗсем: сӑран ҫутӑ тӗсӗ',
    '🤼🏼' => 'кӗрешӳҫӗсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤼🏽' => 'кӗрешӳҫӗсем: сӑран вӑтам тонӗ',
    '🤼🏾' => 'кӗрешӳҫӗсем: сӑран вӑтам тӗксӗм тонӗ',
    '🤼🏿' => 'кӗрешӳҫӗсем: сӑран тӗксӗм тонӗ',
    '🤽🏻' => 'шыв урай: сӑран ҫутӑ тӗсӗ',
    '🤽🏼' => 'шыв урай: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤽🏽' => 'шыв урай: сӑран вӑтам тонӗ',
    '🤽🏾' => 'шыв урай: сӑран вӑтам тӗксӗм тонӗ',
    '🤽🏿' => 'шыв урай: сӑран тӗксӗм тонӗ',
    '🤾🏻' => 'гандбол: сӑран ҫутӑ тӗсӗ',
    '🤾🏼' => 'гандбол: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤾🏽' => 'гандбол: сӑран вӑтам тонӗ',
    '🤾🏾' => 'гандбол: сӑран вӑтам тӗксӗм тонӗ',
    '🤾🏿' => 'гандбол: сӑран тӗксӗм тонӗ',
    '🤹🏻' => 'жонглер: сӑран ҫутӑ тӗсӗ',
    '🤹🏼' => 'жонглер: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🤹🏽' => 'жонглер: сӑран вӑтам тонӗ',
    '🤹🏾' => 'жонглер: сӑран вӑтам тӗксӗм тонӗ',
    '🤹🏿' => 'жонглер: сӑран тӗксӗм тонӗ',
    '🧘🏻' => 'лотос пек ларакан ҫын: сӑран ҫутӑ тӗсӗ',
    '🧘🏼' => 'лотос пек ларакан ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🧘🏽' => 'лотос пек ларакан ҫын: сӑран вӑтам тонӗ',
    '🧘🏾' => 'лотос пек ларакан ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🧘🏿' => 'лотос пек ларакан ҫын: сӑран тӗксӗм тонӗ',
    '🛀🏻' => 'ваннӑри ҫын: сӑран ҫутӑ тӗсӗ',
    '🛀🏼' => 'ваннӑри ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🛀🏽' => 'ваннӑри ҫын: сӑран вӑтам тонӗ',
    '🛀🏾' => 'ваннӑри ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🛀🏿' => 'ваннӑри ҫын: сӑран тӗксӗм тонӗ',
    '🛌🏻' => 'кравать ҫинчи ҫын: сӑран ҫутӑ тӗсӗ',
    '🛌🏼' => 'кравать ҫинчи ҫын: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🛌🏽' => 'кравать ҫинчи ҫын: сӑран вӑтам тонӗ',
    '🛌🏾' => 'кравать ҫинчи ҫын: сӑран вӑтам тӗксӗм тонӗ',
    '🛌🏿' => 'кравать ҫинчи ҫын: сӑран тӗксӗм тонӗ',
    '👭🏻' => 'алӑран тытнӑ хӗрарӑмсем: сӑран ҫутӑ тӗсӗ',
    '👭🏼' => 'алӑран тытнӑ хӗрарӑмсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👭🏽' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тонӗ',
    '👭🏾' => 'алӑран тытнӑ хӗрарӑмсем: сӑран вӑтам тӗксӗм тонӗ',
    '👭🏿' => 'алӑран тытнӑ хӗрарӑмсем: сӑран тӗксӗм тонӗ',
    '👫🏻' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран ҫутӑ тӗсӗ',
    '👫🏼' => 'арҫынпа хӗрарӑм алӑран тытать: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👫🏽' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тонӗ',
    '👫🏾' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран вӑтам тӗксӗм тонӗ',
    '👫🏿' => 'арҫынпа хӗрарӑм алӑран тытать: сӑран тӗксӗм тонӗ',
    '👬🏻' => 'алӑран тытнӑ арҫынсем: сӑран ҫутӑ тӗсӗ',
    '👬🏼' => 'алӑран тытнӑ арҫынсем: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '👬🏽' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тонӗ',
    '👬🏾' => 'алӑран тытнӑ арҫынсем: сӑран вӑтам тӗксӗм тонӗ',
    '👬🏿' => 'алӑран тытнӑ арҫынсем: сӑран тӗксӗм тонӗ',
    '💏🏻' => 'чупту: сӑран ҫутӑ тӗсӗ',
    '💏🏼' => 'чупту: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💏🏽' => 'чупту: сӑран вӑтам тонӗ',
    '💏🏾' => 'чупту: сӑран вӑтам тӗксӗм тонӗ',
    '💏🏿' => 'чупту: сӑран тӗксӗм тонӗ',
    '💑🏻' => 'юратса пӑрахнӑ мӑшӑр: сӑран ҫутӑ тӗсӗ',
    '💑🏼' => 'юратса пӑрахнӑ мӑшӑр: ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '💑🏽' => 'юратса пӑрахнӑ мӑшӑр: сӑран вӑтам тонӗ',
    '💑🏾' => 'юратса пӑрахнӑ мӑшӑр: сӑран вӑтам тӗксӗм тонӗ',
    '💑🏿' => 'юратса пӑрахнӑ мӑшӑр: сӑран тӗксӗм тонӗ',
    '🇦🇨' => 'ялав: Вознесени утравӗ',
    '🇦🇩' => 'ялав: Андорра',
    '🇦🇪' => 'ялав: Пӗрлешнӗ Араб Эмирачӗсем',
    '🇦🇫' => 'ялав: Афганистан',
    '🇦🇬' => 'ялав: Антигуапа Барбуда',
    '🇦🇮' => 'ялав: Ангилья',
    '🇦🇱' => 'ялав: Албани',
    '🇦🇲' => 'ялав: Армени',
    '🇦🇴' => 'ялав: Ангола',
    '🇦🇶' => 'ялав: Антарктида',
    '🇦🇷' => 'ялав: Аргентина',
    '🇦🇸' => 'ялав: Америка Самойи',
    '🇦🇹' => 'ялав: Австри',
    '🇦🇺' => 'ялав: Австрали',
    '🇦🇼' => 'ялав: Аруба',
    '🇦🇽' => 'ялав: Аланд утравӗсем',
    '🇦🇿' => 'ялав: Азербайджан',
    '🇧🇦' => 'ялав: Боснипе Герцеговина',
    '🇧🇧' => 'ялав: Барбадос',
    '🇧🇩' => 'ялав: Бангладеш',
    '🇧🇪' => 'ялав: Бельги',
    '🇧🇫' => 'ялав: Буркина-Фасо',
    '🇧🇬' => 'ялав: Болгари',
    '🇧🇭' => 'ялав: Бахрейн',
    '🇧🇮' => 'ялав: Бурунди',
    '🇧🇯' => 'ялав: Бенин',
    '🇧🇱' => 'ялав: Сен-Бартелеми',
    '🇧🇲' => 'ялав: Бермуд утравӗсем',
    '🇧🇳' => 'ялав: Бруней',
    '🇧🇴' => 'ялав: Боливи',
    '🇧🇶' => 'ялав: Бонэйр, Синт-Эстатиуспа Саба',
    '🇧🇷' => 'ялав: Бразили',
    '🇧🇸' => 'ялав: Багама утравӗсем',
    '🇧🇹' => 'ялав: Бутан',
    '🇧🇻' => 'ялав: Буве утравӗ',
    '🇧🇼' => 'ялав: Ботсвана',
    '🇧🇾' => 'ялав: Беларусь',
    '🇧🇿' => 'ялав: Белиз',
    '🇨🇦' => 'ялав: Канада',
    '🇨🇨' => 'ялав: Кокос утравӗсем',
    '🇨🇩' => 'ялав: Конго',
    '🇨🇫' => 'ялав: Вӑта Африка Республики',
    '🇨🇬' => 'ялав: Конго-Браззавиль',
    '🇨🇭' => 'ялав: Швейцари',
    '🇨🇮' => 'ялав: Кот-д’Ивуар',
    '🇨🇰' => 'ялав: Кук утравӗсем',
    '🇨🇱' => 'ялав: Чили',
    '🇨🇲' => 'ялав: Камерун',
    '🇨🇳' => 'ялав: Китай',
    '🇨🇴' => 'ялав: Колумби',
    '🇨🇵' => 'ялав: Клиппертон утравӗ',
    '🇨🇶' => 'ялав: Сарк',
    '🇨🇷' => 'ялав: Коста-Рика',
    '🇨🇺' => 'ялав: Куба',
    '🇨🇻' => 'ялав: Кабо-Верде',
    '🇨🇼' => 'ялав: Кюрасао',
    '🇨🇽' => 'ялав: Раштав утравӗ',
    '🇨🇾' => 'ялав: Кипр',
    '🇨🇿' => 'ялав: Чехи',
    '🇩🇪' => 'ялав: Германи',
    '🇩🇬' => 'ялав: Диего-Гарси',
    '🇩🇯' => 'ялав: Джибути',
    '🇩🇰' => 'ялав: Дани',
    '🇩🇲' => 'ялав: Доминика',
    '🇩🇴' => 'ялав: Доминика Республики',
    '🇩🇿' => 'ялав: Алжир',
    '🇪🇦' => 'ялав: Сеутӑпа Мелили',
    '🇪🇨' => 'ялав: Эквадор',
    '🇪🇪' => 'ялав: Эстони',
    '🇪🇬' => 'ялав: Египет',
    '🇪🇭' => 'ялав: Анӑҫ Сахара',
    '🇪🇷' => 'ялав: Эритрей',
    '🇪🇸' => 'ялав: Испани',
    '🇪🇹' => 'ялав: Эфиопи',
    '🇪🇺' => 'ялав: Европа Пӗрлешӗвӗ',
    '🇫🇮' => 'ялав: Финлянди',
    '🇫🇯' => 'ялав: Фиджи',
    '🇫🇰' => 'ялав: Фолкленд утравӗсем',
    '🇫🇲' => 'ялав: Микронези',
    '🇫🇴' => 'ялав: Фарер утравӗсем',
    '🇫🇷' => 'ялав: Франци',
    '🇬🇦' => 'ялав: Габон',
    '🇬🇧' => 'ялав: Аслӑ Британи',
    '🇬🇩' => 'ялав: Гренада',
    '🇬🇪' => 'ялав: Грузи',
    '🇬🇫' => 'ялав: Франци Гвиани',
    '🇬🇬' => 'ялав: Гернси',
    '🇬🇭' => 'ялав: Гана',
    '🇬🇮' => 'ялав: Гибралтар',
    '🇬🇱' => 'ялав: Гренланди',
    '🇬🇲' => 'ялав: Гамби',
    '🇬🇳' => 'ялав: Гвиней',
    '🇬🇵' => 'ялав: Гваделупа',
    '🇬🇶' => 'ялав: Экваторти Гвинея',
    '🇬🇷' => 'ялав: Греци',
    '🇬🇸' => 'ялав: Кӑнтӑр Георгипе Кӑнтӑр Сандвич утравӗсем',
    '🇬🇹' => 'ялав: Гватемала',
    '🇬🇺' => 'ялав: Гуам',
    '🇬🇼' => 'ялав: Гвиней-Бисау',
    '🇬🇾' => 'ялав: Гайана',
    '🇭🇰' => 'ялав: Гонконг (ЯАР)',
    '🇭🇲' => 'ялав: Хердпа Макдональд утравӗсем',
    '🇭🇳' => 'ялав: Гондурас',
    '🇭🇷' => 'ялав: Хорвати',
    '🇭🇹' => 'ялав: Гаити',
    '🇭🇺' => 'ялав: Венгри',
    '🇮🇨' => 'ялав: Канар утравӗсем',
    '🇮🇩' => 'ялав: Индонези',
    '🇮🇪' => 'ялав: Ирланди',
    '🇮🇱' => 'ялав: Израиль',
    '🇮🇲' => 'ялав: Мэн утравӗ',
    '🇮🇳' => 'ялав: Инди',
    '🇮🇴' => 'ялав: Инди океанӗнчи Британи территорийӗ',
    '🇮🇶' => 'ялав: Ирак',
    '🇮🇷' => 'ялав: Иран',
    '🇮🇸' => 'ялав: Исланди',
    '🇮🇹' => 'ялав: Итали',
    '🇯🇪' => 'ялав: Джерси',
    '🇯🇲' => 'ялав: Ямайка',
    '🇯🇴' => 'ялав: Иордани',
    '🇯🇵' => 'ялав: Япони',
    '🇰🇪' => 'ялав: Кени',
    '🇰🇬' => 'ялав: Кӑркӑсстан',
    '🇰🇭' => 'ялав: Камбоджа',
    '🇰🇮' => 'ялав: Кирибати',
    '🇰🇲' => 'ялав: Комор утравӗсем',
    '🇰🇳' => 'ялав: Сент-Китспа Невис',
    '🇰🇵' => 'ялав: Ҫур ҫӗр Корея',
    '🇰🇷' => 'ялав: Кӑнтӑр Корея',
    '🇰🇼' => 'ялав: Кувейт',
    '🇰🇾' => 'ялав: Кайман утравӗсем',
    '🇰🇿' => 'ялав: Казахстан',
    '🇱🇦' => 'ялав: Лаос',
    '🇱🇧' => 'ялав: Ливан',
    '🇱🇨' => 'ялав: Сент-Люси',
    '🇱🇮' => 'ялав: Лихтенштейн',
    '🇱🇰' => 'ялав: Шри-Ланка',
    '🇱🇷' => 'ялав: Либери',
    '🇱🇸' => 'ялав: Лесото',
    '🇱🇹' => 'ялав: Литва',
    '🇱🇺' => 'ялав: Люксембург',
    '🇱🇻' => 'ялав: Латви',
    '🇱🇾' => 'ялав: Ливи',
    '🇲🇦' => 'ялав: Марокко',
    '🇲🇨' => 'ялав: Монако',
    '🇲🇩' => 'ялав: Молдова',
    '🇲🇪' => 'ялав: Черногори',
    '🇲🇫' => 'ялав: Сен-Мартен',
    '🇲🇬' => 'ялав: Мадагаскар',
    '🇲🇭' => 'ялав: Маршалл утравӗсем',
    '🇲🇰' => 'ялав: Ҫур ҫӗр Македони',
    '🇲🇱' => 'ялав: Мали',
    '🇲🇲' => 'ялав: Мьянма (Бирма)',
    '🇲🇳' => 'ялав: Монголи',
    '🇲🇴' => 'ялав: Макао (ЯАР)',
    '🇲🇵' => 'ялав: Ҫур ҫӗр Мариан утравӗсем',
    '🇲🇶' => 'ялав: Мартиника',
    '🇲🇷' => 'ялав: Мавритани',
    '🇲🇸' => 'ялав: Монтсеррат',
    '🇲🇹' => 'ялав: Мальта',
    '🇲🇺' => 'ялав: Маврики',
    '🇲🇻' => 'ялав: Мальдив',
    '🇲🇼' => 'ялав: Малави',
    '🇲🇽' => 'ялав: Мексика',
    '🇲🇾' => 'ялав: Малайзи',
    '🇲🇿' => 'ялав: Мозамбик',
    '🇳🇦' => 'ялав: Намиби',
    '🇳🇨' => 'ялав: Ҫӗнӗ Каледони',
    '🇳🇪' => 'ялав: Нигер',
    '🇳🇫' => 'ялав: Норфолк утравӗ',
    '🇳🇬' => 'ялав: Нигери',
    '🇳🇮' => 'ялав: Никарагуа',
    '🇳🇱' => 'ялав: Нидерланд',
    '🇳🇴' => 'ялав: Норвеги',
    '🇳🇵' => 'ялав: Непал',
    '🇳🇷' => 'ялав: Науру',
    '🇳🇺' => 'ялав: Ниуэ',
    '🇳🇿' => 'ялав: Ҫӗнӗ Зеланди',
    '🇴🇲' => 'ялав: Оман',
    '🇵🇦' => 'ялав: Панама',
    '🇵🇪' => 'ялав: Перу',
    '🇵🇫' => 'ялав: Франци Полинезийӗ',
    '🇵🇬' => 'ялав: Папуа — Ҫӗнӗ Гвинея',
    '🇵🇭' => 'ялав: Филиппин',
    '🇵🇰' => 'ялав: Пакистан',
    '🇵🇱' => 'ялав: Польша',
    '🇵🇲' => 'ялав: Сен-Пьерпа Микелон',
    '🇵🇳' => 'ялав: Питкэрн утравӗсем',
    '🇵🇷' => 'ялав: Пуэрто-Рико',
    '🇵🇸' => 'ялав: Палестина территорийӗсем',
    '🇵🇹' => 'ялав: Португали',
    '🇵🇼' => 'ялав: Палау',
    '🇵🇾' => 'ялав: Парагвай',
    '🇶🇦' => 'ялав: Катар',
    '🇷🇪' => 'ялав: Реюньон',
    '🇷🇴' => 'ялав: Румыни',
    '🇷🇸' => 'ялав: Серби',
    '🇷🇺' => 'ялав: Раҫҫей',
    '🇷🇼' => 'ялав: Руанда',
    '🇸🇦' => 'ялав: Сауд Аравийӗ',
    '🇸🇧' => 'ялав: Соломон утравӗсем',
    '🇸🇨' => 'ялав: Сейшел утравӗсем',
    '🇸🇩' => 'ялав: Судан',
    '🇸🇪' => 'ялав: Швеци',
    '🇸🇬' => 'ялав: Сингапур',
    '🇸🇭' => 'ялав: Сӑваплӑ Елена утравӗ',
    '🇸🇮' => 'ялав: Словени',
    '🇸🇯' => 'ялав: Шпицбергенпа Ян-Майен',
    '🇸🇰' => 'ялав: Словаки',
    '🇸🇱' => 'ялав: Сьерра-Леоне',
    '🇸🇲' => 'ялав: Сан-Марино',
    '🇸🇳' => 'ялав: Сенегал',
    '🇸🇴' => 'ялав: Сомали',
    '🇸🇷' => 'ялав: Суринам',
    '🇸🇸' => 'ялав: Кӑнтӑр Судан',
    '🇸🇹' => 'ялав: Сан-Томепе Принсипи',
    '🇸🇻' => 'ялав: Сальвадор',
    '🇸🇽' => 'ялав: Синт-Мартен',
    '🇸🇾' => 'ялав: Сири',
    '🇸🇿' => 'ялав: Эсватини',
    '🇹🇦' => 'ялав: Тристан-да-Куни',
    '🇹🇨' => 'ялав: Тёркспа Кайкос утравӗсем',
    '🇹🇩' => 'ялав: Чад',
    '🇹🇫' => 'ялав: Францин Кӑнтӑр территорийӗсем',
    '🇹🇬' => 'ялав: Того',
    '🇹🇭' => 'ялав: Таиланд',
    '🇹🇯' => 'ялав: Таджикистан',
    '🇹🇰' => 'ялав: Токелау',
    '🇹🇱' => 'ялав: Тухӑҫ Тимор',
    '🇹🇲' => 'ялав: Туркменистан',
    '🇹🇳' => 'ялав: Тунис',
    '🇹🇴' => 'ялав: Тонга',
    '🇹🇷' => 'ялав: Турци',
    '🇹🇹' => 'ялав: Тринидадпа Тобаго',
    '🇹🇻' => 'ялав: Тувалу',
    '🇹🇼' => 'ялав: Тайвань',
    '🇹🇿' => 'ялав: Танзани',
    '🇺🇦' => 'ялав: Украина',
    '🇺🇬' => 'ялав: Уганда',
    '🇺🇲' => 'ялав: АПШ-н тулаш пӗчӗк утравӗсем',
    '🇺🇳' => 'ялав: Пӗрлешнӗ Нацисен Организацийӗ',
    '🇺🇸' => 'ялав: Пӗрлешнӗ Штатсем',
    '🇺🇾' => 'ялав: Уругвай',
    '🇺🇿' => 'ялав: Узбекистан',
    '🇻🇦' => 'ялав: Ватикан',
    '🇻🇨' => 'ялав: Сент-Винсентпа Гренада',
    '🇻🇪' => 'ялав: Венесуэла',
    '🇻🇬' => 'ялав: Виргин утравӗсем (Британи)',
    '🇻🇮' => 'ялав: Виргин утравӗсем (АПШ)',
    '🇻🇳' => 'ялав: Вьетнам',
    '🇻🇺' => 'ялав: Вануату',
    '🇼🇫' => 'ялав: Уоллиспа Футуна',
    '🇼🇸' => 'ялав: Самоа',
    '🇽🇰' => 'ялав: Косово',
    '🇾🇪' => 'ялав: Йемен',
    '🇾🇹' => 'ялав: Майотта',
    '🇿🇦' => 'ялав: Кӑнтӑр Африка Республики',
    '🇿🇲' => 'ялав: Замби',
    '🇿🇼' => 'ялав: Зимбабве',
    '🔟' => 'брелок: 10',
    '🏻' => 'сӑран ҫутӑ тӗсӗ',
    '🏼' => 'ӳт-тирӗн вӑтам-ҫутӑ тӗсӗ',
    '🏽' => 'сӑран вӑтам тонӗ',
    '🏾' => 'сӑран вӑтам тӗксӗм тонӗ',
    '🏿' => 'сӑран тӗксӗм тонӗ',
    '😀' => 'анлӑн кулать',
    '😃' => 'кулать',
    '😄' => 'куҫне хупса кулать',
    '😁' => 'телейпе ҫуталать',
    '😆' => 'куҫне хӗссе кулать',
    '😅' => 'ҫилӗллӗн кулать',
    '🤣' => 'каҫса кайсах кулать',
    '😂' => 'куҫҫуль тухичченех кулать',
    '🙂' => 'кӑшт кулакан пит',
    '🙃' => 'кутӑн-пуҫӑн кутӑн',
    '🫠' => 'ирӗлет',
    '😉' => 'куҫ хӗсет',
    '😊' => 'кӑмӑллӑн кулать',
    '😇' => 'нимблӑ',
    '🥰' => 'чӗреллӗ кулӑ',
    '😍' => 'юратса пӑрахнӑ пит',
    '🤩' => 'куҫри ҫӑлтӑрсем',
    '😘' => 'сывлӑш чуптӑвӑвӗ',
    '😗' => 'чуптӑвать',
    '☺' => 'йӑл кулать',
    '😚' => 'куҫа хупса чуптӑвать',
    '😙' => 'телейлӗ чупту',
    '🥲' => 'кулакан пит-куҫ',
    '😋' => 'тутлӑ',
    '😛' => 'чӗлхе кӑтартать',
    '😜' => 'чӗлхине кӑтартать те куҫне хӗсет',
    '🤪' => 'ухмахлашкалакан пит',
    '😝' => 'пит-куҫне пӗркелентерет, чӗлхине кӑтартать',
    '🤑' => 'куҫ умӗнче укҫа',
    '🤗' => 'ыталать',
    '🤭' => 'ҫӑвара аллипе хуплать',
    '🫢' => 'ҫӑварне аллипе хуплать',
    '🫣' => 'пӑхать',
    '🤫' => 'тс-с-с.',
    '🤔' => 'шухӑшлать',
    '🫡' => 'ҫар саламӗ',
    '🤐' => 'калаçмасть',
    '🤨' => 'ӗненмест',
    '😐' => 'пурпӗрех',
    '😑' => 'эмоцисӗр',
    '😶' => 'ҫӑварсӑр пит',
    '🫥' => 'пит-куҫ пунктирпа',
    '😏' => 'кулкалать',
    '😒' => 'кӑмӑлсӑр',
    '🙄' => 'куҫа хупать',
    '😬' => 'гримас',
    '🤥' => 'суеҫӗ',
    '🫨' => 'чӗтревлӗ пит',
    '😌' => 'ҫӑмӑллӑх туять',
    '😔' => 'шухӑшлӑ пит',
    '😪' => 'ҫывӑрас килет',
    '🤤' => 'сӗлеке юхтарать',
    '😴' => 'ҫывӑрать',
    '🫩' => 'куҫ айӗнчи михӗсем',
    '😷' => 'медицина маскипе',
    '🤒' => 'ҫӑвара градусник хыпнӑ',
    '🤕' => 'пуҫне ҫыхнӑ',
    '🤢' => 'хӑсас килет',
    '🤮' => 'хӑсӑк',
    '🤧' => 'апчху тӑвать',
    '🥵' => 'вӗри',
    '🥶' => 'шӑнать',
    '🥴' => 'пуҫ ҫаврӑннине туять',
    '😵' => 'пуҫ ҫаврӑнни',
    '🤯' => 'миме сирпӗнни',
    '🤠' => 'ковбой шлепке тӑхӑннӑ',
    '🥳' => 'вечеринкӑра',
    '🥸' => 'маскировка',
    '😎' => 'хура куҫлӑхлӑ пит',
    '🤓' => 'куҫлӑхҫӑ',
    '🧐' => 'монокльлӗ',
    '😕' => 'пӑтрашу',
    '🫤' => 'ҫӑвар чалӑшнӑ',
    '😟' => 'канӑҫсӑр',
    '🙁' => 'кӑштах хурланать',
    '☹' => 'тӗксӗм',
    '😮' => 'тӗлӗнӳ',
    '😯' => 'илемсӗр сюрприз',
    '😲' => 'шокра',
    '😳' => 'хӗрелет',
    '🫪' => 'пӑсӑк сӑн-пит',
    '🥺' => 'тархаслать',
    '🥹' => 'куҫҫульне аран чарать',
    '😦' => 'тӗлӗннипе',
    '😧' => 'асапланать',
    '😨' => 'хӑрать',
    '😰' => 'хытӑ пӑшӑрханать',
    '😥' => 'иртсе кайрӗ',
    '😢' => 'макӑрать',
    '😭' => 'куҫҫуль юхать',
    '😱' => 'хӑранипе',
    '😖' => 'ҫухалса кай',
    '😣' => 'кутӑнлӑх',
    '😞' => 'кӑмӑлсӑрланни',
    '😓' => 'сивӗ тарпа',
    '😩' => 'ывӑнни',
    '😫' => 'хытӑ ывӑнни',
    '🥱' => 'анаслакан',
    '😤' => 'ӑнӑҫу пуласса кӗтсе',
    '😡' => 'тарӑхать',
    '😠' => 'ҫилленет',
    '🤬' => 'цензура',
    '😈' => 'йӑл кулакан шуйттан',
    '👿' => 'усал шуйттан',
    '💀' => 'пуҫ купташки',
    '☠' => 'пуҫ шӑммипе пуҫ шӑмми',
    '💩' => 'пăх',
    '🤡' => 'клоун',
    '👹' => 'тискер кайӑк',
    '👺' => 'япони гоблинӗ',
    '👻' => 'мӗлке',
    '👽' => 'ют ҫын',
    '👾' => 'космос монстрӗ',
    '🤖' => 'робот',
    '😺' => 'кулакан кушак',
    '😸' => 'ахӑлтатса кулакан кушак',
    '😹' => 'куҫҫуль тухичченех кулакан кушак',
    '😻' => 'юратса пӑрахнӑ кушак аҫи',
    '😼' => 'ейкеленӳ кушак',
    '😽' => 'чуптӑвакан кушак',
    '🙀' => 'шоклӑ кушак',
    '😿' => 'макӑракан кушак',
    '😾' => 'усал кушак',
    '🙈' => 'нимӗн те курмастӑп',
    '🙉' => 'нимӗн те илтместӗп',
    '🙊' => 'никама та нимӗн те каламастӑп',
    '💌' => 'юрату ҫырӑвӗ',
    '💘' => 'ухӑ йӗппи шӑтарнӑ чӗре',
    '💝' => 'хӑюлӑ чӗре',
    '💖' => 'ялтӑркка чӗре',
    '💗' => 'ӳсекен чӗре',
    '💓' => 'тапакан чӗре',
    '💞' => 'ҫаврӑнакан чӗре',
    '💕' => 'икӗ чӗре',
    '💟' => '"чӗре" палли',
    '❣' => 'чӗре евӗрлӗ кӑшкӑру палли',
    '💔' => 'ҫӗмрӗк чӗре',
    '❤' => 'хӗп-хӗрлӗ чӗре',
    '🩷' => 'кӗрен чӗре',
    '🧡' => 'хӗрлӗрех чӗре',
    '💛' => 'сарă чĕре',
    '💚' => 'симӗс чӗре',
    '💙' => 'кӑвак чӗре',
    '🩵' => 'ҫутӑ кӑвак чӗре',
    '💜' => 'хĕрхĕлтĕм чӗре',
    '🤎' => 'хӑмӑр чӗре',
    '🖤' => 'хура чӗре',
    '🩶' => 'сӑрӑ чӗре',
    '🤍' => 'шурӑ чӗре',
    '💋' => 'чуптӑву йӗрӗ',
    '💯' => 'ҫӗр балл',
    '💢' => '"ҫилли" палли',
    '🫯' => 'пӗлӗтпе тытӑҫ',
    '💥' => 'шартлату',
    '💫' => 'ҫаврӑнакан ҫӑлтӑр',
    '💦' => 'тар тумламӗсем',
    '💨' => 'ҫухални',
    '🕳' => 'шӑтӑк',
    '💬' => 'мӑлатуклӑ пӗлӗт',
    '🗨' => 'пушӑ пӗлӗт',
    '🗯' => 'ҫилӗллӗ пӗлӗт',
    '💭' => 'шухӑшлӑ пӗлӗт',
    '💤' => 'тӗлӗк',
    '👋' => 'аллипе сулать',
    '🤚' => 'ҫӗкленӗ алӑ',
    '🖐' => 'карнӑ ал тупанӗ',
    '✋' => 'ҫӗкленӗ ал тупанӗ',
    '🖖' => 'вулкан салючӗ',
    '🫱' => 'алӑ сылтӑмалла',
    '🫲' => 'алӑ сулахаялла',
    '🫳' => 'алтупанӗпе аялалла',
    '🫴' => 'алтупанӗпе ҫӳлелле',
    '🫷' => 'алтупанӗпе сулахаялла',
    '🫸' => 'алтупанӗпе сылтӑмалла',
    '👌' => '"пурте аван"тесе алӑ сулни',
    '🤌' => 'пӗр чӗптӗм',
    '🤏' => '"сахал"алӑ сулни',
    '✌' => 'V алӑ сулни',
    '🤞' => 'хӗреслӗ пӳрнесем',
    '🫰' => '"укҫа" паллă',
    '🤟' => 'эпӗ-сана-юрататӑп',
    '🤘' => 'рокер алӑпа сулни',
    '🤙' => '"шӑнкӑртаттар-ха мана" паллă',
    '👈' => 'сулахаялла кӑтартакан пӳрне',
    '👉' => 'сылтӑмалла кӑтартакан пӳрне',
    '👆' => 'пӳрнене ҫӳлелле кӑтарт',
    '🖕' => 'вӑта пӳрне',
    '👇' => 'пӳрнене аялалла кӑтарт',
    '☝' => 'шӗвӗр пӳрне ҫӳлелле',
    '🫵' => 'шӗвӗр пӳрне',
    '👍' => 'пуҫ пӳрне ҫӳлелле',
    '👎' => 'пуҫ пӳрне аялалла',
    '✊' => 'ҫӗкленӗ чышкӑ',
    '👊' => 'кулак',
    '🤛' => 'чышкӑ сулахаялла',
    '🤜' => 'чышкӑ сылтӑмалла',
    '👏' => 'алӑ ҫупни',
    '🙌' => 'урра',
    '🫶' => '"чӗре"аллипе сулни',
    '👐' => 'алтупанӗсем айккинелле',
    '🤲' => 'ывӑҫ тупанӗсем кимӗпе',
    '🤝' => 'алӑ тытни',
    '🙏' => 'хуҫлатнӑ алӑсем',
    '✍' => 'ҫыракан алӑ',
    '💅' => 'маникюр',
    '🤳' => 'селфи',
    '💪' => 'бицепс',
    '🦾' => 'механика алли',
    '🦿' => 'механика ури',
    '🦵' => 'ура',
    '🦶' => 'пакӑлчак',
    '👂' => 'хӑлха',
    '🦻' => 'хӑлхи',
    '👃' => 'сӑмса',
    '🧠' => 'пуҫ мими',
    '🫀' => 'ҫын чӗри',
    '🫁' => 'ӳпки',
    '🦷' => 'шӑл',
    '🦴' => 'шӑмӑ',
    '👀' => 'куҫ',
    '👁' => 'хӑрах куҫ',
    '👅' => 'чӗлхе',
    '👄' => 'ҫӑвар',
    '🫦' => 'тутана ҫырт',
    '👶' => 'пĕчĕк ача',
    '🧒' => 'ача',
    '👦' => 'арçын ача',
    '👧' => 'хӗрача',
    '🧑' => 'ҫитӗннӗ ҫын',
    '👱' => 'сарӑ ҫӳҫлӗ ҫын',
    '👨' => 'арҫын',
    '🧔' => 'сухаллӑ ҫын',
    '👩' => 'хӗрарӑм',
    '🧓' => 'ватӑрах ҫын',
    '👴' => 'ватӑрах арҫын',
    '👵' => 'ватӑрах хӗрарӑм',
    '🙍' => 'тӗксӗмленнӗ ҫын',
    '🙎' => 'кӳреннӗ ҫын',
    '🙅' => 'ҫын "ҪУК" тесе алӑ сулать',
    '🙆' => 'ҫын "Ҫапла" тесе алӑ сулать',
    '💁' => 'ҫын алӑ туртать',
    '🙋' => 'ҫӗкленӗ ҫын',
    '🧏' => 'хӑлхасӑр ҫын',
    '🙇' => 'ҫын пуҫ таять',
    '🤦' => 'ҫын сӑмах пултарулӑхне ҫухатнӑ',
    '🤷' => 'ҫын хулпуҫҫийӗсене сиктерет',
    '👮' => 'полицейски',
    '🕵' => 'детектив',
    '💂' => 'гвардеец',
    '🥷' => 'ниндзя',
    '👷' => 'строительство',
    '🫅' => 'коронӑллӑ ҫын',
    '🤴' => 'принц',
    '👸' => 'принцесса',
    '👳' => 'тюрбанлӑ ҫын',
    '👲' => 'китай ҫӗлӗк тӑхӑннӑ арҫын',
    '🧕' => 'пуҫне тутӑр ҫыхнӑ хӗрарӑм',
    '🤵' => 'каччӑ',
    '👰' => 'ҫураҫнӑ хӗр',
    '🤰' => 'йывӑр хӗрарӑм',
    '🫃' => 'арҫын кӳпчесе кайнӑ',
    '🫄' => 'йывӑр ҫын',
    '🤱' => 'кӑкӑр ӗмӗртни',
    '👼' => 'пирӗшти',
    '🎅' => 'Сант-Клаус',
    '🤶' => 'клаус миссис',
    '🦸' => 'супергер',
    '🦹' => 'йӗксӗк',
    '🧙' => 'маг',
    '🧚' => 'фея',
    '🧛' => 'вампир',
    '🧜' => 'вутӑш',
    '🧝' => 'эльф',
    '🧞' => 'джинн',
    '🧟' => 'Зомби',
    '🧌' => 'троллӗ',
    '🫈' => 'ҫӑмлӑ чӗрчун',
    '💆' => 'ҫынна пит массӑлаҫҫӗ',
    '💇' => 'парикмахер ҫынни',
    '🚶' => 'ҫын килет',
    '🧍' => 'ҫын тӑрать',
    '🧎' => 'чӗркуҫленсе ларнӑ ҫын',
    '🏃' => 'ҫын чупать',
    '💃' => 'ташлакан хӗрарӑм',
    '🕺' => 'ташлакан арҫын',
    '🕴' => 'сывлӑшра бизнесмен',
    '👯' => 'мулкач хӑлхаллӑ ҫынсем',
    '🧖' => 'мунча ҫынни',
    '🧗' => 'ҫын чул хысакӗ тӑрӑх хӑпарать',
    '🤺' => 'фехтовальщик',
    '🏇' => 'сиккелени',
    '⛷' => 'ту йӗлтӗрӗсем',
    '🏂' => 'сноубордист',
    '🏌' => 'гольфист',
    '🏄' => 'сефинг',
    '🚣' => 'кӗсмен аври',
    '🏊' => 'ишев',
    '⛹' => 'баскетболист',
    '🏋' => 'йывӑр атлет',
    '🚴' => 'велосипедист',
    '🚵' => 'ту ҫинчи велосипедлӑ ҫын',
    '🤸' => 'акробат трюкӗ',
    '🤼' => 'кӗрешӳҫӗсем',
    '🤽' => 'шыв урай',
    '🤾' => 'гандбол',
    '🤹' => 'жонглер',
    '🧘' => 'лотос пек ларакан ҫын',
    '🛀' => 'ваннӑри ҫын',
    '🛌' => 'кравать ҫинчи ҫын',
    '👭' => 'алӑран тытнӑ хӗрарӑмсем',
    '👫' => 'арҫынпа хӗрарӑм алӑран тытать',
    '👬' => 'алӑран тытнӑ арҫынсем',
    '💏' => 'чупту',
    '💑' => 'юратса пӑрахнӑ мӑшӑр',
    '🗣' => 'юратса пӑрахнӑ мӑшӑркалаҫакан пуҫ',
    '👤' => 'ҫын мӗлки',
    '👥' => 'икӗ мӗлке',
    '🫂' => 'ыталашакан ҫынсем',
    '👪' => 'ҫемье',
    '👣' => 'йӗрсем',
    '🫆' => 'пӳрне йӗрӗ',
    '🦰' => 'хӗрлӗ ҫӳҫ',
    '🦱' => 'явӑнчӑк ҫӳҫ',
    '🦳' => 'шурӑ ҫӳҫ',
    '🦲' => 'кукша пуҫ',
    '🐵' => 'упӑте пуҫӗ',
    '🐒' => 'упӑте',
    '🦍' => 'горилла',
    '🦧' => 'орангутан',
    '🐶' => 'йытӑ пуҫӗ',
    '🐕' => 'йытӑ',
    '🦮' => 'чӗлпӗрҫӗ йытӑ',
    '🐩' => 'çăмламас йытă',
    '🐺' => 'кашкӑр пуҫӗ',
    '🦊' => 'тилӗ пуҫӗ',
    '🦝' => 'енот пуҫӗ',
    '🐱' => 'кушак пуҫӗ',
    '🐈' => 'кушак',
    '🦁' => 'арӑслан пуҫӗ',
    '🐯' => 'тигр пуҫӗ',
    '🐅' => 'тигр',
    '🐆' => 'леопард',
    '🐴' => 'лаша пуҫӗ',
    '🫎' => 'пӑши',
    '🫏' => 'ашак',
    '🐎' => 'лаша',
    '🦄' => 'хӑрах мӑйракаллӑ пуҫ',
    '🦓' => 'зебра',
    '🦌' => 'пӑлан',
    '🦬' => 'бизон',
    '🐮' => 'ӗне пуҫӗ',
    '🐂' => 'вӑкӑр',
    '🐃' => 'буйвол',
    '🐄' => 'ӗне',
    '🐷' => 'сысна пуҫӗ',
    '🐖' => 'сысна',
    '🐗' => 'хир сысни',
    '🐽' => 'сысна пилӗк пус',
    '🐏' => 'така',
    '🐑' => 'сурӑх',
    '🐐' => 'качака',
    '🐪' => 'пӗр курпун тӗве',
    '🐫' => 'икӗ курпун тӗве',
    '🦙' => 'лама',
    '🦒' => 'жираф',
    '🐘' => 'слон',
    '🦣' => 'мамонт',
    '🦏' => 'носорог',
    '🦛' => 'гиппопотам',
    '🐭' => 'шӑши пуҫӗ',
    '🐁' => 'шӑши',
    '🐀' => 'йӗкехӳре',
    '🐹' => 'арлан пуҫӗ',
    '🐰' => 'кролик пуҫӗ',
    '🐇' => 'кролик',
    '🐿' => 'бурундук',
    '🦫' => 'бобр',
    '🦔' => 'чӗрӗп',
    '🦇' => 'ҫара ҫерҫи',
    '🐻' => 'упа пуҫӗ',
    '🐨' => 'коал пуҫӗ',
    '🐼' => 'панда пуҫӗ',
    '🦥' => 'кахал',
    '🦦' => 'вӑлта тӑпри',
    '🦨' => 'скунс',
    '🦘' => 'кенгуру',
    '🦡' => 'пурӑш',
    '🐾' => 'чӗрчун йӗрӗ',
    '🦃' => 'инде хӗрарӑмӗ',
    '🐔' => 'чӑх',
    '🐓' => 'автан',
    '🐣' => 'ҫӑмарта чӗппи',
    '🐤' => 'чӑх чӗппи хӑяккӑн',
    '🐥' => 'чӑх чӗппи',
    '🐦' => 'кайӑк',
    '🐧' => 'пингвин',
    '🕊' => 'кӑвакарчӑн',
    '🦅' => 'ӑмӑрткайӑк',
    '🦆' => 'кӑвакал',
    '🦢' => 'акӑш',
    '🦉' => 'тӑмана',
    '🦤' => 'додо',
    '🪶' => 'перо',
    '🦩' => 'фламинго',
    '🦚' => 'павлин',
    '🦜' => 'попугай',
    '🪽' => 'ҫунат',
    '🪿' => 'хур',
    '🐸' => 'шапан пуҫӗ',
    '🐊' => 'крокодил',
    '🐢' => 'тимӗр шапа',
    '🦎' => 'калта',
    '🐍' => 'ҫӗлен',
    '🐲' => 'аҫтаха пуҫӗ',
    '🐉' => 'аҫтаха',
    '🦕' => 'зауропод',
    '🦖' => 'Ти-Рекс',
    '🐳' => 'фонтанлӑ кит',
    '🐋' => 'кит',
    '🐬' => 'дельфин',
    '🫍' => 'косатка',
    '🦭' => 'тюлень',
    '🐟' => 'пулӑ',
    '🐠' => 'тропик пулли',
    '🐡' => 'чӗрӗп пулӑ',
    '🦈' => 'акула',
    '🐙' => 'осьминог',
    '🐚' => 'рак хуранӗ',
    '🪸' => 'корал',
    '🪼' => 'медуза',
    '🦀' => 'краб',
    '🦞' => 'лобстер',
    '🦐' => 'креветка',
    '🦑' => 'кальмар',
    '🦪' => 'устрис',
    '🐌' => 'улитка',
    '🦋' => 'лӗпӗш',
    '🐛' => 'лĕпĕш хурчĕ',
    '🐜' => 'кӑткӑ',
    '🐝' => 'пыл хурчӗ',
    '🪲' => 'нӑрӑ',
    '🐞' => 'турӑ ӗни',
    '🦗' => 'шӑрчӑк',
    '🪳' => 'таракан',
    '🕷' => 'эрешмен',
    '🕸' => 'эрешмен карти',
    '🦂' => 'скорпион',
    '🦟' => 'вăрăмтуна',
    '🪰' => 'шӑна',
    '🪱' => 'хурт',
    '🦠' => 'микроб',
    '💐' => 'чечек ҫыххи',
    '🌸' => 'чие чечекӗ',
    '💮' => 'шурӑ чечек',
    '🪷' => 'лотос',
    '🏵' => 'розетка',
    '🌹' => 'роза',
    '🥀' => 'шаннӑ чечек',
    '🌺' => 'гибискус',
    '🌻' => 'хӗвелҫаврӑнӑш',
    '🌼' => 'чечек',
    '🌷' => 'тюльпан',
    '🪻' => 'гиацинт',
    '🌱' => 'калча',
    '🪴' => 'чӳлмекри ӳсентӑран',
    '🌲' => 'чӑрӑш',
    '🌳' => 'йывӑҫ',
    '🌴' => 'пальма',
    '🌵' => 'кактус',
    '🌾' => 'пучах',
    '🌿' => 'турат',
    '☘' => 'трилистник',
    '🍀' => 'тӑваткаллӑ клевер',
    '🍁' => 'вӗрене ҫулҫи',
    '🍂' => 'ӳкекен ҫулҫӑсем',
    '🍃' => 'ҫил ҫинчи ҫулҫӑсем',
    '🪹' => 'пушӑ йӑва',
    '🪺' => 'ҫӑмарта йӑви',
    '🍄' => 'кӑмпа',
    '🪾' => 'ҫулҫӑсӑр йывӑҫ',
    '🍇' => 'иҫӗм ҫырли',
    '🍈' => 'дыньӑ',
    '🍉' => 'арпус',
    '🍊' => 'мандарин',
    '🍋' => 'лимон',
    '🍌' => 'банан',
    '🍍' => 'ананас',
    '🥭' => 'манго',
    '🍎' => 'хӗрлӗ панулми',
    '🍏' => 'симӗс панулми',
    '🍐' => 'груша',
    '🍑' => 'персик',
    '🍒' => 'чийе ҫырли',
    '🍓' => 'ҫӗр ҫырли',
    '🫐' => 'хура ҫырла',
    '🥝' => 'киви ҫырли',
    '🍅' => 'помидор',
    '🫒' => 'оливка',
    '🥥' => 'кокос',
    '🥑' => 'авокадо',
    '🍆' => 'паклачан',
    '🥔' => 'ҫӗрулми',
    '🥕' => 'кишӗр',
    '🌽' => 'куккурус пуҫӗ',
    '🌶' => 'шӗвӗр пӑрӑҫ',
    '🫑' => 'пӑлхар пӑрӑҫӗ',
    '🥒' => 'хӑйар',
    '🥬' => 'симӗс ҫулҫӑллӑ',
    '🥦' => 'броколи',
    '🧄' => 'ыхра',
    '🧅' => 'сухан',
    '🥜' => 'арахис мӑйӑрӗ',
    '🫘' => 'фасоль',
    '🌰' => 'каштан',
    '🫚' => 'импир тымарӗ',
    '🫛' => 'пӑрҫа хутаҫҫи',
    '🫜' => 'тымар-ҫимӗҫ',
    '🍞' => 'ҫӑкӑр',
    '🥐' => 'круассан',
    '🥖' => 'багет',
    '🫓' => 'пашалу',
    '🥨' => 'кӗлентӗр',
    '🥯' => 'кукӑркка',
    '🥞' => 'икерчӗ',
    '🧇' => 'вафли',
    '🧀' => 'сыр сӑмси',
    '🍖' => 'шӑмӑллӑ какай',
    '🍗' => 'чăх тукмакки',
    '🥩' => 'аш татӑкӗ',
    '🥓' => 'бекон',
    '🍔' => 'кампӑркӗр',
    '🍟' => 'фри ҫӗрулми',
    '🍕' => 'пицца',
    '🌭' => 'хот-дог',
    '🥪' => 'сандвич',
    '🌮' => 'такко',
    '🌯' => 'буррито',
    '🫔' => 'тамале',
    '🥙' => 'шаурма',
    '🧆' => 'фалафель',
    '🥚' => 'ҫӑмарта',
    '🍳' => 'апат хатӗрлени',
    '🥘' => 'ҫатмари рагу',
    '🍲' => 'вӗри апат кастрюлӗ',
    '🫕' => 'фонтӳ',
    '🥣' => 'кашӑк чашӑкӗ',
    '🥗' => 'симӗс салат',
    '🍿' => 'попкорн',
    '🧈' => 'услам ҫу',
    '🧂' => 'тӑвар',
    '🥫' => 'консерва',
    '🍱' => 'бенто',
    '🍘' => 'рис креккӗрӗ',
    '🍙' => 'рис чӑмӑркки',
    '🍚' => 'пӗҫернӗ рис',
    '🍛' => 'карри рисӗ',
    '🍜' => 'йӑсӑрланса ларакан чашӑк',
    '🍝' => 'спагетти',
    '🍠' => 'ӑшаланӑ пылак ҫӗрулми',
    '🍢' => 'оден',
    '🍣' => 'суҫҫи',
    '🍤' => 'ӑшӑланӑ креветка',
    '🍥' => 'камабоко',
    '🥮' => 'уйӑх кукӑлӗ',
    '🍡' => 'данго',
    '🥟' => 'ҫӑмах',
    '🥠' => 'ытарлӑ печени',
    '🥡' => 'искаймалли хутӑҫ',
    '🍦' => 'ҫемҫе пылак пӑр',
    '🍧' => 'пӑр саваланчӑк',
    '🍨' => 'пылак пӑр',
    '🍩' => 'пончик',
    '🍪' => 'печени',
    '🎂' => 'ҫуралнӑ кун торчӗ',
    '🍰' => 'тăпăркка печени',
    '🧁' => 'кекс',
    '🥧' => 'кукӑль',
    '🍫' => 'шӑккалат плитки',
    '🍬' => 'канфет',
    '🍭' => 'леденец',
    '🍮' => 'пудинг',
    '🍯' => 'пыл',
    '🍼' => 'ача бутылки',
    '🥛' => 'пӗр стакан сӗт',
    '☕' => 'вӗри ӗҫмелли',
    '🫖' => 'чейнӗк',
    '🍵' => 'аврисӗр чей курки',
    '🍶' => 'сакке',
    '🍾' => 'шампански',
    '🍷' => 'эрех бокалӗ',
    '🍸' => 'коктейль бокалӗ',
    '🍹' => 'тропикла ӗҫмелли',
    '🍺' => 'сӑра курки',
    '🍻' => 'шаклатакан кружкӑсем',
    '🥂' => 'шаклатакан бокалсем',
    '🥃' => 'тӑнлавлӑ стакан',
    '🫗' => 'шӑнкӑракан шыв',
    '🥤' => 'улӑм пӗрчиллӗ курка',
    '🧋' => 'хӑмпӑллӑ чей',
    '🧃' => 'ӗҫмеллисен кирпечӗ',
    '🧉' => 'тус',
    '🧊' => 'пӑр',
    '🥢' => 'шакки',
    '🍽' => 'вилкӑпа ҫӗҫӗ тата турилкке',
    '🍴' => 'вилкӑпа ҫӗҫӗ',
    '🥄' => 'кашӑк',
    '🔪' => 'апатламалли ҫӗҫӗ',
    '🫙' => 'банка',
    '🏺' => 'амхура',
    '🌍' => 'Европӑпа Африка кӑтартакан глобус',
    '🌎' => 'Мӑшӑр Америка кӑтартакан глобус',
    '🌏' => 'Аҫипе Австрали кӑтартакан глобус',
    '🌐' => 'меридианпӑлла глобус',
    '🗺' => 'тӗнче картти',
    '🗾' => 'Йаппуни картти',
    '🧭' => 'компас',
    '🏔' => 'юр ҫӗлӗклӗ ту',
    '⛰' => 'ту',
    '🛘' => 'упаленӳ',
    '🌋' => 'вулккан',
    '🗻' => 'Фудзи тӑвӗ',
    '🏕' => 'уйлӑх',
    '🏖' => 'сунчӑклӑ пляж',
    '🏜' => 'пушхир',
    '🏝' => 'ҫын пурӑнман утрав',
    '🏞' => 'наци паркӗ',
    '🏟' => 'стадион',
    '🏛' => 'классикӑллӑ ҫурт',
    '🏗' => 'ҫурт хывни',
    '🧱' => 'кирпӗч',
    '🪨' => 'чул',
    '🪵' => 'йывӑҫ материалсем',
    '🛖' => 'хӳшӗ',
    '🏘' => 'килте',
    '🏚' => 'пӑрахӑҫа тухнӑ ҫурт',
    '🏠' => 'ҫурт',
    '🏡' => 'сад ҫурчӗ',
    '🏢' => 'ухвис ҫурчӗ',
    '🏣' => 'япони почти',
    '🏤' => 'пуштӑ уйрӑмӗ',
    '🏥' => 'сыватӑш',
    '🏦' => 'банк',
    '🏨' => 'хӑна ҫурчӗ',
    '🏩' => 'йурату оттелӗ',
    '🏪' => 'магаҫин',
    '🏫' => 'шкул',
    '🏬' => 'универсаллӑ магаҫин',
    '🏭' => 'хапрӑк',
    '🏯' => 'Йаппунла карман',
    '🏰' => 'карман',
    '💒' => 'мӑшӑрланни',
    '🗼' => 'Токкйо башни',
    '🗽' => 'Ирӗклӗх статуйи',
    '⛪' => 'чиркӳ',
    '🕌' => 'мичет',
    '🛕' => 'индуист храмӗ',
    '🕍' => 'синагога',
    '⛩' => 'синтонизм храмӗ',
    '🕋' => 'каап',
    '⛲' => 'пӗрхӗнчӗк',
    '⛺' => 'чатӑр',
    '🌁' => 'тӗтреллӗ',
    '🌃' => 'ҫӑлтӑрлӑ каҫ',
    '🏙' => 'ҫӗрлехи хула',
    '🌄' => 'ту тӑрринчи хӗвел тухӑҫӗ',
    '🌅' => 'хӗвелтухӑҫ',
    '🌆' => 'хулари хӗвеланӑҫ',
    '🌇' => 'хӗвеланӑҫ',
    '🌉' => 'ҫӗрле кӗпер',
    '♨' => 'вӗри ҫӑлкуҫ',
    '🎠' => 'чуччу лаши',
    '🛝' => 'ача-пӑча тӑвӗ',
    '🎡' => 'обоз урапи',
    '🎢' => 'америка тӑвӗсем',
    '💈' => 'парикмахерски',
    '🎪' => 'цирк чатӑрӗ',
    '🚂' => 'локомотив',
    '🚃' => 'чукун ҫул вакунӗ',
    '🚄' => 'хӑвӑрт ҫӳрекен пуйӑс',
    '🚅' => 'хӑвӑртлӑх пуйӑс',
    '🚆' => 'пуйӑс',
    '🚇' => 'метро',
    '🚈' => 'ҫӑмӑл рельс',
    '🚉' => 'станци',
    '🚊' => 'трамвай',
    '🚝' => 'хӑрах релӗс',
    '🚞' => 'туҫи чукун ҫулӗ',
    '🚋' => 'трамвай вакунӗ',
    '🚌' => 'автобус',
    '🚍' => 'автобус малта',
    '🚎' => 'троллейбус',
    '🚐' => 'микроавтобус',
    '🚑' => 'васкавлӑ пулӑшу',
    '🚒' => 'пушар машини',
    '🚓' => 'полици машини',
    '🚔' => 'полици машини малта',
    '🚕' => 'такси',
    '🚖' => 'такси малта',
    '🚗' => 'самоход',
    '🚘' => 'малта автомобиль',
    '🚙' => 'джип',
    '🛻' => 'пикап',
    '🚚' => 'грузовик',
    '🚛' => 'фура',
    '🚜' => 'трактӑр',
    '🏎' => 'хӑваламалли автомобиль',
    '🏍' => 'мотоцикл',
    '🛵' => 'мотороллер',
    '🦽' => 'кресло-алӑпа кӳме',
    '🦼' => 'моторлӑ кресло',
    '🛺' => 'авторикша',
    '🚲' => 'велосипед',
    '🛴' => 'самокат',
    '🛹' => 'скейтборд',
    '🛼' => 'ролик конькисем',
    '🚏' => 'автобус чарӑнӑвӗ',
    '🛣' => 'автомагистраль',
    '🛤' => 'чукун ҫул',
    '🛢' => 'нефт пички',
    '⛽' => 'хутма насусӗ',
    '🛞' => 'кустӑрма',
    '🚨' => 'мигал хӗрарӑмӗ',
    '🚥' => 'горизонталлӑ ҫутӑфор',
    '🚦' => 'вертикаллӑ ҫутӑфор',
    '🛑' => 'стоп палӑ',
    '🚧' => 'строительство ӗҫӗсем',
    '⚓' => 'йаккӑр',
    '🛟' => 'ункӑ буйӗ',
    '⛵' => 'парӑслӑ кимӗ',
    '🛶' => 'каноэ',
    '🚤' => 'каттӗр',
    '🛳' => 'пассашир карапӗ',
    '⛴' => 'парум',
    '🛥' => 'моторлӑ кимӗ',
    '🚢' => 'карап',
    '✈' => 'вӗҫмек',
    '🛩' => 'пӗчӗк вӗҫмек',
    '🛫' => 'вӗҫсе хӑпарни',
    '🛬' => 'анса ларни',
    '🪂' => 'парашут',
    '💺' => 'ларкӑч',
    '🚁' => 'пӑрӑммак',
    '🚟' => 'ҫакӑнса тӑракан чугун ҫул',
    '🚠' => 'фуникулер вагонӗ',
    '🚡' => 'канат ҫулӗ',
    '🛰' => 'спутник',
    '🚀' => 'ракета',
    '🛸' => 'вӗҫекен турилкке',
    '🛎' => 'гостиница шӑнкӑравӗ',
    '🧳' => 'пакаш',
    '⌛' => 'хӑйӑр сехечӗ',
    '⏳' => 'вӑхӑт кайрӗ',
    '⌚' => 'ал сехечӗ',
    '⏰' => 'вӑраткӑч',
    '⏱' => 'секундомер',
    '⏲' => 'таймӗр сехет',
    '🕰' => 'камин сехечӗ',
    '🕛' => 'вуникӗ сехет',
    '🕧' => 'вуниккӗ-ҫурӑ',
    '🕐' => 'пӗр сехет',
    '🕜' => 'пӗрре-ҫурӑ',
    '🕑' => 'икӗ сехет',
    '🕝' => 'иккӗ-ҫурӑ',
    '🕒' => 'виҫӗ сехет',
    '🕞' => 'виҫҫӗ-ҫурӑ',
    '🕓' => 'тӑватӑ сехет',
    '🕟' => 'тӑваттӑ-ҫурӑ',
    '🕔' => 'пилӗк сехет',
    '🕠' => 'пиллӗк-ҫурӑ',
    '🕕' => 'ултӑ сехет',
    '🕡' => 'улттӑ-ҫурӑ',
    '🕖' => 'ҫичӗ сехет',
    '🕢' => 'ҫиччӗ-ҫурӑ',
    '🕗' => 'сакӑр сехет',
    '🕣' => 'саккӑр-ҫурӑ',
    '🕘' => 'тӑхӑр сехет',
    '🕤' => 'тӑххӑр-ҫурӑ',
    '🕙' => 'вунӑ сехет',
    '🕥' => 'вуннӑ-ҫурӑ',
    '🕚' => 'вунпӗр сехет',
    '🕦' => 'вунпӗр-ҫурӑ',
    '🌑' => 'ҫӗнӗ уйӑх',
    '🌒' => 'ҫамрӑк уйӑх',
    '🌓' => 'пӗрремӗш чӗрӗк уйӑх',
    '🌔' => 'килсе ҫитнӗ уйӑх',
    '🌕' => 'тулли уйӑх',
    '🌖' => 'чакакан уйӑх',
    '🌗' => 'уйӑх юлашки чӗрӗкре',
    '🌘' => 'ватӑ уйӑх',
    '🌙' => 'ҫур уйӑх',
    '🌚' => 'пит-куҫлӑ ҫӗнӗ уйӑх',
    '🌛' => 'пит-куҫлӑ уйӑх пӗрремӗш чӗрӗкӗ',
    '🌜' => 'пит-куҫлӑ уйӑх юлашки чӗрӗкӗ',
    '🌡' => 'термометр',
    '☀' => 'хӗвел',
    '🌝' => 'тулли уйӑх пит',
    '🌞' => 'пит-куҫлӑ хӗвел',
    '🪐' => 'ункӑллӑ планета',
    '⭐' => 'ҫӑлтӑр',
    '🌟' => 'йӑлтӑркка ҫӑлтӑр',
    '🌠' => 'ӳкекен ҫӑлтӑр',
    '🌌' => 'хуркайӑк ҫулӗ',
    '☁' => 'пӗлӗт',
    '⛅' => 'пӗлӗтсем хыҫӗнчи хӗвел',
    '⛈' => 'аслатиллӗ ҫумӑр',
    '🌤' => 'пӗлӗт хыҫӗнче хӗвел',
    '🌥' => 'пӗлӗт хыҫӗнчи хӗвел',
    '🌦' => 'суккӑр ҫумӑр',
    '🌧' => 'ҫумӑр',
    '🌨' => 'юр',
    '🌩' => 'ҫиҫӗм',
    '🌪' => 'торнадо',
    '🌫' => 'тӗтре',
    '🌬' => 'ҫил вӗрет',
    '🌀' => 'циклон',
    '🌈' => 'асамат кӗперӗ',
    '🌂' => 'хупӑ сунчӑк',
    '☂' => 'сунчӑк',
    '☔' => 'ҫумӑр айӗнче сунчӑк',
    '⛱' => 'пляж сунчӑкӗ',
    '⚡' => 'пысӑк напряжени',
    '❄' => 'йур пӗрчи',
    '☃' => 'йур кӗлетки',
    '⛄' => 'юрлӑ юр',
    '☄' => 'комета',
    '🔥' => 'вут-ҫулӑм',
    '💧' => 'тумлам',
    '🌊' => 'шыв хумӗ',
    '🎃' => 'кавӑн хунарӗ',
    '🎄' => 'Раштав елки',
    '🎆' => 'фейерверк',
    '🎇' => 'бенгал вучӗ',
    '🧨' => 'петарт',
    '✨' => 'йӑлтӑркка',
    '🎈' => 'сывлӑш шарӗ',
    '🎉' => 'шартлак',
    '🎊' => 'конфетти шарӗ',
    '🎋' => 'танабат йывӑҫӗ',
    '🎍' => 'капӑрлатнӑ бамбук',
    '🎎' => 'япони пуканисем',
    '🎏' => 'карпов евӗрлӗ вымпелсем',
    '🎐' => 'ҫил музыки',
    '🎑' => 'Уйӑх уявӗ',
    '🧧' => 'хӗрлӗ конверт',
    '🎀' => 'хӑйу',
    '🎁' => 'парне',
    '🎗' => 'асӑнмалӑх лента',
    '🎟' => 'билетсем',
    '🎫' => 'билет',
    '🎖' => 'ҫар медалӗ',
    '🏆' => 'кубок',
    '🏅' => 'спорт медалӗ',
    '🥇' => 'ылтӑн медаль',
    '🥈' => 'кӗмӗл медаль',
    '🥉' => 'бронза медаль',
    '⚽' => 'футбол мечӗкӗ',
    '⚾' => 'бейсбол',
    '🥎' => 'софтбол',
    '🏀' => 'баскетбол',
    '🏐' => 'волейбол',
    '🏈' => 'америка футболӗ',
    '🏉' => 'регби',
    '🎾' => 'теннис',
    '🥏' => 'вӗҫекен диск',
    '🎳' => 'боулинг',
    '🏏' => 'крикет вӑййи',
    '🏑' => 'курӑк ҫинчи хоккей',
    '🏒' => 'хоккей',
    '🥍' => 'лакросс',
    '🏓' => 'пинг-понг',
    '🏸' => 'бадминтон',
    '🥊' => 'боксер перчетки',
    '🥋' => 'спорт кимонӗ',
    '🥅' => 'хапха тетелӗ',
    '⛳' => 'гольф',
    '⛸' => 'коньки',
    '🎣' => 'вӑлта',
    '🤿' => 'чӗлӗмлӗ маска',
    '🎽' => 'чупмалли кӗпешке',
    '🎿' => 'йӗлтӗр',
    '🛷' => 'ҫуна',
    '🥌' => 'керлинг чулӗ',
    '🎯' => 'мишень',
    '🪀' => 'йо-йо',
    '🪁' => 'хут ҫӗлен',
    '🔫' => 'шыв пистолечӗ',
    '🎱' => 'бильярд',
    '🔮' => 'хрусталь шар',
    '🪄' => 'асам патакки',
    '🎮' => 'курмаллӑ вӑйӑ',
    '🕹' => 'чойстик',
    '🎰' => 'вӑйӑ автомачӗ',
    '🎲' => 'вылямалли шӑмӑ',
    '🧩' => 'пуҫватмӑш татки',
    '🧸' => 'плюш мишка',
    '🪅' => 'пинйата',
    '🪩' => 'тӗкӗрлӗ шар',
    '🪆' => 'матрешка',
    '♠' => 'курак карт тӗсӗ',
    '♥' => 'чӗрӗ карт тӗсӗ',
    '♦' => 'кирпӗч карт тӗсӗ',
    '♣' => 'хӗрес карт тӗсӗ',
    '♟' => 'шахмат пешки',
    '🃏' => 'шут',
    '🀄' => 'маджонг',
    '🎴' => 'чечек картти',
    '🎭' => 'маскӑсем',
    '🖼' => 'рамкӑллӑ картин',
    '🎨' => 'сӑрлӑ палитра',
    '🧵' => 'ҫип катушки',
    '🪡' => 'ҫӗвӗ йӗппи',
    '🧶' => 'ҫӑмха',
    '🪢' => 'тӗвӗ',
    '👓' => 'куҫлӑх',
    '🕶' => 'хӗвел хӳтӗлекен куҫлӑх',
    '🥽' => 'симӗс куҫлӑх',
    '🥼' => 'лаборатори халачӗ',
    '🦺' => 'хӳтӗлев шилечӗ',
    '👔' => 'калстук',
    '👕' => 'кӗпешке',
    '👖' => 'джинссем',
    '🧣' => 'шарф',
    '🧤' => 'перчетке',
    '🧥' => 'пальто',
    '🧦' => 'нуски',
    '👗' => 'кӗпе',
    '👘' => 'кимоно',
    '🥻' => 'сари',
    '🩱' => 'пӗтӗм шыва кӗмелли вырӑн',
    '🩲' => 'шӑраткӑҫ',
    '🩳' => 'шортӑ',
    '👙' => 'бикини',
    '👚' => 'хӗрарӑм тум-тирӗ',
    '🪭' => 'хуҫланакан ал веерӗ',
    '👛' => 'йенчӗк',
    '👜' => 'сумка',
    '👝' => 'клатч',
    '🛍' => 'хут хутаҫ',
    '🎒' => 'руксак',
    '🩴' => 'тонг сандалийӗ',
    '👞' => 'арҫын пушмакӗ',
    '👟' => 'чупмак',
    '🥾' => 'треккинг ботинки',
    '🥿' => 'балеткӑсем',
    '👠' => 'кӗлеллӗ туфли',
    '👡' => 'хӗрарӑм сандалийӗ',
    '🩰' => 'балет туфли',
    '👢' => 'хӗреарӑм атти',
    '🪮' => 'афро-ту хысакӗ',
    '👑' => 'корона',
    '👒' => 'хӗрарӑм шлепки',
    '🎩' => 'чӗлинтӑр',
    '🎓' => 'кӑларӑм калпакӗ',
    '🧢' => 'бейсбол хӗрарӑмӗ',
    '🪖' => 'ҫар шлемӗ',
    '⛑' => 'ҫӑлакан каски',
    '📿' => 'кӗлӗ шӑрҫи',
    '💄' => 'тута писевӗ',
    '💍' => 'ҫӗрӗ',
    '💎' => 'хаклӑ йышши чул',
    '🔇' => 'шӑплатнӑ йанраткӑч',
    '🔈' => 'шӑппӑн йанӑракан йанраткӑч',
    '🔉' => 'вӑтам йанӑракан йанраткӑч',
    '🔊' => 'хытӑ йанӑракан йанраткӑч',
    '📢' => 'громкоговоритель',
    '📣' => 'мегафон',
    '📯' => 'пуштӑ кавалӗ',
    '🔔' => 'чан',
    '🔕' => 'чалӑш туртнӑ шӑнкӑрав',
    '🎼' => 'мусӑк партитури',
    '🎵' => 'муcӑк ноти',
    '🎶' => 'мусӑк нотисем',
    '🎙' => 'студи микрофонӗ',
    '🎚' => 'шутаркӑч',
    '🎛' => 'регуляторсем',
    '🎤' => 'микрофон',
    '🎧' => 'хӑлхалӑх',
    '📻' => 'радио',
    '🎷' => 'саксофон',
    '🎺' => 'труба',
    '🪊' => 'тромбон',
    '🪗' => 'аккордеон',
    '🎸' => 'гитар',
    '🎹' => 'мусӑк клавиатури',
    '🎻' => 'сӗрме купӑс',
    '🪕' => 'панчо',
    '🥁' => 'параппан',
    '🪘' => 'вӑрӑм параппан',
    '🪇' => 'мараккас',
    '🪈' => 'флейта',
    '🪉' => 'арфа',
    '📱' => 'мобиллӗ телефон',
    '📲' => 'кӗрекенни',
    '☎' => 'телефон',
    '📞' => 'телефон трубки',
    '📟' => 'пӑйчӑр',
    '📠' => 'факс аппарачӗ',
    '🔋' => 'аккумулятор',
    '🪫' => 'заряд лутра шайӗ',
    '🔌' => 'чикме',
    '💻' => 'ноутбук',
    '🖥' => 'сӗтелҫи компйутӑр',
    '🖨' => 'принтер',
    '⌨' => 'пускӑч хӑми',
    '🖱' => 'компьютер шӑшийӗ',
    '🖲' => 'трек шарикӗ',
    '💽' => 'компйутӑр дискӗ',
    '💾' => 'ҫемҫе диск',
    '💿' => 'оптика дискӗ',
    '📀' => 'двд диск',
    '🧮' => 'шӑрҫа шучӗ',
    '🎥' => 'кинокамера',
    '🎞' => 'филӗмри катӑрсем',
    '📽' => 'кинопроектор',
    '🎬' => 'шартлатакан хӑма',
    '📺' => 'телевидени',
    '📷' => 'камера',
    '📸' => 'ҫуткаҫлӑ камера',
    '📹' => 'видеокамера',
    '📼' => 'видеокассет',
    '🔍' => 'сулахайалла тайӑлнӑ луппӑ',
    '🔎' => 'сылтӑмалла тайӑлнӑ луппӑ',
    '🕯' => 'ҫурта',
    '💡' => 'лампочка',
    '🔦' => 'хунар',
    '🏮' => 'хӗрлӗ хут хунар',
    '🪔' => 'дийа лампи',
    '📔' => 'ҫырмалли кӗнеке',
    '📕' => 'хупнӑ кӗнеке',
    '📖' => 'уҫнӑ кӗнеке',
    '📗' => 'симӗс кӗнеке',
    '📘' => 'кӑвак кӗнеке',
    '📙' => 'хӗрлӗ-сарӑ кӗнеке',
    '📚' => 'кӗнеке',
    '📓' => 'тетрадь',
    '📒' => 'блокнот',
    '📃' => 'авӑнчӑклӑ страница',
    '📜' => 'ҫавӑру',
    '📄' => 'страница',
    '📰' => 'хаҫат',
    '🗞' => 'чӗркенӗ хаҫат',
    '📑' => 'заклад стикерӗсем',
    '🔖' => 'саклат хуни',
    '🏷' => 'бирка',
    '🪙' => 'укҫа',
    '💰' => 'укҫа хутаҫи',
    '🪎' => 'мул арчи',
    '💴' => 'йӑн банкноти',
    '💵' => 'доллар банкноти',
    '💶' => 'евро банкноти',
    '💷' => 'фунт банкноти',
    '💸' => 'ҫунатлӑ банкнот',
    '💳' => 'кредит картти',
    '🧾' => 'квитанци',
    '💹' => 'йӑн',
    '✉' => 'конверт',
    '📧' => 'эл. пуштӑ',
    '📨' => 'кӗрекен ҫыру',
    '📩' => 'пӗтекен ҫыру',
    '📤' => 'тухакансем',
    '📥' => 'кӗрекенсем',
    '📦' => 'посылка',
    '📫' => 'ялав ҫӗкленӗ хупӑ почта ещӗкӗ',
    '📪' => 'ялав усӑнтарнӑ хупӑ почта ещӗкӗ',
    '📬' => 'ялав ҫӗкленӗ уҫӑ почта ещӗкӗ',
    '📭' => 'ялав уснӑ уҫӑ почта ещӗкӗ',
    '📮' => 'пуштӑ йешчӗкӗ',
    '🗳' => 'суйлав урни',
    '✏' => 'кӑранташ',
    '✒' => 'хура перо',
    '🖋' => 'пероллӑ авторучка',
    '🖊' => 'ручка',
    '🖌' => 'кистек',
    '🖍' => 'тӗслӗ кӑранташ',
    '📝' => 'заметка',
    '💼' => 'портфель',
    '📁' => 'папка',
    '📂' => 'уҫӑ папка',
    '🗂' => 'маркировка папкисем',
    '📅' => 'калентар',
    '📆' => 'татӑк календарь',
    '🗒' => 'перекетлӗ блокнот',
    '🗓' => 'перкелешӳллӗ календарь',
    '📇' => 'оргайзер',
    '📈' => 'ӳсӗм диаграмми',
    '📉' => 'ӳкнӗ диаграмма',
    '📊' => 'гистограмма',
    '📋' => 'ылмашу пухвӗрӗ',
    '📌' => 'кнопка',
    '📍' => 'ҫаврака кнопка',
    '📎' => 'хӗстеркӗч',
    '🖇' => 'скрепкӑсем',
    '📏' => 'линейка',
    '📐' => 'виҫкӗтеслӗх линейка',
    '✂' => 'хачӑ',
    '🗃' => 'картотека',
    '🗄' => 'картотека шкапӗ',
    '🗑' => 'ҫӳп-ҫап витри',
    '🔒' => 'питӗрӗнчӗк',
    '🔓' => 'питӗрмен',
    '🔏' => 'питӗрӗнчӗк тата перо',
    '🔐' => 'питӗрӗнчӗк тата уҫҫи',
    '🔑' => 'клавиш',
    '🗝' => 'кивӗ ҫӑраҫҫи',
    '🔨' => 'мӑлатук',
    '🪓' => 'пуртӑ',
    '⛏' => 'кирка',
    '⚒' => 'мӑлатукпа кирка',
    '🛠' => 'мӑлатукпа шӗрӗп уҫҫи',
    '🗡' => 'кинчал',
    '⚔' => 'хӗресленӗ хӗҫ',
    '💣' => 'бомба',
    '🪃' => 'бумеранг',
    '🏹' => 'ухӑпа ҫӗмрен',
    '🛡' => 'хулккан',
    '🪚' => 'пӑчкӑ',
    '🔧' => 'шӗрӗп уҫҫи',
    '🪛' => 'пӑркӑч',
    '🔩' => 'шӗрӗппе болт',
    '⚙' => 'шестерне',
    '🗜' => 'хӗскӗч',
    '⚖' => 'шайлашу шкали',
    '🦯' => 'шурӑ туйа',
    '🔗' => 'каҫӑ',
    '⛓' => 'сӑнчӑр',
    '🪝' => 'ҫекӗл',
    '🧰' => 'инструмент ещӗкӗ',
    '🧲' => 'магнит',
    '🪜' => 'пусма',
    '🪏' => 'кӗреҫе',
    '⚗' => 'йухтаркӑч',
    '🧪' => 'пробирка',
    '🧫' => 'петри чашки',
    '🧬' => 'днк',
    '🔬' => 'микроскоп',
    '🔭' => 'телескоп',
    '📡' => 'спутник антенни',
    '💉' => 'шприц',
    '🩸' => 'йун тумламӗ',
    '💊' => 'пилюля',
    '🩹' => 'пластырь',
    '🩼' => 'каклишке',
    '🩺' => 'стетоскоп',
    '🩻' => 'рентген пайӑрки',
    '🚪' => 'алӑк',
    '🛗' => 'лифт',
    '🪞' => 'тӗкӗр',
    '🪟' => 'чӳрече',
    '🛏' => 'крават',
    '🛋' => 'диванпа лампа',
    '🪑' => 'кресла',
    '🚽' => 'шунтӑ',
    '🪠' => 'поршень',
    '🚿' => 'душ',
    '🛁' => 'ванна',
    '🪤' => 'шӑши таппи',
    '🪒' => 'бритва',
    '🧴' => 'лосйон флаконӗ',
    '🧷' => 'йуплӗ йӗп',
    '🧹' => 'шӑпӑр',
    '🧺' => 'пӗрне',
    '🧻' => 'хут рулонӗ',
    '🪣' => 'витре',
    '🧼' => 'супӑнь',
    '🫧' => 'хӑмпӑ',
    '🪥' => 'шӑл шчетки',
    '🧽' => 'губка',
    '🧯' => 'пушар сӳнтеркӗҫӗ',
    '🛒' => 'магаҫин урапи',
    '🚬' => 'ҫихарет',
    '⚰' => 'тупӑк',
    '🪦' => 'масар чулӗ',
    '⚱' => 'пытару урни',
    '🧿' => 'насар амулечӗ',
    '🪬' => 'хамса',
    '🗿' => 'кӗлетке',
    '🪧' => 'плаккат',
    '🪪' => 'çын камне çирĕплетекен хут',
    '🏧' => 'банкомат палли',
    '🚮' => 'ҫӳп-ҫапа урнӑна пӑрахӑр',
    '🚰' => 'ӗҫмелли шыв',
    '♿' => '"инвалидсем валли" палли',
    '🚹' => 'арҫын туалечӗ',
    '🚺' => 'хӗрарӑм туалечӗ',
    '🚻' => 'уборнӑй',
    '🚼' => 'кипкеле пӳлӗм',
    '🚾' => 'туалет',
    '🛂' => 'паспорт тӗрӗслевӗ',
    '🛃' => 'таможня',
    '🛄' => 'багаж илни',
    '🛅' => 'манӑҫнӑ багаж',
    '⚠' => 'асӑрхаттару значокӗ',
    '🚸' => '"ачасем"палли',
    '⛔' => 'кӗме чарнӑ',
    '🚫' => 'чарнӑ',
    '🚳' => 'чӗркеленчӗк велосипед',
    '🚭' => 'туртма чарнӑ',
    '🚯' => 'ҫӳп-ҫап ан тӑкӑр',
    '🚱' => 'шывсӑр шыв',
    '🚷' => 'ҫул ҫӳреме чарнӑ',
    '📵' => 'мобиль телефонӗсене чарнӑ',
    '🔞' => 'вунсакӑр ҫултан аслӑрах ҫынсем',
    '☢' => 'радиаци',
    '☣' => 'биологи хӑрушлӑхӗ',
    '⬆' => 'хулӑн стрелка ҫӳлелле',
    '↗' => 'стрелка сылтӑмалла-ҫӳлелле',
    '➡' => 'хулӑн стрелка сылтӑмалла',
    '↘' => 'стрелка сылтӑмалла-аялалла',
    '⬇' => 'хулӑн йӗппи аялалла',
    '↙' => 'стрелка сулахаялла-аялалла',
    '⬅' => 'хулӑн стрелка сулахаялла',
    '↖' => 'стрелка сулахаялла-ҫӳлелле',
    '↕' => 'стрелка ҫӳлелле-аялалла',
    '↔' => 'стрелка сулахаялла-сылтӑмалла',
    '↩' => 'стрелка сулахаялла пӑрӑнчӗ',
    '↪' => 'стрелка сылтӑмалла пӑрӑнчӗ',
    '⤴' => 'стрелка сылтӑмалла кукӑрӑлса ҫӳлелле',
    '⤵' => 'стрелка аялалла пӑрӑнчӗ',
    '🔃' => 'сехет йӗппи',
    '🔄' => 'сехет стрелкине хирӗҫ',
    '🔙' => '"каялла" стрелка',
    '🔚' => '"вӗҫӗ" стрелка',
    '🔛' => '"активлӑ" стрелка',
    '🔜' => '"часах" стрелка',
    '🔝' => '"ҫиеле" стрелка',
    '🛐' => 'тӗн',
    '⚛' => 'атом символӗ',
    '🕉' => 'ом',
    '✡' => 'Давид ҫӑлтӑрӗ',
    '☸' => 'дхар урапи',
    '☯' => 'иь-ян',
    '✝' => 'латин хӗресӗ',
    '☦' => 'православи хӗресӗ',
    '☪' => 'ҫӑлтӑрпа ҫур уйӑх',
    '☮' => 'тӑнӑҫ палли',
    '🕎' => 'менора',
    '🔯' => 'ултӑ кӗтеслӗ ҫӑлтӑр',
    '🪯' => 'кханда',
    '♈' => 'Сурӑх зодиак палли',
    '♉' => 'Пӑру зодиак палли',
    '♊' => 'Йӗкӗреш зодиак палли',
    '♋' => 'Рак зодиак палли',
    '♌' => 'Арӑслан зодиак палли',
    '♍' => 'Хӗр зодиак палли',
    '♎' => 'Тараса зодиакӗ',
    '♏' => 'Скорпион зодиак палли',
    '♐' => 'Зодиак палли Стрелец',
    '♑' => 'Зодиак козерог палли',
    '♒' => 'Водоль зодиак палли',
    '♓' => 'Пулӑ зодиак палли',
    '⛎' => 'Ҫӗлен Йӑтса Ҫӳрекен зодиак палли',
    '🔀' => 'ӑнсӑртран суйласа илни',
    '🔁' => 'тепӗр хут',
    '🔂' => 'пӗр юррӑн тепӗр хут кала',
    '▶' => 'ӳкерчӗк',
    '⏩' => 'перемотка',
    '⏭' => 'тепӗр трек',
    '⏯' => 'пауза ӳкерчӗкӗ',
    '◀' => 'реверс',
    '⏪' => 'пӑрамат',
    '⏮' => 'малтанхи трек',
    '🔼' => 'виҫкӗтеслӗх шӗвӗр вӗҫлӗ ҫӳлелле',
    '⏫' => 'шӗвӗр вӗҫлӗ икӗ виҫкӗтеслӗх ҫӳлелле',
    '🔽' => 'виҫкӗтеслӗх шӗвӗр вӗҫлӗ аялла',
    '⏬' => 'шӗвӗр вӗҫлӗ икӗ виҫкӗтеслӗх аяла',
    '⏸' => 'чарăну',
    '⏹' => 'çитет',
    '⏺' => 'ҫырса илни',
    '⏏' => 'кӑларса ывӑтни',
    '🎦' => 'видео çырса пыни',
    '🔅' => 'лутра ҫутӑ',
    '🔆' => 'ҫӳллӗ ҫутӑ',
    '📶' => 'тетел сигналӗ',
    '🛜' => 'пралуксӑр тетел',
    '📳' => 'вибраци режимӗ',
    '📴' => 'сӳнтернӗ телефон',
    '♀' => 'хӗрарӑм символӗхӗрарӑм палли',
    '♂' => 'арҫын палли',
    '⚧' => 'трансгендер',
    '✖' => 'хутламалли палли',
    '➕' => 'кӗлетке палли',
    '➖' => 'вулав палли',
    '➗' => 'пайлану шултра палли',
    '🟰' => 'пӗртанлӑхӑн ҫуллӑ палли',
    '♾' => 'вӗҫсӗр-хӗрсӗрлӗх',
    '‼' => 'икӗ кӑшкӑру палли',
    '⁉' => 'кӑшкӑру-ыйту палли',
    '❓' => 'хӗрлӗ ыйту палли',
    '❔' => 'шурӑ ыйту палли',
    '❕' => 'шурӑ кӑшкӑру палли',
    '❗' => 'хӗрлӗ кӑшкӑру палли',
    '〰' => 'хумлӑ-хумлӑ йӗр',
    '💱' => 'валюта улӑштарни',
    '💲' => 'доллар ҫуллӑ палли',
    '⚕' => 'медицина символӗ',
    '♻' => 'утилизаци',
    '⚜' => 'геральд лилийӗ',
    '🔱' => 'трезубец',
    '📛' => 'бейдж',
    '🔰' => 'ҫӗнӗлӗх символӗ',
    '⭕' => 'хӗрлӗ ункӑ',
    '✅' => 'шурӑ ҫӑмах',
    '☑' => 'тӑваткал ҫӑмах',
    '✔' => 'паллă',
    '❌' => 'хӗрес',
    '❎' => '"хӗрес"кнопка',
    '➰' => 'йӑлӑ',
    '➿' => 'икӗ йӑлӑ',
    '〽' => 'урӑх сасӑ кӗрет',
    '✳' => 'сакӑр вӗҫлӗ ҫӑлтӑр',
    '✴' => 'сакӑр кӗтеслӗ ҫӑлтӑр',
    '❇' => 'хӗлхем',
    '™' => 'тавар палли',
    '🫟' => 'вараланчӑк',
    '🔠' => 'прописк кӗртни',
    '🔡' => 'йӗркепе кӳрт',
    '🔢' => 'цифрӑсем кӗртни',
    '🔣' => 'символсене кӗртни',
    '🔤' => 'латиницӑпа кӗртни',
    '🅰' => 'юн иккӗмӗш ушкӑнӗ',
    '🆎' => 'юн тӑваттӑмӗш ушкӑнӗ',
    '🅱' => 'юн виҫҫӗмӗш ушкӑнӗ',
    '🆑' => '"тасат" кнопка',
    '🆒' => '"чӑнкӑ" палли',
    '🆓' => '"тӳлевсӗр" палли',
    'ℹ' => 'информаци палли',
    '🆔' => '"идентификаци" палли',
    'Ⓜ' => 'кружкӑри "м" саспалли',
    '🆕' => '"çĕнĕ" палли',
    '🆖' => '"юрамасть" палли',
    '🅾' => 'юн пӗрремӗш ушкӑнӗ',
    '🆗' => '"Килӗшетӗп" палли',
    '🅿' => 'парклавăш',
    '🆘' => 'SOS пулӑшма палли',
    '🆙' => '"ҫӗнетӳ" палли',
    '🆚' => '"хирӗҫ" значок',
    '🈁' => '"кунта" значок',
    '🈂' => 'пулӑшу хакӗ',
    '🈷' => 'уйӑх',
    '🈶' => 'тӳлевлӗ',
    '🈯' => 'бронӑланӑ',
    '🉐' => 'ӑнӑҫлӑ килӗшӳ',
    '🈹' => 'ҫӑмӑллӑх',
    '🈚' => 'тӳлевсӗр',
    '🈲' => 'чар',
    '🉑' => 'ирӗклӗх',
    '🈸' => 'заявка',
    '🈴' => 'иртсе ҫӳремелли балл',
    '🈳' => 'вырӑн пур',
    '㊗' => 'саламлани',
    '㊙' => 'вӑрттӑнлӑх',
    '🈺' => 'уҫҫӑнах',
    '🈵' => 'вырӑн ҫук',
    '🔴' => 'хӗрлӗ ҫаврашка',
    '🟠' => 'хӗрлӗрех ҫаврашка',
    '🟡' => 'сарӑ ҫаврашка',
    '🟢' => 'симӗс ҫаврашка',
    '🔵' => 'сенкер ҫаврашка',
    '🟣' => 'кӑвак ҫаврашка',
    '🟤' => 'хӑмӑр ҫаврашка',
    '⚫' => 'хура ҫаврашка',
    '⚪' => 'шурӑ ҫаврашка',
    '🟥' => 'хӗрлӗ тӑваткал',
    '🟧' => 'хӗрлӗрех тӑваткал',
    '🟨' => 'сарӑ тӑваткал',
    '🟩' => 'симӗс тӑваткал',
    '🟦' => 'кӑвак тӑваткал',
    '🟪' => 'хĕрлĕ-кăвак тӑваткал',
    '🟫' => 'хӑмӑр тӑваткал',
    '⬛' => 'пысӑк хура тӑваткал',
    '⬜' => 'пысӑк шурӑ тӑваткал',
    '◼' => 'хура тӑваткал',
    '◻' => 'шурӑ тӑваткал',
    '◾' => 'пысӑках мар хура тӑваткал',
    '◽' => 'пысӑках мар шурӑ тӑваткал',
    '▪' => 'хура пӗчӗк тӑваткал',
    '▫' => 'шурӑ пӗчӗк тӑваткал',
    '🔶' => 'сарӑ пысӑк ромб',
    '🔷' => 'пысӑк сенкер ромб',
    '🔸' => 'хӗрлӗрех сарӑ ромб',
    '🔹' => 'пысӑках мар сенкер ромб',
    '🔺' => 'виҫкӗтеслӗх ҫӳлелле',
    '🔻' => 'виҫкӗтеслӗх',
    '💠' => 'пӑнчӑллӑ ромб',
    '🔘' => 'ҫаврака паллă',
    '🔳' => 'шурӑ рамкӑллӑ кнопка',
    '🔲' => 'хура рамкӑллӑ кнопка',
    '🏁' => 'клеткӑллӑ ялав',
    '🚩' => 'виҫкӗтеслӗ ялав',
    '🎌' => 'хӗреслӗ ялавсем',
    '🏴' => 'хура ялав',
    '🏳' => 'шурӑ ялав',
];
