<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'ምስዓም፦ ሰብ፣ ሰብ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏻‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏻‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏻‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏻‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏻‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏼‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏼‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏼‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏼‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏽‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏽‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏽‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏽‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏾‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏾‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏾‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏾‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏿‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏿‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏿‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏿‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏻‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏻‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏻‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏼‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏼‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏼‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏼‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏽‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏽‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏽‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏽‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏾‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏾‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏾‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏾‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏿‍❤‍💋‍👨🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏿‍❤‍💋‍👨🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏿‍❤‍💋‍👨🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏿‍❤‍💋‍👨🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍❤‍💋‍👨🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍❤‍💋‍👩🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏻‍❤‍💋‍👩🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏻‍❤‍💋‍👩🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏻‍❤‍💋‍👩🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍❤‍💋‍👩🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏼‍❤‍💋‍👩🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍❤‍💋‍👩🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏼‍❤‍💋‍👩🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏼‍❤‍💋‍👩🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏼‍❤‍💋‍👩🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏽‍❤‍💋‍👩🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏽‍❤‍💋‍👩🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍❤‍💋‍👩🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏽‍❤‍💋‍👩🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏽‍❤‍💋‍👩🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏾‍❤‍💋‍👩🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏾‍❤‍💋‍👩🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏾‍❤‍💋‍👩🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍❤‍💋‍👩🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏾‍❤‍💋‍👩🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏿‍❤‍💋‍👩🏻' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏿‍❤‍💋‍👩🏼' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏿‍❤‍💋‍👩🏽' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏿‍❤‍💋‍👩🏾' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍❤‍💋‍👩🏿' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🫯‍🧑🏼' => 'ሰባት እናተቓለሱ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏻‍🫯‍🧑🏽' => 'ሰባት እናተቓለሱ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏻‍🫯‍🧑🏾' => 'ሰባት እናተቓለሱ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🫯‍🧑🏿' => 'ሰባት እናተቓለሱ፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍🫯‍🧑🏻' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🫯‍🧑🏽' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏼‍🫯‍🧑🏾' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍🫯‍🧑🏿' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍🫯‍🧑🏻' => 'ሰባት እናተቓለሱ፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏽‍🫯‍🧑🏼' => 'ሰባት እናተቓለሱ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🫯‍🧑🏾' => 'ሰባት እናተቓለሱ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍🫯‍🧑🏿' => 'ሰባት እናተቓለሱ፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏾‍🫯‍🧑🏻' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏾‍🫯‍🧑🏼' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏾‍🫯‍🧑🏽' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🫯‍🧑🏿' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🫯‍🧑🏻' => 'ሰባት እናተቓለሱ፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏿‍🫯‍🧑🏼' => 'ሰባት እናተቓለሱ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏿‍🫯‍🧑🏽' => 'ሰባት እናተቓለሱ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏿‍🫯‍🧑🏾' => 'ሰባት እናተቓለሱ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍❤‍🧑🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏻‍❤‍🧑🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏻‍❤‍🧑🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍❤‍🧑🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍❤‍🧑🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍❤‍🧑🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏼‍❤‍🧑🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍❤‍🧑🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍❤‍🧑🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏽‍❤‍🧑🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍❤‍🧑🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍❤‍🧑🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏾‍❤‍🧑🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏾‍❤‍🧑🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏾‍❤‍🧑🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍❤‍🧑🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍❤‍🧑🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏿‍❤‍🧑🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏿‍❤‍🧑🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏿‍❤‍🧑🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰብ፣ ሰብ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🐰‍🧑🏼' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏻‍🐰‍🧑🏽' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏻‍🐰‍🧑🏾' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🐰‍🧑🏿' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍🐰‍🧑🏻' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🐰‍🧑🏽' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏼‍🐰‍🧑🏾' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍🐰‍🧑🏿' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍🐰‍🧑🏻' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏽‍🐰‍🧑🏼' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🐰‍🧑🏾' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍🐰‍🧑🏿' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏾‍🐰‍🧑🏻' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏾‍🐰‍🧑🏼' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏾‍🐰‍🧑🏽' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🐰‍🧑🏿' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🐰‍🧑🏻' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏿‍🐰‍🧑🏼' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏿‍🐰‍🧑🏽' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏿‍🐰‍🧑🏾' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🫯‍👨🏼' => 'ደቂ ተባዕትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏻‍🫯‍👨🏽' => 'ደቂ ተባዕትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏻‍🫯‍👨🏾' => 'ደቂ ተባዕትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🫯‍👨🏿' => 'ደቂ ተባዕትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏼‍🫯‍👨🏻' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🫯‍👨🏽' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏼‍🫯‍👨🏾' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏼‍🫯‍👨🏿' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏽‍🫯‍👨🏻' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏽‍🫯‍👨🏼' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🫯‍👨🏾' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏽‍🫯‍👨🏿' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏾‍🫯‍👨🏻' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏾‍🫯‍👨🏼' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏾‍🫯‍👨🏽' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🫯‍👨🏿' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🫯‍👨🏻' => 'ደቂ ተባዕትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏿‍🫯‍👨🏼' => 'ደቂ ተባዕትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏿‍🫯‍👨🏽' => 'ደቂ ተባዕትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏿‍🫯‍👨🏾' => 'ደቂ ተባዕትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏻‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏻‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏻‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏻‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏻‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏼‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏼‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏼‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏼‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏽‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏽‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏽‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏽‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏾‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏾‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏾‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏾‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏿‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏿‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏿‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏿‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🐰‍👨🏼' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏻‍🐰‍👨🏽' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏻‍🐰‍👨🏾' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🐰‍👨🏿' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏼‍🐰‍👨🏻' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🐰‍👨🏽' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏼‍🐰‍👨🏾' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏼‍🐰‍👨🏿' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏽‍🐰‍👨🏻' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏽‍🐰‍👨🏼' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🐰‍👨🏾' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏽‍🐰‍👨🏿' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏾‍🐰‍👨🏻' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏾‍🐰‍👨🏼' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏾‍🐰‍👨🏽' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🐰‍👨🏿' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🐰‍👨🏻' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏿‍🐰‍👨🏼' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏿‍🐰‍👨🏽' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏿‍🐰‍👨🏾' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🫯‍👩🏼' => 'ደቂ ኣንስትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏻‍🫯‍👩🏽' => 'ደቂ ኣንስትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏻‍🫯‍👩🏾' => 'ደቂ ኣንስትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🫯‍👩🏿' => 'ደቂ ኣንስትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏼‍🫯‍👩🏻' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🫯‍👩🏽' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏼‍🫯‍👩🏾' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏼‍🫯‍👩🏿' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏽‍🫯‍👩🏻' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏽‍🫯‍👩🏼' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🫯‍👩🏾' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏽‍🫯‍👩🏿' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏾‍🫯‍👩🏻' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏾‍🫯‍👩🏼' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏾‍🫯‍👩🏽' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🫯‍👩🏿' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🫯‍👩🏻' => 'ደቂ ኣንስትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏿‍🫯‍👩🏼' => 'ደቂ ኣንስትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏿‍🫯‍👩🏽' => 'ደቂ ኣንስትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏿‍🫯‍👩🏾' => 'ደቂ ኣንስትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏻‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏻‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏻‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏼‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏼‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏼‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏼‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏽‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏽‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏽‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏽‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏾‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏾‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏾‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏾‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏿‍❤‍👨🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏿‍❤‍👨🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏿‍❤‍👨🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏿‍❤‍👨🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍❤‍👨🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍❤‍👩🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏻‍❤‍👩🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏻‍❤‍👩🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏻‍❤‍👩🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍❤‍👩🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏼‍❤‍👩🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍❤‍👩🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏼‍❤‍👩🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏼‍❤‍👩🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏼‍❤‍👩🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏽‍❤‍👩🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏽‍❤‍👩🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍❤‍👩🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏽‍❤‍👩🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏽‍❤‍👩🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏾‍❤‍👩🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏾‍❤‍👩🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏾‍❤‍👩🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍❤‍👩🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏾‍❤‍👩🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏿‍❤‍👩🏻' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏿‍❤‍👩🏼' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏿‍❤‍👩🏽' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏿‍❤‍👩🏾' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍❤‍👩🏿' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🐰‍👩🏼' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏻‍🐰‍👩🏽' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏻‍🐰‍👩🏾' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🐰‍👩🏿' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏼‍🐰‍👩🏻' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🐰‍👩🏽' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏼‍🐰‍👩🏾' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏼‍🐰‍👩🏿' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏽‍🐰‍👩🏻' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏽‍🐰‍👩🏼' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🐰‍👩🏾' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏽‍🐰‍👩🏿' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏾‍🐰‍👩🏻' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏾‍🐰‍👩🏼' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏾‍🐰‍👩🏽' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🐰‍👩🏿' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🐰‍👩🏻' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏿‍🐰‍👩🏼' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏿‍🐰‍👩🏽' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏿‍🐰‍👩🏾' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🤝‍🧑🏻' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏻‍🤝‍🧑🏼' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏻‍🤝‍🧑🏽' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏻‍🤝‍🧑🏾' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🤝‍🧑🏿' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍🤝‍🧑🏻' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🤝‍🧑🏼' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏼‍🤝‍🧑🏽' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏼‍🤝‍🧑🏾' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏼‍🤝‍🧑🏿' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍🤝‍🧑🏻' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏽‍🤝‍🧑🏼' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🤝‍🧑🏽' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏽‍🤝‍🧑🏾' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏽‍🤝‍🧑🏿' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏾‍🤝‍🧑🏻' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏾‍🤝‍🧑🏼' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏾‍🤝‍🧑🏽' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🤝‍🧑🏾' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏾‍🤝‍🧑🏿' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🤝‍🧑🏻' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🧑🏿‍🤝‍🧑🏼' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏿‍🤝‍🧑🏽' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏿‍🤝‍🧑🏾' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🤝‍🧑🏿' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🤝‍👩🏼' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏻‍🤝‍👩🏽' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏻‍🤝‍👩🏾' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🤝‍👩🏿' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏼‍🤝‍👩🏻' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🤝‍👩🏽' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏼‍🤝‍👩🏾' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏼‍🤝‍👩🏿' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏽‍🤝‍👩🏻' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏽‍🤝‍👩🏼' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🤝‍👩🏾' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏽‍🤝‍👩🏿' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏾‍🤝‍👩🏻' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏾‍🤝‍👩🏼' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏾‍🤝‍👩🏽' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🤝‍👩🏿' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🤝‍👩🏻' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏿‍🤝‍👩🏼' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏿‍🤝‍👩🏽' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏿‍🤝‍👩🏾' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🤝‍👨🏼' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏻‍🤝‍👨🏽' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏻‍🤝‍👨🏾' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🤝‍👨🏿' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏼‍🤝‍👨🏻' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🤝‍👨🏽' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏼‍🤝‍👨🏾' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏼‍🤝‍👨🏿' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏽‍🤝‍👨🏻' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏽‍🤝‍👨🏼' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🤝‍👨🏾' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏽‍🤝‍👨🏿' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👩🏾‍🤝‍👨🏻' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏾‍🤝‍👨🏼' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏾‍🤝‍👨🏽' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🤝‍👨🏿' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🤝‍👨🏻' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👩🏿‍🤝‍👨🏼' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏿‍🤝‍👨🏽' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👩🏿‍🤝‍👨🏾' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🤝‍👨🏼' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏻‍🤝‍👨🏽' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏻‍🤝‍👨🏾' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🤝‍👨🏿' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏼‍🤝‍👨🏻' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🤝‍👨🏽' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏼‍🤝‍👨🏾' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏼‍🤝‍👨🏿' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏽‍🤝‍👨🏻' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏽‍🤝‍👨🏼' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🤝‍👨🏾' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏽‍🤝‍👨🏿' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '👨🏾‍🤝‍👨🏻' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏾‍🤝‍👨🏼' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏾‍🤝‍👨🏽' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🤝‍👨🏿' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🤝‍👨🏻' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '👨🏿‍🤝‍👨🏼' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏿‍🤝‍👨🏽' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '👨🏿‍🤝‍👨🏾' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩‍❤‍💋‍👨' => 'ምስዓም፦ ሰበይቲ፣ ሰብኣይ',
    '👨‍❤‍💋‍👨' => 'ምስዓም፦ ሰብኣይ፣ ሰብኣይ',
    '👩‍❤‍💋‍👩' => 'ምስዓም፦ ሰበይቲ፣ ሰበይቲ',
    '👨‍👩‍👧‍👦' => 'ስድራ፦ ሰብኣይ፣ ሰበይቲ፣ ጓል፣ ወዲ',
    '👨‍👩‍👦‍👦' => 'ስድራ፦ ሰብኣይ፣ ሰበይቲ፣ ወዲ፣ ወዲ',
    '👨‍👩‍👧‍👧' => 'ስድራ፦ ሰብኣይ፣ ሰበይቲ፣ ጓል፣ ጓል',
    '👨‍👨‍👧‍👦' => 'ስድራ፦ ሰብኣይ፣ ሰብኣይ፣ ጓል፣ ወዲ',
    '👨‍👨‍👦‍👦' => 'ስድራ፦ ሰብኣይ፣ ሰብኣይ፣ ወዲ፣ ወዲ',
    '👨‍👨‍👧‍👧' => 'ስድራ፦ ሰብኣይ፣ ሰብኣይ፣ ጓል፣ ጓል',
    '👩‍👩‍👧‍👦' => 'ስድራ፦ ሰበይቲ፣ ሰበይቲ፣ ጓል፣ ወዲ',
    '👩‍👩‍👦‍👦' => 'ስድራ፦ ሰበይቲ፣ ሰበይቲ፣ ወዲ፣ ወዲ',
    '👩‍👩‍👧‍👧' => 'ስድራ፦ ሰበይቲ፣ ሰበይቲ፣ ጓል፣ ጓል',
    '🧑‍🧑‍🧒‍🧒' => 'ስድራቤት፡ ዓቢ፡ ዓቢ፡ ቆልዓ፡ ቆልዓ',
    '🚶🏻‍♀‍➡' => 'ሰበይቲ እናተጓዕዘት፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🚶🏼‍♀‍➡' => 'ሰበይቲ እናተጓዕዘት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🚶🏽‍♀‍➡' => 'ሰበይቲ እናተጓዕዘት፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🚶🏾‍♀‍➡' => 'ሰበይቲ እናተጓዕዘት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🚶🏿‍♀‍➡' => 'ሰበይቲ እናተጓዕዘት፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🚶🏻‍♂‍➡' => 'ሰብኣይ እናተጓዕዘ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🚶🏼‍♂‍➡' => 'ሰብኣይ እናተጓዕዘ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🚶🏽‍♂‍➡' => 'ሰብኣይ እናተጓዕዘ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🚶🏾‍♂‍➡' => 'ሰብኣይ እናተጓዕዘ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🚶🏿‍♂‍➡' => 'ሰብኣይ እናተጓዕዘ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧎🏻‍♀‍➡' => 'ሰበይቲ ተንበርኪኻ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🧎🏼‍♀‍➡' => 'ሰበይቲ ተንበርኪኻ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧎🏽‍♀‍➡' => 'ሰበይቲ ተንበርኪኻ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧎🏾‍♀‍➡' => 'ሰበይቲ ተንበርኪኻ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧎🏿‍♀‍➡' => 'ሰበይቲ ተንበርኪኻ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧎🏻‍♂‍➡' => 'ሰብኣይ ተንበርኪኹ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🧎🏼‍♂‍➡' => 'ሰብኣይ ተንበርኪኹ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧎🏽‍♂‍➡' => 'ሰብኣይ ተንበርኪኹ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧎🏾‍♂‍➡' => 'ሰብኣይ ተንበርኪኹ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧎🏿‍♂‍➡' => 'ሰብኣይ ተንበርኪኹ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏻‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏼‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧑🏽‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧑🏾‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏿‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👨🏻‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '👨🏼‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👨🏽‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👨🏾‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👨🏿‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👩🏻‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '👩🏼‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👩🏽‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👩🏾‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👩🏿‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏻‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏼‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧑🏽‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧑🏾‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏿‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👨🏻‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '👨🏼‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👨🏽‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👨🏾‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👨🏿‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👩🏻‍🦼‍➡' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '👩🏼‍🦼‍➡' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👩🏽‍🦼‍➡' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👩🏾‍🦼‍➡' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👩🏿‍🦼‍➡' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏻‍🦽‍➡' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏼‍🦽‍➡' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧑🏽‍🦽‍➡' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧑🏾‍🦽‍➡' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏿‍🦽‍➡' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👨🏻‍🦽‍➡' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '👨🏼‍🦽‍➡' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👨🏽‍🦽‍➡' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👨🏾‍🦽‍➡' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👨🏿‍🦽‍➡' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👩🏻‍🦽‍➡' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '👩🏼‍🦽‍➡' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👩🏽‍🦽‍➡' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '👩🏾‍🦽‍➡' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👩🏿‍🦽‍➡' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🏃🏻‍♀‍➡' => 'ሰበይቲ ትጎዪ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🏃🏼‍♀‍➡' => 'ሰበይቲ ትጎዪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🏃🏽‍♀‍➡' => 'ሰበይቲ ትጎዪ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🏃🏾‍♀‍➡' => 'ሰበይቲ ትጎዪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🏃🏿‍♀‍➡' => 'ሰበይቲ ትጎዪ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🏃🏻‍♂‍➡' => 'ሰብኣይ ይጎዪ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🏃🏼‍♂‍➡' => 'ሰብኣይ ይጎዪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🏃🏽‍♂‍➡' => 'ሰብኣይ ይጎዪ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🏃🏾‍♂‍➡' => 'ሰብኣይ ይጎዪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🏃🏿‍♂‍➡' => 'ሰብኣይ ይጎዪ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🫱🏻‍🫲🏼' => 'ምጭብባጥ ኢድ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫱🏻‍🫲🏽' => 'ምጭብባጥ ኢድ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🫱🏻‍🫲🏾' => 'ምጭብባጥ ኢድ፦ ፍኹስ ዝበለ ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫱🏻‍🫲🏿' => 'ምጭብባጥ ኢድ፦ ፍኹስ ዝበለ ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🫱🏼‍🫲🏻' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🫱🏼‍🫲🏽' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ ቆርበት ዘለዎ',
    '🫱🏼‍🫲🏾' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫱🏼‍🫲🏿' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🫱🏽‍🫲🏻' => 'ምጭብባጥ ኢድ፦ ማእከላይ ቆርበት ዘለዎ፣ ፍኹስ ዝበለ ቆርበት',
    '🫱🏽‍🫲🏼' => 'ምጭብባጥ ኢድ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫱🏽‍🫲🏾' => 'ምጭብባጥ ኢድ፦ ማእከላይ ቆርበት ዘለዎ፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫱🏽‍🫲🏿' => 'ምጭብባጥ ኢድ፦ ማእከላይ ቆርበት ዘለዎ፣ ጸሊም ቆርበት ቆርበት',
    '🫱🏾‍🫲🏻' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🫱🏾‍🫲🏼' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫱🏾‍🫲🏽' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🫱🏾‍🫲🏿' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጸሊም ቆርበት ቆርበት',
    '🫱🏿‍🫲🏻' => 'ምጭብባጥ ኢድ፦ ጸሊም ቆርበት ቆርበት፣ ፍኹስ ዝበለ ቆርበት',
    '🫱🏿‍🫲🏼' => 'ምጭብባጥ ኢድ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫱🏿‍🫲🏽' => 'ምጭብባጥ ኢድ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ ቆርበት ዘለዎ',
    '🫱🏿‍🫲🏾' => 'ምጭብባጥ ኢድ፦ ጸሊም ቆርበት ቆርበት፣ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚶‍♀‍➡' => 'ሰበይቲ እናተጓዕዘት፦ ናብ የማን ዝዘረ',
    '🚶‍♂‍➡' => 'ሰብኣይ እናተጓዕዘ፦ ናብ የማን ዝዘረ',
    '🧎‍♀‍➡' => 'ሰበይቲ ተንበርኪኻ፦ ናብ የማን ዝዘረ',
    '🧎‍♂‍➡' => 'ሰብኣይ ተንበርኪኹ፦ ናብ የማን ዝዘረ',
    '🧑‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ናብ የማን ዝዘረ',
    '👨‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ናብ የማን ዝዘረ',
    '👩‍🦯‍➡' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ናብ የማን ዝዘረ',
    '🧑‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ናብ የማን ዝዘረ',
    '👨‍🦼‍➡' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ናብ የማን ዝዘረ',
    '👩‍🦼‍➡' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ናብ የማን ዝዘረ',
    '🧑‍🦽‍➡' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ናብ የማን ዝዘረ',
    '👨‍🦽‍➡' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ናብ የማን ዝዘረ',
    '👩‍🦽‍➡' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ናብ የማን ዝዘረ',
    '🏃‍♀‍➡' => 'ሰበይቲ ትጎዪ፦ ናብ የማን ዝዘረ',
    '🏃‍♂‍➡' => 'ሰብኣይ ይጎዪ፦ ናብ የማን ዝዘረ',
    '👩‍❤‍👨' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰብኣይ',
    '👨‍❤‍👨' => 'መጻምድቲ ምስ ልቢ፦ ሰብኣይ፣ ሰብኣይ',
    '👩‍❤‍👩' => 'መጻምድቲ ምስ ልቢ፦ ሰበይቲ፣ ሰበይቲ',
    '👨‍👩‍👦' => 'ስድራ፦ ሰብኣይ፣ ሰበይቲ፣ ወዲ',
    '👨‍👩‍👧' => 'ስድራ፦ ሰብኣይ፣ ሰበይቲ፣ ጓል',
    '👨‍👨‍👦' => 'ስድራ፦ ሰብኣይ፣ ሰብኣይ፣ ወዲ',
    '👨‍👨‍👧' => 'ስድራ፦ ሰብኣይ፣ ሰብኣይ፣ ጓል',
    '👩‍👩‍👦' => 'ስድራ፦ ሰበይቲ፣ ሰበይቲ፣ ወዲ',
    '👩‍👩‍👧' => 'ስድራ፦ ሰበይቲ፣ ሰበይቲ፣ ጓል',
    '👨‍👦‍👦' => 'ስድራ፦ ሰብኣይ፣ ወዲ፣ ወዲ',
    '👨‍👧‍👦' => 'ስድራ፦ ሰብኣይ፣ ጓል፣ ወዲ',
    '👨‍👧‍👧' => 'ስድራ፦ ሰብኣይ፣ ጓል፣ ጓል',
    '👩‍👦‍👦' => 'ስድራ፦ ሰበይቲ፣ ወዲ፣ ወዲ',
    '👩‍👧‍👦' => 'ስድራ፦ ሰበይቲ፣ ጓል፣ ወዲ',
    '👩‍👧‍👧' => 'ስድራ፦ ሰበይቲ፣ ጓል፣ ጓል',
    '🧑‍🤝‍🧑' => 'ሰባት ኢድ ንኢድ ተተሓሒዞም',
    '🧑‍🧑‍🧒' => 'ስድራቤት፡ ዓቢ፡ ዓቢ፡ ቆልዓ',
    '🧑‍🧒‍🧒' => 'ስድራቤት፡ ዓቢ ሰብ፡ ቆልዓ፡ ቆልዓ',
    '🧑🏻‍🦰' => 'ሰብ፦ ፍኹስ ዝበለ ቆርበት፣ ቀይሕ ጸጉሪ',
    '🧑🏼‍🦰' => 'ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ቀይሕ ጸጉሪ',
    '🧑🏽‍🦰' => 'ሰብ፦ ማእከላይ ቆርበት ዘለዎ፣ ቀይሕ ጸጉሪ',
    '🧑🏾‍🦰' => 'ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ቀይሕ ጸጉሪ',
    '🧑🏿‍🦰' => 'ሰብ፦ ጸሊም ቆርበት ቆርበት፣ ቀይሕ ጸጉሪ',
    '🧑🏻‍🦱' => 'ሰብ፦ ፍኹስ ዝበለ ቆርበት፣ ቁርጽራጽ ጸጉሪ',
    '🧑🏼‍🦱' => 'ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ቁርጽራጽ ጸጉሪ',
    '🧑🏽‍🦱' => 'ሰብ፦ ማእከላይ ቆርበት ዘለዎ፣ ቁርጽራጽ ጸጉሪ',
    '🧑🏾‍🦱' => 'ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ቁርጽራጽ ጸጉሪ',
    '🧑🏿‍🦱' => 'ሰብ፦ ጸሊም ቆርበት ቆርበት፣ ቁርጽራጽ ጸጉሪ',
    '🧑🏻‍🦳' => 'ሰብ፦ ፍኹስ ዝበለ ቆርበት፣ ጻዕዳ ጸጉሪ',
    '🧑🏼‍🦳' => 'ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጻዕዳ ጸጉሪ',
    '🧑🏽‍🦳' => 'ሰብ፦ ማእከላይ ቆርበት ዘለዎ፣ ጻዕዳ ጸጉሪ',
    '🧑🏾‍🦳' => 'ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጻዕዳ ጸጉሪ',
    '🧑🏿‍🦳' => 'ሰብ፦ ጸሊም ቆርበት ቆርበት፣ ጻዕዳ ጸጉሪ',
    '🧑🏻‍🦲' => 'ሰብ፦ ፍኹስ ዝበለ ቆርበት፣ በራሕ',
    '🧑🏼‍🦲' => 'ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ በራሕ',
    '🧑🏽‍🦲' => 'ሰብ፦ ማእከላይ ቆርበት ዘለዎ፣ በራሕ',
    '🧑🏾‍🦲' => 'ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ በራሕ',
    '🧑🏿‍🦲' => 'ሰብ፦ ጸሊም ቆርበት ቆርበት፣ በራሕ',
    '🧑🏻‍🩰' => 'ባሌ ተወዛዋዚ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🩰' => 'ባሌ ተወዛዋዚ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🩰' => 'ባሌ ተወዛዋዚ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🩰' => 'ባሌ ተወዛዋዚ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🩰' => 'ባሌ ተወዛዋዚ፦ ጸሊም ቆርበት ቆርበት',
    '🧔🏻‍♂' => 'ሰብኣይ፡ ጭሕሚ፦ ፍኹስ ዝበለ ቆርበት',
    '🧔🏼‍♂' => 'ሰብኣይ፡ ጭሕሚ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧔🏽‍♂' => 'ሰብኣይ፡ ጭሕሚ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧔🏾‍♂' => 'ሰብኣይ፡ ጭሕሚ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧔🏿‍♂' => 'ሰብኣይ፡ ጭሕሚ፦ ጸሊም ቆርበት ቆርበት',
    '👱🏻‍♂' => 'ሰብኣይ: ጸሊም ጸጉሪ፦ ፍኹስ ዝበለ ቆርበት',
    '👱🏼‍♂' => 'ሰብኣይ: ጸሊም ጸጉሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👱🏽‍♂' => 'ሰብኣይ: ጸሊም ጸጉሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '👱🏾‍♂' => 'ሰብኣይ: ጸሊም ጸጉሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👱🏿‍♂' => 'ሰብኣይ: ጸሊም ጸጉሪ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🦰' => 'ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት፣ ቀይሕ ጸጉሪ',
    '👨🏼‍🦰' => 'ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ቀይሕ ጸጉሪ',
    '👨🏽‍🦰' => 'ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ፣ ቀይሕ ጸጉሪ',
    '👨🏾‍🦰' => 'ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ቀይሕ ጸጉሪ',
    '👨🏿‍🦰' => 'ሰብኣይ፦ ጸሊም ቆርበት ቆርበት፣ ቀይሕ ጸጉሪ',
    '👨🏻‍🦱' => 'ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት፣ ቁርጽራጽ ጸጉሪ',
    '👨🏼‍🦱' => 'ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ቁርጽራጽ ጸጉሪ',
    '👨🏽‍🦱' => 'ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ፣ ቁርጽራጽ ጸጉሪ',
    '👨🏾‍🦱' => 'ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ቁርጽራጽ ጸጉሪ',
    '👨🏿‍🦱' => 'ሰብኣይ፦ ጸሊም ቆርበት ቆርበት፣ ቁርጽራጽ ጸጉሪ',
    '👨🏻‍🦳' => 'ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት፣ ጻዕዳ ጸጉሪ',
    '👨🏼‍🦳' => 'ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጻዕዳ ጸጉሪ',
    '👨🏽‍🦳' => 'ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ፣ ጻዕዳ ጸጉሪ',
    '👨🏾‍🦳' => 'ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጻዕዳ ጸጉሪ',
    '👨🏿‍🦳' => 'ሰብኣይ፦ ጸሊም ቆርበት ቆርበት፣ ጻዕዳ ጸጉሪ',
    '👨🏻‍🦲' => 'ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት፣ በራሕ',
    '👨🏼‍🦲' => 'ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ በራሕ',
    '👨🏽‍🦲' => 'ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ፣ በራሕ',
    '👨🏾‍🦲' => 'ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ በራሕ',
    '👨🏿‍🦲' => 'ሰብኣይ፦ ጸሊም ቆርበት ቆርበት፣ በራሕ',
    '🧔🏻‍♀' => 'ሰበይቲ: ጭሕሚ፦ ፍኹስ ዝበለ ቆርበት',
    '🧔🏼‍♀' => 'ሰበይቲ: ጭሕሚ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧔🏽‍♀' => 'ሰበይቲ: ጭሕሚ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧔🏾‍♀' => 'ሰበይቲ: ጭሕሚ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧔🏿‍♀' => 'ሰበይቲ: ጭሕሚ፦ ጸሊም ቆርበት ቆርበት',
    '👱🏻‍♀' => 'ሰበይቲ: ጸሊም ጸጉሪ፦ ፍኹስ ዝበለ ቆርበት',
    '👱🏼‍♀' => 'ሰበይቲ: ጸሊም ጸጉሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👱🏽‍♀' => 'ሰበይቲ: ጸሊም ጸጉሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '👱🏾‍♀' => 'ሰበይቲ: ጸሊም ጸጉሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👱🏿‍♀' => 'ሰበይቲ: ጸሊም ጸጉሪ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🦰' => 'ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት፣ ቀይሕ ጸጉሪ',
    '👩🏼‍🦰' => 'ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ቀይሕ ጸጉሪ',
    '👩🏽‍🦰' => 'ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ፣ ቀይሕ ጸጉሪ',
    '👩🏾‍🦰' => 'ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ቀይሕ ጸጉሪ',
    '👩🏿‍🦰' => 'ሰበይቲ፦ ጸሊም ቆርበት ቆርበት፣ ቀይሕ ጸጉሪ',
    '👩🏻‍🦱' => 'ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት፣ ቁርጽራጽ ጸጉሪ',
    '👩🏼‍🦱' => 'ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ቁርጽራጽ ጸጉሪ',
    '👩🏽‍🦱' => 'ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ፣ ቁርጽራጽ ጸጉሪ',
    '👩🏾‍🦱' => 'ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ቁርጽራጽ ጸጉሪ',
    '👩🏿‍🦱' => 'ሰበይቲ፦ ጸሊም ቆርበት ቆርበት፣ ቁርጽራጽ ጸጉሪ',
    '👩🏻‍🦳' => 'ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት፣ ጻዕዳ ጸጉሪ',
    '👩🏼‍🦳' => 'ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ጻዕዳ ጸጉሪ',
    '👩🏽‍🦳' => 'ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ፣ ጻዕዳ ጸጉሪ',
    '👩🏾‍🦳' => 'ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ጻዕዳ ጸጉሪ',
    '👩🏿‍🦳' => 'ሰበይቲ፦ ጸሊም ቆርበት ቆርበት፣ ጻዕዳ ጸጉሪ',
    '👩🏻‍🦲' => 'ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት፣ በራሕ',
    '👩🏼‍🦲' => 'ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ በራሕ',
    '👩🏽‍🦲' => 'ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ፣ በራሕ',
    '👩🏾‍🦲' => 'ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ በራሕ',
    '👩🏿‍🦲' => 'ሰበይቲ፦ ጸሊም ቆርበት ቆርበት፣ በራሕ',
    '🙍🏻‍♂' => 'ሰብኣይ ቅጭ መጺኡ፦ ፍኹስ ዝበለ ቆርበት',
    '🙍🏼‍♂' => 'ሰብኣይ ቅጭ መጺኡ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙍🏽‍♂' => 'ሰብኣይ ቅጭ መጺኡ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙍🏾‍♂' => 'ሰብኣይ ቅጭ መጺኡ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙍🏿‍♂' => 'ሰብኣይ ቅጭ መጺኡ፦ ጸሊም ቆርበት ቆርበት',
    '🙍🏻‍♀' => 'ሰበይቲ ቅጭ መጺኣ፦ ፍኹስ ዝበለ ቆርበት',
    '🙍🏼‍♀' => 'ሰበይቲ ቅጭ መጺኣ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙍🏽‍♀' => 'ሰበይቲ ቅጭ መጺኣ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙍🏾‍♀' => 'ሰበይቲ ቅጭ መጺኣ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙍🏿‍♀' => 'ሰበይቲ ቅጭ መጺኣ፦ ጸሊም ቆርበት ቆርበት',
    '🙎🏻‍♂' => 'ሰብኣይ ፖውት ምግባር፦ ፍኹስ ዝበለ ቆርበት',
    '🙎🏼‍♂' => 'ሰብኣይ ፖውት ምግባር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙎🏽‍♂' => 'ሰብኣይ ፖውት ምግባር፦ ማእከላይ ቆርበት ዘለዎ',
    '🙎🏾‍♂' => 'ሰብኣይ ፖውት ምግባር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙎🏿‍♂' => 'ሰብኣይ ፖውት ምግባር፦ ጸሊም ቆርበት ቆርበት',
    '🙎🏻‍♀' => 'ሰበይቲ ፖውት ትገብር፦ ፍኹስ ዝበለ ቆርበት',
    '🙎🏼‍♀' => 'ሰበይቲ ፖውት ትገብር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙎🏽‍♀' => 'ሰበይቲ ፖውት ትገብር፦ ማእከላይ ቆርበት ዘለዎ',
    '🙎🏾‍♀' => 'ሰበይቲ ፖውት ትገብር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙎🏿‍♀' => 'ሰበይቲ ፖውት ትገብር፦ ጸሊም ቆርበት ቆርበት',
    '🙅🏻‍♂' => 'ሰብኣይ ኣይፋልን ብኢዱ እናኣመልከተ፦ ፍኹስ ዝበለ ቆርበት',
    '🙅🏼‍♂' => 'ሰብኣይ ኣይፋልን ብኢዱ እናኣመልከተ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙅🏽‍♂' => 'ሰብኣይ ኣይፋልን ብኢዱ እናኣመልከተ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙅🏾‍♂' => 'ሰብኣይ ኣይፋልን ብኢዱ እናኣመልከተ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙅🏿‍♂' => 'ሰብኣይ ኣይፋልን ብኢዱ እናኣመልከተ፦ ጸሊም ቆርበት ቆርበት',
    '🙅🏻‍♀' => 'ጓል ኣንስተይቲ ኣይፋልን ኢላ ብምምልካት፦ ፍኹስ ዝበለ ቆርበት',
    '🙅🏼‍♀' => 'ጓል ኣንስተይቲ ኣይፋልን ኢላ ብምምልካት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙅🏽‍♀' => 'ጓል ኣንስተይቲ ኣይፋልን ኢላ ብምምልካት፦ ማእከላይ ቆርበት ዘለዎ',
    '🙅🏾‍♀' => 'ጓል ኣንስተይቲ ኣይፋልን ኢላ ብምምልካት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙅🏿‍♀' => 'ጓል ኣንስተይቲ ኣይፋልን ኢላ ብምምልካት፦ ጸሊም ቆርበት ቆርበት',
    '🙆🏻‍♂' => 'ሰብኣይ ሕራይ ብኢዱ እናኣመልከተ፦ ፍኹስ ዝበለ ቆርበት',
    '🙆🏼‍♂' => 'ሰብኣይ ሕራይ ብኢዱ እናኣመልከተ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙆🏽‍♂' => 'ሰብኣይ ሕራይ ብኢዱ እናኣመልከተ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙆🏾‍♂' => 'ሰብኣይ ሕራይ ብኢዱ እናኣመልከተ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙆🏿‍♂' => 'ሰብኣይ ሕራይ ብኢዱ እናኣመልከተ፦ ጸሊም ቆርበት ቆርበት',
    '🙆🏻‍♀' => 'ሰበይቲ ሕራይ ኢላ ምልክት ትገብር፦ ፍኹስ ዝበለ ቆርበት',
    '🙆🏼‍♀' => 'ሰበይቲ ሕራይ ኢላ ምልክት ትገብር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙆🏽‍♀' => 'ሰበይቲ ሕራይ ኢላ ምልክት ትገብር፦ ማእከላይ ቆርበት ዘለዎ',
    '🙆🏾‍♀' => 'ሰበይቲ ሕራይ ኢላ ምልክት ትገብር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙆🏿‍♀' => 'ሰበይቲ ሕራይ ኢላ ምልክት ትገብር፦ ጸሊም ቆርበት ቆርበት',
    '💁🏻‍♂' => 'ሰብኣይ ኢዱ እናጠወየ፦ ፍኹስ ዝበለ ቆርበት',
    '💁🏼‍♂' => 'ሰብኣይ ኢዱ እናጠወየ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💁🏽‍♂' => 'ሰብኣይ ኢዱ እናጠወየ፦ ማእከላይ ቆርበት ዘለዎ',
    '💁🏾‍♂' => 'ሰብኣይ ኢዱ እናጠወየ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💁🏿‍♂' => 'ሰብኣይ ኢዱ እናጠወየ፦ ጸሊም ቆርበት ቆርበት',
    '💁🏻‍♀' => 'ሰበይቲ ኢዳ ትጥምዝዝ፦ ፍኹስ ዝበለ ቆርበት',
    '💁🏼‍♀' => 'ሰበይቲ ኢዳ ትጥምዝዝ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💁🏽‍♀' => 'ሰበይቲ ኢዳ ትጥምዝዝ፦ ማእከላይ ቆርበት ዘለዎ',
    '💁🏾‍♀' => 'ሰበይቲ ኢዳ ትጥምዝዝ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💁🏿‍♀' => 'ሰበይቲ ኢዳ ትጥምዝዝ፦ ጸሊም ቆርበት ቆርበት',
    '🙋🏻‍♂' => 'ኢዱ ዘልዕል ሰብአይ፦ ፍኹስ ዝበለ ቆርበት',
    '🙋🏼‍♂' => 'ኢዱ ዘልዕል ሰብአይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙋🏽‍♂' => 'ኢዱ ዘልዕል ሰብአይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙋🏾‍♂' => 'ኢዱ ዘልዕል ሰብአይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙋🏿‍♂' => 'ኢዱ ዘልዕል ሰብአይ፦ ጸሊም ቆርበት ቆርበት',
    '🙋🏻‍♀' => 'ኢዳ ዘልዓለት ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '🙋🏼‍♀' => 'ኢዳ ዘልዓለት ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙋🏽‍♀' => 'ኢዳ ዘልዓለት ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙋🏾‍♀' => 'ኢዳ ዘልዓለት ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙋🏿‍♀' => 'ኢዳ ዘልዓለት ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '🧏🏻‍♂' => 'ጸማም ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት',
    '🧏🏼‍♂' => 'ጸማም ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧏🏽‍♂' => 'ጸማም ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧏🏾‍♂' => 'ጸማም ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧏🏿‍♂' => 'ጸማም ሰብኣይ፦ ጸሊም ቆርበት ቆርበት',
    '🧏🏻‍♀' => 'ጽሙም ጓል ኣንስተይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '🧏🏼‍♀' => 'ጽሙም ጓል ኣንስተይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧏🏽‍♀' => 'ጽሙም ጓል ኣንስተይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧏🏾‍♀' => 'ጽሙም ጓል ኣንስተይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧏🏿‍♀' => 'ጽሙም ጓል ኣንስተይቲ፦ ጸሊም ቆርበት ቆርበት',
    '🙇🏻‍♂' => 'ሰብአይ አጎንቢሱ፦ ፍኹስ ዝበለ ቆርበት',
    '🙇🏼‍♂' => 'ሰብአይ አጎንቢሱ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙇🏽‍♂' => 'ሰብአይ አጎንቢሱ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙇🏾‍♂' => 'ሰብአይ አጎንቢሱ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙇🏿‍♂' => 'ሰብአይ አጎንቢሱ፦ ጸሊም ቆርበት ቆርበት',
    '🙇🏻‍♀' => 'ዘጎንበሰት ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '🙇🏼‍♀' => 'ዘጎንበሰት ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙇🏽‍♀' => 'ዘጎንበሰት ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙇🏾‍♀' => 'ዘጎንበሰት ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙇🏿‍♀' => 'ዘጎንበሰት ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '🤦🏻‍♂' => 'ሰብአይ ገጹ ሒዙ፦ ፍኹስ ዝበለ ቆርበት',
    '🤦🏼‍♂' => 'ሰብአይ ገጹ ሒዙ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤦🏽‍♂' => 'ሰብአይ ገጹ ሒዙ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤦🏾‍♂' => 'ሰብአይ ገጹ ሒዙ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤦🏿‍♂' => 'ሰብአይ ገጹ ሒዙ፦ ጸሊም ቆርበት ቆርበት',
    '🤦🏻‍♀' => 'ጓል ኣንስተይቲ ንገጻ ሒዛ፦ ፍኹስ ዝበለ ቆርበት',
    '🤦🏼‍♀' => 'ጓል ኣንስተይቲ ንገጻ ሒዛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤦🏽‍♀' => 'ጓል ኣንስተይቲ ንገጻ ሒዛ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤦🏾‍♀' => 'ጓል ኣንስተይቲ ንገጻ ሒዛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤦🏿‍♀' => 'ጓል ኣንስተይቲ ንገጻ ሒዛ፦ ጸሊም ቆርበት ቆርበት',
    '🤷🏻‍♂' => 'ሰብኣይ እናነቕነቐ፦ ፍኹስ ዝበለ ቆርበት',
    '🤷🏼‍♂' => 'ሰብኣይ እናነቕነቐ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤷🏽‍♂' => 'ሰብኣይ እናነቕነቐ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤷🏾‍♂' => 'ሰብኣይ እናነቕነቐ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤷🏿‍♂' => 'ሰብኣይ እናነቕነቐ፦ ጸሊም ቆርበት ቆርበት',
    '🤷🏻‍♀' => 'ሰበይቲ እናነቕነቐት፦ ፍኹስ ዝበለ ቆርበት',
    '🤷🏼‍♀' => 'ሰበይቲ እናነቕነቐት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤷🏽‍♀' => 'ሰበይቲ እናነቕነቐት፦ ማእከላይ ቆርበት ዘለዎ',
    '🤷🏾‍♀' => 'ሰበይቲ እናነቕነቐት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤷🏿‍♀' => 'ሰበይቲ እናነቕነቐት፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍⚕' => 'ሰራሕተኛ ጥዕና፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍⚕' => 'ሰራሕተኛ ጥዕና፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍⚕' => 'ሰራሕተኛ ጥዕና፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍⚕' => 'ሰራሕተኛ ጥዕና፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍⚕' => 'ሰራሕተኛ ጥዕና፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍⚕' => 'ሰብአይ ሰራሕተኛ ጥዕና፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍⚕' => 'ሰብአይ ሰራሕተኛ ጥዕና፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍⚕' => 'ሰብአይ ሰራሕተኛ ጥዕና፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍⚕' => 'ሰብአይ ሰራሕተኛ ጥዕና፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍⚕' => 'ሰብአይ ሰራሕተኛ ጥዕና፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍⚕' => 'ሰበይቲ ሰራሕተኛ ጥዕና፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍⚕' => 'ሰበይቲ ሰራሕተኛ ጥዕና፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍⚕' => 'ሰበይቲ ሰራሕተኛ ጥዕና፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍⚕' => 'ሰበይቲ ሰራሕተኛ ጥዕና፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍⚕' => 'ሰበይቲ ሰራሕተኛ ጥዕና፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🎓' => 'ተምሃራይ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🎓' => 'ተምሃራይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🎓' => 'ተምሃራይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🎓' => 'ተምሃራይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🎓' => 'ተምሃራይ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🎓' => 'ሰብኣይ ተማሃራይ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🎓' => 'ሰብኣይ ተማሃራይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🎓' => 'ሰብኣይ ተማሃራይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🎓' => 'ሰብኣይ ተማሃራይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🎓' => 'ሰብኣይ ተማሃራይ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🎓' => 'ጓል ኣንስተይቲ ተማሃሪት፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🎓' => 'ጓል ኣንስተይቲ ተማሃሪት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🎓' => 'ጓል ኣንስተይቲ ተማሃሪት፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🎓' => 'ጓል ኣንስተይቲ ተማሃሪት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🎓' => 'ጓል ኣንስተይቲ ተማሃሪት፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🏫' => 'መምህር፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🏫' => 'መምህር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🏫' => 'መምህር፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🏫' => 'መምህር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🏫' => 'መምህር፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🏫' => 'ሰብአይ መምህር፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🏫' => 'ሰብአይ መምህር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🏫' => 'ሰብአይ መምህር፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🏫' => 'ሰብአይ መምህር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🏫' => 'ሰብአይ መምህር፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🏫' => 'ጓል ኣንስተይቲ መምህር፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🏫' => 'ጓል ኣንስተይቲ መምህር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🏫' => 'ጓል ኣንስተይቲ መምህር፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🏫' => 'ጓል ኣንስተይቲ መምህር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🏫' => 'ጓል ኣንስተይቲ መምህር፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍⚖' => 'ዳኛ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍⚖' => 'ዳኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍⚖' => 'ዳኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍⚖' => 'ዳኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍⚖' => 'ዳኛ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍⚖' => 'ሰብአይ ዳኛ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍⚖' => 'ሰብአይ ዳኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍⚖' => 'ሰብአይ ዳኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍⚖' => 'ሰብአይ ዳኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍⚖' => 'ሰብአይ ዳኛ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍⚖' => 'ጓል ኣንስተይቲ ዳኛ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍⚖' => 'ጓል ኣንስተይቲ ዳኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍⚖' => 'ጓል ኣንስተይቲ ዳኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍⚖' => 'ጓል ኣንስተይቲ ዳኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍⚖' => 'ጓል ኣንስተይቲ ዳኛ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🌾' => 'ሓረስታይ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🌾' => 'ሓረስታይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🌾' => 'ሓረስታይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🌾' => 'ሓረስታይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🌾' => 'ሓረስታይ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🌾' => 'ሰብኣይ ሓረስታይ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🌾' => 'ሰብኣይ ሓረስታይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🌾' => 'ሰብኣይ ሓረስታይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🌾' => 'ሰብኣይ ሓረስታይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🌾' => 'ሰብኣይ ሓረስታይ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🌾' => 'ጓል ኣንስተይቲ ሓረስታይ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🌾' => 'ጓል ኣንስተይቲ ሓረስታይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🌾' => 'ጓል ኣንስተይቲ ሓረስታይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🌾' => 'ጓል ኣንስተይቲ ሓረስታይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🌾' => 'ጓል ኣንስተይቲ ሓረስታይ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🍳' => 'አብሳሊ ምግቢ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🍳' => 'አብሳሊ ምግቢ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🍳' => 'አብሳሊ ምግቢ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🍳' => 'አብሳሊ ምግቢ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🍳' => 'አብሳሊ ምግቢ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🍳' => 'ሰብኣይ ምግቢ አብሳሊ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🍳' => 'ሰብኣይ ምግቢ አብሳሊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🍳' => 'ሰብኣይ ምግቢ አብሳሊ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🍳' => 'ሰብኣይ ምግቢ አብሳሊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🍳' => 'ሰብኣይ ምግቢ አብሳሊ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🍳' => 'ጓል ኣንስተይቲ ምግቢ አብሳሊት፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🍳' => 'ጓል ኣንስተይቲ ምግቢ አብሳሊት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🍳' => 'ጓል ኣንስተይቲ ምግቢ አብሳሊት፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🍳' => 'ጓል ኣንስተይቲ ምግቢ አብሳሊት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🍳' => 'ጓል ኣንስተይቲ ምግቢ አብሳሊት፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🔧' => 'መካኒክ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🔧' => 'መካኒክ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🔧' => 'መካኒክ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🔧' => 'መካኒክ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🔧' => 'መካኒክ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🔧' => 'ሰብኣይ መካኒክ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🔧' => 'ሰብኣይ መካኒክ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🔧' => 'ሰብኣይ መካኒክ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🔧' => 'ሰብኣይ መካኒክ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🔧' => 'ሰብኣይ መካኒክ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🔧' => 'ጓል ኣንስተይቲ መካኒክ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🔧' => 'ጓል ኣንስተይቲ መካኒክ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🔧' => 'ጓል ኣንስተይቲ መካኒክ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🔧' => 'ጓል ኣንስተይቲ መካኒክ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🔧' => 'ጓል ኣንስተይቲ መካኒክ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🏭' => 'ሰራሕተኛ ፋብሪካ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🏭' => 'ሰራሕተኛ ፋብሪካ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🏭' => 'ሰራሕተኛ ፋብሪካ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🏭' => 'ሰራሕተኛ ፋብሪካ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🏭' => 'ሰራሕተኛ ፋብሪካ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🏭' => 'ሰብኣይ ሰራሕተኛ ፋብሪካ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🏭' => 'ሰብኣይ ሰራሕተኛ ፋብሪካ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🏭' => 'ሰብኣይ ሰራሕተኛ ፋብሪካ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🏭' => 'ሰብኣይ ሰራሕተኛ ፋብሪካ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🏭' => 'ሰብኣይ ሰራሕተኛ ፋብሪካ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🏭' => 'ጓል ኣንስተይቲ ሰራሕተኛ ፋብሪካ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🏭' => 'ጓል ኣንስተይቲ ሰራሕተኛ ፋብሪካ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🏭' => 'ጓል ኣንስተይቲ ሰራሕተኛ ፋብሪካ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🏭' => 'ጓል ኣንስተይቲ ሰራሕተኛ ፋብሪካ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🏭' => 'ጓል ኣንስተይቲ ሰራሕተኛ ፋብሪካ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍💼' => 'ሰራሕተኛ ቤት ጽሕፈት፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍💼' => 'ሰራሕተኛ ቤት ጽሕፈት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍💼' => 'ሰራሕተኛ ቤት ጽሕፈት፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍💼' => 'ሰራሕተኛ ቤት ጽሕፈት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍💼' => 'ሰራሕተኛ ቤት ጽሕፈት፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍💼' => 'ሰብኣይ ሰራሕተኛ ቤት ጽሕፈት፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍💼' => 'ሰብኣይ ሰራሕተኛ ቤት ጽሕፈት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍💼' => 'ሰብኣይ ሰራሕተኛ ቤት ጽሕፈት፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍💼' => 'ሰብኣይ ሰራሕተኛ ቤት ጽሕፈት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍💼' => 'ሰብኣይ ሰራሕተኛ ቤት ጽሕፈት፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍💼' => 'ጓል ኣንስተይቲ ሰራሕተኛ ቤት ጽሕፈት፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍💼' => 'ጓል ኣንስተይቲ ሰራሕተኛ ቤት ጽሕፈት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍💼' => 'ጓል ኣንስተይቲ ሰራሕተኛ ቤት ጽሕፈት፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍💼' => 'ጓል ኣንስተይቲ ሰራሕተኛ ቤት ጽሕፈት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍💼' => 'ጓል ኣንስተይቲ ሰራሕተኛ ቤት ጽሕፈት፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🔬' => 'ሳይንቲስት፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🔬' => 'ሳይንቲስት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🔬' => 'ሳይንቲስት፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🔬' => 'ሳይንቲስት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🔬' => 'ሳይንቲስት፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🔬' => 'ሰብኣይ ሳይንቲስት፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🔬' => 'ሰብኣይ ሳይንቲስት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🔬' => 'ሰብኣይ ሳይንቲስት፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🔬' => 'ሰብኣይ ሳይንቲስት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🔬' => 'ሰብኣይ ሳይንቲስት፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🔬' => 'ጓል ኣንስተይቲ ሳይንቲስት፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🔬' => 'ጓል ኣንስተይቲ ሳይንቲስት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🔬' => 'ጓል ኣንስተይቲ ሳይንቲስት፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🔬' => 'ጓል ኣንስተይቲ ሳይንቲስት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🔬' => 'ጓል ኣንስተይቲ ሳይንቲስት፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍💻' => 'ናይ ቴክኖሎጂ ክኢላ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍💻' => 'ናይ ቴክኖሎጂ ክኢላ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍💻' => 'ናይ ቴክኖሎጂ ክኢላ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍💻' => 'ናይ ቴክኖሎጂ ክኢላ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍💻' => 'ናይ ቴክኖሎጂ ክኢላ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍💻' => 'ሰብአይ ሞያ ቴክኖሎጂ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍💻' => 'ሰብአይ ሞያ ቴክኖሎጂ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍💻' => 'ሰብአይ ሞያ ቴክኖሎጂ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍💻' => 'ሰብአይ ሞያ ቴክኖሎጂ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍💻' => 'ሰብአይ ሞያ ቴክኖሎጂ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍💻' => 'ጓል ኣንስተይቲ ሞያ ቴክኖሎጂ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍💻' => 'ጓል ኣንስተይቲ ሞያ ቴክኖሎጂ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍💻' => 'ጓል ኣንስተይቲ ሞያ ቴክኖሎጂ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍💻' => 'ጓል ኣንስተይቲ ሞያ ቴክኖሎጂ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍💻' => 'ጓል ኣንስተይቲ ሞያ ቴክኖሎጂ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🎤' => 'ደራፋይ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🎤' => 'ደራፋይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🎤' => 'ደራፋይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🎤' => 'ደራፋይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🎤' => 'ደራፋይ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🎤' => 'ሰብኣይ ደራፋይ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🎤' => 'ሰብኣይ ደራፋይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🎤' => 'ሰብኣይ ደራፋይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🎤' => 'ሰብኣይ ደራፋይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🎤' => 'ሰብኣይ ደራፋይ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🎤' => 'ጓል ኣንስተይቲ ደራፊት፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🎤' => 'ጓል ኣንስተይቲ ደራፊት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🎤' => 'ጓል ኣንስተይቲ ደራፊት፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🎤' => 'ጓል ኣንስተይቲ ደራፊት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🎤' => 'ጓል ኣንስተይቲ ደራፊት፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🎨' => 'ስነ ጥበበኛ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🎨' => 'ስነ ጥበበኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🎨' => 'ስነ ጥበበኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🎨' => 'ስነ ጥበበኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🎨' => 'ስነ ጥበበኛ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🎨' => 'ስነጥበባዊ ሰብአይ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🎨' => 'ስነጥበባዊ ሰብአይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🎨' => 'ስነጥበባዊ ሰብአይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🎨' => 'ስነጥበባዊ ሰብአይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🎨' => 'ስነጥበባዊ ሰብአይ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🎨' => 'ጓል ኣንስተይቲ ስነጥበበኛ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🎨' => 'ጓል ኣንስተይቲ ስነጥበበኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🎨' => 'ጓል ኣንስተይቲ ስነጥበበኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🎨' => 'ጓል ኣንስተይቲ ስነጥበበኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🎨' => 'ጓል ኣንስተይቲ ስነጥበበኛ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍✈' => 'አብራሪ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍✈' => 'አብራሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍✈' => 'አብራሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍✈' => 'አብራሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍✈' => 'አብራሪ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍✈' => 'ሰብአይ አብራሪ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍✈' => 'ሰብአይ አብራሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍✈' => 'ሰብአይ አብራሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍✈' => 'ሰብአይ አብራሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍✈' => 'ሰብአይ አብራሪ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍✈' => 'ጓል ኣንስተይቲ አብራሪት፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍✈' => 'ጓል ኣንስተይቲ አብራሪት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍✈' => 'ጓል ኣንስተይቲ አብራሪት፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍✈' => 'ጓል ኣንስተይቲ አብራሪት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍✈' => 'ጓል ኣንስተይቲ አብራሪት፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🚀' => 'ጠፈርተኛ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🚀' => 'ጠፈርተኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🚀' => 'ጠፈርተኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🚀' => 'ጠፈርተኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🚀' => 'ጠፈርተኛ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🚀' => 'ሰብኣይ ጠፈርተኛ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🚀' => 'ሰብኣይ ጠፈርተኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🚀' => 'ሰብኣይ ጠፈርተኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🚀' => 'ሰብኣይ ጠፈርተኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🚀' => 'ሰብኣይ ጠፈርተኛ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🚀' => 'ጓል ኣንስተይቲ ጠፈርተኛ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🚀' => 'ጓል ኣንስተይቲ ጠፈርተኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🚀' => 'ጓል ኣንስተይቲ ጠፈርተኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🚀' => 'ጓል ኣንስተይቲ ጠፈርተኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🚀' => 'ጓል ኣንስተይቲ ጠፈርተኛ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🚒' => 'መጥፋእቲ ሓዊ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🚒' => 'መጥፋእቲ ሓዊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🚒' => 'መጥፋእቲ ሓዊ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🚒' => 'መጥፋእቲ ሓዊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🚒' => 'መጥፋእቲ ሓዊ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🚒' => 'ሰብኣይ መጥፋእቲ ሓዊ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🚒' => 'ሰብኣይ መጥፋእቲ ሓዊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🚒' => 'ሰብኣይ መጥፋእቲ ሓዊ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🚒' => 'ሰብኣይ መጥፋእቲ ሓዊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🚒' => 'ሰብኣይ መጥፋእቲ ሓዊ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🚒' => 'ጓል ኣንስተይቲ መጥፋእቲ ሓዊጓል ኣንስተይቲ መጥፋእቲ ሓዊ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🚒' => 'ጓል ኣንስተይቲ መጥፋእቲ ሓዊጓል ኣንስተይቲ መጥፋእቲ ሓዊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🚒' => 'ጓል ኣንስተይቲ መጥፋእቲ ሓዊጓል ኣንስተይቲ መጥፋእቲ ሓዊ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🚒' => 'ጓል ኣንስተይቲ መጥፋእቲ ሓዊጓል ኣንስተይቲ መጥፋእቲ ሓዊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🚒' => 'ጓል ኣንስተይቲ መጥፋእቲ ሓዊጓል ኣንስተይቲ መጥፋእቲ ሓዊ፦ ጸሊም ቆርበት ቆርበት',
    '👮🏻‍♂' => 'ሰብአይ ፖሊስ፦ ፍኹስ ዝበለ ቆርበት',
    '👮🏼‍♂' => 'ሰብአይ ፖሊስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👮🏽‍♂' => 'ሰብአይ ፖሊስ፦ ማእከላይ ቆርበት ዘለዎ',
    '👮🏾‍♂' => 'ሰብአይ ፖሊስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👮🏿‍♂' => 'ሰብአይ ፖሊስ፦ ጸሊም ቆርበት ቆርበት',
    '👮🏻‍♀' => 'ጓል ኣንስተይቲ ፖሊስ፦ ፍኹስ ዝበለ ቆርበት',
    '👮🏼‍♀' => 'ጓል ኣንስተይቲ ፖሊስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👮🏽‍♀' => 'ጓል ኣንስተይቲ ፖሊስ፦ ማእከላይ ቆርበት ዘለዎ',
    '👮🏾‍♀' => 'ጓል ኣንስተይቲ ፖሊስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👮🏿‍♀' => 'ጓል ኣንስተይቲ ፖሊስ፦ ጸሊም ቆርበት ቆርበት',
    '🕵🏻‍♂' => 'ሰብኣይ መርማሪ፦ ፍኹስ ዝበለ ቆርበት',
    '🕵🏼‍♂' => 'ሰብኣይ መርማሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🕵🏽‍♂' => 'ሰብኣይ መርማሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '🕵🏾‍♂' => 'ሰብኣይ መርማሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🕵🏿‍♂' => 'ሰብኣይ መርማሪ፦ ጸሊም ቆርበት ቆርበት',
    '🕵🏻‍♀' => 'ጓል ኣንስተይቲ መርማሪት፦ ፍኹስ ዝበለ ቆርበት',
    '🕵🏼‍♀' => 'ጓል ኣንስተይቲ መርማሪት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🕵🏽‍♀' => 'ጓል ኣንስተይቲ መርማሪት፦ ማእከላይ ቆርበት ዘለዎ',
    '🕵🏾‍♀' => 'ጓል ኣንስተይቲ መርማሪት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🕵🏿‍♀' => 'ጓል ኣንስተይቲ መርማሪት፦ ጸሊም ቆርበት ቆርበት',
    '💂🏻‍♂' => 'ሰብ ሓላዊ፦ ፍኹስ ዝበለ ቆርበት',
    '💂🏼‍♂' => 'ሰብ ሓላዊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💂🏽‍♂' => 'ሰብ ሓላዊ፦ ማእከላይ ቆርበት ዘለዎ',
    '💂🏾‍♂' => 'ሰብ ሓላዊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💂🏿‍♂' => 'ሰብ ሓላዊ፦ ጸሊም ቆርበት ቆርበት',
    '💂🏻‍♀' => 'ጓል ኣንስተይቲ ሓላዊት፦ ፍኹስ ዝበለ ቆርበት',
    '💂🏼‍♀' => 'ጓል ኣንስተይቲ ሓላዊት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💂🏽‍♀' => 'ጓል ኣንስተይቲ ሓላዊት፦ ማእከላይ ቆርበት ዘለዎ',
    '💂🏾‍♀' => 'ጓል ኣንስተይቲ ሓላዊት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💂🏿‍♀' => 'ጓል ኣንስተይቲ ሓላዊት፦ ጸሊም ቆርበት ቆርበት',
    '👷🏻‍♂' => 'ሰብኣይ ሰራሕተኛ ህንጻ፦ ፍኹስ ዝበለ ቆርበት',
    '👷🏼‍♂' => 'ሰብኣይ ሰራሕተኛ ህንጻ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👷🏽‍♂' => 'ሰብኣይ ሰራሕተኛ ህንጻ፦ ማእከላይ ቆርበት ዘለዎ',
    '👷🏾‍♂' => 'ሰብኣይ ሰራሕተኛ ህንጻ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👷🏿‍♂' => 'ሰብኣይ ሰራሕተኛ ህንጻ፦ ጸሊም ቆርበት ቆርበት',
    '👷🏻‍♀' => 'ናይ ህንጻ ሰራሕተኛ ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '👷🏼‍♀' => 'ናይ ህንጻ ሰራሕተኛ ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👷🏽‍♀' => 'ናይ ህንጻ ሰራሕተኛ ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👷🏾‍♀' => 'ናይ ህንጻ ሰራሕተኛ ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👷🏿‍♀' => 'ናይ ህንጻ ሰራሕተኛ ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '👳🏻‍♂' => 'ቱርባን ዝተኸድነ ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት',
    '👳🏼‍♂' => 'ቱርባን ዝተኸድነ ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👳🏽‍♂' => 'ቱርባን ዝተኸድነ ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👳🏾‍♂' => 'ቱርባን ዝተኸድነ ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👳🏿‍♂' => 'ቱርባን ዝተኸድነ ሰብኣይ፦ ጸሊም ቆርበት ቆርበት',
    '👳🏻‍♀' => 'ቱርባን ዝተኸድነት ጓል ኣንስተይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '👳🏼‍♀' => 'ቱርባን ዝተኸድነት ጓል ኣንስተይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👳🏽‍♀' => 'ቱርባን ዝተኸድነት ጓል ኣንስተይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👳🏾‍♀' => 'ቱርባን ዝተኸድነት ጓል ኣንስተይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👳🏿‍♀' => 'ቱርባን ዝተኸድነት ጓል ኣንስተይቲ፦ ጸሊም ቆርበት ቆርበት',
    '🤵🏻‍♂' => 'ሰብኣይ ብቱክሲዶ፦ ፍኹስ ዝበለ ቆርበት',
    '🤵🏼‍♂' => 'ሰብኣይ ብቱክሲዶ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤵🏽‍♂' => 'ሰብኣይ ብቱክሲዶ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤵🏾‍♂' => 'ሰብኣይ ብቱክሲዶ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤵🏿‍♂' => 'ሰብኣይ ብቱክሲዶ፦ ጸሊም ቆርበት ቆርበት',
    '🤵🏻‍♀' => 'ጓል ኣንስተይቲ ኣብ ቱክሲዶ፦ ፍኹስ ዝበለ ቆርበት',
    '🤵🏼‍♀' => 'ጓል ኣንስተይቲ ኣብ ቱክሲዶ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤵🏽‍♀' => 'ጓል ኣንስተይቲ ኣብ ቱክሲዶ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤵🏾‍♀' => 'ጓል ኣንስተይቲ ኣብ ቱክሲዶ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤵🏿‍♀' => 'ጓል ኣንስተይቲ ኣብ ቱክሲዶ፦ ጸሊም ቆርበት ቆርበት',
    '👰🏻‍♂' => 'መጋረጃ ዘለዎ ሰብአይ፦ ፍኹስ ዝበለ ቆርበት',
    '👰🏼‍♂' => 'መጋረጃ ዘለዎ ሰብአይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👰🏽‍♂' => 'መጋረጃ ዘለዎ ሰብአይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👰🏾‍♂' => 'መጋረጃ ዘለዎ ሰብአይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👰🏿‍♂' => 'መጋረጃ ዘለዎ ሰብአይ፦ ጸሊም ቆርበት ቆርበት',
    '👰🏻‍♀' => 'መጋረጃ ዘለዋ ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '👰🏼‍♀' => 'መጋረጃ ዘለዋ ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👰🏽‍♀' => 'መጋረጃ ዘለዋ ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👰🏾‍♀' => 'መጋረጃ ዘለዋ ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👰🏿‍♀' => 'መጋረጃ ዘለዋ ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🍼' => 'ህጻን እትምግብ ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🍼' => 'ህጻን እትምግብ ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🍼' => 'ህጻን እትምግብ ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🍼' => 'ህጻን እትምግብ ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🍼' => 'ህጻን እትምግብ ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🍼' => 'ወዲ ተባዕታይ ንህጻን ይምግብ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🍼' => 'ወዲ ተባዕታይ ንህጻን ይምግብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🍼' => 'ወዲ ተባዕታይ ንህጻን ይምግብ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🍼' => 'ወዲ ተባዕታይ ንህጻን ይምግብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🍼' => 'ወዲ ተባዕታይ ንህጻን ይምግብ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🍼' => 'ህጻን ዝምግብ ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🍼' => 'ህጻን ዝምግብ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🍼' => 'ህጻን ዝምግብ ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🍼' => 'ህጻን ዝምግብ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🍼' => 'ህጻን ዝምግብ ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🎄' => 'አቶ ክላውስ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🎄' => 'አቶ ክላውስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🎄' => 'አቶ ክላውስ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🎄' => 'አቶ ክላውስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🎄' => 'አቶ ክላውስ፦ ጸሊም ቆርበት ቆርበት',
    '🦸🏻‍♂' => 'ሰብኣይ ሱፐር ሂሮ፦ ፍኹስ ዝበለ ቆርበት',
    '🦸🏼‍♂' => 'ሰብኣይ ሱፐር ሂሮ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🦸🏽‍♂' => 'ሰብኣይ ሱፐር ሂሮ፦ ማእከላይ ቆርበት ዘለዎ',
    '🦸🏾‍♂' => 'ሰብኣይ ሱፐር ሂሮ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🦸🏿‍♂' => 'ሰብኣይ ሱፐር ሂሮ፦ ጸሊም ቆርበት ቆርበት',
    '🦸🏻‍♀' => 'ጓል ኣንስተይቲ ሱፐር ሂሮ፦ ፍኹስ ዝበለ ቆርበት',
    '🦸🏼‍♀' => 'ጓል ኣንስተይቲ ሱፐር ሂሮ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🦸🏽‍♀' => 'ጓል ኣንስተይቲ ሱፐር ሂሮ፦ ማእከላይ ቆርበት ዘለዎ',
    '🦸🏾‍♀' => 'ጓል ኣንስተይቲ ሱፐር ሂሮ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🦸🏿‍♀' => 'ጓል ኣንስተይቲ ሱፐር ሂሮ፦ ጸሊም ቆርበት ቆርበት',
    '🦹🏻‍♂' => 'ሰብኣይ ሱፐርቪላን፦ ፍኹስ ዝበለ ቆርበት',
    '🦹🏼‍♂' => 'ሰብኣይ ሱፐርቪላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🦹🏽‍♂' => 'ሰብኣይ ሱፐርቪላን፦ ማእከላይ ቆርበት ዘለዎ',
    '🦹🏾‍♂' => 'ሰብኣይ ሱፐርቪላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🦹🏿‍♂' => 'ሰብኣይ ሱፐርቪላን፦ ጸሊም ቆርበት ቆርበት',
    '🦹🏻‍♀' => 'ጓል ኣንስተይቲ ሱፐርቪላን፦ ፍኹስ ዝበለ ቆርበት',
    '🦹🏼‍♀' => 'ጓል ኣንስተይቲ ሱፐርቪላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🦹🏽‍♀' => 'ጓል ኣንስተይቲ ሱፐርቪላን፦ ማእከላይ ቆርበት ዘለዎ',
    '🦹🏾‍♀' => 'ጓል ኣንስተይቲ ሱፐርቪላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🦹🏿‍♀' => 'ጓል ኣንስተይቲ ሱፐርቪላን፦ ጸሊም ቆርበት ቆርበት',
    '🧙🏻‍♂' => 'አስማተኛ ስብአይ፦ ፍኹስ ዝበለ ቆርበት',
    '🧙🏼‍♂' => 'አስማተኛ ስብአይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧙🏽‍♂' => 'አስማተኛ ስብአይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧙🏾‍♂' => 'አስማተኛ ስብአይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧙🏿‍♂' => 'አስማተኛ ስብአይ፦ ጸሊም ቆርበት ቆርበት',
    '🧙🏻‍♀' => 'ጓል ኣንስተይቲ አስማተኛ፦ ፍኹስ ዝበለ ቆርበት',
    '🧙🏼‍♀' => 'ጓል ኣንስተይቲ አስማተኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧙🏽‍♀' => 'ጓል ኣንስተይቲ አስማተኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧙🏾‍♀' => 'ጓል ኣንስተይቲ አስማተኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧙🏿‍♀' => 'ጓል ኣንስተይቲ አስማተኛ፦ ጸሊም ቆርበት ቆርበት',
    '🧚🏻‍♂' => 'ሰብኣይ ጽንጽዋይ፦ ፍኹስ ዝበለ ቆርበት',
    '🧚🏼‍♂' => 'ሰብኣይ ጽንጽዋይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧚🏽‍♂' => 'ሰብኣይ ጽንጽዋይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧚🏾‍♂' => 'ሰብኣይ ጽንጽዋይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧚🏿‍♂' => 'ሰብኣይ ጽንጽዋይ፦ ጸሊም ቆርበት ቆርበት',
    '🧚🏻‍♀' => 'ሰበይቲ ጽንጽዋይ፦ ፍኹስ ዝበለ ቆርበት',
    '🧚🏼‍♀' => 'ሰበይቲ ጽንጽዋይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧚🏽‍♀' => 'ሰበይቲ ጽንጽዋይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧚🏾‍♀' => 'ሰበይቲ ጽንጽዋይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧚🏿‍♀' => 'ሰበይቲ ጽንጽዋይ፦ ጸሊም ቆርበት ቆርበት',
    '🧛🏻‍♂' => 'ሰብኣይ ቫምፓየር፦ ፍኹስ ዝበለ ቆርበት',
    '🧛🏼‍♂' => 'ሰብኣይ ቫምፓየር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧛🏽‍♂' => 'ሰብኣይ ቫምፓየር፦ ማእከላይ ቆርበት ዘለዎ',
    '🧛🏾‍♂' => 'ሰብኣይ ቫምፓየር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧛🏿‍♂' => 'ሰብኣይ ቫምፓየር፦ ጸሊም ቆርበት ቆርበት',
    '🧛🏻‍♀' => 'ሰበይቲ ቫምፓየር፦ ፍኹስ ዝበለ ቆርበት',
    '🧛🏼‍♀' => 'ሰበይቲ ቫምፓየር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧛🏽‍♀' => 'ሰበይቲ ቫምፓየር፦ ማእከላይ ቆርበት ዘለዎ',
    '🧛🏾‍♀' => 'ሰበይቲ ቫምፓየር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧛🏿‍♀' => 'ሰበይቲ ቫምፓየር፦ ጸሊም ቆርበት ቆርበት',
    '🧜🏻‍♂' => 'ሰብኣይ ዓሳ፦ ፍኹስ ዝበለ ቆርበት',
    '🧜🏼‍♂' => 'ሰብኣይ ዓሳ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧜🏽‍♂' => 'ሰብኣይ ዓሳ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧜🏾‍♂' => 'ሰብኣይ ዓሳ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧜🏿‍♂' => 'ሰብኣይ ዓሳ፦ ጸሊም ቆርበት ቆርበት',
    '🧜🏻‍♀' => 'ሰብይቲ ዓሳ፦ ፍኹስ ዝበለ ቆርበት',
    '🧜🏼‍♀' => 'ሰብይቲ ዓሳ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧜🏽‍♀' => 'ሰብይቲ ዓሳ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧜🏾‍♀' => 'ሰብይቲ ዓሳ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧜🏿‍♀' => 'ሰብይቲ ዓሳ፦ ጸሊም ቆርበት ቆርበት',
    '🧝🏻‍♂' => 'ሰብ ኤልፍ፦ ፍኹስ ዝበለ ቆርበት',
    '🧝🏼‍♂' => 'ሰብ ኤልፍ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧝🏽‍♂' => 'ሰብ ኤልፍ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧝🏾‍♂' => 'ሰብ ኤልፍ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧝🏿‍♂' => 'ሰብ ኤልፍ፦ ጸሊም ቆርበት ቆርበት',
    '🧝🏻‍♀' => 'ሰበይቲ ኤልፍ፦ ፍኹስ ዝበለ ቆርበት',
    '🧝🏼‍♀' => 'ሰበይቲ ኤልፍ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧝🏽‍♀' => 'ሰበይቲ ኤልፍ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧝🏾‍♀' => 'ሰበይቲ ኤልፍ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧝🏿‍♀' => 'ሰበይቲ ኤልፍ፦ ጸሊም ቆርበት ቆርበት',
    '💆🏻‍♂' => 'ሰብኣይ ማሳጅ ይገብር፦ ፍኹስ ዝበለ ቆርበት',
    '💆🏼‍♂' => 'ሰብኣይ ማሳጅ ይገብር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💆🏽‍♂' => 'ሰብኣይ ማሳጅ ይገብር፦ ማእከላይ ቆርበት ዘለዎ',
    '💆🏾‍♂' => 'ሰብኣይ ማሳጅ ይገብር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💆🏿‍♂' => 'ሰብኣይ ማሳጅ ይገብር፦ ጸሊም ቆርበት ቆርበት',
    '💆🏻‍♀' => 'ሰበይቲ ማሳጅ ክትገብር ከላ፦ ፍኹስ ዝበለ ቆርበት',
    '💆🏼‍♀' => 'ሰበይቲ ማሳጅ ክትገብር ከላ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💆🏽‍♀' => 'ሰበይቲ ማሳጅ ክትገብር ከላ፦ ማእከላይ ቆርበት ዘለዎ',
    '💆🏾‍♀' => 'ሰበይቲ ማሳጅ ክትገብር ከላ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💆🏿‍♀' => 'ሰበይቲ ማሳጅ ክትገብር ከላ፦ ጸሊም ቆርበት ቆርበት',
    '💇🏻‍♂' => 'ሰብኣይ ጸጉሪ ምቑራጽ፦ ፍኹስ ዝበለ ቆርበት',
    '💇🏼‍♂' => 'ሰብኣይ ጸጉሪ ምቑራጽ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💇🏽‍♂' => 'ሰብኣይ ጸጉሪ ምቑራጽ፦ ማእከላይ ቆርበት ዘለዎ',
    '💇🏾‍♂' => 'ሰብኣይ ጸጉሪ ምቑራጽ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💇🏿‍♂' => 'ሰብኣይ ጸጉሪ ምቑራጽ፦ ጸሊም ቆርበት ቆርበት',
    '💇🏻‍♀' => 'ጓል ኣንስተይቲ ጸጉራ ትቑረጽ፦ ፍኹስ ዝበለ ቆርበት',
    '💇🏼‍♀' => 'ጓል ኣንስተይቲ ጸጉራ ትቑረጽ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💇🏽‍♀' => 'ጓል ኣንስተይቲ ጸጉራ ትቑረጽ፦ ማእከላይ ቆርበት ዘለዎ',
    '💇🏾‍♀' => 'ጓል ኣንስተይቲ ጸጉራ ትቑረጽ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💇🏿‍♀' => 'ጓል ኣንስተይቲ ጸጉራ ትቑረጽ፦ ጸሊም ቆርበት ቆርበት',
    '🚶🏻‍♂' => 'ሰብኣይ እናተጓዕዘ፦ ፍኹስ ዝበለ ቆርበት',
    '🚶🏼‍♂' => 'ሰብኣይ እናተጓዕዘ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚶🏽‍♂' => 'ሰብኣይ እናተጓዕዘ፦ ማእከላይ ቆርበት ዘለዎ',
    '🚶🏾‍♂' => 'ሰብኣይ እናተጓዕዘ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚶🏿‍♂' => 'ሰብኣይ እናተጓዕዘ፦ ጸሊም ቆርበት ቆርበት',
    '🚶🏻‍♀' => 'ሰበይቲ እናተጓዕዘት፦ ፍኹስ ዝበለ ቆርበት',
    '🚶🏼‍♀' => 'ሰበይቲ እናተጓዕዘት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚶🏽‍♀' => 'ሰበይቲ እናተጓዕዘት፦ ማእከላይ ቆርበት ዘለዎ',
    '🚶🏾‍♀' => 'ሰበይቲ እናተጓዕዘት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚶🏿‍♀' => 'ሰበይቲ እናተጓዕዘት፦ ጸሊም ቆርበት ቆርበት',
    '🚶🏻‍➡' => 'ሰብ እናተጓዕዘ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🚶🏼‍➡' => 'ሰብ እናተጓዕዘ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🚶🏽‍➡' => 'ሰብ እናተጓዕዘ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🚶🏾‍➡' => 'ሰብ እናተጓዕዘ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🚶🏿‍➡' => 'ሰብ እናተጓዕዘ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧍🏻‍♂' => 'ጠጠው ዝበለ ስብአይ፦ ፍኹስ ዝበለ ቆርበት',
    '🧍🏼‍♂' => 'ጠጠው ዝበለ ስብአይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧍🏽‍♂' => 'ጠጠው ዝበለ ስብአይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧍🏾‍♂' => 'ጠጠው ዝበለ ስብአይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧍🏿‍♂' => 'ጠጠው ዝበለ ስብአይ፦ ጸሊም ቆርበት ቆርበት',
    '🧍🏻‍♀' => 'ጠጠው ዝበለት ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '🧍🏼‍♀' => 'ጠጠው ዝበለት ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧍🏽‍♀' => 'ጠጠው ዝበለት ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧍🏾‍♀' => 'ጠጠው ዝበለት ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧍🏿‍♀' => 'ጠጠው ዝበለት ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '🧎🏻‍♂' => 'ሰብኣይ ተንበርኪኹ፦ ፍኹስ ዝበለ ቆርበት',
    '🧎🏼‍♂' => 'ሰብኣይ ተንበርኪኹ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧎🏽‍♂' => 'ሰብኣይ ተንበርኪኹ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧎🏾‍♂' => 'ሰብኣይ ተንበርኪኹ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧎🏿‍♂' => 'ሰብኣይ ተንበርኪኹ፦ ጸሊም ቆርበት ቆርበት',
    '🧎🏻‍♀' => 'ሰበይቲ ተንበርኪኻ፦ ፍኹስ ዝበለ ቆርበት',
    '🧎🏼‍♀' => 'ሰበይቲ ተንበርኪኻ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧎🏽‍♀' => 'ሰበይቲ ተንበርኪኻ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧎🏾‍♀' => 'ሰበይቲ ተንበርኪኻ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧎🏿‍♀' => 'ሰበይቲ ተንበርኪኻ፦ ጸሊም ቆርበት ቆርበት',
    '🧎🏻‍➡' => 'ሰብ ተንበርኪኹ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🧎🏼‍➡' => 'ሰብ ተንበርኪኹ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧎🏽‍➡' => 'ሰብ ተንበርኪኹ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🧎🏾‍➡' => 'ሰብ ተንበርኪኹ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧎🏿‍➡' => 'ሰብ ተንበርኪኹ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🧑🏻‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🦯' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🦯' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🦯' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🦯' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🦯' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🦼' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🦼' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🦼' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🦼' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🦼' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻‍🦽' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼‍🦽' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽‍🦽' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾‍🦽' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿‍🦽' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻‍🦽' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼‍🦽' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽‍🦽' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾‍🦽' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿‍🦽' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻‍🦽' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼‍🦽' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽‍🦽' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾‍🦽' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿‍🦽' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን፦ ጸሊም ቆርበት ቆርበት',
    '🏃🏻‍♂' => 'ሰብኣይ ይጎዪ፦ ፍኹስ ዝበለ ቆርበት',
    '🏃🏼‍♂' => 'ሰብኣይ ይጎዪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏃🏽‍♂' => 'ሰብኣይ ይጎዪ፦ ማእከላይ ቆርበት ዘለዎ',
    '🏃🏾‍♂' => 'ሰብኣይ ይጎዪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏃🏿‍♂' => 'ሰብኣይ ይጎዪ፦ ጸሊም ቆርበት ቆርበት',
    '🏃🏻‍♀' => 'ሰበይቲ ትጎዪ፦ ፍኹስ ዝበለ ቆርበት',
    '🏃🏼‍♀' => 'ሰበይቲ ትጎዪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏃🏽‍♀' => 'ሰበይቲ ትጎዪ፦ ማእከላይ ቆርበት ዘለዎ',
    '🏃🏾‍♀' => 'ሰበይቲ ትጎዪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏃🏿‍♀' => 'ሰበይቲ ትጎዪ፦ ጸሊም ቆርበት ቆርበት',
    '🏃🏻‍➡' => 'ሰብ ዝጎዪ፦ ፍኹስ ዝበለ ቆርበት፣ ናብ የማን ዝዘረ',
    '🏃🏼‍➡' => 'ሰብ ዝጎዪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🏃🏽‍➡' => 'ሰብ ዝጎዪ፦ ማእከላይ ቆርበት ዘለዎ፣ ናብ የማን ዝዘረ',
    '🏃🏾‍➡' => 'ሰብ ዝጎዪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '🏃🏿‍➡' => 'ሰብ ዝጎዪ፦ ጸሊም ቆርበት ቆርበት፣ ናብ የማን ዝዘረ',
    '👯🏻‍♀' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ፍኹስ ዝበለ ቆርበት',
    '👯🏼‍♀' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👯🏽‍♀' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ ቆርበት ዘለዎ',
    '👯🏾‍♀' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👯🏿‍♀' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ፦ ጸሊም ቆርበት ቆርበት',
    '👯🏻‍♂' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ፍኹስ ዝበለ ቆርበት',
    '👯🏼‍♂' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👯🏽‍♂' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ ቆርበት ዘለዎ',
    '👯🏾‍♂' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👯🏿‍♂' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ፦ ጸሊም ቆርበት ቆርበት',
    '🧖🏻‍♂' => 'ሰብኣይ ኣብ ስቲም ዝመልአ ክፍሊ፦ ፍኹስ ዝበለ ቆርበት',
    '🧖🏼‍♂' => 'ሰብኣይ ኣብ ስቲም ዝመልአ ክፍሊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧖🏽‍♂' => 'ሰብኣይ ኣብ ስቲም ዝመልአ ክፍሊ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧖🏾‍♂' => 'ሰብኣይ ኣብ ስቲም ዝመልአ ክፍሊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧖🏿‍♂' => 'ሰብኣይ ኣብ ስቲም ዝመልአ ክፍሊ፦ ጸሊም ቆርበት ቆርበት',
    '🧖🏻‍♀' => 'ሰበይቲ ኣብ ስቲም ዝመልአ ክፍሊ፦ ፍኹስ ዝበለ ቆርበት',
    '🧖🏼‍♀' => 'ሰበይቲ ኣብ ስቲም ዝመልአ ክፍሊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧖🏽‍♀' => 'ሰበይቲ ኣብ ስቲም ዝመልአ ክፍሊ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧖🏾‍♀' => 'ሰበይቲ ኣብ ስቲም ዝመልአ ክፍሊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧖🏿‍♀' => 'ሰበይቲ ኣብ ስቲም ዝመልአ ክፍሊ፦ ጸሊም ቆርበት ቆርበት',
    '🧗🏻‍♂' => 'ሰብአይ እናደየበ፦ ፍኹስ ዝበለ ቆርበት',
    '🧗🏼‍♂' => 'ሰብአይ እናደየበ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧗🏽‍♂' => 'ሰብአይ እናደየበ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧗🏾‍♂' => 'ሰብአይ እናደየበ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧗🏿‍♂' => 'ሰብአይ እናደየበ፦ ጸሊም ቆርበት ቆርበት',
    '🧗🏻‍♀' => 'ሰበይቲ እናደየበት፦ ፍኹስ ዝበለ ቆርበት',
    '🧗🏼‍♀' => 'ሰበይቲ እናደየበት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧗🏽‍♀' => 'ሰበይቲ እናደየበት፦ ማእከላይ ቆርበት ዘለዎ',
    '🧗🏾‍♀' => 'ሰበይቲ እናደየበት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧗🏿‍♀' => 'ሰበይቲ እናደየበት፦ ጸሊም ቆርበት ቆርበት',
    '🏌🏻‍♂' => 'ሰብኣይ ጎልፍ ይጻወት፦ ፍኹስ ዝበለ ቆርበት',
    '🏌🏼‍♂' => 'ሰብኣይ ጎልፍ ይጻወት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏌🏽‍♂' => 'ሰብኣይ ጎልፍ ይጻወት፦ ማእከላይ ቆርበት ዘለዎ',
    '🏌🏾‍♂' => 'ሰብኣይ ጎልፍ ይጻወት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏌🏿‍♂' => 'ሰብኣይ ጎልፍ ይጻወት፦ ጸሊም ቆርበት ቆርበት',
    '🏌🏻‍♀' => 'ጓል ኣንስተይቲ ጎልፍ ትጻወት፦ ፍኹስ ዝበለ ቆርበት',
    '🏌🏼‍♀' => 'ጓል ኣንስተይቲ ጎልፍ ትጻወት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏌🏽‍♀' => 'ጓል ኣንስተይቲ ጎልፍ ትጻወት፦ ማእከላይ ቆርበት ዘለዎ',
    '🏌🏾‍♀' => 'ጓል ኣንስተይቲ ጎልፍ ትጻወት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏌🏿‍♀' => 'ጓል ኣንስተይቲ ጎልፍ ትጻወት፦ ጸሊም ቆርበት ቆርበት',
    '🏄🏻‍♂' => 'ሰብኣይ ሰርፍ ገባሪ፦ ፍኹስ ዝበለ ቆርበት',
    '🏄🏼‍♂' => 'ሰብኣይ ሰርፍ ገባሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏄🏽‍♂' => 'ሰብኣይ ሰርፍ ገባሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '🏄🏾‍♂' => 'ሰብኣይ ሰርፍ ገባሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏄🏿‍♂' => 'ሰብኣይ ሰርፍ ገባሪ፦ ጸሊም ቆርበት ቆርበት',
    '🏄🏻‍♀' => 'ሰበይቲ ሰርፍ ትገብር፦ ፍኹስ ዝበለ ቆርበት',
    '🏄🏼‍♀' => 'ሰበይቲ ሰርፍ ትገብር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏄🏽‍♀' => 'ሰበይቲ ሰርፍ ትገብር፦ ማእከላይ ቆርበት ዘለዎ',
    '🏄🏾‍♀' => 'ሰበይቲ ሰርፍ ትገብር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏄🏿‍♀' => 'ሰበይቲ ሰርፍ ትገብር፦ ጸሊም ቆርበት ቆርበት',
    '🚣🏻‍♂' => 'ሰብኣይ ጃልባ ምቕዛፍ፦ ፍኹስ ዝበለ ቆርበት',
    '🚣🏼‍♂' => 'ሰብኣይ ጃልባ ምቕዛፍ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚣🏽‍♂' => 'ሰብኣይ ጃልባ ምቕዛፍ፦ ማእከላይ ቆርበት ዘለዎ',
    '🚣🏾‍♂' => 'ሰብኣይ ጃልባ ምቕዛፍ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚣🏿‍♂' => 'ሰብኣይ ጃልባ ምቕዛፍ፦ ጸሊም ቆርበት ቆርበት',
    '🚣🏻‍♀' => 'ጓል ኣንስተይቲ ጃልባ ትቕዝፍ፦ ፍኹስ ዝበለ ቆርበት',
    '🚣🏼‍♀' => 'ጓል ኣንስተይቲ ጃልባ ትቕዝፍ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚣🏽‍♀' => 'ጓል ኣንስተይቲ ጃልባ ትቕዝፍ፦ ማእከላይ ቆርበት ዘለዎ',
    '🚣🏾‍♀' => 'ጓል ኣንስተይቲ ጃልባ ትቕዝፍ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚣🏿‍♀' => 'ጓል ኣንስተይቲ ጃልባ ትቕዝፍ፦ ጸሊም ቆርበት ቆርበት',
    '🏊🏻‍♂' => 'ሰብኣይ ክሕንብስ ከሎ፦ ፍኹስ ዝበለ ቆርበት',
    '🏊🏼‍♂' => 'ሰብኣይ ክሕንብስ ከሎ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏊🏽‍♂' => 'ሰብኣይ ክሕንብስ ከሎ፦ ማእከላይ ቆርበት ዘለዎ',
    '🏊🏾‍♂' => 'ሰብኣይ ክሕንብስ ከሎ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏊🏿‍♂' => 'ሰብኣይ ክሕንብስ ከሎ፦ ጸሊም ቆርበት ቆርበት',
    '🏊🏻‍♀' => 'ሰበይቲ ክትሕንብስ ከላ፦ ፍኹስ ዝበለ ቆርበት',
    '🏊🏼‍♀' => 'ሰበይቲ ክትሕንብስ ከላ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏊🏽‍♀' => 'ሰበይቲ ክትሕንብስ ከላ፦ ማእከላይ ቆርበት ዘለዎ',
    '🏊🏾‍♀' => 'ሰበይቲ ክትሕንብስ ከላ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏊🏿‍♀' => 'ሰበይቲ ክትሕንብስ ከላ፦ ጸሊም ቆርበት ቆርበት',
    '⛹🏻‍♂' => 'ሰብኣይ ኩዕሶ እናተበገሰ፦ ፍኹስ ዝበለ ቆርበት',
    '⛹🏼‍♂' => 'ሰብኣይ ኩዕሶ እናተበገሰ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '⛹🏽‍♂' => 'ሰብኣይ ኩዕሶ እናተበገሰ፦ ማእከላይ ቆርበት ዘለዎ',
    '⛹🏾‍♂' => 'ሰብኣይ ኩዕሶ እናተበገሰ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '⛹🏿‍♂' => 'ሰብኣይ ኩዕሶ እናተበገሰ፦ ጸሊም ቆርበት ቆርበት',
    '⛹🏻‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ እናተበገሰት፦ ፍኹስ ዝበለ ቆርበት',
    '⛹🏼‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ እናተበገሰት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '⛹🏽‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ እናተበገሰት፦ ማእከላይ ቆርበት ዘለዎ',
    '⛹🏾‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ እናተበገሰት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '⛹🏿‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ እናተበገሰት፦ ጸሊም ቆርበት ቆርበት',
    '🏋🏻‍♂' => 'ሰብኣይ ክብደት ምልዓል፦ ፍኹስ ዝበለ ቆርበት',
    '🏋🏼‍♂' => 'ሰብኣይ ክብደት ምልዓል፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏋🏽‍♂' => 'ሰብኣይ ክብደት ምልዓል፦ ማእከላይ ቆርበት ዘለዎ',
    '🏋🏾‍♂' => 'ሰብኣይ ክብደት ምልዓል፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏋🏿‍♂' => 'ሰብኣይ ክብደት ምልዓል፦ ጸሊም ቆርበት ቆርበት',
    '🏋🏻‍♀' => 'ሰበይቲ ሚዛን ምልዓል፦ ፍኹስ ዝበለ ቆርበት',
    '🏋🏼‍♀' => 'ሰበይቲ ሚዛን ምልዓል፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏋🏽‍♀' => 'ሰበይቲ ሚዛን ምልዓል፦ ማእከላይ ቆርበት ዘለዎ',
    '🏋🏾‍♀' => 'ሰበይቲ ሚዛን ምልዓል፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏋🏿‍♀' => 'ሰበይቲ ሚዛን ምልዓል፦ ጸሊም ቆርበት ቆርበት',
    '🚴🏻‍♂' => 'ሰብኣይ ብሽክለታ ምዝዋር፦ ፍኹስ ዝበለ ቆርበት',
    '🚴🏼‍♂' => 'ሰብኣይ ብሽክለታ ምዝዋር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚴🏽‍♂' => 'ሰብኣይ ብሽክለታ ምዝዋር፦ ማእከላይ ቆርበት ዘለዎ',
    '🚴🏾‍♂' => 'ሰብኣይ ብሽክለታ ምዝዋር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚴🏿‍♂' => 'ሰብኣይ ብሽክለታ ምዝዋር፦ ጸሊም ቆርበት ቆርበት',
    '🚴🏻‍♀' => 'ጓል ኣንስተይቲ ብሽክለታ ትዝውር፦ ፍኹስ ዝበለ ቆርበት',
    '🚴🏼‍♀' => 'ጓል ኣንስተይቲ ብሽክለታ ትዝውር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚴🏽‍♀' => 'ጓል ኣንስተይቲ ብሽክለታ ትዝውር፦ ማእከላይ ቆርበት ዘለዎ',
    '🚴🏾‍♀' => 'ጓል ኣንስተይቲ ብሽክለታ ትዝውር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚴🏿‍♀' => 'ጓል ኣንስተይቲ ብሽክለታ ትዝውር፦ ጸሊም ቆርበት ቆርበት',
    '🚵🏻‍♂' => 'ሰብኣይ ናይ ተራራ ብሽክለታ ምዝዋር፦ ፍኹስ ዝበለ ቆርበት',
    '🚵🏼‍♂' => 'ሰብኣይ ናይ ተራራ ብሽክለታ ምዝዋር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚵🏽‍♂' => 'ሰብኣይ ናይ ተራራ ብሽክለታ ምዝዋር፦ ማእከላይ ቆርበት ዘለዎ',
    '🚵🏾‍♂' => 'ሰብኣይ ናይ ተራራ ብሽክለታ ምዝዋር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚵🏿‍♂' => 'ሰብኣይ ናይ ተራራ ብሽክለታ ምዝዋር፦ ጸሊም ቆርበት ቆርበት',
    '🚵🏻‍♀' => 'ጓል ኣንስተይቲ ናይ ተራራ ብሽክለታ ምዝዋር፦ ፍኹስ ዝበለ ቆርበት',
    '🚵🏼‍♀' => 'ጓል ኣንስተይቲ ናይ ተራራ ብሽክለታ ምዝዋር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚵🏽‍♀' => 'ጓል ኣንስተይቲ ናይ ተራራ ብሽክለታ ምዝዋር፦ ማእከላይ ቆርበት ዘለዎ',
    '🚵🏾‍♀' => 'ጓል ኣንስተይቲ ናይ ተራራ ብሽክለታ ምዝዋር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚵🏿‍♀' => 'ጓል ኣንስተይቲ ናይ ተራራ ብሽክለታ ምዝዋር፦ ጸሊም ቆርበት ቆርበት',
    '🤸🏻‍♂' => 'ሰብኣይ እንዳተገልበጠ፦ ፍኹስ ዝበለ ቆርበት',
    '🤸🏼‍♂' => 'ሰብኣይ እንዳተገልበጠ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤸🏽‍♂' => 'ሰብኣይ እንዳተገልበጠ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤸🏾‍♂' => 'ሰብኣይ እንዳተገልበጠ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤸🏿‍♂' => 'ሰብኣይ እንዳተገልበጠ፦ ጸሊም ቆርበት ቆርበት',
    '🤸🏻‍♀' => 'ሰበይቲ እንዳተገልበጠት፦ ፍኹስ ዝበለ ቆርበት',
    '🤸🏼‍♀' => 'ሰበይቲ እንዳተገልበጠት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤸🏽‍♀' => 'ሰበይቲ እንዳተገልበጠት፦ ማእከላይ ቆርበት ዘለዎ',
    '🤸🏾‍♀' => 'ሰበይቲ እንዳተገልበጠት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤸🏿‍♀' => 'ሰበይቲ እንዳተገልበጠት፦ ጸሊም ቆርበት ቆርበት',
    '🤼🏻‍♀' => 'ደቂ ኣንስትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት',
    '🤼🏼‍♀' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤼🏽‍♀' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤼🏾‍♀' => 'ደቂ ኣንስትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤼🏿‍♀' => 'ደቂ ኣንስትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት',
    '🤼🏻‍♂' => 'ደቂ ተባዕትዮ ቅልስ፦ ፍኹስ ዝበለ ቆርበት',
    '🤼🏼‍♂' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤼🏽‍♂' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤼🏾‍♂' => 'ደቂ ተባዕትዮ ቅልስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤼🏿‍♂' => 'ደቂ ተባዕትዮ ቅልስ፦ ጸሊም ቆርበት ቆርበት',
    '🤽🏻‍♂' => 'ሰብኣይ ዋተር ፖሎ እናተጻወተ፦ ፍኹስ ዝበለ ቆርበት',
    '🤽🏼‍♂' => 'ሰብኣይ ዋተር ፖሎ እናተጻወተ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤽🏽‍♂' => 'ሰብኣይ ዋተር ፖሎ እናተጻወተ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤽🏾‍♂' => 'ሰብኣይ ዋተር ፖሎ እናተጻወተ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤽🏿‍♂' => 'ሰብኣይ ዋተር ፖሎ እናተጻወተ፦ ጸሊም ቆርበት ቆርበት',
    '🤽🏻‍♀' => 'ጓል ኣንስተይቲ ዋተር ፖሎ ትጻወት፦ ፍኹስ ዝበለ ቆርበት',
    '🤽🏼‍♀' => 'ጓል ኣንስተይቲ ዋተር ፖሎ ትጻወት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤽🏽‍♀' => 'ጓል ኣንስተይቲ ዋተር ፖሎ ትጻወት፦ ማእከላይ ቆርበት ዘለዎ',
    '🤽🏾‍♀' => 'ጓል ኣንስተይቲ ዋተር ፖሎ ትጻወት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤽🏿‍♀' => 'ጓል ኣንስተይቲ ዋተር ፖሎ ትጻወት፦ ጸሊም ቆርበት ቆርበት',
    '🤾🏻‍♂' => 'ሰብኣይ ኩዕሶ ኢድ ክጻወት ከሎ፦ ፍኹስ ዝበለ ቆርበት',
    '🤾🏼‍♂' => 'ሰብኣይ ኩዕሶ ኢድ ክጻወት ከሎ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤾🏽‍♂' => 'ሰብኣይ ኩዕሶ ኢድ ክጻወት ከሎ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤾🏾‍♂' => 'ሰብኣይ ኩዕሶ ኢድ ክጻወት ከሎ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤾🏿‍♂' => 'ሰብኣይ ኩዕሶ ኢድ ክጻወት ከሎ፦ ጸሊም ቆርበት ቆርበት',
    '🤾🏻‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ ኢድ ትጻወት፦ ፍኹስ ዝበለ ቆርበት',
    '🤾🏼‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ ኢድ ትጻወት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤾🏽‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ ኢድ ትጻወት፦ ማእከላይ ቆርበት ዘለዎ',
    '🤾🏾‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ ኢድ ትጻወት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤾🏿‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ ኢድ ትጻወት፦ ጸሊም ቆርበት ቆርበት',
    '🤹🏻‍♂' => 'ሰብኣይ ጃግሊንግ ምግባር፦ ፍኹስ ዝበለ ቆርበት',
    '🤹🏼‍♂' => 'ሰብኣይ ጃግሊንግ ምግባር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤹🏽‍♂' => 'ሰብኣይ ጃግሊንግ ምግባር፦ ማእከላይ ቆርበት ዘለዎ',
    '🤹🏾‍♂' => 'ሰብኣይ ጃግሊንግ ምግባር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤹🏿‍♂' => 'ሰብኣይ ጃግሊንግ ምግባር፦ ጸሊም ቆርበት ቆርበት',
    '🤹🏻‍♀' => 'ጓል ኣንስተይቲ ጃግሊንግ ምግባር፦ ፍኹስ ዝበለ ቆርበት',
    '🤹🏼‍♀' => 'ጓል ኣንስተይቲ ጃግሊንግ ምግባር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤹🏽‍♀' => 'ጓል ኣንስተይቲ ጃግሊንግ ምግባር፦ ማእከላይ ቆርበት ዘለዎ',
    '🤹🏾‍♀' => 'ጓል ኣንስተይቲ ጃግሊንግ ምግባር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤹🏿‍♀' => 'ጓል ኣንስተይቲ ጃግሊንግ ምግባር፦ ጸሊም ቆርበት ቆርበት',
    '🧘🏻‍♂' => 'ሰብኣይ ኣብ ሎተስ መርገጺ፦ ፍኹስ ዝበለ ቆርበት',
    '🧘🏼‍♂' => 'ሰብኣይ ኣብ ሎተስ መርገጺ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧘🏽‍♂' => 'ሰብኣይ ኣብ ሎተስ መርገጺ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧘🏾‍♂' => 'ሰብኣይ ኣብ ሎተስ መርገጺ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧘🏿‍♂' => 'ሰብኣይ ኣብ ሎተስ መርገጺ፦ ጸሊም ቆርበት ቆርበት',
    '🧘🏻‍♀' => 'ሰበይቲ ኣብ ሎተስ ቅዋም፦ ፍኹስ ዝበለ ቆርበት',
    '🧘🏼‍♀' => 'ሰበይቲ ኣብ ሎተስ ቅዋም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧘🏽‍♀' => 'ሰበይቲ ኣብ ሎተስ ቅዋም፦ ማእከላይ ቆርበት ዘለዎ',
    '🧘🏾‍♀' => 'ሰበይቲ ኣብ ሎተስ ቅዋም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧘🏿‍♀' => 'ሰበይቲ ኣብ ሎተስ ቅዋም፦ ጸሊም ቆርበት ቆርበት',
    '🧑‍🦰' => 'ሰብ፦ ቀይሕ ጸጉሪ',
    '🧑‍🦱' => 'ሰብ፦ ቁርጽራጽ ጸጉሪ',
    '🧑‍🦳' => 'ሰብ፦ ጻዕዳ ጸጉሪ',
    '🧑‍🦲' => 'ሰብ፦ በራሕ',
    '👨‍🦰' => 'ሰብኣይ፦ ቀይሕ ጸጉሪ',
    '👨‍🦱' => 'ሰብኣይ፦ ቁርጽራጽ ጸጉሪ',
    '👨‍🦳' => 'ሰብኣይ፦ ጻዕዳ ጸጉሪ',
    '👨‍🦲' => 'ሰብኣይ፦ በራሕ',
    '👩‍🦰' => 'ሰበይቲ፦ ቀይሕ ጸጉሪ',
    '👩‍🦱' => 'ሰበይቲ፦ ቁርጽራጽ ጸጉሪ',
    '👩‍🦳' => 'ሰበይቲ፦ ጻዕዳ ጸጉሪ',
    '👩‍🦲' => 'ሰበይቲ፦ በራሕ',
    '🚶‍➡' => 'ሰብ እናተጓዕዘ፦ ናብ የማን ዝዘረ',
    '🧎‍➡' => 'ሰብ ተንበርኪኹ፦ ናብ የማን ዝዘረ',
    '🏃‍➡' => 'ሰብ ዝጎዪ፦ ናብ የማን ዝዘረ',
    '👨‍👦' => 'ስድራ፦ ሰብኣይ፣ ወዲ',
    '👨‍👧' => 'ስድራ፦ ሰብኣይ፣ ጓል',
    '👩‍👦' => 'ስድራ፦ ሰበይቲ፣ ወዲ',
    '👩‍👧' => 'ስድራ፦ ሰበይቲ፣ ጓል',
    '😶‍🌫' => 'ኣብ ደበና ዘሎ ገጽ',
    '😮‍💨' => 'ዘስተንፍስ ገጽ',
    '🙂‍↕' => 'ላዕሊን ታሕቲን ዘንቀጥቅጥ ገጽ',
    '😵‍💫' => 'ጥውይዋይ ኣዒንቲ ዘለዉዎ ገጽ',
    '❤‍🔥' => 'ኣብ ባርዕ ዘሎ ልቢ',
    '❤‍🩹' => 'ዝስፈ ልቢ',
    '👁‍🗨' => 'ኣብ ውሽጢ ዓፍራ ዝርርብ ዘሎ ዓይኒ',
    '🧔‍♂' => 'ሰብኣይ፡ ጭሕሚ',
    '👱‍♂' => 'ሰብኣይ: ጸሊም ጸጉሪ',
    '🧔‍♀' => 'ሰበይቲ: ጭሕሚ',
    '👱‍♀' => 'ሰበይቲ: ጸሊም ጸጉሪ',
    '🙍‍♂' => 'ሰብኣይ ቅጭ መጺኡ',
    '🙍‍♀' => 'ሰበይቲ ቅጭ መጺኣ',
    '🙎‍♂' => 'ሰብኣይ ፖውት ምግባር',
    '🙎‍♀' => 'ሰበይቲ ፖውት ትገብር',
    '🙅‍♂' => 'ሰብኣይ ኣይፋልን ብኢዱ እናኣመልከተ',
    '🙅‍♀' => 'ጓል ኣንስተይቲ ኣይፋልን ኢላ ብምምልካት',
    '🙆‍♂' => 'ሰብኣይ ሕራይ ብኢዱ እናኣመልከተ',
    '🙆‍♀' => 'ሰበይቲ ሕራይ ኢላ ምልክት ትገብር',
    '💁‍♂' => 'ሰብኣይ ኢዱ እናጠወየ',
    '💁‍♀' => 'ሰበይቲ ኢዳ ትጥምዝዝ',
    '🙋‍♂' => 'ኢዱ ዘልዕል ሰብአይ',
    '🙋‍♀' => 'ኢዳ ዘልዓለት ሰበይቲ',
    '🧏‍♂' => 'ጸማም ሰብኣይ',
    '🧏‍♀' => 'ጽሙም ጓል ኣንስተይቲ',
    '🙇‍♂' => 'ሰብአይ አጎንቢሱ',
    '🙇‍♀' => 'ዘጎንበሰት ሰበይቲ',
    '🤦‍♂' => 'ሰብአይ ገጹ ሒዙ',
    '🤦‍♀' => 'ጓል ኣንስተይቲ ንገጻ ሒዛ',
    '🤷‍♂' => 'ሰብኣይ እናነቕነቐ',
    '🤷‍♀' => 'ሰበይቲ እናነቕነቐት',
    '🧑‍⚕' => 'ሰራሕተኛ ጥዕና',
    '👨‍⚕' => 'ሰብአይ ሰራሕተኛ ጥዕና',
    '👩‍⚕' => 'ሰበይቲ ሰራሕተኛ ጥዕና',
    '🧑‍🎓' => 'ተምሃራይ',
    '👨‍🎓' => 'ሰብኣይ ተማሃራይ',
    '👩‍🎓' => 'ጓል ኣንስተይቲ ተማሃሪት',
    '🧑‍🏫' => 'መምህር',
    '👨‍🏫' => 'ሰብአይ መምህር',
    '👩‍🏫' => 'ጓል ኣንስተይቲ መምህር',
    '🧑‍⚖' => 'ዳኛ',
    '👨‍⚖' => 'ሰብአይ ዳኛ',
    '👩‍⚖' => 'ጓል ኣንስተይቲ ዳኛ',
    '🧑‍🌾' => 'ሓረስታይ',
    '👨‍🌾' => 'ሰብኣይ ሓረስታይ',
    '👩‍🌾' => 'ጓል ኣንስተይቲ ሓረስታይ',
    '🧑‍🍳' => 'አብሳሊ ምግቢ',
    '👨‍🍳' => 'ሰብኣይ ምግቢ አብሳሊ',
    '👩‍🍳' => 'ጓል ኣንስተይቲ ምግቢ አብሳሊት',
    '🧑‍🔧' => 'መካኒክ',
    '👨‍🔧' => 'ሰብኣይ መካኒክ',
    '👩‍🔧' => 'ጓል ኣንስተይቲ መካኒክ',
    '🧑‍🏭' => 'ሰራሕተኛ ፋብሪካ',
    '👨‍🏭' => 'ሰብኣይ ሰራሕተኛ ፋብሪካ',
    '👩‍🏭' => 'ጓል ኣንስተይቲ ሰራሕተኛ ፋብሪካ',
    '🧑‍💼' => 'ሰራሕተኛ ቤት ጽሕፈት',
    '👨‍💼' => 'ሰብኣይ ሰራሕተኛ ቤት ጽሕፈት',
    '👩‍💼' => 'ጓል ኣንስተይቲ ሰራሕተኛ ቤት ጽሕፈት',
    '🧑‍🔬' => 'ሳይንቲስት',
    '👨‍🔬' => 'ሰብኣይ ሳይንቲስት',
    '👩‍🔬' => 'ጓል ኣንስተይቲ ሳይንቲስት',
    '🧑‍💻' => 'ናይ ቴክኖሎጂ ክኢላ',
    '👨‍💻' => 'ሰብአይ ሞያ ቴክኖሎጂ',
    '👩‍💻' => 'ጓል ኣንስተይቲ ሞያ ቴክኖሎጂ',
    '🧑‍🎤' => 'ደራፋይ',
    '👨‍🎤' => 'ሰብኣይ ደራፋይ',
    '👩‍🎤' => 'ጓል ኣንስተይቲ ደራፊት',
    '🧑‍🎨' => 'ስነ ጥበበኛ',
    '👨‍🎨' => 'ስነጥበባዊ ሰብአይ',
    '👩‍🎨' => 'ጓል ኣንስተይቲ ስነጥበበኛ',
    '🧑‍✈' => 'አብራሪ',
    '👨‍✈' => 'ሰብአይ አብራሪ',
    '👩‍✈' => 'ጓል ኣንስተይቲ አብራሪት',
    '🧑‍🚀' => 'ጠፈርተኛ',
    '👨‍🚀' => 'ሰብኣይ ጠፈርተኛ',
    '👩‍🚀' => 'ጓል ኣንስተይቲ ጠፈርተኛ',
    '🧑‍🚒' => 'መጥፋእቲ ሓዊ',
    '👨‍🚒' => 'ሰብኣይ መጥፋእቲ ሓዊ',
    '👩‍🚒' => 'ጓል ኣንስተይቲ መጥፋእቲ ሓዊጓል ኣንስተይቲ መጥፋእቲ ሓዊ',
    '👮‍♂' => 'ሰብአይ ፖሊስ',
    '👮‍♀' => 'ጓል ኣንስተይቲ ፖሊስ',
    '🕵‍♂' => 'ሰብኣይ መርማሪ',
    '🕵‍♀' => 'ጓል ኣንስተይቲ መርማሪት',
    '💂‍♂' => 'ሰብ ሓላዊ',
    '💂‍♀' => 'ጓል ኣንስተይቲ ሓላዊት',
    '👷‍♂' => 'ሰብኣይ ሰራሕተኛ ህንጻ',
    '👷‍♀' => 'ናይ ህንጻ ሰራሕተኛ ሰበይቲ',
    '👳‍♂' => 'ቱርባን ዝተኸድነ ሰብኣይ',
    '👳‍♀' => 'ቱርባን ዝተኸድነት ጓል ኣንስተይቲ',
    '🤵‍♂' => 'ሰብኣይ ብቱክሲዶ',
    '🤵‍♀' => 'ጓል ኣንስተይቲ ኣብ ቱክሲዶ',
    '👰‍♂' => 'መጋረጃ ዘለዎ ሰብአይ',
    '👰‍♀' => 'መጋረጃ ዘለዋ ሰበይቲ',
    '👩‍🍼' => 'ህጻን እትምግብ ሰበይቲ',
    '👨‍🍼' => 'ወዲ ተባዕታይ ንህጻን ይምግብ',
    '🧑‍🍼' => 'ህጻን ዝምግብ ሰብ',
    '🧑‍🎄' => 'አቶ ክላውስ',
    '🦸‍♂' => 'ሰብኣይ ሱፐር ሂሮ',
    '🦸‍♀' => 'ጓል ኣንስተይቲ ሱፐር ሂሮ',
    '🦹‍♂' => 'ሰብኣይ ሱፐርቪላን',
    '🦹‍♀' => 'ጓል ኣንስተይቲ ሱፐርቪላን',
    '🧙‍♂' => 'አስማተኛ ስብአይ',
    '🧙‍♀' => 'ጓል ኣንስተይቲ አስማተኛ',
    '🧚‍♂' => 'ሰብኣይ ጽንጽዋይ',
    '🧚‍♀' => 'ሰበይቲ ጽንጽዋይ',
    '🧛‍♂' => 'ሰብኣይ ቫምፓየር',
    '🧛‍♀' => 'ሰበይቲ ቫምፓየር',
    '🧜‍♂' => 'ሰብኣይ ዓሳ',
    '🧜‍♀' => 'ሰብይቲ ዓሳ',
    '🧝‍♂' => 'ሰብ ኤልፍ',
    '🧝‍♀' => 'ሰበይቲ ኤልፍ',
    '🧞‍♂' => 'ሰብ ጂን',
    '🧞‍♀' => 'ሰበይቲ ጂን',
    '🧟‍♂' => 'ሰብኣይ ዞምቢ',
    '🧟‍♀' => 'ሰበይቲ ዞምቢ',
    '💆‍♂' => 'ሰብኣይ ማሳጅ ይገብር',
    '💆‍♀' => 'ሰበይቲ ማሳጅ ክትገብር ከላ',
    '💇‍♂' => 'ሰብኣይ ጸጉሪ ምቑራጽ',
    '💇‍♀' => 'ጓል ኣንስተይቲ ጸጉራ ትቑረጽ',
    '🚶‍♂' => 'ሰብኣይ እናተጓዕዘ',
    '🚶‍♀' => 'ሰበይቲ እናተጓዕዘት',
    '🧍‍♂' => 'ጠጠው ዝበለ ስብአይ',
    '🧍‍♀' => 'ጠጠው ዝበለት ሰበይቲ',
    '🧎‍♂' => 'ሰብኣይ ተንበርኪኹ',
    '🧎‍♀' => 'ሰበይቲ ተንበርኪኻ',
    '🧑‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብ',
    '👨‍🦯' => 'ጻዕዳ በትሪ ዘለዎ ሰብኣይ',
    '👩‍🦯' => 'ጻዕዳ በትሪ ዘለዋ ሰበይቲ',
    '🧑‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝነብር ሰብ',
    '👨‍🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን ዝኸይድ ሰብኣይ',
    '👩‍🦼' => 'ጓል ኣንስተይቲ ኣብ ሞተር ዝሰርሕ ዓረብያ ስንኩላን',
    '🧑‍🦽' => 'ሰብ ኣብ ማንዋል ዓረብያ ስንኩላን',
    '👨‍🦽' => 'ሰብኣይ ኣብ ማንዋል ዓረብያ ስንኩላን',
    '👩‍🦽' => 'ጓል ኣንስተይቲ ኣብ ማንዋል ዓረብያ ስንኩላን',
    '🏃‍♂' => 'ሰብኣይ ይጎዪ',
    '🏃‍♀' => 'ሰበይቲ ትጎዪ',
    '🧑‍🩰' => 'ባሌ ተወዛዋዚ',
    '👯‍♂' => 'እዝኒ ባኒ ዘለዎም ደቂ ተባዕትዮ',
    '👯‍♀' => 'ደቂ ኣንስትዮ ምስ እዝኒ ባኒ',
    '🧖‍♂' => 'ሰብኣይ ኣብ ስቲም ዝመልአ ክፍሊ',
    '🧖‍♀' => 'ሰበይቲ ኣብ ስቲም ዝመልአ ክፍሊ',
    '🧗‍♂' => 'ሰብአይ እናደየበ',
    '🧗‍♀' => 'ሰበይቲ እናደየበት',
    '🏌‍♂' => 'ሰብኣይ ጎልፍ ይጻወት',
    '🏌‍♀' => 'ጓል ኣንስተይቲ ጎልፍ ትጻወት',
    '🏄‍♂' => 'ሰብኣይ ሰርፍ ገባሪ',
    '🏄‍♀' => 'ሰበይቲ ሰርፍ ትገብር',
    '🚣‍♂' => 'ሰብኣይ ጃልባ ምቕዛፍ',
    '🚣‍♀' => 'ጓል ኣንስተይቲ ጃልባ ትቕዝፍ',
    '🏊‍♂' => 'ሰብኣይ ክሕንብስ ከሎ',
    '🏊‍♀' => 'ሰበይቲ ክትሕንብስ ከላ',
    '⛹‍♂' => 'ሰብኣይ ኩዕሶ እናተበገሰ',
    '⛹‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ እናተበገሰት',
    '🏋‍♂' => 'ሰብኣይ ክብደት ምልዓል',
    '🏋‍♀' => 'ሰበይቲ ሚዛን ምልዓል',
    '🚴‍♂' => 'ሰብኣይ ብሽክለታ ምዝዋር',
    '🚴‍♀' => 'ጓል ኣንስተይቲ ብሽክለታ ትዝውር',
    '🚵‍♂' => 'ሰብኣይ ናይ ተራራ ብሽክለታ ምዝዋር',
    '🚵‍♀' => 'ጓል ኣንስተይቲ ናይ ተራራ ብሽክለታ ምዝዋር',
    '🤸‍♂' => 'ሰብኣይ እንዳተገልበጠ',
    '🤸‍♀' => 'ሰበይቲ እንዳተገልበጠት',
    '🤼‍♂' => 'ደቂ ተባዕትዮ ቅልስ',
    '🤼‍♀' => 'ደቂ ኣንስትዮ ቅልስ',
    '🤽‍♂' => 'ሰብኣይ ዋተር ፖሎ እናተጻወተ',
    '🤽‍♀' => 'ጓል ኣንስተይቲ ዋተር ፖሎ ትጻወት',
    '🤾‍♂' => 'ሰብኣይ ኩዕሶ ኢድ ክጻወት ከሎ',
    '🤾‍♀' => 'ጓል ኣንስተይቲ ኩዕሶ ኢድ ትጻወት',
    '🤹‍♂' => 'ሰብኣይ ጃግሊንግ ምግባር',
    '🤹‍♀' => 'ጓል ኣንስተይቲ ጃግሊንግ ምግባር',
    '🧘‍♂' => 'ሰብኣይ ኣብ ሎተስ መርገጺ',
    '🧘‍♀' => 'ሰበይቲ ኣብ ሎተስ ቅዋም',
    '🧑‍🧒' => 'ስድራቤት: ዓቢ ሰብ: ቆልዓ',
    '🐕‍🦺' => 'ናይ ኣገልግሎት ከልቢ',
    '🐈‍⬛' => 'ጸሊም ድሙ',
    '🐻‍❄' => 'ዋልታዊ ድቢ',
    '🐦‍⬛' => 'ጸላም ዑፍ',
    '🐦‍🔥' => 'ፊኒክስ',
    '🍋‍🟩' => 'ኖራ',
    '🍄‍🟫' => 'ቡናዊ እንጉዳይ',
    '⛓‍💥' => 'ዝተሰብረ ሰንሰለት',
    '🏳‍🌈' => 'ባንዴራ ቀስተ ደበና',
    '🏳‍⚧' => 'ባንዴራ ስግረ ጾተኛ',
    '🏴‍☠' => 'ባንዴራ ሽፍታ ባሕሪ',
    '👋🏻' => 'ዝወዛወዝ ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '👋🏼' => 'ዝወዛወዝ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👋🏽' => 'ዝወዛወዝ ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '👋🏾' => 'ዝወዛወዝ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👋🏿' => 'ዝወዛወዝ ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '🤚🏻' => 'ኣብ ድሕሪት ናይ ኢድ ዝተልዓለ፦ ፍኹስ ዝበለ ቆርበት',
    '🤚🏼' => 'ኣብ ድሕሪት ናይ ኢድ ዝተልዓለ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤚🏽' => 'ኣብ ድሕሪት ናይ ኢድ ዝተልዓለ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤚🏾' => 'ኣብ ድሕሪት ናይ ኢድ ዝተልዓለ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤚🏿' => 'ኣብ ድሕሪት ናይ ኢድ ዝተልዓለ፦ ጸሊም ቆርበት ቆርበት',
    '🖐🏻' => 'ኢድ ኣጻብዕቲ ተዘርጊሑ፦ ፍኹስ ዝበለ ቆርበት',
    '🖐🏼' => 'ኢድ ኣጻብዕቲ ተዘርጊሑ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🖐🏽' => 'ኢድ ኣጻብዕቲ ተዘርጊሑ፦ ማእከላይ ቆርበት ዘለዎ',
    '🖐🏾' => 'ኢድ ኣጻብዕቲ ተዘርጊሑ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🖐🏿' => 'ኢድ ኣጻብዕቲ ተዘርጊሑ፦ ጸሊም ቆርበት ቆርበት',
    '✋🏻' => 'ዝተልዓለ ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '✋🏼' => 'ዝተልዓለ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '✋🏽' => 'ዝተልዓለ ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '✋🏾' => 'ዝተልዓለ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '✋🏿' => 'ዝተልዓለ ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '🖖🏻' => 'ቫልካን ሰላምታ፦ ፍኹስ ዝበለ ቆርበት',
    '🖖🏼' => 'ቫልካን ሰላምታ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🖖🏽' => 'ቫልካን ሰላምታ፦ ማእከላይ ቆርበት ዘለዎ',
    '🖖🏾' => 'ቫልካን ሰላምታ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🖖🏿' => 'ቫልካን ሰላምታ፦ ጸሊም ቆርበት ቆርበት',
    '🫱🏻' => 'ንየማ ዘመልክት ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '🫱🏼' => 'ንየማ ዘመልክት ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫱🏽' => 'ንየማ ዘመልክት ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '🫱🏾' => 'ንየማ ዘመልክት ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫱🏿' => 'ንየማ ዘመልክት ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '🫲🏻' => 'ንጸጋ ዘመልክት ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '🫲🏼' => 'ንጸጋ ዘመልክት ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫲🏽' => 'ንጸጋ ዘመልክት ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '🫲🏾' => 'ንጸጋ ዘመልክት ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫲🏿' => 'ንጸጋ ዘመልክት ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '🫳🏻' => 'ኢድ ንታሕቲ፦ ፍኹስ ዝበለ ቆርበት',
    '🫳🏼' => 'ኢድ ንታሕቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫳🏽' => 'ኢድ ንታሕቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '🫳🏾' => 'ኢድ ንታሕቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫳🏿' => 'ኢድ ንታሕቲ፦ ጸሊም ቆርበት ቆርበት',
    '🫴🏻' => 'ኢድ ናብ ላዕሊ፦ ፍኹስ ዝበለ ቆርበት',
    '🫴🏼' => 'ኢድ ናብ ላዕሊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫴🏽' => 'ኢድ ናብ ላዕሊ፦ ማእከላይ ቆርበት ዘለዎ',
    '🫴🏾' => 'ኢድ ናብ ላዕሊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫴🏿' => 'ኢድ ናብ ላዕሊ፦ ጸሊም ቆርበት ቆርበት',
    '🫷🏻' => 'ናብ ጸጋም ዝደፍእ ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '🫷🏼' => 'ናብ ጸጋም ዝደፍእ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫷🏽' => 'ናብ ጸጋም ዝደፍእ ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '🫷🏾' => 'ናብ ጸጋም ዝደፍእ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫷🏿' => 'ናብ ጸጋም ዝደፍእ ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '🫸🏻' => 'ናብ የማን ዝደፍእ ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '🫸🏼' => 'ናብ የማን ዝደፍእ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫸🏽' => 'ናብ የማን ዝደፍእ ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '🫸🏾' => 'ናብ የማን ዝደፍእ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫸🏿' => 'ናብ የማን ዝደፍእ ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '👌🏻' => 'ቅኑዕ ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '👌🏼' => 'ቅኑዕ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👌🏽' => 'ቅኑዕ ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '👌🏾' => 'ቅኑዕ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👌🏿' => 'ቅኑዕ ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '🤌🏻' => 'ዝተጨበጠ ኣጻብዕቲ፦ ፍኹስ ዝበለ ቆርበት',
    '🤌🏼' => 'ዝተጨበጠ ኣጻብዕቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤌🏽' => 'ዝተጨበጠ ኣጻብዕቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤌🏾' => 'ዝተጨበጠ ኣጻብዕቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤌🏿' => 'ዝተጨበጠ ኣጻብዕቲ፦ ጸሊም ቆርበት ቆርበት',
    '🤏🏻' => 'መቐንጠጢ ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '🤏🏼' => 'መቐንጠጢ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤏🏽' => 'መቐንጠጢ ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤏🏾' => 'መቐንጠጢ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤏🏿' => 'መቐንጠጢ ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '✌🏻' => 'ኢድ ዓወት፦ ፍኹስ ዝበለ ቆርበት',
    '✌🏼' => 'ኢድ ዓወት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '✌🏽' => 'ኢድ ዓወት፦ ማእከላይ ቆርበት ዘለዎ',
    '✌🏾' => 'ኢድ ዓወት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '✌🏿' => 'ኢድ ዓወት፦ ጸሊም ቆርበት ቆርበት',
    '🤞🏻' => 'ዝተቖላለፉ አጻብዕቲ፦ ፍኹስ ዝበለ ቆርበት',
    '🤞🏼' => 'ዝተቖላለፉ አጻብዕቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤞🏽' => 'ዝተቖላለፉ አጻብዕቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤞🏾' => 'ዝተቖላለፉ አጻብዕቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤞🏿' => 'ዝተቖላለፉ አጻብዕቲ፦ ጸሊም ቆርበት ቆርበት',
    '🫰🏻' => 'ኢድ ምስ ጠቋሚ ኣጻብዕትን ዓባስ ኣጻብዕትን ዝተቖላለፉ፦ ፍኹስ ዝበለ ቆርበት',
    '🫰🏼' => 'ኢድ ምስ ጠቋሚ ኣጻብዕትን ዓባስ ኣጻብዕትን ዝተቖላለፉ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫰🏽' => 'ኢድ ምስ ጠቋሚ ኣጻብዕትን ዓባስ ኣጻብዕትን ዝተቖላለፉ፦ ማእከላይ ቆርበት ዘለዎ',
    '🫰🏾' => 'ኢድ ምስ ጠቋሚ ኣጻብዕትን ዓባስ ኣጻብዕትን ዝተቖላለፉ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫰🏿' => 'ኢድ ምስ ጠቋሚ ኣጻብዕትን ዓባስ ኣጻብዕትን ዝተቖላለፉ፦ ጸሊም ቆርበት ቆርበት',
    '🤟🏻' => 'ናይ ፍቕሪ ምልክት፦ ፍኹስ ዝበለ ቆርበት',
    '🤟🏼' => 'ናይ ፍቕሪ ምልክት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤟🏽' => 'ናይ ፍቕሪ ምልክት፦ ማእከላይ ቆርበት ዘለዎ',
    '🤟🏾' => 'ናይ ፍቕሪ ምልክት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤟🏿' => 'ናይ ፍቕሪ ምልክት፦ ጸሊም ቆርበት ቆርበት',
    '🤘🏻' => 'ምልክት ቀርኒ፦ ፍኹስ ዝበለ ቆርበት',
    '🤘🏼' => 'ምልክት ቀርኒ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤘🏽' => 'ምልክት ቀርኒ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤘🏾' => 'ምልክት ቀርኒ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤘🏿' => 'ምልክት ቀርኒ፦ ጸሊም ቆርበት ቆርበት',
    '🤙🏻' => 'ደውሉለይ ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '🤙🏼' => 'ደውሉለይ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤙🏽' => 'ደውሉለይ ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤙🏾' => 'ደውሉለይ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤙🏿' => 'ደውሉለይ ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '👈🏻' => 'ናብ ጸጋም ዝሕብር መመልከቲ ናይ ድሕሪት ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '👈🏼' => 'ናብ ጸጋም ዝሕብር መመልከቲ ናይ ድሕሪት ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👈🏽' => 'ናብ ጸጋም ዝሕብር መመልከቲ ናይ ድሕሪት ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '👈🏾' => 'ናብ ጸጋም ዝሕብር መመልከቲ ናይ ድሕሪት ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👈🏿' => 'ናብ ጸጋም ዝሕብር መመልከቲ ናይ ድሕሪት ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '👉🏻' => 'ናብ የማን ዝሕብር መመልከቲ ንድሕሪት፦ ፍኹስ ዝበለ ቆርበት',
    '👉🏼' => 'ናብ የማን ዝሕብር መመልከቲ ንድሕሪት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👉🏽' => 'ናብ የማን ዝሕብር መመልከቲ ንድሕሪት፦ ማእከላይ ቆርበት ዘለዎ',
    '👉🏾' => 'ናብ የማን ዝሕብር መመልከቲ ንድሕሪት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👉🏿' => 'ናብ የማን ዝሕብር መመልከቲ ንድሕሪት፦ ጸሊም ቆርበት ቆርበት',
    '👆🏻' => 'መመልከቲ ንድሕሪት ናብ ላዕሊ፦ ፍኹስ ዝበለ ቆርበት',
    '👆🏼' => 'መመልከቲ ንድሕሪት ናብ ላዕሊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👆🏽' => 'መመልከቲ ንድሕሪት ናብ ላዕሊ፦ ማእከላይ ቆርበት ዘለዎ',
    '👆🏾' => 'መመልከቲ ንድሕሪት ናብ ላዕሊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👆🏿' => 'መመልከቲ ንድሕሪት ናብ ላዕሊ፦ ጸሊም ቆርበት ቆርበት',
    '🖕🏻' => 'ማእከላይ ኣጻብዕቲ፦ ፍኹስ ዝበለ ቆርበት',
    '🖕🏼' => 'ማእከላይ ኣጻብዕቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🖕🏽' => 'ማእከላይ ኣጻብዕቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '🖕🏾' => 'ማእከላይ ኣጻብዕቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🖕🏿' => 'ማእከላይ ኣጻብዕቲ፦ ጸሊም ቆርበት ቆርበት',
    '👇🏻' => 'ንድሕሪት ዝጥምት ጠቋሚ፦ ፍኹስ ዝበለ ቆርበት',
    '👇🏼' => 'ንድሕሪት ዝጥምት ጠቋሚ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👇🏽' => 'ንድሕሪት ዝጥምት ጠቋሚ፦ ማእከላይ ቆርበት ዘለዎ',
    '👇🏾' => 'ንድሕሪት ዝጥምት ጠቋሚ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👇🏿' => 'ንድሕሪት ዝጥምት ጠቋሚ፦ ጸሊም ቆርበት ቆርበት',
    '☝🏻' => 'ጠቋሚ ናብ ላዕሊ ዝሕብር፦ ፍኹስ ዝበለ ቆርበት',
    '☝🏼' => 'ጠቋሚ ናብ ላዕሊ ዝሕብር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '☝🏽' => 'ጠቋሚ ናብ ላዕሊ ዝሕብር፦ ማእከላይ ቆርበት ዘለዎ',
    '☝🏾' => 'ጠቋሚ ናብ ላዕሊ ዝሕብር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '☝🏿' => 'ጠቋሚ ናብ ላዕሊ ዝሕብር፦ ጸሊም ቆርበት ቆርበት',
    '🫵🏻' => 'ጠቋሚ ናብ ተዓዛቢ ዝሕብር፦ ፍኹስ ዝበለ ቆርበት',
    '🫵🏼' => 'ጠቋሚ ናብ ተዓዛቢ ዝሕብር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫵🏽' => 'ጠቋሚ ናብ ተዓዛቢ ዝሕብር፦ ማእከላይ ቆርበት ዘለዎ',
    '🫵🏾' => 'ጠቋሚ ናብ ተዓዛቢ ዝሕብር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫵🏿' => 'ጠቋሚ ናብ ተዓዛቢ ዝሕብር፦ ጸሊም ቆርበት ቆርበት',
    '👍🏻' => 'ኣጻብዕቲ ናብ ላዕሊ፦ ፍኹስ ዝበለ ቆርበት',
    '👍🏼' => 'ኣጻብዕቲ ናብ ላዕሊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👍🏽' => 'ኣጻብዕቲ ናብ ላዕሊ፦ ማእከላይ ቆርበት ዘለዎ',
    '👍🏾' => 'ኣጻብዕቲ ናብ ላዕሊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👍🏿' => 'ኣጻብዕቲ ናብ ላዕሊ፦ ጸሊም ቆርበት ቆርበት',
    '👎🏻' => 'ኣጻብዕቲ ናብ ታሕቲ፦ ፍኹስ ዝበለ ቆርበት',
    '👎🏼' => 'ኣጻብዕቲ ናብ ታሕቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👎🏽' => 'ኣጻብዕቲ ናብ ታሕቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👎🏾' => 'ኣጻብዕቲ ናብ ታሕቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👎🏿' => 'ኣጻብዕቲ ናብ ታሕቲ፦ ጸሊም ቆርበት ቆርበት',
    '✊🏻' => 'ዝተልዓለ ጭቡጥ ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '✊🏼' => 'ዝተልዓለ ጭቡጥ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '✊🏽' => 'ዝተልዓለ ጭቡጥ ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '✊🏾' => 'ዝተልዓለ ጭቡጥ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '✊🏿' => 'ዝተልዓለ ጭቡጥ ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '👊🏻' => 'ዝመጽእ ምጭብባጥ ምጭብባጥ፦ ፍኹስ ዝበለ ቆርበት',
    '👊🏼' => 'ዝመጽእ ምጭብባጥ ምጭብባጥ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👊🏽' => 'ዝመጽእ ምጭብባጥ ምጭብባጥ፦ ማእከላይ ቆርበት ዘለዎ',
    '👊🏾' => 'ዝመጽእ ምጭብባጥ ምጭብባጥ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👊🏿' => 'ዝመጽእ ምጭብባጥ ምጭብባጥ፦ ጸሊም ቆርበት ቆርበት',
    '🤛🏻' => 'ንጸጋም ገጹ ዝጥምት ምጭብባጥ፦ ፍኹስ ዝበለ ቆርበት',
    '🤛🏼' => 'ንጸጋም ገጹ ዝጥምት ምጭብባጥ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤛🏽' => 'ንጸጋም ገጹ ዝጥምት ምጭብባጥ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤛🏾' => 'ንጸጋም ገጹ ዝጥምት ምጭብባጥ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤛🏿' => 'ንጸጋም ገጹ ዝጥምት ምጭብባጥ፦ ጸሊም ቆርበት ቆርበት',
    '🤜🏻' => 'ንየማን ገጹ ዝጥምት ምጭብባጥ፦ ፍኹስ ዝበለ ቆርበት',
    '🤜🏼' => 'ንየማን ገጹ ዝጥምት ምጭብባጥ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤜🏽' => 'ንየማን ገጹ ዝጥምት ምጭብባጥ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤜🏾' => 'ንየማን ገጹ ዝጥምት ምጭብባጥ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤜🏿' => 'ንየማን ገጹ ዝጥምት ምጭብባጥ፦ ጸሊም ቆርበት ቆርበት',
    '👏🏻' => 'ኢዶም እናጣቕዑ፦ ፍኹስ ዝበለ ቆርበት',
    '👏🏼' => 'ኢዶም እናጣቕዑ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👏🏽' => 'ኢዶም እናጣቕዑ፦ ማእከላይ ቆርበት ዘለዎ',
    '👏🏾' => 'ኢዶም እናጣቕዑ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👏🏿' => 'ኢዶም እናጣቕዑ፦ ጸሊም ቆርበት ቆርበት',
    '🙌🏻' => 'ኢድ ምልዓል፦ ፍኹስ ዝበለ ቆርበት',
    '🙌🏼' => 'ኢድ ምልዓል፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙌🏽' => 'ኢድ ምልዓል፦ ማእከላይ ቆርበት ዘለዎ',
    '🙌🏾' => 'ኢድ ምልዓል፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙌🏿' => 'ኢድ ምልዓል፦ ጸሊም ቆርበት ቆርበት',
    '🫶🏻' => 'ልቢ ኣእዳው፦ ፍኹስ ዝበለ ቆርበት',
    '🫶🏼' => 'ልቢ ኣእዳው፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫶🏽' => 'ልቢ ኣእዳው፦ ማእከላይ ቆርበት ዘለዎ',
    '🫶🏾' => 'ልቢ ኣእዳው፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫶🏿' => 'ልቢ ኣእዳው፦ ጸሊም ቆርበት ቆርበት',
    '👐🏻' => 'ክፉት ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '👐🏼' => 'ክፉት ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👐🏽' => 'ክፉት ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '👐🏾' => 'ክፉት ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👐🏿' => 'ክፉት ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '🤲🏻' => 'ኣእዳው ብሓባር፦ ፍኹስ ዝበለ ቆርበት',
    '🤲🏼' => 'ኣእዳው ብሓባር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤲🏽' => 'ኣእዳው ብሓባር፦ ማእከላይ ቆርበት ዘለዎ',
    '🤲🏾' => 'ኣእዳው ብሓባር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤲🏿' => 'ኣእዳው ብሓባር፦ ጸሊም ቆርበት ቆርበት',
    '🤝🏻' => 'ምጭብባጥ ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '🤝🏼' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤝🏽' => 'ምጭብባጥ ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤝🏾' => 'ምጭብባጥ ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤝🏿' => 'ምጭብባጥ ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '🙏🏻' => 'ኣእዳው ዓጺፉ፦ ፍኹስ ዝበለ ቆርበት',
    '🙏🏼' => 'ኣእዳው ዓጺፉ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙏🏽' => 'ኣእዳው ዓጺፉ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙏🏾' => 'ኣእዳው ዓጺፉ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙏🏿' => 'ኣእዳው ዓጺፉ፦ ጸሊም ቆርበት ቆርበት',
    '✍🏻' => 'ናይ ጽሕፈት ኢድ፦ ፍኹስ ዝበለ ቆርበት',
    '✍🏼' => 'ናይ ጽሕፈት ኢድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '✍🏽' => 'ናይ ጽሕፈት ኢድ፦ ማእከላይ ቆርበት ዘለዎ',
    '✍🏾' => 'ናይ ጽሕፈት ኢድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '✍🏿' => 'ናይ ጽሕፈት ኢድ፦ ጸሊም ቆርበት ቆርበት',
    '💅🏻' => 'ጽፍሪ ምጽራይ፦ ፍኹስ ዝበለ ቆርበት',
    '💅🏼' => 'ጽፍሪ ምጽራይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💅🏽' => 'ጽፍሪ ምጽራይ፦ ማእከላይ ቆርበት ዘለዎ',
    '💅🏾' => 'ጽፍሪ ምጽራይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💅🏿' => 'ጽፍሪ ምጽራይ፦ ጸሊም ቆርበት ቆርበት',
    '🤳🏻' => 'ሴልፊ ምውሳድ፦ ፍኹስ ዝበለ ቆርበት',
    '🤳🏼' => 'ሴልፊ ምውሳድ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤳🏽' => 'ሴልፊ ምውሳድ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤳🏾' => 'ሴልፊ ምውሳድ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤳🏿' => 'ሴልፊ ምውሳድ፦ ጸሊም ቆርበት ቆርበት',
    '💪🏻' => 'ዝተዓጽፈ ጡንች፦ ፍኹስ ዝበለ ቆርበት',
    '💪🏼' => 'ዝተዓጽፈ ጡንች፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💪🏽' => 'ዝተዓጽፈ ጡንች፦ ማእከላይ ቆርበት ዘለዎ',
    '💪🏾' => 'ዝተዓጽፈ ጡንች፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💪🏿' => 'ዝተዓጽፈ ጡንች፦ ጸሊም ቆርበት ቆርበት',
    '🦵🏻' => 'ሙሉእ እግሪ፦ ፍኹስ ዝበለ ቆርበት',
    '🦵🏼' => 'ሙሉእ እግሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🦵🏽' => 'ሙሉእ እግሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '🦵🏾' => 'ሙሉእ እግሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🦵🏿' => 'ሙሉእ እግሪ፦ ጸሊም ቆርበት ቆርበት',
    '🦶🏻' => 'እግሪ፦ ፍኹስ ዝበለ ቆርበት',
    '🦶🏼' => 'እግሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🦶🏽' => 'እግሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '🦶🏾' => 'እግሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🦶🏿' => 'እግሪ፦ ጸሊም ቆርበት ቆርበት',
    '👂🏻' => 'እዝኒ፦ ፍኹስ ዝበለ ቆርበት',
    '👂🏼' => 'እዝኒ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👂🏽' => 'እዝኒ፦ ማእከላይ ቆርበት ዘለዎ',
    '👂🏾' => 'እዝኒ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👂🏿' => 'እዝኒ፦ ጸሊም ቆርበት ቆርበት',
    '🦻🏻' => 'እዝኒ ምስ መሳርሒ መስምዒ፦ ፍኹስ ዝበለ ቆርበት',
    '🦻🏼' => 'እዝኒ ምስ መሳርሒ መስምዒ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🦻🏽' => 'እዝኒ ምስ መሳርሒ መስምዒ፦ ማእከላይ ቆርበት ዘለዎ',
    '🦻🏾' => 'እዝኒ ምስ መሳርሒ መስምዒ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🦻🏿' => 'እዝኒ ምስ መሳርሒ መስምዒ፦ ጸሊም ቆርበት ቆርበት',
    '👃🏻' => 'ኣፍንጫ፦ ፍኹስ ዝበለ ቆርበት',
    '👃🏼' => 'ኣፍንጫ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👃🏽' => 'ኣፍንጫ፦ ማእከላይ ቆርበት ዘለዎ',
    '👃🏾' => 'ኣፍንጫ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👃🏿' => 'ኣፍንጫ፦ ጸሊም ቆርበት ቆርበት',
    '👶🏻' => 'ህጻን፦ ፍኹስ ዝበለ ቆርበት',
    '👶🏼' => 'ህጻን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👶🏽' => 'ህጻን፦ ማእከላይ ቆርበት ዘለዎ',
    '👶🏾' => 'ህጻን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👶🏿' => 'ህጻን፦ ጸሊም ቆርበት ቆርበት',
    '🧒🏻' => 'ቈልዓ፦ ፍኹስ ዝበለ ቆርበት',
    '🧒🏼' => 'ቈልዓ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧒🏽' => 'ቈልዓ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧒🏾' => 'ቈልዓ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧒🏿' => 'ቈልዓ፦ ጸሊም ቆርበት ቆርበት',
    '👦🏻' => 'ወዲ፦ ፍኹስ ዝበለ ቆርበት',
    '👦🏼' => 'ወዲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👦🏽' => 'ወዲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👦🏾' => 'ወዲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👦🏿' => 'ወዲ፦ ጸሊም ቆርበት ቆርበት',
    '👧🏻' => 'ጓል፦ ፍኹስ ዝበለ ቆርበት',
    '👧🏼' => 'ጓል፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👧🏽' => 'ጓል፦ ማእከላይ ቆርበት ዘለዎ',
    '👧🏾' => 'ጓል፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👧🏿' => 'ጓል፦ ጸሊም ቆርበት ቆርበት',
    '🧑🏻' => 'ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🧑🏼' => 'ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧑🏽' => 'ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧑🏾' => 'ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧑🏿' => 'ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '👱🏻' => 'ሰብ: ጸሊም ጸጉሪ፦ ፍኹስ ዝበለ ቆርበት',
    '👱🏼' => 'ሰብ: ጸሊም ጸጉሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👱🏽' => 'ሰብ: ጸሊም ጸጉሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '👱🏾' => 'ሰብ: ጸሊም ጸጉሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👱🏿' => 'ሰብ: ጸሊም ጸጉሪ፦ ጸሊም ቆርበት ቆርበት',
    '👨🏻' => 'ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት',
    '👨🏼' => 'ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👨🏽' => 'ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👨🏾' => 'ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👨🏿' => 'ሰብኣይ፦ ጸሊም ቆርበት ቆርበት',
    '🧔🏻' => 'ሰብ: ጭሕሚ፦ ፍኹስ ዝበለ ቆርበት',
    '🧔🏼' => 'ሰብ: ጭሕሚ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧔🏽' => 'ሰብ: ጭሕሚ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧔🏾' => 'ሰብ: ጭሕሚ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧔🏿' => 'ሰብ: ጭሕሚ፦ ጸሊም ቆርበት ቆርበት',
    '👩🏻' => 'ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '👩🏼' => 'ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👩🏽' => 'ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👩🏾' => 'ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👩🏿' => 'ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '🧓🏻' => 'ብዕድመ ዝደፍአ ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🧓🏼' => 'ብዕድመ ዝደፍአ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧓🏽' => 'ብዕድመ ዝደፍአ ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧓🏾' => 'ብዕድመ ዝደፍአ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧓🏿' => 'ብዕድመ ዝደፍአ ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '👴🏻' => 'ኣረጊት ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት',
    '👴🏼' => 'ኣረጊት ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👴🏽' => 'ኣረጊት ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ',
    '👴🏾' => 'ኣረጊት ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👴🏿' => 'ኣረጊት ሰብኣይ፦ ጸሊም ቆርበት ቆርበት',
    '👵🏻' => 'ኣረጊት ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '👵🏼' => 'ኣረጊት ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👵🏽' => 'ኣረጊት ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👵🏾' => 'ኣረጊት ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👵🏿' => 'ኣረጊት ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '🙍🏻' => 'ሰብ ቅጭ መጺኡ፦ ፍኹስ ዝበለ ቆርበት',
    '🙍🏼' => 'ሰብ ቅጭ መጺኡ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙍🏽' => 'ሰብ ቅጭ መጺኡ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙍🏾' => 'ሰብ ቅጭ መጺኡ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙍🏿' => 'ሰብ ቅጭ መጺኡ፦ ጸሊም ቆርበት ቆርበት',
    '🙎🏻' => 'ሰብ ፖውት ምግባር፦ ፍኹስ ዝበለ ቆርበት',
    '🙎🏼' => 'ሰብ ፖውት ምግባር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙎🏽' => 'ሰብ ፖውት ምግባር፦ ማእከላይ ቆርበት ዘለዎ',
    '🙎🏾' => 'ሰብ ፖውት ምግባር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙎🏿' => 'ሰብ ፖውት ምግባር፦ ጸሊም ቆርበት ቆርበት',
    '🙅🏻' => 'ሰብ ኣይፋልን ዝብል ምልክት ዝገብር፦ ፍኹስ ዝበለ ቆርበት',
    '🙅🏼' => 'ሰብ ኣይፋልን ዝብል ምልክት ዝገብር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙅🏽' => 'ሰብ ኣይፋልን ዝብል ምልክት ዝገብር፦ ማእከላይ ቆርበት ዘለዎ',
    '🙅🏾' => 'ሰብ ኣይፋልን ዝብል ምልክት ዝገብር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙅🏿' => 'ሰብ ኣይፋልን ዝብል ምልክት ዝገብር፦ ጸሊም ቆርበት ቆርበት',
    '🙆🏻' => 'ሰብ ሕራይ ዝብል ምልክት ዝገብር፦ ፍኹስ ዝበለ ቆርበት',
    '🙆🏼' => 'ሰብ ሕራይ ዝብል ምልክት ዝገብር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙆🏽' => 'ሰብ ሕራይ ዝብል ምልክት ዝገብር፦ ማእከላይ ቆርበት ዘለዎ',
    '🙆🏾' => 'ሰብ ሕራይ ዝብል ምልክት ዝገብር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙆🏿' => 'ሰብ ሕራይ ዝብል ምልክት ዝገብር፦ ጸሊም ቆርበት ቆርበት',
    '💁🏻' => 'ሰብ ኢዱ ዝጥምዝዝ፦ ፍኹስ ዝበለ ቆርበት',
    '💁🏼' => 'ሰብ ኢዱ ዝጥምዝዝ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💁🏽' => 'ሰብ ኢዱ ዝጥምዝዝ፦ ማእከላይ ቆርበት ዘለዎ',
    '💁🏾' => 'ሰብ ኢዱ ዝጥምዝዝ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💁🏿' => 'ሰብ ኢዱ ዝጥምዝዝ፦ ጸሊም ቆርበት ቆርበት',
    '🙋🏻' => 'ኢድ ዘልዕል ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🙋🏼' => 'ኢድ ዘልዕል ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙋🏽' => 'ኢድ ዘልዕል ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙋🏾' => 'ኢድ ዘልዕል ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙋🏿' => 'ኢድ ዘልዕል ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '🧏🏻' => 'ጸማም ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🧏🏼' => 'ጸማም ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧏🏽' => 'ጸማም ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧏🏾' => 'ጸማም ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧏🏿' => 'ጸማም ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '🙇🏻' => 'ሰብ አጎንቢሱ፦ ፍኹስ ዝበለ ቆርበት',
    '🙇🏼' => 'ሰብ አጎንቢሱ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🙇🏽' => 'ሰብ አጎንቢሱ፦ ማእከላይ ቆርበት ዘለዎ',
    '🙇🏾' => 'ሰብ አጎንቢሱ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🙇🏿' => 'ሰብ አጎንቢሱ፦ ጸሊም ቆርበት ቆርበት',
    '🤦🏻' => 'ሰብ ኢዱ አብ ገጹ ምግባር፦ ፍኹስ ዝበለ ቆርበት',
    '🤦🏼' => 'ሰብ ኢዱ አብ ገጹ ምግባር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤦🏽' => 'ሰብ ኢዱ አብ ገጹ ምግባር፦ ማእከላይ ቆርበት ዘለዎ',
    '🤦🏾' => 'ሰብ ኢዱ አብ ገጹ ምግባር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤦🏿' => 'ሰብ ኢዱ አብ ገጹ ምግባር፦ ጸሊም ቆርበት ቆርበት',
    '🤷🏻' => 'ሰብ እናነቕነቐ፦ ፍኹስ ዝበለ ቆርበት',
    '🤷🏼' => 'ሰብ እናነቕነቐ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤷🏽' => 'ሰብ እናነቕነቐ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤷🏾' => 'ሰብ እናነቕነቐ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤷🏿' => 'ሰብ እናነቕነቐ፦ ጸሊም ቆርበት ቆርበት',
    '👮🏻' => 'ፖሊስ፦ ፍኹስ ዝበለ ቆርበት',
    '👮🏼' => 'ፖሊስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👮🏽' => 'ፖሊስ፦ ማእከላይ ቆርበት ዘለዎ',
    '👮🏾' => 'ፖሊስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👮🏿' => 'ፖሊስ፦ ጸሊም ቆርበት ቆርበት',
    '🕵🏻' => 'መርማሪ፦ ፍኹስ ዝበለ ቆርበት',
    '🕵🏼' => 'መርማሪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🕵🏽' => 'መርማሪ፦ ማእከላይ ቆርበት ዘለዎ',
    '🕵🏾' => 'መርማሪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🕵🏿' => 'መርማሪ፦ ጸሊም ቆርበት ቆርበት',
    '💂🏻' => 'ሓላዊ፦ ፍኹስ ዝበለ ቆርበት',
    '💂🏼' => 'ሓላዊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💂🏽' => 'ሓላዊ፦ ማእከላይ ቆርበት ዘለዎ',
    '💂🏾' => 'ሓላዊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💂🏿' => 'ሓላዊ፦ ጸሊም ቆርበት ቆርበት',
    '🥷🏻' => 'ኒንጃ፦ ፍኹስ ዝበለ ቆርበት',
    '🥷🏼' => 'ኒንጃ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🥷🏽' => 'ኒንጃ፦ ማእከላይ ቆርበት ዘለዎ',
    '🥷🏾' => 'ኒንጃ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🥷🏿' => 'ኒንጃ፦ ጸሊም ቆርበት ቆርበት',
    '👷🏻' => 'ሰራሕተኛ ህንጻ፦ ፍኹስ ዝበለ ቆርበት',
    '👷🏼' => 'ሰራሕተኛ ህንጻ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👷🏽' => 'ሰራሕተኛ ህንጻ፦ ማእከላይ ቆርበት ዘለዎ',
    '👷🏾' => 'ሰራሕተኛ ህንጻ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👷🏿' => 'ሰራሕተኛ ህንጻ፦ ጸሊም ቆርበት ቆርበት',
    '🫅🏻' => 'ዘውዲ ዘለዎ ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🫅🏼' => 'ዘውዲ ዘለዎ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫅🏽' => 'ዘውዲ ዘለዎ ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🫅🏾' => 'ዘውዲ ዘለዎ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫅🏿' => 'ዘውዲ ዘለዎ ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '🤴🏻' => 'ልኡል፦ ፍኹስ ዝበለ ቆርበት',
    '🤴🏼' => 'ልኡል፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤴🏽' => 'ልኡል፦ ማእከላይ ቆርበት ዘለዎ',
    '🤴🏾' => 'ልኡል፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤴🏿' => 'ልኡል፦ ጸሊም ቆርበት ቆርበት',
    '👸🏻' => 'ልእልቲ፦ ፍኹስ ዝበለ ቆርበት',
    '👸🏼' => 'ልእልቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👸🏽' => 'ልእልቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '👸🏾' => 'ልእልቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👸🏿' => 'ልእልቲ፦ ጸሊም ቆርበት ቆርበት',
    '👳🏻' => 'ቱርባን ዝለበሰ ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '👳🏼' => 'ቱርባን ዝለበሰ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👳🏽' => 'ቱርባን ዝለበሰ ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '👳🏾' => 'ቱርባን ዝለበሰ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👳🏿' => 'ቱርባን ዝለበሰ ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '👲🏻' => 'ርእሲ ምትካል ዘለዎ ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '👲🏼' => 'ርእሲ ምትካል ዘለዎ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👲🏽' => 'ርእሲ ምትካል ዘለዎ ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '👲🏾' => 'ርእሲ ምትካል ዘለዎ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👲🏿' => 'ርእሲ ምትካል ዘለዎ ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '🧕🏻' => 'ጓል ኣንስተይቲ ሽፋን ርእሲ ዘለዋ፦ ፍኹስ ዝበለ ቆርበት',
    '🧕🏼' => 'ጓል ኣንስተይቲ ሽፋን ርእሲ ዘለዋ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧕🏽' => 'ጓል ኣንስተይቲ ሽፋን ርእሲ ዘለዋ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧕🏾' => 'ጓል ኣንስተይቲ ሽፋን ርእሲ ዘለዋ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧕🏿' => 'ጓል ኣንስተይቲ ሽፋን ርእሲ ዘለዋ፦ ጸሊም ቆርበት ቆርበት',
    '🤵🏻' => 'ቱክሲዶ ዝለበሰ ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🤵🏼' => 'ቱክሲዶ ዝለበሰ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤵🏽' => 'ቱክሲዶ ዝለበሰ ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤵🏾' => 'ቱክሲዶ ዝለበሰ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤵🏿' => 'ቱክሲዶ ዝለበሰ ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '👰🏻' => 'መጋረጃ ዘለዎ ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '👰🏼' => 'መጋረጃ ዘለዎ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👰🏽' => 'መጋረጃ ዘለዎ ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '👰🏾' => 'መጋረጃ ዘለዎ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👰🏿' => 'መጋረጃ ዘለዎ ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '🤰🏻' => 'ነፍሰጾር ሰበይቲ፦ ፍኹስ ዝበለ ቆርበት',
    '🤰🏼' => 'ነፍሰጾር ሰበይቲ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤰🏽' => 'ነፍሰጾር ሰበይቲ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤰🏾' => 'ነፍሰጾር ሰበይቲ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤰🏿' => 'ነፍሰጾር ሰበይቲ፦ ጸሊም ቆርበት ቆርበት',
    '🫃🏻' => 'ጥንሲ ዘለዎ ሰብኣይ፦ ፍኹስ ዝበለ ቆርበት',
    '🫃🏼' => 'ጥንሲ ዘለዎ ሰብኣይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫃🏽' => 'ጥንሲ ዘለዎ ሰብኣይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🫃🏾' => 'ጥንሲ ዘለዎ ሰብኣይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫃🏿' => 'ጥንሲ ዘለዎ ሰብኣይ፦ ጸሊም ቆርበት ቆርበት',
    '🫄🏻' => 'ነፍሰጾር፦ ፍኹስ ዝበለ ቆርበት',
    '🫄🏼' => 'ነፍሰጾር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🫄🏽' => 'ነፍሰጾር፦ ማእከላይ ቆርበት ዘለዎ',
    '🫄🏾' => 'ነፍሰጾር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🫄🏿' => 'ነፍሰጾር፦ ጸሊም ቆርበት ቆርበት',
    '🤱🏻' => 'ተጥቡ ሓራስ፦ ፍኹስ ዝበለ ቆርበት',
    '🤱🏼' => 'ተጥቡ ሓራስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤱🏽' => 'ተጥቡ ሓራስ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤱🏾' => 'ተጥቡ ሓራስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤱🏿' => 'ተጥቡ ሓራስ፦ ጸሊም ቆርበት ቆርበት',
    '👼🏻' => 'ህጻን መልኣኽ፦ ፍኹስ ዝበለ ቆርበት',
    '👼🏼' => 'ህጻን መልኣኽ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👼🏽' => 'ህጻን መልኣኽ፦ ማእከላይ ቆርበት ዘለዎ',
    '👼🏾' => 'ህጻን መልኣኽ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👼🏿' => 'ህጻን መልኣኽ፦ ጸሊም ቆርበት ቆርበት',
    '🎅🏻' => 'አባባ ገና፦ ፍኹስ ዝበለ ቆርበት',
    '🎅🏼' => 'አባባ ገና፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🎅🏽' => 'አባባ ገና፦ ማእከላይ ቆርበት ዘለዎ',
    '🎅🏾' => 'አባባ ገና፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🎅🏿' => 'አባባ ገና፦ ጸሊም ቆርበት ቆርበት',
    '🤶🏻' => 'ወይዘሮ ገና፦ ፍኹስ ዝበለ ቆርበት',
    '🤶🏼' => 'ወይዘሮ ገና፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤶🏽' => 'ወይዘሮ ገና፦ ማእከላይ ቆርበት ዘለዎ',
    '🤶🏾' => 'ወይዘሮ ገና፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤶🏿' => 'ወይዘሮ ገና፦ ጸሊም ቆርበት ቆርበት',
    '🦸🏻' => 'ልዕለ ጅግና፦ ፍኹስ ዝበለ ቆርበት',
    '🦸🏼' => 'ልዕለ ጅግና፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🦸🏽' => 'ልዕለ ጅግና፦ ማእከላይ ቆርበት ዘለዎ',
    '🦸🏾' => 'ልዕለ ጅግና፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🦸🏿' => 'ልዕለ ጅግና፦ ጸሊም ቆርበት ቆርበት',
    '🦹🏻' => 'ሱፐርቪላን፦ ፍኹስ ዝበለ ቆርበት',
    '🦹🏼' => 'ሱፐርቪላን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🦹🏽' => 'ሱፐርቪላን፦ ማእከላይ ቆርበት ዘለዎ',
    '🦹🏾' => 'ሱፐርቪላን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🦹🏿' => 'ሱፐርቪላን፦ ጸሊም ቆርበት ቆርበት',
    '🧙🏻' => 'አስማተኛ፦ ፍኹስ ዝበለ ቆርበት',
    '🧙🏼' => 'አስማተኛ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧙🏽' => 'አስማተኛ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧙🏾' => 'አስማተኛ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧙🏿' => 'አስማተኛ፦ ጸሊም ቆርበት ቆርበት',
    '🧚🏻' => 'ፅውፅዋይ፦ ፍኹስ ዝበለ ቆርበት',
    '🧚🏼' => 'ፅውፅዋይ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧚🏽' => 'ፅውፅዋይ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧚🏾' => 'ፅውፅዋይ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧚🏿' => 'ፅውፅዋይ፦ ጸሊም ቆርበት ቆርበት',
    '🧛🏻' => 'ቫምፓየር፦ ፍኹስ ዝበለ ቆርበት',
    '🧛🏼' => 'ቫምፓየር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧛🏽' => 'ቫምፓየር፦ ማእከላይ ቆርበት ዘለዎ',
    '🧛🏾' => 'ቫምፓየር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧛🏿' => 'ቫምፓየር፦ ጸሊም ቆርበት ቆርበት',
    '🧜🏻' => 'ሰብ ዓሳ፦ ፍኹስ ዝበለ ቆርበት',
    '🧜🏼' => 'ሰብ ዓሳ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧜🏽' => 'ሰብ ዓሳ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧜🏾' => 'ሰብ ዓሳ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧜🏿' => 'ሰብ ዓሳ፦ ጸሊም ቆርበት ቆርበት',
    '🧝🏻' => 'ኤልፍ፦ ፍኹስ ዝበለ ቆርበት',
    '🧝🏼' => 'ኤልፍ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧝🏽' => 'ኤልፍ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧝🏾' => 'ኤልፍ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧝🏿' => 'ኤልፍ፦ ጸሊም ቆርበት ቆርበት',
    '💆🏻' => 'ሰብ ማሳጅ ዝገብር፦ ፍኹስ ዝበለ ቆርበት',
    '💆🏼' => 'ሰብ ማሳጅ ዝገብር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💆🏽' => 'ሰብ ማሳጅ ዝገብር፦ ማእከላይ ቆርበት ዘለዎ',
    '💆🏾' => 'ሰብ ማሳጅ ዝገብር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💆🏿' => 'ሰብ ማሳጅ ዝገብር፦ ጸሊም ቆርበት ቆርበት',
    '💇🏻' => 'ሰብ ጸጉሪ ርእሲ ምቑራጽ፦ ፍኹስ ዝበለ ቆርበት',
    '💇🏼' => 'ሰብ ጸጉሪ ርእሲ ምቑራጽ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💇🏽' => 'ሰብ ጸጉሪ ርእሲ ምቑራጽ፦ ማእከላይ ቆርበት ዘለዎ',
    '💇🏾' => 'ሰብ ጸጉሪ ርእሲ ምቑራጽ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💇🏿' => 'ሰብ ጸጉሪ ርእሲ ምቑራጽ፦ ጸሊም ቆርበት ቆርበት',
    '🚶🏻' => 'ሰብ እናተጓዕዘ፦ ፍኹስ ዝበለ ቆርበት',
    '🚶🏼' => 'ሰብ እናተጓዕዘ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚶🏽' => 'ሰብ እናተጓዕዘ፦ ማእከላይ ቆርበት ዘለዎ',
    '🚶🏾' => 'ሰብ እናተጓዕዘ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚶🏿' => 'ሰብ እናተጓዕዘ፦ ጸሊም ቆርበት ቆርበት',
    '🧍🏻' => 'ጠጠው ዝበለ ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🧍🏼' => 'ጠጠው ዝበለ ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧍🏽' => 'ጠጠው ዝበለ ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧍🏾' => 'ጠጠው ዝበለ ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧍🏿' => 'ጠጠው ዝበለ ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '🧎🏻' => 'ሰብ ተንበርኪኹ፦ ፍኹስ ዝበለ ቆርበት',
    '🧎🏼' => 'ሰብ ተንበርኪኹ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧎🏽' => 'ሰብ ተንበርኪኹ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧎🏾' => 'ሰብ ተንበርኪኹ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧎🏿' => 'ሰብ ተንበርኪኹ፦ ጸሊም ቆርበት ቆርበት',
    '🏃🏻' => 'ሰብ ዝጎዪ፦ ፍኹስ ዝበለ ቆርበት',
    '🏃🏼' => 'ሰብ ዝጎዪ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏃🏽' => 'ሰብ ዝጎዪ፦ ማእከላይ ቆርበት ዘለዎ',
    '🏃🏾' => 'ሰብ ዝጎዪ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏃🏿' => 'ሰብ ዝጎዪ፦ ጸሊም ቆርበት ቆርበት',
    '💃🏻' => 'ሰበይቲ ትስዕስዕ፦ ፍኹስ ዝበለ ቆርበት',
    '💃🏼' => 'ሰበይቲ ትስዕስዕ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💃🏽' => 'ሰበይቲ ትስዕስዕ፦ ማእከላይ ቆርበት ዘለዎ',
    '💃🏾' => 'ሰበይቲ ትስዕስዕ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💃🏿' => 'ሰበይቲ ትስዕስዕ፦ ጸሊም ቆርበት ቆርበት',
    '🕺🏻' => 'ሰብኣይ እናሳዕስዐ፦ ፍኹስ ዝበለ ቆርበት',
    '🕺🏼' => 'ሰብኣይ እናሳዕስዐ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🕺🏽' => 'ሰብኣይ እናሳዕስዐ፦ ማእከላይ ቆርበት ዘለዎ',
    '🕺🏾' => 'ሰብኣይ እናሳዕስዐ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🕺🏿' => 'ሰብኣይ እናሳዕስዐ፦ ጸሊም ቆርበት ቆርበት',
    '🕴🏻' => 'ኮስትሞ ዝለበሰ ሰብ ምልዓል፦ ፍኹስ ዝበለ ቆርበት',
    '🕴🏼' => 'ኮስትሞ ዝለበሰ ሰብ ምልዓል፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🕴🏽' => 'ኮስትሞ ዝለበሰ ሰብ ምልዓል፦ ማእከላይ ቆርበት ዘለዎ',
    '🕴🏾' => 'ኮስትሞ ዝለበሰ ሰብ ምልዓል፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🕴🏿' => 'ኮስትሞ ዝለበሰ ሰብ ምልዓል፦ ጸሊም ቆርበት ቆርበት',
    '👯🏻' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ፍኹስ ዝበለ ቆርበት',
    '👯🏼' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👯🏽' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ ቆርበት ዘለዎ',
    '👯🏾' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👯🏿' => 'እዝኒ ባኒ ዘለዎም ሰባት፦ ጸሊም ቆርበት ቆርበት',
    '🧖🏻' => 'ሰብ ኣብ ስቲም ዝመልአ ክፍሊ፦ ፍኹስ ዝበለ ቆርበት',
    '🧖🏼' => 'ሰብ ኣብ ስቲም ዝመልአ ክፍሊ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧖🏽' => 'ሰብ ኣብ ስቲም ዝመልአ ክፍሊ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧖🏾' => 'ሰብ ኣብ ስቲም ዝመልአ ክፍሊ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧖🏿' => 'ሰብ ኣብ ስቲም ዝመልአ ክፍሊ፦ ጸሊም ቆርበት ቆርበት',
    '🧗🏻' => 'ሰብ እናደየበ፦ ፍኹስ ዝበለ ቆርበት',
    '🧗🏼' => 'ሰብ እናደየበ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧗🏽' => 'ሰብ እናደየበ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧗🏾' => 'ሰብ እናደየበ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧗🏿' => 'ሰብ እናደየበ፦ ጸሊም ቆርበት ቆርበት',
    '🏇🏻' => 'ውድድር ፈረስ፦ ፍኹስ ዝበለ ቆርበት',
    '🏇🏼' => 'ውድድር ፈረስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏇🏽' => 'ውድድር ፈረስ፦ ማእከላይ ቆርበት ዘለዎ',
    '🏇🏾' => 'ውድድር ፈረስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏇🏿' => 'ውድድር ፈረስ፦ ጸሊም ቆርበት ቆርበት',
    '🏂🏻' => 'ተቐዳዳማይ ስኖቦርደር፦ ፍኹስ ዝበለ ቆርበት',
    '🏂🏼' => 'ተቐዳዳማይ ስኖቦርደር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏂🏽' => 'ተቐዳዳማይ ስኖቦርደር፦ ማእከላይ ቆርበት ዘለዎ',
    '🏂🏾' => 'ተቐዳዳማይ ስኖቦርደር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏂🏿' => 'ተቐዳዳማይ ስኖቦርደር፦ ጸሊም ቆርበት ቆርበት',
    '🏌🏻' => 'ሰብ ጎልፍ ዝጻወት፦ ፍኹስ ዝበለ ቆርበት',
    '🏌🏼' => 'ሰብ ጎልፍ ዝጻወት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏌🏽' => 'ሰብ ጎልፍ ዝጻወት፦ ማእከላይ ቆርበት ዘለዎ',
    '🏌🏾' => 'ሰብ ጎልፍ ዝጻወት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏌🏿' => 'ሰብ ጎልፍ ዝጻወት፦ ጸሊም ቆርበት ቆርበት',
    '🏄🏻' => 'ሰብ ሰርፊንግ ምግባር፦ ፍኹስ ዝበለ ቆርበት',
    '🏄🏼' => 'ሰብ ሰርፊንግ ምግባር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏄🏽' => 'ሰብ ሰርፊንግ ምግባር፦ ማእከላይ ቆርበት ዘለዎ',
    '🏄🏾' => 'ሰብ ሰርፊንግ ምግባር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏄🏿' => 'ሰብ ሰርፊንግ ምግባር፦ ጸሊም ቆርበት ቆርበት',
    '🚣🏻' => 'ሰብ ጃልባ ምቕዛፍ፦ ፍኹስ ዝበለ ቆርበት',
    '🚣🏼' => 'ሰብ ጃልባ ምቕዛፍ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚣🏽' => 'ሰብ ጃልባ ምቕዛፍ፦ ማእከላይ ቆርበት ዘለዎ',
    '🚣🏾' => 'ሰብ ጃልባ ምቕዛፍ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚣🏿' => 'ሰብ ጃልባ ምቕዛፍ፦ ጸሊም ቆርበት ቆርበት',
    '🏊🏻' => 'ሰብ ምሕንባስ፦ ፍኹስ ዝበለ ቆርበት',
    '🏊🏼' => 'ሰብ ምሕንባስ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏊🏽' => 'ሰብ ምሕንባስ፦ ማእከላይ ቆርበት ዘለዎ',
    '🏊🏾' => 'ሰብ ምሕንባስ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏊🏿' => 'ሰብ ምሕንባስ፦ ጸሊም ቆርበት ቆርበት',
    '⛹🏻' => 'ሰብ ኩዕሶ ዝብንጭር፦ ፍኹስ ዝበለ ቆርበት',
    '⛹🏼' => 'ሰብ ኩዕሶ ዝብንጭር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '⛹🏽' => 'ሰብ ኩዕሶ ዝብንጭር፦ ማእከላይ ቆርበት ዘለዎ',
    '⛹🏾' => 'ሰብ ኩዕሶ ዝብንጭር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '⛹🏿' => 'ሰብ ኩዕሶ ዝብንጭር፦ ጸሊም ቆርበት ቆርበት',
    '🏋🏻' => 'ሰብ ክብደት ምልዓል፦ ፍኹስ ዝበለ ቆርበት',
    '🏋🏼' => 'ሰብ ክብደት ምልዓል፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏋🏽' => 'ሰብ ክብደት ምልዓል፦ ማእከላይ ቆርበት ዘለዎ',
    '🏋🏾' => 'ሰብ ክብደት ምልዓል፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏋🏿' => 'ሰብ ክብደት ምልዓል፦ ጸሊም ቆርበት ቆርበት',
    '🚴🏻' => 'ሰብ ብሽክለታ ምዝዋር፦ ፍኹስ ዝበለ ቆርበት',
    '🚴🏼' => 'ሰብ ብሽክለታ ምዝዋር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚴🏽' => 'ሰብ ብሽክለታ ምዝዋር፦ ማእከላይ ቆርበት ዘለዎ',
    '🚴🏾' => 'ሰብ ብሽክለታ ምዝዋር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚴🏿' => 'ሰብ ብሽክለታ ምዝዋር፦ ጸሊም ቆርበት ቆርበት',
    '🚵🏻' => 'ሰብ ናይ ተራራ ብሽክለታ ምዝዋር፦ ፍኹስ ዝበለ ቆርበት',
    '🚵🏼' => 'ሰብ ናይ ተራራ ብሽክለታ ምዝዋር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🚵🏽' => 'ሰብ ናይ ተራራ ብሽክለታ ምዝዋር፦ ማእከላይ ቆርበት ዘለዎ',
    '🚵🏾' => 'ሰብ ናይ ተራራ ብሽክለታ ምዝዋር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🚵🏿' => 'ሰብ ናይ ተራራ ብሽክለታ ምዝዋር፦ ጸሊም ቆርበት ቆርበት',
    '🤸🏻' => 'ሰብ ዓረብያ ምዝዋር፦ ፍኹስ ዝበለ ቆርበት',
    '🤸🏼' => 'ሰብ ዓረብያ ምዝዋር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤸🏽' => 'ሰብ ዓረብያ ምዝዋር፦ ማእከላይ ቆርበት ዘለዎ',
    '🤸🏾' => 'ሰብ ዓረብያ ምዝዋር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤸🏿' => 'ሰብ ዓረብያ ምዝዋር፦ ጸሊም ቆርበት ቆርበት',
    '🤼🏻' => 'ሰባት እናተቓለሱ፦ ፍኹስ ዝበለ ቆርበት',
    '🤼🏼' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤼🏽' => 'ሰባት እናተቓለሱ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤼🏾' => 'ሰባት እናተቓለሱ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤼🏿' => 'ሰባት እናተቓለሱ፦ ጸሊም ቆርበት ቆርበት',
    '🤽🏻' => 'ዋተር ፖሎ ዝጻወት ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🤽🏼' => 'ዋተር ፖሎ ዝጻወት ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤽🏽' => 'ዋተር ፖሎ ዝጻወት ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤽🏾' => 'ዋተር ፖሎ ዝጻወት ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤽🏿' => 'ዋተር ፖሎ ዝጻወት ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '🤾🏻' => 'ኩዕሶ ኢድ ዝጻወት ሰብ፦ ፍኹስ ዝበለ ቆርበት',
    '🤾🏼' => 'ኩዕሶ ኢድ ዝጻወት ሰብ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤾🏽' => 'ኩዕሶ ኢድ ዝጻወት ሰብ፦ ማእከላይ ቆርበት ዘለዎ',
    '🤾🏾' => 'ኩዕሶ ኢድ ዝጻወት ሰብ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤾🏿' => 'ኩዕሶ ኢድ ዝጻወት ሰብ፦ ጸሊም ቆርበት ቆርበት',
    '🤹🏻' => 'ሰብ ጃግሊንግ ምግባር፦ ፍኹስ ዝበለ ቆርበት',
    '🤹🏼' => 'ሰብ ጃግሊንግ ምግባር፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🤹🏽' => 'ሰብ ጃግሊንግ ምግባር፦ ማእከላይ ቆርበት ዘለዎ',
    '🤹🏾' => 'ሰብ ጃግሊንግ ምግባር፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🤹🏿' => 'ሰብ ጃግሊንግ ምግባር፦ ጸሊም ቆርበት ቆርበት',
    '🧘🏻' => 'ሰብ ኣብ ሎተስ መርገጺ፦ ፍኹስ ዝበለ ቆርበት',
    '🧘🏼' => 'ሰብ ኣብ ሎተስ መርገጺ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🧘🏽' => 'ሰብ ኣብ ሎተስ መርገጺ፦ ማእከላይ ቆርበት ዘለዎ',
    '🧘🏾' => 'ሰብ ኣብ ሎተስ መርገጺ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🧘🏿' => 'ሰብ ኣብ ሎተስ መርገጺ፦ ጸሊም ቆርበት ቆርበት',
    '🛀🏻' => 'ሰብ ክሕጸብ ከሎ፦ ፍኹስ ዝበለ ቆርበት',
    '🛀🏼' => 'ሰብ ክሕጸብ ከሎ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🛀🏽' => 'ሰብ ክሕጸብ ከሎ፦ ማእከላይ ቆርበት ዘለዎ',
    '🛀🏾' => 'ሰብ ክሕጸብ ከሎ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🛀🏿' => 'ሰብ ክሕጸብ ከሎ፦ ጸሊም ቆርበት ቆርበት',
    '🛌🏻' => 'ሰብ ኣብ ዓራት፦ ፍኹስ ዝበለ ቆርበት',
    '🛌🏼' => 'ሰብ ኣብ ዓራት፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🛌🏽' => 'ሰብ ኣብ ዓራት፦ ማእከላይ ቆርበት ዘለዎ',
    '🛌🏾' => 'ሰብ ኣብ ዓራት፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🛌🏿' => 'ሰብ ኣብ ዓራት፦ ጸሊም ቆርበት ቆርበት',
    '👭🏻' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ፍኹስ ዝበለ ቆርበት',
    '👭🏼' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👭🏽' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ ቆርበት ዘለዎ',
    '👭🏾' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👭🏿' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን፦ ጸሊም ቆርበት ቆርበት',
    '👫🏻' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት',
    '👫🏼' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👫🏽' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ',
    '👫🏾' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👫🏿' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት',
    '👬🏻' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ፍኹስ ዝበለ ቆርበት',
    '👬🏼' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '👬🏽' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ ቆርበት ዘለዎ',
    '👬🏾' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '👬🏿' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም፦ ጸሊም ቆርበት ቆርበት',
    '💏🏻' => 'ምስዓም፦ ፍኹስ ዝበለ ቆርበት',
    '💏🏼' => 'ምስዓም፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💏🏽' => 'ምስዓም፦ ማእከላይ ቆርበት ዘለዎ',
    '💏🏾' => 'ምስዓም፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💏🏿' => 'ምስዓም፦ ጸሊም ቆርበት ቆርበት',
    '💑🏻' => 'መጻምድቲ ምስ ልቢ፦ ፍኹስ ዝበለ ቆርበት',
    '💑🏼' => 'መጻምድቲ ምስ ልቢ፦ ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '💑🏽' => 'መጻምድቲ ምስ ልቢ፦ ማእከላይ ቆርበት ዘለዎ',
    '💑🏾' => 'መጻምድቲ ምስ ልቢ፦ ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '💑🏿' => 'መጻምድቲ ምስ ልቢ፦ ጸሊም ቆርበት ቆርበት',
    '🇦🇨' => 'ባንዴራ፦ ደሴት ኣሰንስዮን',
    '🇦🇩' => 'ባንዴራ፦ ኣንዶራ',
    '🇦🇪' => 'ባንዴራ፦ ሕቡራት ኢማራት ዓረብ',
    '🇦🇫' => 'ባንዴራ፦ ኣፍጋኒስታን',
    '🇦🇬' => 'ባንዴራ፦ ኣንቲጓን ባርቡዳን',
    '🇦🇮' => 'ባንዴራ፦ ኣንጒላ',
    '🇦🇱' => 'ባንዴራ፦ ኣልባንያ',
    '🇦🇲' => 'ባንዴራ፦ ኣርሜንያ',
    '🇦🇴' => 'ባንዴራ፦ ኣንጎላ',
    '🇦🇶' => 'ባንዴራ፦ ኣንታርክቲካ',
    '🇦🇷' => 'ባንዴራ፦ ኣርጀንቲና',
    '🇦🇸' => 'ባንዴራ፦ ኣመሪካዊት ሳሞኣ',
    '🇦🇹' => 'ባንዴራ፦ ኦስትርያ',
    '🇦🇺' => 'ባንዴራ፦ ኣውስትራልያ',
    '🇦🇼' => 'ባንዴራ፦ ኣሩባ',
    '🇦🇽' => 'ባንዴራ፦ ደሴታት ኣላንድ',
    '🇦🇿' => 'ባንዴራ፦ ኣዘርባጃን',
    '🇧🇦' => 'ባንዴራ፦ ቦዝንያን ሄርዘጎቪናን',
    '🇧🇧' => 'ባንዴራ፦ ባርባዶስ',
    '🇧🇩' => 'ባንዴራ፦ ባንግላደሽ',
    '🇧🇪' => 'ባንዴራ፦ ቤልጅዩም',
    '🇧🇫' => 'ባንዴራ፦ ቡርኪና ፋሶ',
    '🇧🇬' => 'ባንዴራ፦ ቡልጋርያ',
    '🇧🇭' => 'ባንዴራ፦ ባሕሬን',
    '🇧🇮' => 'ባንዴራ፦ ብሩንዲ',
    '🇧🇯' => 'ባንዴራ፦ ቤኒን',
    '🇧🇱' => 'ባንዴራ፦ ቅዱስ ባርተለሚ',
    '🇧🇲' => 'ባንዴራ፦ በርሙዳ',
    '🇧🇳' => 'ባንዴራ፦ ብሩነይ',
    '🇧🇴' => 'ባንዴራ፦ ቦሊቭያ',
    '🇧🇶' => 'ባንዴራ፦ ካሪብያን ኔዘርላንድ',
    '🇧🇷' => 'ባንዴራ፦ ብራዚል',
    '🇧🇸' => 'ባንዴራ፦ ባሃማስ',
    '🇧🇹' => 'ባንዴራ፦ ቡታን',
    '🇧🇻' => 'ባንዴራ፦ ደሴት ቡቨት',
    '🇧🇼' => 'ባንዴራ፦ ቦትስዋና',
    '🇧🇾' => 'ባንዴራ፦ ቤላሩስ',
    '🇧🇿' => 'ባንዴራ፦ በሊዝ',
    '🇨🇦' => 'ባንዴራ፦ ካናዳ',
    '🇨🇨' => 'ባንዴራ፦ ደሴታት ኮኮስ',
    '🇨🇩' => 'ባንዴራ፦ ደሞክራስያዊት ሪፓብሊክ ኮንጎ',
    '🇨🇫' => 'ባንዴራ፦ ሪፓብሊክ ማእከላይ ኣፍሪቃ',
    '🇨🇬' => 'ባንዴራ፦ ኮንጎ',
    '🇨🇭' => 'ባንዴራ፦ ስዊዘርላንድ',
    '🇨🇮' => 'ባንዴራ፦ ኮት ዲቭዋር',
    '🇨🇰' => 'ባንዴራ፦ ደሴታት ኩክ',
    '🇨🇱' => 'ባንዴራ፦ ቺሌ',
    '🇨🇲' => 'ባንዴራ፦ ካሜሩን',
    '🇨🇳' => 'ባንዴራ፦ ቻይና',
    '🇨🇴' => 'ባንዴራ፦ ኮሎምብያ',
    '🇨🇵' => 'ባንዴራ፦ ደሴት ክሊፐርቶን',
    '🇨🇶' => 'ባንዴራ፦ ሳርክ',
    '🇨🇷' => 'ባንዴራ፦ ኮስታ ሪካ',
    '🇨🇺' => 'ባንዴራ፦ ኩባ',
    '🇨🇻' => 'ባንዴራ፦ ኬፕ ቨርደ',
    '🇨🇼' => 'ባንዴራ፦ ኩራሳው',
    '🇨🇽' => 'ባንዴራ፦ ደሴት ክሪስማስ',
    '🇨🇾' => 'ባንዴራ፦ ቆጵሮስ',
    '🇨🇿' => 'ባንዴራ፦ ቸክያ',
    '🇩🇪' => 'ባንዴራ፦ ጀርመን',
    '🇩🇬' => 'ባንዴራ፦ ድየጎ ጋርስያ',
    '🇩🇯' => 'ባንዴራ፦ ጅቡቲ',
    '🇩🇰' => 'ባንዴራ፦ ደንማርክ',
    '🇩🇲' => 'ባንዴራ፦ ዶሚኒካ',
    '🇩🇴' => 'ባንዴራ፦ ዶሚኒካዊት ሪፓብሊክ',
    '🇩🇿' => 'ባንዴራ፦ ኣልጀርያ',
    '🇪🇦' => 'ባንዴራ፦ ሴውታን መሊላን',
    '🇪🇨' => 'ባንዴራ፦ ኤኳዶር',
    '🇪🇪' => 'ባንዴራ፦ ኤስቶንያ',
    '🇪🇬' => 'ባንዴራ፦ ግብጺ',
    '🇪🇭' => 'ባንዴራ፦ ምዕራባዊ ሰሃራ',
    '🇪🇷' => 'ባንዴራ፦ ኤርትራ',
    '🇪🇸' => 'ባንዴራ፦ ስጳኛ',
    '🇪🇹' => 'ባንዴራ፦ ኢትዮጵያ',
    '🇪🇺' => 'ባንዴራ፦ ኤውሮጳዊ ሕብረት',
    '🇫🇮' => 'ባንዴራ፦ ፊንላንድ',
    '🇫🇯' => 'ባንዴራ፦ ፊጂ',
    '🇫🇰' => 'ባንዴራ፦ ደሴታት ፎክላንድ',
    '🇫🇲' => 'ባንዴራ፦ ማይክሮነዥያ',
    '🇫🇴' => 'ባንዴራ፦ ደሴታት ፋሮ',
    '🇫🇷' => 'ባንዴራ፦ ፈረንሳ',
    '🇬🇦' => 'ባንዴራ፦ ጋቦን',
    '🇬🇧' => 'ባንዴራ፦ ብሪጣንያ',
    '🇬🇩' => 'ባንዴራ፦ ግረናዳ',
    '🇬🇪' => 'ባንዴራ፦ ጆርጅያ',
    '🇬🇫' => 'ባንዴራ፦ ፈረንሳዊት ጊያና',
    '🇬🇬' => 'ባንዴራ፦ ገርንዚ',
    '🇬🇭' => 'ባንዴራ፦ ጋና',
    '🇬🇮' => 'ባንዴራ፦ ጂብራልታር',
    '🇬🇱' => 'ባንዴራ፦ ግሪንላንድ',
    '🇬🇲' => 'ባንዴራ፦ ጋምብያ',
    '🇬🇳' => 'ባንዴራ፦ ጊኒ',
    '🇬🇵' => 'ባንዴራ፦ ጓደሉፕ',
    '🇬🇶' => 'ባንዴራ፦ ኢኳቶርያል ጊኒ',
    '🇬🇷' => 'ባንዴራ፦ ግሪኽ',
    '🇬🇸' => 'ባንዴራ፦ ደሴታት ደቡብ ጆርጅያን ደቡብ ሳንድዊችን',
    '🇬🇹' => 'ባንዴራ፦ ጓቲማላ',
    '🇬🇺' => 'ባንዴራ፦ ጓም',
    '🇬🇼' => 'ባንዴራ፦ ጊኒ-ቢሳው',
    '🇬🇾' => 'ባንዴራ፦ ጉያና',
    '🇭🇰' => 'ባንዴራ፦ ፍሉይ ምምሕዳራዊ ዞባ ሆንግ ኮንግ (ቻይና)',
    '🇭🇲' => 'ባንዴራ፦ ደሴታት ሄርድን ማክዶናልድን',
    '🇭🇳' => 'ባንዴራ፦ ሆንዱራስ',
    '🇭🇷' => 'ባንዴራ፦ ክሮኤሽያ',
    '🇭🇹' => 'ባንዴራ፦ ሃይቲ',
    '🇭🇺' => 'ባንዴራ፦ ሃንጋሪ',
    '🇮🇨' => 'ባንዴራ፦ ደሴታት ካናሪ',
    '🇮🇩' => 'ባንዴራ፦ ኢንዶነዥያ',
    '🇮🇪' => 'ባንዴራ፦ ኣየርላንድ',
    '🇮🇱' => 'ባንዴራ፦ እስራኤል',
    '🇮🇲' => 'ባንዴራ፦ ኣይል ኦፍ ማን',
    '🇮🇳' => 'ባንዴራ፦ ህንዲ',
    '🇮🇴' => 'ባንዴራ፦ ብሪጣንያዊ ህንዳዊ ውቅያኖስ ግዝኣት',
    '🇮🇶' => 'ባንዴራ፦ ዒራቕ',
    '🇮🇷' => 'ባንዴራ፦ ኢራን',
    '🇮🇸' => 'ባንዴራ፦ ኣይስላንድ',
    '🇮🇹' => 'ባንዴራ፦ ኢጣልያ',
    '🇯🇪' => 'ባንዴራ፦ ጀርዚ',
    '🇯🇲' => 'ባንዴራ፦ ጃማይካ',
    '🇯🇴' => 'ባንዴራ፦ ዮርዳኖስ',
    '🇯🇵' => 'ባንዴራ፦ ጃፓን',
    '🇰🇪' => 'ባንዴራ፦ ኬንያ',
    '🇰🇬' => 'ባንዴራ፦ ኪርጊዝስታን',
    '🇰🇭' => 'ባንዴራ፦ ካምቦድያ',
    '🇰🇮' => 'ባንዴራ፦ ኪሪባቲ',
    '🇰🇲' => 'ባንዴራ፦ ኮሞሮስ',
    '🇰🇳' => 'ባንዴራ፦ ቅዱስ ኪትስን ኔቪስን',
    '🇰🇵' => 'ባንዴራ፦ ሰሜን ኮርያ',
    '🇰🇷' => 'ባንዴራ፦ ደቡብ ኮርያ',
    '🇰🇼' => 'ባንዴራ፦ ኩዌት',
    '🇰🇾' => 'ባንዴራ፦ ደሴታት ካይማን',
    '🇰🇿' => 'ባንዴራ፦ ካዛኪስታን',
    '🇱🇦' => 'ባንዴራ፦ ላኦስ',
    '🇱🇧' => 'ባንዴራ፦ ሊባኖስ',
    '🇱🇨' => 'ባንዴራ፦ ቅድስቲ ሉስያ',
    '🇱🇮' => 'ባንዴራ፦ ሊኽተንሽታይን',
    '🇱🇰' => 'ባንዴራ፦ ስሪ ላንካ',
    '🇱🇷' => 'ባንዴራ፦ ላይበርያ',
    '🇱🇸' => 'ባንዴራ፦ ሌሶቶ',
    '🇱🇹' => 'ባንዴራ፦ ሊትዌንያ',
    '🇱🇺' => 'ባንዴራ፦ ሉክሰምበርግ',
    '🇱🇻' => 'ባንዴራ፦ ላትቭያ',
    '🇱🇾' => 'ባንዴራ፦ ሊብያ',
    '🇲🇦' => 'ባንዴራ፦ ሞሮኮ',
    '🇲🇨' => 'ባንዴራ፦ ሞናኮ',
    '🇲🇩' => 'ባንዴራ፦ ሞልዶቫ',
    '🇲🇪' => 'ባንዴራ፦ ሞንተኔግሮ',
    '🇲🇫' => 'ባንዴራ፦ ቅዱስ ማርቲን',
    '🇲🇬' => 'ባንዴራ፦ ማዳጋስካር',
    '🇲🇭' => 'ባንዴራ፦ ደሴታት ማርሻል',
    '🇲🇰' => 'ባንዴራ፦ ሰሜን መቄዶንያ',
    '🇲🇱' => 'ባንዴራ፦ ማሊ',
    '🇲🇲' => 'ባንዴራ፦ ሚያንማር (በርማ)',
    '🇲🇳' => 'ባንዴራ፦ ሞንጎልያ',
    '🇲🇴' => 'ባንዴራ፦ ፍሉይ ምምሕዳራዊ ዞባ ማካው (ቻይና)',
    '🇲🇵' => 'ባንዴራ፦ ሰሜናዊ ደሴታት ማርያና',
    '🇲🇶' => 'ባንዴራ፦ ማርቲኒክ',
    '🇲🇷' => 'ባንዴራ፦ ማውሪታንያ',
    '🇲🇸' => 'ባንዴራ፦ ሞንትሰራት',
    '🇲🇹' => 'ባንዴራ፦ ማልታ',
    '🇲🇺' => 'ባንዴራ፦ ማውሪሸስ',
    '🇲🇻' => 'ባንዴራ፦ ማልዲቭስ',
    '🇲🇼' => 'ባንዴራ፦ ማላዊ',
    '🇲🇽' => 'ባንዴራ፦ ሜክሲኮ',
    '🇲🇾' => 'ባንዴራ፦ ማለዥያ',
    '🇲🇿' => 'ባንዴራ፦ ሞዛምቢክ',
    '🇳🇦' => 'ባንዴራ፦ ናሚብያ',
    '🇳🇨' => 'ባንዴራ፦ ኒው ካለዶንያ',
    '🇳🇪' => 'ባንዴራ፦ ኒጀር',
    '🇳🇫' => 'ባንዴራ፦ ደሴት ኖርፎልክ',
    '🇳🇬' => 'ባንዴራ፦ ናይጀርያ',
    '🇳🇮' => 'ባንዴራ፦ ኒካራጓ',
    '🇳🇱' => 'ባንዴራ፦ ኔዘርላንድ',
    '🇳🇴' => 'ባንዴራ፦ ኖርወይ',
    '🇳🇵' => 'ባንዴራ፦ ኔፓል',
    '🇳🇷' => 'ባንዴራ፦ ናውሩ',
    '🇳🇺' => 'ባንዴራ፦ ኒዩ',
    '🇳🇿' => 'ባንዴራ፦ ኒው ዚላንድ',
    '🇴🇲' => 'ባንዴራ፦ ዖማን',
    '🇵🇦' => 'ባንዴራ፦ ፓናማ',
    '🇵🇪' => 'ባንዴራ፦ ፔሩ',
    '🇵🇫' => 'ባንዴራ፦ ፈረንሳዊት ፖሊነዥያ',
    '🇵🇬' => 'ባንዴራ፦ ፓፕዋ ኒው ጊኒ',
    '🇵🇭' => 'ባንዴራ፦ ፊሊፒንስ',
    '🇵🇰' => 'ባንዴራ፦ ፓኪስታን',
    '🇵🇱' => 'ባንዴራ፦ ፖላንድ',
    '🇵🇲' => 'ባንዴራ፦ ቅዱስ ፕየርን ሚከሎንን',
    '🇵🇳' => 'ባንዴራ፦ ደሴታት ፒትካርን',
    '🇵🇷' => 'ባንዴራ፦ ፖርቶ ሪኮ',
    '🇵🇸' => 'ባንዴራ፦ ግዝኣታት ፍልስጤም',
    '🇵🇹' => 'ባንዴራ፦ ፖርቱጋል',
    '🇵🇼' => 'ባንዴራ፦ ፓላው',
    '🇵🇾' => 'ባንዴራ፦ ፓራጓይ',
    '🇶🇦' => 'ባንዴራ፦ ቐጠር',
    '🇷🇪' => 'ባንዴራ፦ ርዩንየን',
    '🇷🇴' => 'ባንዴራ፦ ሩማንያ',
    '🇷🇸' => 'ባንዴራ፦ ሰርብያ',
    '🇷🇺' => 'ባንዴራ፦ ሩስያ',
    '🇷🇼' => 'ባንዴራ፦ ርዋንዳ',
    '🇸🇦' => 'ባንዴራ፦ ስዑዲ ዓረብ',
    '🇸🇧' => 'ባንዴራ፦ ደሴታት ሰሎሞን',
    '🇸🇨' => 'ባንዴራ፦ ሲሸልስ',
    '🇸🇩' => 'ባንዴራ፦ ሱዳን',
    '🇸🇪' => 'ባንዴራ፦ ሽወደን',
    '🇸🇬' => 'ባንዴራ፦ ሲንጋፖር',
    '🇸🇭' => 'ባንዴራ፦ ቅድስቲ ሄለና',
    '🇸🇮' => 'ባንዴራ፦ ስሎቬንያ',
    '🇸🇯' => 'ባንዴራ፦ ስቫልባርድን ጃን ማየንን',
    '🇸🇰' => 'ባንዴራ፦ ስሎቫክያ',
    '🇸🇱' => 'ባንዴራ፦ ሴራ ልዮን',
    '🇸🇲' => 'ባንዴራ፦ ሳን ማሪኖ',
    '🇸🇳' => 'ባንዴራ፦ ሰነጋል',
    '🇸🇴' => 'ባንዴራ፦ ሶማልያ',
    '🇸🇷' => 'ባንዴራ፦ ሱሪናም',
    '🇸🇸' => 'ባንዴራ፦ ደቡብ ሱዳን',
    '🇸🇹' => 'ባንዴራ፦ ሳኦ ቶመን ፕሪንሲፐን',
    '🇸🇻' => 'ባንዴራ፦ ኤል ሳልቫዶር',
    '🇸🇽' => 'ባንዴራ፦ ሲንት ማርተን',
    '🇸🇾' => 'ባንዴራ፦ ሶርያ',
    '🇸🇿' => 'ባንዴራ፦ ኤስዋቲኒ',
    '🇹🇦' => 'ባንዴራ፦ ትሪስታን ዳ ኩንያ',
    '🇹🇨' => 'ባንዴራ፦ ደሴታት ቱርካትን ካይኮስን',
    '🇹🇩' => 'ባንዴራ፦ ቻድ',
    '🇹🇫' => 'ባንዴራ፦ ፈረንሳዊ ደቡባዊ ግዝኣታት',
    '🇹🇬' => 'ባንዴራ፦ ቶጎ',
    '🇹🇭' => 'ባንዴራ፦ ታይላንድ',
    '🇹🇯' => 'ባንዴራ፦ ታጂኪስታን',
    '🇹🇰' => 'ባንዴራ፦ ቶከላው',
    '🇹🇱' => 'ባንዴራ፦ ቲሞር-ለስተ',
    '🇹🇲' => 'ባንዴራ፦ ቱርክመኒስታን',
    '🇹🇳' => 'ባንዴራ፦ ቱኒዝያ',
    '🇹🇴' => 'ባንዴራ፦ ቶንጋ',
    '🇹🇷' => 'ባንዴራ፦ ቱርኪ',
    '🇹🇹' => 'ባንዴራ፦ ትሪኒዳድን ቶባጎን',
    '🇹🇻' => 'ባንዴራ፦ ቱቫሉ',
    '🇹🇼' => 'ባንዴራ፦ ታይዋን',
    '🇹🇿' => 'ባንዴራ፦ ታንዛንያ',
    '🇺🇦' => 'ባንዴራ፦ ዩክሬን',
    '🇺🇬' => 'ባንዴራ፦ ኡጋንዳ',
    '🇺🇲' => 'ባንዴራ፦ ካብ ኣመሪካ ርሒቐን ንኣሽቱ ደሴታት',
    '🇺🇳' => 'ባንዴራ፦ ሕቡራት ሃገራት',
    '🇺🇸' => 'ባንዴራ፦ ኣመሪካ',
    '🇺🇾' => 'ባንዴራ፦ ኡራጓይ',
    '🇺🇿' => 'ባንዴራ፦ ኡዝበኪስታን',
    '🇻🇦' => 'ባንዴራ፦ ከተማ ቫቲካን',
    '🇻🇨' => 'ባንዴራ፦ ቅዱስ ቪንሰንትን ግረነዲነዝን',
    '🇻🇪' => 'ባንዴራ፦ ቬኔዝዌላ',
    '🇻🇬' => 'ባንዴራ፦ ደሴታት ደናግል ብሪጣንያ',
    '🇻🇮' => 'ባንዴራ፦ ደሴታት ደናግል ኣመሪካ',
    '🇻🇳' => 'ባንዴራ፦ ቬትናም',
    '🇻🇺' => 'ባንዴራ፦ ቫንዋቱ',
    '🇼🇫' => 'ባንዴራ፦ ዋሊስን ፉቱናን',
    '🇼🇸' => 'ባንዴራ፦ ሳሞኣ',
    '🇽🇰' => 'ባንዴራ፦ ኮሶቮ',
    '🇾🇪' => 'ባንዴራ፦ የመን',
    '🇾🇹' => 'ባንዴራ፦ ማዮት',
    '🇿🇦' => 'ባንዴራ፦ ደቡብ ኣፍሪቃ',
    '🇿🇲' => 'ባንዴራ፦ ዛምብያ',
    '🇿🇼' => 'ባንዴራ፦ ዚምባብዌ',
    '🔟' => 'ዝምልከት ቁልፊ፦ 10',
    '🏻' => 'ፍኹስ ዝበለ ቆርበት',
    '🏼' => 'ማእከላይ-ፈኲስ ቆርበት ዘለዎ',
    '🏽' => 'ማእከላይ ቆርበት ዘለዎ',
    '🏾' => 'ማእከላይ-ጸሊም ቆርበት ቆርበት',
    '🏿' => 'ጸሊም ቆርበት ቆርበት',
    '😀' => 'ፍሽኽታ ዝመልኦ ገጽ',
    '😃' => 'ፍሽኽ ዝበለ ገጽ ምስ ዓበይቲ ኣዒንቲ',
    '😄' => 'ፍሽኽ ዝበለ ገጽ ምስ ፍሽኽ ዝበሉ ኣዒንቲ',
    '😁' => 'ብርህ ዝበለ ገጽ ምስ ፍሽኽ ዝበሉ ኣዒንቲ',
    '😆' => 'ዝስሕቕን ዘጨምጨመን ገጽ',
    '😅' => 'ፍሽኽ ዝበለ ገጽ ምስ ረሃጽ',
    '🤣' => 'ኣብ መሬት እንዳተንከባለለን እንዳሰሓቐን',
    '😂' => 'ናይ ታሕጓስ ንብዓት ዘለዎ ገጽ',
    '🙂' => 'ቁሩብ ፍሽኽ ዝበለ ገጽ',
    '🙃' => 'ዝተገምጠለ ገጽ',
    '🫠' => 'እንዳሓቐቐ ዘሎ ገጽ',
    '😉' => 'ዝጠቅስ ገጽ',
    '😊' => 'ፍሽኽ ዝበሉ ኣዒንቲ ዘለዉዎ ፍሽኽ ዝበለ ገጽ',
    '😇' => 'ፍሽኽ ዝበለ ገጽ ምስ ዓንኬል ብርሃን',
    '🥰' => 'ፍሽኽታ ዝመልኦ ገጽ ምስ ልብታት',
    '😍' => 'ፍሽኽታ ዝመልኦ ገጽ ምስ ኣዒንቲ ልቢ',
    '🤩' => 'ኮኾብ ዘለዎ',
    '😘' => 'ሰዓማይ ገጽ',
    '😗' => 'ዝስዕም ገጽ',
    '☺' => 'ፍሽኽ ዝበለ ገጽ',
    '😚' => 'ፍሽኽ ዝበለ ገጽ ምስ ዝተኸደኑ ኣዒንቲ',
    '😙' => 'ዝስዕም ገጽ ምስ ፍሽኽ ዝበሉ ኣዒንቲ',
    '🥲' => 'ፍሽኽ ዝበለ ገጽ ምስ ንብዓት',
    '😋' => 'መግቢ ዘስተማቕር ገጽ',
    '😛' => 'መልሓስ ዘለዎ ገጽ',
    '😜' => 'ዝጠቅስ ገጽ ምስ መልሓስ',
    '🤪' => 'መስሐቒ ገጽ',
    '😝' => 'ዘጨምጨመ ገጽ ምስ መልሓስ',
    '🤑' => 'ገጽ ናይ ገንዘብ ዘለዎ መልሓስ',
    '🤗' => 'ፍሽኽ ዝበለ ገጽ ምስ ክፉት ኣእዳው',
    '🤭' => 'ኣፉ ዝሓዘ ገጽ',
    '🫢' => 'ክፉት ኣዒንቲን ኣፉ ዝሓዘ ገጽ',
    '🫣' => 'ሰሪቑ ዝርኢ ዓይኒ ዘለዎ ገጽ',
    '🤫' => 'ሹሽ ዝብል ገጽ',
    '🤔' => 'ብሓሳብ ዝተጸመደ ገጽ',
    '🫡' => 'ሰላምታ ዝህብ ገጽ',
    '🤐' => 'ገጽ ምስ ሻርኔራ ዘለዎ ኣፍ',
    '🤨' => 'ሸፋሽፍቱ ናብ ላዕሊ ዝሰቐለ ገጽ',
    '😐' => 'ዘይሻራዊ ገጽ',
    '😑' => 'ስምዒት ዘይብሉ ገጽ',
    '😶' => 'ኣፍ ዘይብሉ ገጽ',
    '🫥' => 'ነጠብጣብ ዘለዎ ገጽ',
    '😏' => 'ግይጽ ዝበለ ገጽ',
    '😒' => 'ታሕጓስ ዘይብሉ ገጽ',
    '🙄' => 'ኣዒንቱ ዘንከብልል ገጽ',
    '😬' => 'ጽዉግ ገጽ',
    '🤥' => 'ዝሕሱ ገጽ',
    '🫨' => 'ዘንቀጥቅጥ ገጽ',
    '😌' => 'እፎይታ ዝተሰመዖ ገጽ',
    '😔' => 'ዝተከዘ ገጽ',
    '😪' => 'ዝታኸስ ገጽ',
    '🤤' => 'ዘለዚ ገጽ',
    '😴' => 'ዝድቅስ ገጽ',
    '🫩' => 'ኣብ ትሕቲ ዓይኒ ቦርሳ ዘለዎ ገጽ',
    '😷' => 'ማስክ ዘለዎ ገጽ',
    '🤒' => 'ቴርሞሜትር ዘለዎ ገጽ',
    '🤕' => 'ፋሻ ዘለዎ ገጽ',
    '🤢' => 'ዕግርግር ዝበሎ ገጽ',
    '🤮' => 'ተምላስ ዘውጽእ ገጽ',
    '🤧' => 'ዝህንጥስ ገጽ',
    '🥵' => 'ረስኒ ዘለዎ ገጽ',
    '🥶' => 'ዝሑል ገጽ',
    '🥴' => 'ጽርውርው ዝበሎ ገጽ',
    '😵' => 'መስቀለኛ ዘለዎም ኣዒንቲ ዘለዉዎ ገጽ',
    '🤯' => 'ዝፍንጀር ርእሲ',
    '🤠' => 'ቆቢዕ ካውቦይ ዘለዎ ገጽ',
    '🥳' => 'ዝጉይል ገጽ',
    '🥸' => 'ዝተሓበአ ገጽ',
    '😎' => 'መነጽር ዝገበረን ፍሽኽ ዝበለን ገጽ',
    '🤓' => 'ዓንጃል ገጽ',
    '🧐' => 'ንጽል መነጽር ዝገበረ ገጽ',
    '😕' => 'ዝተደናገረ ገጽ',
    '🫤' => 'ሰያፍ ኣፍ ዘለዎ ገጽ',
    '😟' => 'ዝተሻቐለ ገጽ',
    '🙁' => 'ቁሩብ ዝተሻቐለ ገጽ',
    '☹' => 'ዝተጨምገገ ገጽ',
    '😮' => 'ኣፉ ዝኸፈተ ገጽ',
    '😯' => 'ዝተገረመ ገጽ',
    '😲' => 'ኣግራሞት ዝመልኦ ገጽ',
    '😳' => 'ብር ዝበለ ገጽ',
    '🫪' => 'ዝተዛብዐ ገጽ',
    '🥺' => 'ዝልምን ገጽ',
    '🥹' => 'ንብዓቱ ዝቆጻጸር ዘሎ ገጽ',
    '😦' => 'ዝተጨምገገ ገጽ ምስ ክፉት ኣፍ',
    '😧' => 'ዝጓሀየ ገጽ',
    '😨' => 'ዝፈርሐ ገጽ',
    '😰' => 'ዝፈርሐ ገጽ ምስ ረሃጽ',
    '😥' => 'ዝሓዘነ ግን ድማ እፎይታ ዝመልኦ ገጽ',
    '😢' => 'ዝነብዕ ገጽ',
    '😭' => 'ዓው ኢሉ ዝበኪ ገጽ',
    '😱' => 'ብፍርሒ ዝጭድር ገጽ',
    '😖' => 'ዝተደንጸወ ገጽ',
    '😣' => 'ዝተጸመመ ገጽ',
    '😞' => 'ዝሓረቐ ገጽ',
    '😓' => 'ዝሓዘነ ገጽ ምስ ረሓጽ',
    '😩' => 'ዝደኸመ ገጽ',
    '😫' => 'ድኹም ገጽ',
    '🥱' => 'ዘምቧህቕ ገጽ',
    '😤' => 'ካብ ኣፍንጭኡ እንፋሎት ዝወጾ ገጽ',
    '😡' => 'ዝተናደደ ገጽ',
    '😠' => 'ዝተበሳጨወ ገጽ',
    '🤬' => 'ኣብ ኣፉ ምልክታት ዘለዉዎ ገጽ',
    '😈' => 'ቀሪኒታት ዘለዎን ፍሽኽ ዝበለን ገጽ',
    '👿' => 'ዝተናደደን ቀርኒታት ዝለዉዎን ገጽ',
    '💀' => 'ሽክና ርእሲ',
    '☠' => 'መመሳቕሎ ኣጽምቲ ዘለዎ ሽክና ርእሲ',
    '💩' => 'ኲምሪ ኲስሒ',
    '🤡' => 'ገጽ ቐላዲ',
    '👹' => 'ጭራቕ',
    '👺' => 'ጎብሊን',
    '👻' => 'መንፈስ',
    '👽' => 'ኤሊየን',
    '👾' => 'ኤሊየን ጨራቕ',
    '🤖' => 'ሮቦት',
    '😺' => 'ፍሽኽ ዝበለ ድሙ',
    '😸' => 'ፍሽኽ ዝብልን ፍሽኽ ዝበሉን ኣዒንቲ ዘለዉዎን ድሙ',
    '😹' => 'ናይ ታሕጓስ ንብዓት ዝመልኦ ድሙ',
    '😻' => 'ፍሽኽታ ዝመልኦ ድሙ ምስ ልባዊ ኣዒንቲ',
    '😼' => 'ፍሽኽታ ዝመልኦ ድሙ',
    '😽' => 'ዝስዕም ድሙ',
    '🙀' => 'ዝደኸሞ ድሙ',
    '😿' => 'ዝበኪ ድሙ',
    '😾' => 'ዝተሸንፈወ ድሙ',
    '🙈' => 'ኩፉእ ኣይተርእየኒ ዝብል ህበይ',
    '🙉' => 'ኩፉእ ኣይተስምዐኒ ዝብል ህበይ',
    '🙊' => 'ኩፉእ ኣይተዛርበኒ ዝብል ህበይ',
    '💌' => 'ናይ ፍቕሪ ደብዳበ',
    '💘' => 'ቀስቲ ዘለዎ ልቢ',
    '💝' => 'ናስትሮ ዘለዎ ልቢ',
    '💖' => 'ዘንጸባርቕ ልቢ',
    '💗' => 'ዝዓቢ ልቢ',
    '💓' => 'ህርመት ልቢ',
    '💞' => 'ዝዘሩ ልቢታት',
    '💕' => 'ክልተ ልብታት',
    '💟' => 'ስልማት ልቢ',
    '❣' => 'ቃለ ኣጋንኖ ልቢ',
    '💔' => 'ዝተሰብረ ልቢ',
    '❤' => 'ቀይሕ ልቢ',
    '🩷' => 'ሮዝ ልቢ',
    '🧡' => 'ቡርትካን ልቢ',
    '💛' => 'ብጫ ልቢ',
    '💚' => 'ቀጠልያ ልቢ',
    '💙' => 'ሰማያዊ ልቢ',
    '🩵' => 'ደብዛዝ ሰማያዊ ልቢ',
    '💜' => 'ወይናይ ልቢ',
    '🤎' => 'ቡናዊ ልቢ',
    '🖤' => 'ጸሊም ልቢ',
    '🩶' => 'ግራጭ ልቢ',
    '🤍' => 'ጻዕዳ ልቢ',
    '💋' => 'ምልክት ምስዓም',
    '💯' => 'ሚእቲ ነጥብታት',
    '💢' => 'ምልክት ሕርቃን',
    '🫯' => 'ቃልሲ ደበና',
    '💥' => 'ምግጫው',
    '💫' => 'ጽርውርው',
    '💦' => 'ነጠብታ ረሃጽ',
    '💨' => 'መጒያይ',
    '🕳' => 'ነዃል',
    '💬' => 'ፍሕኛ ዘረባ',
    '🗨' => 'ዓፍራ ናይ ጸጋም ዝርርብ',
    '🗯' => 'የማናይ ናይ ሕርቃን ዓፍራ',
    '💭' => 'ፍሕኛ ሓሳብ',
    '💤' => 'ድቃስ',
    '👋' => 'ዝወዛወዝ ኢድ',
    '🤚' => 'ኣብ ድሕሪት ናይ ኢድ ዝተልዓለ',
    '🖐' => 'ኢድ ኣጻብዕቲ ተዘርጊሑ',
    '✋' => 'ዝተልዓለ ኢድ',
    '🖖' => 'ቫልካን ሰላምታ',
    '🫱' => 'ንየማ ዘመልክት ኢድ',
    '🫲' => 'ንጸጋ ዘመልክት ኢድ',
    '🫳' => 'ኢድ ንታሕቲ',
    '🫴' => 'ኢድ ናብ ላዕሊ',
    '🫷' => 'ናብ ጸጋም ዝደፍእ ኢድ',
    '🫸' => 'ናብ የማን ዝደፍእ ኢድ',
    '👌' => 'ቅኑዕ ኢድ',
    '🤌' => 'ዝተጨበጠ ኣጻብዕቲ',
    '🤏' => 'መቐንጠጢ ኢድ',
    '✌' => 'ኢድ ዓወት',
    '🤞' => 'ዝተቖላለፉ አጻብዕቲ',
    '🫰' => 'ኢድ ምስ ጠቋሚ ኣጻብዕትን ዓባስ ኣጻብዕትን ዝተቖላለፉ',
    '🤟' => 'ናይ ፍቕሪ ምልክት',
    '🤘' => 'ምልክት ቀርኒ',
    '🤙' => 'ደውሉለይ ኢድ',
    '👈' => 'ናብ ጸጋም ዝሕብር መመልከቲ ናይ ድሕሪት ኢድ',
    '👉' => 'ናብ የማን ዝሕብር መመልከቲ ንድሕሪት',
    '👆' => 'መመልከቲ ንድሕሪት ናብ ላዕሊ',
    '🖕' => 'ማእከላይ ኣጻብዕቲ',
    '👇' => 'ንድሕሪት ዝጥምት ጠቋሚ',
    '☝' => 'ጠቋሚ ናብ ላዕሊ ዝሕብር',
    '🫵' => 'ጠቋሚ ናብ ተዓዛቢ ዝሕብር',
    '👍' => 'ኣጻብዕቲ ናብ ላዕሊ',
    '👎' => 'ኣጻብዕቲ ናብ ታሕቲ',
    '✊' => 'ዝተልዓለ ጭቡጥ ኢድ',
    '👊' => 'ዝመጽእ ምጭብባጥ ምጭብባጥ',
    '🤛' => 'ንጸጋም ገጹ ዝጥምት ምጭብባጥ',
    '🤜' => 'ንየማን ገጹ ዝጥምት ምጭብባጥ',
    '👏' => 'ኢዶም እናጣቕዑ',
    '🙌' => 'ኢድ ምልዓል',
    '🫶' => 'ልቢ ኣእዳው',
    '👐' => 'ክፉት ኢድ',
    '🤲' => 'ኣእዳው ብሓባር',
    '🤝' => 'ምጭብባጥ ኢድ',
    '🙏' => 'ኣእዳው ዓጺፉ',
    '✍' => 'ናይ ጽሕፈት ኢድ',
    '💅' => 'ጽፍሪ ምጽራይ',
    '🤳' => 'ሴልፊ ምውሳድ',
    '💪' => 'ዝተዓጽፈ ጡንች',
    '🦾' => 'መካኒካዊ ቅልጽም',
    '🦿' => 'መካኒካዊ እግሪ',
    '🦵' => 'ሙሉእ እግሪ',
    '🦶' => 'እግሪ',
    '👂' => 'እዝኒ',
    '🦻' => 'እዝኒ ምስ መሳርሒ መስምዒ',
    '👃' => 'ኣፍንጫ',
    '🧠' => 'ሓንጎል',
    '🫀' => 'ኣናቶሚካዊ ልቢ',
    '🫁' => 'ሳናቡእ',
    '🦷' => 'ስኒ',
    '🦴' => 'ዓጽሚ',
    '👀' => 'ኣዒንቲ',
    '👁' => 'ዓይኒ',
    '👅' => 'መልሓስ',
    '👄' => 'ኣፍ',
    '🫦' => 'ከንፈር ዝነክስ',
    '👶' => 'ህጻን',
    '🧒' => 'ቈልዓ',
    '👦' => 'ወዲ',
    '👧' => 'ጓል',
    '🧑' => 'ሰብ',
    '👱' => 'ሰብ: ጸሊም ጸጉሪ',
    '👨' => 'ሰብኣይ',
    '🧔' => 'ሰብ: ጭሕሚ',
    '👩' => 'ሰበይቲ',
    '🧓' => 'ብዕድመ ዝደፍአ ሰብ',
    '👴' => 'ኣረጊት ሰብኣይ',
    '👵' => 'ኣረጊት ሰበይቲ',
    '🙍' => 'ሰብ ቅጭ መጺኡ',
    '🙎' => 'ሰብ ፖውት ምግባር',
    '🙅' => 'ሰብ ኣይፋልን ዝብል ምልክት ዝገብር',
    '🙆' => 'ሰብ ሕራይ ዝብል ምልክት ዝገብር',
    '💁' => 'ሰብ ኢዱ ዝጥምዝዝ',
    '🙋' => 'ኢድ ዘልዕል ሰብ',
    '🧏' => 'ጸማም ሰብ',
    '🙇' => 'ሰብ አጎንቢሱ',
    '🤦' => 'ሰብ ኢዱ አብ ገጹ ምግባር',
    '🤷' => 'ሰብ እናነቕነቐ',
    '👮' => 'ፖሊስ',
    '🕵' => 'መርማሪ',
    '💂' => 'ሓላዊ',
    '🥷' => 'ኒንጃ',
    '👷' => 'ሰራሕተኛ ህንጻ',
    '🫅' => 'ዘውዲ ዘለዎ ሰብ',
    '🤴' => 'ልኡል',
    '👸' => 'ልእልቲ',
    '👳' => 'ቱርባን ዝለበሰ ሰብ',
    '👲' => 'ርእሲ ምትካል ዘለዎ ሰብ',
    '🧕' => 'ጓል ኣንስተይቲ ሽፋን ርእሲ ዘለዋ',
    '🤵' => 'ቱክሲዶ ዝለበሰ ሰብ',
    '👰' => 'መጋረጃ ዘለዎ ሰብ',
    '🤰' => 'ነፍሰጾር ሰበይቲ',
    '🫃' => 'ጥንሲ ዘለዎ ሰብኣይ',
    '🫄' => 'ነፍሰጾር',
    '🤱' => 'ተጥቡ ሓራስ',
    '👼' => 'ህጻን መልኣኽ',
    '🎅' => 'አባባ ገና',
    '🤶' => 'ወይዘሮ ገና',
    '🦸' => 'ልዕለ ጅግና',
    '🦹' => 'ሱፐርቪላን',
    '🧙' => 'አስማተኛ',
    '🧚' => 'ፅውፅዋይ',
    '🧛' => 'ቫምፓየር',
    '🧜' => 'ሰብ ዓሳ',
    '🧝' => 'ኤልፍ',
    '🧞' => 'ጂኒ',
    '🧟' => 'ዞምቢ',
    '🧌' => 'ትሮል',
    '🫈' => 'ጸጉሪ ዘለዎ ፍጡር',
    '💆' => 'ሰብ ማሳጅ ዝገብር',
    '💇' => 'ሰብ ጸጉሪ ርእሲ ምቑራጽ',
    '🚶' => 'ሰብ እናተጓዕዘ',
    '🧍' => 'ጠጠው ዝበለ ሰብ',
    '🧎' => 'ሰብ ተንበርኪኹ',
    '🏃' => 'ሰብ ዝጎዪ',
    '💃' => 'ሰበይቲ ትስዕስዕ',
    '🕺' => 'ሰብኣይ እናሳዕስዐ',
    '🕴' => 'ኮስትሞ ዝለበሰ ሰብ ምልዓል',
    '👯' => 'እዝኒ ባኒ ዘለዎም ሰባት',
    '🧖' => 'ሰብ ኣብ ስቲም ዝመልአ ክፍሊ',
    '🧗' => 'ሰብ እናደየበ',
    '🤺' => 'ሰብ ሓጹር ምግባር',
    '🏇' => 'ውድድር ፈረስ',
    '⛷' => 'ስኪዒ ገባሪ',
    '🏂' => 'ተቐዳዳማይ ስኖቦርደር',
    '🏌' => 'ሰብ ጎልፍ ዝጻወት',
    '🏄' => 'ሰብ ሰርፊንግ ምግባር',
    '🚣' => 'ሰብ ጃልባ ምቕዛፍ',
    '🏊' => 'ሰብ ምሕንባስ',
    '⛹' => 'ሰብ ኩዕሶ ዝብንጭር',
    '🏋' => 'ሰብ ክብደት ምልዓል',
    '🚴' => 'ሰብ ብሽክለታ ምዝዋር',
    '🚵' => 'ሰብ ናይ ተራራ ብሽክለታ ምዝዋር',
    '🤸' => 'ሰብ ዓረብያ ምዝዋር',
    '🤼' => 'ሰባት እናተቓለሱ',
    '🤽' => 'ዋተር ፖሎ ዝጻወት ሰብ',
    '🤾' => 'ኩዕሶ ኢድ ዝጻወት ሰብ',
    '🤹' => 'ሰብ ጃግሊንግ ምግባር',
    '🧘' => 'ሰብ ኣብ ሎተስ መርገጺ',
    '🛀' => 'ሰብ ክሕጸብ ከሎ',
    '🛌' => 'ሰብ ኣብ ዓራት',
    '👭' => 'ደቂ ኣንስትዮ ኢድ ንኢድ ተተሓሒዘን',
    '👫' => 'ሰበይትን ሰብኣይን ኢድ ንኢድ ተተሓሒዞም',
    '👬' => 'ደቂ ተባዕትዮ ኢድ ንኢድ ተተሓሒዞም',
    '💏' => 'ምስዓም',
    '💑' => 'መጻምድቲ ምስ ልቢ',
    '🗣' => 'ዝዛረብ ርእሲ',
    '👤' => 'ቡስት ኣብ ሲልሆውት',
    '👥' => 'ቡስትስ ኣብ ሲልሆውት',
    '🫂' => 'ሰባት እናተሓቛቖፉ',
    '👪' => 'ስድራ',
    '👣' => 'ኣሰር እግሪ',
    '🫆' => 'ኣሰር ኣጻብዕቲ',
    '🦰' => 'ቀይሕ ጸጉሪ',
    '🦱' => 'ቁርጽራጽ ጸጉሪ',
    '🦳' => 'ጻዕዳ ጸጉሪ',
    '🦲' => 'በራሕ',
    '🐵' => 'ገጽ ህበይ',
    '🐒' => 'ህበይ',
    '🦍' => 'ጎሪላ',
    '🦧' => 'ኦራንጉታን',
    '🐶' => 'ገጽ ከልቢ',
    '🐕' => 'ከልቢ',
    '🦮' => 'መምርሒ ከልቢ',
    '🐩' => 'ፑድል',
    '🐺' => 'ተኹላ',
    '🦊' => 'ወኻርያ',
    '🦝' => 'ራኩን',
    '🐱' => 'ገጽ ድሙ',
    '🐈' => 'ድሙ',
    '🦁' => 'ኣንበሳ',
    '🐯' => 'ገጽ ነብሪ',
    '🐅' => 'ነብሪ',
    '🐆' => 'ልዮፓርድ',
    '🐴' => 'ገጽ ፈረስ',
    '🫎' => 'ሙስ',
    '🫏' => 'አድጊ',
    '🐎' => 'ፈረስ',
    '🦄' => 'ዩኒኮርን',
    '🦓' => 'ኣድጊ በረኻ',
    '🦌' => 'ዓጋዘን',
    '🦬' => 'ብዕራይ በረኻ',
    '🐮' => 'ገጽ ላም',
    '🐂' => 'ብዕራይ',
    '🐃' => 'ጎባይ ማይ',
    '🐄' => 'ላም',
    '🐷' => 'ገጽ ሓሰማ',
    '🐖' => 'ሓሰማ',
    '🐗' => 'መፍለስ',
    '🐽' => 'ኣፍንጫ ሓሰማ',
    '🐏' => 'ዓብዪ በጊዕ',
    '🐑' => 'ሽበን',
    '🐐' => 'ጤል',
    '🐪' => 'ገመል',
    '🐫' => 'ክልተ ሑቆ ዘለዎ ገመልክልተ ሑምባሻ ዘለዎ ገመል',
    '🦙' => 'ላማ',
    '🦒' => 'ዘራፍ',
    '🐘' => 'ሓርማዝ',
    '🦣' => 'ማሞዝ',
    '🦏' => 'ሓርሽ',
    '🦛' => 'ጉማረ',
    '🐭' => 'ገጽ ኣንጭዋ',
    '🐁' => 'ንእሽቶ ኣንጭዋ',
    '🐀' => 'ራት',
    '🐹' => 'ክሪቸቶ',
    '🐰' => 'ገጽ ማንቲለ',
    '🐇' => 'ማንቲለ',
    '🐿' => 'ምጹጽላይ',
    '🦫' => 'ቢቨር',
    '🦔' => 'ቅንፍዝ',
    '🦇' => 'መንካዕ',
    '🐻' => 'ድቢ',
    '🐨' => 'ኮዋላ',
    '🐼' => 'ፓንዳ',
    '🦥' => 'ስሎዝ',
    '🦦' => 'ጣቑስታ',
    '🦨' => 'ቱሕቱሓ',
    '🦘' => 'ካንጋሩ',
    '🦡' => 'ባድጀር',
    '🐾' => 'ሕትመት መንኮርኮር',
    '🦃' => 'ታኪን',
    '🐔' => 'ደርሆ',
    '🐓' => 'ኣርሓ ደርሆ',
    '🐣' => 'ዝፍልፈል ጩጩት',
    '🐤' => 'ህጻን ጩጩት',
    '🐥' => 'ንቕድሚት ዝጥምት ህጻን ጫጩት',
    '🐦' => 'ዑፍ',
    '🐧' => 'ፐንጒን',
    '🕊' => 'ርግቢት',
    '🦅' => 'ንስሪ',
    '🦆' => 'ደርሆ ማይ',
    '🦢' => 'ስዋን',
    '🦉' => 'ጉንጓ',
    '🦤' => 'ዶዶ',
    '🪶' => 'ላሒም',
    '🦩' => 'ፍላሚንጎ',
    '🦚' => 'ፒኮክ',
    '🦜' => 'ፓፓጋሎ',
    '🪽' => 'ክንፊ',
    '🪿' => 'ይብራ',
    '🐸' => 'እንቁርዖብ',
    '🐊' => 'ሓርገጽ',
    '🐢' => 'ጎብየ',
    '🦎' => 'ጠበቕ',
    '🐍' => 'ተመን',
    '🐲' => 'ገጽ ድራጎን',
    '🐉' => 'ድራጎን',
    '🦕' => 'ሳውሮፖድ',
    '🦖' => 'ቲ-ሬክስ',
    '🐳' => 'ስፍሕ ዝበለ ዓሳ ነባሪ',
    '🐋' => 'ዓሳ ነባሪ',
    '🐬' => 'ኣቡ ሰላማ',
    '🫍' => 'ኦርካ',
    '🦭' => 'ፎካ',
    '🐟' => 'ዓሳ',
    '🐠' => 'ትሮፒካዊ ዓሳ',
    '🐡' => 'ብሎፊሽ',
    '🦈' => 'ከልቢ ዓሳ',
    '🐙' => 'ኦክቶፑስ',
    '🐚' => 'ዛዕጎል ባሕሪ',
    '🪸' => 'መርጀን',
    '🪼' => 'ጀሊፊሽ',
    '🦀' => 'ሻርጣን',
    '🦞' => 'ሎብስተር',
    '🦐' => 'ጋምበሪ',
    '🦑' => 'ኣቡ ቐለም',
    '🦪' => 'ኦይስተር',
    '🐌' => 'ኣረነ',
    '🦋' => 'ጽምብላሊዕ',
    '🐛' => 'ትዃን',
    '🐜' => 'ጻጸ',
    '🐝' => 'ንህቢ',
    '🪲' => 'ሕንዚዝ',
    '🐞' => 'እመቤት ዕንቅርቢት',
    '🦗' => 'ዕንጭራር',
    '🪳' => 'ድዱዕ',
    '🕷' => 'ሳሬት',
    '🕸' => 'ዓለባ ሳሬት',
    '🦂' => 'ዕንቅርቢት',
    '🦟' => 'ጣንጡ',
    '🪰' => 'ሃመማ',
    '🪱' => 'ሓሰኻ',
    '🦠' => 'ማይክሮብ',
    '💐' => 'ሕቋፍ ዕምባባ',
    '🌸' => 'ዕምባባ ቸሪ',
    '💮' => 'ጻዕዳ ዕምባባ',
    '🪷' => 'ሹሻን',
    '🏵' => 'ሮዘት',
    '🌹' => 'ጽገሬዳ',
    '🥀' => 'ዝነቐጸ ዕምባባ',
    '🌺' => 'ሂቢስኩስ',
    '🌻' => 'ሱፍ',
    '🌼' => 'ዕምባባ',
    '🌷' => 'ቱሊፕ',
    '🪻' => 'ሃያሲንት',
    '🌱' => 'ፈልሲ',
    '🪴' => 'ኣብ ድስቲ ዝተቐመጠ ተኽሊ',
    '🌲' => 'ወትሩ ሓምላይ ዝኾነ ገረብ',
    '🌳' => 'ቆጽሊ ዝወድቕ ገረብ',
    '🌴' => 'ስየ',
    '🌵' => 'ቁልቋል',
    '🌾' => 'ዕስለ ሩዝ',
    '🌿' => 'ሓጸብቲ ዕጸዋት',
    '☘' => 'ሻምሮክ',
    '🍀' => 'ኣርባዕተ ቆጽሊ ዘለዎ ጽሕዲ',
    '🍁' => 'ቆጽሊ ሜፕል',
    '🍂' => 'ዝወደቐ ቆጽሊ',
    '🍃' => 'ቆጽሊ ኣብ ንፋስ ዝነፍሕ',
    '🪹' => 'ባዶ ሰፈር',
    '🪺' => 'ምስ እንቋቑሖ ሰፈር ምግባር',
    '🍄' => 'ቃንጥሻ',
    '🪾' => 'ቆጽሊ ዘይብሉ ገረብ',
    '🍇' => 'ወይኒ',
    '🍈' => 'melon',
    '🍉' => 'ብርጭቕ',
    '🍊' => 'ታንጀሪን',
    '🍋' => 'ለሚን',
    '🍌' => 'ባናና',
    '🍍' => 'ኣናናስ',
    '🥭' => 'ማንጉስ',
    '🍎' => 'ቀይሕ ኣፕል',
    '🍏' => 'ቀጠልያ ኣፕል',
    '🍐' => 'ፒር',
    '🍑' => 'ኩኽ',
    '🍒' => 'ቼሪ',
    '🍓' => 'ፍራውለ',
    '🫐' => 'ብሉቤሪ',
    '🥝' => 'ኪዊ',
    '🍅' => 'ኮሚደረ',
    '🫒' => 'ኣውሊዕ',
    '🥥' => 'ኮኮናት',
    '🥑' => 'ኣቮካዶ',
    '🍆' => 'መለንዛና',
    '🥔' => 'ድንሽ',
    '🥕' => 'ካሮቲ',
    '🌽' => 'ጉንቦ ዕፉን',
    '🌶' => 'ውዑይ በርበረ',
    '🫑' => 'ጉዕ በርበረ',
    '🥒' => 'ኩኩምበር',
    '🥬' => 'ቆጽሊ ዘለዎ ቀጠልያ',
    '🥦' => 'ብሮኮሊ',
    '🧄' => 'ጻዕዳ ሽጉርቲ',
    '🧅' => 'ሽጉርቲ',
    '🥜' => 'ፉል',
    '🫘' => 'ዓልቋይ',
    '🌰' => 'ቸስትነት',
    '🫚' => 'ሱር ጅንጅብል',
    '🫛' => 'ቆጽሊ ኣተር',
    '🫜' => 'ሱር ኣሕምልቲ',
    '🍞' => 'ባኒ',
    '🥐' => 'ክሮሳንት',
    '🥖' => 'ባጌት ባኒ',
    '🫓' => 'ጸፍሒ ባኒ',
    '🥨' => 'ፕሬትዘል',
    '🥯' => 'ባጌል',
    '🥞' => 'ፓንኬክ',
    '🧇' => 'ዋፍል',
    '🧀' => 'በርበረ ዌጅ',
    '🍖' => 'ስጋ ኣብ ልዕሊ ዓጽሚ',
    '🍗' => 'እግሪ ደርሆ',
    '🥩' => 'ዝተቖርጸ ስጋ',
    '🥓' => 'ቤኮን',
    '🍔' => 'ሃምበርገር',
    '🍟' => 'ቅልዋ ድንሽ',
    '🍕' => 'ፒሳ',
    '🌭' => 'ሆት ዶግ',
    '🥪' => 'እምቦቲቶ',
    '🌮' => 'ታኮ',
    '🌯' => 'ቡሪቶ',
    '🫔' => 'ታማል',
    '🥙' => 'ዝተመልአ ሰፋሕ ባኒ',
    '🧆' => 'ፋላፈል',
    '🥚' => 'እንቋቑሖ',
    '🍳' => 'ምብሳል ምግቢ',
    '🥘' => 'ዓሚቝ ዘይኮነ ጣውላ መግቢ',
    '🍲' => 'ካሴሮል',
    '🫕' => 'ፎንዱ',
    '🥣' => 'ሳእኒ ምስ ማንካ',
    '🥗' => 'ሰላጣ',
    '🍿' => 'እንበባ',
    '🧈' => 'ጠስሚ',
    '🧂' => 'ጨው',
    '🥫' => 'ቆርቆሮ መግቢ',
    '🍱' => 'ቤንቶ ሳንዱቕ',
    '🍘' => 'ሩዝ ቅራፍ',
    '🍙' => 'ኩዕሶ ሩዝ',
    '🍚' => 'ዝበሰለ ሩዝ',
    '🍛' => 'ሩዝ ካሪ',
    '🍜' => 'ብሓዊ ዝሕንበብ ሳእኒ',
    '🍝' => 'ስፓጌቲ',
    '🍠' => 'ዝተጠበሰ ሽኮር ድንሽ',
    '🍢' => 'ኦደን',
    '🍣' => 'ሱሺ',
    '🍤' => 'ዝተጠብሰ ጋምበሪ',
    '🍥' => 'ዓሳ ኬክ ምስ ስዊርል',
    '🥮' => 'ወርሒ ኬክ',
    '🍡' => 'ዳንጎ',
    '🥟' => 'ዱምፕሊንግ ምግባር',
    '🥠' => 'ብሽኮቲ ዕድል',
    '🥡' => 'ቴክኣውት መውሰዲ',
    '🍦' => 'ልስሉስ ኣይስክሪም',
    '🍧' => 'ዝተላጽየ በረድ',
    '🍨' => 'ጀላቶ',
    '🍩' => 'ዶናት',
    '🍪' => 'ብሽኮቲ',
    '🎂' => 'ናይ ልደት ኬክ',
    '🍰' => 'ንእሽተይ ኬክ',
    '🧁' => 'ካፕኬክ',
    '🥧' => 'ፓይ',
    '🍫' => 'ቸኮሌት ባር',
    '🍬' => 'ካራሜላ',
    '🍭' => 'ሌካሌካ',
    '🍮' => 'ካስታርድ',
    '🍯' => 'ድስቲ መዓር',
    '🍼' => 'ናይ ህጻን ጥርሙዝ',
    '🥛' => 'ብርጭቆ ጸባ ምውሳድ',
    '☕' => 'ውዑይ መስተ',
    '🫖' => 'በራድ ሻሂ',
    '🍵' => 'ሻሂ ብዘይ መትሓዚ',
    '🍶' => 'ሳኬ',
    '🍾' => 'ጥርሙዝ ምስ ፖፒንግ ኮርክ',
    '🍷' => 'ብርጭቆ ወይኒ',
    '🍸' => 'ኮክቴል ብርጭቆ',
    '🍹' => 'ትሮፒካዊ መስተ',
    '🍺' => 'ናይ ቢራ ብርጭቆ',
    '🍻' => 'ጭርጭር ዝብሉ ናይ ቢራ ማንካታት',
    '🥂' => 'ብርጭቆ ጭርጭር ምባል',
    '🥃' => 'ቱምብለር ብርጭቆ',
    '🫗' => 'ፈሳሲ ምፍሳስ',
    '🥤' => 'ጽዋእ ምስ ሓሰር',
    '🧋' => 'ሻሂ ቡምባ',
    '🧃' => 'ሳንዱቕ መስተ',
    '🧉' => 'መሓዛ',
    '🧊' => 'በረድ',
    '🥢' => 'በትሪ ምግቢ ምብላዕ',
    '🍽' => 'ፋርኬታን ካራን ምስ ጻሕሊ',
    '🍴' => 'ፋርኬታን ካራን',
    '🥄' => 'ማንካ',
    '🔪' => 'ናይ ክሽነ ካራ',
    '🫙' => 'ኩባያ',
    '🏺' => 'ኣምፎራ',
    '🌍' => 'ኤውሮጳ-ኣፍሪቃ ዘርኢ ሉል',
    '🌎' => 'ንኣሜሪካታት ዘርኢ ግሎብ',
    '🌏' => 'ኤስያ-ኣውስትራልያ ዘርኢ ግሎብ',
    '🌐' => 'ግሎብ ምስ ሜሪድያን',
    '🗺' => 'ካርታ ዓለም',
    '🗾' => 'ካርታ ጃፓን',
    '🧭' => 'ኮምፓስ',
    '🏔' => 'ብበረድ ዝተሸፈነ እምባ',
    '⛰' => 'እምባ',
    '🛘' => 'ምሽርታት መሬት',
    '🌋' => 'እሳተ ጎመራ',
    '🗻' => 'እምባ ፉጂ',
    '🏕' => 'ካምፒንግ ምግባር',
    '🏖' => 'ገማግም ባሕሪ ምስ ጽላል',
    '🏜' => 'ምድረ በዳ',
    '🏝' => 'ምድረ በዳዊ ደሴት',
    '🏞' => 'ሃገራዊ መናፈሻ',
    '🏟' => 'ስታድዩም',
    '🏛' => 'ክላሲካል ህንጻ',
    '🏗' => 'ህንጸት ህንጻ',
    '🧱' => 'ሕጡብ',
    '🪨' => 'ከውሒ',
    '🪵' => 'ዕንጨይቲ',
    '🛖' => 'ኣጉዶ',
    '🏘' => 'ገዛውቲ',
    '🏚' => 'ዝተደርበየ ገዛ',
    '🏠' => 'ገዛ',
    '🏡' => 'ገዛ ምስ ጀርዲን',
    '🏢' => 'ህንጻ ቤት ጽሕፈት',
    '🏣' => 'ጃፓናዊ ፖስታ ቤት',
    '🏤' => 'ፖስታ ቤት',
    '🏥' => 'ሆስፒታል',
    '🏦' => 'ባንክ',
    '🏨' => 'ሆቴል',
    '🏩' => 'ሆቴል ፍቕሪ',
    '🏪' => 'ዓቢ ድኳን',
    '🏫' => 'ቤት ትምህርቲ',
    '🏬' => 'ዓቢ መኽዘን',
    '🏭' => 'ፋብሪካ',
    '🏯' => 'ጃፓናዊ ካስትል',
    '🏰' => 'ግምቢ',
    '💒' => 'መርዓ',
    '🗼' => 'ግምቢ ቶክዮ',
    '🗽' => 'ሓወልቲ ሓርነት',
    '⛪' => 'ቤተ ክርስትያን',
    '🕌' => 'መስጊድ',
    '🛕' => 'ቤተ መቕደስ ሂንዱ',
    '🕍' => 'ምኩራብ',
    '⛩' => 'ሺንቶ ዝበሃል መቕደስ',
    '🕋' => 'ካባ',
    '⛲' => 'ፈልፋሊ ማይ',
    '⛺' => 'ድኳን',
    '🌁' => 'ጉም ዝመልኦ',
    '🌃' => 'ለይቲ ምስ ከዋኽብቲ',
    '🏙' => 'መልክዕ ከተማ',
    '🌄' => 'ጸሓይ ኣብ ልዕሊ ኣኽራን ምብራቓ',
    '🌅' => 'ምብራቕ ጸሓይ',
    '🌆' => 'መልክዕ ከተማ ኣብ እዋን ምድረበዳ',
    '🌇' => 'ጸሓይ ዕራርቦ',
    '🌉' => 'ድልድል ብለይቲ',
    '♨' => 'ውዑይ ምንጪ ማይ',
    '🎠' => 'ካሮሰል ፈረስ',
    '🛝' => 'ናይ መጻወቲ ቦታ ስላይድ',
    '🎡' => 'ፈሪስ መንኰርኰር',
    '🎢' => 'ሮለር ኮስተር',
    '💈' => 'ዓንዲ ጸጉሪ ርእሲ',
    '🎪' => 'ዳስ ሰርከስ',
    '🚂' => 'ሎኮሞቲቭ',
    '🚃' => 'ናይ ባቡር መኪና',
    '🚄' => 'ፍጥነት ዘለዋ ባቡር',
    '🚅' => 'ፈጣን ባቡር',
    '🚆' => 'ባቡር',
    '🚇' => 'ሜትሮ',
    '🚈' => 'ዜጋ',
    '🚉' => 'ጣብያ',
    '🚊' => 'ትራም',
    '🚝' => 'ሞኖረይል',
    '🚞' => 'ናይ ከረን ባቡር',
    '🚋' => 'ናይ ትራም መኪና',
    '🚌' => 'ኣውቶቡስ',
    '🚍' => 'ኣብ ቅድሚት እትመጽእ ኣውቶቡስ',
    '🚎' => 'ትሮሊባስ',
    '🚐' => 'ሚኒባስ ዝበሃል ትካል',
    '🚑' => 'ኣምቡላንስ',
    '🚒' => 'ሞተር መጥፋእቲ ሓዊ',
    '🚓' => 'ናይ ፖሊስ ማኪና',
    '🚔' => 'ኣብ ቅድሚኡ ዝነበረት ናይ ፖሊስ መኪና',
    '🚕' => 'ታክሲ',
    '🚖' => 'ዝመጽእ ዘሎ ታክሲ',
    '🚗' => 'መኪና',
    '🚘' => 'ኣብ ቅድሚት እትመጽእ መኪና',
    '🚙' => 'ስፖርት ዩቲሊቲ ተሽከርካሪት',
    '🛻' => 'ናይ ፒክኣፕ መኪና',
    '🚚' => 'ናይ መብጽሒ መኪና',
    '🚛' => 'ኣርቲኩለድ ሎጋሪ',
    '🚜' => 'ትራክተር',
    '🏎' => 'ናይ ውድድር መኪና',
    '🏍' => 'ሞተር ሳይክል',
    '🛵' => 'ሞተር ስኩተር',
    '🦽' => 'ማንዋል ዓረብያ ስንኩላን እዩ',
    '🦼' => 'ብሞተር ዝሰርሕ ዓረብያ ስንኩላን እዩ',
    '🛺' => 'ኣውቶ ሪክሻ',
    '🚲' => 'ብሽክለታ',
    '🛴' => 'ርግጽ ስኩተር',
    '🛹' => 'መንሻተቲ ጣውላ',
    '🛼' => 'ሮለር ስኬት',
    '🚏' => 'መዕረፊ ኣውቶቡስ',
    '🛣' => 'ጽርግያ',
    '🛤' => 'መስመር ባቡር',
    '🛢' => 'ዘይቲ ከበሮ',
    '⛽' => 'ነዳዲ ፓምፕ',
    '🛞' => 'መንኮርኮር',
    '🚨' => 'ናይ ፖሊስ መኪና መብራህቲ',
    '🚥' => 'ልኡል መብራህቲ ትራፊክ',
    '🚦' => 'አግድም መብራህቲ ትራፊክ',
    '🛑' => 'ደው ምባል ዝብል ምልክት',
    '🚧' => 'ናይ ህንፃ ስራሕ',
    '⚓' => 'መልሕቕ',
    '🛟' => 'ቀለቤት ቦይ',
    '⛵' => 'ጃልባ ምዝዋር',
    '🛶' => 'ታንኳ',
    '🚤' => 'ፍጥነት ዘለዋ ጃልባ',
    '🛳' => 'ናይ ተሳፈርቲ መርከብ',
    '⛴' => 'ጃልባ',
    '🛥' => 'ሞተር ጃልባ',
    '🚢' => 'መርከብ',
    '✈' => 'ነፋሪት',
    '🛩' => 'ንእሽቶ ነፋሪት',
    '🛫' => 'ነፋሪት ምብጋስ',
    '🛬' => 'ነፋሪት ምምጻእ',
    '🪂' => 'ጋንጽላ',
    '💺' => 'መንበር',
    '🚁' => 'ሄሊኮፕተር',
    '🚟' => 'ተንጠልጣሊ ባቡር',
    '🚠' => 'ናይ ከረን ገመድ መንገዲ',
    '🚡' => 'ካብ ኣየር ዝኸይድ መንገዲ ትራም',
    '🛰' => 'ሳተላይት',
    '🚀' => 'ሮኬት',
    '🛸' => 'ዝነፍር ሳእኒ',
    '🛎' => 'ቤልሆፕ ደወል',
    '🧳' => 'ባልጃ',
    '⌛' => 'ሰዓት ሰዓት ተገይሩ',
    '⏳' => 'ሰዓት ሰዓት ዘይተገብረ',
    '⌚' => 'ሰዓት',
    '⏰' => 'ሰዓት ደወል',
    '⏱' => 'ሰዓት መትሓዚ',
    '⏲' => 'ታይመር ሰዓት',
    '🕰' => 'ማንቴልፒስ ሰዓት',
    '🕛' => 'ሰዓት ዓሰርተ ክልተ',
    '🕧' => 'ዓሰርተ ክልተን ፈረቓን',
    '🕐' => 'ሰዓት ሓደ',
    '🕜' => 'ሕደን ፈረቓን',
    '🕑' => 'ሰዓት ክልተ',
    '🕝' => 'ክልተን ፈረቓን',
    '🕒' => 'ሰዓት ሰለስተ',
    '🕞' => 'ሰለስተን ፈረቓን',
    '🕓' => 'ሰዓት ኣርባዕተ',
    '🕟' => 'ኣርባዕተን ፈረቓን',
    '🕔' => 'ሰዓት ሓሙሽተ',
    '🕠' => 'ሓሙሽተን ፈረቓን',
    '🕕' => 'ሰዓት ሽዱሽተ',
    '🕡' => 'ሽዱሽተን ፈረቓን',
    '🕖' => 'ሰዓት ሸውዓተ',
    '🕢' => 'ሸውዓተን ፈረቓን',
    '🕗' => 'ሰዓት ሸሞንተ',
    '🕣' => 'ሸሞንተን ፈረቓን',
    '🕘' => 'ሰዓት ትሽዓተ',
    '🕤' => 'ትሸዓተን ፈረቓን',
    '🕙' => 'ሰዓት ዓሰርተ',
    '🕥' => 'ዓሰርተን ፈረቓን',
    '🕚' => 'ሰዓት ዓሰርተ ሓደ',
    '🕦' => 'ዓሰርተ ሓደን ፈረቓን',
    '🌑' => 'ሓዳስ ወርሒ',
    '🌒' => 'ዋክሲንግ ወርሓዊ ወርሒ',
    '🌓' => 'ቀዳማይ ርብዒ ወርሒ',
    '🌔' => 'ዋክሲንግ ጊቦስ ወርሒ',
    '🌕' => 'ምልእቲ ወርሒ',
    '🌖' => 'እናነከየት ትኸይድ ዘላ ጊቦስ ወርሒ',
    '🌗' => 'ናይ መወዳእታ ርብዒ ወርሒ',
    '🌘' => 'እናነከየት ትኸይድ ዘላ ወርሒ ወርሒ',
    '🌙' => 'ወርሒ ፍርቂ ወርሒ',
    '🌚' => 'ገጽ ሓዳስ ወርሒ',
    '🌛' => 'ቀዳማይ ርብዒ ወርሒ ገጽ',
    '🌜' => 'ናይ መወዳእታ ርብዒ ወርሒ ገጽ',
    '🌡' => 'ተርሞሜተር',
    '☀' => 'ጸሓይ',
    '🌝' => 'ምሉእ ወርሒ ገጽ',
    '🌞' => 'ጸሓይ ምስ ገጽ',
    '🪐' => 'ቀለበት ዘለዎ ፕላኔት',
    '⭐' => 'ኮኾብ',
    '🌟' => 'ዝበርህ ኮኾብ',
    '🌠' => 'ተወንጫፊ ኮኾብ',
    '🌌' => 'ሚልኪዌይ',
    '☁' => 'ደበና',
    '⛅' => 'ጸሓይ ብድሕሪ ደበና',
    '⛈' => 'ደበና ምስ በርቅን ዝናብን',
    '🌤' => 'ጸሓይ ብድሕሪ ንእሽቶ ደበና',
    '🌥' => 'ጸሓይ ብድሕሪ ዓቢ ደበና',
    '🌦' => 'ጸሓይ ብድሕሪ ዝናብ ደበና',
    '🌧' => 'ደበና ምስ ዝናብ',
    '🌨' => 'ደበና ምስ በረድ',
    '🌩' => 'ደበና ምስ በርቂ',
    '🌪' => 'ህቦብላ ንፋስ',
    '🌫' => 'ግመ',
    '🌬' => 'ንፋስ ገጽ',
    '🌀' => 'ሳይክሎን',
    '🌈' => 'ቀስተ ደበና',
    '🌂' => 'ዕጹው ጽላል',
    '☂' => 'ጽላል',
    '☔' => 'ጽላል ምስ ነጠብጣብ ዝናብ',
    '⛱' => 'ጽላል ኣብ መሬት',
    '⚡' => 'ልዑል ቮልቴጅ',
    '❄' => 'ንጣብ በረድ',
    '☃' => 'ሰብ በረድ',
    '⛄' => 'በረድ ዘይብሉ ሰብ በረድ',
    '☄' => 'ኮሜት',
    '🔥' => 'ሓዊ',
    '💧' => 'ነጠብጣብ',
    '🌊' => 'ማዕበል ማይ',
    '🎃' => 'ጃክ-ኦ-ላንተርን',
    '🎄' => 'ገረብ ልደት',
    '🎆' => 'ርችታት',
    '🎇' => 'ስፓርለር',
    '🧨' => 'ርችት',
    '✨' => 'ስፓርክ',
    '🎈' => 'ባላንቺና',
    '🎉' => 'ፓርቲ ፖፐር',
    '🎊' => 'ኮንፈቲ ኩዕሶ',
    '🎋' => 'ታናባታ ዝበሃል ገረብ',
    '🎍' => 'ጽሕዲ ስልማት',
    '🎎' => 'ጃፓናዊ ባምቡላ',
    '🎏' => 'ካርፕ ስትሪመር',
    '🎐' => 'ንፋስ ምውቃዕ',
    '🎑' => 'ስነ-ስርዓት ምርኣይ ወርሒ',
    '🧧' => 'ቀይሕ ፖስታ',
    '🎀' => 'ሪባን',
    '🎁' => 'ህያብ',
    '🎗' => 'መዘኻኸሪ ሪባን',
    '🎟' => 'ናይ መእተዊ ትኬት',
    '🎫' => 'ቲከት',
    '🎖' => 'ወተሃደራዊ መዳልያ',
    '🏆' => 'ዋንጫ',
    '🏅' => 'ስፖርታዊ መዳልያ',
    '🥇' => '1ይ ደረጃ መዳልያ',
    '🥈' => '2ይ ደረጃ መዳልያ2ይ ደረጃ መዳልያ',
    '🥉' => '3ይ ደረጃ መዳልያ',
    '⚽' => 'ኩዕሶ እግሪ ኩዕሶ',
    '⚾' => 'ቤዝቦል',
    '🥎' => 'softball',
    '🏀' => 'ኩዕሶ ሰኪዔት',
    '🏐' => 'ቮሊቦል ዝበሃል ጸወታ',
    '🏈' => 'ኣሜሪካዊ ኩዕሶ እግሪ',
    '🏉' => 'ራግቢ ኩዕሶ እግሪ',
    '🎾' => 'ቴኒስ',
    '🥏' => 'ዝነፍር ዲስክ',
    '🎳' => 'ቦውሊንግ',
    '🏏' => 'ጸወታ ክሪኬት',
    '🏑' => 'ናይ ሜዳ ሆኪ',
    '🏒' => 'ናይ በረድ ሆኪ',
    '🥍' => 'ላክሮስ ዝበሃል ውድድር',
    '🏓' => 'ፒንግ ፖንግ',
    '🏸' => 'ባድሚንተን',
    '🥊' => 'ናይ ቦክሲንግ ጓንቲ',
    '🥋' => 'ናይ ማርሻል ኣርት ዩኒፎርም',
    '🥅' => 'ሸቶ መርበብ',
    '⛳' => 'ባንዴራ ኣብ ጉድጓድ',
    '⛸' => 'በረድ ስኬት',
    '🎣' => 'ዓንዲ ምግፋፍ ዓሳ',
    '🤿' => 'ናይ ምጥላቕ ማስክ',
    '🎽' => 'ናይ ጉያ ማልያ',
    '🎿' => 'ስኪስ',
    '🛷' => 'ስልዝ',
    '🥌' => 'ቁርጽራጽ እምኒ',
    '🎯' => 'ዓይኒ ብዕራይ',
    '🪀' => 'ዮ-ዮ',
    '🪁' => 'ካይት',
    '🔫' => 'ናይ ማይ ሽጉጥ',
    '🎱' => 'ፑል 8 ኩዕሶ',
    '🔮' => 'ክሪስታል ኩዕሶ',
    '🪄' => 'ናይ ስሕበት በትሪ',
    '🎮' => 'ቪድዮ ጸወታ',
    '🕹' => 'ጆይስቲክ',
    '🎰' => 'ስሎት ማሽን',
    '🎲' => 'ናይ ጌም መጻወቲ',
    '🧩' => 'ቁራጽ ሕንቅልሕንቅሊተይ',
    '🧸' => 'ቴዲ ድቢ',
    '🪅' => 'ፒኛታ',
    '🪩' => 'መስትያት ኩዕሶ',
    '🪆' => 'ሰፈር ዝገብሩ ኣሻንጉሊት',
    '♠' => 'ስፓድ ኮስትሞ',
    '♥' => 'ናይ ልቢ ኮስትሞ',
    '♦' => 'ናይ ኣልማዝ ኮስትሞ',
    '♣' => 'ክለብ ኮስትሞ',
    '♟' => 'ቸስ ወታደር',
    '🃏' => 'ጆኬር',
    '🀄' => 'ማህጆንግ ቀይሕ ገበል',
    '🎴' => 'ዕምባባ መጻወቲ ካርድታት',
    '🎭' => 'ስነ-ጥበብ ምርኢት',
    '🖼' => 'ኣብ ፍሬም ዝተቐመጠ ስእሊ',
    '🎨' => 'ስነጥበባዊ ፓለቲካ',
    '🧵' => 'ፈትሊ',
    '🪡' => 'መርፍእ ስፌት',
    '🧶' => 'ፈትሊታት',
    '🪢' => 'ዝተአሰረ',
    '👓' => 'መስታወታት',
    '🕶' => 'መነጽር ጸሓይ',
    '🥽' => 'መነጽር መነጽር',
    '🥼' => 'ናይ ላብራቶሪ ካቦት',
    '🦺' => 'ናይ ድሕነት ቬስት',
    '👔' => 'ክራቫታ',
    '👕' => 'ቲሸርት',
    '👖' => 'ጂንስ',
    '🧣' => 'መሃረብ',
    '🧤' => 'ጓንትታት',
    '🧥' => 'ኮት',
    '🧦' => 'ካልስታት',
    '👗' => 'ቀምሽ',
    '👘' => 'ኪሚኖ',
    '🥻' => 'ሳሪ',
    '🩱' => 'ሓደ ቁራጽ ናይ መሐንበሲ ክዳን',
    '🩲' => 'ፕታንቲ',
    '🩳' => 'ሓጺር ስረ',
    '👙' => 'ቢኪኒ',
    '👚' => 'ክዳውንቲ ጓል ኣንስተይቲ',
    '🪭' => 'ዝዕጸፍ ናይ ኢድ ፋን',
    '👛' => 'ቦርሳ',
    '👜' => 'ቦርሳ ኢድ',
    '👝' => 'ክላች ቦርሳ',
    '🛍' => 'ናይ ዕዳጋ ቦርሳታት',
    '🎒' => 'ቦርሳ ድሕሪት ምውሳድ',
    '🩴' => 'ቶንግ ሳንዱቕ',
    '👞' => 'ናይ ሰብኣይ ጫማ',
    '👟' => 'ናይ ጉያ ጫማ',
    '🥾' => 'ናይ እግሪ ጉዕዞ',
    '🥿' => 'ጸፍሒ ጫማ',
    '👠' => 'ልዑል ሸኾና ዘለዎ ጫማ',
    '👡' => 'ናይ ሰበይቲ ሳንዱቕ',
    '🩰' => 'ጫማ ባሌ',
    '👢' => 'ናይ ጓል ኣንስተይቲ ቦቲ',
    '🪮' => 'ጸጉሪ መሰንተር',
    '👑' => 'ዘውዲ',
    '👒' => 'ቆቢዕ ጓል ኣንስተይቲ',
    '🎩' => 'ላዕለዋይ ቆቢዕ',
    '🎓' => 'ናይ ምረቓ ቆቢዕ',
    '🧢' => 'ሕሳብ ዘለዎ ካፕ',
    '🪖' => 'ወተሃደራዊ መክላኸሊ ርእሲ',
    '⛑' => 'ቁራዕ ርእሲ ሰራሕተኛ ህይወት ኣድሕን',
    '📿' => 'ናይ ጸሎት ምልክት',
    '💄' => 'ልፕስቲክ',
    '💍' => 'ቀለቤት',
    '💎' => 'ዕንቊ እምኒ',
    '🔇' => 'ድምጺ ኣልቦ ዝኾነ ስፒከር',
    '🔈' => 'ስፒከር ትሑት ድምጺ',
    '🔉' => 'ስፒከር ማእከላይ ድምጺ',
    '🔊' => 'ስፒከር ልዑል ድምጺ',
    '📢' => 'መጉልሒ ድምጺ',
    '📣' => 'ሜጋፎን',
    '📯' => 'ቀርኒ ፖስታ',
    '🔔' => 'ደወል',
    '🔕' => 'ደወል ምስ ስላሽ',
    '🎼' => 'ሙዚቃዊ ስኮር',
    '🎵' => 'ሙዚቃዊ ኖታ',
    '🎶' => 'ሙዚቃዊ ኖታታት',
    '🎙' => 'ናይ ስቱድዮ ማይክሮፎን',
    '🎚' => 'ደረጃ ስላይደር',
    '🎛' => 'ናይ ምቁጽጻር መቆጻጸሪታት',
    '🎤' => 'ማይክሮፎን',
    '🎧' => 'ናይ ርእሲ ስልኪ',
    '📻' => 'ራድዮ',
    '🎷' => 'ሳክስፎን',
    '🎺' => 'መለኸት',
    '🪊' => 'ትሮምቦን',
    '🪗' => 'ኣኮርድዮን',
    '🎸' => 'ጊታር',
    '🎹' => 'ሙዚቃዊ ቁልፊ ሰሌዳ',
    '🎻' => 'ክራር',
    '🪕' => 'ባንጆ',
    '🥁' => 'ከበሮ',
    '🪘' => 'ነዊሕ ከበሮ',
    '🪇' => 'ማራካስ',
    '🪈' => 'ዋጣ',
    '🪉' => 'በገና',
    '📱' => 'ሞባይል ቴሌፎን',
    '📲' => 'ሞባይል ምስ ፍላጻ',
    '☎' => 'ተለፎን',
    '📞' => 'ተቐባሊ ቴሌፎን',
    '📟' => 'ፔጀር',
    '📠' => 'ፋክስ ማሽን',
    '🔋' => 'ባትሪ',
    '🪫' => 'ትሑት ባትሪ ዘለዎ',
    '🔌' => 'ናይ ኤሌክትሪክ ፕላግ',
    '💻' => 'ላፕቶፕ',
    '🖥' => 'ናይ ዴስክቶፕ ኮምፒተር',
    '🖨' => 'ሓታሚት',
    '⌨' => 'ቁልፊ ሰሌዳ',
    '🖱' => 'ናይ ኮምፒተር ማውስ',
    '🖲' => 'ትራክቦል ዝበሃል ጸወታ',
    '💽' => 'ናይ ኮምፒተር ዲስክ',
    '💾' => 'ፍሎፒ ዲስክ',
    '💿' => 'ኦፕቲካል ዲስክ',
    '📀' => 'ዲቪዲ',
    '🧮' => 'አባከስ',
    '🎥' => 'ፊልም ካሜራ',
    '🎞' => 'ፊልም ፍሬማት',
    '📽' => 'ፊልም ፕሮጀክተር',
    '🎬' => 'ክላፐር ቦርድ',
    '📺' => 'ተለቪዥን',
    '📷' => 'ካሜራ',
    '📸' => 'ካሜራ ምስ ፍላሽ',
    '📹' => 'ቪድዮ ካሜራ',
    '📼' => 'ቪድዮ ካሴት',
    '🔍' => 'መጉልሒ ብርጭቆ ንጸጋም ተገልቢጡ',
    '🔎' => 'መጉልሒ ብርጭቆ ንየማን ተገልቢጡ',
    '🕯' => 'ሽምዓ',
    '💡' => 'ኣምፑል መብራህቲ',
    '🔦' => 'ፍላሽ ላምባ',
    '🏮' => 'ቀይሕ ወረቐት ፋኑስ',
    '🪔' => 'ዲያ ላምባ',
    '📔' => 'ደፍተር ምስ ስልማት ሽፋን',
    '📕' => 'ዕጹው መጽሓፍ',
    '📖' => 'ክፉት መጽሓፍ',
    '📗' => 'ቀጠልያ መጽሓፍ',
    '📘' => 'ሰማያዊ መጽሓፍ',
    '📙' => 'ኣራንሺ መጽሓፍ',
    '📚' => 'መጻሕፍቲ',
    '📓' => 'ደፍተር',
    '📒' => 'መዝገብ',
    '📃' => 'ገጽ ምስ ቁርጽራጽ',
    '📜' => 'ስክሮል ምግባር',
    '📄' => 'ገጽ ንላዕሊ ገጹ ዝጥምት',
    '📰' => 'ጋዜጣ',
    '🗞' => 'ዝተጠቕለለ ጋዜጣ',
    '📑' => 'ዕልባት ትቦታት',
    '🔖' => 'ዕልባት ምልክት ምግባር',
    '🏷' => 'መፍለዪ',
    '🪙' => 'ሰልዲ',
    '💰' => 'ናይ ገንዘብ ቦርሳ',
    '🪎' => 'ሳንዱቕ ሐብቲ',
    '💴' => 'የን ኖት ባንክ',
    '💵' => 'ናይ ዶላር ኖት',
    '💶' => 'ናይ ዩሮ ኖት',
    '💷' => 'ፓውንድ ኖት',
    '💸' => 'ገንዘብ ምስ ክንፊ',
    '💳' => 'ናይ ልቓሕ ካርድ',
    '🧾' => 'ቅብሊት',
    '💹' => 'ቻርት ምስ የን እናወሰኸ ይኸይድ',
    '✉' => 'መዐሸጊ',
    '📧' => 'ኢመይል',
    '📨' => 'ዝኣቱ ፖስታ',
    '📩' => 'ፖስታ ምስ ፍላጻ',
    '📤' => 'ኣውትቦክስ ትሬይ',
    '📥' => 'ናይ ኢንቦክስ ትሬይ',
    '📦' => 'ጥቕላል',
    '📫' => 'ዕጹው ሳጹን ፖስታ ምስ ልዕል ዝበለ ባንዴራ',
    '📪' => 'ዕጹው ሳጹን ፖስታ ምስ ዝወረደ ባንዴራ',
    '📬' => 'ልዕል ዝበለ ባንዴራ ዘለዎ ሳጹን ፖስታ ክፈት',
    '📭' => 'ሳጹን ፖስታ ምስ ዝወረደ ባንዴራ ክፈት',
    '📮' => 'ሳጹን ፖስታ',
    '🗳' => 'ሳንዱቕ ድምጺ ምስ ድምጺ ምሃብ',
    '✏' => 'ርሳስ',
    '✒' => 'ጸሊም ኒብ',
    '🖋' => 'ፈልፋሊ ብርዒ',
    '🖊' => 'ቢሮ',
    '🖌' => 'ብራሽ ቀለም',
    '🖍' => 'ክራዮን',
    '📝' => 'መዘክር',
    '💼' => 'መትሓዚ ቦርሳ',
    '📁' => 'ፋይል ማህደር',
    '📂' => 'ፋይል ፎልደር ክፈት',
    '🗂' => 'ካርድ ኢንዴክስ መከፋፈልቲ',
    '📅' => 'ዓውደ ኣዋርሕ',
    '📆' => 'ምቕዳድ ካላንደር',
    '🗒' => 'ስፓይራል ኖትፓድ',
    '🗓' => 'ስፓይራል ካላንደር',
    '📇' => 'ካርድ ኢንዴክስ',
    '📈' => 'ቻርት እናወሰኸ ይኸይድ',
    '📉' => 'ሰንጠረዥ እናነከየ ይኸይድ',
    '📊' => 'ባር ቻርት',
    '📋' => 'ሰሌዳ ቅንጣብ',
    '📌' => 'ፑሽፒን',
    '📍' => 'ክቢ ፑሽፒን',
    '📎' => 'መቐመጢ ወረቐት',
    '🖇' => 'ዝተኣሳሰሩ ናይ ወረቐት መቐመጢታት',
    '📏' => 'ትኽ ዝበለ ገዛኢ',
    '📐' => 'ስሉስ ኩርናዕ ዘለዎ ገዛኢ',
    '✂' => 'መቐሳት',
    '🗃' => 'ናይ ካርድ ፋይል ሳጹን',
    '🗄' => 'ፋይል ካቢነ',
    '🗑' => 'መሶብ ጎሓፍ',
    '🔒' => 'ተዓጽዩ',
    '🔓' => 'ተኸፊቱ',
    '🔏' => 'ብብርዒ ዝተዓጽወ',
    '🔐' => 'ብመፍትሕ ዝተዓጽወ',
    '🔑' => 'መፍትሕ',
    '🗝' => 'ናይ ቀደም መፍትሕ',
    '🔨' => 'መርቴሎ',
    '🪓' => 'መፍለጽ',
    '⛏' => 'ምልዓል',
    '⚒' => 'መዶሻን ምልቃምን ምግባር',
    '🛠' => 'መዶሻን መፍትሕን',
    '🗡' => 'ዳጋር',
    '⚔' => 'ኣስያፍ ዝሰገሩ',
    '💣' => 'ቦምብ',
    '🪃' => 'ቡመራንግ',
    '🏹' => 'ቀስቲን ፍላጻን',
    '🛡' => 'ዋልታ',
    '🪚' => 'ጸራቢ ስርናይ',
    '🔧' => 'መላሕልሒ',
    '🪛' => 'ስክሩድራይቨር',
    '🔩' => 'ናትን ቦልትን',
    '⚙' => 'ማርሺ',
    '🗜' => 'ምጭባጥ',
    '⚖' => 'ሚዛን ስኬል',
    '🦯' => 'ጻዕዳ በትሪ',
    '🔗' => 'ሊንክ',
    '⛓' => 'ሰንሰለታት',
    '🪝' => 'መፈንጠሪ',
    '🧰' => 'ሳንዱቕ መሳርሒታት',
    '🧲' => 'ማግኔት',
    '🪜' => 'መሳልል',
    '🪏' => 'አካፋ',
    '⚗' => 'ኣለምቢክ',
    '🧪' => 'ናይ መርመራ ሻምብቆ',
    '🧫' => 'ፔትሪ ዲሽ',
    '🧬' => 'dna',
    '🔬' => 'ማይክሮስኮፕ',
    '🔭' => 'ቴለስኮፕ',
    '📡' => 'ሳተላይት ኣንቴና',
    '💉' => 'መርፍእ ምውሳድ',
    '🩸' => 'ንጣብ ደም',
    '💊' => 'ከኒና',
    '🩹' => 'ተጣባቒ ፋስ ምግባር',
    '🩼' => 'በትሪ',
    '🩺' => 'ስቴቶስኮፕ',
    '🩻' => 'ራጂ',
    '🚪' => 'ማዕጾ',
    '🛗' => 'ሊፍት',
    '🪞' => 'መስተዋት',
    '🪟' => 'መስኮት',
    '🛏' => 'ዓራት',
    '🛋' => 'ሶፋን ላምባን',
    '🪑' => 'ወንበር',
    '🚽' => 'ሽቓቕ',
    '🪠' => 'ፕላንጀር',
    '🚿' => 'መሕጸቢ',
    '🛁' => 'ባኞ',
    '🪤' => 'መጻወድያ ኣንጭዋ',
    '🪒' => 'መላጸ',
    '🧴' => 'ጥርሙዝ ሎሽን',
    '🧷' => 'ናይ ድሕነት ፒን',
    '🧹' => 'መኾስተር',
    '🧺' => 'መሶብ',
    '🧻' => 'ጥቕላል ወረቐት',
    '🪣' => 'ሸንኬሎ',
    '🧼' => 'ሳሙና',
    '🫧' => 'ፍንጣጣታት',
    '🪥' => 'ብራሽ ስኒ',
    '🧽' => 'ሰፍነግ',
    '🧯' => 'መጥፋኢ ሓዊ',
    '🛒' => 'ናይ ዕዳጋ ዓረብያ',
    '🚬' => 'ሽጋራ',
    '⚰' => 'ሳንዱቕ ሬሳ',
    '🪦' => 'እምኒ ርእሲ',
    '⚱' => 'ናይ ቀብሪ ሳንዱቕ',
    '🧿' => 'ናዛር ኣምልኾ',
    '🪬' => 'ሓዝምዛ',
    '🗿' => 'ሞዋ',
    '🪧' => 'ፕላካርድ',
    '🪪' => 'መለለዪ ወረቐት',
    '🏧' => 'ምልክት ATM',
    '🚮' => 'ጎሓፍ ኣብ ምልክት ናይ መጉሓፊ',
    '🚰' => 'ጽሩይ ዝስተ ማይ',
    '♿' => 'ምልክት ናይ መበጻጽሒ ሰድያ',
    '🚹' => 'ክፍሊ ሰብኡት',
    '🚺' => 'ክፍሊ ናይ ኣንስቲ',
    '🚻' => 'ሽቃቅ',
    '🚼' => 'ምልክት ናይ ቆልዓ',
    '🚾' => 'መዕቆሪ ማይ',
    '🛂' => 'ናይ ፓስስፖርት ቁጽጽር',
    '🛃' => 'ጉምሩክ',
    '🛄' => 'መበጻጽሒ ሳንጣ',
    '🛅' => 'ጸጋማይ ሳንጣ',
    '⚠' => 'መጠንቀቕታ',
    '🚸' => 'መሕለፊ ቆልዑ',
    '⛔' => 'ምእታው ክልኩል',
    '🚫' => 'ዝተኣገደ',
    '🚳' => 'ብሽክለታ ኣይፍቀድን',
    '🚭' => 'ሽጋራ ኣይፍቀድን',
    '🚯' => 'ምጉሓፍ ኣይፍቀድን',
    '🚱' => 'ዘይጽሩይ ማይ',
    '🚷' => 'ኣጋር የለዉን',
    '📵' => 'ተንቀሳቃሲ ተለፎን ኣይፍቀድን',
    '🔞' => 'ትሕቲ 18 ዝዕድሚኦም ኣይኮኑን',
    '☢' => 'ጸርገ-ንጥፈት',
    '☣' => 'ናይ ሓደጋ',
    '⬆' => 'ምልክት ናብ ላዕሊ',
    '↗' => 'ምልክት ናብ-የማናይ ላዕሊ',
    '➡' => 'የማናይ ምልክት',
    '↘' => 'ምልክት ናብ-የማናይ ታሕቲ',
    '⬇' => 'ምልክት ናብ ታሕቲ',
    '↙' => 'ምልክት ናብ-ጸጋማይ ታሕቲ',
    '⬅' => 'ምልክት ናብ-ጸጋም',
    '↖' => 'ምልክት ናብ-ጸጋማይ ላዕሊ',
    '↕' => 'ምልክት ናብ-ላዕሊ ታሕቲ',
    '↔' => 'ምልክት ናብ-የማን ጸጋም',
    '↩' => 'የማናይ ምልክት ናብ ጸጋም ዝተጠውየ',
    '↪' => 'ጸጋማይ ምልክት ናብ የማን ዝተጠውየ',
    '⤴' => 'የማናይ ምልክት ናብ ላዕሊ ዝተጠውየ',
    '⤵' => 'የማናይ ምልክት ናብ ታሕቲ ዝተጠውየ',
    '🔃' => 'ከመ ሰዓት ዝዘውር ትኹል ምልክት',
    '🔄' => 'ኣንጻር ሰዓት ዝዘውር ትኹል ምልክት መልጎም',
    '🔙' => 'ዳሕረዋይ ምልክት',
    '🔚' => 'መወዳእታ ናይ ምልክት',
    '🔛' => 'ኣብ ልዕሊ! ምልክት',
    '🔜' => 'ቕልጡፍ ምልክት',
    '🔝' => 'ላዕለዋይ ምልክት',
    '🛐' => 'ናይ ኣምልኾ ቦታ',
    '⚛' => 'ናይ ኣቶም ኣርማ',
    '🕉' => 'om',
    '✡' => 'ኮኾብ ናይ ዳዊት',
    '☸' => 'መንኮርኮር ናይ ዳርማ',
    '☯' => 'ዪን ያንግ',
    '✝' => 'ናይ ላቲን መስቀል',
    '☦' => 'ናይ ኦርቶዶክስ መስቀል',
    '☪' => 'ኮኾብ ከምኡ`ውን ቅርጺ ማዕጺድ',
    '☮' => 'ናይ ሰላም ኣርማ',
    '🕎' => '7 ቀንዴል',
    '🔯' => 'ነጥብጣብ 6-ጫፍ ኮኾብ',
    '🪯' => 'ካንዳ',
    '♈' => 'ኣሬስ',
    '♉' => 'ታውሩስ',
    '♊' => 'ጀሚኒ',
    '♋' => 'መንሽሮ',
    '♌' => 'ሌዮ',
    '♍' => 'ቪርጎ',
    '♎' => 'ሊብራ',
    '♏' => 'ስኮርፕዮ',
    '♐' => 'ሲጊታሩስ',
    '♑' => 'ወጠጦ',
    '♒' => 'ኣክዋርዩስ',
    '♓' => 'ፒስከስ',
    '⛎' => 'ኦፊኩስ',
    '🔀' => 'ዝተሓላለፈ ምልክታትመልጎም',
    '🔁' => 'መድገሚ መልጎም',
    '🔂' => 'መድገሚ ንጽል መልጎም',
    '▶' => 'መጻወቲ መልጎም',
    '⏩' => 'መቀላጥፊ መልጎም',
    '⏭' => 'መሰጋገሪ መልጎም',
    '⏯' => 'መጻወቲ ወይ መዕጸዊ መልጎም',
    '◀' => 'መምለሲ መልጎም',
    '⏪' => 'ቅልጡፍ መምለሲ መልጎም',
    '⏮' => 'ናይ መወዳእታ መልጎም',
    '🔼' => 'ኣንቃዕራሪ መልጎም',
    '⏫' => 'መቀላጠፊ መልጎም',
    '🔽' => 'ኣንቈልቋሊ መልጎም',
    '⏬' => 'ቅልጡፍ ኣንቈልቋሊ መልጎም',
    '⏸' => 'መዕጸዊ መልጎም',
    '⏹' => 'መጥፍኢ መልጎም',
    '⏺' => 'መዐቀቢ መልጎም',
    '⏏' => 'መትፍኢ መልጎም',
    '🎦' => 'ሲነማ',
    '🔅' => 'መደበኒ መልጎም',
    '🔆' => 'ብሩህ መልጎም',
    '📶' => 'ናይ ኣንተና ሽራጣት',
    '🛜' => 'ገመድ ኣልቦ',
    '📳' => 'ነዝነዝታዊ ሃለዋት',
    '📴' => 'ተንቀሳቃሲት ተለፎን ምዕጽው',
    '♀' => 'ናይ ጋል-ኣንስተይቲ ምልክት',
    '♂' => 'ናይ ወዲ-ተባዕታይ ምልክት',
    '⚧' => 'ጸታ ዝቀየሩ ምልክት',
    '✖' => 'ሕሳብ',
    '➕' => 'ምድማር',
    '➖' => 'ምጉዳል',
    '➗' => 'ምምቃል',
    '🟰' => 'ከቢድ ማዕረ ምልክት',
    '♾' => 'ደረት ኣልቦነት',
    '‼' => 'ድርብ ምልክት ስምዒት',
    '⁉' => '!',
    '❓' => 'ቀይሕ ምልክት ሕቶ',
    '❔' => 'ጻዕዳ ምልክት ሕቶ',
    '❕' => 'ጻዕዳ ምልክት ስምዒት',
    '❗' => 'ቀይሕ ምልክት ስምዒት',
    '〰' => 'ሞገዳዊ ዳሽ',
    '💱' => 'ለውጢ ገንዘብ',
    '💲' => 'ከቢድ ምልክት ናይ ዶላር',
    '⚕' => 'ኣርማ ሕክምና',
    '♻' => 'ኣርማ ረሳይክል',
    '⚜' => 'ፍሉር-ደ-ሊስ',
    '🔱' => 'ኣርማ ትሪደንት',
    '📛' => 'ሽም ባድጀ',
    '🔰' => 'ጃፓናዊ ምልክት ን ጀማሪ',
    '⭕' => 'ክፉት ቀይሕ ዓንኬል',
    '✅' => 'ምልክት መልጎም ኣረጋግጽ',
    '☑' => 'ነቲ ሳንዱቕ ኣረጋግጾ',
    '✔' => 'ምልክት ኣረጋግጽ',
    '❌' => 'ተማሓላላፊ ምልክት',
    '❎' => 'ተማሓላላፊ ምልክት መልጎም',
    '➰' => 'ዕኽሉል ጥውይዋይ',
    '➿' => 'ድርብ ዕኽሉል ጥውይዋይ',
    '〽' => 'ኣማራጺ ምልክት ክፋል',
    '✳' => 'ሻሙናይ-መሳልል ኣስተሪስክ',
    '✴' => 'ሻሙናይ-ነጥቢ ኮኾብ',
    '❇' => 'ኣብለጭላጪ',
    '™' => 'ምልክት ንግዲ',
    '🫟' => 'ረሳሕ ፈሳሲ',
    '🔠' => 'ናይ ላቲን ዓበይቲ-ቃላት ኣእቱ',
    '🔡' => 'ናይ ላቲን ነኣሽቱ-ቃላት ኣእቱ',
    '🔢' => 'ቁጽርታት ኣእቱ',
    '🔣' => 'ኣርማታት ኣእቱ',
    '🔤' => 'ላቲን ቃላት ኣእቱ',
    '🅰' => 'A መልጎም (ዓይነት ደም)',
    '🆎' => 'AB መልጎም (ዓይነት ደም)',
    '🅱' => 'B መልጎም (ዓይነት ደም)',
    '🆑' => 'CL መልጎም',
    '🆒' => 'COOL መልጎም',
    '🆓' => 'ክፉት መልጎም',
    'ℹ' => 'ሓበሬታ',
    '🆔' => 'ID መልጎም',
    'Ⓜ' => 'ዓንኬላዊ M',
    '🆕' => 'ሓዲሽ መልጎም',
    '🆖' => 'NG መልጎም',
    '🅾' => 'O መልጎም (ዓይነት ደም)',
    '🆗' => 'OK መልጎም',
    '🅿' => 'P መልጎም',
    '🆘' => 'SOS መልጎም',
    '🆙' => 'ንላዕሊ! መልጎም',
    '🆚' => 'VS መልጎም',
    '🈁' => 'ናይ ጃፓን “ኣብዚ” መልጎም',
    '🈂' => 'ናይ ጃፓን “ክፍሊት ኣገልግሎት” መልጎም',
    '🈷' => 'ናይ ጃፓን “ወርሓዊ ድምር” መልጎም',
    '🈶' => 'ናይ ጃፓን “ነጻ ዘይኮነ ክፍሊት” መልጎም',
    '🈯' => 'ናይ ጃፓን “ዝተዓቀበ” መልጎም',
    '🉐' => 'ናይ ጃፓን “ምውጋይ” መልጎም',
    '🈹' => 'ናይ ጃፓን “ምጉዳል ዋጋ” መልጎም',
    '🈚' => 'ናይ ጃፓን “ካብ ክፍሊት ነጻ” መልጎም',
    '🈲' => 'ናይ ጃፓን “ዝተኣገደ” መልጎም',
    '🉑' => 'ናይ ጃፓን “ቅቡል” መልጎም',
    '🈸' => 'ናይ ጃፓን “ምልክታ” መልጎም',
    '🈴' => 'ናይ ጃፓን “መሕለፊ ነጥቢ” መልጎም',
    '🈳' => 'ናይ ጃፓን “ክፉት ቦታ ስራሕ” መልጎም',
    '㊗' => 'ናይ ጃፓን “እንቃዕ ሓጎሰኩም” መልጎም',
    '㊙' => 'ናይ ጃፓን “ምስጢር” መልጎም',
    '🈺' => 'ናይ ጃፓን “ን ቢዝነስ ክፉት” መልጎም',
    '🈵' => 'ናይ ጃፓን “ክፉት ቦታ ስራሕ የለን” መልጎም',
    '🔴' => 'ቀይሕ ዓንኬል',
    '🟠' => 'ኣራንሾኒ ዓንኬል',
    '🟡' => 'ቢጫ ዓንኬል',
    '🟢' => 'ቀጠልያ ዓንኬል',
    '🔵' => 'ሰማያዊ ዓንኬል',
    '🟣' => 'ሊላ ዓንኬል',
    '🟤' => 'ቡናዊ ዓንኬል',
    '⚫' => 'ጸሊም ዓንኬል',
    '⚪' => 'ጻዕዳ ዓንኬል',
    '🟥' => 'ቀይሕ ትርብዒት',
    '🟧' => 'ኣራንሾኒ ትርብዒት',
    '🟨' => 'ቢጫ ትርብዒት',
    '🟩' => 'ቀጠልያ ትርብዒት',
    '🟦' => 'ሰማያዊ ትርብዒት',
    '🟪' => 'ሊላ ትርብዒት',
    '🟫' => 'ቡናዊ ትርብዒት',
    '⬛' => 'ጸሊም ዓቢ ትርብዒት',
    '⬜' => 'ጻዕዳ ዓቢ ትርብዒት',
    '◼' => 'ጸሊም ማእከላይ ትርብዒት',
    '◻' => 'ጻዕዳ ማእከላይ ትርብዒት',
    '◾' => 'ጸሊም ማእከላይ-ንኢሽተይ ትርብዒት',
    '◽' => 'ጻዕዳ ማእከላይ-ንኢሽተይ ትርብዒት',
    '▪' => 'ጸሊም ንኢሽተይ ትርብዒት',
    '▫' => 'ጻዕዳ ንኢሽተይ ትርብዒት',
    '🔶' => 'ዓቢ ኣራንሾኒ ኣልማዝ',
    '🔷' => 'ዓቢ ሰማያዊ ኣልማዝ',
    '🔸' => 'ንኢሽተይ ሰማያዊ ኣልማዝ',
    '🔹' => 'ንኢሽተይ ሰማያዊት ኣልማዝ',
    '🔺' => 'ቀያሕ ስሉስ-ኩርናዕ ኣርኣየ',
    '🔻' => 'ቀያሕ ስሉስ-ኩርናዕ ንታሕቲ ኣርኣየ',
    '💠' => 'ኣልማዝ ምስ ዶት',
    '🔘' => 'መልጎም ናይ ራድዮ',
    '🔳' => 'ጻዕዳ ትርብዒት መልጎም',
    '🔲' => 'ጸሊም ትርብዒት መልጎም',
    '🏁' => 'ሸርጣን ባንዴራ',
    '🚩' => 'ስሉስ ኩርናዕ ባንዴራ',
    '🎌' => 'ዝሰገሩ ባንዴራታት',
    '🏴' => 'ጸሊም ባንዴራ',
    '🏳' => 'ጻዕዳ ባንዴራ',
];
