<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'بوسه: شخص،‏ شخص،‏ پوست سفید، و پوست روشن',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'بوسه: شخص،‏ شخص،‏ پوست سفید، و پوست طلایی',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'بوسه: شخص،‏ شخص،‏ پوست سفید، و پوست گندمی',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'بوسه: شخص،‏ شخص،‏ پوست سفید، و پوست آبنوسی',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'بوسه: شخص،‏ شخص،‏ پوست روشن، و پوست سفید',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'بوسه: شخص،‏ شخص،‏ پوست روشن، و پوست طلایی',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'بوسه: شخص،‏ شخص،‏ پوست روشن، و پوست گندمی',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'بوسه: شخص،‏ شخص،‏ پوست روشن، و پوست آبنوسی',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'بوسه: شخص،‏ شخص،‏ پوست طلایی، و پوست سفید',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'بوسه: شخص،‏ شخص،‏ پوست طلایی، و پوست روشن',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'بوسه: شخص،‏ شخص،‏ پوست طلایی، و پوست گندمی',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'بوسه: شخص،‏ شخص،‏ پوست طلایی، و پوست آبنوسی',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'بوسه: شخص،‏ شخص،‏ پوست گندمی، و پوست سفید',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'بوسه: شخص،‏ شخص،‏ پوست گندمی، و پوست روشن',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'بوسه: شخص،‏ شخص،‏ پوست گندمی، و پوست طلایی',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'بوسه: شخص،‏ شخص،‏ پوست گندمی، و پوست آبنوسی',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'بوسه: شخص،‏ شخص،‏ پوست آبنوسی، و پوست سفید',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'بوسه: شخص،‏ شخص،‏ پوست آبنوسی، و پوست روشن',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'بوسه: شخص،‏ شخص،‏ پوست آبنوسی، و پوست طلایی',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'بوسه: شخص،‏ شخص،‏ پوست آبنوسی، و پوست گندمی',
    '👨🏻‍❤‍💋‍👨🏻' => 'بوسه: مرد،‏ مرد، و پوست سفید',
    '👨🏻‍❤‍💋‍👨🏼' => 'بوسه: مرد،‏ مرد،‏ پوست سفید، و پوست روشن',
    '👨🏻‍❤‍💋‍👨🏽' => 'بوسه: مرد،‏ مرد،‏ پوست سفید، و پوست طلایی',
    '👨🏻‍❤‍💋‍👨🏾' => 'بوسه: مرد،‏ مرد،‏ پوست سفید، و پوست گندمی',
    '👨🏻‍❤‍💋‍👨🏿' => 'بوسه: مرد،‏ مرد،‏ پوست سفید، و پوست آبنوسی',
    '👨🏼‍❤‍💋‍👨🏻' => 'بوسه: مرد،‏ مرد،‏ پوست روشن، و پوست سفید',
    '👨🏼‍❤‍💋‍👨🏼' => 'بوسه: مرد،‏ مرد، و پوست روشن',
    '👨🏼‍❤‍💋‍👨🏽' => 'بوسه: مرد،‏ مرد،‏ پوست روشن، و پوست طلایی',
    '👨🏼‍❤‍💋‍👨🏾' => 'بوسه: مرد،‏ مرد،‏ پوست روشن، و پوست گندمی',
    '👨🏼‍❤‍💋‍👨🏿' => 'بوسه: مرد،‏ مرد،‏ پوست روشن، و پوست آبنوسی',
    '👨🏽‍❤‍💋‍👨🏻' => 'بوسه: مرد،‏ مرد،‏ پوست طلایی، و پوست سفید',
    '👨🏽‍❤‍💋‍👨🏼' => 'بوسه: مرد،‏ مرد،‏ پوست طلایی، و پوست روشن',
    '👨🏽‍❤‍💋‍👨🏽' => 'بوسه: مرد،‏ مرد، و پوست طلایی',
    '👨🏽‍❤‍💋‍👨🏾' => 'بوسه: مرد،‏ مرد،‏ پوست طلایی، و پوست گندمی',
    '👨🏽‍❤‍💋‍👨🏿' => 'بوسه: مرد،‏ مرد،‏ پوست طلایی، و پوست آبنوسی',
    '👨🏾‍❤‍💋‍👨🏻' => 'بوسه: مرد،‏ مرد،‏ پوست گندمی، و پوست سفید',
    '👨🏾‍❤‍💋‍👨🏼' => 'بوسه: مرد،‏ مرد،‏ پوست گندمی، و پوست روشن',
    '👨🏾‍❤‍💋‍👨🏽' => 'بوسه: مرد،‏ مرد،‏ پوست گندمی، و پوست طلایی',
    '👨🏾‍❤‍💋‍👨🏾' => 'بوسه: مرد،‏ مرد، و پوست گندمی',
    '👨🏾‍❤‍💋‍👨🏿' => 'بوسه: مرد،‏ مرد،‏ پوست گندمی، و پوست آبنوسی',
    '👨🏿‍❤‍💋‍👨🏻' => 'بوسه: مرد،‏ مرد،‏ پوست آبنوسی، و پوست سفید',
    '👨🏿‍❤‍💋‍👨🏼' => 'بوسه: مرد،‏ مرد،‏ پوست آبنوسی، و پوست روشن',
    '👨🏿‍❤‍💋‍👨🏽' => 'بوسه: مرد،‏ مرد،‏ پوست آبنوسی، و پوست طلایی',
    '👨🏿‍❤‍💋‍👨🏾' => 'بوسه: مرد،‏ مرد،‏ پوست آبنوسی، و پوست گندمی',
    '👨🏿‍❤‍💋‍👨🏿' => 'بوسه: مرد،‏ مرد، و پوست آبنوسی',
    '👩🏻‍❤‍💋‍👨🏻' => 'بوسه: زن،‏ مرد، و پوست سفید',
    '👩🏻‍❤‍💋‍👨🏼' => 'بوسه: زن،‏ مرد،‏ پوست سفید، و پوست روشن',
    '👩🏻‍❤‍💋‍👨🏽' => 'بوسه: زن،‏ مرد،‏ پوست سفید، و پوست طلایی',
    '👩🏻‍❤‍💋‍👨🏾' => 'بوسه: زن،‏ مرد،‏ پوست سفید، و پوست گندمی',
    '👩🏻‍❤‍💋‍👨🏿' => 'بوسه: زن،‏ مرد،‏ پوست سفید، و پوست آبنوسی',
    '👩🏼‍❤‍💋‍👨🏻' => 'بوسه: زن،‏ مرد،‏ پوست روشن، و پوست سفید',
    '👩🏼‍❤‍💋‍👨🏼' => 'بوسه: زن،‏ مرد، و پوست روشن',
    '👩🏼‍❤‍💋‍👨🏽' => 'بوسه: زن،‏ مرد،‏ پوست روشن، و پوست طلایی',
    '👩🏼‍❤‍💋‍👨🏾' => 'بوسه: زن،‏ مرد،‏ پوست روشن، و پوست گندمی',
    '👩🏼‍❤‍💋‍👨🏿' => 'بوسه: زن،‏ مرد،‏ پوست روشن، و پوست آبنوسی',
    '👩🏽‍❤‍💋‍👨🏻' => 'بوسه: زن،‏ مرد،‏ پوست طلایی، و پوست سفید',
    '👩🏽‍❤‍💋‍👨🏼' => 'بوسه: زن،‏ مرد،‏ پوست طلایی، و پوست روشن',
    '👩🏽‍❤‍💋‍👨🏽' => 'بوسه: زن،‏ مرد، و پوست طلایی',
    '👩🏽‍❤‍💋‍👨🏾' => 'بوسه: زن،‏ مرد،‏ پوست طلایی، و پوست گندمی',
    '👩🏽‍❤‍💋‍👨🏿' => 'بوسه: زن،‏ مرد،‏ پوست طلایی، و پوست آبنوسی',
    '👩🏾‍❤‍💋‍👨🏻' => 'بوسه: زن،‏ مرد،‏ پوست گندمی، و پوست سفید',
    '👩🏾‍❤‍💋‍👨🏼' => 'بوسه: زن،‏ مرد،‏ پوست گندمی، و پوست روشن',
    '👩🏾‍❤‍💋‍👨🏽' => 'بوسه: زن،‏ مرد،‏ پوست گندمی، و پوست طلایی',
    '👩🏾‍❤‍💋‍👨🏾' => 'بوسه: زن،‏ مرد، و پوست گندمی',
    '👩🏾‍❤‍💋‍👨🏿' => 'بوسه: زن،‏ مرد،‏ پوست گندمی، و پوست آبنوسی',
    '👩🏿‍❤‍💋‍👨🏻' => 'بوسه: زن،‏ مرد،‏ پوست آبنوسی، و پوست سفید',
    '👩🏿‍❤‍💋‍👨🏼' => 'بوسه: زن،‏ مرد،‏ پوست آبنوسی، و پوست روشن',
    '👩🏿‍❤‍💋‍👨🏽' => 'بوسه: زن،‏ مرد،‏ پوست آبنوسی، و پوست طلایی',
    '👩🏿‍❤‍💋‍👨🏾' => 'بوسه: زن،‏ مرد،‏ پوست آبنوسی، و پوست گندمی',
    '👩🏿‍❤‍💋‍👨🏿' => 'بوسه: زن،‏ مرد، و پوست آبنوسی',
    '👩🏻‍❤‍💋‍👩🏻' => 'بوسه: زن،‏ زن، و پوست سفید',
    '👩🏻‍❤‍💋‍👩🏼' => 'بوسه: زن،‏ زن،‏ پوست سفید، و پوست روشن',
    '👩🏻‍❤‍💋‍👩🏽' => 'بوسه: زن،‏ زن،‏ پوست سفید، و پوست طلایی',
    '👩🏻‍❤‍💋‍👩🏾' => 'بوسه: زن،‏ زن،‏ پوست سفید، و پوست گندمی',
    '👩🏻‍❤‍💋‍👩🏿' => 'بوسه: زن،‏ زن،‏ پوست سفید، و پوست آبنوسی',
    '👩🏼‍❤‍💋‍👩🏻' => 'بوسه: زن،‏ زن،‏ پوست روشن، و پوست سفید',
    '👩🏼‍❤‍💋‍👩🏼' => 'بوسه: زن،‏ زن، و پوست روشن',
    '👩🏼‍❤‍💋‍👩🏽' => 'بوسه: زن،‏ زن،‏ پوست روشن، و پوست طلایی',
    '👩🏼‍❤‍💋‍👩🏾' => 'بوسه: زن،‏ زن،‏ پوست روشن، و پوست گندمی',
    '👩🏼‍❤‍💋‍👩🏿' => 'بوسه: زن،‏ زن،‏ پوست روشن، و پوست آبنوسی',
    '👩🏽‍❤‍💋‍👩🏻' => 'بوسه: زن،‏ زن،‏ پوست طلایی، و پوست سفید',
    '👩🏽‍❤‍💋‍👩🏼' => 'بوسه: زن،‏ زن،‏ پوست طلایی، و پوست روشن',
    '👩🏽‍❤‍💋‍👩🏽' => 'بوسه: زن،‏ زن، و پوست طلایی',
    '👩🏽‍❤‍💋‍👩🏾' => 'بوسه: زن،‏ زن،‏ پوست طلایی، و پوست گندمی',
    '👩🏽‍❤‍💋‍👩🏿' => 'بوسه: زن،‏ زن،‏ پوست طلایی، و پوست آبنوسی',
    '👩🏾‍❤‍💋‍👩🏻' => 'بوسه: زن،‏ زن،‏ پوست گندمی، و پوست سفید',
    '👩🏾‍❤‍💋‍👩🏼' => 'بوسه: زن،‏ زن،‏ پوست گندمی، و پوست روشن',
    '👩🏾‍❤‍💋‍👩🏽' => 'بوسه: زن،‏ زن،‏ پوست گندمی، و پوست طلایی',
    '👩🏾‍❤‍💋‍👩🏾' => 'بوسه: زن،‏ زن، و پوست گندمی',
    '👩🏾‍❤‍💋‍👩🏿' => 'بوسه: زن،‏ زن،‏ پوست گندمی، و پوست آبنوسی',
    '👩🏿‍❤‍💋‍👩🏻' => 'بوسه: زن،‏ زن،‏ پوست آبنوسی، و پوست سفید',
    '👩🏿‍❤‍💋‍👩🏼' => 'بوسه: زن،‏ زن،‏ پوست آبنوسی، و پوست روشن',
    '👩🏿‍❤‍💋‍👩🏽' => 'بوسه: زن،‏ زن،‏ پوست آبنوسی، و پوست طلایی',
    '👩🏿‍❤‍💋‍👩🏾' => 'بوسه: زن،‏ زن،‏ پوست آبنوسی، و پوست گندمی',
    '👩🏿‍❤‍💋‍👩🏿' => 'بوسه: زن،‏ زن، و پوست آبنوسی',
    '🧑🏻‍🫯‍🧑🏼' => 'کُشتی‌گیران: پوست سفید،‏ پوست روشن',
    '🧑🏻‍🫯‍🧑🏽' => 'کُشتی‌گیران: پوست سفید،‏ پوست طلایی',
    '🧑🏻‍🫯‍🧑🏾' => 'کُشتی‌گیران: پوست سفید،‏ پوست گندمی',
    '🧑🏻‍🫯‍🧑🏿' => 'کُشتی‌گیران: پوست سفید،‏ پوست آبنوسی',
    '🧑🏼‍🫯‍🧑🏻' => 'کُشتی‌گیران: پوست روشن،‏ پوست سفید',
    '🧑🏼‍🫯‍🧑🏽' => 'کُشتی‌گیران: پوست روشن،‏ پوست طلایی',
    '🧑🏼‍🫯‍🧑🏾' => 'کُشتی‌گیران: پوست روشن،‏ پوست گندمی',
    '🧑🏼‍🫯‍🧑🏿' => 'کُشتی‌گیران: پوست روشن،‏ پوست آبنوسی',
    '🧑🏽‍🫯‍🧑🏻' => 'کُشتی‌گیران: پوست طلایی،‏ پوست سفید',
    '🧑🏽‍🫯‍🧑🏼' => 'کُشتی‌گیران: پوست طلایی،‏ پوست روشن',
    '🧑🏽‍🫯‍🧑🏾' => 'کُشتی‌گیران: پوست طلایی،‏ پوست گندمی',
    '🧑🏽‍🫯‍🧑🏿' => 'کُشتی‌گیران: پوست طلایی،‏ پوست آبنوسی',
    '🧑🏾‍🫯‍🧑🏻' => 'کُشتی‌گیران: پوست گندمی،‏ پوست سفید',
    '🧑🏾‍🫯‍🧑🏼' => 'کُشتی‌گیران: پوست گندمی،‏ پوست روشن',
    '🧑🏾‍🫯‍🧑🏽' => 'کُشتی‌گیران: پوست گندمی،‏ پوست طلایی',
    '🧑🏾‍🫯‍🧑🏿' => 'کُشتی‌گیران: پوست گندمی،‏ پوست آبنوسی',
    '🧑🏿‍🫯‍🧑🏻' => 'کُشتی‌گیران: پوست آبنوسی،‏ پوست سفید',
    '🧑🏿‍🫯‍🧑🏼' => 'کُشتی‌گیران: پوست آبنوسی،‏ پوست روشن',
    '🧑🏿‍🫯‍🧑🏽' => 'کُشتی‌گیران: پوست آبنوسی،‏ پوست طلایی',
    '🧑🏿‍🫯‍🧑🏾' => 'کُشتی‌گیران: پوست آبنوسی،‏ پوست گندمی',
    '🧑🏻‍❤‍🧑🏼' => 'زوج عاشق: شخص،‏ شخص،‏ پوست سفید، و پوست روشن',
    '🧑🏻‍❤‍🧑🏽' => 'زوج عاشق: شخص،‏ شخص،‏ پوست سفید، و پوست طلایی',
    '🧑🏻‍❤‍🧑🏾' => 'زوج عاشق: شخص،‏ شخص،‏ پوست سفید، و پوست گندمی',
    '🧑🏻‍❤‍🧑🏿' => 'زوج عاشق: شخص،‏ شخص،‏ پوست سفید، و پوست آبنوسی',
    '🧑🏼‍❤‍🧑🏻' => 'زوج عاشق: شخص،‏ شخص،‏ پوست روشن، و پوست سفید',
    '🧑🏼‍❤‍🧑🏽' => 'زوج عاشق: شخص،‏ شخص،‏ پوست روشن، و پوست طلایی',
    '🧑🏼‍❤‍🧑🏾' => 'زوج عاشق: شخص،‏ شخص،‏ پوست روشن، و پوست گندمی',
    '🧑🏼‍❤‍🧑🏿' => 'زوج عاشق: شخص،‏ شخص،‏ پوست روشن، و پوست آبنوسی',
    '🧑🏽‍❤‍🧑🏻' => 'زوج عاشق: شخص،‏ شخص،‏ پوست طلایی، و پوست سفید',
    '🧑🏽‍❤‍🧑🏼' => 'زوج عاشق: شخص،‏ شخص،‏ پوست طلایی، و پوست روشن',
    '🧑🏽‍❤‍🧑🏾' => 'زوج عاشق: شخص،‏ شخص،‏ پوست طلایی، و پوست گندمی',
    '🧑🏽‍❤‍🧑🏿' => 'زوج عاشق: شخص،‏ شخص،‏ پوست طلایی، و پوست آبنوسی',
    '🧑🏾‍❤‍🧑🏻' => 'زوج عاشق: شخص،‏ شخص،‏ پوست گندمی، و پوست سفید',
    '🧑🏾‍❤‍🧑🏼' => 'زوج عاشق: شخص،‏ شخص،‏ پوست گندمی، و پوست روشن',
    '🧑🏾‍❤‍🧑🏽' => 'زوج عاشق: شخص،‏ شخص،‏ پوست گندمی، و پوست طلایی',
    '🧑🏾‍❤‍🧑🏿' => 'زوج عاشق: شخص،‏ شخص،‏ پوست گندمی، و پوست آبنوسی',
    '🧑🏿‍❤‍🧑🏻' => 'زوج عاشق: شخص،‏ شخص،‏ پوست آبنوسی، و پوست سفید',
    '🧑🏿‍❤‍🧑🏼' => 'زوج عاشق: شخص،‏ شخص،‏ پوست آبنوسی، و پوست روشن',
    '🧑🏿‍❤‍🧑🏽' => 'زوج عاشق: شخص،‏ شخص،‏ پوست آبنوسی، و پوست طلایی',
    '🧑🏿‍❤‍🧑🏾' => 'زوج عاشق: شخص،‏ شخص،‏ پوست آبنوسی، و پوست گندمی',
    '🧑🏻‍🐰‍🧑🏼' => 'رقص: پوست سفید،‏ پوست روشن',
    '🧑🏻‍🐰‍🧑🏽' => 'رقص: پوست سفید،‏ پوست طلایی',
    '🧑🏻‍🐰‍🧑🏾' => 'رقص: پوست سفید،‏ پوست گندمی',
    '🧑🏻‍🐰‍🧑🏿' => 'رقص: پوست سفید،‏ پوست آبنوسی',
    '🧑🏼‍🐰‍🧑🏻' => 'رقص: پوست روشن،‏ پوست سفید',
    '🧑🏼‍🐰‍🧑🏽' => 'رقص: پوست روشن،‏ پوست طلایی',
    '🧑🏼‍🐰‍🧑🏾' => 'رقص: پوست روشن،‏ پوست گندمی',
    '🧑🏼‍🐰‍🧑🏿' => 'رقص: پوست روشن،‏ پوست آبنوسی',
    '🧑🏽‍🐰‍🧑🏻' => 'رقص: پوست طلایی،‏ پوست سفید',
    '🧑🏽‍🐰‍🧑🏼' => 'رقص: پوست طلایی،‏ پوست روشن',
    '🧑🏽‍🐰‍🧑🏾' => 'رقص: پوست طلایی،‏ پوست گندمی',
    '🧑🏽‍🐰‍🧑🏿' => 'رقص: پوست طلایی،‏ پوست آبنوسی',
    '🧑🏾‍🐰‍🧑🏻' => 'رقص: پوست گندمی،‏ پوست سفید',
    '🧑🏾‍🐰‍🧑🏼' => 'رقص: پوست گندمی،‏ پوست روشن',
    '🧑🏾‍🐰‍🧑🏽' => 'رقص: پوست گندمی،‏ پوست طلایی',
    '🧑🏾‍🐰‍🧑🏿' => 'رقص: پوست گندمی،‏ پوست آبنوسی',
    '🧑🏿‍🐰‍🧑🏻' => 'رقص: پوست آبنوسی،‏ پوست سفید',
    '🧑🏿‍🐰‍🧑🏼' => 'رقص: پوست آبنوسی،‏ پوست روشن',
    '🧑🏿‍🐰‍🧑🏽' => 'رقص: پوست آبنوسی،‏ پوست طلایی',
    '🧑🏿‍🐰‍🧑🏾' => 'رقص: پوست آبنوسی،‏ پوست گندمی',
    '👨🏻‍🫯‍👨🏼' => 'کُشتی‌گیر مرد: پوست سفید،‏ پوست روشن',
    '👨🏻‍🫯‍👨🏽' => 'کُشتی‌گیر مرد: پوست سفید،‏ پوست طلایی',
    '👨🏻‍🫯‍👨🏾' => 'کُشتی‌گیر مرد: پوست سفید،‏ پوست گندمی',
    '👨🏻‍🫯‍👨🏿' => 'کُشتی‌گیر مرد: پوست سفید،‏ پوست آبنوسی',
    '👨🏼‍🫯‍👨🏻' => 'کُشتی‌گیر مرد: پوست روشن،‏ پوست سفید',
    '👨🏼‍🫯‍👨🏽' => 'کُشتی‌گیر مرد: پوست روشن،‏ پوست طلایی',
    '👨🏼‍🫯‍👨🏾' => 'کُشتی‌گیر مرد: پوست روشن،‏ پوست گندمی',
    '👨🏼‍🫯‍👨🏿' => 'کُشتی‌گیر مرد: پوست روشن،‏ پوست آبنوسی',
    '👨🏽‍🫯‍👨🏻' => 'کُشتی‌گیر مرد: پوست طلایی،‏ پوست سفید',
    '👨🏽‍🫯‍👨🏼' => 'کُشتی‌گیر مرد: پوست طلایی،‏ پوست روشن',
    '👨🏽‍🫯‍👨🏾' => 'کُشتی‌گیر مرد: پوست طلایی،‏ پوست گندمی',
    '👨🏽‍🫯‍👨🏿' => 'کُشتی‌گیر مرد: پوست طلایی،‏ پوست آبنوسی',
    '👨🏾‍🫯‍👨🏻' => 'کُشتی‌گیر مرد: پوست گندمی،‏ پوست سفید',
    '👨🏾‍🫯‍👨🏼' => 'کُشتی‌گیر مرد: پوست گندمی،‏ پوست روشن',
    '👨🏾‍🫯‍👨🏽' => 'کُشتی‌گیر مرد: پوست گندمی،‏ پوست طلایی',
    '👨🏾‍🫯‍👨🏿' => 'کُشتی‌گیر مرد: پوست گندمی،‏ پوست آبنوسی',
    '👨🏿‍🫯‍👨🏻' => 'کُشتی‌گیر مرد: پوست آبنوسی،‏ پوست سفید',
    '👨🏿‍🫯‍👨🏼' => 'کُشتی‌گیر مرد: پوست آبنوسی،‏ پوست روشن',
    '👨🏿‍🫯‍👨🏽' => 'کُشتی‌گیر مرد: پوست آبنوسی،‏ پوست طلایی',
    '👨🏿‍🫯‍👨🏾' => 'کُشتی‌گیر مرد: پوست آبنوسی،‏ پوست گندمی',
    '👨🏻‍❤‍👨🏻' => 'زوج عاشق: مرد،‏ مرد، و پوست سفید',
    '👨🏻‍❤‍👨🏼' => 'زوج عاشق: مرد،‏ مرد،‏ پوست سفید، و پوست روشن',
    '👨🏻‍❤‍👨🏽' => 'زوج عاشق: مرد،‏ مرد،‏ پوست سفید، و پوست طلایی',
    '👨🏻‍❤‍👨🏾' => 'زوج عاشق: مرد،‏ مرد،‏ پوست سفید، و پوست گندمی',
    '👨🏻‍❤‍👨🏿' => 'زوج عاشق: مرد،‏ مرد،‏ پوست سفید، و پوست آبنوسی',
    '👨🏼‍❤‍👨🏻' => 'زوج عاشق: مرد،‏ مرد،‏ پوست روشن، و پوست سفید',
    '👨🏼‍❤‍👨🏼' => 'زوج عاشق: مرد،‏ مرد، و پوست روشن',
    '👨🏼‍❤‍👨🏽' => 'زوج عاشق: مرد،‏ مرد،‏ پوست روشن، و پوست طلایی',
    '👨🏼‍❤‍👨🏾' => 'زوج عاشق: مرد،‏ مرد،‏ پوست روشن، و پوست گندمی',
    '👨🏼‍❤‍👨🏿' => 'زوج عاشق: مرد،‏ مرد،‏ پوست روشن، و پوست آبنوسی',
    '👨🏽‍❤‍👨🏻' => 'زوج عاشق: مرد،‏ مرد،‏ پوست طلایی، و پوست سفید',
    '👨🏽‍❤‍👨🏼' => 'زوج عاشق: مرد،‏ مرد،‏ پوست طلایی، و پوست روشن',
    '👨🏽‍❤‍👨🏽' => 'زوج عاشق: مرد،‏ مرد، و پوست طلایی',
    '👨🏽‍❤‍👨🏾' => 'زوج عاشق: مرد،‏ مرد،‏ پوست طلایی، و پوست گندمی',
    '👨🏽‍❤‍👨🏿' => 'زوج عاشق: مرد،‏ مرد،‏ پوست طلایی، و پوست آبنوسی',
    '👨🏾‍❤‍👨🏻' => 'زوج عاشق: مرد،‏ مرد،‏ پوست گندمی، و پوست سفید',
    '👨🏾‍❤‍👨🏼' => 'زوج عاشق: مرد،‏ مرد،‏ پوست گندمی، و پوست روشن',
    '👨🏾‍❤‍👨🏽' => 'زوج عاشق: مرد،‏ مرد،‏ پوست گندمی، و پوست طلایی',
    '👨🏾‍❤‍👨🏾' => 'زوج عاشق: مرد،‏ مرد، و پوست گندمی',
    '👨🏾‍❤‍👨🏿' => 'زوج عاشق: مرد،‏ مرد،‏ پوست گندمی، و پوست آبنوسی',
    '👨🏿‍❤‍👨🏻' => 'زوج عاشق: مرد،‏ مرد،‏ پوست آبنوسی، و پوست سفید',
    '👨🏿‍❤‍👨🏼' => 'زوج عاشق: مرد،‏ مرد،‏ پوست آبنوسی، و پوست روشن',
    '👨🏿‍❤‍👨🏽' => 'زوج عاشق: مرد،‏ مرد،‏ پوست آبنوسی، و پوست طلایی',
    '👨🏿‍❤‍👨🏾' => 'زوج عاشق: مرد،‏ مرد،‏ پوست آبنوسی، و پوست گندمی',
    '👨🏿‍❤‍👨🏿' => 'زوج عاشق: مرد،‏ مرد، و پوست آبنوسی',
    '👨🏻‍🐰‍👨🏼' => 'مردان در پارتی: پوست سفید،‏ پوست روشن',
    '👨🏻‍🐰‍👨🏽' => 'مردان در پارتی: پوست سفید،‏ پوست طلایی',
    '👨🏻‍🐰‍👨🏾' => 'مردان در پارتی: پوست سفید،‏ پوست گندمی',
    '👨🏻‍🐰‍👨🏿' => 'مردان در پارتی: پوست سفید،‏ پوست آبنوسی',
    '👨🏼‍🐰‍👨🏻' => 'مردان در پارتی: پوست روشن،‏ پوست سفید',
    '👨🏼‍🐰‍👨🏽' => 'مردان در پارتی: پوست روشن،‏ پوست طلایی',
    '👨🏼‍🐰‍👨🏾' => 'مردان در پارتی: پوست روشن،‏ پوست گندمی',
    '👨🏼‍🐰‍👨🏿' => 'مردان در پارتی: پوست روشن،‏ پوست آبنوسی',
    '👨🏽‍🐰‍👨🏻' => 'مردان در پارتی: پوست طلایی،‏ پوست سفید',
    '👨🏽‍🐰‍👨🏼' => 'مردان در پارتی: پوست طلایی،‏ پوست روشن',
    '👨🏽‍🐰‍👨🏾' => 'مردان در پارتی: پوست طلایی،‏ پوست گندمی',
    '👨🏽‍🐰‍👨🏿' => 'مردان در پارتی: پوست طلایی،‏ پوست آبنوسی',
    '👨🏾‍🐰‍👨🏻' => 'مردان در پارتی: پوست گندمی،‏ پوست سفید',
    '👨🏾‍🐰‍👨🏼' => 'مردان در پارتی: پوست گندمی،‏ پوست روشن',
    '👨🏾‍🐰‍👨🏽' => 'مردان در پارتی: پوست گندمی،‏ پوست طلایی',
    '👨🏾‍🐰‍👨🏿' => 'مردان در پارتی: پوست گندمی،‏ پوست آبنوسی',
    '👨🏿‍🐰‍👨🏻' => 'مردان در پارتی: پوست آبنوسی،‏ پوست سفید',
    '👨🏿‍🐰‍👨🏼' => 'مردان در پارتی: پوست آبنوسی،‏ پوست روشن',
    '👨🏿‍🐰‍👨🏽' => 'مردان در پارتی: پوست آبنوسی،‏ پوست طلایی',
    '👨🏿‍🐰‍👨🏾' => 'مردان در پارتی: پوست آبنوسی،‏ پوست گندمی',
    '👩🏻‍🫯‍👩🏼' => 'کُشتی‌گیر زن: پوست سفید،‏ پوست روشن',
    '👩🏻‍🫯‍👩🏽' => 'کُشتی‌گیر زن: پوست سفید،‏ پوست طلایی',
    '👩🏻‍🫯‍👩🏾' => 'کُشتی‌گیر زن: پوست سفید،‏ پوست گندمی',
    '👩🏻‍🫯‍👩🏿' => 'کُشتی‌گیر زن: پوست سفید،‏ پوست آبنوسی',
    '👩🏼‍🫯‍👩🏻' => 'کُشتی‌گیر زن: پوست روشن،‏ پوست سفید',
    '👩🏼‍🫯‍👩🏽' => 'کُشتی‌گیر زن: پوست روشن،‏ پوست طلایی',
    '👩🏼‍🫯‍👩🏾' => 'کُشتی‌گیر زن: پوست روشن،‏ پوست گندمی',
    '👩🏼‍🫯‍👩🏿' => 'کُشتی‌گیر زن: پوست روشن،‏ پوست آبنوسی',
    '👩🏽‍🫯‍👩🏻' => 'کُشتی‌گیر زن: پوست طلایی،‏ پوست سفید',
    '👩🏽‍🫯‍👩🏼' => 'کُشتی‌گیر زن: پوست طلایی،‏ پوست روشن',
    '👩🏽‍🫯‍👩🏾' => 'کُشتی‌گیر زن: پوست طلایی،‏ پوست گندمی',
    '👩🏽‍🫯‍👩🏿' => 'کُشتی‌گیر زن: پوست طلایی،‏ پوست آبنوسی',
    '👩🏾‍🫯‍👩🏻' => 'کُشتی‌گیر زن: پوست گندمی،‏ پوست سفید',
    '👩🏾‍🫯‍👩🏼' => 'کُشتی‌گیر زن: پوست گندمی،‏ پوست روشن',
    '👩🏾‍🫯‍👩🏽' => 'کُشتی‌گیر زن: پوست گندمی،‏ پوست طلایی',
    '👩🏾‍🫯‍👩🏿' => 'کُشتی‌گیر زن: پوست گندمی،‏ پوست آبنوسی',
    '👩🏿‍🫯‍👩🏻' => 'کُشتی‌گیر زن: پوست آبنوسی،‏ پوست سفید',
    '👩🏿‍🫯‍👩🏼' => 'کُشتی‌گیر زن: پوست آبنوسی،‏ پوست روشن',
    '👩🏿‍🫯‍👩🏽' => 'کُشتی‌گیر زن: پوست آبنوسی،‏ پوست طلایی',
    '👩🏿‍🫯‍👩🏾' => 'کُشتی‌گیر زن: پوست آبنوسی،‏ پوست گندمی',
    '👩🏻‍❤‍👨🏻' => 'زوج عاشق: زن،‏ مرد، و پوست سفید',
    '👩🏻‍❤‍👨🏼' => 'زوج عاشق: زن،‏ مرد،‏ پوست سفید، و پوست روشن',
    '👩🏻‍❤‍👨🏽' => 'زوج عاشق: زن،‏ مرد،‏ پوست سفید، و پوست طلایی',
    '👩🏻‍❤‍👨🏾' => 'زوج عاشق: زن،‏ مرد،‏ پوست سفید، و پوست گندمی',
    '👩🏻‍❤‍👨🏿' => 'زوج عاشق: زن،‏ مرد،‏ پوست سفید، و پوست آبنوسی',
    '👩🏼‍❤‍👨🏻' => 'زوج عاشق: زن،‏ مرد،‏ پوست روشن، و پوست سفید',
    '👩🏼‍❤‍👨🏼' => 'زوج عاشق: زن،‏ مرد، و پوست روشن',
    '👩🏼‍❤‍👨🏽' => 'زوج عاشق: زن،‏ مرد،‏ پوست روشن، و پوست طلایی',
    '👩🏼‍❤‍👨🏾' => 'زوج عاشق: زن،‏ مرد،‏ پوست روشن، و پوست گندمی',
    '👩🏼‍❤‍👨🏿' => 'زوج عاشق: زن،‏ مرد،‏ پوست روشن، و پوست آبنوسی',
    '👩🏽‍❤‍👨🏻' => 'زوج عاشق: زن،‏ مرد،‏ پوست طلایی، و پوست سفید',
    '👩🏽‍❤‍👨🏼' => 'زوج عاشق: زن،‏ مرد،‏ پوست طلایی، و پوست روشن',
    '👩🏽‍❤‍👨🏽' => 'زوج عاشق: زن،‏ مرد، و پوست طلایی',
    '👩🏽‍❤‍👨🏾' => 'زوج عاشق: زن،‏ مرد،‏ پوست طلایی، و پوست گندمی',
    '👩🏽‍❤‍👨🏿' => 'زوج عاشق: زن،‏ مرد،‏ پوست طلایی، و پوست آبنوسی',
    '👩🏾‍❤‍👨🏻' => 'زوج عاشق: زن،‏ مرد،‏ پوست گندمی، و پوست سفید',
    '👩🏾‍❤‍👨🏼' => 'زوج عاشق: زن،‏ مرد،‏ پوست گندمی، و پوست روشن',
    '👩🏾‍❤‍👨🏽' => 'زوج عاشق: زن،‏ مرد،‏ پوست گندمی، و پوست طلایی',
    '👩🏾‍❤‍👨🏾' => 'زوج عاشق: زن،‏ مرد، و پوست گندمی',
    '👩🏾‍❤‍👨🏿' => 'زوج عاشق: زن،‏ مرد،‏ پوست گندمی، و پوست آبنوسی',
    '👩🏿‍❤‍👨🏻' => 'زوج عاشق: زن،‏ مرد،‏ پوست آبنوسی، و پوست سفید',
    '👩🏿‍❤‍👨🏼' => 'زوج عاشق: زن،‏ مرد،‏ پوست آبنوسی، و پوست روشن',
    '👩🏿‍❤‍👨🏽' => 'زوج عاشق: زن،‏ مرد،‏ پوست آبنوسی، و پوست طلایی',
    '👩🏿‍❤‍👨🏾' => 'زوج عاشق: زن،‏ مرد،‏ پوست آبنوسی، و پوست گندمی',
    '👩🏿‍❤‍👨🏿' => 'زوج عاشق: زن،‏ مرد، و پوست آبنوسی',
    '👩🏻‍❤‍👩🏻' => 'زوج عاشق: زن،‏ زن، و پوست سفید',
    '👩🏻‍❤‍👩🏼' => 'زوج عاشق: زن،‏ زن،‏ پوست سفید، و پوست روشن',
    '👩🏻‍❤‍👩🏽' => 'زوج عاشق: زن،‏ زن،‏ پوست سفید، و پوست طلایی',
    '👩🏻‍❤‍👩🏾' => 'زوج عاشق: زن،‏ زن،‏ پوست سفید، و پوست گندمی',
    '👩🏻‍❤‍👩🏿' => 'زوج عاشق: زن،‏ زن،‏ پوست سفید، و پوست آبنوسی',
    '👩🏼‍❤‍👩🏻' => 'زوج عاشق: زن،‏ زن،‏ پوست روشن، و پوست سفید',
    '👩🏼‍❤‍👩🏼' => 'زوج عاشق: زن،‏ زن، و پوست روشن',
    '👩🏼‍❤‍👩🏽' => 'زوج عاشق: زن،‏ زن،‏ پوست روشن، و پوست طلایی',
    '👩🏼‍❤‍👩🏾' => 'زوج عاشق: زن،‏ زن،‏ پوست روشن، و پوست گندمی',
    '👩🏼‍❤‍👩🏿' => 'زوج عاشق: زن،‏ زن،‏ پوست روشن، و پوست آبنوسی',
    '👩🏽‍❤‍👩🏻' => 'زوج عاشق: زن،‏ زن،‏ پوست طلایی، و پوست سفید',
    '👩🏽‍❤‍👩🏼' => 'زوج عاشق: زن،‏ زن،‏ پوست طلایی، و پوست روشن',
    '👩🏽‍❤‍👩🏽' => 'زوج عاشق: زن،‏ زن، و پوست طلایی',
    '👩🏽‍❤‍👩🏾' => 'زوج عاشق: زن،‏ زن،‏ پوست طلایی، و پوست گندمی',
    '👩🏽‍❤‍👩🏿' => 'زوج عاشق: زن،‏ زن،‏ پوست طلایی، و پوست آبنوسی',
    '👩🏾‍❤‍👩🏻' => 'زوج عاشق: زن،‏ زن،‏ پوست گندمی، و پوست سفید',
    '👩🏾‍❤‍👩🏼' => 'زوج عاشق: زن،‏ زن،‏ پوست گندمی، و پوست روشن',
    '👩🏾‍❤‍👩🏽' => 'زوج عاشق: زن،‏ زن،‏ پوست گندمی، و پوست طلایی',
    '👩🏾‍❤‍👩🏾' => 'زوج عاشق: زن،‏ زن، و پوست گندمی',
    '👩🏾‍❤‍👩🏿' => 'زوج عاشق: زن،‏ زن،‏ پوست گندمی، و پوست آبنوسی',
    '👩🏿‍❤‍👩🏻' => 'زوج عاشق: زن،‏ زن،‏ پوست آبنوسی، و پوست سفید',
    '👩🏿‍❤‍👩🏼' => 'زوج عاشق: زن،‏ زن،‏ پوست آبنوسی، و پوست روشن',
    '👩🏿‍❤‍👩🏽' => 'زوج عاشق: زن،‏ زن،‏ پوست آبنوسی، و پوست طلایی',
    '👩🏿‍❤‍👩🏾' => 'زوج عاشق: زن،‏ زن،‏ پوست آبنوسی، و پوست گندمی',
    '👩🏿‍❤‍👩🏿' => 'زوج عاشق: زن،‏ زن، و پوست آبنوسی',
    '👩🏻‍🐰‍👩🏼' => 'زنان در پارتی: پوست سفید،‏ پوست روشن',
    '👩🏻‍🐰‍👩🏽' => 'زنان در پارتی: پوست سفید،‏ پوست طلایی',
    '👩🏻‍🐰‍👩🏾' => 'زنان در پارتی: پوست سفید،‏ پوست گندمی',
    '👩🏻‍🐰‍👩🏿' => 'زنان در پارتی: پوست سفید،‏ پوست آبنوسی',
    '👩🏼‍🐰‍👩🏻' => 'زنان در پارتی: پوست روشن،‏ پوست سفید',
    '👩🏼‍🐰‍👩🏽' => 'زنان در پارتی: پوست روشن،‏ پوست طلایی',
    '👩🏼‍🐰‍👩🏾' => 'زنان در پارتی: پوست روشن،‏ پوست گندمی',
    '👩🏼‍🐰‍👩🏿' => 'زنان در پارتی: پوست روشن،‏ پوست آبنوسی',
    '👩🏽‍🐰‍👩🏻' => 'زنان در پارتی: پوست طلایی،‏ پوست سفید',
    '👩🏽‍🐰‍👩🏼' => 'زنان در پارتی: پوست طلایی،‏ پوست روشن',
    '👩🏽‍🐰‍👩🏾' => 'زنان در پارتی: پوست طلایی،‏ پوست گندمی',
    '👩🏽‍🐰‍👩🏿' => 'زنان در پارتی: پوست طلایی،‏ پوست آبنوسی',
    '👩🏾‍🐰‍👩🏻' => 'زنان در پارتی: پوست گندمی،‏ پوست سفید',
    '👩🏾‍🐰‍👩🏼' => 'زنان در پارتی: پوست گندمی،‏ پوست روشن',
    '👩🏾‍🐰‍👩🏽' => 'زنان در پارتی: پوست گندمی،‏ پوست طلایی',
    '👩🏾‍🐰‍👩🏿' => 'زنان در پارتی: پوست گندمی،‏ پوست آبنوسی',
    '👩🏿‍🐰‍👩🏻' => 'زنان در پارتی: پوست آبنوسی،‏ پوست سفید',
    '👩🏿‍🐰‍👩🏼' => 'زنان در پارتی: پوست آبنوسی،‏ پوست روشن',
    '👩🏿‍🐰‍👩🏽' => 'زنان در پارتی: پوست آبنوسی،‏ پوست طلایی',
    '👩🏿‍🐰‍👩🏾' => 'زنان در پارتی: پوست آبنوسی،‏ پوست گندمی',
    '🧑🏻‍🤝‍🧑🏻' => 'اشخاصی دست در دست هم: پوست سفید',
    '🧑🏻‍🤝‍🧑🏼' => 'اشخاصی دست در دست هم: پوست سفید،‏ پوست روشن',
    '🧑🏻‍🤝‍🧑🏽' => 'اشخاصی دست در دست هم: پوست سفید،‏ پوست طلایی',
    '🧑🏻‍🤝‍🧑🏾' => 'اشخاصی دست در دست هم: پوست سفید،‏ پوست گندمی',
    '🧑🏻‍🤝‍🧑🏿' => 'اشخاصی دست در دست هم: پوست سفید،‏ پوست آبنوسی',
    '🧑🏼‍🤝‍🧑🏻' => 'اشخاصی دست در دست هم: پوست روشن،‏ پوست سفید',
    '🧑🏼‍🤝‍🧑🏼' => 'اشخاصی دست در دست هم: پوست روشن',
    '🧑🏼‍🤝‍🧑🏽' => 'اشخاصی دست در دست هم: پوست روشن،‏ پوست طلایی',
    '🧑🏼‍🤝‍🧑🏾' => 'اشخاصی دست در دست هم: پوست روشن،‏ پوست گندمی',
    '🧑🏼‍🤝‍🧑🏿' => 'اشخاصی دست در دست هم: پوست روشن،‏ پوست آبنوسی',
    '🧑🏽‍🤝‍🧑🏻' => 'اشخاصی دست در دست هم: پوست طلایی،‏ پوست سفید',
    '🧑🏽‍🤝‍🧑🏼' => 'اشخاصی دست در دست هم: پوست طلایی،‏ پوست روشن',
    '🧑🏽‍🤝‍🧑🏽' => 'اشخاصی دست در دست هم: پوست طلایی',
    '🧑🏽‍🤝‍🧑🏾' => 'اشخاصی دست در دست هم: پوست طلایی،‏ پوست گندمی',
    '🧑🏽‍🤝‍🧑🏿' => 'اشخاصی دست در دست هم: پوست طلایی،‏ پوست آبنوسی',
    '🧑🏾‍🤝‍🧑🏻' => 'اشخاصی دست در دست هم: پوست گندمی،‏ پوست سفید',
    '🧑🏾‍🤝‍🧑🏼' => 'اشخاصی دست در دست هم: پوست گندمی،‏ پوست روشن',
    '🧑🏾‍🤝‍🧑🏽' => 'اشخاصی دست در دست هم: پوست گندمی،‏ پوست طلایی',
    '🧑🏾‍🤝‍🧑🏾' => 'اشخاصی دست در دست هم: پوست گندمی',
    '🧑🏾‍🤝‍🧑🏿' => 'اشخاصی دست در دست هم: پوست گندمی،‏ پوست آبنوسی',
    '🧑🏿‍🤝‍🧑🏻' => 'اشخاصی دست در دست هم: پوست آبنوسی،‏ پوست سفید',
    '🧑🏿‍🤝‍🧑🏼' => 'اشخاصی دست در دست هم: پوست آبنوسی،‏ پوست روشن',
    '🧑🏿‍🤝‍🧑🏽' => 'اشخاصی دست در دست هم: پوست آبنوسی،‏ پوست طلایی',
    '🧑🏿‍🤝‍🧑🏾' => 'اشخاصی دست در دست هم: پوست آبنوسی،‏ پوست گندمی',
    '🧑🏿‍🤝‍🧑🏿' => 'اشخاصی دست در دست هم: پوست آبنوسی',
    '👩🏻‍🤝‍👩🏼' => 'دو زن دست در دست: پوست سفید،‏ پوست روشن',
    '👩🏻‍🤝‍👩🏽' => 'دو زن دست در دست: پوست سفید،‏ پوست طلایی',
    '👩🏻‍🤝‍👩🏾' => 'دو زن دست در دست: پوست سفید،‏ پوست گندمی',
    '👩🏻‍🤝‍👩🏿' => 'دو زن دست در دست: پوست سفید،‏ پوست آبنوسی',
    '👩🏼‍🤝‍👩🏻' => 'دو زن دست در دست: پوست روشن،‏ پوست سفید',
    '👩🏼‍🤝‍👩🏽' => 'دو زن دست در دست: پوست روشن،‏ پوست طلایی',
    '👩🏼‍🤝‍👩🏾' => 'دو زن دست در دست: پوست روشن،‏ پوست گندمی',
    '👩🏼‍🤝‍👩🏿' => 'دو زن دست در دست: پوست روشن،‏ پوست آبنوسی',
    '👩🏽‍🤝‍👩🏻' => 'دو زن دست در دست: پوست طلایی،‏ پوست سفید',
    '👩🏽‍🤝‍👩🏼' => 'دو زن دست در دست: پوست طلایی،‏ پوست روشن',
    '👩🏽‍🤝‍👩🏾' => 'دو زن دست در دست: پوست طلایی،‏ پوست گندمی',
    '👩🏽‍🤝‍👩🏿' => 'دو زن دست در دست: پوست طلایی،‏ پوست آبنوسی',
    '👩🏾‍🤝‍👩🏻' => 'دو زن دست در دست: پوست گندمی،‏ پوست سفید',
    '👩🏾‍🤝‍👩🏼' => 'دو زن دست در دست: پوست گندمی،‏ پوست روشن',
    '👩🏾‍🤝‍👩🏽' => 'دو زن دست در دست: پوست گندمی،‏ پوست طلایی',
    '👩🏾‍🤝‍👩🏿' => 'دو زن دست در دست: پوست گندمی،‏ پوست آبنوسی',
    '👩🏿‍🤝‍👩🏻' => 'دو زن دست در دست: پوست آبنوسی،‏ پوست سفید',
    '👩🏿‍🤝‍👩🏼' => 'دو زن دست در دست: پوست آبنوسی،‏ پوست روشن',
    '👩🏿‍🤝‍👩🏽' => 'دو زن دست در دست: پوست آبنوسی،‏ پوست طلایی',
    '👩🏿‍🤝‍👩🏾' => 'دو زن دست در دست: پوست آبنوسی،‏ پوست گندمی',
    '👩🏻‍🤝‍👨🏼' => 'زن و مرد دست در‌ دست: پوست سفید،‏ پوست روشن',
    '👩🏻‍🤝‍👨🏽' => 'زن و مرد دست در‌ دست: پوست سفید،‏ پوست طلایی',
    '👩🏻‍🤝‍👨🏾' => 'زن و مرد دست در‌ دست: پوست سفید،‏ پوست گندمی',
    '👩🏻‍🤝‍👨🏿' => 'زن و مرد دست در‌ دست: پوست سفید،‏ پوست آبنوسی',
    '👩🏼‍🤝‍👨🏻' => 'زن و مرد دست در‌ دست: پوست روشن،‏ پوست سفید',
    '👩🏼‍🤝‍👨🏽' => 'زن و مرد دست در‌ دست: پوست روشن،‏ پوست طلایی',
    '👩🏼‍🤝‍👨🏾' => 'زن و مرد دست در‌ دست: پوست روشن،‏ پوست گندمی',
    '👩🏼‍🤝‍👨🏿' => 'زن و مرد دست در‌ دست: پوست روشن،‏ پوست آبنوسی',
    '👩🏽‍🤝‍👨🏻' => 'زن و مرد دست در‌ دست: پوست طلایی،‏ پوست سفید',
    '👩🏽‍🤝‍👨🏼' => 'زن و مرد دست در‌ دست: پوست طلایی،‏ پوست روشن',
    '👩🏽‍🤝‍👨🏾' => 'زن و مرد دست در‌ دست: پوست طلایی،‏ پوست گندمی',
    '👩🏽‍🤝‍👨🏿' => 'زن و مرد دست در‌ دست: پوست طلایی،‏ پوست آبنوسی',
    '👩🏾‍🤝‍👨🏻' => 'زن و مرد دست در‌ دست: پوست گندمی،‏ پوست سفید',
    '👩🏾‍🤝‍👨🏼' => 'زن و مرد دست در‌ دست: پوست گندمی،‏ پوست روشن',
    '👩🏾‍🤝‍👨🏽' => 'زن و مرد دست در‌ دست: پوست گندمی،‏ پوست طلایی',
    '👩🏾‍🤝‍👨🏿' => 'زن و مرد دست در‌ دست: پوست گندمی،‏ پوست آبنوسی',
    '👩🏿‍🤝‍👨🏻' => 'زن و مرد دست در‌ دست: پوست آبنوسی،‏ پوست سفید',
    '👩🏿‍🤝‍👨🏼' => 'زن و مرد دست در‌ دست: پوست آبنوسی،‏ پوست روشن',
    '👩🏿‍🤝‍👨🏽' => 'زن و مرد دست در‌ دست: پوست آبنوسی،‏ پوست طلایی',
    '👩🏿‍🤝‍👨🏾' => 'زن و مرد دست در‌ دست: پوست آبنوسی،‏ پوست گندمی',
    '👨🏻‍🤝‍👨🏼' => 'دو مرد دست در دست: پوست سفید،‏ پوست روشن',
    '👨🏻‍🤝‍👨🏽' => 'دو مرد دست در دست: پوست سفید،‏ پوست طلایی',
    '👨🏻‍🤝‍👨🏾' => 'دو مرد دست در دست: پوست سفید،‏ پوست گندمی',
    '👨🏻‍🤝‍👨🏿' => 'دو مرد دست در دست: پوست سفید،‏ پوست آبنوسی',
    '👨🏼‍🤝‍👨🏻' => 'دو مرد دست در دست: پوست روشن،‏ پوست سفید',
    '👨🏼‍🤝‍👨🏽' => 'دو مرد دست در دست: پوست روشن،‏ پوست طلایی',
    '👨🏼‍🤝‍👨🏾' => 'دو مرد دست در دست: پوست روشن،‏ پوست گندمی',
    '👨🏼‍🤝‍👨🏿' => 'دو مرد دست در دست: پوست روشن،‏ پوست آبنوسی',
    '👨🏽‍🤝‍👨🏻' => 'دو مرد دست در دست: پوست طلایی،‏ پوست سفید',
    '👨🏽‍🤝‍👨🏼' => 'دو مرد دست در دست: پوست طلایی،‏ پوست روشن',
    '👨🏽‍🤝‍👨🏾' => 'دو مرد دست در دست: پوست طلایی،‏ پوست گندمی',
    '👨🏽‍🤝‍👨🏿' => 'دو مرد دست در دست: پوست طلایی،‏ پوست آبنوسی',
    '👨🏾‍🤝‍👨🏻' => 'دو مرد دست در دست: پوست گندمی،‏ پوست سفید',
    '👨🏾‍🤝‍👨🏼' => 'دو مرد دست در دست: پوست گندمی،‏ پوست روشن',
    '👨🏾‍🤝‍👨🏽' => 'دو مرد دست در دست: پوست گندمی،‏ پوست طلایی',
    '👨🏾‍🤝‍👨🏿' => 'دو مرد دست در دست: پوست گندمی،‏ پوست آبنوسی',
    '👨🏿‍🤝‍👨🏻' => 'دو مرد دست در دست: پوست آبنوسی،‏ پوست سفید',
    '👨🏿‍🤝‍👨🏼' => 'دو مرد دست در دست: پوست آبنوسی،‏ پوست روشن',
    '👨🏿‍🤝‍👨🏽' => 'دو مرد دست در دست: پوست آبنوسی،‏ پوست طلایی',
    '👨🏿‍🤝‍👨🏾' => 'دو مرد دست در دست: پوست آبنوسی،‏ پوست گندمی',
    '👩‍❤‍💋‍👨' => 'بوسه: زن،‏ مرد',
    '👨‍❤‍💋‍👨' => 'بوسه: مرد،‏ مرد',
    '👩‍❤‍💋‍👩' => 'بوسه: زن،‏ زن',
    '👨‍👩‍👧‍👦' => 'خانواده: مرد،‏ زن،‏ دختر، و پسر',
    '👨‍👩‍👦‍👦' => 'خانواده: مرد،‏ زن،‏ پسر، و پسر',
    '👨‍👩‍👧‍👧' => 'خانواده: مرد،‏ زن،‏ دختر، و دختر',
    '👨‍👨‍👧‍👦' => 'خانواده: مرد،‏ مرد،‏ دختر، و پسر',
    '👨‍👨‍👦‍👦' => 'خانواده: مرد،‏ مرد،‏ پسر، و پسر',
    '👨‍👨‍👧‍👧' => 'خانواده: مرد،‏ مرد،‏ دختر، و دختر',
    '👩‍👩‍👧‍👦' => 'خانواده: زن،‏ زن،‏ دختر، و پسر',
    '👩‍👩‍👦‍👦' => 'خانواده: زن،‏ زن،‏ پسر، و پسر',
    '👩‍👩‍👧‍👧' => 'خانواده: زن،‏ زن،‏ دختر، و دختر',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'پرچم: انگلستان',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'پرچم: اسکاتلند',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'پرچم: ویلز',
    '🧑‍🧑‍🧒‍🧒' => 'خانواده: بزرگسال، بالغ، کودک، فرزند',
    '🚶🏻‍♀‍➡' => 'زن پیاده‌روی می‌کند: پوست سفید،‏ به سمت راست',
    '🚶🏼‍♀‍➡' => 'زن پیاده‌روی می‌کند: پوست روشن،‏ به سمت راست',
    '🚶🏽‍♀‍➡' => 'زن پیاده‌روی می‌کند: پوست طلایی،‏ به سمت راست',
    '🚶🏾‍♀‍➡' => 'زن پیاده‌روی می‌کند: پوست گندمی،‏ به سمت راست',
    '🚶🏿‍♀‍➡' => 'زن پیاده‌روی می‌کند: پوست آبنوسی،‏ به سمت راست',
    '🚶🏻‍♂‍➡' => 'مرد پیاده‌روی می‌کند: پوست سفید،‏ به سمت راست',
    '🚶🏼‍♂‍➡' => 'مرد پیاده‌روی می‌کند: پوست روشن،‏ به سمت راست',
    '🚶🏽‍♂‍➡' => 'مرد پیاده‌روی می‌کند: پوست طلایی،‏ به سمت راست',
    '🚶🏾‍♂‍➡' => 'مرد پیاده‌روی می‌کند: پوست گندمی،‏ به سمت راست',
    '🚶🏿‍♂‍➡' => 'مرد پیاده‌روی می‌کند: پوست آبنوسی،‏ به سمت راست',
    '🧎🏻‍♀‍➡' => 'زن زانوزده: پوست سفید،‏ به سمت راست',
    '🧎🏼‍♀‍➡' => 'زن زانوزده: پوست روشن،‏ به سمت راست',
    '🧎🏽‍♀‍➡' => 'زن زانوزده: پوست طلایی،‏ به سمت راست',
    '🧎🏾‍♀‍➡' => 'زن زانوزده: پوست گندمی،‏ به سمت راست',
    '🧎🏿‍♀‍➡' => 'زن زانوزده: پوست آبنوسی،‏ به سمت راست',
    '🧎🏻‍♂‍➡' => 'مرد زانوزده: پوست سفید،‏ به سمت راست',
    '🧎🏼‍♂‍➡' => 'مرد زانوزده: پوست روشن،‏ به سمت راست',
    '🧎🏽‍♂‍➡' => 'مرد زانوزده: پوست طلایی،‏ به سمت راست',
    '🧎🏾‍♂‍➡' => 'مرد زانوزده: پوست گندمی،‏ به سمت راست',
    '🧎🏿‍♂‍➡' => 'مرد زانوزده: پوست آبنوسی،‏ به سمت راست',
    '🧑🏻‍🦯‍➡' => 'شخصی با عصای راهنما: پوست سفید،‏ به سمت راست',
    '🧑🏼‍🦯‍➡' => 'شخصی با عصای راهنما: پوست روشن،‏ به سمت راست',
    '🧑🏽‍🦯‍➡' => 'شخصی با عصای راهنما: پوست طلایی،‏ به سمت راست',
    '🧑🏾‍🦯‍➡' => 'شخصی با عصای راهنما: پوست گندمی،‏ به سمت راست',
    '🧑🏿‍🦯‍➡' => 'شخصی با عصای راهنما: پوست آبنوسی،‏ به سمت راست',
    '👨🏻‍🦯‍➡' => 'مرد با عصای سفید: پوست سفید،‏ به سمت راست',
    '👨🏼‍🦯‍➡' => 'مرد با عصای سفید: پوست روشن،‏ به سمت راست',
    '👨🏽‍🦯‍➡' => 'مرد با عصای سفید: پوست طلایی،‏ به سمت راست',
    '👨🏾‍🦯‍➡' => 'مرد با عصای سفید: پوست گندمی،‏ به سمت راست',
    '👨🏿‍🦯‍➡' => 'مرد با عصای سفید: پوست آبنوسی،‏ به سمت راست',
    '👩🏻‍🦯‍➡' => 'زن با عصای سفید: پوست سفید،‏ به سمت راست',
    '👩🏼‍🦯‍➡' => 'زن با عصای سفید: پوست روشن،‏ به سمت راست',
    '👩🏽‍🦯‍➡' => 'زن با عصای سفید: پوست طلایی،‏ به سمت راست',
    '👩🏾‍🦯‍➡' => 'زن با عصای سفید: پوست گندمی،‏ به سمت راست',
    '👩🏿‍🦯‍➡' => 'زن با عصای سفید: پوست آبنوسی،‏ به سمت راست',
    '🧑🏻‍🦼‍➡' => 'شخصی با صندلی چرخ‌دار موتوری: پوست سفید،‏ به سمت راست',
    '🧑🏼‍🦼‍➡' => 'شخصی با صندلی چرخ‌دار موتوری: پوست روشن،‏ به سمت راست',
    '🧑🏽‍🦼‍➡' => 'شخصی با صندلی چرخ‌دار موتوری: پوست طلایی،‏ به سمت راست',
    '🧑🏾‍🦼‍➡' => 'شخصی با صندلی چرخ‌دار موتوری: پوست گندمی،‏ به سمت راست',
    '🧑🏿‍🦼‍➡' => 'شخصی با صندلی چرخ‌دار موتوری: پوست آبنوسی،‏ به سمت راست',
    '👨🏻‍🦼‍➡' => 'مرد در صندلی چرخ‌دار برقی: پوست سفید،‏ به سمت راست',
    '👨🏼‍🦼‍➡' => 'مرد در صندلی چرخ‌دار برقی: پوست روشن،‏ به سمت راست',
    '👨🏽‍🦼‍➡' => 'مرد در صندلی چرخ‌دار برقی: پوست طلایی،‏ به سمت راست',
    '👨🏾‍🦼‍➡' => 'مرد در صندلی چرخ‌دار برقی: پوست گندمی،‏ به سمت راست',
    '👨🏿‍🦼‍➡' => 'مرد در صندلی چرخ‌دار برقی: پوست آبنوسی،‏ به سمت راست',
    '👩🏻‍🦼‍➡' => 'زن در صندلی چرخ‌دار برقی: پوست سفید،‏ به سمت راست',
    '👩🏼‍🦼‍➡' => 'زن در صندلی چرخ‌دار برقی: پوست روشن،‏ به سمت راست',
    '👩🏽‍🦼‍➡' => 'زن در صندلی چرخ‌دار برقی: پوست طلایی،‏ به سمت راست',
    '👩🏾‍🦼‍➡' => 'زن در صندلی چرخ‌دار برقی: پوست گندمی،‏ به سمت راست',
    '👩🏿‍🦼‍➡' => 'زن در صندلی چرخ‌دار برقی: پوست آبنوسی،‏ به سمت راست',
    '🧑🏻‍🦽‍➡' => 'شخصی با صندلی چرخ‌دار دستی: پوست سفید،‏ به سمت راست',
    '🧑🏼‍🦽‍➡' => 'شخصی با صندلی چرخ‌دار دستی: پوست روشن،‏ به سمت راست',
    '🧑🏽‍🦽‍➡' => 'شخصی با صندلی چرخ‌دار دستی: پوست طلایی،‏ به سمت راست',
    '🧑🏾‍🦽‍➡' => 'شخصی با صندلی چرخ‌دار دستی: پوست گندمی،‏ به سمت راست',
    '🧑🏿‍🦽‍➡' => 'شخصی با صندلی چرخ‌دار دستی: پوست آبنوسی،‏ به سمت راست',
    '👨🏻‍🦽‍➡' => 'مرد در صندلی چرخ‌دار دستی: پوست سفید،‏ به سمت راست',
    '👨🏼‍🦽‍➡' => 'مرد در صندلی چرخ‌دار دستی: پوست روشن،‏ به سمت راست',
    '👨🏽‍🦽‍➡' => 'مرد در صندلی چرخ‌دار دستی: پوست طلایی،‏ به سمت راست',
    '👨🏾‍🦽‍➡' => 'مرد در صندلی چرخ‌دار دستی: پوست گندمی،‏ به سمت راست',
    '👨🏿‍🦽‍➡' => 'مرد در صندلی چرخ‌دار دستی: پوست آبنوسی،‏ به سمت راست',
    '👩🏻‍🦽‍➡' => 'زن در صندلی چرخ‌دار دستی: پوست سفید،‏ به سمت راست',
    '👩🏼‍🦽‍➡' => 'زن در صندلی چرخ‌دار دستی: پوست روشن،‏ به سمت راست',
    '👩🏽‍🦽‍➡' => 'زن در صندلی چرخ‌دار دستی: پوست طلایی،‏ به سمت راست',
    '👩🏾‍🦽‍➡' => 'زن در صندلی چرخ‌دار دستی: پوست گندمی،‏ به سمت راست',
    '👩🏿‍🦽‍➡' => 'زن در صندلی چرخ‌دار دستی: پوست آبنوسی،‏ به سمت راست',
    '🏃🏻‍♀‍➡' => 'زن دونده: پوست سفید،‏ به سمت راست',
    '🏃🏼‍♀‍➡' => 'زن دونده: پوست روشن،‏ به سمت راست',
    '🏃🏽‍♀‍➡' => 'زن دونده: پوست طلایی،‏ به سمت راست',
    '🏃🏾‍♀‍➡' => 'زن دونده: پوست گندمی،‏ به سمت راست',
    '🏃🏿‍♀‍➡' => 'زن دونده: پوست آبنوسی،‏ به سمت راست',
    '🏃🏻‍♂‍➡' => 'مرد دونده: پوست سفید،‏ به سمت راست',
    '🏃🏼‍♂‍➡' => 'مرد دونده: پوست روشن،‏ به سمت راست',
    '🏃🏽‍♂‍➡' => 'مرد دونده: پوست طلایی،‏ به سمت راست',
    '🏃🏾‍♂‍➡' => 'مرد دونده: پوست گندمی،‏ به سمت راست',
    '🏃🏿‍♂‍➡' => 'مرد دونده: پوست آبنوسی،‏ به سمت راست',
    '🫱🏻‍🫲🏼' => 'دست دادن: پوست سفید،‏ پوست روشن',
    '🫱🏻‍🫲🏽' => 'دست دادن: پوست سفید،‏ پوست طلایی',
    '🫱🏻‍🫲🏾' => 'دست دادن: پوست سفید،‏ پوست گندمی',
    '🫱🏻‍🫲🏿' => 'دست دادن: پوست سفید،‏ پوست آبنوسی',
    '🫱🏼‍🫲🏻' => 'دست دادن: پوست روشن،‏ پوست سفید',
    '🫱🏼‍🫲🏽' => 'دست دادن: پوست روشن،‏ پوست طلایی',
    '🫱🏼‍🫲🏾' => 'دست دادن: پوست روشن،‏ پوست گندمی',
    '🫱🏼‍🫲🏿' => 'دست دادن: پوست روشن،‏ پوست آبنوسی',
    '🫱🏽‍🫲🏻' => 'دست دادن: پوست طلایی،‏ پوست سفید',
    '🫱🏽‍🫲🏼' => 'دست دادن: پوست طلایی،‏ پوست روشن',
    '🫱🏽‍🫲🏾' => 'دست دادن: پوست طلایی،‏ پوست گندمی',
    '🫱🏽‍🫲🏿' => 'دست دادن: پوست طلایی،‏ پوست آبنوسی',
    '🫱🏾‍🫲🏻' => 'دست دادن: پوست گندمی،‏ پوست سفید',
    '🫱🏾‍🫲🏼' => 'دست دادن: پوست گندمی،‏ پوست روشن',
    '🫱🏾‍🫲🏽' => 'دست دادن: پوست گندمی،‏ پوست طلایی',
    '🫱🏾‍🫲🏿' => 'دست دادن: پوست گندمی،‏ پوست آبنوسی',
    '🫱🏿‍🫲🏻' => 'دست دادن: پوست آبنوسی،‏ پوست سفید',
    '🫱🏿‍🫲🏼' => 'دست دادن: پوست آبنوسی،‏ پوست روشن',
    '🫱🏿‍🫲🏽' => 'دست دادن: پوست آبنوسی،‏ پوست طلایی',
    '🫱🏿‍🫲🏾' => 'دست دادن: پوست آبنوسی،‏ پوست گندمی',
    '🚶‍♀‍➡' => 'زن پیاده‌روی می‌کند: به سمت راست',
    '🚶‍♂‍➡' => 'مرد پیاده‌روی می‌کند: به سمت راست',
    '🧎‍♀‍➡' => 'زن زانوزده: به سمت راست',
    '🧎‍♂‍➡' => 'مرد زانوزده: به سمت راست',
    '🧑‍🦯‍➡' => 'شخصی با عصای راهنما: به سمت راست',
    '👨‍🦯‍➡' => 'مرد با عصای سفید: به سمت راست',
    '👩‍🦯‍➡' => 'زن با عصای سفید: به سمت راست',
    '🧑‍🦼‍➡' => 'شخصی با صندلی چرخ‌دار موتوری: به سمت راست',
    '👨‍🦼‍➡' => 'مرد در صندلی چرخ‌دار برقی: به سمت راست',
    '👩‍🦼‍➡' => 'زن در صندلی چرخ‌دار برقی: به سمت راست',
    '🧑‍🦽‍➡' => 'شخصی با صندلی چرخ‌دار دستی: به سمت راست',
    '👨‍🦽‍➡' => 'مرد در صندلی چرخ‌دار دستی: به سمت راست',
    '👩‍🦽‍➡' => 'زن در صندلی چرخ‌دار دستی: به سمت راست',
    '🏃‍♀‍➡' => 'زن دونده: به سمت راست',
    '🏃‍♂‍➡' => 'مرد دونده: به سمت راست',
    '👩‍❤‍👨' => 'زوج عاشق: زن،‏ مرد',
    '👨‍❤‍👨' => 'زوج عاشق: مرد،‏ مرد',
    '👩‍❤‍👩' => 'زوج عاشق: زن،‏ زن',
    '👨‍👩‍👦' => 'خانواده: مرد،‏ زن، و پسر',
    '👨‍👩‍👧' => 'خانواده: مرد،‏ زن، و دختر',
    '👨‍👨‍👦' => 'خانواده: مرد،‏ مرد، و پسر',
    '👨‍👨‍👧' => 'خانواده: مرد،‏ مرد، و دختر',
    '👩‍👩‍👦' => 'خانواده: زن،‏ زن، و پسر',
    '👩‍👩‍👧' => 'خانواده: زن،‏ زن، و دختر',
    '👨‍👦‍👦' => 'خانواده: مرد،‏ پسر، و پسر',
    '👨‍👧‍👦' => 'خانواده: مرد،‏ دختر، و پسر',
    '👨‍👧‍👧' => 'خانواده: مرد،‏ دختر، و دختر',
    '👩‍👦‍👦' => 'خانواده: زن،‏ پسر، و پسر',
    '👩‍👧‍👦' => 'خانواده: زن،‏ دختر، و پسر',
    '👩‍👧‍👧' => 'خانواده: زن،‏ دختر، و دختر',
    '🧑‍🤝‍🧑' => 'اشخاصی دست در دست هم',
    '🧑‍🧑‍🧒' => 'خانواده: بزرگسال، بالغ، کودک',
    '🧑‍🧒‍🧒' => 'خانواده: بزرگسال، کودک، فرزند',
    '🧑🏻‍🦰' => 'شخص: پوست سفید،‏ موقرمز',
    '🧑🏼‍🦰' => 'شخص: پوست روشن،‏ موقرمز',
    '🧑🏽‍🦰' => 'شخص: پوست طلایی،‏ موقرمز',
    '🧑🏾‍🦰' => 'شخص: پوست گندمی،‏ موقرمز',
    '🧑🏿‍🦰' => 'شخص: پوست آبنوسی،‏ موقرمز',
    '🧑🏻‍🦱' => 'شخص: پوست سفید،‏ موفرفری',
    '🧑🏼‍🦱' => 'شخص: پوست روشن،‏ موفرفری',
    '🧑🏽‍🦱' => 'شخص: پوست طلایی،‏ موفرفری',
    '🧑🏾‍🦱' => 'شخص: پوست گندمی،‏ موفرفری',
    '🧑🏿‍🦱' => 'شخص: پوست آبنوسی،‏ موفرفری',
    '🧑🏻‍🦳' => 'شخص: پوست سفید،‏ موسفید',
    '🧑🏼‍🦳' => 'شخص: پوست روشن،‏ موسفید',
    '🧑🏽‍🦳' => 'شخص: پوست طلایی،‏ موسفید',
    '🧑🏾‍🦳' => 'شخص: پوست گندمی،‏ موسفید',
    '🧑🏿‍🦳' => 'شخص: پوست آبنوسی،‏ موسفید',
    '🧑🏻‍🦲' => 'شخص: پوست سفید،‏ تاس',
    '🧑🏼‍🦲' => 'شخص: پوست روشن،‏ تاس',
    '🧑🏽‍🦲' => 'شخص: پوست طلایی،‏ تاس',
    '🧑🏾‍🦲' => 'شخص: پوست گندمی،‏ تاس',
    '🧑🏿‍🦲' => 'شخص: پوست آبنوسی،‏ تاس',
    '🧑🏻‍🩰' => 'رقصنده باله: پوست سفید',
    '🧑🏼‍🩰' => 'رقصنده باله: پوست روشن',
    '🧑🏽‍🩰' => 'رقصنده باله: پوست طلایی',
    '🧑🏾‍🩰' => 'رقصنده باله: پوست گندمی',
    '🧑🏿‍🩰' => 'رقصنده باله: پوست آبنوسی',
    '🧔🏻‍♂' => 'مرد: پوست سفید،‏ ریش',
    '🧔🏼‍♂' => 'مرد: پوست روشن،‏ ریش',
    '🧔🏽‍♂' => 'مرد: پوست طلایی،‏ ریش',
    '🧔🏾‍♂' => 'مرد: پوست گندمی،‏ ریش',
    '🧔🏿‍♂' => 'مرد: پوست آبنوسی،‏ ریش',
    '👱🏻‍♂' => 'مرد: پوست سفید،‏ مو بور',
    '👱🏼‍♂' => 'مرد: پوست روشن،‏ مو بور',
    '👱🏽‍♂' => 'مرد: پوست طلایی،‏ مو بور',
    '👱🏾‍♂' => 'مرد: پوست گندمی،‏ مو بور',
    '👱🏿‍♂' => 'مرد: پوست آبنوسی،‏ مو بور',
    '👨🏻‍🦰' => 'مرد: پوست سفید،‏ موقرمز',
    '👨🏼‍🦰' => 'مرد: پوست روشن،‏ موقرمز',
    '👨🏽‍🦰' => 'مرد: پوست طلایی،‏ موقرمز',
    '👨🏾‍🦰' => 'مرد: پوست گندمی،‏ موقرمز',
    '👨🏿‍🦰' => 'مرد: پوست آبنوسی،‏ موقرمز',
    '👨🏻‍🦱' => 'مرد: پوست سفید،‏ موفرفری',
    '👨🏼‍🦱' => 'مرد: پوست روشن،‏ موفرفری',
    '👨🏽‍🦱' => 'مرد: پوست طلایی،‏ موفرفری',
    '👨🏾‍🦱' => 'مرد: پوست گندمی،‏ موفرفری',
    '👨🏿‍🦱' => 'مرد: پوست آبنوسی،‏ موفرفری',
    '👨🏻‍🦳' => 'مرد: پوست سفید،‏ موسفید',
    '👨🏼‍🦳' => 'مرد: پوست روشن،‏ موسفید',
    '👨🏽‍🦳' => 'مرد: پوست طلایی،‏ موسفید',
    '👨🏾‍🦳' => 'مرد: پوست گندمی،‏ موسفید',
    '👨🏿‍🦳' => 'مرد: پوست آبنوسی،‏ موسفید',
    '👨🏻‍🦲' => 'مرد: پوست سفید،‏ تاس',
    '👨🏼‍🦲' => 'مرد: پوست روشن،‏ تاس',
    '👨🏽‍🦲' => 'مرد: پوست طلایی،‏ تاس',
    '👨🏾‍🦲' => 'مرد: پوست گندمی،‏ تاس',
    '👨🏿‍🦲' => 'مرد: پوست آبنوسی،‏ تاس',
    '🧔🏻‍♀' => 'زن: پوست سفید،‏ ریش',
    '🧔🏼‍♀' => 'زن: پوست روشن،‏ ریش',
    '🧔🏽‍♀' => 'زن: پوست طلایی،‏ ریش',
    '🧔🏾‍♀' => 'زن: پوست گندمی،‏ ریش',
    '🧔🏿‍♀' => 'زن: پوست آبنوسی،‏ ریش',
    '👱🏻‍♀' => 'زن: پوست سفید،‏ موبور',
    '👱🏼‍♀' => 'زن: پوست روشن،‏ موبور',
    '👱🏽‍♀' => 'زن: پوست طلایی،‏ موبور',
    '👱🏾‍♀' => 'زن: پوست گندمی،‏ موبور',
    '👱🏿‍♀' => 'زن: پوست آبنوسی،‏ موبور',
    '👩🏻‍🦰' => 'زن: پوست سفید،‏ موقرمز',
    '👩🏼‍🦰' => 'زن: پوست روشن،‏ موقرمز',
    '👩🏽‍🦰' => 'زن: پوست طلایی،‏ موقرمز',
    '👩🏾‍🦰' => 'زن: پوست گندمی،‏ موقرمز',
    '👩🏿‍🦰' => 'زن: پوست آبنوسی،‏ موقرمز',
    '👩🏻‍🦱' => 'زن: پوست سفید،‏ موفرفری',
    '👩🏼‍🦱' => 'زن: پوست روشن،‏ موفرفری',
    '👩🏽‍🦱' => 'زن: پوست طلایی،‏ موفرفری',
    '👩🏾‍🦱' => 'زن: پوست گندمی،‏ موفرفری',
    '👩🏿‍🦱' => 'زن: پوست آبنوسی،‏ موفرفری',
    '👩🏻‍🦳' => 'زن: پوست سفید،‏ موسفید',
    '👩🏼‍🦳' => 'زن: پوست روشن،‏ موسفید',
    '👩🏽‍🦳' => 'زن: پوست طلایی،‏ موسفید',
    '👩🏾‍🦳' => 'زن: پوست گندمی،‏ موسفید',
    '👩🏿‍🦳' => 'زن: پوست آبنوسی،‏ موسفید',
    '👩🏻‍🦲' => 'زن: پوست سفید،‏ تاس',
    '👩🏼‍🦲' => 'زن: پوست روشن،‏ تاس',
    '👩🏽‍🦲' => 'زن: پوست طلایی،‏ تاس',
    '👩🏾‍🦲' => 'زن: پوست گندمی،‏ تاس',
    '👩🏿‍🦲' => 'زن: پوست آبنوسی،‏ تاس',
    '🙍🏻‍♂' => 'مرد اخم می‌کند: پوست سفید',
    '🙍🏼‍♂' => 'مرد اخم می‌کند: پوست روشن',
    '🙍🏽‍♂' => 'مرد اخم می‌کند: پوست طلایی',
    '🙍🏾‍♂' => 'مرد اخم می‌کند: پوست گندمی',
    '🙍🏿‍♂' => 'مرد اخم می‌کند: پوست آبنوسی',
    '🙍🏻‍♀' => 'زن اخم می‌کند: پوست سفید',
    '🙍🏼‍♀' => 'زن اخم می‌کند: پوست روشن',
    '🙍🏽‍♀' => 'زن اخم می‌کند: پوست طلایی',
    '🙍🏾‍♀' => 'زن اخم می‌کند: پوست گندمی',
    '🙍🏿‍♀' => 'زن اخم می‌کند: پوست آبنوسی',
    '🙎🏻‍♂' => 'مرد اخم‌وتخم می‌کند: پوست سفید',
    '🙎🏼‍♂' => 'مرد اخم‌وتخم می‌کند: پوست روشن',
    '🙎🏽‍♂' => 'مرد اخم‌وتخم می‌کند: پوست طلایی',
    '🙎🏾‍♂' => 'مرد اخم‌وتخم می‌کند: پوست گندمی',
    '🙎🏿‍♂' => 'مرد اخم‌وتخم می‌کند: پوست آبنوسی',
    '🙎🏻‍♀' => 'زن اخم‌وتخم می‌کند: پوست سفید',
    '🙎🏼‍♀' => 'زن اخم‌وتخم می‌کند: پوست روشن',
    '🙎🏽‍♀' => 'زن اخم‌وتخم می‌کند: پوست طلایی',
    '🙎🏾‍♀' => 'زن اخم‌وتخم می‌کند: پوست گندمی',
    '🙎🏿‍♀' => 'زن اخم‌وتخم می‌کند: پوست آبنوسی',
    '🙅🏻‍♂' => 'مرد نمی‌پذیرد: پوست سفید',
    '🙅🏼‍♂' => 'مرد نمی‌پذیرد: پوست روشن',
    '🙅🏽‍♂' => 'مرد نمی‌پذیرد: پوست طلایی',
    '🙅🏾‍♂' => 'مرد نمی‌پذیرد: پوست گندمی',
    '🙅🏿‍♂' => 'مرد نمی‌پذیرد: پوست آبنوسی',
    '🙅🏻‍♀' => 'زن نمی‌پذیرد: پوست سفید',
    '🙅🏼‍♀' => 'زن نمی‌پذیرد: پوست روشن',
    '🙅🏽‍♀' => 'زن نمی‌پذیرد: پوست طلایی',
    '🙅🏾‍♀' => 'زن نمی‌پذیرد: پوست گندمی',
    '🙅🏿‍♀' => 'زن نمی‌پذیرد: پوست آبنوسی',
    '🙆🏻‍♂' => 'مرد می‌پذیرد: پوست سفید',
    '🙆🏼‍♂' => 'مرد می‌پذیرد: پوست روشن',
    '🙆🏽‍♂' => 'مرد می‌پذیرد: پوست طلایی',
    '🙆🏾‍♂' => 'مرد می‌پذیرد: پوست گندمی',
    '🙆🏿‍♂' => 'مرد می‌پذیرد: پوست آبنوسی',
    '🙆🏻‍♀' => 'زن می‌پذیرد: پوست سفید',
    '🙆🏼‍♀' => 'زن می‌پذیرد: پوست روشن',
    '🙆🏽‍♀' => 'زن می‌پذیرد: پوست طلایی',
    '🙆🏾‍♀' => 'زن می‌پذیرد: پوست گندمی',
    '🙆🏿‍♀' => 'زن می‌پذیرد: پوست آبنوسی',
    '💁🏻‍♂' => 'مرد کمک می‌کند: پوست سفید',
    '💁🏼‍♂' => 'مرد کمک می‌کند: پوست روشن',
    '💁🏽‍♂' => 'مرد کمک می‌کند: پوست طلایی',
    '💁🏾‍♂' => 'مرد کمک می‌کند: پوست گندمی',
    '💁🏿‍♂' => 'مرد کمک می‌کند: پوست آبنوسی',
    '💁🏻‍♀' => 'زن کمک می‌کند: پوست سفید',
    '💁🏼‍♀' => 'زن کمک می‌کند: پوست روشن',
    '💁🏽‍♀' => 'زن کمک می‌کند: پوست طلایی',
    '💁🏾‍♀' => 'زن کمک می‌کند: پوست گندمی',
    '💁🏿‍♀' => 'زن کمک می‌کند: پوست آبنوسی',
    '🙋🏻‍♂' => 'مرد دستش را بالا می‌برد: پوست سفید',
    '🙋🏼‍♂' => 'مرد دستش را بالا می‌برد: پوست روشن',
    '🙋🏽‍♂' => 'مرد دستش را بالا می‌برد: پوست طلایی',
    '🙋🏾‍♂' => 'مرد دستش را بالا می‌برد: پوست گندمی',
    '🙋🏿‍♂' => 'مرد دستش را بالا می‌برد: پوست آبنوسی',
    '🙋🏻‍♀' => 'زن دستش را بالا می‌برد: پوست سفید',
    '🙋🏼‍♀' => 'زن دستش را بالا می‌برد: پوست روشن',
    '🙋🏽‍♀' => 'زن دستش را بالا می‌برد: پوست طلایی',
    '🙋🏾‍♀' => 'زن دستش را بالا می‌برد: پوست گندمی',
    '🙋🏿‍♀' => 'زن دستش را بالا می‌برد: پوست آبنوسی',
    '🧏🏻‍♂' => 'مرد ناشنوا: پوست سفید',
    '🧏🏼‍♂' => 'مرد ناشنوا: پوست روشن',
    '🧏🏽‍♂' => 'مرد ناشنوا: پوست طلایی',
    '🧏🏾‍♂' => 'مرد ناشنوا: پوست گندمی',
    '🧏🏿‍♂' => 'مرد ناشنوا: پوست آبنوسی',
    '🧏🏻‍♀' => 'زن ناشنوا: پوست سفید',
    '🧏🏼‍♀' => 'زن ناشنوا: پوست روشن',
    '🧏🏽‍♀' => 'زن ناشنوا: پوست طلایی',
    '🧏🏾‍♀' => 'زن ناشنوا: پوست گندمی',
    '🧏🏿‍♀' => 'زن ناشنوا: پوست آبنوسی',
    '🙇🏻‍♂' => 'مرد تعظیم می‌کند: پوست سفید',
    '🙇🏼‍♂' => 'مرد تعظیم می‌کند: پوست روشن',
    '🙇🏽‍♂' => 'مرد تعظیم می‌کند: پوست طلایی',
    '🙇🏾‍♂' => 'مرد تعظیم می‌کند: پوست گندمی',
    '🙇🏿‍♂' => 'مرد تعظیم می‌کند: پوست آبنوسی',
    '🙇🏻‍♀' => 'زن تعظیم می‌کند: پوست سفید',
    '🙇🏼‍♀' => 'زن تعظیم می‌کند: پوست روشن',
    '🙇🏽‍♀' => 'زن تعظیم می‌کند: پوست طلایی',
    '🙇🏾‍♀' => 'زن تعظیم می‌کند: پوست گندمی',
    '🙇🏿‍♀' => 'زن تعظیم می‌کند: پوست آبنوسی',
    '🤦🏻‍♂' => 'مرد با کف دست به پیشانی می‌زند: پوست سفید',
    '🤦🏼‍♂' => 'مرد با کف دست به پیشانی می‌زند: پوست روشن',
    '🤦🏽‍♂' => 'مرد با کف دست به پیشانی می‌زند: پوست طلایی',
    '🤦🏾‍♂' => 'مرد با کف دست به پیشانی می‌زند: پوست گندمی',
    '🤦🏿‍♂' => 'مرد با کف دست به پیشانی می‌زند: پوست آبنوسی',
    '🤦🏻‍♀' => 'زن با کف دست به پیشانی می‌زند: پوست سفید',
    '🤦🏼‍♀' => 'زن با کف دست به پیشانی می‌زند: پوست روشن',
    '🤦🏽‍♀' => 'زن با کف دست به پیشانی می‌زند: پوست طلایی',
    '🤦🏾‍♀' => 'زن با کف دست به پیشانی می‌زند: پوست گندمی',
    '🤦🏿‍♀' => 'زن با کف دست به پیشانی می‌زند: پوست آبنوسی',
    '🤷🏻‍♂' => 'مرد شانه بالا می‌اندازد: پوست سفید',
    '🤷🏼‍♂' => 'مرد شانه بالا می‌اندازد: پوست روشن',
    '🤷🏽‍♂' => 'مرد شانه بالا می‌اندازد: پوست طلایی',
    '🤷🏾‍♂' => 'مرد شانه بالا می‌اندازد: پوست گندمی',
    '🤷🏿‍♂' => 'مرد شانه بالا می‌اندازد: پوست آبنوسی',
    '🤷🏻‍♀' => 'زن شانه بالا می‌اندازد: پوست سفید',
    '🤷🏼‍♀' => 'زن شانه بالا می‌اندازد: پوست روشن',
    '🤷🏽‍♀' => 'زن شانه بالا می‌اندازد: پوست طلایی',
    '🤷🏾‍♀' => 'زن شانه بالا می‌اندازد: پوست گندمی',
    '🤷🏿‍♀' => 'زن شانه بالا می‌اندازد: پوست آبنوسی',
    '🧑🏻‍⚕' => 'مأمور بهداشت: پوست سفید',
    '🧑🏼‍⚕' => 'مأمور بهداشت: پوست روشن',
    '🧑🏽‍⚕' => 'مأمور بهداشت: پوست طلایی',
    '🧑🏾‍⚕' => 'مأمور بهداشت: پوست گندمی',
    '🧑🏿‍⚕' => 'مأمور بهداشت: پوست آبنوسی',
    '👨🏻‍⚕' => 'مددکار بهداشت مرد: پوست سفید',
    '👨🏼‍⚕' => 'مددکار بهداشت مرد: پوست روشن',
    '👨🏽‍⚕' => 'مددکار بهداشت مرد: پوست طلایی',
    '👨🏾‍⚕' => 'مددکار بهداشت مرد: پوست گندمی',
    '👨🏿‍⚕' => 'مددکار بهداشت مرد: پوست آبنوسی',
    '👩🏻‍⚕' => 'مددکار بهداشت زن: پوست سفید',
    '👩🏼‍⚕' => 'مددکار بهداشت زن: پوست روشن',
    '👩🏽‍⚕' => 'مددکار بهداشت زن: پوست طلایی',
    '👩🏾‍⚕' => 'مددکار بهداشت زن: پوست گندمی',
    '👩🏿‍⚕' => 'مددکار بهداشت زن: پوست آبنوسی',
    '🧑🏻‍🎓' => 'دانش‌آموز: پوست سفید',
    '🧑🏼‍🎓' => 'دانش‌آموز: پوست روشن',
    '🧑🏽‍🎓' => 'دانش‌آموز: پوست طلایی',
    '🧑🏾‍🎓' => 'دانش‌آموز: پوست گندمی',
    '🧑🏿‍🎓' => 'دانش‌آموز: پوست آبنوسی',
    '👨🏻‍🎓' => 'دانشجوی مرد: پوست سفید',
    '👨🏼‍🎓' => 'دانشجوی مرد: پوست روشن',
    '👨🏽‍🎓' => 'دانشجوی مرد: پوست طلایی',
    '👨🏾‍🎓' => 'دانشجوی مرد: پوست گندمی',
    '👨🏿‍🎓' => 'دانشجوی مرد: پوست آبنوسی',
    '👩🏻‍🎓' => 'دانشجوی زن: پوست سفید',
    '👩🏼‍🎓' => 'دانشجوی زن: پوست روشن',
    '👩🏽‍🎓' => 'دانشجوی زن: پوست طلایی',
    '👩🏾‍🎓' => 'دانشجوی زن: پوست گندمی',
    '👩🏿‍🎓' => 'دانشجوی زن: پوست آبنوسی',
    '🧑🏻‍🏫' => 'معلم: پوست سفید',
    '🧑🏼‍🏫' => 'معلم: پوست روشن',
    '🧑🏽‍🏫' => 'معلم: پوست طلایی',
    '🧑🏾‍🏫' => 'معلم: پوست گندمی',
    '🧑🏿‍🏫' => 'معلم: پوست آبنوسی',
    '👨🏻‍🏫' => 'آموزگار مرد: پوست سفید',
    '👨🏼‍🏫' => 'آموزگار مرد: پوست روشن',
    '👨🏽‍🏫' => 'آموزگار مرد: پوست طلایی',
    '👨🏾‍🏫' => 'آموزگار مرد: پوست گندمی',
    '👨🏿‍🏫' => 'آموزگار مرد: پوست آبنوسی',
    '👩🏻‍🏫' => 'آموزگار زن: پوست سفید',
    '👩🏼‍🏫' => 'آموزگار زن: پوست روشن',
    '👩🏽‍🏫' => 'آموزگار زن: پوست طلایی',
    '👩🏾‍🏫' => 'آموزگار زن: پوست گندمی',
    '👩🏿‍🏫' => 'آموزگار زن: پوست آبنوسی',
    '🧑🏻‍⚖' => 'قاضی: پوست سفید',
    '🧑🏼‍⚖' => 'قاضی: پوست روشن',
    '🧑🏽‍⚖' => 'قاضی: پوست طلایی',
    '🧑🏾‍⚖' => 'قاضی: پوست گندمی',
    '🧑🏿‍⚖' => 'قاضی: پوست آبنوسی',
    '👨🏻‍⚖' => 'قاضی مرد: پوست سفید',
    '👨🏼‍⚖' => 'قاضی مرد: پوست روشن',
    '👨🏽‍⚖' => 'قاضی مرد: پوست طلایی',
    '👨🏾‍⚖' => 'قاضی مرد: پوست گندمی',
    '👨🏿‍⚖' => 'قاضی مرد: پوست آبنوسی',
    '👩🏻‍⚖' => 'قاضی زن: پوست سفید',
    '👩🏼‍⚖' => 'قاضی زن: پوست روشن',
    '👩🏽‍⚖' => 'قاضی زن: پوست طلایی',
    '👩🏾‍⚖' => 'قاضی زن: پوست گندمی',
    '👩🏿‍⚖' => 'قاضی زن: پوست آبنوسی',
    '🧑🏻‍🌾' => 'کشاورز: پوست سفید',
    '🧑🏼‍🌾' => 'کشاورز: پوست روشن',
    '🧑🏽‍🌾' => 'کشاورز: پوست طلایی',
    '🧑🏾‍🌾' => 'کشاورز: پوست گندمی',
    '🧑🏿‍🌾' => 'کشاورز: پوست آبنوسی',
    '👨🏻‍🌾' => 'کشاورز مرد: پوست سفید',
    '👨🏼‍🌾' => 'کشاورز مرد: پوست روشن',
    '👨🏽‍🌾' => 'کشاورز مرد: پوست طلایی',
    '👨🏾‍🌾' => 'کشاورز مرد: پوست گندمی',
    '👨🏿‍🌾' => 'کشاورز مرد: پوست آبنوسی',
    '👩🏻‍🌾' => 'کشاورز زن: پوست سفید',
    '👩🏼‍🌾' => 'کشاورز زن: پوست روشن',
    '👩🏽‍🌾' => 'کشاورز زن: پوست طلایی',
    '👩🏾‍🌾' => 'کشاورز زن: پوست گندمی',
    '👩🏿‍🌾' => 'کشاورز زن: پوست آبنوسی',
    '🧑🏻‍🍳' => 'آشپز: پوست سفید',
    '🧑🏼‍🍳' => 'آشپز: پوست روشن',
    '🧑🏽‍🍳' => 'آشپز: پوست طلایی',
    '🧑🏾‍🍳' => 'آشپز: پوست گندمی',
    '🧑🏿‍🍳' => 'آشپز: پوست آبنوسی',
    '👨🏻‍🍳' => 'آشپز مرد: پوست سفید',
    '👨🏼‍🍳' => 'آشپز مرد: پوست روشن',
    '👨🏽‍🍳' => 'آشپز مرد: پوست طلایی',
    '👨🏾‍🍳' => 'آشپز مرد: پوست گندمی',
    '👨🏿‍🍳' => 'آشپز مرد: پوست آبنوسی',
    '👩🏻‍🍳' => 'آشپز زن: پوست سفید',
    '👩🏼‍🍳' => 'آشپز زن: پوست روشن',
    '👩🏽‍🍳' => 'آشپز زن: پوست طلایی',
    '👩🏾‍🍳' => 'آشپز زن: پوست گندمی',
    '👩🏿‍🍳' => 'آشپز زن: پوست آبنوسی',
    '🧑🏻‍🔧' => 'مکانیک: پوست سفید',
    '🧑🏼‍🔧' => 'مکانیک: پوست روشن',
    '🧑🏽‍🔧' => 'مکانیک: پوست طلایی',
    '🧑🏾‍🔧' => 'مکانیک: پوست گندمی',
    '🧑🏿‍🔧' => 'مکانیک: پوست آبنوسی',
    '👨🏻‍🔧' => 'تعمیرکار مرد: پوست سفید',
    '👨🏼‍🔧' => 'تعمیرکار مرد: پوست روشن',
    '👨🏽‍🔧' => 'تعمیرکار مرد: پوست طلایی',
    '👨🏾‍🔧' => 'تعمیرکار مرد: پوست گندمی',
    '👨🏿‍🔧' => 'تعمیرکار مرد: پوست آبنوسی',
    '👩🏻‍🔧' => 'تعمیرکار زن: پوست سفید',
    '👩🏼‍🔧' => 'تعمیرکار زن: پوست روشن',
    '👩🏽‍🔧' => 'تعمیرکار زن: پوست طلایی',
    '👩🏾‍🔧' => 'تعمیرکار زن: پوست گندمی',
    '👩🏿‍🔧' => 'تعمیرکار زن: پوست آبنوسی',
    '🧑🏻‍🏭' => 'کارگر کارخانه: پوست سفید',
    '🧑🏼‍🏭' => 'کارگر کارخانه: پوست روشن',
    '🧑🏽‍🏭' => 'کارگر کارخانه: پوست طلایی',
    '🧑🏾‍🏭' => 'کارگر کارخانه: پوست گندمی',
    '🧑🏿‍🏭' => 'کارگر کارخانه: پوست آبنوسی',
    '👨🏻‍🏭' => 'کارگر کارخانه مرد: پوست سفید',
    '👨🏼‍🏭' => 'کارگر کارخانه مرد: پوست روشن',
    '👨🏽‍🏭' => 'کارگر کارخانه مرد: پوست طلایی',
    '👨🏾‍🏭' => 'کارگر کارخانه مرد: پوست گندمی',
    '👨🏿‍🏭' => 'کارگر کارخانه مرد: پوست آبنوسی',
    '👩🏻‍🏭' => 'کارگر کارخانه زن: پوست سفید',
    '👩🏼‍🏭' => 'کارگر کارخانه زن: پوست روشن',
    '👩🏽‍🏭' => 'کارگر کارخانه زن: پوست طلایی',
    '👩🏾‍🏭' => 'کارگر کارخانه زن: پوست گندمی',
    '👩🏿‍🏭' => 'کارگر کارخانه زن: پوست آبنوسی',
    '🧑🏻‍💼' => 'کارمند: پوست سفید',
    '🧑🏼‍💼' => 'کارمند: پوست روشن',
    '🧑🏽‍💼' => 'کارمند: پوست طلایی',
    '🧑🏾‍💼' => 'کارمند: پوست گندمی',
    '🧑🏿‍💼' => 'کارمند: پوست آبنوسی',
    '👨🏻‍💼' => 'کارمند مرد: پوست سفید',
    '👨🏼‍💼' => 'کارمند مرد: پوست روشن',
    '👨🏽‍💼' => 'کارمند مرد: پوست طلایی',
    '👨🏾‍💼' => 'کارمند مرد: پوست گندمی',
    '👨🏿‍💼' => 'کارمند مرد: پوست آبنوسی',
    '👩🏻‍💼' => 'کارمند زن: پوست سفید',
    '👩🏼‍💼' => 'کارمند زن: پوست روشن',
    '👩🏽‍💼' => 'کارمند زن: پوست طلایی',
    '👩🏾‍💼' => 'کارمند زن: پوست گندمی',
    '👩🏿‍💼' => 'کارمند زن: پوست آبنوسی',
    '🧑🏻‍🔬' => 'دانشمند: پوست سفید',
    '🧑🏼‍🔬' => 'دانشمند: پوست روشن',
    '🧑🏽‍🔬' => 'دانشمند: پوست طلایی',
    '🧑🏾‍🔬' => 'دانشمند: پوست گندمی',
    '🧑🏿‍🔬' => 'دانشمند: پوست آبنوسی',
    '👨🏻‍🔬' => 'دانشمند مرد: پوست سفید',
    '👨🏼‍🔬' => 'دانشمند مرد: پوست روشن',
    '👨🏽‍🔬' => 'دانشمند مرد: پوست طلایی',
    '👨🏾‍🔬' => 'دانشمند مرد: پوست گندمی',
    '👨🏿‍🔬' => 'دانشمند مرد: پوست آبنوسی',
    '👩🏻‍🔬' => 'دانشمند زن: پوست سفید',
    '👩🏼‍🔬' => 'دانشمند زن: پوست روشن',
    '👩🏽‍🔬' => 'دانشمند زن: پوست طلایی',
    '👩🏾‍🔬' => 'دانشمند زن: پوست گندمی',
    '👩🏿‍🔬' => 'دانشمند زن: پوست آبنوسی',
    '🧑🏻‍💻' => 'متخصص: پوست سفید',
    '🧑🏼‍💻' => 'متخصص: پوست روشن',
    '🧑🏽‍💻' => 'متخصص: پوست طلایی',
    '🧑🏾‍💻' => 'متخصص: پوست گندمی',
    '🧑🏿‍💻' => 'متخصص: پوست آبنوسی',
    '👨🏻‍💻' => 'کارشناس فناوری مرد: پوست سفید',
    '👨🏼‍💻' => 'کارشناس فناوری مرد: پوست روشن',
    '👨🏽‍💻' => 'کارشناس فناوری مرد: پوست طلایی',
    '👨🏾‍💻' => 'کارشناس فناوری مرد: پوست گندمی',
    '👨🏿‍💻' => 'کارشناس فناوری مرد: پوست آبنوسی',
    '👩🏻‍💻' => 'کارشناس فناوری زن: پوست سفید',
    '👩🏼‍💻' => 'کارشناس فناوری زن: پوست روشن',
    '👩🏽‍💻' => 'کارشناس فناوری زن: پوست طلایی',
    '👩🏾‍💻' => 'کارشناس فناوری زن: پوست گندمی',
    '👩🏿‍💻' => 'کارشناس فناوری زن: پوست آبنوسی',
    '🧑🏻‍🎤' => 'خواننده: پوست سفید',
    '🧑🏼‍🎤' => 'خواننده: پوست روشن',
    '🧑🏽‍🎤' => 'خواننده: پوست طلایی',
    '🧑🏾‍🎤' => 'خواننده: پوست گندمی',
    '🧑🏿‍🎤' => 'خواننده: پوست آبنوسی',
    '👨🏻‍🎤' => 'خواننده مرد: پوست سفید',
    '👨🏼‍🎤' => 'خواننده مرد: پوست روشن',
    '👨🏽‍🎤' => 'خواننده مرد: پوست طلایی',
    '👨🏾‍🎤' => 'خواننده مرد: پوست گندمی',
    '👨🏿‍🎤' => 'خواننده مرد: پوست آبنوسی',
    '👩🏻‍🎤' => 'خواننده زن: پوست سفید',
    '👩🏼‍🎤' => 'خواننده زن: پوست روشن',
    '👩🏽‍🎤' => 'خواننده زن: پوست طلایی',
    '👩🏾‍🎤' => 'خواننده زن: پوست گندمی',
    '👩🏿‍🎤' => 'خواننده زن: پوست آبنوسی',
    '🧑🏻‍🎨' => 'هنرمند: پوست سفید',
    '🧑🏼‍🎨' => 'هنرمند: پوست روشن',
    '🧑🏽‍🎨' => 'هنرمند: پوست طلایی',
    '🧑🏾‍🎨' => 'هنرمند: پوست گندمی',
    '🧑🏿‍🎨' => 'هنرمند: پوست آبنوسی',
    '👨🏻‍🎨' => 'هنرمند مرد: پوست سفید',
    '👨🏼‍🎨' => 'هنرمند مرد: پوست روشن',
    '👨🏽‍🎨' => 'هنرمند مرد: پوست طلایی',
    '👨🏾‍🎨' => 'هنرمند مرد: پوست گندمی',
    '👨🏿‍🎨' => 'هنرمند مرد: پوست آبنوسی',
    '👩🏻‍🎨' => 'هنرمند زن: پوست سفید',
    '👩🏼‍🎨' => 'هنرمند زن: پوست روشن',
    '👩🏽‍🎨' => 'هنرمند زن: پوست طلایی',
    '👩🏾‍🎨' => 'هنرمند زن: پوست گندمی',
    '👩🏿‍🎨' => 'هنرمند زن: پوست آبنوسی',
    '🧑🏻‍✈' => 'خلبان: پوست سفید',
    '🧑🏼‍✈' => 'خلبان: پوست روشن',
    '🧑🏽‍✈' => 'خلبان: پوست طلایی',
    '🧑🏾‍✈' => 'خلبان: پوست گندمی',
    '🧑🏿‍✈' => 'خلبان: پوست آبنوسی',
    '👨🏻‍✈' => 'خلبان مرد: پوست سفید',
    '👨🏼‍✈' => 'خلبان مرد: پوست روشن',
    '👨🏽‍✈' => 'خلبان مرد: پوست طلایی',
    '👨🏾‍✈' => 'خلبان مرد: پوست گندمی',
    '👨🏿‍✈' => 'خلبان مرد: پوست آبنوسی',
    '👩🏻‍✈' => 'خلبان زن: پوست سفید',
    '👩🏼‍✈' => 'خلبان زن: پوست روشن',
    '👩🏽‍✈' => 'خلبان زن: پوست طلایی',
    '👩🏾‍✈' => 'خلبان زن: پوست گندمی',
    '👩🏿‍✈' => 'خلبان زن: پوست آبنوسی',
    '🧑🏻‍🚀' => 'فضانورد: پوست سفید',
    '🧑🏼‍🚀' => 'فضانورد: پوست روشن',
    '🧑🏽‍🚀' => 'فضانورد: پوست طلایی',
    '🧑🏾‍🚀' => 'فضانورد: پوست گندمی',
    '🧑🏿‍🚀' => 'فضانورد: پوست آبنوسی',
    '👨🏻‍🚀' => 'فضانورد مرد: پوست سفید',
    '👨🏼‍🚀' => 'فضانورد مرد: پوست روشن',
    '👨🏽‍🚀' => 'فضانورد مرد: پوست طلایی',
    '👨🏾‍🚀' => 'فضانورد مرد: پوست گندمی',
    '👨🏿‍🚀' => 'فضانورد مرد: پوست آبنوسی',
    '👩🏻‍🚀' => 'فضانورد زن: پوست سفید',
    '👩🏼‍🚀' => 'فضانورد زن: پوست روشن',
    '👩🏽‍🚀' => 'فضانورد زن: پوست طلایی',
    '👩🏾‍🚀' => 'فضانورد زن: پوست گندمی',
    '👩🏿‍🚀' => 'فضانورد زن: پوست آبنوسی',
    '🧑🏻‍🚒' => 'مأمور آتش‌نشانی: پوست سفید',
    '🧑🏼‍🚒' => 'مأمور آتش‌نشانی: پوست روشن',
    '🧑🏽‍🚒' => 'مأمور آتش‌نشانی: پوست طلایی',
    '🧑🏾‍🚒' => 'مأمور آتش‌نشانی: پوست گندمی',
    '🧑🏿‍🚒' => 'مأمور آتش‌نشانی: پوست آبنوسی',
    '👨🏻‍🚒' => 'آتش‌نشان مرد: پوست سفید',
    '👨🏼‍🚒' => 'آتش‌نشان مرد: پوست روشن',
    '👨🏽‍🚒' => 'آتش‌نشان مرد: پوست طلایی',
    '👨🏾‍🚒' => 'آتش‌نشان مرد: پوست گندمی',
    '👨🏿‍🚒' => 'آتش‌نشان مرد: پوست آبنوسی',
    '👩🏻‍🚒' => 'آتش‌نشان زن: پوست سفید',
    '👩🏼‍🚒' => 'آتش‌نشان زن: پوست روشن',
    '👩🏽‍🚒' => 'آتش‌نشان زن: پوست طلایی',
    '👩🏾‍🚒' => 'آتش‌نشان زن: پوست گندمی',
    '👩🏿‍🚒' => 'آتش‌نشان زن: پوست آبنوسی',
    '👮🏻‍♂' => 'پلیس مرد: پوست سفید',
    '👮🏼‍♂' => 'پلیس مرد: پوست روشن',
    '👮🏽‍♂' => 'پلیس مرد: پوست طلایی',
    '👮🏾‍♂' => 'پلیس مرد: پوست گندمی',
    '👮🏿‍♂' => 'پلیس مرد: پوست آبنوسی',
    '👮🏻‍♀' => 'پلیس زن: پوست سفید',
    '👮🏼‍♀' => 'پلیس زن: پوست روشن',
    '👮🏽‍♀' => 'پلیس زن: پوست طلایی',
    '👮🏾‍♀' => 'پلیس زن: پوست گندمی',
    '👮🏿‍♀' => 'پلیس زن: پوست آبنوسی',
    '🕵🏻‍♂' => 'کارآگاه مرد: پوست سفید',
    '🕵🏼‍♂' => 'کارآگاه مرد: پوست روشن',
    '🕵🏽‍♂' => 'کارآگاه مرد: پوست طلایی',
    '🕵🏾‍♂' => 'کارآگاه مرد: پوست گندمی',
    '🕵🏿‍♂' => 'کارآگاه مرد: پوست آبنوسی',
    '🕵🏻‍♀' => 'کارآگاه زن: پوست سفید',
    '🕵🏼‍♀' => 'کارآگاه زن: پوست روشن',
    '🕵🏽‍♀' => 'کارآگاه زن: پوست طلایی',
    '🕵🏾‍♀' => 'کارآگاه زن: پوست گندمی',
    '🕵🏿‍♀' => 'کارآگاه زن: پوست آبنوسی',
    '💂🏻‍♂' => 'گارد مرد: پوست سفید',
    '💂🏼‍♂' => 'گارد مرد: پوست روشن',
    '💂🏽‍♂' => 'گارد مرد: پوست طلایی',
    '💂🏾‍♂' => 'گارد مرد: پوست گندمی',
    '💂🏿‍♂' => 'گارد مرد: پوست آبنوسی',
    '💂🏻‍♀' => 'گارد زن: پوست سفید',
    '💂🏼‍♀' => 'گارد زن: پوست روشن',
    '💂🏽‍♀' => 'گارد زن: پوست طلایی',
    '💂🏾‍♀' => 'گارد زن: پوست گندمی',
    '💂🏿‍♀' => 'گارد زن: پوست آبنوسی',
    '👷🏻‍♂' => 'کارگر ساختمانی مرد: پوست سفید',
    '👷🏼‍♂' => 'کارگر ساختمانی مرد: پوست روشن',
    '👷🏽‍♂' => 'کارگر ساختمانی مرد: پوست طلایی',
    '👷🏾‍♂' => 'کارگر ساختمانی مرد: پوست گندمی',
    '👷🏿‍♂' => 'کارگر ساختمانی مرد: پوست آبنوسی',
    '👷🏻‍♀' => 'کارگر ساختمانی زن: پوست سفید',
    '👷🏼‍♀' => 'کارگر ساختمانی زن: پوست روشن',
    '👷🏽‍♀' => 'کارگر ساختمانی زن: پوست طلایی',
    '👷🏾‍♀' => 'کارگر ساختمانی زن: پوست گندمی',
    '👷🏿‍♀' => 'کارگر ساختمانی زن: پوست آبنوسی',
    '👳🏻‍♂' => 'مرد با دستار: پوست سفید',
    '👳🏼‍♂' => 'مرد با دستار: پوست روشن',
    '👳🏽‍♂' => 'مرد با دستار: پوست طلایی',
    '👳🏾‍♂' => 'مرد با دستار: پوست گندمی',
    '👳🏿‍♂' => 'مرد با دستار: پوست آبنوسی',
    '👳🏻‍♀' => 'زن با دستار: پوست سفید',
    '👳🏼‍♀' => 'زن با دستار: پوست روشن',
    '👳🏽‍♀' => 'زن با دستار: پوست طلایی',
    '👳🏾‍♀' => 'زن با دستار: پوست گندمی',
    '👳🏿‍♀' => 'زن با دستار: پوست آبنوسی',
    '🤵🏻‍♂' => 'مرد با کت و شلوار و پاپیون: پوست سفید',
    '🤵🏼‍♂' => 'مرد با کت و شلوار و پاپیون: پوست روشن',
    '🤵🏽‍♂' => 'مرد با کت و شلوار و پاپیون: پوست طلایی',
    '🤵🏾‍♂' => 'مرد با کت و شلوار و پاپیون: پوست گندمی',
    '🤵🏿‍♂' => 'مرد با کت و شلوار و پاپیون: پوست آبنوسی',
    '🤵🏻‍♀' => 'زن با کت و شلوار و پاپیون: پوست سفید',
    '🤵🏼‍♀' => 'زن با کت و شلوار و پاپیون: پوست روشن',
    '🤵🏽‍♀' => 'زن با کت و شلوار و پاپیون: پوست طلایی',
    '🤵🏾‍♀' => 'زن با کت و شلوار و پاپیون: پوست گندمی',
    '🤵🏿‍♀' => 'زن با کت و شلوار و پاپیون: پوست آبنوسی',
    '👰🏻‍♂' => 'مرد با تور عروس: پوست سفید',
    '👰🏼‍♂' => 'مرد با تور عروس: پوست روشن',
    '👰🏽‍♂' => 'مرد با تور عروس: پوست طلایی',
    '👰🏾‍♂' => 'مرد با تور عروس: پوست گندمی',
    '👰🏿‍♂' => 'مرد با تور عروس: پوست آبنوسی',
    '👰🏻‍♀' => 'زن با تور عروس: پوست سفید',
    '👰🏼‍♀' => 'زن با تور عروس: پوست روشن',
    '👰🏽‍♀' => 'زن با تور عروس: پوست طلایی',
    '👰🏾‍♀' => 'زن با تور عروس: پوست گندمی',
    '👰🏿‍♀' => 'زن با تور عروس: پوست آبنوسی',
    '👩🏻‍🍼' => 'زنی که به بچه شیر می‌دهد: پوست سفید',
    '👩🏼‍🍼' => 'زنی که به بچه شیر می‌دهد: پوست روشن',
    '👩🏽‍🍼' => 'زنی که به بچه شیر می‌دهد: پوست طلایی',
    '👩🏾‍🍼' => 'زنی که به بچه شیر می‌دهد: پوست گندمی',
    '👩🏿‍🍼' => 'زنی که به بچه شیر می‌دهد: پوست آبنوسی',
    '👨🏻‍🍼' => 'مردی که به بچه شیر می‌دهد: پوست سفید',
    '👨🏼‍🍼' => 'مردی که به بچه شیر می‌دهد: پوست روشن',
    '👨🏽‍🍼' => 'مردی که به بچه شیر می‌دهد: پوست طلایی',
    '👨🏾‍🍼' => 'مردی که به بچه شیر می‌دهد: پوست گندمی',
    '👨🏿‍🍼' => 'مردی که به بچه شیر می‌دهد: پوست آبنوسی',
    '🧑🏻‍🍼' => 'شخصی که به بچه شیر می‌دهد: پوست سفید',
    '🧑🏼‍🍼' => 'شخصی که به بچه شیر می‌دهد: پوست روشن',
    '🧑🏽‍🍼' => 'شخصی که به بچه شیر می‌دهد: پوست طلایی',
    '🧑🏾‍🍼' => 'شخصی که به بچه شیر می‌دهد: پوست گندمی',
    '🧑🏿‍🍼' => 'شخصی که به بچه شیر می‌دهد: پوست آبنوسی',
    '🧑🏻‍🎄' => 'نوئل: پوست سفید',
    '🧑🏼‍🎄' => 'نوئل: پوست روشن',
    '🧑🏽‍🎄' => 'نوئل: پوست طلایی',
    '🧑🏾‍🎄' => 'نوئل: پوست گندمی',
    '🧑🏿‍🎄' => 'نوئل: پوست آبنوسی',
    '🦸🏻‍♂' => 'ابرقهرمان مرد: پوست سفید',
    '🦸🏼‍♂' => 'ابرقهرمان مرد: پوست روشن',
    '🦸🏽‍♂' => 'ابرقهرمان مرد: پوست طلایی',
    '🦸🏾‍♂' => 'ابرقهرمان مرد: پوست گندمی',
    '🦸🏿‍♂' => 'ابرقهرمان مرد: پوست آبنوسی',
    '🦸🏻‍♀' => 'ابرقهرمان زن: پوست سفید',
    '🦸🏼‍♀' => 'ابرقهرمان زن: پوست روشن',
    '🦸🏽‍♀' => 'ابرقهرمان زن: پوست طلایی',
    '🦸🏾‍♀' => 'ابرقهرمان زن: پوست گندمی',
    '🦸🏿‍♀' => 'ابرقهرمان زن: پوست آبنوسی',
    '🦹🏻‍♂' => 'ابرشرور مرد: پوست سفید',
    '🦹🏼‍♂' => 'ابرشرور مرد: پوست روشن',
    '🦹🏽‍♂' => 'ابرشرور مرد: پوست طلایی',
    '🦹🏾‍♂' => 'ابرشرور مرد: پوست گندمی',
    '🦹🏿‍♂' => 'ابرشرور مرد: پوست آبنوسی',
    '🦹🏻‍♀' => 'ابرشرور زن: پوست سفید',
    '🦹🏼‍♀' => 'ابرشرور زن: پوست روشن',
    '🦹🏽‍♀' => 'ابرشرور زن: پوست طلایی',
    '🦹🏾‍♀' => 'ابرشرور زن: پوست گندمی',
    '🦹🏿‍♀' => 'ابرشرور زن: پوست آبنوسی',
    '🧙🏻‍♂' => 'ساحر مرد: پوست سفید',
    '🧙🏼‍♂' => 'ساحر مرد: پوست روشن',
    '🧙🏽‍♂' => 'ساحر مرد: پوست طلایی',
    '🧙🏾‍♂' => 'ساحر مرد: پوست گندمی',
    '🧙🏿‍♂' => 'ساحر مرد: پوست آبنوسی',
    '🧙🏻‍♀' => 'ساحر زن: پوست سفید',
    '🧙🏼‍♀' => 'ساحر زن: پوست روشن',
    '🧙🏽‍♀' => 'ساحر زن: پوست طلایی',
    '🧙🏾‍♀' => 'ساحر زن: پوست گندمی',
    '🧙🏿‍♀' => 'ساحر زن: پوست آبنوسی',
    '🧚🏻‍♂' => 'پری مرد: پوست سفید',
    '🧚🏼‍♂' => 'پری مرد: پوست روشن',
    '🧚🏽‍♂' => 'پری مرد: پوست طلایی',
    '🧚🏾‍♂' => 'پری مرد: پوست گندمی',
    '🧚🏿‍♂' => 'پری مرد: پوست آبنوسی',
    '🧚🏻‍♀' => 'پری زن: پوست سفید',
    '🧚🏼‍♀' => 'پری زن: پوست روشن',
    '🧚🏽‍♀' => 'پری زن: پوست طلایی',
    '🧚🏾‍♀' => 'پری زن: پوست گندمی',
    '🧚🏿‍♀' => 'پری زن: پوست آبنوسی',
    '🧛🏻‍♂' => 'خون‌آشام مرد: پوست سفید',
    '🧛🏼‍♂' => 'خون‌آشام مرد: پوست روشن',
    '🧛🏽‍♂' => 'خون‌آشام مرد: پوست طلایی',
    '🧛🏾‍♂' => 'خون‌آشام مرد: پوست گندمی',
    '🧛🏿‍♂' => 'خون‌آشام مرد: پوست آبنوسی',
    '🧛🏻‍♀' => 'دراکولای زن: پوست سفید',
    '🧛🏼‍♀' => 'دراکولای زن: پوست روشن',
    '🧛🏽‍♀' => 'دراکولای زن: پوست طلایی',
    '🧛🏾‍♀' => 'دراکولای زن: پوست گندمی',
    '🧛🏿‍♀' => 'دراکولای زن: پوست آبنوسی',
    '🧜🏻‍♂' => 'دریامرد: پوست سفید',
    '🧜🏼‍♂' => 'دریامرد: پوست روشن',
    '🧜🏽‍♂' => 'دریامرد: پوست طلایی',
    '🧜🏾‍♂' => 'دریامرد: پوست گندمی',
    '🧜🏿‍♂' => 'دریامرد: پوست آبنوسی',
    '🧜🏻‍♀' => 'پری دریایی: پوست سفید',
    '🧜🏼‍♀' => 'پری دریایی: پوست روشن',
    '🧜🏽‍♀' => 'پری دریایی: پوست طلایی',
    '🧜🏾‍♀' => 'پری دریایی: پوست گندمی',
    '🧜🏿‍♀' => 'پری دریایی: پوست آبنوسی',
    '🧝🏻‍♂' => 'اِلف مرد: پوست سفید',
    '🧝🏼‍♂' => 'اِلف مرد: پوست روشن',
    '🧝🏽‍♂' => 'اِلف مرد: پوست طلایی',
    '🧝🏾‍♂' => 'اِلف مرد: پوست گندمی',
    '🧝🏿‍♂' => 'اِلف مرد: پوست آبنوسی',
    '🧝🏻‍♀' => 'اِلف زن: پوست سفید',
    '🧝🏼‍♀' => 'اِلف زن: پوست روشن',
    '🧝🏽‍♀' => 'اِلف زن: پوست طلایی',
    '🧝🏾‍♀' => 'اِلف زن: پوست گندمی',
    '🧝🏿‍♀' => 'اِلف زن: پوست آبنوسی',
    '💆🏻‍♂' => 'ماساژ صورت مرد: پوست سفید',
    '💆🏼‍♂' => 'ماساژ صورت مرد: پوست روشن',
    '💆🏽‍♂' => 'ماساژ صورت مرد: پوست طلایی',
    '💆🏾‍♂' => 'ماساژ صورت مرد: پوست گندمی',
    '💆🏿‍♂' => 'ماساژ صورت مرد: پوست آبنوسی',
    '💆🏻‍♀' => 'ماساژ صورت زن: پوست سفید',
    '💆🏼‍♀' => 'ماساژ صورت زن: پوست روشن',
    '💆🏽‍♀' => 'ماساژ صورت زن: پوست طلایی',
    '💆🏾‍♀' => 'ماساژ صورت زن: پوست گندمی',
    '💆🏿‍♀' => 'ماساژ صورت زن: پوست آبنوسی',
    '💇🏻‍♂' => 'مرد مو کوتاه می‌کند: پوست سفید',
    '💇🏼‍♂' => 'مرد مو کوتاه می‌کند: پوست روشن',
    '💇🏽‍♂' => 'مرد مو کوتاه می‌کند: پوست طلایی',
    '💇🏾‍♂' => 'مرد مو کوتاه می‌کند: پوست گندمی',
    '💇🏿‍♂' => 'مرد مو کوتاه می‌کند: پوست آبنوسی',
    '💇🏻‍♀' => 'زن مو کوتاه می‌کند: پوست سفید',
    '💇🏼‍♀' => 'زن مو کوتاه می‌کند: پوست روشن',
    '💇🏽‍♀' => 'زن مو کوتاه می‌کند: پوست طلایی',
    '💇🏾‍♀' => 'زن مو کوتاه می‌کند: پوست گندمی',
    '💇🏿‍♀' => 'زن مو کوتاه می‌کند: پوست آبنوسی',
    '🚶🏻‍♂' => 'مرد پیاده‌روی می‌کند: پوست سفید',
    '🚶🏼‍♂' => 'مرد پیاده‌روی می‌کند: پوست روشن',
    '🚶🏽‍♂' => 'مرد پیاده‌روی می‌کند: پوست طلایی',
    '🚶🏾‍♂' => 'مرد پیاده‌روی می‌کند: پوست گندمی',
    '🚶🏿‍♂' => 'مرد پیاده‌روی می‌کند: پوست آبنوسی',
    '🚶🏻‍♀' => 'زن پیاده‌روی می‌کند: پوست سفید',
    '🚶🏼‍♀' => 'زن پیاده‌روی می‌کند: پوست روشن',
    '🚶🏽‍♀' => 'زن پیاده‌روی می‌کند: پوست طلایی',
    '🚶🏾‍♀' => 'زن پیاده‌روی می‌کند: پوست گندمی',
    '🚶🏿‍♀' => 'زن پیاده‌روی می‌کند: پوست آبنوسی',
    '🚶🏻‍➡' => 'عابر پیاده: پوست سفید،‏ به سمت راست',
    '🚶🏼‍➡' => 'عابر پیاده: پوست روشن،‏ به سمت راست',
    '🚶🏽‍➡' => 'عابر پیاده: پوست طلایی،‏ به سمت راست',
    '🚶🏾‍➡' => 'عابر پیاده: پوست گندمی،‏ به سمت راست',
    '🚶🏿‍➡' => 'عابر پیاده: پوست آبنوسی،‏ به سمت راست',
    '🧍🏻‍♂' => 'مرد ایستاده: پوست سفید',
    '🧍🏼‍♂' => 'مرد ایستاده: پوست روشن',
    '🧍🏽‍♂' => 'مرد ایستاده: پوست طلایی',
    '🧍🏾‍♂' => 'مرد ایستاده: پوست گندمی',
    '🧍🏿‍♂' => 'مرد ایستاده: پوست آبنوسی',
    '🧍🏻‍♀' => 'زن ایستاده: پوست سفید',
    '🧍🏼‍♀' => 'زن ایستاده: پوست روشن',
    '🧍🏽‍♀' => 'زن ایستاده: پوست طلایی',
    '🧍🏾‍♀' => 'زن ایستاده: پوست گندمی',
    '🧍🏿‍♀' => 'زن ایستاده: پوست آبنوسی',
    '🧎🏻‍♂' => 'مرد زانوزده: پوست سفید',
    '🧎🏼‍♂' => 'مرد زانوزده: پوست روشن',
    '🧎🏽‍♂' => 'مرد زانوزده: پوست طلایی',
    '🧎🏾‍♂' => 'مرد زانوزده: پوست گندمی',
    '🧎🏿‍♂' => 'مرد زانوزده: پوست آبنوسی',
    '🧎🏻‍♀' => 'زن زانوزده: پوست سفید',
    '🧎🏼‍♀' => 'زن زانوزده: پوست روشن',
    '🧎🏽‍♀' => 'زن زانوزده: پوست طلایی',
    '🧎🏾‍♀' => 'زن زانوزده: پوست گندمی',
    '🧎🏿‍♀' => 'زن زانوزده: پوست آبنوسی',
    '🧎🏻‍➡' => 'آدم زانوزده: پوست سفید،‏ به سمت راست',
    '🧎🏼‍➡' => 'آدم زانوزده: پوست روشن،‏ به سمت راست',
    '🧎🏽‍➡' => 'آدم زانوزده: پوست طلایی،‏ به سمت راست',
    '🧎🏾‍➡' => 'آدم زانوزده: پوست گندمی،‏ به سمت راست',
    '🧎🏿‍➡' => 'آدم زانوزده: پوست آبنوسی،‏ به سمت راست',
    '🧑🏻‍🦯' => 'شخصی با عصای راهنما: پوست سفید',
    '🧑🏼‍🦯' => 'شخصی با عصای راهنما: پوست روشن',
    '🧑🏽‍🦯' => 'شخصی با عصای راهنما: پوست طلایی',
    '🧑🏾‍🦯' => 'شخصی با عصای راهنما: پوست گندمی',
    '🧑🏿‍🦯' => 'شخصی با عصای راهنما: پوست آبنوسی',
    '👨🏻‍🦯' => 'مرد با عصای سفید: پوست سفید',
    '👨🏼‍🦯' => 'مرد با عصای سفید: پوست روشن',
    '👨🏽‍🦯' => 'مرد با عصای سفید: پوست طلایی',
    '👨🏾‍🦯' => 'مرد با عصای سفید: پوست گندمی',
    '👨🏿‍🦯' => 'مرد با عصای سفید: پوست آبنوسی',
    '👩🏻‍🦯' => 'زن با عصای سفید: پوست سفید',
    '👩🏼‍🦯' => 'زن با عصای سفید: پوست روشن',
    '👩🏽‍🦯' => 'زن با عصای سفید: پوست طلایی',
    '👩🏾‍🦯' => 'زن با عصای سفید: پوست گندمی',
    '👩🏿‍🦯' => 'زن با عصای سفید: پوست آبنوسی',
    '🧑🏻‍🦼' => 'شخصی با صندلی چرخ‌دار موتوری: پوست سفید',
    '🧑🏼‍🦼' => 'شخصی با صندلی چرخ‌دار موتوری: پوست روشن',
    '🧑🏽‍🦼' => 'شخصی با صندلی چرخ‌دار موتوری: پوست طلایی',
    '🧑🏾‍🦼' => 'شخصی با صندلی چرخ‌دار موتوری: پوست گندمی',
    '🧑🏿‍🦼' => 'شخصی با صندلی چرخ‌دار موتوری: پوست آبنوسی',
    '👨🏻‍🦼' => 'مرد در صندلی چرخ‌دار برقی: پوست سفید',
    '👨🏼‍🦼' => 'مرد در صندلی چرخ‌دار برقی: پوست روشن',
    '👨🏽‍🦼' => 'مرد در صندلی چرخ‌دار برقی: پوست طلایی',
    '👨🏾‍🦼' => 'مرد در صندلی چرخ‌دار برقی: پوست گندمی',
    '👨🏿‍🦼' => 'مرد در صندلی چرخ‌دار برقی: پوست آبنوسی',
    '👩🏻‍🦼' => 'زن در صندلی چرخ‌دار برقی: پوست سفید',
    '👩🏼‍🦼' => 'زن در صندلی چرخ‌دار برقی: پوست روشن',
    '👩🏽‍🦼' => 'زن در صندلی چرخ‌دار برقی: پوست طلایی',
    '👩🏾‍🦼' => 'زن در صندلی چرخ‌دار برقی: پوست گندمی',
    '👩🏿‍🦼' => 'زن در صندلی چرخ‌دار برقی: پوست آبنوسی',
    '🧑🏻‍🦽' => 'شخصی با صندلی چرخ‌دار دستی: پوست سفید',
    '🧑🏼‍🦽' => 'شخصی با صندلی چرخ‌دار دستی: پوست روشن',
    '🧑🏽‍🦽' => 'شخصی با صندلی چرخ‌دار دستی: پوست طلایی',
    '🧑🏾‍🦽' => 'شخصی با صندلی چرخ‌دار دستی: پوست گندمی',
    '🧑🏿‍🦽' => 'شخصی با صندلی چرخ‌دار دستی: پوست آبنوسی',
    '👨🏻‍🦽' => 'مرد در صندلی چرخ‌دار دستی: پوست سفید',
    '👨🏼‍🦽' => 'مرد در صندلی چرخ‌دار دستی: پوست روشن',
    '👨🏽‍🦽' => 'مرد در صندلی چرخ‌دار دستی: پوست طلایی',
    '👨🏾‍🦽' => 'مرد در صندلی چرخ‌دار دستی: پوست گندمی',
    '👨🏿‍🦽' => 'مرد در صندلی چرخ‌دار دستی: پوست آبنوسی',
    '👩🏻‍🦽' => 'زن در صندلی چرخ‌دار دستی: پوست سفید',
    '👩🏼‍🦽' => 'زن در صندلی چرخ‌دار دستی: پوست روشن',
    '👩🏽‍🦽' => 'زن در صندلی چرخ‌دار دستی: پوست طلایی',
    '👩🏾‍🦽' => 'زن در صندلی چرخ‌دار دستی: پوست گندمی',
    '👩🏿‍🦽' => 'زن در صندلی چرخ‌دار دستی: پوست آبنوسی',
    '🏃🏻‍♂' => 'مرد دونده: پوست سفید',
    '🏃🏼‍♂' => 'مرد دونده: پوست روشن',
    '🏃🏽‍♂' => 'مرد دونده: پوست طلایی',
    '🏃🏾‍♂' => 'مرد دونده: پوست گندمی',
    '🏃🏿‍♂' => 'مرد دونده: پوست آبنوسی',
    '🏃🏻‍♀' => 'زن دونده: پوست سفید',
    '🏃🏼‍♀' => 'زن دونده: پوست روشن',
    '🏃🏽‍♀' => 'زن دونده: پوست طلایی',
    '🏃🏾‍♀' => 'زن دونده: پوست گندمی',
    '🏃🏿‍♀' => 'زن دونده: پوست آبنوسی',
    '🏃🏻‍➡' => 'دونده: پوست سفید،‏ به سمت راست',
    '🏃🏼‍➡' => 'دونده: پوست روشن،‏ به سمت راست',
    '🏃🏽‍➡' => 'دونده: پوست طلایی،‏ به سمت راست',
    '🏃🏾‍➡' => 'دونده: پوست گندمی،‏ به سمت راست',
    '🏃🏿‍➡' => 'دونده: پوست آبنوسی،‏ به سمت راست',
    '👯🏻‍♀' => 'زنان در پارتی: پوست سفید',
    '👯🏼‍♀' => 'زنان در پارتی: پوست روشن',
    '👯🏽‍♀' => 'زنان در پارتی: پوست طلایی',
    '👯🏾‍♀' => 'زنان در پارتی: پوست گندمی',
    '👯🏿‍♀' => 'زنان در پارتی: پوست آبنوسی',
    '👯🏻‍♂' => 'مردان در پارتی: پوست سفید',
    '👯🏼‍♂' => 'مردان در پارتی: پوست روشن',
    '👯🏽‍♂' => 'مردان در پارتی: پوست طلایی',
    '👯🏾‍♂' => 'مردان در پارتی: پوست گندمی',
    '👯🏿‍♂' => 'مردان در پارتی: پوست آبنوسی',
    '🧖🏻‍♂' => 'مرد در حمام بخار: پوست سفید',
    '🧖🏼‍♂' => 'مرد در حمام بخار: پوست روشن',
    '🧖🏽‍♂' => 'مرد در حمام بخار: پوست طلایی',
    '🧖🏾‍♂' => 'مرد در حمام بخار: پوست گندمی',
    '🧖🏿‍♂' => 'مرد در حمام بخار: پوست آبنوسی',
    '🧖🏻‍♀' => 'زن در حمام بخار: پوست سفید',
    '🧖🏼‍♀' => 'زن در حمام بخار: پوست روشن',
    '🧖🏽‍♀' => 'زن در حمام بخار: پوست طلایی',
    '🧖🏾‍♀' => 'زن در حمام بخار: پوست گندمی',
    '🧖🏿‍♀' => 'زن در حمام بخار: پوست آبنوسی',
    '🧗🏻‍♂' => 'مرد کوه‌نوردی می‌کند: پوست سفید',
    '🧗🏼‍♂' => 'مرد کوه‌نوردی می‌کند: پوست روشن',
    '🧗🏽‍♂' => 'مرد کوه‌نوردی می‌کند: پوست طلایی',
    '🧗🏾‍♂' => 'مرد کوه‌نوردی می‌کند: پوست گندمی',
    '🧗🏿‍♂' => 'مرد کوه‌نوردی می‌کند: پوست آبنوسی',
    '🧗🏻‍♀' => 'زن کوه‌نوردی می‌کند: پوست سفید',
    '🧗🏼‍♀' => 'زن کوه‌نوردی می‌کند: پوست روشن',
    '🧗🏽‍♀' => 'زن کوه‌نوردی می‌کند: پوست طلایی',
    '🧗🏾‍♀' => 'زن کوه‌نوردی می‌کند: پوست گندمی',
    '🧗🏿‍♀' => 'زن کوه‌نوردی می‌کند: پوست آبنوسی',
    '🏌🏻‍♂' => 'گلف‌باز مرد: پوست سفید',
    '🏌🏼‍♂' => 'گلف‌باز مرد: پوست روشن',
    '🏌🏽‍♂' => 'گلف‌باز مرد: پوست طلایی',
    '🏌🏾‍♂' => 'گلف‌باز مرد: پوست گندمی',
    '🏌🏿‍♂' => 'گلف‌باز مرد: پوست آبنوسی',
    '🏌🏻‍♀' => 'گلف‌باز زن: پوست سفید',
    '🏌🏼‍♀' => 'گلف‌باز زن: پوست روشن',
    '🏌🏽‍♀' => 'گلف‌باز زن: پوست طلایی',
    '🏌🏾‍♀' => 'گلف‌باز زن: پوست گندمی',
    '🏌🏿‍♀' => 'گلف‌باز زن: پوست آبنوسی',
    '🏄🏻‍♂' => 'موج‌سوار مرد: پوست سفید',
    '🏄🏼‍♂' => 'موج‌سوار مرد: پوست روشن',
    '🏄🏽‍♂' => 'موج‌سوار مرد: پوست طلایی',
    '🏄🏾‍♂' => 'موج‌سوار مرد: پوست گندمی',
    '🏄🏿‍♂' => 'موج‌سوار مرد: پوست آبنوسی',
    '🏄🏻‍♀' => 'موج‌سوار زن: پوست سفید',
    '🏄🏼‍♀' => 'موج‌سوار زن: پوست روشن',
    '🏄🏽‍♀' => 'موج‌سوار زن: پوست طلایی',
    '🏄🏾‍♀' => 'موج‌سوار زن: پوست گندمی',
    '🏄🏿‍♀' => 'موج‌سوار زن: پوست آبنوسی',
    '🚣🏻‍♂' => 'پاروزن مرد: پوست سفید',
    '🚣🏼‍♂' => 'پاروزن مرد: پوست روشن',
    '🚣🏽‍♂' => 'پاروزن مرد: پوست طلایی',
    '🚣🏾‍♂' => 'پاروزن مرد: پوست گندمی',
    '🚣🏿‍♂' => 'پاروزن مرد: پوست آبنوسی',
    '🚣🏻‍♀' => 'پاروزن زن: پوست سفید',
    '🚣🏼‍♀' => 'پاروزن زن: پوست روشن',
    '🚣🏽‍♀' => 'پاروزن زن: پوست طلایی',
    '🚣🏾‍♀' => 'پاروزن زن: پوست گندمی',
    '🚣🏿‍♀' => 'پاروزن زن: پوست آبنوسی',
    '🏊🏻‍♂' => 'شناگر مرد: پوست سفید',
    '🏊🏼‍♂' => 'شناگر مرد: پوست روشن',
    '🏊🏽‍♂' => 'شناگر مرد: پوست طلایی',
    '🏊🏾‍♂' => 'شناگر مرد: پوست گندمی',
    '🏊🏿‍♂' => 'شناگر مرد: پوست آبنوسی',
    '🏊🏻‍♀' => 'شناگر زن: پوست سفید',
    '🏊🏼‍♀' => 'شناگر زن: پوست روشن',
    '🏊🏽‍♀' => 'شناگر زن: پوست طلایی',
    '🏊🏾‍♀' => 'شناگر زن: پوست گندمی',
    '🏊🏿‍♀' => 'شناگر زن: پوست آبنوسی',
    '⛹🏻‍♂' => 'مرد و توپ: پوست سفید',
    '⛹🏼‍♂' => 'مرد و توپ: پوست روشن',
    '⛹🏽‍♂' => 'مرد و توپ: پوست طلایی',
    '⛹🏾‍♂' => 'مرد و توپ: پوست گندمی',
    '⛹🏿‍♂' => 'مرد و توپ: پوست آبنوسی',
    '⛹🏻‍♀' => 'زن و توپ: پوست سفید',
    '⛹🏼‍♀' => 'زن و توپ: پوست روشن',
    '⛹🏽‍♀' => 'زن و توپ: پوست طلایی',
    '⛹🏾‍♀' => 'زن و توپ: پوست گندمی',
    '⛹🏿‍♀' => 'زن و توپ: پوست آبنوسی',
    '🏋🏻‍♂' => 'وزنه‌بردار مرد: پوست سفید',
    '🏋🏼‍♂' => 'وزنه‌بردار مرد: پوست روشن',
    '🏋🏽‍♂' => 'وزنه‌بردار مرد: پوست طلایی',
    '🏋🏾‍♂' => 'وزنه‌بردار مرد: پوست گندمی',
    '🏋🏿‍♂' => 'وزنه‌بردار مرد: پوست آبنوسی',
    '🏋🏻‍♀' => 'وزنه‌بردار زن: پوست سفید',
    '🏋🏼‍♀' => 'وزنه‌بردار زن: پوست روشن',
    '🏋🏽‍♀' => 'وزنه‌بردار زن: پوست طلایی',
    '🏋🏾‍♀' => 'وزنه‌بردار زن: پوست گندمی',
    '🏋🏿‍♀' => 'وزنه‌بردار زن: پوست آبنوسی',
    '🚴🏻‍♂' => 'دوچرخه‌سوار مرد: پوست سفید',
    '🚴🏼‍♂' => 'دوچرخه‌سوار مرد: پوست روشن',
    '🚴🏽‍♂' => 'دوچرخه‌سوار مرد: پوست طلایی',
    '🚴🏾‍♂' => 'دوچرخه‌سوار مرد: پوست گندمی',
    '🚴🏿‍♂' => 'دوچرخه‌سوار مرد: پوست آبنوسی',
    '🚴🏻‍♀' => 'دوچرخه‌سوار زن: پوست سفید',
    '🚴🏼‍♀' => 'دوچرخه‌سوار زن: پوست روشن',
    '🚴🏽‍♀' => 'دوچرخه‌سوار زن: پوست طلایی',
    '🚴🏾‍♀' => 'دوچرخه‌سوار زن: پوست گندمی',
    '🚴🏿‍♀' => 'دوچرخه‌سوار زن: پوست آبنوسی',
    '🚵🏻‍♂' => 'مرد و دوچرخه‌سواری کوهستان: پوست سفید',
    '🚵🏼‍♂' => 'مرد و دوچرخه‌سواری کوهستان: پوست روشن',
    '🚵🏽‍♂' => 'مرد و دوچرخه‌سواری کوهستان: پوست طلایی',
    '🚵🏾‍♂' => 'مرد و دوچرخه‌سواری کوهستان: پوست گندمی',
    '🚵🏿‍♂' => 'مرد و دوچرخه‌سواری کوهستان: پوست آبنوسی',
    '🚵🏻‍♀' => 'زن و دوچرخه‌سواری کوهستان: پوست سفید',
    '🚵🏼‍♀' => 'زن و دوچرخه‌سواری کوهستان: پوست روشن',
    '🚵🏽‍♀' => 'زن و دوچرخه‌سواری کوهستان: پوست طلایی',
    '🚵🏾‍♀' => 'زن و دوچرخه‌سواری کوهستان: پوست گندمی',
    '🚵🏿‍♀' => 'زن و دوچرخه‌سواری کوهستان: پوست آبنوسی',
    '🤸🏻‍♂' => 'مردِ چرخ‌وفلک‌زن: پوست سفید',
    '🤸🏼‍♂' => 'مردِ چرخ‌وفلک‌زن: پوست روشن',
    '🤸🏽‍♂' => 'مردِ چرخ‌وفلک‌زن: پوست طلایی',
    '🤸🏾‍♂' => 'مردِ چرخ‌وفلک‌زن: پوست گندمی',
    '🤸🏿‍♂' => 'مردِ چرخ‌وفلک‌زن: پوست آبنوسی',
    '🤸🏻‍♀' => 'زنِ چرخ‌وفلک‌زن: پوست سفید',
    '🤸🏼‍♀' => 'زنِ چرخ‌وفلک‌زن: پوست روشن',
    '🤸🏽‍♀' => 'زنِ چرخ‌وفلک‌زن: پوست طلایی',
    '🤸🏾‍♀' => 'زنِ چرخ‌وفلک‌زن: پوست گندمی',
    '🤸🏿‍♀' => 'زنِ چرخ‌وفلک‌زن: پوست آبنوسی',
    '🤼🏻‍♀' => 'کُشتی‌گیر زن: پوست سفید',
    '🤼🏼‍♀' => 'کُشتی‌گیر زن: پوست روشن',
    '🤼🏽‍♀' => 'کُشتی‌گیر زن: پوست طلایی',
    '🤼🏾‍♀' => 'کُشتی‌گیر زن: پوست گندمی',
    '🤼🏿‍♀' => 'کُشتی‌گیر زن: پوست آبنوسی',
    '🤼🏻‍♂' => 'کُشتی‌گیر مرد: پوست سفید',
    '🤼🏼‍♂' => 'کُشتی‌گیر مرد: پوست روشن',
    '🤼🏽‍♂' => 'کُشتی‌گیر مرد: پوست طلایی',
    '🤼🏾‍♂' => 'کُشتی‌گیر مرد: پوست گندمی',
    '🤼🏿‍♂' => 'کُشتی‌گیر مرد: پوست آبنوسی',
    '🤽🏻‍♂' => 'واترپلو مردان: پوست سفید',
    '🤽🏼‍♂' => 'واترپلو مردان: پوست روشن',
    '🤽🏽‍♂' => 'واترپلو مردان: پوست طلایی',
    '🤽🏾‍♂' => 'واترپلو مردان: پوست گندمی',
    '🤽🏿‍♂' => 'واترپلو مردان: پوست آبنوسی',
    '🤽🏻‍♀' => 'واترپلو زنان: پوست سفید',
    '🤽🏼‍♀' => 'واترپلو زنان: پوست روشن',
    '🤽🏽‍♀' => 'واترپلو زنان: پوست طلایی',
    '🤽🏾‍♀' => 'واترپلو زنان: پوست گندمی',
    '🤽🏿‍♀' => 'واترپلو زنان: پوست آبنوسی',
    '🤾🏻‍♂' => 'هندبالیست مرد: پوست سفید',
    '🤾🏼‍♂' => 'هندبالیست مرد: پوست روشن',
    '🤾🏽‍♂' => 'هندبالیست مرد: پوست طلایی',
    '🤾🏾‍♂' => 'هندبالیست مرد: پوست گندمی',
    '🤾🏿‍♂' => 'هندبالیست مرد: پوست آبنوسی',
    '🤾🏻‍♀' => 'هندبالیست زن: پوست سفید',
    '🤾🏼‍♀' => 'هندبالیست زن: پوست روشن',
    '🤾🏽‍♀' => 'هندبالیست زن: پوست طلایی',
    '🤾🏾‍♀' => 'هندبالیست زن: پوست گندمی',
    '🤾🏿‍♀' => 'هندبالیست زن: پوست آبنوسی',
    '🤹🏻‍♂' => 'مرد ژانگولربازی می‌کند: پوست سفید',
    '🤹🏼‍♂' => 'مرد ژانگولربازی می‌کند: پوست روشن',
    '🤹🏽‍♂' => 'مرد ژانگولربازی می‌کند: پوست طلایی',
    '🤹🏾‍♂' => 'مرد ژانگولربازی می‌کند: پوست گندمی',
    '🤹🏿‍♂' => 'مرد ژانگولربازی می‌کند: پوست آبنوسی',
    '🤹🏻‍♀' => 'زن ژانگولربازی می‌کند: پوست سفید',
    '🤹🏼‍♀' => 'زن ژانگولربازی می‌کند: پوست روشن',
    '🤹🏽‍♀' => 'زن ژانگولربازی می‌کند: پوست طلایی',
    '🤹🏾‍♀' => 'زن ژانگولربازی می‌کند: پوست گندمی',
    '🤹🏿‍♀' => 'زن ژانگولربازی می‌کند: پوست آبنوسی',
    '🧘🏻‍♂' => 'مرد در حالت خلسه: پوست سفید',
    '🧘🏼‍♂' => 'مرد در حالت خلسه: پوست روشن',
    '🧘🏽‍♂' => 'مرد در حالت خلسه: پوست طلایی',
    '🧘🏾‍♂' => 'مرد در حالت خلسه: پوست گندمی',
    '🧘🏿‍♂' => 'مرد در حالت خلسه: پوست آبنوسی',
    '🧘🏻‍♀' => 'زن در حالت خلسه: پوست سفید',
    '🧘🏼‍♀' => 'زن در حالت خلسه: پوست روشن',
    '🧘🏽‍♀' => 'زن در حالت خلسه: پوست طلایی',
    '🧘🏾‍♀' => 'زن در حالت خلسه: پوست گندمی',
    '🧘🏿‍♀' => 'زن در حالت خلسه: پوست آبنوسی',
    '🧑‍🦰' => 'شخص: موقرمز',
    '🧑‍🦱' => 'شخص: موفرفری',
    '🧑‍🦳' => 'شخص: موسفید',
    '🧑‍🦲' => 'شخص: تاس',
    '👨‍🦰' => 'مرد: موقرمز',
    '👨‍🦱' => 'مرد: موفرفری',
    '👨‍🦳' => 'مرد: موسفید',
    '👨‍🦲' => 'مرد: تاس',
    '👩‍🦰' => 'زن: موقرمز',
    '👩‍🦱' => 'زن: موفرفری',
    '👩‍🦳' => 'زن: موسفید',
    '👩‍🦲' => 'زن: تاس',
    '🚶‍➡' => 'عابر پیاده: به سمت راست',
    '🧎‍➡' => 'آدم زانوزده: به سمت راست',
    '🏃‍➡' => 'دونده: به سمت راست',
    '👨‍👦' => 'خانواده: مرد،‏ پسر',
    '👨‍👧' => 'خانواده: مرد،‏ دختر',
    '👩‍👦' => 'خانواده: زن،‏ پسر',
    '👩‍👧' => 'خانواده: زن،‏ دختر',
    '😶‍🌫' => 'صورتک میان ابر',
    '😮‍💨' => 'صورتک در حال بازدم',
    '🙂‍↕' => 'تکان دادن عمودی سر',
    '😵‍💫' => 'صورتک با چشمان چرخشی',
    '❤‍🔥' => 'قلب در آتش',
    '❤‍🩹' => 'قلب التیام‌یافته',
    '👁‍🗨' => 'چشم در حباب گفتار',
    '🧔‍♂' => 'مرد: ریش',
    '👱‍♂' => 'مرد: مو بور',
    '🧔‍♀' => 'زن: ریش',
    '👱‍♀' => 'زن: موبور',
    '🙍‍♂' => 'مرد اخم می‌کند',
    '🙍‍♀' => 'زن اخم می‌کند',
    '🙎‍♂' => 'مرد اخم‌وتخم می‌کند',
    '🙎‍♀' => 'زن اخم‌وتخم می‌کند',
    '🙅‍♂' => 'مرد نمی‌پذیرد',
    '🙅‍♀' => 'زن نمی‌پذیرد',
    '🙆‍♂' => 'مرد می‌پذیرد',
    '🙆‍♀' => 'زن می‌پذیرد',
    '💁‍♂' => 'مرد کمک می‌کند',
    '💁‍♀' => 'زن کمک می‌کند',
    '🙋‍♂' => 'مرد دستش را بالا می‌برد',
    '🙋‍♀' => 'زن دستش را بالا می‌برد',
    '🧏‍♂' => 'مرد ناشنوا',
    '🧏‍♀' => 'زن ناشنوا',
    '🙇‍♂' => 'مرد تعظیم می‌کند',
    '🙇‍♀' => 'زن تعظیم می‌کند',
    '🤦‍♂' => 'مرد با کف دست به پیشانی می‌زند',
    '🤦‍♀' => 'زن با کف دست به پیشانی می‌زند',
    '🤷‍♂' => 'مرد شانه بالا می‌اندازد',
    '🤷‍♀' => 'زن شانه بالا می‌اندازد',
    '🧑‍⚕' => 'مأمور بهداشت',
    '👨‍⚕' => 'مددکار بهداشت مرد',
    '👩‍⚕' => 'مددکار بهداشت زن',
    '🧑‍🎓' => 'دانش‌آموز',
    '👨‍🎓' => 'دانشجوی مرد',
    '👩‍🎓' => 'دانشجوی زن',
    '🧑‍🏫' => 'معلم',
    '👨‍🏫' => 'آموزگار مرد',
    '👩‍🏫' => 'آموزگار زن',
    '🧑‍⚖' => 'قاضی',
    '👨‍⚖' => 'قاضی مرد',
    '👩‍⚖' => 'قاضی زن',
    '🧑‍🌾' => 'کشاورز',
    '👨‍🌾' => 'کشاورز مرد',
    '👩‍🌾' => 'کشاورز زن',
    '🧑‍🍳' => 'آشپز',
    '👨‍🍳' => 'آشپز مرد',
    '👩‍🍳' => 'آشپز زن',
    '🧑‍🔧' => 'مکانیک',
    '👨‍🔧' => 'تعمیرکار مرد',
    '👩‍🔧' => 'تعمیرکار زن',
    '🧑‍🏭' => 'کارگر کارخانه',
    '👨‍🏭' => 'کارگر کارخانه مرد',
    '👩‍🏭' => 'کارگر کارخانه زن',
    '🧑‍💼' => 'کارمند',
    '👨‍💼' => 'کارمند مرد',
    '👩‍💼' => 'کارمند زن',
    '🧑‍🔬' => 'دانشمند',
    '👨‍🔬' => 'دانشمند مرد',
    '👩‍🔬' => 'دانشمند زن',
    '🧑‍💻' => 'متخصص',
    '👨‍💻' => 'کارشناس فناوری مرد',
    '👩‍💻' => 'کارشناس فناوری زن',
    '🧑‍🎤' => 'خواننده',
    '👨‍🎤' => 'خواننده مرد',
    '👩‍🎤' => 'خواننده زن',
    '🧑‍🎨' => 'هنرمند',
    '👨‍🎨' => 'هنرمند مرد',
    '👩‍🎨' => 'هنرمند زن',
    '🧑‍✈' => 'خلبان',
    '👨‍✈' => 'خلبان مرد',
    '👩‍✈' => 'خلبان زن',
    '🧑‍🚀' => 'فضانورد',
    '👨‍🚀' => 'فضانورد مرد',
    '👩‍🚀' => 'فضانورد زن',
    '🧑‍🚒' => 'مأمور آتش‌نشانی',
    '👨‍🚒' => 'آتش‌نشان مرد',
    '👩‍🚒' => 'آتش‌نشان زن',
    '👮‍♂' => 'پلیس مرد',
    '👮‍♀' => 'پلیس زن',
    '🕵‍♂' => 'کارآگاه مرد',
    '🕵‍♀' => 'کارآگاه زن',
    '💂‍♂' => 'گارد مرد',
    '💂‍♀' => 'گارد زن',
    '👷‍♂' => 'کارگر ساختمانی مرد',
    '👷‍♀' => 'کارگر ساختمانی زن',
    '👳‍♂' => 'مرد با دستار',
    '👳‍♀' => 'زن با دستار',
    '🤵‍♂' => 'مرد با کت و شلوار و پاپیون',
    '🤵‍♀' => 'زن با کت و شلوار و پاپیون',
    '👰‍♂' => 'مرد با تور عروس',
    '👰‍♀' => 'زن با تور عروس',
    '👩‍🍼' => 'زنی که به بچه شیر می‌دهد',
    '👨‍🍼' => 'مردی که به بچه شیر می‌دهد',
    '🧑‍🍼' => 'شخصی که به بچه شیر می‌دهد',
    '🧑‍🎄' => 'نوئل',
    '🦸‍♂' => 'ابرقهرمان مرد',
    '🦸‍♀' => 'ابرقهرمان زن',
    '🦹‍♂' => 'ابرشرور مرد',
    '🦹‍♀' => 'ابرشرور زن',
    '🧙‍♂' => 'ساحر مرد',
    '🧙‍♀' => 'ساحر زن',
    '🧚‍♂' => 'پری مرد',
    '🧚‍♀' => 'پری زن',
    '🧛‍♂' => 'خون‌آشام مرد',
    '🧛‍♀' => 'دراکولای زن',
    '🧜‍♂' => 'دریامرد',
    '🧜‍♀' => 'پری دریایی',
    '🧝‍♂' => 'اِلف مرد',
    '🧝‍♀' => 'اِلف زن',
    '🧞‍♂' => 'مرد جن',
    '🧞‍♀' => 'زن جن',
    '🧟‍♂' => 'مرده متحرک مرد',
    '🧟‍♀' => 'مرده متحرک زن',
    '💆‍♂' => 'ماساژ صورت مرد',
    '💆‍♀' => 'ماساژ صورت زن',
    '💇‍♂' => 'مرد مو کوتاه می‌کند',
    '💇‍♀' => 'زن مو کوتاه می‌کند',
    '🚶‍♂' => 'مرد پیاده‌روی می‌کند',
    '🚶‍♀' => 'زن پیاده‌روی می‌کند',
    '🧍‍♂' => 'مرد ایستاده',
    '🧍‍♀' => 'زن ایستاده',
    '🧎‍♂' => 'مرد زانوزده',
    '🧎‍♀' => 'زن زانوزده',
    '🧑‍🦯' => 'شخصی با عصای راهنما',
    '👨‍🦯' => 'مرد با عصای سفید',
    '👩‍🦯' => 'زن با عصای سفید',
    '🧑‍🦼' => 'شخصی با صندلی چرخ‌دار موتوری',
    '👨‍🦼' => 'مرد در صندلی چرخ‌دار برقی',
    '👩‍🦼' => 'زن در صندلی چرخ‌دار برقی',
    '🧑‍🦽' => 'شخصی با صندلی چرخ‌دار دستی',
    '👨‍🦽' => 'مرد در صندلی چرخ‌دار دستی',
    '👩‍🦽' => 'زن در صندلی چرخ‌دار دستی',
    '🏃‍♂' => 'مرد دونده',
    '🏃‍♀' => 'زن دونده',
    '🧑‍🩰' => 'رقصنده باله',
    '👯‍♂' => 'مردان در پارتی',
    '👯‍♀' => 'زنان در پارتی',
    '🧖‍♂' => 'مرد در حمام بخار',
    '🧖‍♀' => 'زن در حمام بخار',
    '🧗‍♂' => 'مرد کوه‌نوردی می‌کند',
    '🧗‍♀' => 'زن کوه‌نوردی می‌کند',
    '🏌‍♂' => 'گلف‌باز مرد',
    '🏌‍♀' => 'گلف‌باز زن',
    '🏄‍♂' => 'موج‌سوار مرد',
    '🏄‍♀' => 'موج‌سوار زن',
    '🚣‍♂' => 'پاروزن مرد',
    '🚣‍♀' => 'پاروزن زن',
    '🏊‍♂' => 'شناگر مرد',
    '🏊‍♀' => 'شناگر زن',
    '⛹‍♂' => 'مرد و توپ',
    '⛹‍♀' => 'زن و توپ',
    '🏋‍♂' => 'وزنه‌بردار مرد',
    '🏋‍♀' => 'وزنه‌بردار زن',
    '🚴‍♂' => 'دوچرخه‌سوار مرد',
    '🚴‍♀' => 'دوچرخه‌سوار زن',
    '🚵‍♂' => 'مرد و دوچرخه‌سواری کوهستان',
    '🚵‍♀' => 'زن و دوچرخه‌سواری کوهستان',
    '🤸‍♂' => 'مردِ چرخ‌وفلک‌زن',
    '🤸‍♀' => 'زنِ چرخ‌وفلک‌زن',
    '🤼‍♂' => 'کُشتی‌گیر مرد',
    '🤼‍♀' => 'کُشتی‌گیر زن',
    '🤽‍♂' => 'واترپلو مردان',
    '🤽‍♀' => 'واترپلو زنان',
    '🤾‍♂' => 'هندبالیست مرد',
    '🤾‍♀' => 'هندبالیست زن',
    '🤹‍♂' => 'مرد ژانگولربازی می‌کند',
    '🤹‍♀' => 'زن ژانگولربازی می‌کند',
    '🧘‍♂' => 'مرد در حالت خلسه',
    '🧘‍♀' => 'زن در حالت خلسه',
    '🧑‍🧒' => 'خانواده: بزرگسال، کودک',
    '🐕‍🦺' => 'سگ کمکی',
    '🐈‍⬛' => 'گربه سیاه',
    '🐻‍❄' => 'خرس قطبی',
    '🐦‍⬛' => 'پرنده سیاه',
    '🐦‍🔥' => 'ققنوس',
    '🍋‍🟩' => 'لیمو',
    '🍄‍🟫' => 'قارچ قهوه‌ای',
    '⛓‍💥' => 'زنجیر پاره',
    '🏳‍🌈' => 'پرچم رنگین‌کمان',
    '🏳‍⚧' => 'پرچم تراجنسیتی',
    '🏴‍☠' => 'پرچم دزدان دریایی',
    '👋🏻' => 'تکان دادن دست: پوست سفید',
    '👋🏼' => 'تکان دادن دست: پوست روشن',
    '👋🏽' => 'تکان دادن دست: پوست طلایی',
    '👋🏾' => 'تکان دادن دست: پوست گندمی',
    '👋🏿' => 'تکان دادن دست: پوست آبنوسی',
    '🤚🏻' => 'پشت دست روبه بالا: پوست سفید',
    '🤚🏼' => 'پشت دست روبه بالا: پوست روشن',
    '🤚🏽' => 'پشت دست روبه بالا: پوست طلایی',
    '🤚🏾' => 'پشت دست روبه بالا: پوست گندمی',
    '🤚🏿' => 'پشت دست روبه بالا: پوست آبنوسی',
    '🖐🏻' => 'دست با انگشتان باز: پوست سفید',
    '🖐🏼' => 'دست با انگشتان باز: پوست روشن',
    '🖐🏽' => 'دست با انگشتان باز: پوست طلایی',
    '🖐🏾' => 'دست با انگشتان باز: پوست گندمی',
    '🖐🏿' => 'دست با انگشتان باز: پوست آبنوسی',
    '✋🏻' => 'دست بالابرده: پوست سفید',
    '✋🏼' => 'دست بالابرده: پوست روشن',
    '✋🏽' => 'دست بالابرده: پوست طلایی',
    '✋🏾' => 'دست بالابرده: پوست گندمی',
    '✋🏿' => 'دست بالابرده: پوست آبنوسی',
    '🖖🏻' => 'سلام ولکان: پوست سفید',
    '🖖🏼' => 'سلام ولکان: پوست روشن',
    '🖖🏽' => 'سلام ولکان: پوست طلایی',
    '🖖🏾' => 'سلام ولکان: پوست گندمی',
    '🖖🏿' => 'سلام ولکان: پوست آبنوسی',
    '🫱🏻' => 'دست به سمت راست: پوست سفید',
    '🫱🏼' => 'دست به سمت راست: پوست روشن',
    '🫱🏽' => 'دست به سمت راست: پوست طلایی',
    '🫱🏾' => 'دست به سمت راست: پوست گندمی',
    '🫱🏿' => 'دست به سمت راست: پوست آبنوسی',
    '🫲🏻' => 'دست به سمت چپ: پوست سفید',
    '🫲🏼' => 'دست به سمت چپ: پوست روشن',
    '🫲🏽' => 'دست به سمت چپ: پوست طلایی',
    '🫲🏾' => 'دست به سمت چپ: پوست گندمی',
    '🫲🏿' => 'دست به سمت چپ: پوست آبنوسی',
    '🫳🏻' => 'کف دست به پایین: پوست سفید',
    '🫳🏼' => 'کف دست به پایین: پوست روشن',
    '🫳🏽' => 'کف دست به پایین: پوست طلایی',
    '🫳🏾' => 'کف دست به پایین: پوست گندمی',
    '🫳🏿' => 'کف دست به پایین: پوست آبنوسی',
    '🫴🏻' => 'کف دست به بالا: پوست سفید',
    '🫴🏼' => 'کف دست به بالا: پوست روشن',
    '🫴🏽' => 'کف دست به بالا: پوست طلایی',
    '🫴🏾' => 'کف دست به بالا: پوست گندمی',
    '🫴🏿' => 'کف دست به بالا: پوست آبنوسی',
    '🫷🏻' => 'دست فشاردهنده به سمت چپ: پوست سفید',
    '🫷🏼' => 'دست فشاردهنده به سمت چپ: پوست روشن',
    '🫷🏽' => 'دست فشاردهنده به سمت چپ: پوست طلایی',
    '🫷🏾' => 'دست فشاردهنده به سمت چپ: پوست گندمی',
    '🫷🏿' => 'دست فشاردهنده به سمت چپ: پوست آبنوسی',
    '🫸🏻' => 'دست فشاردهنده به سمت راست: پوست سفید',
    '🫸🏼' => 'دست فشاردهنده به سمت راست: پوست روشن',
    '🫸🏽' => 'دست فشاردهنده به سمت راست: پوست طلایی',
    '🫸🏾' => 'دست فشاردهنده به سمت راست: پوست گندمی',
    '🫸🏿' => 'دست فشاردهنده به سمت راست: پوست آبنوسی',
    '👌🏻' => 'علامت اوکی: پوست سفید',
    '👌🏼' => 'علامت اوکی: پوست روشن',
    '👌🏽' => 'علامت اوکی: پوست طلایی',
    '👌🏾' => 'علامت اوکی: پوست گندمی',
    '👌🏿' => 'علامت اوکی: پوست آبنوسی',
    '🤌🏻' => 'انگشتان جمع‌شده: پوست سفید',
    '🤌🏼' => 'انگشتان جمع‌شده: پوست روشن',
    '🤌🏽' => 'انگشتان جمع‌شده: پوست طلایی',
    '🤌🏾' => 'انگشتان جمع‌شده: پوست گندمی',
    '🤌🏿' => 'انگشتان جمع‌شده: پوست آبنوسی',
    '🤏🏻' => 'دست در حال نیشگون گرفتن: پوست سفید',
    '🤏🏼' => 'دست در حال نیشگون گرفتن: پوست روشن',
    '🤏🏽' => 'دست در حال نیشگون گرفتن: پوست طلایی',
    '🤏🏾' => 'دست در حال نیشگون گرفتن: پوست گندمی',
    '🤏🏿' => 'دست در حال نیشگون گرفتن: پوست آبنوسی',
    '✌🏻' => 'علامت پیروزی: پوست سفید',
    '✌🏼' => 'علامت پیروزی: پوست روشن',
    '✌🏽' => 'علامت پیروزی: پوست طلایی',
    '✌🏾' => 'علامت پیروزی: پوست گندمی',
    '✌🏿' => 'علامت پیروزی: پوست آبنوسی',
    '🤞🏻' => 'انگشتان گره خورده: پوست سفید',
    '🤞🏼' => 'انگشتان گره خورده: پوست روشن',
    '🤞🏽' => 'انگشتان گره خورده: پوست طلایی',
    '🤞🏾' => 'انگشتان گره خورده: پوست گندمی',
    '🤞🏿' => 'انگشتان گره خورده: پوست آبنوسی',
    '🫰🏻' => 'دست با انگشت اشاره و شست متقاطع: پوست سفید',
    '🫰🏼' => 'دست با انگشت اشاره و شست متقاطع: پوست روشن',
    '🫰🏽' => 'دست با انگشت اشاره و شست متقاطع: پوست طلایی',
    '🫰🏾' => 'دست با انگشت اشاره و شست متقاطع: پوست گندمی',
    '🫰🏿' => 'دست با انگشت اشاره و شست متقاطع: پوست آبنوسی',
    '🤟🏻' => 'علامت دوستت دارم: پوست سفید',
    '🤟🏼' => 'علامت دوستت دارم: پوست روشن',
    '🤟🏽' => 'علامت دوستت دارم: پوست طلایی',
    '🤟🏾' => 'علامت دوستت دارم: پوست گندمی',
    '🤟🏿' => 'علامت دوستت دارم: پوست آبنوسی',
    '🤘🏻' => 'نماد شاخ: پوست سفید',
    '🤘🏼' => 'نماد شاخ: پوست روشن',
    '🤘🏽' => 'نماد شاخ: پوست طلایی',
    '🤘🏾' => 'نماد شاخ: پوست گندمی',
    '🤘🏿' => 'نماد شاخ: پوست آبنوسی',
    '🤙🏻' => 'دست به شکل تلفن: پوست سفید',
    '🤙🏼' => 'دست به شکل تلفن: پوست روشن',
    '🤙🏽' => 'دست به شکل تلفن: پوست طلایی',
    '🤙🏾' => 'دست به شکل تلفن: پوست گندمی',
    '🤙🏿' => 'دست به شکل تلفن: پوست آبنوسی',
    '👈🏻' => 'اشاره به چپ: پوست سفید',
    '👈🏼' => 'اشاره به چپ: پوست روشن',
    '👈🏽' => 'اشاره به چپ: پوست طلایی',
    '👈🏾' => 'اشاره به چپ: پوست گندمی',
    '👈🏿' => 'اشاره به چپ: پوست آبنوسی',
    '👉🏻' => 'اشاره به راست: پوست سفید',
    '👉🏼' => 'اشاره به راست: پوست روشن',
    '👉🏽' => 'اشاره به راست: پوست طلایی',
    '👉🏾' => 'اشاره به راست: پوست گندمی',
    '👉🏿' => 'اشاره به راست: پوست آبنوسی',
    '👆🏻' => 'اشاره به بالا با پشت دست: پوست سفید',
    '👆🏼' => 'اشاره به بالا با پشت دست: پوست روشن',
    '👆🏽' => 'اشاره به بالا با پشت دست: پوست طلایی',
    '👆🏾' => 'اشاره به بالا با پشت دست: پوست گندمی',
    '👆🏿' => 'اشاره به بالا با پشت دست: پوست آبنوسی',
    '🖕🏻' => 'انگشت میانه: پوست سفید',
    '🖕🏼' => 'انگشت میانه: پوست روشن',
    '🖕🏽' => 'انگشت میانه: پوست طلایی',
    '🖕🏾' => 'انگشت میانه: پوست گندمی',
    '🖕🏿' => 'انگشت میانه: پوست آبنوسی',
    '👇🏻' => 'اشاره به پایین: پوست سفید',
    '👇🏼' => 'اشاره به پایین: پوست روشن',
    '👇🏽' => 'اشاره به پایین: پوست طلایی',
    '👇🏾' => 'اشاره به پایین: پوست گندمی',
    '👇🏿' => 'اشاره به پایین: پوست آبنوسی',
    '☝🏻' => 'اشاره به بالا: پوست سفید',
    '☝🏼' => 'اشاره به بالا: پوست روشن',
    '☝🏽' => 'اشاره به بالا: پوست طلایی',
    '☝🏾' => 'اشاره به بالا: پوست گندمی',
    '☝🏿' => 'اشاره به بالا: پوست آبنوسی',
    '🫵🏻' => 'اشاره به بیننده: پوست سفید',
    '🫵🏼' => 'اشاره به بیننده: پوست روشن',
    '🫵🏽' => 'اشاره به بیننده: پوست طلایی',
    '🫵🏾' => 'اشاره به بیننده: پوست گندمی',
    '🫵🏿' => 'اشاره به بیننده: پوست آبنوسی',
    '👍🏻' => 'پسندیدن: پوست سفید',
    '👍🏼' => 'پسندیدن: پوست روشن',
    '👍🏽' => 'پسندیدن: پوست طلایی',
    '👍🏾' => 'پسندیدن: پوست گندمی',
    '👍🏿' => 'پسندیدن: پوست آبنوسی',
    '👎🏻' => 'نپسندیدن: پوست سفید',
    '👎🏼' => 'نپسندیدن: پوست روشن',
    '👎🏽' => 'نپسندیدن: پوست طلایی',
    '👎🏾' => 'نپسندیدن: پوست گندمی',
    '👎🏿' => 'نپسندیدن: پوست آبنوسی',
    '✊🏻' => 'مشت کردن: پوست سفید',
    '✊🏼' => 'مشت کردن: پوست روشن',
    '✊🏽' => 'مشت کردن: پوست طلایی',
    '✊🏾' => 'مشت کردن: پوست گندمی',
    '✊🏿' => 'مشت کردن: پوست آبنوسی',
    '👊🏻' => 'مشت گره‌کرده: پوست سفید',
    '👊🏼' => 'مشت گره‌کرده: پوست روشن',
    '👊🏽' => 'مشت گره‌کرده: پوست طلایی',
    '👊🏾' => 'مشت گره‌کرده: پوست گندمی',
    '👊🏿' => 'مشت گره‌کرده: پوست آبنوسی',
    '🤛🏻' => 'مشت به چپ: پوست سفید',
    '🤛🏼' => 'مشت به چپ: پوست روشن',
    '🤛🏽' => 'مشت به چپ: پوست طلایی',
    '🤛🏾' => 'مشت به چپ: پوست گندمی',
    '🤛🏿' => 'مشت به چپ: پوست آبنوسی',
    '🤜🏻' => 'مشت به راست: پوست سفید',
    '🤜🏼' => 'مشت به راست: پوست روشن',
    '🤜🏽' => 'مشت به راست: پوست طلایی',
    '🤜🏾' => 'مشت به راست: پوست گندمی',
    '🤜🏿' => 'مشت به راست: پوست آبنوسی',
    '👏🏻' => 'دست زدن: پوست سفید',
    '👏🏼' => 'دست زدن: پوست روشن',
    '👏🏽' => 'دست زدن: پوست طلایی',
    '👏🏾' => 'دست زدن: پوست گندمی',
    '👏🏿' => 'دست زدن: پوست آبنوسی',
    '🙌🏻' => 'دست‌های بالا آورده: پوست سفید',
    '🙌🏼' => 'دست‌های بالا آورده: پوست روشن',
    '🙌🏽' => 'دست‌های بالا آورده: پوست طلایی',
    '🙌🏾' => 'دست‌های بالا آورده: پوست گندمی',
    '🙌🏿' => 'دست‌های بالا آورده: پوست آبنوسی',
    '🫶🏻' => 'شکل قلب با دست: پوست سفید',
    '🫶🏼' => 'شکل قلب با دست: پوست روشن',
    '🫶🏽' => 'شکل قلب با دست: پوست طلایی',
    '🫶🏾' => 'شکل قلب با دست: پوست گندمی',
    '🫶🏿' => 'شکل قلب با دست: پوست آبنوسی',
    '👐🏻' => 'دست‌های باز: پوست سفید',
    '👐🏼' => 'دست‌های باز: پوست روشن',
    '👐🏽' => 'دست‌های باز: پوست طلایی',
    '👐🏾' => 'دست‌های باز: پوست گندمی',
    '👐🏿' => 'دست‌های باز: پوست آبنوسی',
    '🤲🏻' => 'دست دعا: پوست سفید',
    '🤲🏼' => 'دست دعا: پوست روشن',
    '🤲🏽' => 'دست دعا: پوست طلایی',
    '🤲🏾' => 'دست دعا: پوست گندمی',
    '🤲🏿' => 'دست دعا: پوست آبنوسی',
    '🤝🏻' => 'دست دادن: پوست سفید',
    '🤝🏼' => 'دست دادن: پوست روشن',
    '🤝🏽' => 'دست دادن: پوست طلایی',
    '🤝🏾' => 'دست دادن: پوست گندمی',
    '🤝🏿' => 'دست دادن: پوست آبنوسی',
    '🙏🏻' => 'خواهش می‌کنم: پوست سفید',
    '🙏🏼' => 'خواهش می‌کنم: پوست روشن',
    '🙏🏽' => 'خواهش می‌کنم: پوست طلایی',
    '🙏🏾' => 'خواهش می‌کنم: پوست گندمی',
    '🙏🏿' => 'خواهش می‌کنم: پوست آبنوسی',
    '✍🏻' => 'نوشتن با دست: پوست سفید',
    '✍🏼' => 'نوشتن با دست: پوست روشن',
    '✍🏽' => 'نوشتن با دست: پوست طلایی',
    '✍🏾' => 'نوشتن با دست: پوست گندمی',
    '✍🏿' => 'نوشتن با دست: پوست آبنوسی',
    '💅🏻' => 'لاک زدن: پوست سفید',
    '💅🏼' => 'لاک زدن: پوست روشن',
    '💅🏽' => 'لاک زدن: پوست طلایی',
    '💅🏾' => 'لاک زدن: پوست گندمی',
    '💅🏿' => 'لاک زدن: پوست آبنوسی',
    '🤳🏻' => 'خودگرفت: پوست سفید',
    '🤳🏼' => 'خودگرفت: پوست روشن',
    '🤳🏽' => 'خودگرفت: پوست طلایی',
    '🤳🏾' => 'خودگرفت: پوست گندمی',
    '🤳🏿' => 'خودگرفت: پوست آبنوسی',
    '💪🏻' => 'عضلهٔ بازو: پوست سفید',
    '💪🏼' => 'عضلهٔ بازو: پوست روشن',
    '💪🏽' => 'عضلهٔ بازو: پوست طلایی',
    '💪🏾' => 'عضلهٔ بازو: پوست گندمی',
    '💪🏿' => 'عضلهٔ بازو: پوست آبنوسی',
    '🦵🏻' => 'لنگ: پوست سفید',
    '🦵🏼' => 'لنگ: پوست روشن',
    '🦵🏽' => 'لنگ: پوست طلایی',
    '🦵🏾' => 'لنگ: پوست گندمی',
    '🦵🏿' => 'لنگ: پوست آبنوسی',
    '🦶🏻' => 'پا: پوست سفید',
    '🦶🏼' => 'پا: پوست روشن',
    '🦶🏽' => 'پا: پوست طلایی',
    '🦶🏾' => 'پا: پوست گندمی',
    '🦶🏿' => 'پا: پوست آبنوسی',
    '👂🏻' => 'گوش: پوست سفید',
    '👂🏼' => 'گوش: پوست روشن',
    '👂🏽' => 'گوش: پوست طلایی',
    '👂🏾' => 'گوش: پوست گندمی',
    '👂🏿' => 'گوش: پوست آبنوسی',
    '🦻🏻' => 'سمعک در گوش: پوست سفید',
    '🦻🏼' => 'سمعک در گوش: پوست روشن',
    '🦻🏽' => 'سمعک در گوش: پوست طلایی',
    '🦻🏾' => 'سمعک در گوش: پوست گندمی',
    '🦻🏿' => 'سمعک در گوش: پوست آبنوسی',
    '👃🏻' => 'بینی: پوست سفید',
    '👃🏼' => 'بینی: پوست روشن',
    '👃🏽' => 'بینی: پوست طلایی',
    '👃🏾' => 'بینی: پوست گندمی',
    '👃🏿' => 'بینی: پوست آبنوسی',
    '👶🏻' => 'نوزاد: پوست سفید',
    '👶🏼' => 'نوزاد: پوست روشن',
    '👶🏽' => 'نوزاد: پوست طلایی',
    '👶🏾' => 'نوزاد: پوست گندمی',
    '👶🏿' => 'نوزاد: پوست آبنوسی',
    '🧒🏻' => 'بچه: پوست سفید',
    '🧒🏼' => 'بچه: پوست روشن',
    '🧒🏽' => 'بچه: پوست طلایی',
    '🧒🏾' => 'بچه: پوست گندمی',
    '🧒🏿' => 'بچه: پوست آبنوسی',
    '👦🏻' => 'پسر: پوست سفید',
    '👦🏼' => 'پسر: پوست روشن',
    '👦🏽' => 'پسر: پوست طلایی',
    '👦🏾' => 'پسر: پوست گندمی',
    '👦🏿' => 'پسر: پوست آبنوسی',
    '👧🏻' => 'دختر: پوست سفید',
    '👧🏼' => 'دختر: پوست روشن',
    '👧🏽' => 'دختر: پوست طلایی',
    '👧🏾' => 'دختر: پوست گندمی',
    '👧🏿' => 'دختر: پوست آبنوسی',
    '🧑🏻' => 'شخص: پوست سفید',
    '🧑🏼' => 'شخص: پوست روشن',
    '🧑🏽' => 'شخص: پوست طلایی',
    '🧑🏾' => 'شخص: پوست گندمی',
    '🧑🏿' => 'شخص: پوست آبنوسی',
    '👱🏻' => 'آدم: پوست سفید،‏ موبلوند',
    '👱🏼' => 'آدم: پوست روشن،‏ موبلوند',
    '👱🏽' => 'آدم: پوست طلایی،‏ موبلوند',
    '👱🏾' => 'آدم: پوست گندمی،‏ موبلوند',
    '👱🏿' => 'آدم: پوست آبنوسی،‏ موبلوند',
    '👨🏻' => 'مرد: پوست سفید',
    '👨🏼' => 'مرد: پوست روشن',
    '👨🏽' => 'مرد: پوست طلایی',
    '👨🏾' => 'مرد: پوست گندمی',
    '👨🏿' => 'مرد: پوست آبنوسی',
    '🧔🏻' => 'مرد: پوست سفید،‏ ریش‌دار',
    '🧔🏼' => 'مرد: پوست روشن،‏ ریش‌دار',
    '🧔🏽' => 'مرد: پوست طلایی،‏ ریش‌دار',
    '🧔🏾' => 'مرد: پوست گندمی،‏ ریش‌دار',
    '🧔🏿' => 'مرد: پوست آبنوسی،‏ ریش‌دار',
    '👩🏻' => 'زن: پوست سفید',
    '👩🏼' => 'زن: پوست روشن',
    '👩🏽' => 'زن: پوست طلایی',
    '👩🏾' => 'زن: پوست گندمی',
    '👩🏿' => 'زن: پوست آبنوسی',
    '🧓🏻' => 'میان‌سال: پوست سفید',
    '🧓🏼' => 'میان‌سال: پوست روشن',
    '🧓🏽' => 'میان‌سال: پوست طلایی',
    '🧓🏾' => 'میان‌سال: پوست گندمی',
    '🧓🏿' => 'میان‌سال: پوست آبنوسی',
    '👴🏻' => 'پیرمرد: پوست سفید',
    '👴🏼' => 'پیرمرد: پوست روشن',
    '👴🏽' => 'پیرمرد: پوست طلایی',
    '👴🏾' => 'پیرمرد: پوست گندمی',
    '👴🏿' => 'پیرمرد: پوست آبنوسی',
    '👵🏻' => 'پیرزن: پوست سفید',
    '👵🏼' => 'پیرزن: پوست روشن',
    '👵🏽' => 'پیرزن: پوست طلایی',
    '👵🏾' => 'پیرزن: پوست گندمی',
    '👵🏿' => 'پیرزن: پوست آبنوسی',
    '🙍🏻' => 'آدم اخمو: پوست سفید',
    '🙍🏼' => 'آدم اخمو: پوست روشن',
    '🙍🏽' => 'آدم اخمو: پوست طلایی',
    '🙍🏾' => 'آدم اخمو: پوست گندمی',
    '🙍🏿' => 'آدم اخمو: پوست آبنوسی',
    '🙎🏻' => 'آدم ناراضی: پوست سفید',
    '🙎🏼' => 'آدم ناراضی: پوست روشن',
    '🙎🏽' => 'آدم ناراضی: پوست طلایی',
    '🙎🏾' => 'آدم ناراضی: پوست گندمی',
    '🙎🏿' => 'آدم ناراضی: پوست آبنوسی',
    '🙅🏻' => 'ابداً نه: پوست سفید',
    '🙅🏼' => 'ابداً نه: پوست روشن',
    '🙅🏽' => 'ابداً نه: پوست طلایی',
    '🙅🏾' => 'ابداً نه: پوست گندمی',
    '🙅🏿' => 'ابداً نه: پوست آبنوسی',
    '🙆🏻' => 'باشه: پوست سفید',
    '🙆🏼' => 'باشه: پوست روشن',
    '🙆🏽' => 'باشه: پوست طلایی',
    '🙆🏾' => 'باشه: پوست گندمی',
    '🙆🏿' => 'باشه: پوست آبنوسی',
    '💁🏻' => 'آماده کمک: پوست سفید',
    '💁🏼' => 'آماده کمک: پوست روشن',
    '💁🏽' => 'آماده کمک: پوست طلایی',
    '💁🏾' => 'آماده کمک: پوست گندمی',
    '💁🏿' => 'آماده کمک: پوست آبنوسی',
    '🙋🏻' => 'ای ول: پوست سفید',
    '🙋🏼' => 'ای ول: پوست روشن',
    '🙋🏽' => 'ای ول: پوست طلایی',
    '🙋🏾' => 'ای ول: پوست گندمی',
    '🙋🏿' => 'ای ول: پوست آبنوسی',
    '🧏🏻' => 'آدم ناشنوا: پوست سفید',
    '🧏🏼' => 'آدم ناشنوا: پوست روشن',
    '🧏🏽' => 'آدم ناشنوا: پوست طلایی',
    '🧏🏾' => 'آدم ناشنوا: پوست گندمی',
    '🧏🏿' => 'آدم ناشنوا: پوست آبنوسی',
    '🙇🏻' => 'عذرخواهی: پوست سفید',
    '🙇🏼' => 'عذرخواهی: پوست روشن',
    '🙇🏽' => 'عذرخواهی: پوست طلایی',
    '🙇🏾' => 'عذرخواهی: پوست گندمی',
    '🙇🏿' => 'عذرخواهی: پوست آبنوسی',
    '🤦🏻' => 'با کف دست به پیشانی زدن: پوست سفید',
    '🤦🏼' => 'با کف دست به پیشانی زدن: پوست روشن',
    '🤦🏽' => 'با کف دست به پیشانی زدن: پوست طلایی',
    '🤦🏾' => 'با کف دست به پیشانی زدن: پوست گندمی',
    '🤦🏿' => 'با کف دست به پیشانی زدن: پوست آبنوسی',
    '🤷🏻' => 'شانه بالا انداختن: پوست سفید',
    '🤷🏼' => 'شانه بالا انداختن: پوست روشن',
    '🤷🏽' => 'شانه بالا انداختن: پوست طلایی',
    '🤷🏾' => 'شانه بالا انداختن: پوست گندمی',
    '🤷🏿' => 'شانه بالا انداختن: پوست آبنوسی',
    '👮🏻' => 'پلیس: پوست سفید',
    '👮🏼' => 'پلیس: پوست روشن',
    '👮🏽' => 'پلیس: پوست طلایی',
    '👮🏾' => 'پلیس: پوست گندمی',
    '👮🏿' => 'پلیس: پوست آبنوسی',
    '🕵🏻' => 'کارآگاه: پوست سفید',
    '🕵🏼' => 'کارآگاه: پوست روشن',
    '🕵🏽' => 'کارآگاه: پوست طلایی',
    '🕵🏾' => 'کارآگاه: پوست گندمی',
    '🕵🏿' => 'کارآگاه: پوست آبنوسی',
    '💂🏻' => 'گارد نظامی: پوست سفید',
    '💂🏼' => 'گارد نظامی: پوست روشن',
    '💂🏽' => 'گارد نظامی: پوست طلایی',
    '💂🏾' => 'گارد نظامی: پوست گندمی',
    '💂🏿' => 'گارد نظامی: پوست آبنوسی',
    '🥷🏻' => 'نینجا: پوست سفید',
    '🥷🏼' => 'نینجا: پوست روشن',
    '🥷🏽' => 'نینجا: پوست طلایی',
    '🥷🏾' => 'نینجا: پوست گندمی',
    '🥷🏿' => 'نینجا: پوست آبنوسی',
    '👷🏻' => 'کارگر: پوست سفید',
    '👷🏼' => 'کارگر: پوست روشن',
    '👷🏽' => 'کارگر: پوست طلایی',
    '👷🏾' => 'کارگر: پوست گندمی',
    '👷🏿' => 'کارگر: پوست آبنوسی',
    '🫅🏻' => 'آدم تاج‌دار: پوست سفید',
    '🫅🏼' => 'آدم تاج‌دار: پوست روشن',
    '🫅🏽' => 'آدم تاج‌دار: پوست طلایی',
    '🫅🏾' => 'آدم تاج‌دار: پوست گندمی',
    '🫅🏿' => 'آدم تاج‌دار: پوست آبنوسی',
    '🤴🏻' => 'شاهزاده: پوست سفید',
    '🤴🏼' => 'شاهزاده: پوست روشن',
    '🤴🏽' => 'شاهزاده: پوست طلایی',
    '🤴🏾' => 'شاهزاده: پوست گندمی',
    '🤴🏿' => 'شاهزاده: پوست آبنوسی',
    '👸🏻' => 'شاهزاده خانم: پوست سفید',
    '👸🏼' => 'شاهزاده خانم: پوست روشن',
    '👸🏽' => 'شاهزاده خانم: پوست طلایی',
    '👸🏾' => 'شاهزاده خانم: پوست گندمی',
    '👸🏿' => 'شاهزاده خانم: پوست آبنوسی',
    '👳🏻' => 'مرد عمامه‌دار: پوست سفید',
    '👳🏼' => 'مرد عمامه‌دار: پوست روشن',
    '👳🏽' => 'مرد عمامه‌دار: پوست طلایی',
    '👳🏾' => 'مرد عمامه‌دار: پوست گندمی',
    '👳🏿' => 'مرد عمامه‌دار: پوست آبنوسی',
    '👲🏻' => 'مرد با کلاه چینی: پوست سفید',
    '👲🏼' => 'مرد با کلاه چینی: پوست روشن',
    '👲🏽' => 'مرد با کلاه چینی: پوست طلایی',
    '👲🏾' => 'مرد با کلاه چینی: پوست گندمی',
    '👲🏿' => 'مرد با کلاه چینی: پوست آبنوسی',
    '🧕🏻' => 'زن با روسری: پوست سفید',
    '🧕🏼' => 'زن با روسری: پوست روشن',
    '🧕🏽' => 'زن با روسری: پوست طلایی',
    '🧕🏾' => 'زن با روسری: پوست گندمی',
    '🧕🏿' => 'زن با روسری: پوست آبنوسی',
    '🤵🏻' => 'شخص با کت و شلوار و پاپیون: پوست سفید',
    '🤵🏼' => 'شخص با کت و شلوار و پاپیون: پوست روشن',
    '🤵🏽' => 'شخص با کت و شلوار و پاپیون: پوست طلایی',
    '🤵🏾' => 'شخص با کت و شلوار و پاپیون: پوست گندمی',
    '🤵🏿' => 'شخص با کت و شلوار و پاپیون: پوست آبنوسی',
    '👰🏻' => 'شخص با تور عروس: پوست سفید',
    '👰🏼' => 'شخص با تور عروس: پوست روشن',
    '👰🏽' => 'شخص با تور عروس: پوست طلایی',
    '👰🏾' => 'شخص با تور عروس: پوست گندمی',
    '👰🏿' => 'شخص با تور عروس: پوست آبنوسی',
    '🤰🏻' => 'زن باردار: پوست سفید',
    '🤰🏼' => 'زن باردار: پوست روشن',
    '🤰🏽' => 'زن باردار: پوست طلایی',
    '🤰🏾' => 'زن باردار: پوست گندمی',
    '🤰🏿' => 'زن باردار: پوست آبنوسی',
    '🫃🏻' => 'مرد باردار: پوست سفید',
    '🫃🏼' => 'مرد باردار: پوست روشن',
    '🫃🏽' => 'مرد باردار: پوست طلایی',
    '🫃🏾' => 'مرد باردار: پوست گندمی',
    '🫃🏿' => 'مرد باردار: پوست آبنوسی',
    '🫄🏻' => 'آدم باردار: پوست سفید',
    '🫄🏼' => 'آدم باردار: پوست روشن',
    '🫄🏽' => 'آدم باردار: پوست طلایی',
    '🫄🏾' => 'آدم باردار: پوست گندمی',
    '🫄🏿' => 'آدم باردار: پوست آبنوسی',
    '🤱🏻' => 'تغذیه با شیر مادر: پوست سفید',
    '🤱🏼' => 'تغذیه با شیر مادر: پوست روشن',
    '🤱🏽' => 'تغذیه با شیر مادر: پوست طلایی',
    '🤱🏾' => 'تغذیه با شیر مادر: پوست گندمی',
    '🤱🏿' => 'تغذیه با شیر مادر: پوست آبنوسی',
    '👼🏻' => 'فرشته کوچولو: پوست سفید',
    '👼🏼' => 'فرشته کوچولو: پوست روشن',
    '👼🏽' => 'فرشته کوچولو: پوست طلایی',
    '👼🏾' => 'فرشته کوچولو: پوست گندمی',
    '👼🏿' => 'فرشته کوچولو: پوست آبنوسی',
    '🎅🏻' => 'بابا نوئل: پوست سفید',
    '🎅🏼' => 'بابا نوئل: پوست روشن',
    '🎅🏽' => 'بابا نوئل: پوست طلایی',
    '🎅🏾' => 'بابا نوئل: پوست گندمی',
    '🎅🏿' => 'بابا نوئل: پوست آبنوسی',
    '🤶🏻' => 'مامان نوئل: پوست سفید',
    '🤶🏼' => 'مامان نوئل: پوست روشن',
    '🤶🏽' => 'مامان نوئل: پوست طلایی',
    '🤶🏾' => 'مامان نوئل: پوست گندمی',
    '🤶🏿' => 'مامان نوئل: پوست آبنوسی',
    '🦸🏻' => 'ابرقهرمان: پوست سفید',
    '🦸🏼' => 'ابرقهرمان: پوست روشن',
    '🦸🏽' => 'ابرقهرمان: پوست طلایی',
    '🦸🏾' => 'ابرقهرمان: پوست گندمی',
    '🦸🏿' => 'ابرقهرمان: پوست آبنوسی',
    '🦹🏻' => 'ابرشرور: پوست سفید',
    '🦹🏼' => 'ابرشرور: پوست روشن',
    '🦹🏽' => 'ابرشرور: پوست طلایی',
    '🦹🏾' => 'ابرشرور: پوست گندمی',
    '🦹🏿' => 'ابرشرور: پوست آبنوسی',
    '🧙🏻' => 'ساحر: پوست سفید',
    '🧙🏼' => 'ساحر: پوست روشن',
    '🧙🏽' => 'ساحر: پوست طلایی',
    '🧙🏾' => 'ساحر: پوست گندمی',
    '🧙🏿' => 'ساحر: پوست آبنوسی',
    '🧚🏻' => 'پری: پوست سفید',
    '🧚🏼' => 'پری: پوست روشن',
    '🧚🏽' => 'پری: پوست طلایی',
    '🧚🏾' => 'پری: پوست گندمی',
    '🧚🏿' => 'پری: پوست آبنوسی',
    '🧛🏻' => 'خون‌آشام: پوست سفید',
    '🧛🏼' => 'خون‌آشام: پوست روشن',
    '🧛🏽' => 'خون‌آشام: پوست طلایی',
    '🧛🏾' => 'خون‌آشام: پوست گندمی',
    '🧛🏿' => 'خون‌آشام: پوست آبنوسی',
    '🧜🏻' => 'دریامردمان: پوست سفید',
    '🧜🏼' => 'دریامردمان: پوست روشن',
    '🧜🏽' => 'دریامردمان: پوست طلایی',
    '🧜🏾' => 'دریامردمان: پوست گندمی',
    '🧜🏿' => 'دریامردمان: پوست آبنوسی',
    '🧝🏻' => 'اِلف: پوست سفید',
    '🧝🏼' => 'اِلف: پوست روشن',
    '🧝🏽' => 'اِلف: پوست طلایی',
    '🧝🏾' => 'اِلف: پوست گندمی',
    '🧝🏿' => 'اِلف: پوست آبنوسی',
    '💆🏻' => 'ماساژ صورت: پوست سفید',
    '💆🏼' => 'ماساژ صورت: پوست روشن',
    '💆🏽' => 'ماساژ صورت: پوست طلایی',
    '💆🏾' => 'ماساژ صورت: پوست گندمی',
    '💆🏿' => 'ماساژ صورت: پوست آبنوسی',
    '💇🏻' => 'آرایشگاه: پوست سفید',
    '💇🏼' => 'آرایشگاه: پوست روشن',
    '💇🏽' => 'آرایشگاه: پوست طلایی',
    '💇🏾' => 'آرایشگاه: پوست گندمی',
    '💇🏿' => 'آرایشگاه: پوست آبنوسی',
    '🚶🏻' => 'عابر پیاده: پوست سفید',
    '🚶🏼' => 'عابر پیاده: پوست روشن',
    '🚶🏽' => 'عابر پیاده: پوست طلایی',
    '🚶🏾' => 'عابر پیاده: پوست گندمی',
    '🚶🏿' => 'عابر پیاده: پوست آبنوسی',
    '🧍🏻' => 'آدم ایستاده: پوست سفید',
    '🧍🏼' => 'آدم ایستاده: پوست روشن',
    '🧍🏽' => 'آدم ایستاده: پوست طلایی',
    '🧍🏾' => 'آدم ایستاده: پوست گندمی',
    '🧍🏿' => 'آدم ایستاده: پوست آبنوسی',
    '🧎🏻' => 'آدم زانوزده: پوست سفید',
    '🧎🏼' => 'آدم زانوزده: پوست روشن',
    '🧎🏽' => 'آدم زانوزده: پوست طلایی',
    '🧎🏾' => 'آدم زانوزده: پوست گندمی',
    '🧎🏿' => 'آدم زانوزده: پوست آبنوسی',
    '🏃🏻' => 'دونده: پوست سفید',
    '🏃🏼' => 'دونده: پوست روشن',
    '🏃🏽' => 'دونده: پوست طلایی',
    '🏃🏾' => 'دونده: پوست گندمی',
    '🏃🏿' => 'دونده: پوست آبنوسی',
    '💃🏻' => 'رقاص: پوست سفید',
    '💃🏼' => 'رقاص: پوست روشن',
    '💃🏽' => 'رقاص: پوست طلایی',
    '💃🏾' => 'رقاص: پوست گندمی',
    '💃🏿' => 'رقاص: پوست آبنوسی',
    '🕺🏻' => 'مرد درحال رقص: پوست سفید',
    '🕺🏼' => 'مرد درحال رقص: پوست روشن',
    '🕺🏽' => 'مرد درحال رقص: پوست طلایی',
    '🕺🏾' => 'مرد درحال رقص: پوست گندمی',
    '🕺🏿' => 'مرد درحال رقص: پوست آبنوسی',
    '🕴🏻' => 'پرواز مرد با لباس رسمی: پوست سفید',
    '🕴🏼' => 'پرواز مرد با لباس رسمی: پوست روشن',
    '🕴🏽' => 'پرواز مرد با لباس رسمی: پوست طلایی',
    '🕴🏾' => 'پرواز مرد با لباس رسمی: پوست گندمی',
    '🕴🏿' => 'پرواز مرد با لباس رسمی: پوست آبنوسی',
    '👯🏻' => 'رقص: پوست سفید',
    '👯🏼' => 'رقص: پوست روشن',
    '👯🏽' => 'رقص: پوست طلایی',
    '👯🏾' => 'رقص: پوست گندمی',
    '👯🏿' => 'رقص: پوست آبنوسی',
    '🧖🏻' => 'فردی در حمام بخار: پوست سفید',
    '🧖🏼' => 'فردی در حمام بخار: پوست روشن',
    '🧖🏽' => 'فردی در حمام بخار: پوست طلایی',
    '🧖🏾' => 'فردی در حمام بخار: پوست گندمی',
    '🧖🏿' => 'فردی در حمام بخار: پوست آبنوسی',
    '🧗🏻' => 'فردی کوه‌نوردی می‌کند: پوست سفید',
    '🧗🏼' => 'فردی کوه‌نوردی می‌کند: پوست روشن',
    '🧗🏽' => 'فردی کوه‌نوردی می‌کند: پوست طلایی',
    '🧗🏾' => 'فردی کوه‌نوردی می‌کند: پوست گندمی',
    '🧗🏿' => 'فردی کوه‌نوردی می‌کند: پوست آبنوسی',
    '🏇🏻' => 'مسابقه اسب‌سواری: پوست سفید',
    '🏇🏼' => 'مسابقه اسب‌سواری: پوست روشن',
    '🏇🏽' => 'مسابقه اسب‌سواری: پوست طلایی',
    '🏇🏾' => 'مسابقه اسب‌سواری: پوست گندمی',
    '🏇🏿' => 'مسابقه اسب‌سواری: پوست آبنوسی',
    '🏂🏻' => 'اسنوبرد: پوست سفید',
    '🏂🏼' => 'اسنوبرد: پوست روشن',
    '🏂🏽' => 'اسنوبرد: پوست طلایی',
    '🏂🏾' => 'اسنوبرد: پوست گندمی',
    '🏂🏿' => 'اسنوبرد: پوست آبنوسی',
    '🏌🏻' => 'گلف‌باز: پوست سفید',
    '🏌🏼' => 'گلف‌باز: پوست روشن',
    '🏌🏽' => 'گلف‌باز: پوست طلایی',
    '🏌🏾' => 'گلف‌باز: پوست گندمی',
    '🏌🏿' => 'گلف‌باز: پوست آبنوسی',
    '🏄🏻' => 'موج‌سوار: پوست سفید',
    '🏄🏼' => 'موج‌سوار: پوست روشن',
    '🏄🏽' => 'موج‌سوار: پوست طلایی',
    '🏄🏾' => 'موج‌سوار: پوست گندمی',
    '🏄🏿' => 'موج‌سوار: پوست آبنوسی',
    '🚣🏻' => 'قایق پارویی: پوست سفید',
    '🚣🏼' => 'قایق پارویی: پوست روشن',
    '🚣🏽' => 'قایق پارویی: پوست طلایی',
    '🚣🏾' => 'قایق پارویی: پوست گندمی',
    '🚣🏿' => 'قایق پارویی: پوست آبنوسی',
    '🏊🏻' => 'شناگر: پوست سفید',
    '🏊🏼' => 'شناگر: پوست روشن',
    '🏊🏽' => 'شناگر: پوست طلایی',
    '🏊🏾' => 'شناگر: پوست گندمی',
    '🏊🏿' => 'شناگر: پوست آبنوسی',
    '⛹🏻' => 'شخص با توپ: پوست سفید',
    '⛹🏼' => 'شخص با توپ: پوست روشن',
    '⛹🏽' => 'شخص با توپ: پوست طلایی',
    '⛹🏾' => 'شخص با توپ: پوست گندمی',
    '⛹🏿' => 'شخص با توپ: پوست آبنوسی',
    '🏋🏻' => 'وزنه‌بردار: پوست سفید',
    '🏋🏼' => 'وزنه‌بردار: پوست روشن',
    '🏋🏽' => 'وزنه‌بردار: پوست طلایی',
    '🏋🏾' => 'وزنه‌بردار: پوست گندمی',
    '🏋🏿' => 'وزنه‌بردار: پوست آبنوسی',
    '🚴🏻' => 'دوچرخه‌سوار: پوست سفید',
    '🚴🏼' => 'دوچرخه‌سوار: پوست روشن',
    '🚴🏽' => 'دوچرخه‌سوار: پوست طلایی',
    '🚴🏾' => 'دوچرخه‌سوار: پوست گندمی',
    '🚴🏿' => 'دوچرخه‌سوار: پوست آبنوسی',
    '🚵🏻' => 'دوچرخه کوهستان: پوست سفید',
    '🚵🏼' => 'دوچرخه کوهستان: پوست روشن',
    '🚵🏽' => 'دوچرخه کوهستان: پوست طلایی',
    '🚵🏾' => 'دوچرخه کوهستان: پوست گندمی',
    '🚵🏿' => 'دوچرخه کوهستان: پوست آبنوسی',
    '🤸🏻' => 'حرکت چرخ و فلک: پوست سفید',
    '🤸🏼' => 'حرکت چرخ و فلک: پوست روشن',
    '🤸🏽' => 'حرکت چرخ و فلک: پوست طلایی',
    '🤸🏾' => 'حرکت چرخ و فلک: پوست گندمی',
    '🤸🏿' => 'حرکت چرخ و فلک: پوست آبنوسی',
    '🤼🏻' => 'کُشتی‌گیران: پوست سفید',
    '🤼🏼' => 'کُشتی‌گیران: پوست روشن',
    '🤼🏽' => 'کُشتی‌گیران: پوست طلایی',
    '🤼🏾' => 'کُشتی‌گیران: پوست گندمی',
    '🤼🏿' => 'کُشتی‌گیران: پوست آبنوسی',
    '🤽🏻' => 'واترپلو: پوست سفید',
    '🤽🏼' => 'واترپلو: پوست روشن',
    '🤽🏽' => 'واترپلو: پوست طلایی',
    '🤽🏾' => 'واترپلو: پوست گندمی',
    '🤽🏿' => 'واترپلو: پوست آبنوسی',
    '🤾🏻' => 'هندبال: پوست سفید',
    '🤾🏼' => 'هندبال: پوست روشن',
    '🤾🏽' => 'هندبال: پوست طلایی',
    '🤾🏾' => 'هندبال: پوست گندمی',
    '🤾🏿' => 'هندبال: پوست آبنوسی',
    '🤹🏻' => 'ژانگولربازی: پوست سفید',
    '🤹🏼' => 'ژانگولربازی: پوست روشن',
    '🤹🏽' => 'ژانگولربازی: پوست طلایی',
    '🤹🏾' => 'ژانگولربازی: پوست گندمی',
    '🤹🏿' => 'ژانگولربازی: پوست آبنوسی',
    '🧘🏻' => 'فرد در حالت خلسه: پوست سفید',
    '🧘🏼' => 'فرد در حالت خلسه: پوست روشن',
    '🧘🏽' => 'فرد در حالت خلسه: پوست طلایی',
    '🧘🏾' => 'فرد در حالت خلسه: پوست گندمی',
    '🧘🏿' => 'فرد در حالت خلسه: پوست آبنوسی',
    '🛀🏻' => 'فرد در وان: پوست سفید',
    '🛀🏼' => 'فرد در وان: پوست روشن',
    '🛀🏽' => 'فرد در وان: پوست طلایی',
    '🛀🏾' => 'فرد در وان: پوست گندمی',
    '🛀🏿' => 'فرد در وان: پوست آبنوسی',
    '🛌🏻' => 'فرد در تختخواب: پوست سفید',
    '🛌🏼' => 'فرد در تختخواب: پوست روشن',
    '🛌🏽' => 'فرد در تختخواب: پوست طلایی',
    '🛌🏾' => 'فرد در تختخواب: پوست گندمی',
    '🛌🏿' => 'فرد در تختخواب: پوست آبنوسی',
    '👭🏻' => 'دو زن دست در دست: پوست سفید',
    '👭🏼' => 'دو زن دست در دست: پوست روشن',
    '👭🏽' => 'دو زن دست در دست: پوست طلایی',
    '👭🏾' => 'دو زن دست در دست: پوست گندمی',
    '👭🏿' => 'دو زن دست در دست: پوست آبنوسی',
    '👫🏻' => 'زن و مرد دست در‌ دست: پوست سفید',
    '👫🏼' => 'زن و مرد دست در‌ دست: پوست روشن',
    '👫🏽' => 'زن و مرد دست در‌ دست: پوست طلایی',
    '👫🏾' => 'زن و مرد دست در‌ دست: پوست گندمی',
    '👫🏿' => 'زن و مرد دست در‌ دست: پوست آبنوسی',
    '👬🏻' => 'دو مرد دست در دست: پوست سفید',
    '👬🏼' => 'دو مرد دست در دست: پوست روشن',
    '👬🏽' => 'دو مرد دست در دست: پوست طلایی',
    '👬🏾' => 'دو مرد دست در دست: پوست گندمی',
    '👬🏿' => 'دو مرد دست در دست: پوست آبنوسی',
    '💏🏻' => 'بوسه: پوست سفید',
    '💏🏼' => 'بوسه: پوست روشن',
    '💏🏽' => 'بوسه: پوست طلایی',
    '💏🏾' => 'بوسه: پوست گندمی',
    '💏🏿' => 'بوسه: پوست آبنوسی',
    '💑🏻' => 'زوج عاشق: پوست سفید',
    '💑🏼' => 'زوج عاشق: پوست روشن',
    '💑🏽' => 'زوج عاشق: پوست طلایی',
    '💑🏾' => 'زوج عاشق: پوست گندمی',
    '💑🏿' => 'زوج عاشق: پوست آبنوسی',
    '🇦🇨' => 'پرچم: جزایر آسنسیون',
    '🇦🇩' => 'پرچم: آندورا',
    '🇦🇪' => 'پرچم: امارات متحدهٔ عربی',
    '🇦🇫' => 'پرچم: افغانستان',
    '🇦🇬' => 'پرچم: آنتیگوا و باربودا',
    '🇦🇮' => 'پرچم: آنگویلا',
    '🇦🇱' => 'پرچم: آلبانی',
    '🇦🇲' => 'پرچم: ارمنستان',
    '🇦🇴' => 'پرچم: آنگولا',
    '🇦🇶' => 'پرچم: جنوبگان',
    '🇦🇷' => 'پرچم: آرژانتین',
    '🇦🇸' => 'پرچم: ساموآی امریکا',
    '🇦🇹' => 'پرچم: اتریش',
    '🇦🇺' => 'پرچم: استرالیا',
    '🇦🇼' => 'پرچم: آروبا',
    '🇦🇽' => 'پرچم: جزایر آلاند',
    '🇦🇿' => 'پرچم: جمهوری آذربایجان',
    '🇧🇦' => 'پرچم: بوسنی و هرزگوین',
    '🇧🇧' => 'پرچم: باربادوس',
    '🇧🇩' => 'پرچم: بنگلادش',
    '🇧🇪' => 'پرچم: بلژیک',
    '🇧🇫' => 'پرچم: بورکینافاسو',
    '🇧🇬' => 'پرچم: بلغارستان',
    '🇧🇭' => 'پرچم: بحرین',
    '🇧🇮' => 'پرچم: بوروندی',
    '🇧🇯' => 'پرچم: بنین',
    '🇧🇱' => 'پرچم: سن بارتلمی',
    '🇧🇲' => 'پرچم: برمودا',
    '🇧🇳' => 'پرچم: برونئی',
    '🇧🇴' => 'پرچم: بولیوی',
    '🇧🇶' => 'پرچم: جزایر کارائیب هلند',
    '🇧🇷' => 'پرچم: برزیل',
    '🇧🇸' => 'پرچم: باهاما',
    '🇧🇹' => 'پرچم: بوتان',
    '🇧🇻' => 'پرچم: جزیرهٔ بووه',
    '🇧🇼' => 'پرچم: بوتسوانا',
    '🇧🇾' => 'پرچم: بلاروس',
    '🇧🇿' => 'پرچم: بلیز',
    '🇨🇦' => 'پرچم: کانادا',
    '🇨🇨' => 'پرچم: جزایر کوکوس',
    '🇨🇩' => 'پرچم: کنگو - کینشاسا',
    '🇨🇫' => 'پرچم: جمهوری افریقای مرکزی',
    '🇨🇬' => 'پرچم: کنگو - برازویل',
    '🇨🇭' => 'پرچم: سوئیس',
    '🇨🇮' => 'پرچم: ساحل عاج',
    '🇨🇰' => 'پرچم: جزایر کوک',
    '🇨🇱' => 'پرچم: شیلی',
    '🇨🇲' => 'پرچم: کامرون',
    '🇨🇳' => 'پرچم: چین',
    '🇨🇴' => 'پرچم: کلمبیا',
    '🇨🇵' => 'پرچم: جزایر کلیپرتون',
    '🇨🇶' => 'پرچم: سارک',
    '🇨🇷' => 'پرچم: کاستاریکا',
    '🇨🇺' => 'پرچم: کوبا',
    '🇨🇻' => 'پرچم: کیپ‌ورد',
    '🇨🇼' => 'پرچم: کوراسائو',
    '🇨🇽' => 'پرچم: جزیرهٔ کریسمس',
    '🇨🇾' => 'پرچم: قبرس',
    '🇨🇿' => 'پرچم: چک',
    '🇩🇪' => 'پرچم: آلمان',
    '🇩🇬' => 'پرچم: دیه‌گو گارسیا',
    '🇩🇯' => 'پرچم: جیبوتی',
    '🇩🇰' => 'پرچم: دانمارک',
    '🇩🇲' => 'پرچم: دومینیکا',
    '🇩🇴' => 'پرچم: جمهوری دومینیکن',
    '🇩🇿' => 'پرچم: الجزایر',
    '🇪🇦' => 'پرچم: سبته و ملیله',
    '🇪🇨' => 'پرچم: اکوادور',
    '🇪🇪' => 'پرچم: استونی',
    '🇪🇬' => 'پرچم: مصر',
    '🇪🇭' => 'پرچم: صحرای غربی',
    '🇪🇷' => 'پرچم: اریتره',
    '🇪🇸' => 'پرچم: اسپانیا',
    '🇪🇹' => 'پرچم: اتیوپی',
    '🇪🇺' => 'پرچم: اتحادیهٔ اروپا',
    '🇫🇮' => 'پرچم: فنلاند',
    '🇫🇯' => 'پرچم: فیجی',
    '🇫🇰' => 'پرچم: جزایر فالکلند',
    '🇫🇲' => 'پرچم: میکرونزی',
    '🇫🇴' => 'پرچم: جزایر فارو',
    '🇫🇷' => 'پرچم: فرانسه',
    '🇬🇦' => 'پرچم: گابن',
    '🇬🇧' => 'پرچم: بریتانیا',
    '🇬🇩' => 'پرچم: گرنادا',
    '🇬🇪' => 'پرچم: گرجستان',
    '🇬🇫' => 'پرچم: گویان فرانسه',
    '🇬🇬' => 'پرچم: گرنزی',
    '🇬🇭' => 'پرچم: غنا',
    '🇬🇮' => 'پرچم: جبل‌الطارق',
    '🇬🇱' => 'پرچم: گرینلند',
    '🇬🇲' => 'پرچم: گامبیا',
    '🇬🇳' => 'پرچم: گینه',
    '🇬🇵' => 'پرچم: گوادلوپ',
    '🇬🇶' => 'پرچم: گینهٔ استوایی',
    '🇬🇷' => 'پرچم: یونان',
    '🇬🇸' => 'پرچم: جورجیای جنوبی و جزایر ساندویچ جنوبی',
    '🇬🇹' => 'پرچم: گواتمالا',
    '🇬🇺' => 'پرچم: گوام',
    '🇬🇼' => 'پرچم: گینهٔ بیسائو',
    '🇬🇾' => 'پرچم: گویان',
    '🇭🇰' => 'پرچم: هنگ‌کنگ، منطقهٔ ویژهٔ اداری چین',
    '🇭🇲' => 'پرچم: هرد و جزایر مک‌دونالد',
    '🇭🇳' => 'پرچم: هندوراس',
    '🇭🇷' => 'پرچم: کرواسی',
    '🇭🇹' => 'پرچم: هائیتی',
    '🇭🇺' => 'پرچم: مجارستان',
    '🇮🇨' => 'پرچم: جزایر قناری',
    '🇮🇩' => 'پرچم: اندونزی',
    '🇮🇪' => 'پرچم: ایرلند',
    '🇮🇱' => 'پرچم: اسرائیل',
    '🇮🇲' => 'پرچم: جزیرهٔ من',
    '🇮🇳' => 'پرچم: هند',
    '🇮🇴' => 'پرچم: قلمرو بریتانیا در اقیانوس هند',
    '🇮🇶' => 'پرچم: عراق',
    '🇮🇷' => 'پرچم: ایران',
    '🇮🇸' => 'پرچم: ایسلند',
    '🇮🇹' => 'پرچم: ایتالیا',
    '🇯🇪' => 'پرچم: جرزی',
    '🇯🇲' => 'پرچم: جامائیکا',
    '🇯🇴' => 'پرچم: اردن',
    '🇯🇵' => 'پرچم: ژاپن',
    '🇰🇪' => 'پرچم: کنیا',
    '🇰🇬' => 'پرچم: قرقیزستان',
    '🇰🇭' => 'پرچم: کامبوج',
    '🇰🇮' => 'پرچم: کیریباتی',
    '🇰🇲' => 'پرچم: کومور',
    '🇰🇳' => 'پرچم: سنت کیتس و نویس',
    '🇰🇵' => 'پرچم: کرهٔ شمالی',
    '🇰🇷' => 'پرچم: کرهٔ جنوبی',
    '🇰🇼' => 'پرچم: کویت',
    '🇰🇾' => 'پرچم: جزایر کِیمن',
    '🇰🇿' => 'پرچم: قزاقستان',
    '🇱🇦' => 'پرچم: لائوس',
    '🇱🇧' => 'پرچم: لبنان',
    '🇱🇨' => 'پرچم: سنت لوسیا',
    '🇱🇮' => 'پرچم: لیختن‌اشتاین',
    '🇱🇰' => 'پرچم: سری‌لانکا',
    '🇱🇷' => 'پرچم: لیبریا',
    '🇱🇸' => 'پرچم: لسوتو',
    '🇱🇹' => 'پرچم: لیتوانی',
    '🇱🇺' => 'پرچم: لوکزامبورگ',
    '🇱🇻' => 'پرچم: لتونی',
    '🇱🇾' => 'پرچم: لیبی',
    '🇲🇦' => 'پرچم: مراکش',
    '🇲🇨' => 'پرچم: موناکو',
    '🇲🇩' => 'پرچم: مولداوی',
    '🇲🇪' => 'پرچم: مونته‌نگرو',
    '🇲🇫' => 'پرچم: سنت مارتین',
    '🇲🇬' => 'پرچم: ماداگاسکار',
    '🇲🇭' => 'پرچم: جزایر مارشال',
    '🇲🇰' => 'پرچم: مقدونیهٔ شمالی',
    '🇲🇱' => 'پرچم: مالی',
    '🇲🇲' => 'پرچم: میانمار (برمه)',
    '🇲🇳' => 'پرچم: مغولستان',
    '🇲🇴' => 'پرچم: ماکائو، منطقهٔ ویژهٔ اداری چین',
    '🇲🇵' => 'پرچم: جزایر ماریانای شمالی',
    '🇲🇶' => 'پرچم: مارتینیک',
    '🇲🇷' => 'پرچم: موریتانی',
    '🇲🇸' => 'پرچم: مونت‌سرات',
    '🇲🇹' => 'پرچم: مالت',
    '🇲🇺' => 'پرچم: موریس',
    '🇲🇻' => 'پرچم: مالدیو',
    '🇲🇼' => 'پرچم: مالاوی',
    '🇲🇽' => 'پرچم: مکزیک',
    '🇲🇾' => 'پرچم: مالزی',
    '🇲🇿' => 'پرچم: موزامبیک',
    '🇳🇦' => 'پرچم: نامیبیا',
    '🇳🇨' => 'پرچم: کالدونیای جدید',
    '🇳🇪' => 'پرچم: نیجر',
    '🇳🇫' => 'پرچم: جزیرهٔ نورفولک',
    '🇳🇬' => 'پرچم: نیجریه',
    '🇳🇮' => 'پرچم: نیکاراگوئه',
    '🇳🇱' => 'پرچم: هلند',
    '🇳🇴' => 'پرچم: نروژ',
    '🇳🇵' => 'پرچم: نپال',
    '🇳🇷' => 'پرچم: نائورو',
    '🇳🇺' => 'پرچم: نیوئه',
    '🇳🇿' => 'پرچم: نیوزیلند',
    '🇴🇲' => 'پرچم: عمان',
    '🇵🇦' => 'پرچم: پاناما',
    '🇵🇪' => 'پرچم: پرو',
    '🇵🇫' => 'پرچم: پلی‌نزی فرانسه',
    '🇵🇬' => 'پرچم: پاپوا گینهٔ نو',
    '🇵🇭' => 'پرچم: فیلیپین',
    '🇵🇰' => 'پرچم: پاکستان',
    '🇵🇱' => 'پرچم: لهستان',
    '🇵🇲' => 'پرچم: سن پیر و میکلن',
    '🇵🇳' => 'پرچم: جزایر پیت‌کرن',
    '🇵🇷' => 'پرچم: پورتوریکو',
    '🇵🇸' => 'پرچم: سرزمین‌های فلسطینی',
    '🇵🇹' => 'پرچم: پرتغال',
    '🇵🇼' => 'پرچم: پالائو',
    '🇵🇾' => 'پرچم: پاراگوئه',
    '🇶🇦' => 'پرچم: قطر',
    '🇷🇪' => 'پرچم: رئونیون',
    '🇷🇴' => 'پرچم: رومانی',
    '🇷🇸' => 'پرچم: صربستان',
    '🇷🇺' => 'پرچم: روسیه',
    '🇷🇼' => 'پرچم: رواندا',
    '🇸🇦' => 'پرچم: عربستان سعودی',
    '🇸🇧' => 'پرچم: جزایر سلیمان',
    '🇸🇨' => 'پرچم: سیشل',
    '🇸🇩' => 'پرچم: سودان',
    '🇸🇪' => 'پرچم: سوئد',
    '🇸🇬' => 'پرچم: سنگاپور',
    '🇸🇭' => 'پرچم: سنت هلن',
    '🇸🇮' => 'پرچم: اسلوونی',
    '🇸🇯' => 'پرچم: سوالبارد و یان ماین',
    '🇸🇰' => 'پرچم: اسلواکی',
    '🇸🇱' => 'پرچم: سیرالئون',
    '🇸🇲' => 'پرچم: سان‌مارینو',
    '🇸🇳' => 'پرچم: سنگال',
    '🇸🇴' => 'پرچم: سومالی',
    '🇸🇷' => 'پرچم: سورینام',
    '🇸🇸' => 'پرچم: سودان جنوبی',
    '🇸🇹' => 'پرچم: سائوتومه و پرینسیپ',
    '🇸🇻' => 'پرچم: السالوادور',
    '🇸🇽' => 'پرچم: سنت مارتن',
    '🇸🇾' => 'پرچم: سوریه',
    '🇸🇿' => 'پرچم: اسواتینی',
    '🇹🇦' => 'پرچم: تریستان دا کونا',
    '🇹🇨' => 'پرچم: جزایر تورکس و کایکوس',
    '🇹🇩' => 'پرچم: چاد',
    '🇹🇫' => 'پرچم: سرزمین‌های جنوبی فرانسه',
    '🇹🇬' => 'پرچم: توگو',
    '🇹🇭' => 'پرچم: تایلند',
    '🇹🇯' => 'پرچم: تاجیکستان',
    '🇹🇰' => 'پرچم: توکلائو',
    '🇹🇱' => 'پرچم: تیمور-لسته',
    '🇹🇲' => 'پرچم: ترکمنستان',
    '🇹🇳' => 'پرچم: تونس',
    '🇹🇴' => 'پرچم: تونگا',
    '🇹🇷' => 'پرچم: ترکیه',
    '🇹🇹' => 'پرچم: ترینیداد و توباگو',
    '🇹🇻' => 'پرچم: تووالو',
    '🇹🇼' => 'پرچم: تایوان',
    '🇹🇿' => 'پرچم: تانزانیا',
    '🇺🇦' => 'پرچم: اوکراین',
    '🇺🇬' => 'پرچم: اوگاندا',
    '🇺🇲' => 'پرچم: جزایر دورافتادهٔ ایالات متحده',
    '🇺🇳' => 'پرچم: سازمان ملل متحد',
    '🇺🇸' => 'پرچم: ایالات متحده',
    '🇺🇾' => 'پرچم: اروگوئه',
    '🇺🇿' => 'پرچم: ازبکستان',
    '🇻🇦' => 'پرچم: واتیکان',
    '🇻🇨' => 'پرچم: سنت وینسنت و گرنادین',
    '🇻🇪' => 'پرچم: ونزوئلا',
    '🇻🇬' => 'پرچم: جزایر ویرجین بریتانیا',
    '🇻🇮' => 'پرچم: جزایر ویرجین ایالات متحده',
    '🇻🇳' => 'پرچم: ویتنام',
    '🇻🇺' => 'پرچم: وانواتو',
    '🇼🇫' => 'پرچم: والیس و فوتونا',
    '🇼🇸' => 'پرچم: ساموآ',
    '🇽🇰' => 'پرچم: کوزوو',
    '🇾🇪' => 'پرچم: یمن',
    '🇾🇹' => 'پرچم: مایوت',
    '🇿🇦' => 'پرچم: افریقای جنوبی',
    '🇿🇲' => 'پرچم: زامبیا',
    '🇿🇼' => 'پرچم: زیمبابوه',
    '🔟' => 'جلد کلید: 10',
    '🏻' => 'پوست سفید',
    '🏼' => 'پوست روشن',
    '🏽' => 'پوست طلایی',
    '🏾' => 'پوست گندمی',
    '🏿' => 'پوست آبنوسی',
    '😀' => 'خنده',
    '😃' => 'صورت خندان',
    '😄' => 'خندان',
    '😁' => 'خندهٔ دندانی',
    '😆' => 'صورت نیشخندزنان با چشم نیم‌باز',
    '😅' => 'صورت خندان و عرق‌کرده',
    '🤣' => 'از خنده غش کردن',
    '😂' => 'صورت با اشک شادی',
    '🙂' => 'لبخند ملایم',
    '🙃' => 'صورت وارونه',
    '🫠' => 'چهره درحال ذوب شدن',
    '😉' => 'چشمک',
    '😊' => 'لبخند خجالتی',
    '😇' => 'هاله‌دار',
    '🥰' => 'صورت خندان و عاشق',
    '😍' => 'چشم‌های عاشق',
    '🤩' => 'فوق‌العاده',
    '😘' => 'بوسه فرستادن',
    '😗' => 'بوسیدن',
    '☺' => 'لبخند',
    '😚' => 'بوسهٔ خجالتی',
    '😙' => 'بوسیدن با چشمان خندان',
    '🥲' => 'چهرهٔ خندان با اشک',
    '😋' => 'صورت درحال لیسیدن لب',
    '😛' => 'صورت با زبان بیرون‌آمده',
    '😜' => 'صورت با چشمک و زبان بیرون آمده',
    '🤪' => 'صورتک لوده',
    '😝' => 'زبونک با چشم بسته',
    '🤑' => 'صورت پول‌دوست',
    '🤗' => 'بغل کردن',
    '🤭' => 'صورتک با دست روی دهان',
    '🫢' => 'چهره با چشمان باز و دست روی دهان',
    '🫣' => 'چهره با نگاه دزدکی',
    '🤫' => 'هیس',
    '🤔' => 'درحال تفکر',
    '🫡' => 'چهره سلام‌کنان',
    '🤐' => 'دهان چفت',
    '🤨' => 'صورت با ابروی بالاداده',
    '😐' => 'خنثی',
    '😑' => 'صورت بی‌حالت',
    '😶' => 'صورت بدون لب',
    '🫥' => 'چهره با خط‌چین',
    '😏' => 'پوزخند',
    '😒' => 'کسل',
    '🙄' => 'نگاه کلافه',
    '😬' => 'دهن‌کجی',
    '🤥' => 'صورت دروغگو',
    '🫨' => 'چهره لرزان',
    '😌' => 'آسوده‌خاطر',
    '😔' => 'چهره غمگین',
    '😪' => 'خواب‌آلود',
    '🤤' => 'آب افتادن دهان',
    '😴' => 'خوابیده',
    '🫩' => 'چهره با چشمان پف‌آلود',
    '😷' => 'صورت با ماسک پزشکی',
    '🤒' => 'تب‌دار',
    '🤕' => 'سر باندپیچی‌شده',
    '🤢' => 'حالت تهوع',
    '🤮' => 'درحال استفراغ',
    '🤧' => 'عطسه',
    '🥵' => 'خیلی گرم',
    '🥶' => 'خیلی سرد',
    '🥴' => 'نشئه',
    '😵' => 'گیج',
    '🤯' => 'سر منفجرشده',
    '🤠' => 'کلاه کابوی',
    '🥳' => 'جشن و سور',
    '🥸' => 'تغییرقیافه داده',
    '😎' => 'باحال',
    '🤓' => 'خوره',
    '🧐' => 'صورت با عینک یک‌چشمی',
    '😕' => 'گیج‌شده',
    '🫤' => 'صورت با دهان کج',
    '😟' => 'چهره نگران',
    '🙁' => 'دلخور',
    '☹' => 'اخمو',
    '😮' => 'دهان باز از تعجب',
    '😯' => 'مات و مبهوت',
    '😲' => 'بهت‌زده',
    '😳' => 'سرخ‌شده',
    '🫪' => 'صورت درهم‌ریخته',
    '🥺' => 'التماس‌کنان',
    '🥹' => 'چهره با چشمان پراشک',
    '😦' => 'چهره درهم‌کشیده با دهان باز',
    '😧' => 'دردمند',
    '😨' => 'ترسیده',
    '😰' => 'عرق ترس',
    '😥' => 'ناامید اما تسکین‌یافته',
    '😢' => 'گریان',
    '😭' => 'هق‌هق گریه',
    '😱' => 'جیغ ترس',
    '😖' => 'سردرگم',
    '😣' => 'پافشاری',
    '😞' => 'ناامید',
    '😓' => 'عرق سرد',
    '😩' => 'ازپاافتاده',
    '😫' => 'صورت خسته',
    '🥱' => 'صورت خمیازه‌کش',
    '😤' => 'ژست برندگی با دلخوری',
    '😡' => 'خشمگین',
    '😠' => 'عصبانی',
    '🤬' => 'صورت با نمادهایی روی دهان',
    '😈' => 'صورت لبخندزنان با دوشاخ',
    '👿' => 'چهره عصبانی با دو شاخ',
    '💀' => 'جمجمه',
    '☠' => 'جمجمه و استخوان صلیبی',
    '💩' => 'یه تپهٔ گه',
    '🤡' => 'دلقک',
    '👹' => 'دیو',
    '👺' => 'جن کوتوله',
    '👻' => 'روح',
    '👽' => 'موجود فضایی',
    '👾' => 'هیولای فضایی',
    '🤖' => 'روبات',
    '😺' => 'گربهٔ خندان',
    '😸' => 'گربه با چشم‌های خندان',
    '😹' => 'گربهٔ خندان با اشک شوق',
    '😻' => 'گربهٔ خندان عاشق',
    '😼' => 'گربه با پوزخند',
    '😽' => 'گربه و بوسهٔ خجالتی',
    '🙀' => 'گربهٔ بهت‌زده',
    '😿' => 'گربهٔ گریان',
    '😾' => 'گربهٔ اخمو',
    '🙈' => 'میمون شرنبین',
    '🙉' => 'میمون شرنشنو',
    '🙊' => 'میمون شرنگو',
    '💌' => 'نامهٔ عاشقانه',
    '💘' => 'قلب تیرخورده',
    '💝' => 'قلب با روبان',
    '💖' => 'قلب درخشان',
    '💗' => 'قلب هیجان‌زده',
    '💓' => 'قلب تپنده',
    '💞' => 'قلب چرخان',
    '💕' => 'دو قلب',
    '💟' => 'قلب تزئینی',
    '❣' => 'علامت تعجب قلبی',
    '💔' => 'قلب شکسته',
    '❤' => 'قلب قرمز',
    '🩷' => 'قلب صورتی',
    '🧡' => 'قلب نارنجی',
    '💛' => 'قلب زرد',
    '💚' => 'قلب سبز',
    '💙' => 'قلب آبی',
    '🩵' => 'قلب آبی کم‌رنگ',
    '💜' => 'قلب بنفش',
    '🤎' => 'قلب قهوه‌ای',
    '🖤' => 'قلب سیاه',
    '🩶' => 'قلب خاکستری',
    '🤍' => 'قلب سفید',
    '💋' => 'بوسه ماتیکی',
    '💯' => '۱۰۰ امتیاز',
    '💢' => 'نماد عصبانیت',
    '🫯' => 'گردوخاک جنگ و جدال',
    '💥' => 'برخورد',
    '💫' => 'سرگیجه',
    '💦' => 'قطره‌های عرق',
    '💨' => 'به سرعت باد',
    '🕳' => 'چاله',
    '💬' => 'بالن گفتار',
    '🗨' => 'حباب گفتار چپ',
    '🗯' => 'حباب خشم راست',
    '💭' => 'بالن افکار',
    '💤' => 'خروپف',
    '👋' => 'تکان دادن دست',
    '🤚' => 'پشت دست روبه بالا',
    '🖐' => 'دست با انگشتان باز',
    '✋' => 'دست بالابرده',
    '🖖' => 'سلام ولکان',
    '🫱' => 'دست به سمت راست',
    '🫲' => 'دست به سمت چپ',
    '🫳' => 'کف دست به پایین',
    '🫴' => 'کف دست به بالا',
    '🫷' => 'دست فشاردهنده به سمت چپ',
    '🫸' => 'دست فشاردهنده به سمت راست',
    '👌' => 'علامت اوکی',
    '🤌' => 'انگشتان جمع‌شده',
    '🤏' => 'دست در حال نیشگون گرفتن',
    '✌' => 'علامت پیروزی',
    '🤞' => 'انگشتان گره خورده',
    '🫰' => 'دست با انگشت اشاره و شست متقاطع',
    '🤟' => 'علامت دوستت دارم',
    '🤘' => 'نماد شاخ',
    '🤙' => 'دست به شکل تلفن',
    '👈' => 'اشاره به چپ',
    '👉' => 'اشاره به راست',
    '👆' => 'اشاره به بالا با پشت دست',
    '🖕' => 'انگشت میانه',
    '👇' => 'اشاره به پایین',
    '☝' => 'اشاره به بالا',
    '🫵' => 'اشاره به بیننده',
    '👍' => 'پسندیدن',
    '👎' => 'نپسندیدن',
    '✊' => 'مشت کردن',
    '👊' => 'مشت گره‌کرده',
    '🤛' => 'مشت به چپ',
    '🤜' => 'مشت به راست',
    '👏' => 'دست زدن',
    '🙌' => 'دست‌های بالا آورده',
    '🫶' => 'شکل قلب با دست',
    '👐' => 'دست‌های باز',
    '🤲' => 'دست دعا',
    '🤝' => 'دست دادن',
    '🙏' => 'خواهش می‌کنم',
    '✍' => 'نوشتن با دست',
    '💅' => 'لاک زدن',
    '🤳' => 'خودگرفت',
    '💪' => 'عضلهٔ بازو',
    '🦾' => 'بازوی مکانیکی',
    '🦿' => 'پای مکانیکی',
    '🦵' => 'لنگ',
    '🦶' => 'پا',
    '👂' => 'گوش',
    '🦻' => 'سمعک در گوش',
    '👃' => 'بینی',
    '🧠' => 'مغز',
    '🫀' => 'قلب',
    '🫁' => 'ریه',
    '🦷' => 'دندان',
    '🦴' => 'استخوان',
    '👀' => 'دو چشم',
    '👁' => 'چشم',
    '👅' => 'زبان',
    '👄' => 'لب',
    '🫦' => 'گازگرفتن لب',
    '👶' => 'نوزاد',
    '🧒' => 'بچه',
    '👦' => 'پسر',
    '👧' => 'دختر',
    '🧑' => 'شخص',
    '👱' => 'آدم: موبلوند',
    '👨' => 'مرد',
    '🧔' => 'مرد: ریش‌دار',
    '👩' => 'زن',
    '🧓' => 'میان‌سال',
    '👴' => 'پیرمرد',
    '👵' => 'پیرزن',
    '🙍' => 'آدم اخمو',
    '🙎' => 'آدم ناراضی',
    '🙅' => 'ابداً نه',
    '🙆' => 'باشه',
    '💁' => 'آماده کمک',
    '🙋' => 'ای ول',
    '🧏' => 'آدم ناشنوا',
    '🙇' => 'عذرخواهی',
    '🤦' => 'با کف دست به پیشانی زدن',
    '🤷' => 'شانه بالا انداختن',
    '👮' => 'پلیس',
    '🕵' => 'کارآگاه',
    '💂' => 'گارد نظامی',
    '🥷' => 'نینجا',
    '👷' => 'کارگر',
    '🫅' => 'آدم تاج‌دار',
    '🤴' => 'شاهزاده',
    '👸' => 'شاهزاده خانم',
    '👳' => 'مرد عمامه‌دار',
    '👲' => 'مرد با کلاه چینی',
    '🧕' => 'زن با روسری',
    '🤵' => 'شخص با کت و شلوار و پاپیون',
    '👰' => 'شخص با تور عروس',
    '🤰' => 'زن باردار',
    '🫃' => 'مرد باردار',
    '🫄' => 'آدم باردار',
    '🤱' => 'تغذیه با شیر مادر',
    '👼' => 'فرشته کوچولو',
    '🎅' => 'بابا نوئل',
    '🤶' => 'مامان نوئل',
    '🦸' => 'ابرقهرمان',
    '🦹' => 'ابرشرور',
    '🧙' => 'ساحر',
    '🧚' => 'پری',
    '🧛' => 'خون‌آشام',
    '🧜' => 'دریامردمان',
    '🧝' => 'اِلف',
    '🧞' => 'جن',
    '🧟' => 'مرده متحرک',
    '🧌' => 'غول',
    '🫈' => 'جانور پشمالو',
    '💆' => 'ماساژ صورت',
    '💇' => 'آرایشگاه',
    '🚶' => 'عابر پیاده',
    '🧍' => 'آدم ایستاده',
    '🧎' => 'آدم زانوزده',
    '🏃' => 'دونده',
    '💃' => 'رقاص',
    '🕺' => 'مرد درحال رقص',
    '🕴' => 'پرواز مرد با لباس رسمی',
    '👯' => 'رقص',
    '🧖' => 'فردی در حمام بخار',
    '🧗' => 'فردی کوه‌نوردی می‌کند',
    '🤺' => 'شمشیربازی',
    '🏇' => 'مسابقه اسب‌سواری',
    '⛷' => 'اسکی‌سوار',
    '🏂' => 'اسنوبرد',
    '🏌' => 'گلف‌باز',
    '🏄' => 'موج‌سوار',
    '🚣' => 'قایق پارویی',
    '🏊' => 'شناگر',
    '⛹' => 'شخص با توپ',
    '🏋' => 'وزنه‌بردار',
    '🚴' => 'دوچرخه‌سوار',
    '🚵' => 'دوچرخه کوهستان',
    '🤸' => 'حرکت چرخ و فلک',
    '🤼' => 'کُشتی‌گیران',
    '🤽' => 'واترپلو',
    '🤾' => 'هندبال',
    '🤹' => 'ژانگولربازی',
    '🧘' => 'فرد در حالت خلسه',
    '🛀' => 'فرد در وان',
    '🛌' => 'فرد در تختخواب',
    '👭' => 'دو زن دست در دست',
    '👫' => 'زن و مرد دست در‌ دست',
    '👬' => 'دو مرد دست در دست',
    '💏' => 'بوسه',
    '💑' => 'زوج عاشق',
    '🗣' => 'درحال صحبت کردن',
    '👤' => 'تندیس سایه‌نما',
    '👥' => 'تندیس‌های سایه‌نما',
    '🫂' => 'درآغوش گرفتن',
    '👪' => 'خانواده',
    '👣' => 'رد پا',
    '🫆' => 'اثر انگشت',
    '🦰' => 'موقرمز',
    '🦱' => 'موفرفری',
    '🦳' => 'موسفید',
    '🦲' => 'تاس',
    '🐵' => 'صورت میمون',
    '🐒' => 'میمون',
    '🦍' => 'گوریل',
    '🦧' => 'اورانگوتان',
    '🐶' => 'صورت سگ',
    '🐕' => 'سگ',
    '🦮' => 'سگ راهنما',
    '🐩' => 'پودل',
    '🐺' => 'گرگ',
    '🦊' => 'روباه',
    '🦝' => 'راکون',
    '🐱' => 'صورت گربه',
    '🐈' => 'گربه',
    '🦁' => 'شیر',
    '🐯' => 'صورت ببر',
    '🐅' => 'ببر',
    '🐆' => 'پلنگ',
    '🐴' => 'صورت اسب',
    '🫎' => 'موس',
    '🫏' => 'الاغ',
    '🐎' => 'اسب',
    '🦄' => 'تک‌شاخ',
    '🦓' => 'گورخر',
    '🦌' => 'گوزن',
    '🦬' => 'گاومیش',
    '🐮' => 'صورت گاو',
    '🐂' => 'گاو نر',
    '🐃' => 'بوفالوی آبی',
    '🐄' => 'گاو ماده',
    '🐷' => 'صورت خوک',
    '🐖' => 'خوک',
    '🐗' => 'گراز نر',
    '🐽' => 'دماغ خوک',
    '🐏' => 'قوچ',
    '🐑' => 'میش',
    '🐐' => 'بز',
    '🐪' => 'شتر',
    '🐫' => 'شتر دو کوهان',
    '🦙' => 'لاما',
    '🦒' => 'زرافه',
    '🐘' => 'فیل',
    '🦣' => 'ماموت',
    '🦏' => 'کرگدن',
    '🦛' => 'اسب آبی',
    '🐭' => 'صورت موش',
    '🐁' => 'موش',
    '🐀' => 'موش صحرایی',
    '🐹' => 'همستر',
    '🐰' => 'صورت خرگوش',
    '🐇' => 'خرگوش',
    '🐿' => 'سنجاب راه‌راه',
    '🦫' => 'بیدستر',
    '🦔' => 'جوجه‌تیغی',
    '🦇' => 'خفاش',
    '🐻' => 'خرس',
    '🐨' => 'کوآلا',
    '🐼' => 'پاندا',
    '🦥' => 'تنبل',
    '🦦' => 'سمور آبی',
    '🦨' => 'راسو',
    '🦘' => 'کانگورو',
    '🦡' => 'گورکن',
    '🐾' => 'رد پنجه',
    '🦃' => 'بوقلمون',
    '🐔' => 'مرغ',
    '🐓' => 'خروس',
    '🐣' => 'جوجه ازتخم‌بیرون‌آمده',
    '🐤' => 'جوجه',
    '🐥' => 'جوجه از روبرو',
    '🐦' => 'پرنده',
    '🐧' => 'پنگوئن',
    '🕊' => 'کبوتر',
    '🦅' => 'عقاب',
    '🦆' => 'مرغابی',
    '🦢' => 'قو',
    '🦉' => 'جغد',
    '🦤' => 'دودو',
    '🪶' => 'پَر',
    '🦩' => 'فلامینگو',
    '🦚' => 'طاووس',
    '🦜' => 'طوطی',
    '🪽' => 'بال',
    '🪿' => 'غاز',
    '🐸' => 'قورباغه',
    '🐊' => 'تمساح',
    '🐢' => 'لاک‌پشت',
    '🦎' => 'مارمولک',
    '🐍' => 'مار',
    '🐲' => 'صورت اژدها',
    '🐉' => 'اژدها',
    '🦕' => 'سوسمار',
    '🦖' => 'تی‌رکس',
    '🐳' => 'نهنگ در حال آب‌فشانی',
    '🐋' => 'نهنگ',
    '🐬' => 'دلفین',
    '🫍' => 'نهنگ قاتل',
    '🦭' => 'فُک',
    '🐟' => 'ماهی',
    '🐠' => 'ماهی استوایی',
    '🐡' => 'ماهی بادکنکی',
    '🦈' => 'کوسه',
    '🐙' => 'هشت‌پا',
    '🐚' => 'صدف مارپیچی',
    '🪸' => 'مرجان',
    '🪼' => 'عروس دریایی',
    '🦀' => 'خرچنگ',
    '🦞' => 'لابستر',
    '🦐' => 'میگو',
    '🦑' => 'ماهی مرکب',
    '🦪' => 'صدف خوراکی',
    '🐌' => 'حلزون',
    '🦋' => 'پروانه',
    '🐛' => 'حشره',
    '🐜' => 'مورچه',
    '🐝' => 'زنبور عسل',
    '🪲' => 'سوسک',
    '🐞' => 'کفشدوزک',
    '🦗' => 'جیرجیرک',
    '🪳' => 'سوسک حمام',
    '🕷' => 'عنکبوت',
    '🕸' => 'تار عنکبوت',
    '🦂' => 'عقرب',
    '🦟' => 'پشه',
    '🪰' => 'مگس',
    '🪱' => 'کرم',
    '🦠' => 'میکروب',
    '💐' => 'دسته گل',
    '🌸' => 'شکوفه گیلاس',
    '💮' => 'گل سفید',
    '🪷' => 'نیلوفر',
    '🏵' => 'گل رزت',
    '🌹' => 'رز',
    '🥀' => 'گل پژمرده',
    '🌺' => 'گل ختمی',
    '🌻' => 'گل آفتابگردان',
    '🌼' => 'شکوفه',
    '🌷' => 'لاله',
    '🪻' => 'سنبل',
    '🌱' => 'جوانه',
    '🪴' => 'گیاه گلدانی',
    '🌲' => 'همیشه‌سبز',
    '🌳' => 'درخت سبز',
    '🌴' => 'نخل',
    '🌵' => 'کاکتوس',
    '🌾' => 'خوشه برنج',
    '🌿' => 'گیاه دارویی',
    '☘' => 'برگ شبدر',
    '🍀' => 'شبدر چهاربرگ',
    '🍁' => 'برگ افرا',
    '🍂' => 'برگ‌ریزان',
    '🍃' => 'رقص برگ در باد',
    '🪹' => 'آشیانه خالی',
    '🪺' => 'آشیانه با تخم',
    '🍄' => 'قارچ',
    '🪾' => 'درخت بدون برگ',
    '🍇' => 'انگور',
    '🍈' => 'طالبی',
    '🍉' => 'هندوانه',
    '🍊' => 'نارنگی',
    '🍋' => 'لیمو ترش',
    '🍌' => 'موز',
    '🍍' => 'آناناس',
    '🥭' => 'انبه',
    '🍎' => 'سیب سرخ',
    '🍏' => 'سیب سبز',
    '🍐' => 'گلابی',
    '🍑' => 'هلو',
    '🍒' => 'گیلاس',
    '🍓' => 'توت‌فرنگی',
    '🫐' => 'توت آبی',
    '🥝' => 'کیوی',
    '🍅' => 'گوجه‌فرنگی',
    '🫒' => 'زیتون',
    '🥥' => 'نارگیل',
    '🥑' => 'آووکادو',
    '🍆' => 'بادمجان',
    '🥔' => 'سیب زمینی',
    '🥕' => 'هویج',
    '🌽' => 'بلال ذرت',
    '🌶' => 'فلفل قرمز',
    '🫑' => 'فلفل دلمه‌ای',
    '🥒' => 'خیار',
    '🥬' => 'برگ‌سبز',
    '🥦' => 'بروکلی',
    '🧄' => 'سیر',
    '🧅' => 'پیاز',
    '🥜' => 'بادام زمینی',
    '🫘' => 'لوبیا',
    '🌰' => 'فندق',
    '🫚' => 'زنجبیل',
    '🫛' => 'نخودفرنگی',
    '🫜' => 'سبزیجات ریشه‌ای',
    '🍞' => 'نان',
    '🥐' => 'کرواسان',
    '🥖' => 'نان باگت',
    '🫓' => 'نان مسطح',
    '🥨' => 'چوب‌شور',
    '🥯' => 'نان بیگل',
    '🥞' => 'پنکیک',
    '🧇' => 'وافل',
    '🧀' => 'قاچ پنیر',
    '🍖' => 'گوشت با استخوان',
    '🍗' => 'ران ماکیان',
    '🥩' => 'برش گوشت',
    '🥓' => 'بیکن',
    '🍔' => 'همبرگر',
    '🍟' => 'سیب‌زمینی سرخ‌کرده',
    '🍕' => 'پیتزا',
    '🌭' => 'هات داگ',
    '🥪' => 'ساندویچ',
    '🌮' => 'تاکو',
    '🌯' => 'بوریتو',
    '🫔' => 'تامال',
    '🥙' => 'لقمه',
    '🧆' => 'فلافل',
    '🥚' => 'تخم مرغ',
    '🍳' => 'آشپزی',
    '🥘' => 'ماهیتابه غذا',
    '🍲' => 'ظرف غذا',
    '🫕' => 'فوندو',
    '🥣' => 'کاسه و قاشق',
    '🥗' => 'سالاد سبزیجات',
    '🍿' => 'ذرت بوداده',
    '🧈' => 'کره',
    '🧂' => 'نمک',
    '🥫' => 'غذای کنسروشده',
    '🍱' => 'جعبه بنتو',
    '🍘' => 'تردک برنجی',
    '🍙' => 'کوفته برنجی',
    '🍚' => 'برنج پخته',
    '🍛' => 'برنج با کاری',
    '🍜' => 'کاسه نودل',
    '🍝' => 'اسپاگتی',
    '🍠' => 'سیب‌زمینی شیرین کباب‌شده',
    '🍢' => 'اودن',
    '🍣' => 'سوشی',
    '🍤' => 'میگو سوخاری',
    '🍥' => 'کیک ماهی',
    '🥮' => 'کیک ماه',
    '🍡' => 'دانگو',
    '🥟' => 'کوفته',
    '🥠' => 'شیرینی شانس',
    '🥡' => 'جعبه بردنی',
    '🍦' => 'بستنی قیفی',
    '🍧' => 'یخ در بهشت',
    '🍨' => 'بستنی',
    '🍩' => 'دونات',
    '🍪' => 'کلوچه',
    '🎂' => 'کیک تولد',
    '🍰' => 'شُرت‌کیک',
    '🧁' => 'کیک فنجانی',
    '🥧' => 'پای',
    '🍫' => 'تخته شکلات',
    '🍬' => 'آب‌نبات‌',
    '🍭' => 'آب‌نبات‌چوبی',
    '🍮' => 'کاستارد',
    '🍯' => 'ظرف عسل',
    '🍼' => 'شیشه شیر',
    '🥛' => 'لیوان شیر',
    '☕' => 'نوشیدنی گرم',
    '🫖' => 'قوری',
    '🍵' => 'فنجان چای بدون دسته',
    '🍶' => 'ساکی',
    '🍾' => 'شامپاین جوشان',
    '🍷' => 'جام شراب',
    '🍸' => 'جام کوکتل',
    '🍹' => 'نوشیدنی استوایی',
    '🍺' => 'لیوان آب‌جو',
    '🍻' => 'لیوان‌های آبجو را به‌هم زدن',
    '🥂' => 'صدای به‌هم خوردن پیاله‌ها',
    '🥃' => 'لیوان ته‌گنبدی',
    '🫗' => 'ریختن مایع',
    '🥤' => 'فنجان با نی',
    '🧋' => 'چای حُبابی',
    '🧃' => 'پاکت نوشیدنی',
    '🧉' => 'ماته',
    '🧊' => 'قالب یخ',
    '🥢' => 'چاپ‌استیک',
    '🍽' => 'بشقاب و کارد و چنگال',
    '🍴' => 'کارد و چنگال',
    '🥄' => 'قاشق',
    '🔪' => 'چاقوی آشپزخانه',
    '🫙' => 'شیشه دهان‌گشاد',
    '🏺' => 'سبو',
    '🌍' => 'نقشهٔ اروپا-افریقا روی کره',
    '🌎' => 'نقشهٔ قارهٔ امریکا روی کره',
    '🌏' => 'نقشهٔ آسیا-اقیانوسیه روی کره',
    '🌐' => 'کره با نصف‌النهارها',
    '🗺' => 'نقشهٔ جهان',
    '🗾' => 'نقشهٔ ژاپن',
    '🧭' => 'قطب‌نما',
    '🏔' => 'قلهٔ برفی',
    '⛰' => 'کوه',
    '🛘' => 'ریزش کوه',
    '🌋' => 'آتشفشان',
    '🗻' => 'کوه فوجی',
    '🏕' => 'چادرزنی',
    '🏖' => 'ساحل و سایبان',
    '🏜' => 'بیابان',
    '🏝' => 'جزیرهٔ خالی از سکنه',
    '🏞' => 'پارک ملی',
    '🏟' => 'ورزشگاه',
    '🏛' => 'ساختمان باستانی',
    '🏗' => 'ساخت‌وساز ساختمانی',
    '🧱' => 'دیوار آجری',
    '🪨' => 'صخره',
    '🪵' => 'چوب',
    '🛖' => 'کلبه',
    '🏘' => 'منازل',
    '🏚' => 'خانهٔ متروکه',
    '🏠' => 'خانه',
    '🏡' => 'خانهٔ حیاط‌دار',
    '🏢' => 'ساختمان اداری',
    '🏣' => 'پست‌خانهٔ ژاپنی',
    '🏤' => 'ادارهٔ پست',
    '🏥' => 'بیمارستان',
    '🏦' => 'بانک',
    '🏨' => 'هتل',
    '🏩' => 'هتل عشق‌ورزی',
    '🏪' => 'بقالی',
    '🏫' => 'مدرسه',
    '🏬' => 'فروشگاه بزرگ',
    '🏭' => 'کارخانه',
    '🏯' => 'قلعهٔ ژاپنی',
    '🏰' => 'قلعه',
    '💒' => 'ازدواج',
    '🗼' => 'برج توکیو',
    '🗽' => 'مجسمهٔ آزادی',
    '⛪' => 'کلیسا',
    '🕌' => 'مسجد',
    '🛕' => 'معبد هندو',
    '🕍' => 'کنیسه',
    '⛩' => 'معبد شینتو',
    '🕋' => 'کعبه',
    '⛲' => 'فواره',
    '⛺' => 'چادر',
    '🌁' => 'مه‌آلود',
    '🌃' => 'شب پرستاره',
    '🏙' => 'نمای شهر',
    '🌄' => 'طلوع در کوهستان',
    '🌅' => 'طلوع',
    '🌆' => 'نمای شهر هنگام غروب',
    '🌇' => 'غروب',
    '🌉' => 'پل در شب',
    '♨' => 'چشمهٔ آب گرم',
    '🎠' => 'چرخ‌وفلک اسبی',
    '🛝' => 'سرسره',
    '🎡' => 'چرخ‌وفلک',
    '🎢' => 'ترن هوایی',
    '💈' => 'چراغ سلمانی',
    '🎪' => 'چادر سیرک',
    '🚂' => 'لوکوموتیو',
    '🚃' => 'واگن ریلی',
    '🚄' => 'قطار سریع‌السیر',
    '🚅' => 'قطار تندرو',
    '🚆' => 'قطار',
    '🚇' => 'قطار شهری',
    '🚈' => 'قطار سبک شهری',
    '🚉' => 'ایستگاه قطار',
    '🚊' => 'تراموا',
    '🚝' => 'تک‌ریل',
    '🚞' => 'ریل کوهستانی',
    '🚋' => 'قطار خیابانی',
    '🚌' => 'اتوبوس',
    '🚍' => 'اتوبوس روبه‌جلو',
    '🚎' => 'اتوبوس برقی',
    '🚐' => 'مینی‌بوس',
    '🚑' => 'آمبولانس',
    '🚒' => 'ماشین آتش‌نشانی',
    '🚓' => 'ماشین پلیس',
    '🚔' => 'ماشین پلیسی که نزدیک می‌شود',
    '🚕' => 'تاکسی',
    '🚖' => 'تاکسی‌ای که نزدیک می‌شود',
    '🚗' => 'خودرو',
    '🚘' => 'خودرویی که نزدیک می‌شود',
    '🚙' => 'خودروی شاسی‌بلند',
    '🛻' => 'وانت',
    '🚚' => 'کامیون پخش',
    '🚛' => 'کامیون مفصلی',
    '🚜' => 'تراکتور',
    '🏎' => 'ماشین مسابقه',
    '🏍' => 'موتورسیکلت',
    '🛵' => 'اسکوتر',
    '🦽' => 'صندلی چرخ‌دار دستی',
    '🦼' => 'صندلی چرخ‌دار برقی',
    '🛺' => 'اتوریکشا',
    '🚲' => 'دوچرخه',
    '🛴' => 'چرخ پایی',
    '🛹' => 'تختهٔ اسکیت',
    '🛼' => 'کفش اسکیت',
    '🚏' => 'ایستگاه اتوبوس',
    '🛣' => 'بزرگراه',
    '🛤' => 'ریل قطار',
    '🛢' => 'بشکه نفت',
    '⛽' => 'پمپ بنزین',
    '🛞' => 'چرخ',
    '🚨' => 'چراغ ماشین پلیس',
    '🚥' => 'چراغ راهنمایی افقی',
    '🚦' => 'چراغ راهنمایی عمودی',
    '🛑' => 'علامت ایست',
    '🚧' => 'ساخت‌وساز',
    '⚓' => 'لنگر',
    '🛟' => 'حلقه نجات',
    '⛵' => 'قایق بادبانی',
    '🛶' => 'بلم',
    '🚤' => 'قایق تندرو',
    '🛳' => 'کشتی مسافربری',
    '⛴' => 'فرابر',
    '🛥' => 'قایق موتوری',
    '🚢' => 'کشتی',
    '✈' => 'هواپیما',
    '🛩' => 'هواپیمای کوچک',
    '🛫' => 'زمان حرکت هواپیما',
    '🛬' => 'زمان ورود هواپیما',
    '🪂' => 'چتر نجات',
    '💺' => 'جایگاه',
    '🚁' => 'هلیکوپتر',
    '🚟' => 'قطار معلق',
    '🚠' => 'تله‌کابین کوهستانی',
    '🚡' => 'تراموای هوایی',
    '🛰' => 'ماهواره',
    '🚀' => 'موشک',
    '🛸' => 'بشقاب‌پرنده',
    '🛎' => 'زنگ میز پذیرش',
    '🧳' => 'چمدان',
    '⌛' => 'ساعت شنی',
    '⏳' => 'ساعت شنی با شن روان',
    '⌚' => 'ساعت مچی',
    '⏰' => 'ساعت رومیزی',
    '⏱' => 'کرنومتر',
    '⏲' => 'تایمر',
    '🕰' => 'ساعت طاقچه‌ای',
    '🕛' => 'ساعت دوازده',
    '🕧' => 'ساعت دوازده و نیم',
    '🕐' => 'ساعت یک',
    '🕜' => 'ساعت یک و نیم',
    '🕑' => 'ساعت دو',
    '🕝' => 'ساعت دو و نیم',
    '🕒' => 'ساعت سه',
    '🕞' => 'ساعت سه و نیم',
    '🕓' => 'ساعت چهار',
    '🕟' => 'ساعت چهار و نیم',
    '🕔' => 'ساعت پنج',
    '🕠' => 'ساعت پنج و نیم',
    '🕕' => 'ساعت شش',
    '🕡' => 'ساعت شش و نیم',
    '🕖' => 'ساعت هفت',
    '🕢' => 'ساعت هفت و نیم',
    '🕗' => 'ساعت هشت',
    '🕣' => 'ساعت هشت و نیم',
    '🕘' => 'ساعت نه',
    '🕤' => 'ساعت نه و نیم',
    '🕙' => 'ساعت ده',
    '🕥' => 'ساعت ده و نیم',
    '🕚' => 'ساعت یازده',
    '🕦' => 'ساعت یازده و نیم',
    '🌑' => 'ماه نو',
    '🌒' => 'هلال فزاینده ماه',
    '🌓' => 'یک‌چهارم نخست',
    '🌔' => 'کوژماه افزاینده',
    '🌕' => 'ماه کامل',
    '🌖' => 'کوژماه کاهنده',
    '🌗' => 'یک‌چهارم پایان',
    '🌘' => 'هلال کاهنده ماه',
    '🌙' => 'هلال ماه',
    '🌚' => 'صورت ماه نو',
    '🌛' => 'صورت یک‌چهارم اول',
    '🌜' => 'صورت یک‌چهارم آخر',
    '🌡' => 'دماسنج',
    '☀' => 'خورشید',
    '🌝' => 'صورت ماه کامل',
    '🌞' => 'صورت خورشید',
    '🪐' => 'سیاره حلقه‌دار',
    '⭐' => 'ستاره سفید',
    '🌟' => 'ستاره درخشان',
    '🌠' => 'ستاره ثاقب',
    '🌌' => 'راه شیری',
    '☁' => 'ابر',
    '⛅' => 'خورشید پشت ابر',
    '⛈' => 'ابر با رعدوبرق و باران',
    '🌤' => 'خورشید پشت ابر کوچک',
    '🌥' => 'خورشید پشت ابر بزرگ',
    '🌦' => 'خورشید پشت ابر بارانی',
    '🌧' => 'ابر بارانی',
    '🌨' => 'ابر برفی',
    '🌩' => 'ابر با برق',
    '🌪' => 'گردباد',
    '🌫' => 'مه',
    '🌬' => 'صورت باد',
    '🌀' => 'چرخند',
    '🌈' => 'رنگین کمان',
    '🌂' => 'چتر بسته',
    '☂' => 'چتر',
    '☔' => 'چتر خیس',
    '⛱' => 'چتر روی زمین',
    '⚡' => 'ولتاژ بالا',
    '❄' => 'برف‌دانه',
    '☃' => 'آدم برفی',
    '⛄' => 'آدم برفی بدون برف',
    '☄' => 'ستاره دنباله‌دار',
    '🔥' => 'آتش',
    '💧' => 'قطره',
    '🌊' => 'موج آب',
    '🎃' => 'فانوس کدو تنبل',
    '🎄' => 'درخت کریسمس',
    '🎆' => 'آتش‌بازی',
    '🎇' => 'فشفشه',
    '🧨' => 'ترقه',
    '✨' => 'درخشش',
    '🎈' => 'بادکنک',
    '🎉' => 'بمب کاغذ رنگی',
    '🎊' => 'توپ پولکی',
    '🎋' => 'درخت تاناباتا',
    '🎍' => 'تزئین کاج',
    '🎎' => 'عروسک‌های ژاپنی',
    '🎏' => 'پرچم‌های ماهی در باد',
    '🎐' => 'باد سِنج',
    '🎑' => 'آئین مشاهدهٔ ماه کامل',
    '🧧' => 'پاکت سرخ',
    '🎀' => 'روبان',
    '🎁' => 'هدیهٔ کادوشده',
    '🎗' => 'روبان یادآوری',
    '🎟' => 'بلیت ورود',
    '🎫' => 'بلیت',
    '🎖' => 'مدال ارتشی',
    '🏆' => 'جام ورزشی',
    '🏅' => 'مدال ورزشی',
    '🥇' => 'مدال طلا',
    '🥈' => 'مدال نقره',
    '🥉' => 'مدال برنز',
    '⚽' => 'توپ فوتبال',
    '⚾' => 'بیسبال',
    '🥎' => 'سافت‌بال',
    '🏀' => 'بسکتبال',
    '🏐' => 'والیبال',
    '🏈' => 'فوتبال امریکایی',
    '🏉' => 'راگبی',
    '🎾' => 'تنیس',
    '🥏' => 'فریزبی',
    '🎳' => 'بولینگ',
    '🏏' => 'کریکت',
    '🏑' => 'هاکی روی چمن',
    '🏒' => 'هاکی روی یخ',
    '🥍' => 'لاکراس',
    '🏓' => 'پینگ‌پونگ',
    '🏸' => 'بدمینتون',
    '🥊' => 'دست‌کش بوکس',
    '🥋' => 'لباس هنرهای رزمی',
    '🥅' => 'دروازه',
    '⛳' => 'پرچم در سوراخ',
    '⛸' => 'اسکی روی یخ',
    '🎣' => 'چوب ماهیگیری',
    '🤿' => 'ماسک غواصی',
    '🎽' => 'لباس دو',
    '🎿' => 'چوب اسکی',
    '🛷' => 'سورتمه',
    '🥌' => 'سنگ کرلینگ',
    '🎯' => 'پیکان در قلب هدف',
    '🪀' => 'یویو',
    '🪁' => 'بادبادک',
    '🔫' => 'تفنگ آب‌پاش',
    '🎱' => 'بیلیارد',
    '🔮' => 'گوی',
    '🪄' => 'عصای سحرآمیز',
    '🎮' => 'بازی ویدیویی',
    '🕹' => 'دسته بازی',
    '🎰' => 'ماشین پولی',
    '🎲' => 'تاس بازی',
    '🧩' => 'قطعه پازل',
    '🧸' => 'تدی خرسه',
    '🪅' => 'پینیاتا',
    '🪩' => 'توپ آینه‌ای',
    '🪆' => 'عروسک تودرتو',
    '♠' => 'خال پیک',
    '♥' => 'خال دل',
    '♦' => 'خال خشت',
    '♣' => 'خال گشنیز',
    '♟' => 'پیاده شطرنج',
    '🃏' => 'جوکر',
    '🀄' => 'ماژونگ اژدهای قرمز',
    '🎴' => 'کارت بازی گل‌دار',
    '🎭' => 'هنرهای نمایشی',
    '🖼' => 'عکس در قاب',
    '🎨' => 'پالت نقاشی',
    '🧵' => 'نخ',
    '🪡' => 'سوزن خیاطی',
    '🧶' => 'نخ بافندگی',
    '🪢' => 'گره',
    '👓' => 'عینک طبی',
    '🕶' => 'عینک آفتابی',
    '🥽' => 'عینک ایمنی',
    '🥼' => 'روپوش آزمایشگاه',
    '🦺' => 'جلیقه ایمنی',
    '👔' => 'کراوات',
    '👕' => 'تی‌شرت',
    '👖' => 'شلوار جین',
    '🧣' => 'روسری',
    '🧤' => 'دستکش',
    '🧥' => 'پالتو',
    '🧦' => 'جوراب',
    '👗' => 'پیراهن زنانه',
    '👘' => 'کیمونو',
    '🥻' => 'ساری',
    '🩱' => 'مایو یک‌تکه',
    '🩲' => 'شورت اسلیپ',
    '🩳' => 'شلوارک',
    '👙' => 'بیکینی',
    '👚' => 'لباس زنانه',
    '🪭' => 'بادبزن',
    '👛' => 'کیف دستی',
    '👜' => 'کیف دوشی',
    '👝' => 'کیف بدون تسمه زنانه',
    '🛍' => 'کیف خرید',
    '🎒' => 'کوله‌پشتی',
    '🩴' => 'دمپایی لاانگشتی',
    '👞' => 'کفش مردانه',
    '👟' => 'کفش دویدن',
    '🥾' => 'چکمه راه‌پیمایی',
    '🥿' => 'کفش بی‌پاشنه',
    '👠' => 'کفش پاشنه بلند',
    '👡' => 'صندل زنانه',
    '🩰' => 'کفش باله',
    '👢' => 'پوتین زنانه',
    '🪮' => 'شانه جداکننده',
    '👑' => 'تاج',
    '👒' => 'کلاه زنانه',
    '🎩' => 'کلاه مردانه استوانه‌ای',
    '🎓' => 'کلاه فارغ‌التحصیلی',
    '🧢' => 'کلاه لبه‌دار',
    '🪖' => 'کلاه‌خود',
    '⛑' => 'کلاه صلیب سرخ',
    '📿' => 'تسبیح',
    '💄' => 'رژلب',
    '💍' => 'حلقه',
    '💎' => 'جواهر',
    '🔇' => 'بلندگوی خاموش',
    '🔈' => 'بلندگو با صدای کم',
    '🔉' => 'بلندگو با صدای متعادل',
    '🔊' => 'بلندگو با صدای بلند',
    '📢' => 'بلندگو',
    '📣' => 'بلندگوی دستی',
    '📯' => 'شیپور پست',
    '🔔' => 'زنگ',
    '🔕' => 'خط قرمز روی زنگوله',
    '🎼' => 'پارتیتور',
    '🎵' => 'نت موسیقی',
    '🎶' => 'نت‌های موسیقی',
    '🎙' => 'میکروفون استودیویی',
    '🎚' => 'درجهٔ تنظیم‌کننده',
    '🎛' => 'دسته‌های کنترل',
    '🎤' => 'میکروفون',
    '🎧' => 'هدفون',
    '📻' => 'رادیو',
    '🎷' => 'ساکسیفون',
    '🎺' => 'ترومپت',
    '🪊' => 'شیپور',
    '🪗' => 'آکوردئون',
    '🎸' => 'گیتار',
    '🎹' => 'کیبورد موسیقی',
    '🎻' => 'ویولن',
    '🪕' => 'بانجو',
    '🥁' => 'طبل',
    '🪘' => 'طبل بلند',
    '🪇' => 'ساز جغجغه‌ای',
    '🪈' => 'فلوت',
    '🪉' => 'چنگ',
    '📱' => 'تلفن همراه',
    '📲' => 'تلفن همراه با پیکان',
    '☎' => 'تلفن',
    '📞' => 'گوشی تلفن',
    '📟' => 'پیجر',
    '📠' => 'دستگاه نمابر',
    '🔋' => 'باتری',
    '🪫' => 'باتری ضعیف',
    '🔌' => 'دوشاخه',
    '💻' => 'رایانهٔ کیفی',
    '🖥' => 'رایانهٔ میزی',
    '🖨' => 'چاپگر',
    '⌨' => 'صفحه‌کلید',
    '🖱' => 'موشواره',
    '🖲' => 'توپک',
    '💽' => 'مینی دیسک',
    '💾' => 'فلاپی دیسک',
    '💿' => 'سی‌دی',
    '📀' => 'دی‌وی‌دی',
    '🧮' => 'چرتکه',
    '🎥' => 'دوربین سینمایی',
    '🎞' => 'حلقهٔ فیلم',
    '📽' => 'پروژکتور',
    '🎬' => 'کلاکت',
    '📺' => 'تلویزیون',
    '📷' => 'دوربین',
    '📸' => 'دوربین با فلاش',
    '📹' => 'دوربین فیلم‌برداری',
    '📼' => 'کاست ویدیویی',
    '🔍' => 'ذره‌بین روبه‌چپ',
    '🔎' => 'ذره‌بین روبه‌راست',
    '🕯' => 'شمع',
    '💡' => 'لامپ',
    '🔦' => 'چراغ‌قوه',
    '🏮' => 'فانوس کاغذی قرمز',
    '🪔' => 'چراغ دایا',
    '📔' => 'دفتر با جلد سخت',
    '📕' => 'کتاب بسته',
    '📖' => 'کتاب باز',
    '📗' => 'کتاب سبز',
    '📘' => 'کتاب آبی',
    '📙' => 'کتاب نارنجی',
    '📚' => 'چند کتاب',
    '📓' => 'دفتر یادداشت',
    '📒' => 'دفتر سیمی',
    '📃' => 'صفحهٔ تاشده',
    '📜' => 'طومار',
    '📄' => 'صفحهٔ روبه‌بالا',
    '📰' => 'روزنامه',
    '🗞' => 'رول روزنامه',
    '📑' => 'برچسب‌های نشانه‌گذاری',
    '🔖' => 'نشان‌گذار کتاب',
    '🏷' => 'برچسب',
    '🪙' => 'سکه',
    '💰' => 'کیسهٔ پول',
    '🪎' => 'صندوق جواهرات',
    '💴' => 'اسکناس ین',
    '💵' => 'اسکناس دلار',
    '💶' => 'اسکناس یورو',
    '💷' => 'اسکناس پوند',
    '💸' => 'اسکناس بال‌دار',
    '💳' => 'کارت اعتباری',
    '🧾' => 'رسید',
    '💹' => 'نمودار صعودی با ین',
    '✉' => 'پاکت نامه',
    '📧' => 'ایمیل',
    '📨' => 'پاکت نامهٔ ورودی',
    '📩' => 'پاکت نامه با پیکان',
    '📤' => 'صندوق خروجی',
    '📥' => 'صندوق ورودی',
    '📦' => 'بسته',
    '📫' => 'صندوق پستی بسته با پرچم بالا',
    '📪' => 'صندوق پستی بسته با پرچم پایین',
    '📬' => 'صندوق پستی باز با پرچم بالا',
    '📭' => 'صندوق پستی باز با پرچم پایین',
    '📮' => 'صندوق پست',
    '🗳' => 'صندوق رأی',
    '✏' => 'مداد',
    '✒' => 'قلم مشکی',
    '🖋' => 'خودنویس',
    '🖊' => 'خودکار',
    '🖌' => 'قلم‌مو',
    '🖍' => 'مدادشمعی',
    '📝' => 'یادداشت',
    '💼' => 'کیف اسناد',
    '📁' => 'پوشه',
    '📂' => 'پوشهٔ باز',
    '🗂' => 'جداکننده',
    '📅' => 'تقویم',
    '📆' => 'تقویم رومیزی',
    '🗒' => 'دفترچهٔ یادداشت سیمی',
    '🗓' => 'تقویم سیمی',
    '📇' => 'کارت‌های راهنما',
    '📈' => 'نمودار صعودی',
    '📉' => 'نمودار نزولی',
    '📊' => 'نمودار ستونی',
    '📋' => 'تختهٔ گیره‌دار',
    '📌' => 'سنجاق',
    '📍' => 'سنجاق ته‌گرد',
    '📎' => 'گیرهٔ کاغذ',
    '🖇' => 'زنجیرهٔ گیره',
    '📏' => 'خط‌کش',
    '📐' => 'گونیا',
    '✂' => 'قیچی',
    '🗃' => 'جعبه نگه‌داری کارت',
    '🗄' => 'کشوی پرونده',
    '🗑' => 'سطل کاغذ باطله',
    '🔒' => 'قفل',
    '🔓' => 'قفل باز',
    '🔏' => 'قفل با قلم',
    '🔐' => 'قفل و کلید',
    '🔑' => 'کلید',
    '🗝' => 'کلید قدیمی',
    '🔨' => 'چکش',
    '🪓' => 'تبر',
    '⛏' => 'کلنگ',
    '⚒' => 'چکش و کلنگ',
    '🛠' => 'چکش و آچار',
    '🗡' => 'خنجر',
    '⚔' => 'شمشیرهای ضرب‌دری',
    '💣' => 'بمب',
    '🪃' => 'بومرنگ',
    '🏹' => 'تیر و کمان',
    '🛡' => 'سپر',
    '🪚' => 'اره نجاری',
    '🔧' => 'آچار',
    '🪛' => 'پیچ‌گوشتی',
    '🔩' => 'پیچ و مهره',
    '⚙' => 'چرخ‌دنده',
    '🗜' => 'پرس',
    '⚖' => 'ترازو',
    '🦯' => 'عصای سفید',
    '🔗' => 'حلقهٔ زنجیر',
    '⛓' => 'غل و زنجیر',
    '🪝' => 'قلاب',
    '🧰' => 'جعبه‌ابزار',
    '🧲' => 'آهن‌ربا',
    '🪜' => 'نردبان',
    '🪏' => 'بیل',
    '⚗' => 'انبیق',
    '🧪' => 'لولهٔ آزمایشگاه',
    '🧫' => 'ظرف کشت',
    '🧬' => 'دی‌ان‌ای',
    '🔬' => 'میکروسکوپ',
    '🔭' => 'تلسکوپ',
    '📡' => 'آنتن ماهواره',
    '💉' => 'سرنگ',
    '🩸' => 'قطره خون',
    '💊' => 'قرص',
    '🩹' => 'چسب زخم',
    '🩼' => 'عصای زیر بغل',
    '🩺' => 'گوشی پزشکی',
    '🩻' => 'اشعه ایکس',
    '🚪' => 'در',
    '🛗' => 'بالابر',
    '🪞' => 'آینه',
    '🪟' => 'پنجره',
    '🛏' => 'تختخواب',
    '🛋' => 'مبل راحتی و چراغ',
    '🪑' => 'صندلی',
    '🚽' => 'توالت',
    '🪠' => 'لوله‌بازکن',
    '🚿' => 'دوش',
    '🛁' => 'وان حمام',
    '🪤' => 'تله موش',
    '🪒' => 'ریش‌تراش',
    '🧴' => 'بطری لوسیون',
    '🧷' => 'سنجاق قفلی',
    '🧹' => 'جارو',
    '🧺' => 'سبد',
    '🧻' => 'رول کاغذ',
    '🪣' => 'سطل',
    '🧼' => 'صابون',
    '🫧' => 'حباب',
    '🪥' => 'مسواک',
    '🧽' => 'لیف حمام',
    '🧯' => 'کپسول آتش‌نشانی',
    '🛒' => 'گاری خرید',
    '🚬' => 'سیگار',
    '⚰' => 'تابوت',
    '🪦' => 'سنگ قبر',
    '⚱' => 'خاکستردان',
    '🧿' => 'نظرقربانی',
    '🪬' => 'خمسه',
    '🗿' => 'سردیس موآی',
    '🪧' => 'پلاکارد',
    '🪪' => 'کارت شناسایی',
    '🏧' => 'نشان عابربانک',
    '🚮' => 'علامت ریختن زباله در زباله‌دان',
    '🚰' => 'آب آشامیدنی',
    '♿' => 'علامت صندلی چرخ‌دار',
    '🚹' => 'توالت مردانه',
    '🚺' => 'توالت زنانه',
    '🚻' => 'توالت عمومی',
    '🚼' => 'نماد نوزاد',
    '🚾' => 'سرویس بهداشتی',
    '🛂' => 'کنترل گذرنامه',
    '🛃' => 'گمرک',
    '🛄' => 'دریافت بار',
    '🛅' => 'امانت بار',
    '⚠' => 'هشدار',
    '🚸' => 'عبور کودکان',
    '⛔' => 'ورود ممنوع',
    '🚫' => 'ممنوع',
    '🚳' => 'دوچرخه ممنوع',
    '🚭' => 'سیگار کشیدن ممنوع',
    '🚯' => 'ریختن زباله ممنوع',
    '🚱' => 'آب غیرآشامیدنی',
    '🚷' => 'عابر پیاده ممنوع',
    '📵' => 'تلفن همراه ممنوع',
    '🔞' => 'زیر ۱۸ سال ممنوع',
    '☢' => 'رادیواکتیو',
    '☣' => 'خطر زیستی',
    '⬆' => 'پیکان بالا',
    '↗' => 'پیکان بالا راست',
    '➡' => 'پیکان راست',
    '↘' => 'پیکان پایین راست',
    '⬇' => 'پیکان پایین',
    '↙' => 'پیکان پایین چپ',
    '⬅' => 'پیکان چپ',
    '↖' => 'پیکان بالا چپ',
    '↕' => 'پیکان بالا و پایین',
    '↔' => 'پیکان دوطرفه',
    '↩' => 'پیکان خمیده راست',
    '↪' => 'پیکان خمیده چپ',
    '⤴' => 'پیکان خمیده بالا راست',
    '⤵' => 'پیکان خمیده پایین راست',
    '🔃' => 'جهت عقربه‌های ساعت',
    '🔄' => 'خلاف جهت عقربه‌های ساعت',
    '🔙' => 'پیکان عقب',
    '🔚' => 'پیکان پایان',
    '🔛' => 'پیکان روشن',
    '🔜' => 'پیکان به‌زودی',
    '🔝' => 'پیکان رو',
    '🛐' => 'محل عبادت',
    '⚛' => 'نماد اتم',
    '🕉' => 'اُم',
    '✡' => 'ستارهٔ داود',
    '☸' => 'چرخ دارما',
    '☯' => 'یین و ینگ',
    '✝' => 'صلیب',
    '☦' => 'صلیب ارتدوکسی',
    '☪' => 'هلال و ستاره',
    '☮' => 'نماد صلح',
    '🕎' => 'منورا',
    '🔯' => 'ستارهٔ شش‌پر',
    '🪯' => 'خندا',
    '♈' => 'برج حمل',
    '♉' => 'برج ثور',
    '♊' => 'برج جوزا',
    '♋' => 'برج سرطان',
    '♌' => 'برج اسد',
    '♍' => 'برج سنبله',
    '♎' => 'برج میزان',
    '♏' => 'برج عقرب',
    '♐' => 'برج قوس',
    '♑' => 'برج جدی',
    '♒' => 'برج دلو',
    '♓' => 'برج حوت',
    '⛎' => 'برج حوا',
    '🔀' => 'دکمهٔ پخش تصادفی',
    '🔁' => 'دکمهٔ تکرار',
    '🔂' => 'دکمهٔ یک‌بار تکرار',
    '▶' => 'دکمهٔ پخش',
    '⏩' => 'دکمهٔ سریع به جلو',
    '⏭' => 'دکمهٔ آهنگ بعدی',
    '⏯' => 'دکمهٔ پخش یا مکث',
    '◀' => 'دکمهٔ برگرداندن',
    '⏪' => 'دکمهٔ سریع به عقب',
    '⏮' => 'دکمهٔ آهنگ قبلی',
    '🔼' => 'دکمهٔ بالا',
    '⏫' => 'دکمهٔ سریع به بالا',
    '🔽' => 'دکمهٔ پایین',
    '⏬' => 'دکمهٔ سریع به پایین',
    '⏸' => 'دکمهٔ مکث',
    '⏹' => 'دکمهٔ توقف',
    '⏺' => 'دکمهٔ ضبط',
    '⏏' => 'دکمهٔ خروج',
    '🎦' => 'سینما',
    '🔅' => 'دکمهٔ تار کردن صفحه',
    '🔆' => 'دکمهٔ روشن کردن صفحه',
    '📶' => 'نوار سیگنال',
    '🛜' => 'بی‌سیم',
    '📳' => 'حالت لرزش',
    '📴' => 'تلفن همراه خاموش',
    '♀' => 'نشان ناهید',
    '♂' => 'نشان مریخ',
    '⚧' => 'علامت تراجنسیتی',
    '✖' => 'ضرب کردن',
    '➕' => 'بعلاوه',
    '➖' => 'تفریق',
    '➗' => 'تقسیم کردن',
    '🟰' => 'علامت تساوی پررنگ',
    '♾' => 'بی‌نهایت',
    '‼' => 'علامت تعجب دوتایی',
    '⁉' => 'علامت تعجب و سؤال',
    '❓' => 'علامت سؤال قرمز',
    '❔' => 'علامت سؤال سفید',
    '❕' => 'علامت تعجب سفید',
    '❗' => 'علامت تعجب قرمز',
    '〰' => 'خط موج‌دار',
    '💱' => 'تبدیل ارز',
    '💲' => 'نماد دلار',
    '⚕' => 'نماد پزشکی',
    '♻' => 'نماد بازیافت',
    '⚜' => 'نماد گل زنبق',
    '🔱' => 'نیزهٔ سه‌شاخه',
    '📛' => 'برچسب نام',
    '🔰' => 'نماد ژاپنی سطح مبتدی',
    '⭕' => 'دایره قرمز توخالی',
    '✅' => 'علامت تأیید',
    '☑' => 'مربع با علامت تیک',
    '✔' => 'علامت تیک',
    '❌' => 'ضربدر',
    '❎' => 'دکمه ایکس',
    '➰' => 'حلقه مجعد',
    '➿' => 'حلقه مجعد دوتایی',
    '〽' => 'علامت تناوب بخش',
    '✳' => 'ستاره هشت‌پره',
    '✴' => 'ستاره هشت‌پر',
    '❇' => 'جرقه',
    '™' => 'نماد بازرگانی',
    '🫟' => 'لکه رنگ',
    '🔠' => 'ورودی حروف بزرگ',
    '🔡' => 'ورودی حروف کوچک',
    '🔢' => 'ورودی عددی',
    '🔣' => 'ورودی نماد',
    '🔤' => 'ورودی حروف لاتین',
    '🅰' => 'دکمه آ (گروه خونی)',
    '🆎' => 'دکمه آ ب (گروه خونی)',
    '🅱' => 'دکمه ب (گروه خونی)',
    '🆑' => 'دکمهٔ CL',
    '🆒' => 'دکمهٔ COOL',
    '🆓' => 'دکمهٔ FREE',
    'ℹ' => 'اطلاعات',
    '🆔' => 'دکمهٔ شناسایی',
    'Ⓜ' => 'حرف ام در دایره',
    '🆕' => 'دکمهٔ NEW',
    '🆖' => 'دکمهٔ NG',
    '🅾' => 'دکمه اُ (گروه خونی)',
    '🆗' => 'دکمهٔ OK',
    '🅿' => 'دکمه پی',
    '🆘' => 'دکمه اس او اس',
    '🆙' => 'دکمهٔ !UP',
    '🆚' => 'دکمهٔ VS',
    '🈁' => 'دکمهٔ «اینجا» به ژاپنی',
    '🈂' => 'دکمهٔ «هزینهٔ خدمات» به ژاپنی',
    '🈷' => 'دکمهٔ «مقدار ماهانه» به ژاپنی',
    '🈶' => 'دکمهٔ غیرمجانی به ژاپنی',
    '🈯' => 'دکمۀ «رزروشده» به ژاپنی',
    '🉐' => 'دکمهٔ «قیمت مناسب» به ژاپنی',
    '🈹' => 'دکمۀ «تخفیف» به ژاپنی',
    '🈚' => 'دکمۀ «رایگان» به ژاپنی',
    '🈲' => 'دکمۀ «ممنوع» به ژاپنی',
    '🉑' => 'دکمۀ «قابل قبول» به ژاپنی',
    '🈸' => 'دکمۀ «تقاضانامه» به ژاپنی',
    '🈴' => 'دکمۀ «نمرهٔ قبولی» به ژاپنی',
    '🈳' => 'دکمۀ «پست خالی» به ژاپنی',
    '㊗' => 'دکمهٔ «تبریک» به ژاپنی',
    '㊙' => 'دکمهٔ «راز» به ژاپنی',
    '🈺' => 'دکمۀ «آماده برای کسب‌وکار» به ژاپنی',
    '🈵' => 'دکمهٔ «پُر» به ژاپنی',
    '🔴' => 'دایره قرمز',
    '🟠' => 'دایره نارنجی',
    '🟡' => 'دایره زرد',
    '🟢' => 'دایره سبز',
    '🔵' => 'دایره آبی',
    '🟣' => 'دایره بنفش',
    '🟤' => 'دایره قهوه‌ای',
    '⚫' => 'دایره مشکی',
    '⚪' => 'دایره سفید',
    '🟥' => 'مربع سرخ',
    '🟧' => 'مربع نارنجی',
    '🟨' => 'مربع زرد',
    '🟩' => 'مربع سبز',
    '🟦' => 'مربع آبی',
    '🟪' => 'مربع بنفش',
    '🟫' => 'مربع قهوه‌ای',
    '⬛' => 'مربع مشکی بزرگ',
    '⬜' => 'مربع سفید بزرگ',
    '◼' => 'مربع مشکی متوسط',
    '◻' => 'مربع سفید متوسط',
    '◾' => 'مربع مشکی نسبتاً کوچک',
    '◽' => 'مربع سفید نسبتاً کوچک',
    '▪' => 'مربع مشکی کوچک',
    '▫' => 'مربع سفید کوچک',
    '🔶' => 'لوزی نارنجی بزرگ',
    '🔷' => 'لوزی آبی بزرگ',
    '🔸' => 'لوزی نارنجی کوچک',
    '🔹' => 'لوزی آبی کوچک',
    '🔺' => 'مثلث با رأس بالا',
    '🔻' => 'مثلث با رأس پایین',
    '💠' => 'لوزی نقطه‌دار',
    '🔘' => 'دکمهٔ رادیویی',
    '🔳' => 'دکمۀ مربع سفید',
    '🔲' => 'دکمۀ مربع مشکی',
    '🏁' => 'پرچم شطرنجی',
    '🚩' => 'پرچم مثلثی',
    '🎌' => 'پرچم‌های ضرب‌دری',
    '🏴' => 'پرچم سیاه',
    '🏳' => 'پرچم سفید',
];
