<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'nsusò ọnụ: okenye, okenye, ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏻‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha',
    '👨🏻‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏻‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👨🏻‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏻‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👨🏼‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏼‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏼‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏼‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏼‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏽‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏽‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ ndịna etiti',
    '👨🏽‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏽‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏾‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏾‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏾‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏾‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏾‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏿‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👨🏿‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏿‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👨🏿‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwoke, nwoke, ọtanjele ahụ maka òji',
    '👩🏻‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha',
    '👩🏻‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏻‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👩🏻‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👩🏼‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏼‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏼‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏼‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏼‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏽‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏽‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ ndịna etiti',
    '👩🏽‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏽‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏾‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏾‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏾‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏾‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏾‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏿‍❤‍💋‍👨🏻' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👩🏿‍❤‍💋‍👨🏼' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏿‍❤‍💋‍👨🏽' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👩🏿‍❤‍💋‍👨🏾' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍❤‍💋‍👨🏿' => 'nsusò ọnụ: nwanyị, nwoke, ọtanjele ahụ maka òji',
    '👩🏻‍❤‍💋‍👩🏻' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha',
    '👩🏻‍❤‍💋‍👩🏼' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏻‍❤‍💋‍👩🏽' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👩🏻‍❤‍💋‍👩🏾' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍❤‍💋‍👩🏿' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👩🏼‍❤‍💋‍👩🏻' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏼‍❤‍💋‍👩🏼' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏼‍❤‍💋‍👩🏽' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏼‍❤‍💋‍👩🏾' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏼‍❤‍💋‍👩🏿' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏽‍❤‍💋‍👩🏻' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏽‍❤‍💋‍👩🏼' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍❤‍💋‍👩🏽' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti',
    '👩🏽‍❤‍💋‍👩🏾' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏽‍❤‍💋‍👩🏿' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏾‍❤‍💋‍👩🏻' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏾‍❤‍💋‍👩🏼' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏾‍❤‍💋‍👩🏽' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏾‍❤‍💋‍👩🏾' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏾‍❤‍💋‍👩🏿' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏿‍❤‍💋‍👩🏻' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👩🏿‍❤‍💋‍👩🏼' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏿‍❤‍💋‍👩🏽' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👩🏿‍❤‍💋‍👩🏾' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍❤‍💋‍👩🏿' => 'nsusò ọnụ: nwanyị, nwanyị, ọtanjele ahụ maka òji',
    '🧑🏻‍🫯‍🧑🏼' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏻‍🫯‍🧑🏽' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '🧑🏻‍🫯‍🧑🏾' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏻‍🫯‍🧑🏿' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '🧑🏼‍🫯‍🧑🏻' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏼‍🫯‍🧑🏽' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏼‍🫯‍🧑🏾' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏼‍🫯‍🧑🏿' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏽‍🫯‍🧑🏻' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏽‍🫯‍🧑🏼' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🫯‍🧑🏾' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏽‍🫯‍🧑🏿' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏾‍🫯‍🧑🏻' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏾‍🫯‍🧑🏼' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏾‍🫯‍🧑🏽' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🫯‍🧑🏿' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏿‍🫯‍🧑🏻' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '🧑🏿‍🫯‍🧑🏼' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏿‍🫯‍🧑🏽' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '🧑🏿‍🫯‍🧑🏾' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏻‍❤‍🧑🏼' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏻‍❤‍🧑🏽' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '🧑🏻‍❤‍🧑🏾' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏻‍❤‍🧑🏿' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '🧑🏼‍❤‍🧑🏻' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏼‍❤‍🧑🏽' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏼‍❤‍🧑🏾' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏼‍❤‍🧑🏿' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏽‍❤‍🧑🏻' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏽‍❤‍🧑🏼' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍❤‍🧑🏾' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏽‍❤‍🧑🏿' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏾‍❤‍🧑🏻' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏾‍❤‍🧑🏼' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏾‍❤‍🧑🏽' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏾‍❤‍🧑🏿' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏿‍❤‍🧑🏻' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '🧑🏿‍❤‍🧑🏼' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏿‍❤‍🧑🏽' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '🧑🏿‍❤‍🧑🏾' => 'di na nwunye nwere obi: okenye, okenye, ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏻‍🐰‍🧑🏼' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏻‍🐰‍🧑🏽' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '🧑🏻‍🐰‍🧑🏾' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏻‍🐰‍🧑🏿' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '🧑🏼‍🐰‍🧑🏻' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏼‍🐰‍🧑🏽' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏼‍🐰‍🧑🏾' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏼‍🐰‍🧑🏿' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏽‍🐰‍🧑🏻' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏽‍🐰‍🧑🏼' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🐰‍🧑🏾' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏽‍🐰‍🧑🏿' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏾‍🐰‍🧑🏻' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏾‍🐰‍🧑🏼' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏾‍🐰‍🧑🏽' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🐰‍🧑🏿' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏿‍🐰‍🧑🏻' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '🧑🏿‍🐰‍🧑🏼' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏿‍🐰‍🧑🏽' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '🧑🏿‍🐰‍🧑🏾' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏻‍🫯‍👨🏼' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏻‍🫯‍👨🏽' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👨🏻‍🫯‍👨🏾' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏻‍🫯‍👨🏿' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👨🏼‍🫯‍👨🏻' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏼‍🫯‍👨🏽' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏼‍🫯‍👨🏾' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏼‍🫯‍👨🏿' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏽‍🫯‍👨🏻' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏽‍🫯‍👨🏼' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🫯‍👨🏾' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏽‍🫯‍👨🏿' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏾‍🫯‍👨🏻' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏾‍🫯‍👨🏼' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏾‍🫯‍👨🏽' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏾‍🫯‍👨🏿' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏿‍🫯‍👨🏻' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👨🏿‍🫯‍👨🏼' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏿‍🫯‍👨🏽' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👨🏿‍🫯‍👨🏾' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏻‍❤‍👨🏻' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha',
    '👨🏻‍❤‍👨🏼' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏻‍❤‍👨🏽' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👨🏻‍❤‍👨🏾' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏻‍❤‍👨🏿' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👨🏼‍❤‍👨🏻' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏼‍❤‍👨🏼' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏼‍❤‍👨🏽' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏼‍❤‍👨🏾' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏼‍❤‍👨🏿' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏽‍❤‍👨🏻' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏽‍❤‍👨🏼' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍❤‍👨🏽' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ ndịna etiti',
    '👨🏽‍❤‍👨🏾' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏽‍❤‍👨🏿' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏾‍❤‍👨🏻' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏾‍❤‍👨🏼' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏾‍❤‍👨🏽' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏾‍❤‍👨🏾' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏾‍❤‍👨🏿' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏿‍❤‍👨🏻' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👨🏿‍❤‍👨🏼' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏿‍❤‍👨🏽' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👨🏿‍❤‍👨🏾' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍❤‍👨🏿' => 'di na nwunye nwere obi: nwoke, nwoke, ọtanjele ahụ maka òji',
    '👨🏻‍🐰‍👨🏼' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏻‍🐰‍👨🏽' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👨🏻‍🐰‍👨🏾' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏻‍🐰‍👨🏿' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👨🏼‍🐰‍👨🏻' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏼‍🐰‍👨🏽' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏼‍🐰‍👨🏾' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏼‍🐰‍👨🏿' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏽‍🐰‍👨🏻' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏽‍🐰‍👨🏼' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🐰‍👨🏾' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏽‍🐰‍👨🏿' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏾‍🐰‍👨🏻' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏾‍🐰‍👨🏼' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏾‍🐰‍👨🏽' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏾‍🐰‍👨🏿' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏿‍🐰‍👨🏻' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👨🏿‍🐰‍👨🏼' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏿‍🐰‍👨🏽' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👨🏿‍🐰‍👨🏾' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍🫯‍👩🏼' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏻‍🫯‍👩🏽' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👩🏻‍🫯‍👩🏾' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍🫯‍👩🏿' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👩🏼‍🫯‍👩🏻' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏼‍🫯‍👩🏽' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏼‍🫯‍👩🏾' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏼‍🫯‍👩🏿' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏽‍🫯‍👩🏻' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏽‍🫯‍👩🏼' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🫯‍👩🏾' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏽‍🫯‍👩🏿' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏾‍🫯‍👩🏻' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏾‍🫯‍👩🏼' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏾‍🫯‍👩🏽' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏾‍🫯‍👩🏿' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏿‍🫯‍👩🏻' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👩🏿‍🫯‍👩🏼' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏿‍🫯‍👩🏽' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👩🏿‍🫯‍👩🏾' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍❤‍👨🏻' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha',
    '👩🏻‍❤‍👨🏼' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏻‍❤‍👨🏽' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👩🏻‍❤‍👨🏾' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍❤‍👨🏿' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👩🏼‍❤‍👨🏻' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏼‍❤‍👨🏼' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏼‍❤‍👨🏽' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏼‍❤‍👨🏾' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏼‍❤‍👨🏿' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏽‍❤‍👨🏻' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏽‍❤‍👨🏼' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍❤‍👨🏽' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ ndịna etiti',
    '👩🏽‍❤‍👨🏾' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏽‍❤‍👨🏿' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏾‍❤‍👨🏻' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏾‍❤‍👨🏼' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏾‍❤‍👨🏽' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏾‍❤‍👨🏾' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏾‍❤‍👨🏿' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏿‍❤‍👨🏻' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👩🏿‍❤‍👨🏼' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏿‍❤‍👨🏽' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👩🏿‍❤‍👨🏾' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍❤‍👨🏿' => 'di na nwunye nwere obi: nwanyị, nwoke, ọtanjele ahụ maka òji',
    '👩🏻‍❤‍👩🏻' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha',
    '👩🏻‍❤‍👩🏼' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏻‍❤‍👩🏽' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👩🏻‍❤‍👩🏾' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍❤‍👩🏿' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👩🏼‍❤‍👩🏻' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏼‍❤‍👩🏼' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏼‍❤‍👩🏽' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏼‍❤‍👩🏾' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏼‍❤‍👩🏿' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏽‍❤‍👩🏻' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏽‍❤‍👩🏼' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍❤‍👩🏽' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti',
    '👩🏽‍❤‍👩🏾' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏽‍❤‍👩🏿' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏾‍❤‍👩🏻' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏾‍❤‍👩🏼' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏾‍❤‍👩🏽' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏾‍❤‍👩🏾' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏾‍❤‍👩🏿' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏿‍❤‍👩🏻' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👩🏿‍❤‍👩🏼' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏿‍❤‍👩🏽' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👩🏿‍❤‍👩🏾' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍❤‍👩🏿' => 'di na nwunye nwere obi: nwanyị, nwanyị, ọtanjele ahụ maka òji',
    '👩🏻‍🐰‍👩🏼' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏻‍🐰‍👩🏽' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👩🏻‍🐰‍👩🏾' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍🐰‍👩🏿' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👩🏼‍🐰‍👩🏻' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏼‍🐰‍👩🏽' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏼‍🐰‍👩🏾' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏼‍🐰‍👩🏿' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏽‍🐰‍👩🏻' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏽‍🐰‍👩🏼' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🐰‍👩🏾' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏽‍🐰‍👩🏿' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏾‍🐰‍👩🏻' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏾‍🐰‍👩🏼' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏾‍🐰‍👩🏽' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏾‍🐰‍👩🏿' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏿‍🐰‍👩🏻' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👩🏿‍🐰‍👩🏼' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏿‍🐰‍👩🏽' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👩🏿‍🐰‍👩🏾' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏻‍🤝‍🧑🏻' => 'ndị ji aka: ọtanjele ahụ maka ọcha',
    '🧑🏻‍🤝‍🧑🏼' => 'ndị ji aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏻‍🤝‍🧑🏽' => 'ndị ji aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '🧑🏻‍🤝‍🧑🏾' => 'ndị ji aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏻‍🤝‍🧑🏿' => 'ndị ji aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '🧑🏼‍🤝‍🧑🏻' => 'ndị ji aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏼‍🤝‍🧑🏼' => 'ndị ji aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏼‍🤝‍🧑🏽' => 'ndị ji aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏼‍🤝‍🧑🏾' => 'ndị ji aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏼‍🤝‍🧑🏿' => 'ndị ji aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏽‍🤝‍🧑🏻' => 'ndị ji aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏽‍🤝‍🧑🏼' => 'ndị ji aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🤝‍🧑🏽' => 'ndị ji aka: ọtanjele ahụ ndịna etiti',
    '🧑🏽‍🤝‍🧑🏾' => 'ndị ji aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏽‍🤝‍🧑🏿' => 'ndị ji aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏾‍🤝‍🧑🏻' => 'ndị ji aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🧑🏾‍🤝‍🧑🏼' => 'ndị ji aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏾‍🤝‍🧑🏽' => 'ndị ji aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🤝‍🧑🏾' => 'ndị ji aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏾‍🤝‍🧑🏿' => 'ndị ji aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '🧑🏿‍🤝‍🧑🏻' => 'ndị ji aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '🧑🏿‍🤝‍🧑🏼' => 'ndị ji aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏿‍🤝‍🧑🏽' => 'ndị ji aka: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '🧑🏿‍🤝‍🧑🏾' => 'ndị ji aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🤝‍🧑🏿' => 'ndị ji aka: ọtanjele ahụ maka òji',
    '👩🏻‍🤝‍👩🏼' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏻‍🤝‍👩🏽' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👩🏻‍🤝‍👩🏾' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍🤝‍👩🏿' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👩🏼‍🤝‍👩🏻' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏼‍🤝‍👩🏽' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏼‍🤝‍👩🏾' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏼‍🤝‍👩🏿' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏽‍🤝‍👩🏻' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏽‍🤝‍👩🏼' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🤝‍👩🏾' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏽‍🤝‍👩🏿' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏾‍🤝‍👩🏻' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏾‍🤝‍👩🏼' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏾‍🤝‍👩🏽' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏾‍🤝‍👩🏿' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏿‍🤝‍👩🏻' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👩🏿‍🤝‍👩🏼' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏿‍🤝‍👩🏽' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👩🏿‍🤝‍👩🏾' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍🤝‍👨🏼' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏻‍🤝‍👨🏽' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👩🏻‍🤝‍👨🏾' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏻‍🤝‍👨🏿' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👩🏼‍🤝‍👨🏻' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏼‍🤝‍👨🏽' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏼‍🤝‍👨🏾' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏼‍🤝‍👨🏿' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏽‍🤝‍👨🏻' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏽‍🤝‍👨🏼' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🤝‍👨🏾' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏽‍🤝‍👨🏿' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏾‍🤝‍👨🏻' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👩🏾‍🤝‍👨🏼' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏾‍🤝‍👨🏽' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👩🏾‍🤝‍👨🏿' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👩🏿‍🤝‍👨🏻' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👩🏿‍🤝‍👨🏼' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏿‍🤝‍👨🏽' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👩🏿‍🤝‍👨🏾' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏻‍🤝‍👨🏼' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏻‍🤝‍👨🏽' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '👨🏻‍🤝‍👨🏾' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏻‍🤝‍👨🏿' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '👨🏼‍🤝‍👨🏻' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏼‍🤝‍👨🏽' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏼‍🤝‍👨🏾' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏼‍🤝‍👨🏿' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏽‍🤝‍👨🏻' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏽‍🤝‍👨🏼' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🤝‍👨🏾' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏽‍🤝‍👨🏿' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏾‍🤝‍👨🏻' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '👨🏾‍🤝‍👨🏼' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏾‍🤝‍👨🏽' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '👨🏾‍🤝‍👨🏿' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '👨🏿‍🤝‍👨🏻' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '👨🏿‍🤝‍👨🏼' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏿‍🤝‍👨🏽' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '👨🏿‍🤝‍👨🏾' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '👩‍❤‍💋‍👨' => 'nsusò ọnụ: nwanyị, nwoke',
    '👨‍❤‍💋‍👨' => 'nsusò ọnụ: nwoke, nwoke',
    '👩‍❤‍💋‍👩' => 'nsusò ọnụ: nwanyị, nwanyị',
    '👨‍👩‍👧‍👦' => 'ezinaụlọ: nwoke, nwanyị, nwata nwaanyị, nwa nwoke',
    '👨‍👩‍👦‍👦' => 'ezinaụlọ: nwoke, nwanyị, nwa nwoke, nwa nwoke',
    '👨‍👩‍👧‍👧' => 'ezinaụlọ: nwoke, nwanyị, nwata nwaanyị, nwata nwaanyị',
    '👨‍👨‍👧‍👦' => 'ezinaụlọ: nwoke, nwoke, nwata nwaanyị, nwa nwoke',
    '👨‍👨‍👦‍👦' => 'ezinaụlọ: nwoke, nwoke, nwa nwoke, nwa nwoke',
    '👨‍👨‍👧‍👧' => 'ezinaụlọ: nwoke, nwoke, nwata nwaanyị, nwata nwaanyị',
    '👩‍👩‍👧‍👦' => 'ezinaụlọ: nwanyị, nwanyị, nwata nwaanyị, nwa nwoke',
    '👩‍👩‍👦‍👦' => 'ezinaụlọ: nwanyị, nwanyị, nwa nwoke, nwa nwoke',
    '👩‍👩‍👧‍👧' => 'ezinaụlọ: nwanyị, nwanyị, nwata nwaanyị, nwata nwaanyị',
    '🧑‍🧑‍🧒‍🧒' => 'ezinaụlọ: okenye, okenye, nwata, nwata',
    '🚶🏻‍♀‍➡' => 'nwanyị na-aga ije: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🚶🏼‍♀‍➡' => 'nwanyị na-aga ije: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🚶🏽‍♀‍➡' => 'nwanyị na-aga ije: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🚶🏾‍♀‍➡' => 'nwanyị na-aga ije: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🚶🏿‍♀‍➡' => 'nwanyị na-aga ije: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🚶🏻‍♂‍➡' => 'nwoke na-aga ije: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🚶🏼‍♂‍➡' => 'nwoke na-aga ije: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🚶🏽‍♂‍➡' => 'nwoke na-aga ije: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🚶🏾‍♂‍➡' => 'nwoke na-aga ije: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🚶🏿‍♂‍➡' => 'nwoke na-aga ije: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🧎🏻‍♀‍➡' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🧎🏼‍♀‍➡' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🧎🏽‍♀‍➡' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🧎🏾‍♀‍➡' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🧎🏿‍♀‍➡' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🧎🏻‍♂‍➡' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🧎🏼‍♂‍➡' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🧎🏽‍♂‍➡' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🧎🏾‍♂‍➡' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🧎🏿‍♂‍➡' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🧑🏻‍🦯‍➡' => 'onye ji mkpara ọcha: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🧑🏼‍🦯‍➡' => 'onye ji mkpara ọcha: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🧑🏽‍🦯‍➡' => 'onye ji mkpara ọcha: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🧑🏾‍🦯‍➡' => 'onye ji mkpara ọcha: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🧑🏿‍🦯‍➡' => 'onye ji mkpara ọcha: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '👨🏻‍🦯‍➡' => 'nwoke ji mkpara ọcha: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '👨🏼‍🦯‍➡' => 'nwoke ji mkpara ọcha: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '👨🏽‍🦯‍➡' => 'nwoke ji mkpara ọcha: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '👨🏾‍🦯‍➡' => 'nwoke ji mkpara ọcha: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '👨🏿‍🦯‍➡' => 'nwoke ji mkpara ọcha: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '👩🏻‍🦯‍➡' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '👩🏼‍🦯‍➡' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '👩🏽‍🦯‍➡' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '👩🏾‍🦯‍➡' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '👩🏿‍🦯‍➡' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🧑🏻‍🦼‍➡' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🧑🏼‍🦼‍➡' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🧑🏽‍🦼‍➡' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🧑🏾‍🦼‍➡' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🧑🏿‍🦼‍➡' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '👨🏻‍🦼‍➡' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '👨🏼‍🦼‍➡' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '👨🏽‍🦼‍➡' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '👨🏾‍🦼‍➡' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '👨🏿‍🦼‍➡' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '👩🏻‍🦼‍➡' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '👩🏼‍🦼‍➡' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '👩🏽‍🦼‍➡' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '👩🏾‍🦼‍➡' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '👩🏿‍🦼‍➡' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🧑🏻‍🦽‍➡' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🧑🏼‍🦽‍➡' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🧑🏽‍🦽‍➡' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🧑🏾‍🦽‍➡' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🧑🏿‍🦽‍➡' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '👨🏻‍🦽‍➡' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '👨🏼‍🦽‍➡' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '👨🏽‍🦽‍➡' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '👨🏾‍🦽‍➡' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '👨🏿‍🦽‍➡' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '👩🏻‍🦽‍➡' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '👩🏼‍🦽‍➡' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '👩🏽‍🦽‍➡' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '👩🏾‍🦽‍➡' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '👩🏿‍🦽‍➡' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🏃🏻‍♀‍➡' => 'nwanyị na-agba ọsọ: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🏃🏼‍♀‍➡' => 'nwanyị na-agba ọsọ: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🏃🏽‍♀‍➡' => 'nwanyị na-agba ọsọ: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🏃🏾‍♀‍➡' => 'nwanyị na-agba ọsọ: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🏃🏿‍♀‍➡' => 'nwanyị na-agba ọsọ: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🏃🏻‍♂‍➡' => 'nwoke na-agba ọsọ: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🏃🏼‍♂‍➡' => 'nwoke na-agba ọsọ: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🏃🏽‍♂‍➡' => 'nwoke na-agba ọsọ: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🏃🏾‍♂‍➡' => 'nwoke na-agba ọsọ: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🏃🏿‍♂‍➡' => 'nwoke na-agba ọsọ: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🫱🏻‍🫲🏼' => 'nkwenaka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫱🏻‍🫲🏽' => 'nkwenaka: ọtanjele ahụ maka ọcha, ọtanjele ahụ ndịna etiti',
    '🫱🏻‍🫲🏾' => 'nkwenaka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji-ndịna etiti',
    '🫱🏻‍🫲🏿' => 'nkwenaka: ọtanjele ahụ maka ọcha, ọtanjele ahụ maka òji',
    '🫱🏼‍🫲🏻' => 'nkwenaka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🫱🏼‍🫲🏽' => 'nkwenaka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🫱🏼‍🫲🏾' => 'nkwenaka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🫱🏼‍🫲🏿' => 'nkwenaka: ọtanjele ahụ maka ọcha-ndịna etiti, ọtanjele ahụ maka òji',
    '🫱🏽‍🫲🏻' => 'nkwenaka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha',
    '🫱🏽‍🫲🏼' => 'nkwenaka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫱🏽‍🫲🏾' => 'nkwenaka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji-ndịna etiti',
    '🫱🏽‍🫲🏿' => 'nkwenaka: ọtanjele ahụ ndịna etiti, ọtanjele ahụ maka òji',
    '🫱🏾‍🫲🏻' => 'nkwenaka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha',
    '🫱🏾‍🫲🏼' => 'nkwenaka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫱🏾‍🫲🏽' => 'nkwenaka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ ndịna etiti',
    '🫱🏾‍🫲🏿' => 'nkwenaka: ọtanjele ahụ maka òji-ndịna etiti, ọtanjele ahụ maka òji',
    '🫱🏿‍🫲🏻' => 'nkwenaka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha',
    '🫱🏿‍🫲🏼' => 'nkwenaka: ọtanjele ahụ maka òji, ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫱🏿‍🫲🏽' => 'nkwenaka: ọtanjele ahụ maka òji, ọtanjele ahụ ndịna etiti',
    '🫱🏿‍🫲🏾' => 'nkwenaka: ọtanjele ahụ maka òji, ọtanjele ahụ maka òji-ndịna etiti',
    '🚶‍♀‍➡' => 'nwanyị na-aga ije: na-eche ihu aka nri',
    '🚶‍♂‍➡' => 'nwoke na-aga ije: na-eche ihu aka nri',
    '🧎‍♀‍➡' => 'nwanyị gbu ikpere n’ala: na-eche ihu aka nri',
    '🧎‍♂‍➡' => 'nwoke gbu ikpere n’ala: na-eche ihu aka nri',
    '🧑‍🦯‍➡' => 'onye ji mkpara ọcha: na-eche ihu aka nri',
    '👨‍🦯‍➡' => 'nwoke ji mkpara ọcha: na-eche ihu aka nri',
    '👩‍🦯‍➡' => 'nwanyị ji mkpara ọcha: na-eche ihu aka nri',
    '🧑‍🦼‍➡' => 'onye nọ n’oche nkwagharị nwere moto: na-eche ihu aka nri',
    '👨‍🦼‍➡' => 'nwoke nọ n’oche nkwagharị nwere moto: na-eche ihu aka nri',
    '👩‍🦼‍➡' => 'nwanyị nọ n’oche nkwagharị nwere moto: na-eche ihu aka nri',
    '🧑‍🦽‍➡' => 'onye nọ n’oche nkwagharị nke aka: na-eche ihu aka nri',
    '👨‍🦽‍➡' => 'nwoke nọ n’oche nkwagharị nke aka: na-eche ihu aka nri',
    '👩‍🦽‍➡' => 'nwanyị nọ n’oche nkwagharị nke aka: na-eche ihu aka nri',
    '🏃‍♀‍➡' => 'nwanyị na-agba ọsọ: na-eche ihu aka nri',
    '🏃‍♂‍➡' => 'nwoke na-agba ọsọ: na-eche ihu aka nri',
    '👩‍❤‍👨' => 'di na nwunye nwere obi: nwanyị, nwoke',
    '👨‍❤‍👨' => 'di na nwunye nwere obi: nwoke, nwoke',
    '👩‍❤‍👩' => 'di na nwunye nwere obi: nwanyị, nwanyị',
    '👨‍👩‍👦' => 'ezinaụlọ: nwoke, nwanyị, nwa nwoke',
    '👨‍👩‍👧' => 'ezinaụlọ: nwoke, nwanyị, nwata nwaanyị',
    '👨‍👨‍👦' => 'ezinaụlọ: nwoke, nwoke, nwa nwoke',
    '👨‍👨‍👧' => 'ezinaụlọ: nwoke, nwoke, nwata nwaanyị',
    '👩‍👩‍👦' => 'ezinaụlọ: nwanyị, nwanyị, nwa nwoke',
    '👩‍👩‍👧' => 'ezinaụlọ: nwanyị, nwanyị, nwata nwaanyị',
    '👨‍👦‍👦' => 'ezinaụlọ: nwoke, nwa nwoke, nwa nwoke',
    '👨‍👧‍👦' => 'ezinaụlọ: nwoke, nwata nwaanyị, nwa nwoke',
    '👨‍👧‍👧' => 'ezinaụlọ: nwoke, nwata nwaanyị, nwata nwaanyị',
    '👩‍👦‍👦' => 'ezinaụlọ: nwanyị, nwa nwoke, nwa nwoke',
    '👩‍👧‍👦' => 'ezinaụlọ: nwanyị, nwata nwaanyị, nwa nwoke',
    '👩‍👧‍👧' => 'ezinaụlọ: nwanyị, nwata nwaanyị, nwata nwaanyị',
    '🧑‍🤝‍🧑' => 'ndị ji aka',
    '🧑‍🧑‍🧒' => 'ezinaụlọ: okenye, okenye, nwata',
    '🧑‍🧒‍🧒' => 'ezinaụlọ: okenye, nwata, nwata',
    '🧑🏻‍🦰' => 'okenye: ọtanjele ahụ maka ọcha, ntutu isi uhie',
    '🧑🏼‍🦰' => 'okenye: ọtanjele ahụ maka ọcha-ndịna etiti, ntutu isi uhie',
    '🧑🏽‍🦰' => 'okenye: ọtanjele ahụ ndịna etiti, ntutu isi uhie',
    '🧑🏾‍🦰' => 'okenye: ọtanjele ahụ maka òji-ndịna etiti, ntutu isi uhie',
    '🧑🏿‍🦰' => 'okenye: ọtanjele ahụ maka òji, ntutu isi uhie',
    '🧑🏻‍🦱' => 'okenye: ọtanjele ahụ maka ọcha, ntutu isi gbakọrọ agbakọ',
    '🧑🏼‍🦱' => 'okenye: ọtanjele ahụ maka ọcha-ndịna etiti, ntutu isi gbakọrọ agbakọ',
    '🧑🏽‍🦱' => 'okenye: ọtanjele ahụ ndịna etiti, ntutu isi gbakọrọ agbakọ',
    '🧑🏾‍🦱' => 'okenye: ọtanjele ahụ maka òji-ndịna etiti, ntutu isi gbakọrọ agbakọ',
    '🧑🏿‍🦱' => 'okenye: ọtanjele ahụ maka òji, ntutu isi gbakọrọ agbakọ',
    '🧑🏻‍🦳' => 'okenye: ọtanjele ahụ maka ọcha, ntutu isi ocha',
    '🧑🏼‍🦳' => 'okenye: ọtanjele ahụ maka ọcha-ndịna etiti, ntutu isi ocha',
    '🧑🏽‍🦳' => 'okenye: ọtanjele ahụ ndịna etiti, ntutu isi ocha',
    '🧑🏾‍🦳' => 'okenye: ọtanjele ahụ maka òji-ndịna etiti, ntutu isi ocha',
    '🧑🏿‍🦳' => 'okenye: ọtanjele ahụ maka òji, ntutu isi ocha',
    '🧑🏻‍🦲' => 'okenye: ọtanjele ahụ maka ọcha, isi nkwọcha',
    '🧑🏼‍🦲' => 'okenye: ọtanjele ahụ maka ọcha-ndịna etiti, isi nkwọcha',
    '🧑🏽‍🦲' => 'okenye: ọtanjele ahụ ndịna etiti, isi nkwọcha',
    '🧑🏾‍🦲' => 'okenye: ọtanjele ahụ maka òji-ndịna etiti, isi nkwọcha',
    '🧑🏿‍🦲' => 'okenye: ọtanjele ahụ maka òji, isi nkwọcha',
    '🧑🏻‍🩰' => 'onye na-agba egwú ballet: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🩰' => 'onye na-agba egwú ballet: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🩰' => 'onye na-agba egwú ballet: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🩰' => 'onye na-agba egwú ballet: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🩰' => 'onye na-agba egwú ballet: ọtanjele ahụ maka òji',
    '🧔🏻‍♂' => 'nwoke: ọtanjele ahụ maka ọcha, afụ ọnụ',
    '🧔🏼‍♂' => 'nwoke: ọtanjele ahụ maka ọcha-ndịna etiti, afụ ọnụ',
    '🧔🏽‍♂' => 'nwoke: ọtanjele ahụ ndịna etiti, afụ ọnụ',
    '🧔🏾‍♂' => 'nwoke: ọtanjele ahụ maka òji-ndịna etiti, afụ ọnụ',
    '🧔🏿‍♂' => 'nwoke: ọtanjele ahụ maka òji, afụ ọnụ',
    '👱🏻‍♂' => 'nwoke nwere isi-awọ: ọtanjele ahụ maka ọcha',
    '👱🏼‍♂' => 'nwoke nwere isi-awọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👱🏽‍♂' => 'nwoke nwere isi-awọ: ọtanjele ahụ ndịna etiti',
    '👱🏾‍♂' => 'nwoke nwere isi-awọ: ọtanjele ahụ maka òji-ndịna etiti',
    '👱🏿‍♂' => 'nwoke nwere isi-awọ: ọtanjele ahụ maka òji',
    '👨🏻‍🦰' => 'nwoke: ọtanjele ahụ maka ọcha, ntutu isi uhie',
    '👨🏼‍🦰' => 'nwoke: ọtanjele ahụ maka ọcha-ndịna etiti, ntutu isi uhie',
    '👨🏽‍🦰' => 'nwoke: ọtanjele ahụ ndịna etiti, ntutu isi uhie',
    '👨🏾‍🦰' => 'nwoke: ọtanjele ahụ maka òji-ndịna etiti, ntutu isi uhie',
    '👨🏿‍🦰' => 'nwoke: ọtanjele ahụ maka òji, ntutu isi uhie',
    '👨🏻‍🦱' => 'nwoke: ọtanjele ahụ maka ọcha, ntutu isi gbakọrọ agbakọ',
    '👨🏼‍🦱' => 'nwoke: ọtanjele ahụ maka ọcha-ndịna etiti, ntutu isi gbakọrọ agbakọ',
    '👨🏽‍🦱' => 'nwoke: ọtanjele ahụ ndịna etiti, ntutu isi gbakọrọ agbakọ',
    '👨🏾‍🦱' => 'nwoke: ọtanjele ahụ maka òji-ndịna etiti, ntutu isi gbakọrọ agbakọ',
    '👨🏿‍🦱' => 'nwoke: ọtanjele ahụ maka òji, ntutu isi gbakọrọ agbakọ',
    '👨🏻‍🦳' => 'nwoke: ọtanjele ahụ maka ọcha, ntutu isi ocha',
    '👨🏼‍🦳' => 'nwoke: ọtanjele ahụ maka ọcha-ndịna etiti, ntutu isi ocha',
    '👨🏽‍🦳' => 'nwoke: ọtanjele ahụ ndịna etiti, ntutu isi ocha',
    '👨🏾‍🦳' => 'nwoke: ọtanjele ahụ maka òji-ndịna etiti, ntutu isi ocha',
    '👨🏿‍🦳' => 'nwoke: ọtanjele ahụ maka òji, ntutu isi ocha',
    '👨🏻‍🦲' => 'nwoke: ọtanjele ahụ maka ọcha, isi nkwọcha',
    '👨🏼‍🦲' => 'nwoke: ọtanjele ahụ maka ọcha-ndịna etiti, isi nkwọcha',
    '👨🏽‍🦲' => 'nwoke: ọtanjele ahụ ndịna etiti, isi nkwọcha',
    '👨🏾‍🦲' => 'nwoke: ọtanjele ahụ maka òji-ndịna etiti, isi nkwọcha',
    '👨🏿‍🦲' => 'nwoke: ọtanjele ahụ maka òji, isi nkwọcha',
    '🧔🏻‍♀' => 'nwanyị: ọtanjele ahụ maka ọcha, afụ ọnụ',
    '🧔🏼‍♀' => 'nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti, afụ ọnụ',
    '🧔🏽‍♀' => 'nwanyị: ọtanjele ahụ ndịna etiti, afụ ọnụ',
    '🧔🏾‍♀' => 'nwanyị: ọtanjele ahụ maka òji-ndịna etiti, afụ ọnụ',
    '🧔🏿‍♀' => 'nwanyị: ọtanjele ahụ maka òji, afụ ọnụ',
    '👱🏻‍♀' => 'nwanyị nwere isi-awọ: ọtanjele ahụ maka ọcha',
    '👱🏼‍♀' => 'nwanyị nwere isi-awọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👱🏽‍♀' => 'nwanyị nwere isi-awọ: ọtanjele ahụ ndịna etiti',
    '👱🏾‍♀' => 'nwanyị nwere isi-awọ: ọtanjele ahụ maka òji-ndịna etiti',
    '👱🏿‍♀' => 'nwanyị nwere isi-awọ: ọtanjele ahụ maka òji',
    '👩🏻‍🦰' => 'nwanyị: ọtanjele ahụ maka ọcha, ntutu isi uhie',
    '👩🏼‍🦰' => 'nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti, ntutu isi uhie',
    '👩🏽‍🦰' => 'nwanyị: ọtanjele ahụ ndịna etiti, ntutu isi uhie',
    '👩🏾‍🦰' => 'nwanyị: ọtanjele ahụ maka òji-ndịna etiti, ntutu isi uhie',
    '👩🏿‍🦰' => 'nwanyị: ọtanjele ahụ maka òji, ntutu isi uhie',
    '👩🏻‍🦱' => 'nwanyị: ọtanjele ahụ maka ọcha, ntutu isi gbakọrọ agbakọ',
    '👩🏼‍🦱' => 'nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti, ntutu isi gbakọrọ agbakọ',
    '👩🏽‍🦱' => 'nwanyị: ọtanjele ahụ ndịna etiti, ntutu isi gbakọrọ agbakọ',
    '👩🏾‍🦱' => 'nwanyị: ọtanjele ahụ maka òji-ndịna etiti, ntutu isi gbakọrọ agbakọ',
    '👩🏿‍🦱' => 'nwanyị: ọtanjele ahụ maka òji, ntutu isi gbakọrọ agbakọ',
    '👩🏻‍🦳' => 'nwanyị: ọtanjele ahụ maka ọcha, ntutu isi ocha',
    '👩🏼‍🦳' => 'nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti, ntutu isi ocha',
    '👩🏽‍🦳' => 'nwanyị: ọtanjele ahụ ndịna etiti, ntutu isi ocha',
    '👩🏾‍🦳' => 'nwanyị: ọtanjele ahụ maka òji-ndịna etiti, ntutu isi ocha',
    '👩🏿‍🦳' => 'nwanyị: ọtanjele ahụ maka òji, ntutu isi ocha',
    '👩🏻‍🦲' => 'nwanyị: ọtanjele ahụ maka ọcha, isi nkwọcha',
    '👩🏼‍🦲' => 'nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti, isi nkwọcha',
    '👩🏽‍🦲' => 'nwanyị: ọtanjele ahụ ndịna etiti, isi nkwọcha',
    '👩🏾‍🦲' => 'nwanyị: ọtanjele ahụ maka òji-ndịna etiti, isi nkwọcha',
    '👩🏿‍🦲' => 'nwanyị: ọtanjele ahụ maka òji, isi nkwọcha',
    '🙍🏻‍♂' => 'nwoke na-agbarụ ihu: ọtanjele ahụ maka ọcha',
    '🙍🏼‍♂' => 'nwoke na-agbarụ ihu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙍🏽‍♂' => 'nwoke na-agbarụ ihu: ọtanjele ahụ ndịna etiti',
    '🙍🏾‍♂' => 'nwoke na-agbarụ ihu: ọtanjele ahụ maka òji-ndịna etiti',
    '🙍🏿‍♂' => 'nwoke na-agbarụ ihu: ọtanjele ahụ maka òji',
    '🙍🏻‍♀' => 'nwanyị na-agbarụ ihu: ọtanjele ahụ maka ọcha',
    '🙍🏼‍♀' => 'nwanyị na-agbarụ ihu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙍🏽‍♀' => 'nwanyị na-agbarụ ihu: ọtanjele ahụ ndịna etiti',
    '🙍🏾‍♀' => 'nwanyị na-agbarụ ihu: ọtanjele ahụ maka òji-ndịna etiti',
    '🙍🏿‍♀' => 'nwanyị na-agbarụ ihu: ọtanjele ahụ maka òji',
    '🙎🏻‍♂' => 'nwoke na-asọpụta ọnụ: ọtanjele ahụ maka ọcha',
    '🙎🏼‍♂' => 'nwoke na-asọpụta ọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙎🏽‍♂' => 'nwoke na-asọpụta ọnụ: ọtanjele ahụ ndịna etiti',
    '🙎🏾‍♂' => 'nwoke na-asọpụta ọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🙎🏿‍♂' => 'nwoke na-asọpụta ọnụ: ọtanjele ahụ maka òji',
    '🙎🏻‍♀' => 'nwanyị na-asọpụta ọnụ: ọtanjele ahụ maka ọcha',
    '🙎🏼‍♀' => 'nwanyị na-asọpụta ọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙎🏽‍♀' => 'nwanyị na-asọpụta ọnụ: ọtanjele ahụ ndịna etiti',
    '🙎🏾‍♀' => 'nwanyị na-asọpụta ọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🙎🏿‍♀' => 'nwanyị na-asọpụta ọnụ: ọtanjele ahụ maka òji',
    '🙅🏻‍♂' => 'nwoke na-egosipta MBÀ: ọtanjele ahụ maka ọcha',
    '🙅🏼‍♂' => 'nwoke na-egosipta MBÀ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙅🏽‍♂' => 'nwoke na-egosipta MBÀ: ọtanjele ahụ ndịna etiti',
    '🙅🏾‍♂' => 'nwoke na-egosipta MBÀ: ọtanjele ahụ maka òji-ndịna etiti',
    '🙅🏿‍♂' => 'nwoke na-egosipta MBÀ: ọtanjele ahụ maka òji',
    '🙅🏻‍♀' => 'nwanyị na-egosipta MBÀ: ọtanjele ahụ maka ọcha',
    '🙅🏼‍♀' => 'nwanyị na-egosipta MBÀ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙅🏽‍♀' => 'nwanyị na-egosipta MBÀ: ọtanjele ahụ ndịna etiti',
    '🙅🏾‍♀' => 'nwanyị na-egosipta MBÀ: ọtanjele ahụ maka òji-ndịna etiti',
    '🙅🏿‍♀' => 'nwanyị na-egosipta MBÀ: ọtanjele ahụ maka òji',
    '🙆🏻‍♂' => 'nwoke na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka ọcha',
    '🙆🏼‍♂' => 'nwoke na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙆🏽‍♂' => 'nwoke na-egosipta Ọ DỊ MMA: ọtanjele ahụ ndịna etiti',
    '🙆🏾‍♂' => 'nwoke na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka òji-ndịna etiti',
    '🙆🏿‍♂' => 'nwoke na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka òji',
    '🙆🏻‍♀' => 'nwanyị na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka ọcha',
    '🙆🏼‍♀' => 'nwanyị na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙆🏽‍♀' => 'nwanyị na-egosipta Ọ DỊ MMA: ọtanjele ahụ ndịna etiti',
    '🙆🏾‍♀' => 'nwanyị na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka òji-ndịna etiti',
    '🙆🏿‍♀' => 'nwanyị na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka òji',
    '💁🏻‍♂' => 'nwoke na-ehulata aka: ọtanjele ahụ maka ọcha',
    '💁🏼‍♂' => 'nwoke na-ehulata aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💁🏽‍♂' => 'nwoke na-ehulata aka: ọtanjele ahụ ndịna etiti',
    '💁🏾‍♂' => 'nwoke na-ehulata aka: ọtanjele ahụ maka òji-ndịna etiti',
    '💁🏿‍♂' => 'nwoke na-ehulata aka: ọtanjele ahụ maka òji',
    '💁🏻‍♀' => 'nwanyị na-ehulata aka: ọtanjele ahụ maka ọcha',
    '💁🏼‍♀' => 'nwanyị na-ehulata aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💁🏽‍♀' => 'nwanyị na-ehulata aka: ọtanjele ahụ ndịna etiti',
    '💁🏾‍♀' => 'nwanyị na-ehulata aka: ọtanjele ahụ maka òji-ndịna etiti',
    '💁🏿‍♀' => 'nwanyị na-ehulata aka: ọtanjele ahụ maka òji',
    '🙋🏻‍♂' => 'nwoke na-ewelite aka: ọtanjele ahụ maka ọcha',
    '🙋🏼‍♂' => 'nwoke na-ewelite aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙋🏽‍♂' => 'nwoke na-ewelite aka: ọtanjele ahụ ndịna etiti',
    '🙋🏾‍♂' => 'nwoke na-ewelite aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🙋🏿‍♂' => 'nwoke na-ewelite aka: ọtanjele ahụ maka òji',
    '🙋🏻‍♀' => 'nwanyị na-ewelite aka: ọtanjele ahụ maka ọcha',
    '🙋🏼‍♀' => 'nwanyị na-ewelite aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙋🏽‍♀' => 'nwanyị na-ewelite aka: ọtanjele ahụ ndịna etiti',
    '🙋🏾‍♀' => 'nwanyị na-ewelite aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🙋🏿‍♀' => 'nwanyị na-ewelite aka: ọtanjele ahụ maka òji',
    '🧏🏻‍♂' => 'nwoke ntị chiri: ọtanjele ahụ maka ọcha',
    '🧏🏼‍♂' => 'nwoke ntị chiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧏🏽‍♂' => 'nwoke ntị chiri: ọtanjele ahụ ndịna etiti',
    '🧏🏾‍♂' => 'nwoke ntị chiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🧏🏿‍♂' => 'nwoke ntị chiri: ọtanjele ahụ maka òji',
    '🧏🏻‍♀' => 'nwanyị ntị chiri: ọtanjele ahụ maka ọcha',
    '🧏🏼‍♀' => 'nwanyị ntị chiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧏🏽‍♀' => 'nwanyị ntị chiri: ọtanjele ahụ ndịna etiti',
    '🧏🏾‍♀' => 'nwanyị ntị chiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🧏🏿‍♀' => 'nwanyị ntị chiri: ọtanjele ahụ maka òji',
    '🙇🏻‍♂' => 'nwoke na-ehulata ala: ọtanjele ahụ maka ọcha',
    '🙇🏼‍♂' => 'nwoke na-ehulata ala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙇🏽‍♂' => 'nwoke na-ehulata ala: ọtanjele ahụ ndịna etiti',
    '🙇🏾‍♂' => 'nwoke na-ehulata ala: ọtanjele ahụ maka òji-ndịna etiti',
    '🙇🏿‍♂' => 'nwoke na-ehulata ala: ọtanjele ahụ maka òji',
    '🙇🏻‍♀' => 'nwanyị na-ehulata ala: ọtanjele ahụ maka ọcha',
    '🙇🏼‍♀' => 'nwanyị na-ehulata ala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙇🏽‍♀' => 'nwanyị na-ehulata ala: ọtanjele ahụ ndịna etiti',
    '🙇🏾‍♀' => 'nwanyị na-ehulata ala: ọtanjele ahụ maka òji-ndịna etiti',
    '🙇🏿‍♀' => 'nwanyị na-ehulata ala: ọtanjele ahụ maka òji',
    '🤦🏻‍♂' => 'nwoke na-ezo ihu ya èzo: ọtanjele ahụ maka ọcha',
    '🤦🏼‍♂' => 'nwoke na-ezo ihu ya èzo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤦🏽‍♂' => 'nwoke na-ezo ihu ya èzo: ọtanjele ahụ ndịna etiti',
    '🤦🏾‍♂' => 'nwoke na-ezo ihu ya èzo: ọtanjele ahụ maka òji-ndịna etiti',
    '🤦🏿‍♂' => 'nwoke na-ezo ihu ya èzo: ọtanjele ahụ maka òji',
    '🤦🏻‍♀' => 'nwanyị na-ezo ihu ya èzo: ọtanjele ahụ maka ọcha',
    '🤦🏼‍♀' => 'nwanyị na-ezo ihu ya èzo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤦🏽‍♀' => 'nwanyị na-ezo ihu ya èzo: ọtanjele ahụ ndịna etiti',
    '🤦🏾‍♀' => 'nwanyị na-ezo ihu ya èzo: ọtanjele ahụ maka òji-ndịna etiti',
    '🤦🏿‍♀' => 'nwanyị na-ezo ihu ya èzo: ọtanjele ahụ maka òji',
    '🤷🏻‍♂' => 'nwoke na-egosi nhatanha aka: ọtanjele ahụ maka ọcha',
    '🤷🏼‍♂' => 'nwoke na-egosi nhatanha aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤷🏽‍♂' => 'nwoke na-egosi nhatanha aka: ọtanjele ahụ ndịna etiti',
    '🤷🏾‍♂' => 'nwoke na-egosi nhatanha aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤷🏿‍♂' => 'nwoke na-egosi nhatanha aka: ọtanjele ahụ maka òji',
    '🤷🏻‍♀' => 'nwanyị na-egosi nhatanha aka: ọtanjele ahụ maka ọcha',
    '🤷🏼‍♀' => 'nwanyị na-egosi nhatanha aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤷🏽‍♀' => 'nwanyị na-egosi nhatanha aka: ọtanjele ahụ ndịna etiti',
    '🤷🏾‍♀' => 'nwanyị na-egosi nhatanha aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤷🏿‍♀' => 'nwanyị na-egosi nhatanha aka: ọtanjele ahụ maka òji',
    '🧑🏻‍⚕' => 'onye ọrụ ahụike: ọtanjele ahụ maka ọcha',
    '🧑🏼‍⚕' => 'onye ọrụ ahụike: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍⚕' => 'onye ọrụ ahụike: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍⚕' => 'onye ọrụ ahụike: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍⚕' => 'onye ọrụ ahụike: ọtanjele ahụ maka òji',
    '👨🏻‍⚕' => 'nwoke ọrụ ahụike: ọtanjele ahụ maka ọcha',
    '👨🏼‍⚕' => 'nwoke ọrụ ahụike: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍⚕' => 'nwoke ọrụ ahụike: ọtanjele ahụ ndịna etiti',
    '👨🏾‍⚕' => 'nwoke ọrụ ahụike: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍⚕' => 'nwoke ọrụ ahụike: ọtanjele ahụ maka òji',
    '👩🏻‍⚕' => 'nwanyị onye ọrụ ahụike: ọtanjele ahụ maka ọcha',
    '👩🏼‍⚕' => 'nwanyị onye ọrụ ahụike: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍⚕' => 'nwanyị onye ọrụ ahụike: ọtanjele ahụ ndịna etiti',
    '👩🏾‍⚕' => 'nwanyị onye ọrụ ahụike: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍⚕' => 'nwanyị onye ọrụ ahụike: ọtanjele ahụ maka òji',
    '🧑🏻‍🎓' => 'nwata akwụkwọ: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🎓' => 'nwata akwụkwọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🎓' => 'nwata akwụkwọ: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🎓' => 'nwata akwụkwọ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🎓' => 'nwata akwụkwọ: ọtanjele ahụ maka òji',
    '👨🏻‍🎓' => 'nwoke nwata akwụkwọ: ọtanjele ahụ maka ọcha',
    '👨🏼‍🎓' => 'nwoke nwata akwụkwọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🎓' => 'nwoke nwata akwụkwọ: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🎓' => 'nwoke nwata akwụkwọ: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🎓' => 'nwoke nwata akwụkwọ: ọtanjele ahụ maka òji',
    '👩🏻‍🎓' => 'nwanyị nwaakwụkwọ: ọtanjele ahụ maka ọcha',
    '👩🏼‍🎓' => 'nwanyị nwaakwụkwọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🎓' => 'nwanyị nwaakwụkwọ: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🎓' => 'nwanyị nwaakwụkwọ: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🎓' => 'nwanyị nwaakwụkwọ: ọtanjele ahụ maka òji',
    '🧑🏻‍🏫' => 'onyenkuzi: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🏫' => 'onyenkuzi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🏫' => 'onyenkuzi: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🏫' => 'onyenkuzi: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🏫' => 'onyenkuzi: ọtanjele ahụ maka òji',
    '👨🏻‍🏫' => 'nwoke onyenkuzi: ọtanjele ahụ maka ọcha',
    '👨🏼‍🏫' => 'nwoke onyenkuzi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🏫' => 'nwoke onyenkuzi: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🏫' => 'nwoke onyenkuzi: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🏫' => 'nwoke onyenkuzi: ọtanjele ahụ maka òji',
    '👩🏻‍🏫' => 'nwanyị ọkammụta: ọtanjele ahụ maka ọcha',
    '👩🏼‍🏫' => 'nwanyị ọkammụta: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🏫' => 'nwanyị ọkammụta: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🏫' => 'nwanyị ọkammụta: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🏫' => 'nwanyị ọkammụta: ọtanjele ahụ maka òji',
    '🧑🏻‍⚖' => 'onye ikpe: ọtanjele ahụ maka ọcha',
    '🧑🏼‍⚖' => 'onye ikpe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍⚖' => 'onye ikpe: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍⚖' => 'onye ikpe: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍⚖' => 'onye ikpe: ọtanjele ahụ maka òji',
    '👨🏻‍⚖' => 'nwoke ikpe: ọtanjele ahụ maka ọcha',
    '👨🏼‍⚖' => 'nwoke ikpe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍⚖' => 'nwoke ikpe: ọtanjele ahụ ndịna etiti',
    '👨🏾‍⚖' => 'nwoke ikpe: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍⚖' => 'nwoke ikpe: ọtanjele ahụ maka òji',
    '👩🏻‍⚖' => 'nwanyị ikpe nkwụọtọ: ọtanjele ahụ maka ọcha',
    '👩🏼‍⚖' => 'nwanyị ikpe nkwụọtọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍⚖' => 'nwanyị ikpe nkwụọtọ: ọtanjele ahụ ndịna etiti',
    '👩🏾‍⚖' => 'nwanyị ikpe nkwụọtọ: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍⚖' => 'nwanyị ikpe nkwụọtọ: ọtanjele ahụ maka òji',
    '🧑🏻‍🌾' => 'onye ọrụ ugbo: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🌾' => 'onye ọrụ ugbo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🌾' => 'onye ọrụ ugbo: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🌾' => 'onye ọrụ ugbo: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🌾' => 'onye ọrụ ugbo: ọtanjele ahụ maka òji',
    '👨🏻‍🌾' => 'nwoke ọrụ ugbo: ọtanjele ahụ maka ọcha',
    '👨🏼‍🌾' => 'nwoke ọrụ ugbo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🌾' => 'nwoke ọrụ ugbo: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🌾' => 'nwoke ọrụ ugbo: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🌾' => 'nwoke ọrụ ugbo: ọtanjele ahụ maka òji',
    '👩🏻‍🌾' => 'nwanyị ọrụ ugbo: ọtanjele ahụ maka ọcha',
    '👩🏼‍🌾' => 'nwanyị ọrụ ugbo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🌾' => 'nwanyị ọrụ ugbo: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🌾' => 'nwanyị ọrụ ugbo: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🌾' => 'nwanyị ọrụ ugbo: ọtanjele ahụ maka òji',
    '🧑🏻‍🍳' => 'onye na-esi nri: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🍳' => 'onye na-esi nri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🍳' => 'onye na-esi nri: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🍳' => 'onye na-esi nri: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🍳' => 'onye na-esi nri: ọtanjele ahụ maka òji',
    '👨🏻‍🍳' => 'nwoke na-esi nri: ọtanjele ahụ maka ọcha',
    '👨🏼‍🍳' => 'nwoke na-esi nri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🍳' => 'nwoke na-esi nri: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🍳' => 'nwoke na-esi nri: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🍳' => 'nwoke na-esi nri: ọtanjele ahụ maka òji',
    '👩🏻‍🍳' => 'nwanyị na-esi: ọtanjele ahụ maka ọcha',
    '👩🏼‍🍳' => 'nwanyị na-esi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🍳' => 'nwanyị na-esi: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🍳' => 'nwanyị na-esi: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🍳' => 'nwanyị na-esi: ọtanjele ahụ maka òji',
    '🧑🏻‍🔧' => 'onye na-arụzi ụgbọala: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🔧' => 'onye na-arụzi ụgbọala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🔧' => 'onye na-arụzi ụgbọala: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🔧' => 'onye na-arụzi ụgbọala: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🔧' => 'onye na-arụzi ụgbọala: ọtanjele ahụ maka òji',
    '👨🏻‍🔧' => 'nwoke onye na-arụzi ụgbọala: ọtanjele ahụ maka ọcha',
    '👨🏼‍🔧' => 'nwoke onye na-arụzi ụgbọala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🔧' => 'nwoke onye na-arụzi ụgbọala: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🔧' => 'nwoke onye na-arụzi ụgbọala: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🔧' => 'nwoke onye na-arụzi ụgbọala: ọtanjele ahụ maka òji',
    '👩🏻‍🔧' => 'nwanyị na-arụzi ụgbọala: ọtanjele ahụ maka ọcha',
    '👩🏼‍🔧' => 'nwanyị na-arụzi ụgbọala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🔧' => 'nwanyị na-arụzi ụgbọala: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🔧' => 'nwanyị na-arụzi ụgbọala: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🔧' => 'nwanyị na-arụzi ụgbọala: ọtanjele ahụ maka òji',
    '🧑🏻‍🏭' => 'onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🏭' => 'onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🏭' => 'onyeọrụ ụlọ ọrụ: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🏭' => 'onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🏭' => 'onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka òji',
    '👨🏻‍🏭' => 'nwoke onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka ọcha',
    '👨🏼‍🏭' => 'nwoke onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🏭' => 'nwoke onyeọrụ ụlọ ọrụ: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🏭' => 'nwoke onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🏭' => 'nwoke onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka òji',
    '👩🏻‍🏭' => 'nwanyị onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka ọcha',
    '👩🏼‍🏭' => 'nwanyị onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🏭' => 'nwanyị onyeọrụ ụlọ ọrụ: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🏭' => 'nwanyị onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🏭' => 'nwanyị onyeọrụ ụlọ ọrụ: ọtanjele ahụ maka òji',
    '🧑🏻‍💼' => 'onye ọrụ ọfịịsị: ọtanjele ahụ maka ọcha',
    '🧑🏼‍💼' => 'onye ọrụ ọfịịsị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍💼' => 'onye ọrụ ọfịịsị: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍💼' => 'onye ọrụ ọfịịsị: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍💼' => 'onye ọrụ ọfịịsị: ọtanjele ahụ maka òji',
    '👨🏻‍💼' => 'nwoke onye ọrụ ọfịịsị: ọtanjele ahụ maka ọcha',
    '👨🏼‍💼' => 'nwoke onye ọrụ ọfịịsị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍💼' => 'nwoke onye ọrụ ọfịịsị: ọtanjele ahụ ndịna etiti',
    '👨🏾‍💼' => 'nwoke onye ọrụ ọfịịsị: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍💼' => 'nwoke onye ọrụ ọfịịsị: ọtanjele ahụ maka òji',
    '👩🏻‍💼' => 'nwanyị onye ọrụ ọfịịsị: ọtanjele ahụ maka ọcha',
    '👩🏼‍💼' => 'nwanyị onye ọrụ ọfịịsị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍💼' => 'nwanyị onye ọrụ ọfịịsị: ọtanjele ahụ ndịna etiti',
    '👩🏾‍💼' => 'nwanyị onye ọrụ ọfịịsị: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍💼' => 'nwanyị onye ọrụ ọfịịsị: ọtanjele ahụ maka òji',
    '🧑🏻‍🔬' => 'ọkammụta sayensi: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🔬' => 'ọkammụta sayensi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🔬' => 'ọkammụta sayensi: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🔬' => 'ọkammụta sayensi: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🔬' => 'ọkammụta sayensi: ọtanjele ahụ maka òji',
    '👨🏻‍🔬' => 'nwoke ọkammụta sayensi: ọtanjele ahụ maka ọcha',
    '👨🏼‍🔬' => 'nwoke ọkammụta sayensi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🔬' => 'nwoke ọkammụta sayensi: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🔬' => 'nwoke ọkammụta sayensi: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🔬' => 'nwoke ọkammụta sayensi: ọtanjele ahụ maka òji',
    '👩🏻‍🔬' => 'nwanyị ọkammụta sayensi: ọtanjele ahụ maka ọcha',
    '👩🏼‍🔬' => 'nwanyị ọkammụta sayensi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🔬' => 'nwanyị ọkammụta sayensi: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🔬' => 'nwanyị ọkammụta sayensi: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🔬' => 'nwanyị ọkammụta sayensi: ọtanjele ahụ maka òji',
    '🧑🏻‍💻' => 'onye teknụụzụ: ọtanjele ahụ maka ọcha',
    '🧑🏼‍💻' => 'onye teknụụzụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍💻' => 'onye teknụụzụ: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍💻' => 'onye teknụụzụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍💻' => 'onye teknụụzụ: ọtanjele ahụ maka òji',
    '👨🏻‍💻' => 'nwoke onye teknụụzụ: ọtanjele ahụ maka ọcha',
    '👨🏼‍💻' => 'nwoke onye teknụụzụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍💻' => 'nwoke onye teknụụzụ: ọtanjele ahụ ndịna etiti',
    '👨🏾‍💻' => 'nwoke onye teknụụzụ: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍💻' => 'nwoke onye teknụụzụ: ọtanjele ahụ maka òji',
    '👩🏻‍💻' => 'nwanyi onye teknụụzụ: ọtanjele ahụ maka ọcha',
    '👩🏼‍💻' => 'nwanyi onye teknụụzụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍💻' => 'nwanyi onye teknụụzụ: ọtanjele ahụ ndịna etiti',
    '👩🏾‍💻' => 'nwanyi onye teknụụzụ: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍💻' => 'nwanyi onye teknụụzụ: ọtanjele ahụ maka òji',
    '🧑🏻‍🎤' => 'ọgụụ egwu: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🎤' => 'ọgụụ egwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🎤' => 'ọgụụ egwu: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🎤' => 'ọgụụ egwu: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🎤' => 'ọgụụ egwu: ọtanjele ahụ maka òji',
    '👨🏻‍🎤' => 'nwoke ọgụụ egwu: ọtanjele ahụ maka ọcha',
    '👨🏼‍🎤' => 'nwoke ọgụụ egwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🎤' => 'nwoke ọgụụ egwu: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🎤' => 'nwoke ọgụụ egwu: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🎤' => 'nwoke ọgụụ egwu: ọtanjele ahụ maka òji',
    '👩🏻‍🎤' => 'nwanyi ọgụụ egwu: ọtanjele ahụ maka ọcha',
    '👩🏼‍🎤' => 'nwanyi ọgụụ egwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🎤' => 'nwanyi ọgụụ egwu: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🎤' => 'nwanyi ọgụụ egwu: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🎤' => 'nwanyi ọgụụ egwu: ọtanjele ahụ maka òji',
    '🧑🏻‍🎨' => 'omeǹkà: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🎨' => 'omeǹkà: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🎨' => 'omeǹkà: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🎨' => 'omeǹkà: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🎨' => 'omeǹkà: ọtanjele ahụ maka òji',
    '👨🏻‍🎨' => 'omeǹkà nwoke: ọtanjele ahụ maka ọcha',
    '👨🏼‍🎨' => 'omeǹkà nwoke: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🎨' => 'omeǹkà nwoke: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🎨' => 'omeǹkà nwoke: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🎨' => 'omeǹkà nwoke: ọtanjele ahụ maka òji',
    '👩🏻‍🎨' => 'omeǹkà nwanyị: ọtanjele ahụ maka ọcha',
    '👩🏼‍🎨' => 'omeǹkà nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🎨' => 'omeǹkà nwanyị: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🎨' => 'omeǹkà nwanyị: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🎨' => 'omeǹkà nwanyị: ọtanjele ahụ maka òji',
    '🧑🏻‍✈' => 'ọkwọ ugbọelu: ọtanjele ahụ maka ọcha',
    '🧑🏼‍✈' => 'ọkwọ ugbọelu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍✈' => 'ọkwọ ugbọelu: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍✈' => 'ọkwọ ugbọelu: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍✈' => 'ọkwọ ugbọelu: ọtanjele ahụ maka òji',
    '👨🏻‍✈' => 'nwoke ọkwọ ugbọelu: ọtanjele ahụ maka ọcha',
    '👨🏼‍✈' => 'nwoke ọkwọ ugbọelu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍✈' => 'nwoke ọkwọ ugbọelu: ọtanjele ahụ ndịna etiti',
    '👨🏾‍✈' => 'nwoke ọkwọ ugbọelu: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍✈' => 'nwoke ọkwọ ugbọelu: ọtanjele ahụ maka òji',
    '👩🏻‍✈' => 'nwanyị ọkwọ ugbọelu: ọtanjele ahụ maka ọcha',
    '👩🏼‍✈' => 'nwanyị ọkwọ ugbọelu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍✈' => 'nwanyị ọkwọ ugbọelu: ọtanjele ahụ ndịna etiti',
    '👩🏾‍✈' => 'nwanyị ọkwọ ugbọelu: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍✈' => 'nwanyị ọkwọ ugbọelu: ọtanjele ahụ maka òji',
    '🧑🏻‍🚀' => 'òjenọnwa: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🚀' => 'òjenọnwa: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🚀' => 'òjenọnwa: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🚀' => 'òjenọnwa: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🚀' => 'òjenọnwa: ọtanjele ahụ maka òji',
    '👨🏻‍🚀' => 'nwoke òjenọnwa: ọtanjele ahụ maka ọcha',
    '👨🏼‍🚀' => 'nwoke òjenọnwa: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🚀' => 'nwoke òjenọnwa: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🚀' => 'nwoke òjenọnwa: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🚀' => 'nwoke òjenọnwa: ọtanjele ahụ maka òji',
    '👩🏻‍🚀' => 'nwanyị òjenọnwa: ọtanjele ahụ maka ọcha',
    '👩🏼‍🚀' => 'nwanyị òjenọnwa: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🚀' => 'nwanyị òjenọnwa: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🚀' => 'nwanyị òjenọnwa: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🚀' => 'nwanyị òjenọnwa: ọtanjele ahụ maka òji',
    '🧑🏻‍🚒' => 'onyemgbanyụọkụ: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🚒' => 'onyemgbanyụọkụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🚒' => 'onyemgbanyụọkụ: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🚒' => 'onyemgbanyụọkụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🚒' => 'onyemgbanyụọkụ: ọtanjele ahụ maka òji',
    '👨🏻‍🚒' => 'nwoke onyemgbanyụọkụ: ọtanjele ahụ maka ọcha',
    '👨🏼‍🚒' => 'nwoke onyemgbanyụọkụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🚒' => 'nwoke onyemgbanyụọkụ: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🚒' => 'nwoke onyemgbanyụọkụ: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🚒' => 'nwoke onyemgbanyụọkụ: ọtanjele ahụ maka òji',
    '👩🏻‍🚒' => 'nwanyị onyemgbanyụọkụ: ọtanjele ahụ maka ọcha',
    '👩🏼‍🚒' => 'nwanyị onyemgbanyụọkụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🚒' => 'nwanyị onyemgbanyụọkụ: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🚒' => 'nwanyị onyemgbanyụọkụ: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🚒' => 'nwanyị onyemgbanyụọkụ: ọtanjele ahụ maka òji',
    '👮🏻‍♂' => 'jide: ọtanjele ahụ maka ọcha',
    '👮🏼‍♂' => 'jide: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👮🏽‍♂' => 'jide: ọtanjele ahụ ndịna etiti',
    '👮🏾‍♂' => 'jide: ọtanjele ahụ maka òji-ndịna etiti',
    '👮🏿‍♂' => 'jide: ọtanjele ahụ maka òji',
    '👮🏻‍♀' => 'nwanyị onye uweojii: ọtanjele ahụ maka ọcha',
    '👮🏼‍♀' => 'nwanyị onye uweojii: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👮🏽‍♀' => 'nwanyị onye uweojii: ọtanjele ahụ ndịna etiti',
    '👮🏾‍♀' => 'nwanyị onye uweojii: ọtanjele ahụ maka òji-ndịna etiti',
    '👮🏿‍♀' => 'nwanyị onye uweojii: ọtanjele ahụ maka òji',
    '🕵🏻‍♂' => 'nwoke nchọpụta: ọtanjele ahụ maka ọcha',
    '🕵🏼‍♂' => 'nwoke nchọpụta: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🕵🏽‍♂' => 'nwoke nchọpụta: ọtanjele ahụ ndịna etiti',
    '🕵🏾‍♂' => 'nwoke nchọpụta: ọtanjele ahụ maka òji-ndịna etiti',
    '🕵🏿‍♂' => 'nwoke nchọpụta: ọtanjele ahụ maka òji',
    '🕵🏻‍♀' => 'nwanyị nchọpụta: ọtanjele ahụ maka ọcha',
    '🕵🏼‍♀' => 'nwanyị nchọpụta: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🕵🏽‍♀' => 'nwanyị nchọpụta: ọtanjele ahụ ndịna etiti',
    '🕵🏾‍♀' => 'nwanyị nchọpụta: ọtanjele ahụ maka òji-ndịna etiti',
    '🕵🏿‍♀' => 'nwanyị nchọpụta: ọtanjele ahụ maka òji',
    '💂🏻‍♂' => 'nwoke nche: ọtanjele ahụ maka ọcha',
    '💂🏼‍♂' => 'nwoke nche: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💂🏽‍♂' => 'nwoke nche: ọtanjele ahụ ndịna etiti',
    '💂🏾‍♂' => 'nwoke nche: ọtanjele ahụ maka òji-ndịna etiti',
    '💂🏿‍♂' => 'nwoke nche: ọtanjele ahụ maka òji',
    '💂🏻‍♀' => 'nwanyị nche: ọtanjele ahụ maka ọcha',
    '💂🏼‍♀' => 'nwanyị nche: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💂🏽‍♀' => 'nwanyị nche: ọtanjele ahụ ndịna etiti',
    '💂🏾‍♀' => 'nwanyị nche: ọtanjele ahụ maka òji-ndịna etiti',
    '💂🏿‍♀' => 'nwanyị nche: ọtanjele ahụ maka òji',
    '👷🏻‍♂' => 'onye ọrụ nwoke: ọtanjele ahụ maka ọcha',
    '👷🏼‍♂' => 'onye ọrụ nwoke: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👷🏽‍♂' => 'onye ọrụ nwoke: ọtanjele ahụ ndịna etiti',
    '👷🏾‍♂' => 'onye ọrụ nwoke: ọtanjele ahụ maka òji-ndịna etiti',
    '👷🏿‍♂' => 'onye ọrụ nwoke: ọtanjele ahụ maka òji',
    '👷🏻‍♀' => 'onye ọrụ nwanyị: ọtanjele ahụ maka ọcha',
    '👷🏼‍♀' => 'onye ọrụ nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👷🏽‍♀' => 'onye ọrụ nwanyị: ọtanjele ahụ ndịna etiti',
    '👷🏾‍♀' => 'onye ọrụ nwanyị: ọtanjele ahụ maka òji-ndịna etiti',
    '👷🏿‍♀' => 'onye ọrụ nwanyị: ọtanjele ahụ maka òji',
    '👳🏻‍♂' => 'nwoke yi turban: ọtanjele ahụ maka ọcha',
    '👳🏼‍♂' => 'nwoke yi turban: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👳🏽‍♂' => 'nwoke yi turban: ọtanjele ahụ ndịna etiti',
    '👳🏾‍♂' => 'nwoke yi turban: ọtanjele ahụ maka òji-ndịna etiti',
    '👳🏿‍♂' => 'nwoke yi turban: ọtanjele ahụ maka òji',
    '👳🏻‍♀' => 'nwanyị yi turban: ọtanjele ahụ maka ọcha',
    '👳🏼‍♀' => 'nwanyị yi turban: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👳🏽‍♀' => 'nwanyị yi turban: ọtanjele ahụ ndịna etiti',
    '👳🏾‍♀' => 'nwanyị yi turban: ọtanjele ahụ maka òji-ndịna etiti',
    '👳🏿‍♀' => 'nwanyị yi turban: ọtanjele ahụ maka òji',
    '🤵🏻‍♂' => 'nwoke yi uwe tuxedo: ọtanjele ahụ maka ọcha',
    '🤵🏼‍♂' => 'nwoke yi uwe tuxedo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤵🏽‍♂' => 'nwoke yi uwe tuxedo: ọtanjele ahụ ndịna etiti',
    '🤵🏾‍♂' => 'nwoke yi uwe tuxedo: ọtanjele ahụ maka òji-ndịna etiti',
    '🤵🏿‍♂' => 'nwoke yi uwe tuxedo: ọtanjele ahụ maka òji',
    '🤵🏻‍♀' => 'nwanyị yi uwe tuxedo: ọtanjele ahụ maka ọcha',
    '🤵🏼‍♀' => 'nwanyị yi uwe tuxedo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤵🏽‍♀' => 'nwanyị yi uwe tuxedo: ọtanjele ahụ ndịna etiti',
    '🤵🏾‍♀' => 'nwanyị yi uwe tuxedo: ọtanjele ahụ maka òji-ndịna etiti',
    '🤵🏿‍♀' => 'nwanyị yi uwe tuxedo: ọtanjele ahụ maka òji',
    '👰🏻‍♂' => 'nwoke yi akwà nkochi ihu: ọtanjele ahụ maka ọcha',
    '👰🏼‍♂' => 'nwoke yi akwà nkochi ihu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👰🏽‍♂' => 'nwoke yi akwà nkochi ihu: ọtanjele ahụ ndịna etiti',
    '👰🏾‍♂' => 'nwoke yi akwà nkochi ihu: ọtanjele ahụ maka òji-ndịna etiti',
    '👰🏿‍♂' => 'nwoke yi akwà nkochi ihu: ọtanjele ahụ maka òji',
    '👰🏻‍♀' => 'nwanyị nkochi ihu: ọtanjele ahụ maka ọcha',
    '👰🏼‍♀' => 'nwanyị nkochi ihu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👰🏽‍♀' => 'nwanyị nkochi ihu: ọtanjele ahụ ndịna etiti',
    '👰🏾‍♀' => 'nwanyị nkochi ihu: ọtanjele ahụ maka òji-ndịna etiti',
    '👰🏿‍♀' => 'nwanyị nkochi ihu: ọtanjele ahụ maka òji',
    '👩🏻‍🍼' => 'nwanyị n’enye nwa nri: ọtanjele ahụ maka ọcha',
    '👩🏼‍🍼' => 'nwanyị n’enye nwa nri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🍼' => 'nwanyị n’enye nwa nri: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🍼' => 'nwanyị n’enye nwa nri: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🍼' => 'nwanyị n’enye nwa nri: ọtanjele ahụ maka òji',
    '👨🏻‍🍼' => 'nwoke n’enye nwa nri: ọtanjele ahụ maka ọcha',
    '👨🏼‍🍼' => 'nwoke n’enye nwa nri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🍼' => 'nwoke n’enye nwa nri: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🍼' => 'nwoke n’enye nwa nri: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🍼' => 'nwoke n’enye nwa nri: ọtanjele ahụ maka òji',
    '🧑🏻‍🍼' => 'onye n’enye nwa nri: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🍼' => 'onye n’enye nwa nri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🍼' => 'onye n’enye nwa nri: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🍼' => 'onye n’enye nwa nri: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🍼' => 'onye n’enye nwa nri: ọtanjele ahụ maka òji',
    '🧑🏻‍🎄' => 'mx claus: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🎄' => 'mx claus: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🎄' => 'mx claus: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🎄' => 'mx claus: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🎄' => 'mx claus: ọtanjele ahụ maka òji',
    '🦸🏻‍♂' => 'dike nwoke: ọtanjele ahụ maka ọcha',
    '🦸🏼‍♂' => 'dike nwoke: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🦸🏽‍♂' => 'dike nwoke: ọtanjele ahụ ndịna etiti',
    '🦸🏾‍♂' => 'dike nwoke: ọtanjele ahụ maka òji-ndịna etiti',
    '🦸🏿‍♂' => 'dike nwoke: ọtanjele ahụ maka òji',
    '🦸🏻‍♀' => 'dike nwanyị: ọtanjele ahụ maka ọcha',
    '🦸🏼‍♀' => 'dike nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🦸🏽‍♀' => 'dike nwanyị: ọtanjele ahụ ndịna etiti',
    '🦸🏾‍♀' => 'dike nwanyị: ọtanjele ahụ maka òji-ndịna etiti',
    '🦸🏿‍♀' => 'dike nwanyị: ọtanjele ahụ maka òji',
    '🦹🏻‍♂' => 'nwoke onye ọjọọ: ọtanjele ahụ maka ọcha',
    '🦹🏼‍♂' => 'nwoke onye ọjọọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🦹🏽‍♂' => 'nwoke onye ọjọọ: ọtanjele ahụ ndịna etiti',
    '🦹🏾‍♂' => 'nwoke onye ọjọọ: ọtanjele ahụ maka òji-ndịna etiti',
    '🦹🏿‍♂' => 'nwoke onye ọjọọ: ọtanjele ahụ maka òji',
    '🦹🏻‍♀' => 'nwanyị onye ọjọọ: ọtanjele ahụ maka ọcha',
    '🦹🏼‍♀' => 'nwanyị onye ọjọọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🦹🏽‍♀' => 'nwanyị onye ọjọọ: ọtanjele ahụ ndịna etiti',
    '🦹🏾‍♀' => 'nwanyị onye ọjọọ: ọtanjele ahụ maka òji-ndịna etiti',
    '🦹🏿‍♀' => 'nwanyị onye ọjọọ: ọtanjele ahụ maka òji',
    '🧙🏻‍♂' => 'nwoke abrakatabra: ọtanjele ahụ maka ọcha',
    '🧙🏼‍♂' => 'nwoke abrakatabra: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧙🏽‍♂' => 'nwoke abrakatabra: ọtanjele ahụ ndịna etiti',
    '🧙🏾‍♂' => 'nwoke abrakatabra: ọtanjele ahụ maka òji-ndịna etiti',
    '🧙🏿‍♂' => 'nwoke abrakatabra: ọtanjele ahụ maka òji',
    '🧙🏻‍♀' => 'nwanyị onye abrakatabra: ọtanjele ahụ maka ọcha',
    '🧙🏼‍♀' => 'nwanyị onye abrakatabra: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧙🏽‍♀' => 'nwanyị onye abrakatabra: ọtanjele ahụ ndịna etiti',
    '🧙🏾‍♀' => 'nwanyị onye abrakatabra: ọtanjele ahụ maka òji-ndịna etiti',
    '🧙🏿‍♀' => 'nwanyị onye abrakatabra: ọtanjele ahụ maka òji',
    '🧚🏻‍♂' => 'akụkọ nwoke: ọtanjele ahụ maka ọcha',
    '🧚🏼‍♂' => 'akụkọ nwoke: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧚🏽‍♂' => 'akụkọ nwoke: ọtanjele ahụ ndịna etiti',
    '🧚🏾‍♂' => 'akụkọ nwoke: ọtanjele ahụ maka òji-ndịna etiti',
    '🧚🏿‍♂' => 'akụkọ nwoke: ọtanjele ahụ maka òji',
    '🧚🏻‍♀' => 'akụkọ nwanyị: ọtanjele ahụ maka ọcha',
    '🧚🏼‍♀' => 'akụkọ nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧚🏽‍♀' => 'akụkọ nwanyị: ọtanjele ahụ ndịna etiti',
    '🧚🏾‍♀' => 'akụkọ nwanyị: ọtanjele ahụ maka òji-ndịna etiti',
    '🧚🏿‍♀' => 'akụkọ nwanyị: ọtanjele ahụ maka òji',
    '🧛🏻‍♂' => 'nwoke ọmị ọbara: ọtanjele ahụ maka ọcha',
    '🧛🏼‍♂' => 'nwoke ọmị ọbara: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧛🏽‍♂' => 'nwoke ọmị ọbara: ọtanjele ahụ ndịna etiti',
    '🧛🏾‍♂' => 'nwoke ọmị ọbara: ọtanjele ahụ maka òji-ndịna etiti',
    '🧛🏿‍♂' => 'nwoke ọmị ọbara: ọtanjele ahụ maka òji',
    '🧛🏻‍♀' => 'nwanyị ọmị obara: ọtanjele ahụ maka ọcha',
    '🧛🏼‍♀' => 'nwanyị ọmị obara: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧛🏽‍♀' => 'nwanyị ọmị obara: ọtanjele ahụ ndịna etiti',
    '🧛🏾‍♀' => 'nwanyị ọmị obara: ọtanjele ahụ maka òji-ndịna etiti',
    '🧛🏿‍♀' => 'nwanyị ọmị obara: ọtanjele ahụ maka òji',
    '🧜🏻‍♂' => 'nwokewọta: ọtanjele ahụ maka ọcha',
    '🧜🏼‍♂' => 'nwokewọta: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧜🏽‍♂' => 'nwokewọta: ọtanjele ahụ ndịna etiti',
    '🧜🏾‍♂' => 'nwokewọta: ọtanjele ahụ maka òji-ndịna etiti',
    '🧜🏿‍♂' => 'nwokewọta: ọtanjele ahụ maka òji',
    '🧜🏻‍♀' => 'mamịwọta: ọtanjele ahụ maka ọcha',
    '🧜🏼‍♀' => 'mamịwọta: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧜🏽‍♀' => 'mamịwọta: ọtanjele ahụ ndịna etiti',
    '🧜🏾‍♀' => 'mamịwọta: ọtanjele ahụ maka òji-ndịna etiti',
    '🧜🏿‍♀' => 'mamịwọta: ọtanjele ahụ maka òji',
    '🧝🏻‍♂' => 'nwoke elfụ: ọtanjele ahụ maka ọcha',
    '🧝🏼‍♂' => 'nwoke elfụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧝🏽‍♂' => 'nwoke elfụ: ọtanjele ahụ ndịna etiti',
    '🧝🏾‍♂' => 'nwoke elfụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧝🏿‍♂' => 'nwoke elfụ: ọtanjele ahụ maka òji',
    '🧝🏻‍♀' => 'nwanyị elfụ: ọtanjele ahụ maka ọcha',
    '🧝🏼‍♀' => 'nwanyị elfụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧝🏽‍♀' => 'nwanyị elfụ: ọtanjele ahụ ndịna etiti',
    '🧝🏾‍♀' => 'nwanyị elfụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧝🏿‍♀' => 'nwanyị elfụ: ọtanjele ahụ maka òji',
    '💆🏻‍♂' => 'nwoke na-anata ozi: ọtanjele ahụ maka ọcha',
    '💆🏼‍♂' => 'nwoke na-anata ozi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💆🏽‍♂' => 'nwoke na-anata ozi: ọtanjele ahụ ndịna etiti',
    '💆🏾‍♂' => 'nwoke na-anata ozi: ọtanjele ahụ maka òji-ndịna etiti',
    '💆🏿‍♂' => 'nwoke na-anata ozi: ọtanjele ahụ maka òji',
    '💆🏻‍♀' => 'nwanyị na-anata ozi: ọtanjele ahụ maka ọcha',
    '💆🏼‍♀' => 'nwanyị na-anata ozi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💆🏽‍♀' => 'nwanyị na-anata ozi: ọtanjele ahụ ndịna etiti',
    '💆🏾‍♀' => 'nwanyị na-anata ozi: ọtanjele ahụ maka òji-ndịna etiti',
    '💆🏿‍♀' => 'nwanyị na-anata ozi: ọtanjele ahụ maka òji',
    '💇🏻‍♂' => 'nwoke na-enweta ọkpụkpụisi: ọtanjele ahụ maka ọcha',
    '💇🏼‍♂' => 'nwoke na-enweta ọkpụkpụisi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💇🏽‍♂' => 'nwoke na-enweta ọkpụkpụisi: ọtanjele ahụ ndịna etiti',
    '💇🏾‍♂' => 'nwoke na-enweta ọkpụkpụisi: ọtanjele ahụ maka òji-ndịna etiti',
    '💇🏿‍♂' => 'nwoke na-enweta ọkpụkpụisi: ọtanjele ahụ maka òji',
    '💇🏻‍♀' => 'nwanyị na-enweta ọkpụkpụisi: ọtanjele ahụ maka ọcha',
    '💇🏼‍♀' => 'nwanyị na-enweta ọkpụkpụisi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💇🏽‍♀' => 'nwanyị na-enweta ọkpụkpụisi: ọtanjele ahụ ndịna etiti',
    '💇🏾‍♀' => 'nwanyị na-enweta ọkpụkpụisi: ọtanjele ahụ maka òji-ndịna etiti',
    '💇🏿‍♀' => 'nwanyị na-enweta ọkpụkpụisi: ọtanjele ahụ maka òji',
    '🚶🏻‍♂' => 'nwoke na-aga ije: ọtanjele ahụ maka ọcha',
    '🚶🏼‍♂' => 'nwoke na-aga ije: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚶🏽‍♂' => 'nwoke na-aga ije: ọtanjele ahụ ndịna etiti',
    '🚶🏾‍♂' => 'nwoke na-aga ije: ọtanjele ahụ maka òji-ndịna etiti',
    '🚶🏿‍♂' => 'nwoke na-aga ije: ọtanjele ahụ maka òji',
    '🚶🏻‍♀' => 'nwanyị na-aga ije: ọtanjele ahụ maka ọcha',
    '🚶🏼‍♀' => 'nwanyị na-aga ije: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚶🏽‍♀' => 'nwanyị na-aga ije: ọtanjele ahụ ndịna etiti',
    '🚶🏾‍♀' => 'nwanyị na-aga ije: ọtanjele ahụ maka òji-ndịna etiti',
    '🚶🏿‍♀' => 'nwanyị na-aga ije: ọtanjele ahụ maka òji',
    '🚶🏻‍➡' => 'onye na-aga ije: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🚶🏼‍➡' => 'onye na-aga ije: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🚶🏽‍➡' => 'onye na-aga ije: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🚶🏾‍➡' => 'onye na-aga ije: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🚶🏿‍➡' => 'onye na-aga ije: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🧍🏻‍♂' => 'nwoke na-eguzo: ọtanjele ahụ maka ọcha',
    '🧍🏼‍♂' => 'nwoke na-eguzo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧍🏽‍♂' => 'nwoke na-eguzo: ọtanjele ahụ ndịna etiti',
    '🧍🏾‍♂' => 'nwoke na-eguzo: ọtanjele ahụ maka òji-ndịna etiti',
    '🧍🏿‍♂' => 'nwoke na-eguzo: ọtanjele ahụ maka òji',
    '🧍🏻‍♀' => 'nwanyị na-eguzo: ọtanjele ahụ maka ọcha',
    '🧍🏼‍♀' => 'nwanyị na-eguzo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧍🏽‍♀' => 'nwanyị na-eguzo: ọtanjele ahụ ndịna etiti',
    '🧍🏾‍♀' => 'nwanyị na-eguzo: ọtanjele ahụ maka òji-ndịna etiti',
    '🧍🏿‍♀' => 'nwanyị na-eguzo: ọtanjele ahụ maka òji',
    '🧎🏻‍♂' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ maka ọcha',
    '🧎🏼‍♂' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧎🏽‍♂' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ ndịna etiti',
    '🧎🏾‍♂' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ maka òji-ndịna etiti',
    '🧎🏿‍♂' => 'nwoke gbu ikpere n’ala: ọtanjele ahụ maka òji',
    '🧎🏻‍♀' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ maka ọcha',
    '🧎🏼‍♀' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧎🏽‍♀' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ ndịna etiti',
    '🧎🏾‍♀' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ maka òji-ndịna etiti',
    '🧎🏿‍♀' => 'nwanyị gbu ikpere n’ala: ọtanjele ahụ maka òji',
    '🧎🏻‍➡' => 'onye gbu ikpere n’ala: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🧎🏼‍➡' => 'onye gbu ikpere n’ala: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🧎🏽‍➡' => 'onye gbu ikpere n’ala: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🧎🏾‍➡' => 'onye gbu ikpere n’ala: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🧎🏿‍➡' => 'onye gbu ikpere n’ala: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '🧑🏻‍🦯' => 'onye ji mkpara ọcha: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🦯' => 'onye ji mkpara ọcha: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🦯' => 'onye ji mkpara ọcha: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🦯' => 'onye ji mkpara ọcha: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🦯' => 'onye ji mkpara ọcha: ọtanjele ahụ maka òji',
    '👨🏻‍🦯' => 'nwoke ji mkpara ọcha: ọtanjele ahụ maka ọcha',
    '👨🏼‍🦯' => 'nwoke ji mkpara ọcha: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🦯' => 'nwoke ji mkpara ọcha: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🦯' => 'nwoke ji mkpara ọcha: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🦯' => 'nwoke ji mkpara ọcha: ọtanjele ahụ maka òji',
    '👩🏻‍🦯' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ maka ọcha',
    '👩🏼‍🦯' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🦯' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🦯' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🦯' => 'nwanyị ji mkpara ọcha: ọtanjele ahụ maka òji',
    '🧑🏻‍🦼' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🦼' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🦼' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🦼' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🦼' => 'onye nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji',
    '👨🏻‍🦼' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha',
    '👨🏼‍🦼' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🦼' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🦼' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🦼' => 'nwoke nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji',
    '👩🏻‍🦼' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha',
    '👩🏼‍🦼' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🦼' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🦼' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🦼' => 'nwanyị nọ n’oche nkwagharị nwere moto: ọtanjele ahụ maka òji',
    '🧑🏻‍🦽' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha',
    '🧑🏼‍🦽' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽‍🦽' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ ndịna etiti',
    '🧑🏾‍🦽' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿‍🦽' => 'onye nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji',
    '👨🏻‍🦽' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha',
    '👨🏼‍🦽' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽‍🦽' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ ndịna etiti',
    '👨🏾‍🦽' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿‍🦽' => 'nwoke nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji',
    '👩🏻‍🦽' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha',
    '👩🏼‍🦽' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽‍🦽' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ ndịna etiti',
    '👩🏾‍🦽' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿‍🦽' => 'nwanyị nọ n’oche nkwagharị nke aka: ọtanjele ahụ maka òji',
    '🏃🏻‍♂' => 'nwoke na-agba ọsọ: ọtanjele ahụ maka ọcha',
    '🏃🏼‍♂' => 'nwoke na-agba ọsọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏃🏽‍♂' => 'nwoke na-agba ọsọ: ọtanjele ahụ ndịna etiti',
    '🏃🏾‍♂' => 'nwoke na-agba ọsọ: ọtanjele ahụ maka òji-ndịna etiti',
    '🏃🏿‍♂' => 'nwoke na-agba ọsọ: ọtanjele ahụ maka òji',
    '🏃🏻‍♀' => 'nwanyị na-agba ọsọ: ọtanjele ahụ maka ọcha',
    '🏃🏼‍♀' => 'nwanyị na-agba ọsọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏃🏽‍♀' => 'nwanyị na-agba ọsọ: ọtanjele ahụ ndịna etiti',
    '🏃🏾‍♀' => 'nwanyị na-agba ọsọ: ọtanjele ahụ maka òji-ndịna etiti',
    '🏃🏿‍♀' => 'nwanyị na-agba ọsọ: ọtanjele ahụ maka òji',
    '🏃🏻‍➡' => 'onye na-agba ọsọ: ọtanjele ahụ maka ọcha, na-eche ihu aka nri',
    '🏃🏼‍➡' => 'onye na-agba ọsọ: ọtanjele ahụ maka ọcha-ndịna etiti, na-eche ihu aka nri',
    '🏃🏽‍➡' => 'onye na-agba ọsọ: ọtanjele ahụ ndịna etiti, na-eche ihu aka nri',
    '🏃🏾‍➡' => 'onye na-agba ọsọ: ọtanjele ahụ maka òji-ndịna etiti, na-eche ihu aka nri',
    '🏃🏿‍➡' => 'onye na-agba ọsọ: ọtanjele ahụ maka òji, na-eche ihu aka nri',
    '👯🏻‍♀' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha',
    '👯🏼‍♀' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👯🏽‍♀' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti',
    '👯🏾‍♀' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti',
    '👯🏿‍♀' => 'ụmụnwanyi nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji',
    '👯🏻‍♂' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha',
    '👯🏼‍♂' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👯🏽‍♂' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ ndịna etiti',
    '👯🏾‍♂' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti',
    '👯🏿‍♂' => 'ụmụnwoke nwere nti ogologo na-agba egwu: ọtanjele ahụ maka òji',
    '🧖🏻‍♂' => 'nwoke nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka ọcha',
    '🧖🏼‍♂' => 'nwoke nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧖🏽‍♂' => 'nwoke nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ ndịna etiti',
    '🧖🏾‍♂' => 'nwoke nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧖🏿‍♂' => 'nwoke nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka òji',
    '🧖🏻‍♀' => 'nwanyị nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka ọcha',
    '🧖🏼‍♀' => 'nwanyị nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧖🏽‍♀' => 'nwanyị nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ ndịna etiti',
    '🧖🏾‍♀' => 'nwanyị nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧖🏿‍♀' => 'nwanyị nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka òji',
    '🧗🏻‍♂' => 'nwoke na-arị elu: ọtanjele ahụ maka ọcha',
    '🧗🏼‍♂' => 'nwoke na-arị elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧗🏽‍♂' => 'nwoke na-arị elu: ọtanjele ahụ ndịna etiti',
    '🧗🏾‍♂' => 'nwoke na-arị elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🧗🏿‍♂' => 'nwoke na-arị elu: ọtanjele ahụ maka òji',
    '🧗🏻‍♀' => 'nwanyị na-arị elu: ọtanjele ahụ maka ọcha',
    '🧗🏼‍♀' => 'nwanyị na-arị elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧗🏽‍♀' => 'nwanyị na-arị elu: ọtanjele ahụ ndịna etiti',
    '🧗🏾‍♀' => 'nwanyị na-arị elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🧗🏿‍♀' => 'nwanyị na-arị elu: ọtanjele ahụ maka òji',
    '🏌🏻‍♂' => 'nwoke na-akụ gọfụ: ọtanjele ahụ maka ọcha',
    '🏌🏼‍♂' => 'nwoke na-akụ gọfụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏌🏽‍♂' => 'nwoke na-akụ gọfụ: ọtanjele ahụ ndịna etiti',
    '🏌🏾‍♂' => 'nwoke na-akụ gọfụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🏌🏿‍♂' => 'nwoke na-akụ gọfụ: ọtanjele ahụ maka òji',
    '🏌🏻‍♀' => 'nwanyị na-akụ gọfụ: ọtanjele ahụ maka ọcha',
    '🏌🏼‍♀' => 'nwanyị na-akụ gọfụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏌🏽‍♀' => 'nwanyị na-akụ gọfụ: ọtanjele ahụ ndịna etiti',
    '🏌🏾‍♀' => 'nwanyị na-akụ gọfụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🏌🏿‍♀' => 'nwanyị na-akụ gọfụ: ọtanjele ahụ maka òji',
    '🏄🏻‍♂' => 'nwoke na-eme egwuregwu oshimiri: ọtanjele ahụ maka ọcha',
    '🏄🏼‍♂' => 'nwoke na-eme egwuregwu oshimiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏄🏽‍♂' => 'nwoke na-eme egwuregwu oshimiri: ọtanjele ahụ ndịna etiti',
    '🏄🏾‍♂' => 'nwoke na-eme egwuregwu oshimiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🏄🏿‍♂' => 'nwoke na-eme egwuregwu oshimiri: ọtanjele ahụ maka òji',
    '🏄🏻‍♀' => 'nwanyị na-eme egwuregwu oshimiri: ọtanjele ahụ maka ọcha',
    '🏄🏼‍♀' => 'nwanyị na-eme egwuregwu oshimiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏄🏽‍♀' => 'nwanyị na-eme egwuregwu oshimiri: ọtanjele ahụ ndịna etiti',
    '🏄🏾‍♀' => 'nwanyị na-eme egwuregwu oshimiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🏄🏿‍♀' => 'nwanyị na-eme egwuregwu oshimiri: ọtanjele ahụ maka òji',
    '🚣🏻‍♂' => 'nwoke na-akwọ ụgbọmmiri: ọtanjele ahụ maka ọcha',
    '🚣🏼‍♂' => 'nwoke na-akwọ ụgbọmmiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚣🏽‍♂' => 'nwoke na-akwọ ụgbọmmiri: ọtanjele ahụ ndịna etiti',
    '🚣🏾‍♂' => 'nwoke na-akwọ ụgbọmmiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🚣🏿‍♂' => 'nwoke na-akwọ ụgbọmmiri: ọtanjele ahụ maka òji',
    '🚣🏻‍♀' => 'nwanyị na-akwọ ụgbọmmiri: ọtanjele ahụ maka ọcha',
    '🚣🏼‍♀' => 'nwanyị na-akwọ ụgbọmmiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚣🏽‍♀' => 'nwanyị na-akwọ ụgbọmmiri: ọtanjele ahụ ndịna etiti',
    '🚣🏾‍♀' => 'nwanyị na-akwọ ụgbọmmiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🚣🏿‍♀' => 'nwanyị na-akwọ ụgbọmmiri: ọtanjele ahụ maka òji',
    '🏊🏻‍♂' => 'nwoke na-egwu mmiri: ọtanjele ahụ maka ọcha',
    '🏊🏼‍♂' => 'nwoke na-egwu mmiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏊🏽‍♂' => 'nwoke na-egwu mmiri: ọtanjele ahụ ndịna etiti',
    '🏊🏾‍♂' => 'nwoke na-egwu mmiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🏊🏿‍♂' => 'nwoke na-egwu mmiri: ọtanjele ahụ maka òji',
    '🏊🏻‍♀' => 'nwanyị na-egwu mmiri: ọtanjele ahụ maka ọcha',
    '🏊🏼‍♀' => 'nwanyị na-egwu mmiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏊🏽‍♀' => 'nwanyị na-egwu mmiri: ọtanjele ahụ ndịna etiti',
    '🏊🏾‍♀' => 'nwanyị na-egwu mmiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🏊🏿‍♀' => 'nwanyị na-egwu mmiri: ọtanjele ahụ maka òji',
    '⛹🏻‍♂' => 'nwoke na-atụ bọolụ: ọtanjele ahụ maka ọcha',
    '⛹🏼‍♂' => 'nwoke na-atụ bọolụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '⛹🏽‍♂' => 'nwoke na-atụ bọolụ: ọtanjele ahụ ndịna etiti',
    '⛹🏾‍♂' => 'nwoke na-atụ bọolụ: ọtanjele ahụ maka òji-ndịna etiti',
    '⛹🏿‍♂' => 'nwoke na-atụ bọolụ: ọtanjele ahụ maka òji',
    '⛹🏻‍♀' => 'nwanyị na-atụ bọolụ: ọtanjele ahụ maka ọcha',
    '⛹🏼‍♀' => 'nwanyị na-atụ bọolụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '⛹🏽‍♀' => 'nwanyị na-atụ bọolụ: ọtanjele ahụ ndịna etiti',
    '⛹🏾‍♀' => 'nwanyị na-atụ bọolụ: ọtanjele ahụ maka òji-ndịna etiti',
    '⛹🏿‍♀' => 'nwanyị na-atụ bọolụ: ọtanjele ahụ maka òji',
    '🏋🏻‍♂' => 'nwoke na-ebuli ihe elu: ọtanjele ahụ maka ọcha',
    '🏋🏼‍♂' => 'nwoke na-ebuli ihe elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏋🏽‍♂' => 'nwoke na-ebuli ihe elu: ọtanjele ahụ ndịna etiti',
    '🏋🏾‍♂' => 'nwoke na-ebuli ihe elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🏋🏿‍♂' => 'nwoke na-ebuli ihe elu: ọtanjele ahụ maka òji',
    '🏋🏻‍♀' => 'nwanyị na-ebuli ihe elu: ọtanjele ahụ maka ọcha',
    '🏋🏼‍♀' => 'nwanyị na-ebuli ihe elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏋🏽‍♀' => 'nwanyị na-ebuli ihe elu: ọtanjele ahụ ndịna etiti',
    '🏋🏾‍♀' => 'nwanyị na-ebuli ihe elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🏋🏿‍♀' => 'nwanyị na-ebuli ihe elu: ọtanjele ahụ maka òji',
    '🚴🏻‍♂' => 'nwoke na-agba igwe: ọtanjele ahụ maka ọcha',
    '🚴🏼‍♂' => 'nwoke na-agba igwe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚴🏽‍♂' => 'nwoke na-agba igwe: ọtanjele ahụ ndịna etiti',
    '🚴🏾‍♂' => 'nwoke na-agba igwe: ọtanjele ahụ maka òji-ndịna etiti',
    '🚴🏿‍♂' => 'nwoke na-agba igwe: ọtanjele ahụ maka òji',
    '🚴🏻‍♀' => 'nwanyị na-agba igwe: ọtanjele ahụ maka ọcha',
    '🚴🏼‍♀' => 'nwanyị na-agba igwe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚴🏽‍♀' => 'nwanyị na-agba igwe: ọtanjele ahụ ndịna etiti',
    '🚴🏾‍♀' => 'nwanyị na-agba igwe: ọtanjele ahụ maka òji-ndịna etiti',
    '🚴🏿‍♀' => 'nwanyị na-agba igwe: ọtanjele ahụ maka òji',
    '🚵🏻‍♂' => 'nwoke egwuregwu ịrị ugwu: ọtanjele ahụ maka ọcha',
    '🚵🏼‍♂' => 'nwoke egwuregwu ịrị ugwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚵🏽‍♂' => 'nwoke egwuregwu ịrị ugwu: ọtanjele ahụ ndịna etiti',
    '🚵🏾‍♂' => 'nwoke egwuregwu ịrị ugwu: ọtanjele ahụ maka òji-ndịna etiti',
    '🚵🏿‍♂' => 'nwoke egwuregwu ịrị ugwu: ọtanjele ahụ maka òji',
    '🚵🏻‍♀' => 'nwanyi egwuregwu ịrị ugwu: ọtanjele ahụ maka ọcha',
    '🚵🏼‍♀' => 'nwanyi egwuregwu ịrị ugwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚵🏽‍♀' => 'nwanyi egwuregwu ịrị ugwu: ọtanjele ahụ ndịna etiti',
    '🚵🏾‍♀' => 'nwanyi egwuregwu ịrị ugwu: ọtanjele ahụ maka òji-ndịna etiti',
    '🚵🏿‍♀' => 'nwanyi egwuregwu ịrị ugwu: ọtanjele ahụ maka òji',
    '🤸🏻‍♂' => 'nwoke na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ maka ọcha',
    '🤸🏼‍♂' => 'nwoke na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤸🏽‍♂' => 'nwoke na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ ndịna etiti',
    '🤸🏾‍♂' => 'nwoke na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ maka òji-ndịna etiti',
    '🤸🏿‍♂' => 'nwoke na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ maka òji',
    '🤸🏻‍♀' => 'nwanyị na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ maka ọcha',
    '🤸🏼‍♀' => 'nwanyị na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤸🏽‍♀' => 'nwanyị na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ ndịna etiti',
    '🤸🏾‍♀' => 'nwanyị na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ maka òji-ndịna etiti',
    '🤸🏿‍♀' => 'nwanyị na-eme egwuregwu ntụgharị onwe: ọtanjele ahụ maka òji',
    '🤼🏻‍♀' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha',
    '🤼🏼‍♀' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤼🏽‍♀' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ ndịna etiti',
    '🤼🏾‍♀' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti',
    '🤼🏿‍♀' => 'ụmụnwanyị na-agba m̀gba: ọtanjele ahụ maka òji',
    '🤼🏻‍♂' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha',
    '🤼🏼‍♂' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤼🏽‍♂' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti',
    '🤼🏾‍♂' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti',
    '🤼🏿‍♂' => 'ụmụnwoke ndị na-agba m̀gba: ọtanjele ahụ maka òji',
    '🤽🏻‍♂' => 'nwoke na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka ọcha',
    '🤽🏼‍♂' => 'nwoke na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤽🏽‍♂' => 'nwoke na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ ndịna etiti',
    '🤽🏾‍♂' => 'nwoke na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🤽🏿‍♂' => 'nwoke na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka òji',
    '🤽🏻‍♀' => 'nwanyi na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka ọcha',
    '🤽🏼‍♀' => 'nwanyi na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤽🏽‍♀' => 'nwanyi na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ ndịna etiti',
    '🤽🏾‍♀' => 'nwanyi na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🤽🏿‍♀' => 'nwanyi na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka òji',
    '🤾🏻‍♂' => 'nwoke na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka ọcha',
    '🤾🏼‍♂' => 'nwoke na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤾🏽‍♂' => 'nwoke na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ ndịna etiti',
    '🤾🏾‍♂' => 'nwoke na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤾🏿‍♂' => 'nwoke na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka òji',
    '🤾🏻‍♀' => 'nwanyị na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka ọcha',
    '🤾🏼‍♀' => 'nwanyị na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤾🏽‍♀' => 'nwanyị na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ ndịna etiti',
    '🤾🏾‍♀' => 'nwanyị na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤾🏿‍♀' => 'nwanyị na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka òji',
    '🤹🏻‍♂' => 'nwoke na-eme egwuregwu aka: ọtanjele ahụ maka ọcha',
    '🤹🏼‍♂' => 'nwoke na-eme egwuregwu aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤹🏽‍♂' => 'nwoke na-eme egwuregwu aka: ọtanjele ahụ ndịna etiti',
    '🤹🏾‍♂' => 'nwoke na-eme egwuregwu aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤹🏿‍♂' => 'nwoke na-eme egwuregwu aka: ọtanjele ahụ maka òji',
    '🤹🏻‍♀' => 'nwanyị na-eme egwuregwu aka: ọtanjele ahụ maka ọcha',
    '🤹🏼‍♀' => 'nwanyị na-eme egwuregwu aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤹🏽‍♀' => 'nwanyị na-eme egwuregwu aka: ọtanjele ahụ ndịna etiti',
    '🤹🏾‍♀' => 'nwanyị na-eme egwuregwu aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤹🏿‍♀' => 'nwanyị na-eme egwuregwu aka: ọtanjele ahụ maka òji',
    '🧘🏻‍♂' => 'nwoke chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka ọcha',
    '🧘🏼‍♂' => 'nwoke chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧘🏽‍♂' => 'nwoke chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ ndịna etiti',
    '🧘🏾‍♂' => 'nwoke chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧘🏿‍♂' => 'nwoke chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka òji',
    '🧘🏻‍♀' => 'nwanyị chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka ọcha',
    '🧘🏼‍♀' => 'nwanyị chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧘🏽‍♀' => 'nwanyị chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ ndịna etiti',
    '🧘🏾‍♀' => 'nwanyị chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧘🏿‍♀' => 'nwanyị chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka òji',
    '🧑‍🦰' => 'okenye: ntutu isi uhie',
    '🧑‍🦱' => 'okenye: ntutu isi gbakọrọ agbakọ',
    '🧑‍🦳' => 'okenye: ntutu isi ocha',
    '🧑‍🦲' => 'okenye: isi nkwọcha',
    '👨‍🦰' => 'nwoke: ntutu isi uhie',
    '👨‍🦱' => 'nwoke: ntutu isi gbakọrọ agbakọ',
    '👨‍🦳' => 'nwoke: ntutu isi ocha',
    '👨‍🦲' => 'nwoke: isi nkwọcha',
    '👩‍🦰' => 'nwanyị: ntutu isi uhie',
    '👩‍🦱' => 'nwanyị: ntutu isi gbakọrọ agbakọ',
    '👩‍🦳' => 'nwanyị: ntutu isi ocha',
    '👩‍🦲' => 'nwanyị: isi nkwọcha',
    '🚶‍➡' => 'onye na-aga ije: na-eche ihu aka nri',
    '🧎‍➡' => 'onye gbu ikpere n’ala: na-eche ihu aka nri',
    '🏃‍➡' => 'onye na-agba ọsọ: na-eche ihu aka nri',
    '👨‍👦' => 'ezinaụlọ: nwoke, nwa nwoke',
    '👨‍👧' => 'ezinaụlọ: nwoke, nwata nwaanyị',
    '👩‍👦' => 'ezinaụlọ: nwanyị, nwa nwoke',
    '👩‍👧' => 'ezinaụlọ: nwanyị, nwata nwaanyị',
    '😶‍🌫' => 'ihu nọ n’ígwé',
    '😮‍💨' => 'ihu na-ekuda ume',
    '🙂‍↕' => 'ekwe n’isi site n’elu ga n’ala',
    '😵‍💫' => 'ihu nwere anya na-agba gburugburu',
    '❤‍🔥' => 'mkpụrụobi n’ere ọkụ',
    '❤‍🩹' => 'mkpụrụobi nwere mmedo',
    '👁‍🗨' => 'anya na blonblo okwu',
    '🧔‍♂' => 'nwoke: afụ ọnụ',
    '👱‍♂' => 'nwoke nwere isi-awọ',
    '🧔‍♀' => 'nwanyị: afụ ọnụ',
    '👱‍♀' => 'nwanyị nwere isi-awọ',
    '🙍‍♂' => 'nwoke na-agbarụ ihu',
    '🙍‍♀' => 'nwanyị na-agbarụ ihu',
    '🙎‍♂' => 'nwoke na-asọpụta ọnụ',
    '🙎‍♀' => 'nwanyị na-asọpụta ọnụ',
    '🙅‍♂' => 'nwoke na-egosipta MBÀ',
    '🙅‍♀' => 'nwanyị na-egosipta MBÀ',
    '🙆‍♂' => 'nwoke na-egosipta Ọ DỊ MMA',
    '🙆‍♀' => 'nwanyị na-egosipta Ọ DỊ MMA',
    '💁‍♂' => 'nwoke na-ehulata aka',
    '💁‍♀' => 'nwanyị na-ehulata aka',
    '🙋‍♂' => 'nwoke na-ewelite aka',
    '🙋‍♀' => 'nwanyị na-ewelite aka',
    '🧏‍♂' => 'nwoke ntị chiri',
    '🧏‍♀' => 'nwanyị ntị chiri',
    '🙇‍♂' => 'nwoke na-ehulata ala',
    '🙇‍♀' => 'nwanyị na-ehulata ala',
    '🤦‍♂' => 'nwoke na-ezo ihu ya èzo',
    '🤦‍♀' => 'nwanyị na-ezo ihu ya èzo',
    '🤷‍♂' => 'nwoke na-egosi nhatanha aka',
    '🤷‍♀' => 'nwanyị na-egosi nhatanha aka',
    '🧑‍⚕' => 'onye ọrụ ahụike',
    '👨‍⚕' => 'nwoke ọrụ ahụike',
    '👩‍⚕' => 'nwanyị onye ọrụ ahụike',
    '🧑‍🎓' => 'nwata akwụkwọ',
    '👨‍🎓' => 'nwoke nwata akwụkwọ',
    '👩‍🎓' => 'nwanyị nwaakwụkwọ',
    '🧑‍🏫' => 'onyenkuzi',
    '👨‍🏫' => 'nwoke onyenkuzi',
    '👩‍🏫' => 'nwanyị ọkammụta',
    '🧑‍⚖' => 'onye ikpe',
    '👨‍⚖' => 'nwoke ikpe',
    '👩‍⚖' => 'nwanyị ikpe nkwụọtọ',
    '🧑‍🌾' => 'onye ọrụ ugbo',
    '👨‍🌾' => 'nwoke ọrụ ugbo',
    '👩‍🌾' => 'nwanyị ọrụ ugbo',
    '🧑‍🍳' => 'onye na-esi nri',
    '👨‍🍳' => 'nwoke na-esi nri',
    '👩‍🍳' => 'nwanyị na-esi',
    '🧑‍🔧' => 'onye na-arụzi ụgbọala',
    '👨‍🔧' => 'nwoke onye na-arụzi ụgbọala',
    '👩‍🔧' => 'nwanyị na-arụzi ụgbọala',
    '🧑‍🏭' => 'onyeọrụ ụlọ ọrụ',
    '👨‍🏭' => 'nwoke onyeọrụ ụlọ ọrụ',
    '👩‍🏭' => 'nwanyị onyeọrụ ụlọ ọrụ',
    '🧑‍💼' => 'onye ọrụ ọfịịsị',
    '👨‍💼' => 'nwoke onye ọrụ ọfịịsị',
    '👩‍💼' => 'nwanyị onye ọrụ ọfịịsị',
    '🧑‍🔬' => 'ọkammụta sayensi',
    '👨‍🔬' => 'nwoke ọkammụta sayensi',
    '👩‍🔬' => 'nwanyị ọkammụta sayensi',
    '🧑‍💻' => 'onye teknụụzụ',
    '👨‍💻' => 'nwoke onye teknụụzụ',
    '👩‍💻' => 'nwanyi onye teknụụzụ',
    '🧑‍🎤' => 'ọgụụ egwu',
    '👨‍🎤' => 'nwoke ọgụụ egwu',
    '👩‍🎤' => 'nwanyi ọgụụ egwu',
    '🧑‍🎨' => 'omeǹkà',
    '👨‍🎨' => 'omeǹkà nwoke',
    '👩‍🎨' => 'omeǹkà nwanyị',
    '🧑‍✈' => 'ọkwọ ugbọelu',
    '👨‍✈' => 'nwoke ọkwọ ugbọelu',
    '👩‍✈' => 'nwanyị ọkwọ ugbọelu',
    '🧑‍🚀' => 'òjenọnwa',
    '👨‍🚀' => 'nwoke òjenọnwa',
    '👩‍🚀' => 'nwanyị òjenọnwa',
    '🧑‍🚒' => 'onyemgbanyụọkụ',
    '👨‍🚒' => 'nwoke onyemgbanyụọkụ',
    '👩‍🚒' => 'nwanyị onyemgbanyụọkụ',
    '👮‍♂' => 'jide',
    '👮‍♀' => 'nwanyị onye uweojii',
    '🕵‍♂' => 'nwoke nchọpụta',
    '🕵‍♀' => 'nwanyị nchọpụta',
    '💂‍♂' => 'nwoke nche',
    '💂‍♀' => 'nwanyị nche',
    '👷‍♂' => 'onye ọrụ nwoke',
    '👷‍♀' => 'onye ọrụ nwanyị',
    '👳‍♂' => 'nwoke yi turban',
    '👳‍♀' => 'nwanyị yi turban',
    '🤵‍♂' => 'nwoke yi uwe tuxedo',
    '🤵‍♀' => 'nwanyị yi uwe tuxedo',
    '👰‍♂' => 'nwoke yi akwà nkochi ihu',
    '👰‍♀' => 'nwanyị nkochi ihu',
    '👩‍🍼' => 'nwanyị n’enye nwa nri',
    '👨‍🍼' => 'nwoke n’enye nwa nri',
    '🧑‍🍼' => 'onye n’enye nwa nri',
    '🧑‍🎄' => 'mx claus',
    '🦸‍♂' => 'dike nwoke',
    '🦸‍♀' => 'dike nwanyị',
    '🦹‍♂' => 'nwoke onye ọjọọ',
    '🦹‍♀' => 'nwanyị onye ọjọọ',
    '🧙‍♂' => 'nwoke abrakatabra',
    '🧙‍♀' => 'nwanyị onye abrakatabra',
    '🧚‍♂' => 'akụkọ nwoke',
    '🧚‍♀' => 'akụkọ nwanyị',
    '🧛‍♂' => 'nwoke ọmị ọbara',
    '🧛‍♀' => 'nwanyị ọmị obara',
    '🧜‍♂' => 'nwokewọta',
    '🧜‍♀' => 'mamịwọta',
    '🧝‍♂' => 'nwoke elfụ',
    '🧝‍♀' => 'nwanyị elfụ',
    '🧞‍♂' => 'nwoke mmegbu',
    '🧞‍♀' => 'nwanyị mmegbu',
    '🧟‍♂' => 'nwoke nwụrụ anwụ na-aga ije',
    '🧟‍♀' => 'nwanyị nwụrụ anwụ na-aga ije',
    '💆‍♂' => 'nwoke na-anata ozi',
    '💆‍♀' => 'nwanyị na-anata ozi',
    '💇‍♂' => 'nwoke na-enweta ọkpụkpụisi',
    '💇‍♀' => 'nwanyị na-enweta ọkpụkpụisi',
    '🚶‍♂' => 'nwoke na-aga ije',
    '🚶‍♀' => 'nwanyị na-aga ije',
    '🧍‍♂' => 'nwoke na-eguzo',
    '🧍‍♀' => 'nwanyị na-eguzo',
    '🧎‍♂' => 'nwoke gbu ikpere n’ala',
    '🧎‍♀' => 'nwanyị gbu ikpere n’ala',
    '🧑‍🦯' => 'onye ji mkpara ọcha',
    '👨‍🦯' => 'nwoke ji mkpara ọcha',
    '👩‍🦯' => 'nwanyị ji mkpara ọcha',
    '🧑‍🦼' => 'onye nọ n’oche nkwagharị nwere moto',
    '👨‍🦼' => 'nwoke nọ n’oche nkwagharị nwere moto',
    '👩‍🦼' => 'nwanyị nọ n’oche nkwagharị nwere moto',
    '🧑‍🦽' => 'onye nọ n’oche nkwagharị nke aka',
    '👨‍🦽' => 'nwoke nọ n’oche nkwagharị nke aka',
    '👩‍🦽' => 'nwanyị nọ n’oche nkwagharị nke aka',
    '🏃‍♂' => 'nwoke na-agba ọsọ',
    '🏃‍♀' => 'nwanyị na-agba ọsọ',
    '🧑‍🩰' => 'onye na-agba egwú ballet',
    '👯‍♂' => 'ụmụnwoke nwere nti ogologo na-agba egwu',
    '👯‍♀' => 'ụmụnwanyi nwere nti ogologo na-agba egwu',
    '🧖‍♂' => 'nwoke nọ n’ụlọ okpomọọkụ mmiri ahụ',
    '🧖‍♀' => 'nwanyị nọ n’ụlọ okpomọọkụ mmiri ahụ',
    '🧗‍♂' => 'nwoke na-arị elu',
    '🧗‍♀' => 'nwanyị na-arị elu',
    '🏌‍♂' => 'nwoke na-akụ gọfụ',
    '🏌‍♀' => 'nwanyị na-akụ gọfụ',
    '🏄‍♂' => 'nwoke na-eme egwuregwu oshimiri',
    '🏄‍♀' => 'nwanyị na-eme egwuregwu oshimiri',
    '🚣‍♂' => 'nwoke na-akwọ ụgbọmmiri',
    '🚣‍♀' => 'nwanyị na-akwọ ụgbọmmiri',
    '🏊‍♂' => 'nwoke na-egwu mmiri',
    '🏊‍♀' => 'nwanyị na-egwu mmiri',
    '⛹‍♂' => 'nwoke na-atụ bọolụ',
    '⛹‍♀' => 'nwanyị na-atụ bọolụ',
    '🏋‍♂' => 'nwoke na-ebuli ihe elu',
    '🏋‍♀' => 'nwanyị na-ebuli ihe elu',
    '🚴‍♂' => 'nwoke na-agba igwe',
    '🚴‍♀' => 'nwanyị na-agba igwe',
    '🚵‍♂' => 'nwoke egwuregwu ịrị ugwu',
    '🚵‍♀' => 'nwanyi egwuregwu ịrị ugwu',
    '🤸‍♂' => 'nwoke na-eme egwuregwu ntụgharị onwe',
    '🤸‍♀' => 'nwanyị na-eme egwuregwu ntụgharị onwe',
    '🤼‍♂' => 'ụmụnwoke ndị na-agba m̀gba',
    '🤼‍♀' => 'ụmụnwanyị na-agba m̀gba',
    '🤽‍♂' => 'nwoke na-egwu egwuregwu bọọlụ mmiri',
    '🤽‍♀' => 'nwanyi na-egwu egwuregwu bọọlụ mmiri',
    '🤾‍♂' => 'nwoke na-egwu egwuregwu bọọlụ aka',
    '🤾‍♀' => 'nwanyị na-egwu egwuregwu bọọlụ aka',
    '🤹‍♂' => 'nwoke na-eme egwuregwu aka',
    '🤹‍♀' => 'nwanyị na-eme egwuregwu aka',
    '🧘‍♂' => 'nwoke chịkọrọ ụkwụ ya abụọ ọnụ',
    '🧘‍♀' => 'nwanyị chịkọrọ ụkwụ ya abụọ ọnụ',
    '🧑‍🧒' => 'ezinaụlọ: okenye, nwata',
    '🐕‍🦺' => 'nkịta ọrụ',
    '🐈‍⬛' => 'nwamba ojii',
    '🐻‍❄' => 'bịar oyi',
    '🐦‍⬛' => 'nnụnụ ojii',
    '🐦‍🔥' => 'nnụnụ n’ere ọkụ',
    '🍋‍🟩' => 'oroma nkịrịsị',
    '🍄‍🟫' => 'ero aja aja',
    '⛓‍💥' => 'agbụ ígwè gbajiri agbaji',
    '🏳‍🌈' => 'ọkọlọtọ egwurugwu',
    '🏳‍⚧' => 'ọkọlọtọ ndị na-agbanwe okike ha',
    '🏴‍☠' => 'ọkọlọtọ ndị ohi oké osimiri',
    '👋🏻' => 'na-efe aka: ọtanjele ahụ maka ọcha',
    '👋🏼' => 'na-efe aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👋🏽' => 'na-efe aka: ọtanjele ahụ ndịna etiti',
    '👋🏾' => 'na-efe aka: ọtanjele ahụ maka òji-ndịna etiti',
    '👋🏿' => 'na-efe aka: ọtanjele ahụ maka òji',
    '🤚🏻' => 'azụ aka nke ewelitere elu: ọtanjele ahụ maka ọcha',
    '🤚🏼' => 'azụ aka nke ewelitere elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤚🏽' => 'azụ aka nke ewelitere elu: ọtanjele ahụ ndịna etiti',
    '🤚🏾' => 'azụ aka nke ewelitere elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🤚🏿' => 'azụ aka nke ewelitere elu: ọtanjele ahụ maka òji',
    '🖐🏻' => 'welitere aka elu n’iji mgbasa mkpịsịaka: ọtanjele ahụ maka ọcha',
    '🖐🏼' => 'welitere aka elu n’iji mgbasa mkpịsịaka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🖐🏽' => 'welitere aka elu n’iji mgbasa mkpịsịaka: ọtanjele ahụ ndịna etiti',
    '🖐🏾' => 'welitere aka elu n’iji mgbasa mkpịsịaka: ọtanjele ahụ maka òji-ndịna etiti',
    '🖐🏿' => 'welitere aka elu n’iji mgbasa mkpịsịaka: ọtanjele ahụ maka òji',
    '✋🏻' => 'aka ewèliri: ọtanjele ahụ maka ọcha',
    '✋🏼' => 'aka ewèliri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '✋🏽' => 'aka ewèliri: ọtanjele ahụ ndịna etiti',
    '✋🏾' => 'aka ewèliri: ọtanjele ahụ maka òji-ndịna etiti',
    '✋🏿' => 'aka ewèliri: ọtanjele ahụ maka òji',
    '🖖🏻' => 'ajọọ èkèle: ọtanjele ahụ maka ọcha',
    '🖖🏼' => 'ajọọ èkèle: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🖖🏽' => 'ajọọ èkèle: ọtanjele ahụ ndịna etiti',
    '🖖🏾' => 'ajọọ èkèle: ọtanjele ahụ maka òji-ndịna etiti',
    '🖖🏿' => 'ajọọ èkèle: ọtanjele ahụ maka òji',
    '🫱🏻' => 'aka nri: ọtanjele ahụ maka ọcha',
    '🫱🏼' => 'aka nri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫱🏽' => 'aka nri: ọtanjele ahụ ndịna etiti',
    '🫱🏾' => 'aka nri: ọtanjele ahụ maka òji-ndịna etiti',
    '🫱🏿' => 'aka nri: ọtanjele ahụ maka òji',
    '🫲🏻' => 'uzo aka ekpe: ọtanjele ahụ maka ọcha',
    '🫲🏼' => 'uzo aka ekpe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫲🏽' => 'uzo aka ekpe: ọtanjele ahụ ndịna etiti',
    '🫲🏾' => 'uzo aka ekpe: ọtanjele ahụ maka òji-ndịna etiti',
    '🫲🏿' => 'uzo aka ekpe: ọtanjele ahụ maka òji',
    '🫳🏻' => 'aka l’ara ala: ọtanjele ahụ maka ọcha',
    '🫳🏼' => 'aka l’ara ala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫳🏽' => 'aka l’ara ala: ọtanjele ahụ ndịna etiti',
    '🫳🏾' => 'aka l’ara ala: ọtanjele ahụ maka òji-ndịna etiti',
    '🫳🏿' => 'aka l’ara ala: ọtanjele ahụ maka òji',
    '🫴🏻' => 'aka l’ara elu: ọtanjele ahụ maka ọcha',
    '🫴🏼' => 'aka l’ara elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫴🏽' => 'aka l’ara elu: ọtanjele ahụ ndịna etiti',
    '🫴🏾' => 'aka l’ara elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🫴🏿' => 'aka l’ara elu: ọtanjele ahụ maka òji',
    '🫷🏻' => 'aka na-aga n’aka ekpe: ọtanjele ahụ maka ọcha',
    '🫷🏼' => 'aka na-aga n’aka ekpe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫷🏽' => 'aka na-aga n’aka ekpe: ọtanjele ahụ ndịna etiti',
    '🫷🏾' => 'aka na-aga n’aka ekpe: ọtanjele ahụ maka òji-ndịna etiti',
    '🫷🏿' => 'aka na-aga n’aka ekpe: ọtanjele ahụ maka òji',
    '🫸🏻' => 'uzo aka nri na-kwaa aka: ọtanjele ahụ maka ọcha',
    '🫸🏼' => 'uzo aka nri na-kwaa aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫸🏽' => 'uzo aka nri na-kwaa aka: ọtanjele ahụ ndịna etiti',
    '🫸🏾' => 'uzo aka nri na-kwaa aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🫸🏿' => 'uzo aka nri na-kwaa aka: ọtanjele ahụ maka òji',
    '👌🏻' => 'AKA dị mma: ọtanjele ahụ maka ọcha',
    '👌🏼' => 'AKA dị mma: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👌🏽' => 'AKA dị mma: ọtanjele ahụ ndịna etiti',
    '👌🏾' => 'AKA dị mma: ọtanjele ahụ maka òji-ndịna etiti',
    '👌🏿' => 'AKA dị mma: ọtanjele ahụ maka òji',
    '🤌🏻' => 'itu mkpịsị aka: ọtanjele ahụ maka ọcha',
    '🤌🏼' => 'itu mkpịsị aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤌🏽' => 'itu mkpịsị aka: ọtanjele ahụ ndịna etiti',
    '🤌🏾' => 'itu mkpịsị aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤌🏿' => 'itu mkpịsị aka: ọtanjele ahụ maka òji',
    '🤏🏻' => 'tuo aka: ọtanjele ahụ maka ọcha',
    '🤏🏼' => 'tuo aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤏🏽' => 'tuo aka: ọtanjele ahụ ndịna etiti',
    '🤏🏾' => 'tuo aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤏🏿' => 'tuo aka: ọtanjele ahụ maka òji',
    '✌🏻' => 'aka mmeri: ọtanjele ahụ maka ọcha',
    '✌🏼' => 'aka mmeri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '✌🏽' => 'aka mmeri: ọtanjele ahụ ndịna etiti',
    '✌🏾' => 'aka mmeri: ọtanjele ahụ maka òji-ndịna etiti',
    '✌🏿' => 'aka mmeri: ọtanjele ahụ maka òji',
    '🤞🏻' => 'mkpịakọ mkpịsịaka gasị: ọtanjele ahụ maka ọcha',
    '🤞🏼' => 'mkpịakọ mkpịsịaka gasị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤞🏽' => 'mkpịakọ mkpịsịaka gasị: ọtanjele ahụ ndịna etiti',
    '🤞🏾' => 'mkpịakọ mkpịsịaka gasị: ọtanjele ahụ maka òji-ndịna etiti',
    '🤞🏿' => 'mkpịakọ mkpịsịaka gasị: ọtanjele ahụ maka òji',
    '🫰🏻' => 'aka: ọtanjele ahụ maka ọcha',
    '🫰🏼' => 'aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫰🏽' => 'aka: ọtanjele ahụ ndịna etiti',
    '🫰🏾' => 'aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🫰🏿' => 'aka: ọtanjele ahụ maka òji',
    '🤟🏻' => 'ogbugbu-ịhụnanya: ọtanjele ahụ maka ọcha',
    '🤟🏼' => 'ogbugbu-ịhụnanya: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤟🏽' => 'ogbugbu-ịhụnanya: ọtanjele ahụ ndịna etiti',
    '🤟🏾' => 'ogbugbu-ịhụnanya: ọtanjele ahụ maka òji-ndịna etiti',
    '🤟🏿' => 'ogbugbu-ịhụnanya: ọtanjele ahụ maka òji',
    '🤘🏻' => 'akara nke mpi gasị: ọtanjele ahụ maka ọcha',
    '🤘🏼' => 'akara nke mpi gasị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤘🏽' => 'akara nke mpi gasị: ọtanjele ahụ ndịna etiti',
    '🤘🏾' => 'akara nke mpi gasị: ọtanjele ahụ maka òji-ndịna etiti',
    '🤘🏿' => 'akara nke mpi gasị: ọtanjele ahụ maka òji',
    '🤙🏻' => 'kpọọ mụ aka: ọtanjele ahụ maka ọcha',
    '🤙🏼' => 'kpọọ mụ aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤙🏽' => 'kpọọ mụ aka: ọtanjele ahụ ndịna etiti',
    '🤙🏾' => 'kpọọ mụ aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤙🏿' => 'kpọọ mụ aka: ọtanjele ahụ maka òji',
    '👈🏻' => 'àzụaka na-arụ aka akaèkpè: ọtanjele ahụ maka ọcha',
    '👈🏼' => 'àzụaka na-arụ aka akaèkpè: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👈🏽' => 'àzụaka na-arụ aka akaèkpè: ọtanjele ahụ ndịna etiti',
    '👈🏾' => 'àzụaka na-arụ aka akaèkpè: ọtanjele ahụ maka òji-ndịna etiti',
    '👈🏿' => 'àzụaka na-arụ aka akaèkpè: ọtanjele ahụ maka òji',
    '👉🏻' => 'àzụaka na-arụ aka akanri: ọtanjele ahụ maka ọcha',
    '👉🏼' => 'àzụaka na-arụ aka akanri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👉🏽' => 'àzụaka na-arụ aka akanri: ọtanjele ahụ ndịna etiti',
    '👉🏾' => 'àzụaka na-arụ aka akanri: ọtanjele ahụ maka òji-ndịna etiti',
    '👉🏿' => 'àzụaka na-arụ aka akanri: ọtanjele ahụ maka òji',
    '👆🏻' => 'àzụaka na-arụ aka n’elu: ọtanjele ahụ maka ọcha',
    '👆🏼' => 'àzụaka na-arụ aka n’elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👆🏽' => 'àzụaka na-arụ aka n’elu: ọtanjele ahụ ndịna etiti',
    '👆🏾' => 'àzụaka na-arụ aka n’elu: ọtanjele ahụ maka òji-ndịna etiti',
    '👆🏿' => 'àzụaka na-arụ aka n’elu: ọtanjele ahụ maka òji',
    '🖕🏻' => 'mkpịsịaka etiti: ọtanjele ahụ maka ọcha',
    '🖕🏼' => 'mkpịsịaka etiti: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🖕🏽' => 'mkpịsịaka etiti: ọtanjele ahụ ndịna etiti',
    '🖕🏾' => 'mkpịsịaka etiti: ọtanjele ahụ maka òji-ndịna etiti',
    '🖕🏿' => 'mkpịsịaka etiti: ọtanjele ahụ maka òji',
    '👇🏻' => 'àzụaka na-arụ aka n’ala: ọtanjele ahụ maka ọcha',
    '👇🏼' => 'àzụaka na-arụ aka n’ala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👇🏽' => 'àzụaka na-arụ aka n’ala: ọtanjele ahụ ndịna etiti',
    '👇🏾' => 'àzụaka na-arụ aka n’ala: ọtanjele ahụ maka òji-ndịna etiti',
    '👇🏿' => 'àzụaka na-arụ aka n’ala: ọtanjele ahụ maka òji',
    '☝🏻' => 'na-arụ aka n’elu: ọtanjele ahụ maka ọcha',
    '☝🏼' => 'na-arụ aka n’elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '☝🏽' => 'na-arụ aka n’elu: ọtanjele ahụ ndịna etiti',
    '☝🏾' => 'na-arụ aka n’elu: ọtanjele ahụ maka òji-ndịna etiti',
    '☝🏿' => 'na-arụ aka n’elu: ọtanjele ahụ maka òji',
    '🫵🏻' => 'mkpịsị aka na-atu na mmadu: ọtanjele ahụ maka ọcha',
    '🫵🏼' => 'mkpịsị aka na-atu na mmadu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫵🏽' => 'mkpịsị aka na-atu na mmadu: ọtanjele ahụ ndịna etiti',
    '🫵🏾' => 'mkpịsị aka na-atu na mmadu: ọtanjele ahụ maka òji-ndịna etiti',
    '🫵🏿' => 'mkpịsị aka na-atu na mmadu: ọtanjele ahụ maka òji',
    '👍🏻' => 'oboaka n’elu: ọtanjele ahụ maka ọcha',
    '👍🏼' => 'oboaka n’elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👍🏽' => 'oboaka n’elu: ọtanjele ahụ ndịna etiti',
    '👍🏾' => 'oboaka n’elu: ọtanjele ahụ maka òji-ndịna etiti',
    '👍🏿' => 'oboaka n’elu: ọtanjele ahụ maka òji',
    '👎🏻' => 'oboaka n’ala: ọtanjele ahụ maka ọcha',
    '👎🏼' => 'oboaka n’ala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👎🏽' => 'oboaka n’ala: ọtanjele ahụ ndịna etiti',
    '👎🏾' => 'oboaka n’ala: ọtanjele ahụ maka òji-ndịna etiti',
    '👎🏿' => 'oboaka n’ala: ọtanjele ahụ maka òji',
    '✊🏻' => 'aka ọkpọ ewelitere: ọtanjele ahụ maka ọcha',
    '✊🏼' => 'aka ọkpọ ewelitere: ọtanjele ahụ maka ọcha-ndịna etiti',
    '✊🏽' => 'aka ọkpọ ewelitere: ọtanjele ahụ ndịna etiti',
    '✊🏾' => 'aka ọkpọ ewelitere: ọtanjele ahụ maka òji-ndịna etiti',
    '✊🏿' => 'aka ọkpọ ewelitere: ọtanjele ahụ maka òji',
    '👊🏻' => 'aka ọkpọ na-abịa abịa: ọtanjele ahụ maka ọcha',
    '👊🏼' => 'aka ọkpọ na-abịa abịa: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👊🏽' => 'aka ọkpọ na-abịa abịa: ọtanjele ahụ ndịna etiti',
    '👊🏾' => 'aka ọkpọ na-abịa abịa: ọtanjele ahụ maka òji-ndịna etiti',
    '👊🏿' => 'aka ọkpọ na-abịa abịa: ọtanjele ahụ maka òji',
    '🤛🏻' => 'aka ọkpọ chewere-akaèkpè: ọtanjele ahụ maka ọcha',
    '🤛🏼' => 'aka ọkpọ chewere-akaèkpè: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤛🏽' => 'aka ọkpọ chewere-akaèkpè: ọtanjele ahụ ndịna etiti',
    '🤛🏾' => 'aka ọkpọ chewere-akaèkpè: ọtanjele ahụ maka òji-ndịna etiti',
    '🤛🏿' => 'aka ọkpọ chewere-akaèkpè: ọtanjele ahụ maka òji',
    '🤜🏻' => 'aka ọkpọ chewere-akanri: ọtanjele ahụ maka ọcha',
    '🤜🏼' => 'aka ọkpọ chewere-akanri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤜🏽' => 'aka ọkpọ chewere-akanri: ọtanjele ahụ ndịna etiti',
    '🤜🏾' => 'aka ọkpọ chewere-akanri: ọtanjele ahụ maka òji-ndịna etiti',
    '🤜🏿' => 'aka ọkpọ chewere-akanri: ọtanjele ahụ maka òji',
    '👏🏻' => 'na-akụ aka: ọtanjele ahụ maka ọcha',
    '👏🏼' => 'na-akụ aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👏🏽' => 'na-akụ aka: ọtanjele ahụ ndịna etiti',
    '👏🏾' => 'na-akụ aka: ọtanjele ahụ maka òji-ndịna etiti',
    '👏🏿' => 'na-akụ aka: ọtanjele ahụ maka òji',
    '🙌🏻' => 'aka ndị eweliri elu: ọtanjele ahụ maka ọcha',
    '🙌🏼' => 'aka ndị eweliri elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙌🏽' => 'aka ndị eweliri elu: ọtanjele ahụ ndịna etiti',
    '🙌🏾' => 'aka ndị eweliri elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🙌🏿' => 'aka ndị eweliri elu: ọtanjele ahụ maka òji',
    '🫶🏻' => 'obi aka: ọtanjele ahụ maka ọcha',
    '🫶🏼' => 'obi aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫶🏽' => 'obi aka: ọtanjele ahụ ndịna etiti',
    '🫶🏾' => 'obi aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🫶🏿' => 'obi aka: ọtanjele ahụ maka òji',
    '👐🏻' => 'aka mepere emepe: ọtanjele ahụ maka ọcha',
    '👐🏼' => 'aka mepere emepe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👐🏽' => 'aka mepere emepe: ọtanjele ahụ ndịna etiti',
    '👐🏾' => 'aka mepere emepe: ọtanjele ahụ maka òji-ndịna etiti',
    '👐🏿' => 'aka mepere emepe: ọtanjele ahụ maka òji',
    '🤲🏻' => 'nchịkọta aka abụọ ọnụ: ọtanjele ahụ maka ọcha',
    '🤲🏼' => 'nchịkọta aka abụọ ọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤲🏽' => 'nchịkọta aka abụọ ọnụ: ọtanjele ahụ ndịna etiti',
    '🤲🏾' => 'nchịkọta aka abụọ ọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🤲🏿' => 'nchịkọta aka abụọ ọnụ: ọtanjele ahụ maka òji',
    '🤝🏻' => 'nkwenaka: ọtanjele ahụ maka ọcha',
    '🤝🏼' => 'nkwenaka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤝🏽' => 'nkwenaka: ọtanjele ahụ ndịna etiti',
    '🤝🏾' => 'nkwenaka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤝🏿' => 'nkwenaka: ọtanjele ahụ maka òji',
    '🙏🏻' => 'aka ejikọrọ ọnụ: ọtanjele ahụ maka ọcha',
    '🙏🏼' => 'aka ejikọrọ ọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙏🏽' => 'aka ejikọrọ ọnụ: ọtanjele ahụ ndịna etiti',
    '🙏🏾' => 'aka ejikọrọ ọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🙏🏿' => 'aka ejikọrọ ọnụ: ọtanjele ahụ maka òji',
    '✍🏻' => 'aka na-ede ihe: ọtanjele ahụ maka ọcha',
    '✍🏼' => 'aka na-ede ihe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '✍🏽' => 'aka na-ede ihe: ọtanjele ahụ ndịna etiti',
    '✍🏾' => 'aka na-ede ihe: ọtanjele ahụ maka òji-ndịna etiti',
    '✍🏿' => 'aka na-ede ihe: ọtanjele ahụ maka òji',
    '💅🏻' => 'nteji mbọaka: ọtanjele ahụ maka ọcha',
    '💅🏼' => 'nteji mbọaka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💅🏽' => 'nteji mbọaka: ọtanjele ahụ ndịna etiti',
    '💅🏾' => 'nteji mbọaka: ọtanjele ahụ maka òji-ndịna etiti',
    '💅🏿' => 'nteji mbọaka: ọtanjele ahụ maka òji',
    '🤳🏻' => 'selfi: ọtanjele ahụ maka ọcha',
    '🤳🏼' => 'selfi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤳🏽' => 'selfi: ọtanjele ahụ ndịna etiti',
    '🤳🏾' => 'selfi: ọtanjele ahụ maka òji-ndịna etiti',
    '🤳🏿' => 'selfi: ọtanjele ahụ maka òji',
    '💪🏻' => 'akpụ̀ aka: ọtanjele ahụ maka ọcha',
    '💪🏼' => 'akpụ̀ aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💪🏽' => 'akpụ̀ aka: ọtanjele ahụ ndịna etiti',
    '💪🏾' => 'akpụ̀ aka: ọtanjele ahụ maka òji-ndịna etiti',
    '💪🏿' => 'akpụ̀ aka: ọtanjele ahụ maka òji',
    '🦵🏻' => 'ụkwụ: ọtanjele ahụ maka ọcha',
    '🦵🏼' => 'ụkwụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🦵🏽' => 'ụkwụ: ọtanjele ahụ ndịna etiti',
    '🦵🏾' => 'ụkwụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🦵🏿' => 'ụkwụ: ọtanjele ahụ maka òji',
    '🦶🏻' => 'ukwu: ọtanjele ahụ maka ọcha',
    '🦶🏼' => 'ukwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🦶🏽' => 'ukwu: ọtanjele ahụ ndịna etiti',
    '🦶🏾' => 'ukwu: ọtanjele ahụ maka òji-ndịna etiti',
    '🦶🏿' => 'ukwu: ọtanjele ahụ maka òji',
    '👂🏻' => 'nti: ọtanjele ahụ maka ọcha',
    '👂🏼' => 'nti: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👂🏽' => 'nti: ọtanjele ahụ ndịna etiti',
    '👂🏾' => 'nti: ọtanjele ahụ maka òji-ndịna etiti',
    '👂🏿' => 'nti: ọtanjele ahụ maka òji',
    '🦻🏻' => 'nti na hearing aid: ọtanjele ahụ maka ọcha',
    '🦻🏼' => 'nti na hearing aid: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🦻🏽' => 'nti na hearing aid: ọtanjele ahụ ndịna etiti',
    '🦻🏾' => 'nti na hearing aid: ọtanjele ahụ maka òji-ndịna etiti',
    '🦻🏿' => 'nti na hearing aid: ọtanjele ahụ maka òji',
    '👃🏻' => 'imi: ọtanjele ahụ maka ọcha',
    '👃🏼' => 'imi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👃🏽' => 'imi: ọtanjele ahụ ndịna etiti',
    '👃🏾' => 'imi: ọtanjele ahụ maka òji-ndịna etiti',
    '👃🏿' => 'imi: ọtanjele ahụ maka òji',
    '👶🏻' => 'nwata ọhụrụ: ọtanjele ahụ maka ọcha',
    '👶🏼' => 'nwata ọhụrụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👶🏽' => 'nwata ọhụrụ: ọtanjele ahụ ndịna etiti',
    '👶🏾' => 'nwata ọhụrụ: ọtanjele ahụ maka òji-ndịna etiti',
    '👶🏿' => 'nwata ọhụrụ: ọtanjele ahụ maka òji',
    '🧒🏻' => 'nwata: ọtanjele ahụ maka ọcha',
    '🧒🏼' => 'nwata: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧒🏽' => 'nwata: ọtanjele ahụ ndịna etiti',
    '🧒🏾' => 'nwata: ọtanjele ahụ maka òji-ndịna etiti',
    '🧒🏿' => 'nwata: ọtanjele ahụ maka òji',
    '👦🏻' => 'nwa nwoke: ọtanjele ahụ maka ọcha',
    '👦🏼' => 'nwa nwoke: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👦🏽' => 'nwa nwoke: ọtanjele ahụ ndịna etiti',
    '👦🏾' => 'nwa nwoke: ọtanjele ahụ maka òji-ndịna etiti',
    '👦🏿' => 'nwa nwoke: ọtanjele ahụ maka òji',
    '👧🏻' => 'nwata nwaanyị: ọtanjele ahụ maka ọcha',
    '👧🏼' => 'nwata nwaanyị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👧🏽' => 'nwata nwaanyị: ọtanjele ahụ ndịna etiti',
    '👧🏾' => 'nwata nwaanyị: ọtanjele ahụ maka òji-ndịna etiti',
    '👧🏿' => 'nwata nwaanyị: ọtanjele ahụ maka òji',
    '🧑🏻' => 'okenye: ọtanjele ahụ maka ọcha',
    '🧑🏼' => 'okenye: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧑🏽' => 'okenye: ọtanjele ahụ ndịna etiti',
    '🧑🏾' => 'okenye: ọtanjele ahụ maka òji-ndịna etiti',
    '🧑🏿' => 'okenye: ọtanjele ahụ maka òji',
    '👱🏻' => 'Onye-isi awọ: ọtanjele ahụ maka ọcha',
    '👱🏼' => 'Onye-isi awọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👱🏽' => 'Onye-isi awọ: ọtanjele ahụ ndịna etiti',
    '👱🏾' => 'Onye-isi awọ: ọtanjele ahụ maka òji-ndịna etiti',
    '👱🏿' => 'Onye-isi awọ: ọtanjele ahụ maka òji',
    '👨🏻' => 'nwoke: ọtanjele ahụ maka ọcha',
    '👨🏼' => 'nwoke: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👨🏽' => 'nwoke: ọtanjele ahụ ndịna etiti',
    '👨🏾' => 'nwoke: ọtanjele ahụ maka òji-ndịna etiti',
    '👨🏿' => 'nwoke: ọtanjele ahụ maka òji',
    '🧔🏻' => 'onye nwere ahụọnụ: ọtanjele ahụ maka ọcha',
    '🧔🏼' => 'onye nwere ahụọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧔🏽' => 'onye nwere ahụọnụ: ọtanjele ahụ ndịna etiti',
    '🧔🏾' => 'onye nwere ahụọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧔🏿' => 'onye nwere ahụọnụ: ọtanjele ahụ maka òji',
    '👩🏻' => 'nwanyị: ọtanjele ahụ maka ọcha',
    '👩🏼' => 'nwanyị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👩🏽' => 'nwanyị: ọtanjele ahụ ndịna etiti',
    '👩🏾' => 'nwanyị: ọtanjele ahụ maka òji-ndịna etiti',
    '👩🏿' => 'nwanyị: ọtanjele ahụ maka òji',
    '🧓🏻' => 'kara dị okenye: ọtanjele ahụ maka ọcha',
    '🧓🏼' => 'kara dị okenye: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧓🏽' => 'kara dị okenye: ọtanjele ahụ ndịna etiti',
    '🧓🏾' => 'kara dị okenye: ọtanjele ahụ maka òji-ndịna etiti',
    '🧓🏿' => 'kara dị okenye: ọtanjele ahụ maka òji',
    '👴🏻' => 'okenye nwoke: ọtanjele ahụ maka ọcha',
    '👴🏼' => 'okenye nwoke: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👴🏽' => 'okenye nwoke: ọtanjele ahụ ndịna etiti',
    '👴🏾' => 'okenye nwoke: ọtanjele ahụ maka òji-ndịna etiti',
    '👴🏿' => 'okenye nwoke: ọtanjele ahụ maka òji',
    '👵🏻' => 'okenye nwaanyị: ọtanjele ahụ maka ọcha',
    '👵🏼' => 'okenye nwaanyị: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👵🏽' => 'okenye nwaanyị: ọtanjele ahụ ndịna etiti',
    '👵🏾' => 'okenye nwaanyị: ọtanjele ahụ maka òji-ndịna etiti',
    '👵🏿' => 'okenye nwaanyị: ọtanjele ahụ maka òji',
    '🙍🏻' => 'onye na-agbarụ ihu: ọtanjele ahụ maka ọcha',
    '🙍🏼' => 'onye na-agbarụ ihu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙍🏽' => 'onye na-agbarụ ihu: ọtanjele ahụ ndịna etiti',
    '🙍🏾' => 'onye na-agbarụ ihu: ọtanjele ahụ maka òji-ndịna etiti',
    '🙍🏿' => 'onye na-agbarụ ihu: ọtanjele ahụ maka òji',
    '🙎🏻' => 'onye na-asọpụta ọnụ: ọtanjele ahụ maka ọcha',
    '🙎🏼' => 'onye na-asọpụta ọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙎🏽' => 'onye na-asọpụta ọnụ: ọtanjele ahụ ndịna etiti',
    '🙎🏾' => 'onye na-asọpụta ọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🙎🏿' => 'onye na-asọpụta ọnụ: ọtanjele ahụ maka òji',
    '🙅🏻' => 'onye na-egosipta MBÀ: ọtanjele ahụ maka ọcha',
    '🙅🏼' => 'onye na-egosipta MBÀ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙅🏽' => 'onye na-egosipta MBÀ: ọtanjele ahụ ndịna etiti',
    '🙅🏾' => 'onye na-egosipta MBÀ: ọtanjele ahụ maka òji-ndịna etiti',
    '🙅🏿' => 'onye na-egosipta MBÀ: ọtanjele ahụ maka òji',
    '🙆🏻' => 'onye na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka ọcha',
    '🙆🏼' => 'onye na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙆🏽' => 'onye na-egosipta Ọ DỊ MMA: ọtanjele ahụ ndịna etiti',
    '🙆🏾' => 'onye na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka òji-ndịna etiti',
    '🙆🏿' => 'onye na-egosipta Ọ DỊ MMA: ọtanjele ahụ maka òji',
    '💁🏻' => 'onye na-ehulata aka: ọtanjele ahụ maka ọcha',
    '💁🏼' => 'onye na-ehulata aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💁🏽' => 'onye na-ehulata aka: ọtanjele ahụ ndịna etiti',
    '💁🏾' => 'onye na-ehulata aka: ọtanjele ahụ maka òji-ndịna etiti',
    '💁🏿' => 'onye na-ehulata aka: ọtanjele ahụ maka òji',
    '🙋🏻' => 'onye na-ewelite aka: ọtanjele ahụ maka ọcha',
    '🙋🏼' => 'onye na-ewelite aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙋🏽' => 'onye na-ewelite aka: ọtanjele ahụ ndịna etiti',
    '🙋🏾' => 'onye na-ewelite aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🙋🏿' => 'onye na-ewelite aka: ọtanjele ahụ maka òji',
    '🧏🏻' => 'onye ntị chiri: ọtanjele ahụ maka ọcha',
    '🧏🏼' => 'onye ntị chiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧏🏽' => 'onye ntị chiri: ọtanjele ahụ ndịna etiti',
    '🧏🏾' => 'onye ntị chiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🧏🏿' => 'onye ntị chiri: ọtanjele ahụ maka òji',
    '🙇🏻' => 'onye na-ehulata ala: ọtanjele ahụ maka ọcha',
    '🙇🏼' => 'onye na-ehulata ala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🙇🏽' => 'onye na-ehulata ala: ọtanjele ahụ ndịna etiti',
    '🙇🏾' => 'onye na-ehulata ala: ọtanjele ahụ maka òji-ndịna etiti',
    '🙇🏿' => 'onye na-ehulata ala: ọtanjele ahụ maka òji',
    '🤦🏻' => 'onye na-ezo ihu ya èzo: ọtanjele ahụ maka ọcha',
    '🤦🏼' => 'onye na-ezo ihu ya èzo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤦🏽' => 'onye na-ezo ihu ya èzo: ọtanjele ahụ ndịna etiti',
    '🤦🏾' => 'onye na-ezo ihu ya èzo: ọtanjele ahụ maka òji-ndịna etiti',
    '🤦🏿' => 'onye na-ezo ihu ya èzo: ọtanjele ahụ maka òji',
    '🤷🏻' => 'onye ngosipụta nhatanha aka: ọtanjele ahụ maka ọcha',
    '🤷🏼' => 'onye ngosipụta nhatanha aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤷🏽' => 'onye ngosipụta nhatanha aka: ọtanjele ahụ ndịna etiti',
    '🤷🏾' => 'onye ngosipụta nhatanha aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤷🏿' => 'onye ngosipụta nhatanha aka: ọtanjele ahụ maka òji',
    '👮🏻' => 'onye uweojii: ọtanjele ahụ maka ọcha',
    '👮🏼' => 'onye uweojii: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👮🏽' => 'onye uweojii: ọtanjele ahụ ndịna etiti',
    '👮🏾' => 'onye uweojii: ọtanjele ahụ maka òji-ndịna etiti',
    '👮🏿' => 'onye uweojii: ọtanjele ahụ maka òji',
    '🕵🏻' => 'nchọpụta: ọtanjele ahụ maka ọcha',
    '🕵🏼' => 'nchọpụta: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🕵🏽' => 'nchọpụta: ọtanjele ahụ ndịna etiti',
    '🕵🏾' => 'nchọpụta: ọtanjele ahụ maka òji-ndịna etiti',
    '🕵🏿' => 'nchọpụta: ọtanjele ahụ maka òji',
    '💂🏻' => 'nche: ọtanjele ahụ maka ọcha',
    '💂🏼' => 'nche: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💂🏽' => 'nche: ọtanjele ahụ ndịna etiti',
    '💂🏾' => 'nche: ọtanjele ahụ maka òji-ndịna etiti',
    '💂🏿' => 'nche: ọtanjele ahụ maka òji',
    '🥷🏻' => 'ninja: ọtanjele ahụ maka ọcha',
    '🥷🏼' => 'ninja: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🥷🏽' => 'ninja: ọtanjele ahụ ndịna etiti',
    '🥷🏾' => 'ninja: ọtanjele ahụ maka òji-ndịna etiti',
    '🥷🏿' => 'ninja: ọtanjele ahụ maka òji',
    '👷🏻' => 'onye ọrụ ụzọ: ọtanjele ahụ maka ọcha',
    '👷🏼' => 'onye ọrụ ụzọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👷🏽' => 'onye ọrụ ụzọ: ọtanjele ahụ ndịna etiti',
    '👷🏾' => 'onye ọrụ ụzọ: ọtanjele ahụ maka òji-ndịna etiti',
    '👷🏿' => 'onye ọrụ ụzọ: ọtanjele ahụ maka òji',
    '🫅🏻' => 'onye ji okpueze: ọtanjele ahụ maka ọcha',
    '🫅🏼' => 'onye ji okpueze: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫅🏽' => 'onye ji okpueze: ọtanjele ahụ ndịna etiti',
    '🫅🏾' => 'onye ji okpueze: ọtanjele ahụ maka òji-ndịna etiti',
    '🫅🏿' => 'onye ji okpueze: ọtanjele ahụ maka òji',
    '🤴🏻' => 'ọkparaeze: ọtanjele ahụ maka ọcha',
    '🤴🏼' => 'ọkparaeze: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤴🏽' => 'ọkparaeze: ọtanjele ahụ ndịna etiti',
    '🤴🏾' => 'ọkparaeze: ọtanjele ahụ maka òji-ndịna etiti',
    '🤴🏿' => 'ọkparaeze: ọtanjele ahụ maka òji',
    '👸🏻' => 'àdaeze: ọtanjele ahụ maka ọcha',
    '👸🏼' => 'àdaeze: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👸🏽' => 'àdaeze: ọtanjele ahụ ndịna etiti',
    '👸🏾' => 'àdaeze: ọtanjele ahụ maka òji-ndịna etiti',
    '👸🏿' => 'àdaeze: ọtanjele ahụ maka òji',
    '👳🏻' => 'onye yi turban: ọtanjele ahụ maka ọcha',
    '👳🏼' => 'onye yi turban: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👳🏽' => 'onye yi turban: ọtanjele ahụ ndịna etiti',
    '👳🏾' => 'onye yi turban: ọtanjele ahụ maka òji-ndịna etiti',
    '👳🏿' => 'onye yi turban: ọtanjele ahụ maka òji',
    '👲🏻' => 'nwoke kpu okpu ndị China: ọtanjele ahụ maka ọcha',
    '👲🏼' => 'nwoke kpu okpu ndị China: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👲🏽' => 'nwoke kpu okpu ndị China: ọtanjele ahụ ndịna etiti',
    '👲🏾' => 'nwoke kpu okpu ndị China: ọtanjele ahụ maka òji-ndịna etiti',
    '👲🏿' => 'nwoke kpu okpu ndị China: ọtanjele ahụ maka òji',
    '🧕🏻' => 'nwanyị nwere ichafùisi: ọtanjele ahụ maka ọcha',
    '🧕🏼' => 'nwanyị nwere ichafùisi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧕🏽' => 'nwanyị nwere ichafùisi: ọtanjele ahụ ndịna etiti',
    '🧕🏾' => 'nwanyị nwere ichafùisi: ọtanjele ahụ maka òji-ndịna etiti',
    '🧕🏿' => 'nwanyị nwere ichafùisi: ọtanjele ahụ maka òji',
    '🤵🏻' => 'nwoke yi uwe agbamụakwụkwọ: ọtanjele ahụ maka ọcha',
    '🤵🏼' => 'nwoke yi uwe agbamụakwụkwọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤵🏽' => 'nwoke yi uwe agbamụakwụkwọ: ọtanjele ahụ ndịna etiti',
    '🤵🏾' => 'nwoke yi uwe agbamụakwụkwọ: ọtanjele ahụ maka òji-ndịna etiti',
    '🤵🏿' => 'nwoke yi uwe agbamụakwụkwọ: ọtanjele ahụ maka òji',
    '👰🏻' => 'nwanyị na-agba akwụkwọ yi akwa nkochi ihu: ọtanjele ahụ maka ọcha',
    '👰🏼' => 'nwanyị na-agba akwụkwọ yi akwa nkochi ihu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👰🏽' => 'nwanyị na-agba akwụkwọ yi akwa nkochi ihu: ọtanjele ahụ ndịna etiti',
    '👰🏾' => 'nwanyị na-agba akwụkwọ yi akwa nkochi ihu: ọtanjele ahụ maka òji-ndịna etiti',
    '👰🏿' => 'nwanyị na-agba akwụkwọ yi akwa nkochi ihu: ọtanjele ahụ maka òji',
    '🤰🏻' => 'nwanyị dị ime: ọtanjele ahụ maka ọcha',
    '🤰🏼' => 'nwanyị dị ime: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤰🏽' => 'nwanyị dị ime: ọtanjele ahụ ndịna etiti',
    '🤰🏾' => 'nwanyị dị ime: ọtanjele ahụ maka òji-ndịna etiti',
    '🤰🏿' => 'nwanyị dị ime: ọtanjele ahụ maka òji',
    '🫃🏻' => 'nwoke di ime: ọtanjele ahụ maka ọcha',
    '🫃🏼' => 'nwoke di ime: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫃🏽' => 'nwoke di ime: ọtanjele ahụ ndịna etiti',
    '🫃🏾' => 'nwoke di ime: ọtanjele ahụ maka òji-ndịna etiti',
    '🫃🏿' => 'nwoke di ime: ọtanjele ahụ maka òji',
    '🫄🏻' => 'onye di ime: ọtanjele ahụ maka ọcha',
    '🫄🏼' => 'onye di ime: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🫄🏽' => 'onye di ime: ọtanjele ahụ ndịna etiti',
    '🫄🏾' => 'onye di ime: ọtanjele ahụ maka òji-ndịna etiti',
    '🫄🏿' => 'onye di ime: ọtanjele ahụ maka òji',
    '🤱🏻' => 'enyemụara: ọtanjele ahụ maka ọcha',
    '🤱🏼' => 'enyemụara: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤱🏽' => 'enyemụara: ọtanjele ahụ ndịna etiti',
    '🤱🏾' => 'enyemụara: ọtanjele ahụ maka òji-ndịna etiti',
    '🤱🏿' => 'enyemụara: ọtanjele ahụ maka òji',
    '👼🏻' => 'mụo ọma nwata ọhụrụ: ọtanjele ahụ maka ọcha',
    '👼🏼' => 'mụo ọma nwata ọhụrụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👼🏽' => 'mụo ọma nwata ọhụrụ: ọtanjele ahụ ndịna etiti',
    '👼🏾' => 'mụo ọma nwata ọhụrụ: ọtanjele ahụ maka òji-ndịna etiti',
    '👼🏿' => 'mụo ọma nwata ọhụrụ: ọtanjele ahụ maka òji',
    '🎅🏻' => 'Nna Ekeresìmesi: ọtanjele ahụ maka ọcha',
    '🎅🏼' => 'Nna Ekeresìmesi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🎅🏽' => 'Nna Ekeresìmesi: ọtanjele ahụ ndịna etiti',
    '🎅🏾' => 'Nna Ekeresìmesi: ọtanjele ahụ maka òji-ndịna etiti',
    '🎅🏿' => 'Nna Ekeresìmesi: ọtanjele ahụ maka òji',
    '🤶🏻' => 'Nne Ekeresìmesi: ọtanjele ahụ maka ọcha',
    '🤶🏼' => 'Nne Ekeresìmesi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤶🏽' => 'Nne Ekeresìmesi: ọtanjele ahụ ndịna etiti',
    '🤶🏾' => 'Nne Ekeresìmesi: ọtanjele ahụ maka òji-ndịna etiti',
    '🤶🏿' => 'Nne Ekeresìmesi: ọtanjele ahụ maka òji',
    '🦸🏻' => 'dike: ọtanjele ahụ maka ọcha',
    '🦸🏼' => 'dike: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🦸🏽' => 'dike: ọtanjele ahụ ndịna etiti',
    '🦸🏾' => 'dike: ọtanjele ahụ maka òji-ndịna etiti',
    '🦸🏿' => 'dike: ọtanjele ahụ maka òji',
    '🦹🏻' => 'onye ọjọọ: ọtanjele ahụ maka ọcha',
    '🦹🏼' => 'onye ọjọọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🦹🏽' => 'onye ọjọọ: ọtanjele ahụ ndịna etiti',
    '🦹🏾' => 'onye ọjọọ: ọtanjele ahụ maka òji-ndịna etiti',
    '🦹🏿' => 'onye ọjọọ: ọtanjele ahụ maka òji',
    '🧙🏻' => 'onye abrakatabra: ọtanjele ahụ maka ọcha',
    '🧙🏼' => 'onye abrakatabra: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧙🏽' => 'onye abrakatabra: ọtanjele ahụ ndịna etiti',
    '🧙🏾' => 'onye abrakatabra: ọtanjele ahụ maka òji-ndịna etiti',
    '🧙🏿' => 'onye abrakatabra: ọtanjele ahụ maka òji',
    '🧚🏻' => 'akụkọ: ọtanjele ahụ maka ọcha',
    '🧚🏼' => 'akụkọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧚🏽' => 'akụkọ: ọtanjele ahụ ndịna etiti',
    '🧚🏾' => 'akụkọ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧚🏿' => 'akụkọ: ọtanjele ahụ maka òji',
    '🧛🏻' => 'ọmị ọbara: ọtanjele ahụ maka ọcha',
    '🧛🏼' => 'ọmị ọbara: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧛🏽' => 'ọmị ọbara: ọtanjele ahụ ndịna etiti',
    '🧛🏾' => 'ọmị ọbara: ọtanjele ahụ maka òji-ndịna etiti',
    '🧛🏿' => 'ọmị ọbara: ọtanjele ahụ maka òji',
    '🧜🏻' => 'onyewọta: ọtanjele ahụ maka ọcha',
    '🧜🏼' => 'onyewọta: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧜🏽' => 'onyewọta: ọtanjele ahụ ndịna etiti',
    '🧜🏾' => 'onyewọta: ọtanjele ahụ maka òji-ndịna etiti',
    '🧜🏿' => 'onyewọta: ọtanjele ahụ maka òji',
    '🧝🏻' => 'elfụ: ọtanjele ahụ maka ọcha',
    '🧝🏼' => 'elfụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧝🏽' => 'elfụ: ọtanjele ahụ ndịna etiti',
    '🧝🏾' => 'elfụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧝🏿' => 'elfụ: ọtanjele ahụ maka òji',
    '💆🏻' => 'onye na-anata ozi: ọtanjele ahụ maka ọcha',
    '💆🏼' => 'onye na-anata ozi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💆🏽' => 'onye na-anata ozi: ọtanjele ahụ ndịna etiti',
    '💆🏾' => 'onye na-anata ozi: ọtanjele ahụ maka òji-ndịna etiti',
    '💆🏿' => 'onye na-anata ozi: ọtanjele ahụ maka òji',
    '💇🏻' => 'Onye na-enweta ọkpụkpụisi: ọtanjele ahụ maka ọcha',
    '💇🏼' => 'Onye na-enweta ọkpụkpụisi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💇🏽' => 'Onye na-enweta ọkpụkpụisi: ọtanjele ahụ ndịna etiti',
    '💇🏾' => 'Onye na-enweta ọkpụkpụisi: ọtanjele ahụ maka òji-ndịna etiti',
    '💇🏿' => 'Onye na-enweta ọkpụkpụisi: ọtanjele ahụ maka òji',
    '🚶🏻' => 'onye na-aga ije: ọtanjele ahụ maka ọcha',
    '🚶🏼' => 'onye na-aga ije: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚶🏽' => 'onye na-aga ije: ọtanjele ahụ ndịna etiti',
    '🚶🏾' => 'onye na-aga ije: ọtanjele ahụ maka òji-ndịna etiti',
    '🚶🏿' => 'onye na-aga ije: ọtanjele ahụ maka òji',
    '🧍🏻' => 'onye na-e guzo: ọtanjele ahụ maka ọcha',
    '🧍🏼' => 'onye na-e guzo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧍🏽' => 'onye na-e guzo: ọtanjele ahụ ndịna etiti',
    '🧍🏾' => 'onye na-e guzo: ọtanjele ahụ maka òji-ndịna etiti',
    '🧍🏿' => 'onye na-e guzo: ọtanjele ahụ maka òji',
    '🧎🏻' => 'onye gbu ikpere n’ala: ọtanjele ahụ maka ọcha',
    '🧎🏼' => 'onye gbu ikpere n’ala: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧎🏽' => 'onye gbu ikpere n’ala: ọtanjele ahụ ndịna etiti',
    '🧎🏾' => 'onye gbu ikpere n’ala: ọtanjele ahụ maka òji-ndịna etiti',
    '🧎🏿' => 'onye gbu ikpere n’ala: ọtanjele ahụ maka òji',
    '🏃🏻' => 'onye na-agba ọsọ: ọtanjele ahụ maka ọcha',
    '🏃🏼' => 'onye na-agba ọsọ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏃🏽' => 'onye na-agba ọsọ: ọtanjele ahụ ndịna etiti',
    '🏃🏾' => 'onye na-agba ọsọ: ọtanjele ahụ maka òji-ndịna etiti',
    '🏃🏿' => 'onye na-agba ọsọ: ọtanjele ahụ maka òji',
    '💃🏻' => 'nwanyị na-agba egwu: ọtanjele ahụ maka ọcha',
    '💃🏼' => 'nwanyị na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💃🏽' => 'nwanyị na-agba egwu: ọtanjele ahụ ndịna etiti',
    '💃🏾' => 'nwanyị na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti',
    '💃🏿' => 'nwanyị na-agba egwu: ọtanjele ahụ maka òji',
    '🕺🏻' => 'nwoke na-agba egwu: ọtanjele ahụ maka ọcha',
    '🕺🏼' => 'nwoke na-agba egwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🕺🏽' => 'nwoke na-agba egwu: ọtanjele ahụ ndịna etiti',
    '🕺🏾' => 'nwoke na-agba egwu: ọtanjele ahụ maka òji-ndịna etiti',
    '🕺🏿' => 'nwoke na-agba egwu: ọtanjele ahụ maka òji',
    '🕴🏻' => 'nwoke yi akwà azụmaahịa na-efe n’elu: ọtanjele ahụ maka ọcha',
    '🕴🏼' => 'nwoke yi akwà azụmaahịa na-efe n’elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🕴🏽' => 'nwoke yi akwà azụmaahịa na-efe n’elu: ọtanjele ahụ ndịna etiti',
    '🕴🏾' => 'nwoke yi akwà azụmaahịa na-efe n’elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🕴🏿' => 'nwoke yi akwà azụmaahịa na-efe n’elu: ọtanjele ahụ maka òji',
    '👯🏻' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha',
    '👯🏼' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👯🏽' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ ndịna etiti',
    '👯🏾' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji-ndịna etiti',
    '👯🏿' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo: ọtanjele ahụ maka òji',
    '🧖🏻' => 'onye nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka ọcha',
    '🧖🏼' => 'onye nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧖🏽' => 'onye nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ ndịna etiti',
    '🧖🏾' => 'onye nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧖🏿' => 'onye nọ n’ụlọ okpomọọkụ mmiri ahụ: ọtanjele ahụ maka òji',
    '🧗🏻' => 'onye na-arị elu: ọtanjele ahụ maka ọcha',
    '🧗🏼' => 'onye na-arị elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧗🏽' => 'onye na-arị elu: ọtanjele ahụ ndịna etiti',
    '🧗🏾' => 'onye na-arị elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🧗🏿' => 'onye na-arị elu: ọtanjele ahụ maka òji',
    '🏇🏻' => 'egwuregwu inyinyà: ọtanjele ahụ maka ọcha',
    '🏇🏼' => 'egwuregwu inyinyà: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏇🏽' => 'egwuregwu inyinyà: ọtanjele ahụ ndịna etiti',
    '🏇🏾' => 'egwuregwu inyinyà: ọtanjele ahụ maka òji-ndịna etiti',
    '🏇🏿' => 'egwuregwu inyinyà: ọtanjele ahụ maka òji',
    '🏂🏻' => 'onye egwuregwu akụrụ mmiri: ọtanjele ahụ maka ọcha',
    '🏂🏼' => 'onye egwuregwu akụrụ mmiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏂🏽' => 'onye egwuregwu akụrụ mmiri: ọtanjele ahụ ndịna etiti',
    '🏂🏾' => 'onye egwuregwu akụrụ mmiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🏂🏿' => 'onye egwuregwu akụrụ mmiri: ọtanjele ahụ maka òji',
    '🏌🏻' => 'onye na-akụ gọfụ: ọtanjele ahụ maka ọcha',
    '🏌🏼' => 'onye na-akụ gọfụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏌🏽' => 'onye na-akụ gọfụ: ọtanjele ahụ ndịna etiti',
    '🏌🏾' => 'onye na-akụ gọfụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🏌🏿' => 'onye na-akụ gọfụ: ọtanjele ahụ maka òji',
    '🏄🏻' => 'onye egwuregwu oshimiri: ọtanjele ahụ maka ọcha',
    '🏄🏼' => 'onye egwuregwu oshimiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏄🏽' => 'onye egwuregwu oshimiri: ọtanjele ahụ ndịna etiti',
    '🏄🏾' => 'onye egwuregwu oshimiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🏄🏿' => 'onye egwuregwu oshimiri: ọtanjele ahụ maka òji',
    '🚣🏻' => 'onye na-akwọ ụgbọ epepe: ọtanjele ahụ maka ọcha',
    '🚣🏼' => 'onye na-akwọ ụgbọ epepe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚣🏽' => 'onye na-akwọ ụgbọ epepe: ọtanjele ahụ ndịna etiti',
    '🚣🏾' => 'onye na-akwọ ụgbọ epepe: ọtanjele ahụ maka òji-ndịna etiti',
    '🚣🏿' => 'onye na-akwọ ụgbọ epepe: ọtanjele ahụ maka òji',
    '🏊🏻' => 'onye na-egwu mmiri: ọtanjele ahụ maka ọcha',
    '🏊🏼' => 'onye na-egwu mmiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏊🏽' => 'onye na-egwu mmiri: ọtanjele ahụ ndịna etiti',
    '🏊🏾' => 'onye na-egwu mmiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🏊🏿' => 'onye na-egwu mmiri: ọtanjele ahụ maka òji',
    '⛹🏻' => 'onye na-atụ bọolụ: ọtanjele ahụ maka ọcha',
    '⛹🏼' => 'onye na-atụ bọolụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '⛹🏽' => 'onye na-atụ bọolụ: ọtanjele ahụ ndịna etiti',
    '⛹🏾' => 'onye na-atụ bọolụ: ọtanjele ahụ maka òji-ndịna etiti',
    '⛹🏿' => 'onye na-atụ bọolụ: ọtanjele ahụ maka òji',
    '🏋🏻' => 'onye na-ebuli ihe elu: ọtanjele ahụ maka ọcha',
    '🏋🏼' => 'onye na-ebuli ihe elu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏋🏽' => 'onye na-ebuli ihe elu: ọtanjele ahụ ndịna etiti',
    '🏋🏾' => 'onye na-ebuli ihe elu: ọtanjele ahụ maka òji-ndịna etiti',
    '🏋🏿' => 'onye na-ebuli ihe elu: ọtanjele ahụ maka òji',
    '🚴🏻' => 'Onye egwuregwu ịgba Igwe: ọtanjele ahụ maka ọcha',
    '🚴🏼' => 'Onye egwuregwu ịgba Igwe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚴🏽' => 'Onye egwuregwu ịgba Igwe: ọtanjele ahụ ndịna etiti',
    '🚴🏾' => 'Onye egwuregwu ịgba Igwe: ọtanjele ahụ maka òji-ndịna etiti',
    '🚴🏿' => 'Onye egwuregwu ịgba Igwe: ọtanjele ahụ maka òji',
    '🚵🏻' => 'onye egwuregwu ịrị ugwu: ọtanjele ahụ maka ọcha',
    '🚵🏼' => 'onye egwuregwu ịrị ugwu: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🚵🏽' => 'onye egwuregwu ịrị ugwu: ọtanjele ahụ ndịna etiti',
    '🚵🏾' => 'onye egwuregwu ịrị ugwu: ọtanjele ahụ maka òji-ndịna etiti',
    '🚵🏿' => 'onye egwuregwu ịrị ugwu: ọtanjele ahụ maka òji',
    '🤸🏻' => 'onye na-eme egwuntụgharị onwe: ọtanjele ahụ maka ọcha',
    '🤸🏼' => 'onye na-eme egwuntụgharị onwe: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤸🏽' => 'onye na-eme egwuntụgharị onwe: ọtanjele ahụ ndịna etiti',
    '🤸🏾' => 'onye na-eme egwuntụgharị onwe: ọtanjele ahụ maka òji-ndịna etiti',
    '🤸🏿' => 'onye na-eme egwuntụgharị onwe: ọtanjele ahụ maka òji',
    '🤼🏻' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha',
    '🤼🏼' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤼🏽' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ ndịna etiti',
    '🤼🏾' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji-ndịna etiti',
    '🤼🏿' => 'ndị mmadụ ndị na-agba m̀gba: ọtanjele ahụ maka òji',
    '🤽🏻' => 'onye na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka ọcha',
    '🤽🏼' => 'onye na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤽🏽' => 'onye na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ ndịna etiti',
    '🤽🏾' => 'onye na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka òji-ndịna etiti',
    '🤽🏿' => 'onye na-egwu egwuregwu bọọlụ mmiri: ọtanjele ahụ maka òji',
    '🤾🏻' => 'onye na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka ọcha',
    '🤾🏼' => 'onye na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤾🏽' => 'onye na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ ndịna etiti',
    '🤾🏾' => 'onye na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤾🏿' => 'onye na-egwu egwuregwu bọọlụ aka: ọtanjele ahụ maka òji',
    '🤹🏻' => 'onye na-eme egwuregwu aka: ọtanjele ahụ maka ọcha',
    '🤹🏼' => 'onye na-eme egwuregwu aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🤹🏽' => 'onye na-eme egwuregwu aka: ọtanjele ahụ ndịna etiti',
    '🤹🏾' => 'onye na-eme egwuregwu aka: ọtanjele ahụ maka òji-ndịna etiti',
    '🤹🏿' => 'onye na-eme egwuregwu aka: ọtanjele ahụ maka òji',
    '🧘🏻' => 'onye chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka ọcha',
    '🧘🏼' => 'onye chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🧘🏽' => 'onye chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ ndịna etiti',
    '🧘🏾' => 'onye chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🧘🏿' => 'onye chịkọrọ ụkwụ ya abụọ ọnụ: ọtanjele ahụ maka òji',
    '🛀🏻' => 'onye na-asa ahụ: ọtanjele ahụ maka ọcha',
    '🛀🏼' => 'onye na-asa ahụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🛀🏽' => 'onye na-asa ahụ: ọtanjele ahụ ndịna etiti',
    '🛀🏾' => 'onye na-asa ahụ: ọtanjele ahụ maka òji-ndịna etiti',
    '🛀🏿' => 'onye na-asa ahụ: ọtanjele ahụ maka òji',
    '🛌🏻' => 'onye nọ n’àkwà: ọtanjele ahụ maka ọcha',
    '🛌🏼' => 'onye nọ n’àkwà: ọtanjele ahụ maka ọcha-ndịna etiti',
    '🛌🏽' => 'onye nọ n’àkwà: ọtanjele ahụ ndịna etiti',
    '🛌🏾' => 'onye nọ n’àkwà: ọtanjele ahụ maka òji-ndịna etiti',
    '🛌🏿' => 'onye nọ n’àkwà: ọtanjele ahụ maka òji',
    '👭🏻' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha',
    '👭🏼' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👭🏽' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ ndịna etiti',
    '👭🏾' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti',
    '👭🏿' => 'ụmụ nwanyị abụọ jikọtara aka: ọtanjele ahụ maka òji',
    '👫🏻' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha',
    '👫🏼' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👫🏽' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ ndịna etiti',
    '👫🏾' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti',
    '👫🏿' => 'nwoke na nwaanyị jikọtara aka: ọtanjele ahụ maka òji',
    '👬🏻' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha',
    '👬🏼' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka ọcha-ndịna etiti',
    '👬🏽' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ ndịna etiti',
    '👬🏾' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji-ndịna etiti',
    '👬🏿' => 'ụmụ nwoke abụọ jikọtara aka: ọtanjele ahụ maka òji',
    '💏🏻' => 'nsusò ọnụ: ọtanjele ahụ maka ọcha',
    '💏🏼' => 'nsusò ọnụ: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💏🏽' => 'nsusò ọnụ: ọtanjele ahụ ndịna etiti',
    '💏🏾' => 'nsusò ọnụ: ọtanjele ahụ maka òji-ndịna etiti',
    '💏🏿' => 'nsusò ọnụ: ọtanjele ahụ maka òji',
    '💑🏻' => 'di na nwunye nwere obi: ọtanjele ahụ maka ọcha',
    '💑🏼' => 'di na nwunye nwere obi: ọtanjele ahụ maka ọcha-ndịna etiti',
    '💑🏽' => 'di na nwunye nwere obi: ọtanjele ahụ ndịna etiti',
    '💑🏾' => 'di na nwunye nwere obi: ọtanjele ahụ maka òji-ndịna etiti',
    '💑🏿' => 'di na nwunye nwere obi: ọtanjele ahụ maka òji',
    '🏻' => 'ọtanjele ahụ maka ọcha',
    '🏼' => 'ọtanjele ahụ maka ọcha-ndịna etiti',
    '🏽' => 'ọtanjele ahụ ndịna etiti',
    '🏾' => 'ọtanjele ahụ maka òji-ndịna etiti',
    '🏿' => 'ọtanjele ahụ maka òji',
    '😀' => 'ihu ọchị',
    '😃' => 'Ihu Amụ Nwere Ọnụ Ghe oghe',
    '😄' => 'ihu amụ nwere mmepe ọnụ & anya amụ',
    '😁' => 'ihu ọchị nwere anya amụ',
    '😆' => 'ihu amụ nwere mmepe ọnụ & anya mechiri emechi',
    '😅' => 'ihu amụ nwere mmepe ọnụ & okpofufu oyi',
    '🤣' => 'na-atụgharị n’ala na-achị ọchị',
    '😂' => 'ihu nwere anya mmiri nke aṅụrị',
    '🙂' => 'nwa obere ihu na-amụ amụ',
    '🙃' => 'ihu nsụgharị-isi n’ala',
    '🫠' => 'ihu agbaze',
    '😉' => 'Ihu na-atabi anya',
    '😊' => 'ihu amụ nwere anya amụ',
    '😇' => 'ihu amụ nwere okirikiri okụ',
    '🥰' => 'ihu nwere obi',
    '😍' => 'ihu amụ nwere anya-obi ọcha',
    '🤩' => 'kpakpando-mere',
    '😘' => 'ihu dị mma nsusò ọnụ',
    '😗' => 'ihu nsusò ọnụ',
    '☺' => 'ihu na-amụ amụ',
    '😚' => 'ihu nsusò ọnụ emechiri anya',
    '😙' => 'Ihu Na-Eme Nsusu Nwere Anya Amụ',
    '🥲' => 'ihu na-amụ amụ nwere anya mmirị',
    '😋' => 'ihu nri dị ezigbo ụtọ',
    '😛' => 'ihu nwere mmipụta ire',
    '😜' => 'ihu nwere mmipụta ire & ntaji anya',
    '🤪' => 'ihu ara',
    '😝' => 'ihu nwere mmipụta ire & nwere mmechi anya',
    '🤑' => 'Ihu ọnụ-ego',
    '🤗' => 'ihu ọchị nwere aka mepere emepe',
    '🤭' => 'ihu n’iji aka mechie ọnụ',
    '🫢' => 'ihu mwute',
    '🫣' => 'ihu anya inyocha',
    '🤫' => 'ihu mechie onụ',
    '🤔' => 'ihu na-eche echiche',
    '🫡' => 'ihu na-ekele',
    '🤐' => 'ihu mgbachi ọnụ',
    '🤨' => 'ihu weliri anya elu',
    '😐' => 'ihu nkịtị',
    '😑' => 'ihu enweghị ngosipụta',
    '😶' => 'ihu enweghị ọnụ',
    '🫥' => 'ihu',
    '😏' => 'ihu na-eme nka ọchị',
    '😒' => 'uhu atọghị ọchị',
    '🙄' => 'ihu nwere kpụrụkpụrụ anya na-akpọgharị akpọgharị',
    '😬' => 'ihu ntachị anya',
    '🤥' => 'Ihu asị',
    '🫨' => 'ihu na-ama jijiji',
    '😌' => 'ihu nnwere onwe',
    '😔' => 'ihu echiche',
    '😪' => 'ihu anya ụra',
    '🤤' => 'ihu na-agụsị asọ mmiri',
    '😴' => 'ihu na-ehi ụra',
    '🫩' => 'ihu nwere anya ụra',
    '😷' => 'ihu nwere mkpuchi ihu ngwaọrụ ụlọ ọgwụ',
    '🤒' => 'ihu nwere ngwa ogologo',
    '🤕' => 'ihu nwere akwà mkpuchi',
    '🤢' => 'ihu nkoropu',
    '🤮' => 'ihu na-agbọ agbọ',
    '🤧' => 'ihu nfụkọ',
    '🥵' => 'ihu ọkụ',
    '🥶' => 'ihu oyi',
    '🥴' => 'ihu kpọrọ asị',
    '😵' => 'ihu nwere anya a kachiri',
    '🤯' => 'isi mere nkụwa',
    '🤠' => 'ihu okpu onye ọchụụ nnama',
    '🥳' => 'ihu oriri na mmanya',
    '🥸' => 'ihu nwogharia',
    '😎' => 'ihu amụ nwere ugogbe anya anyanwụ',
    '🤓' => 'ihu eze ọchị',
    '🧐' => 'ihu nwere ahụọnụ',
    '😕' => 'ihu mgbagwoju anya',
    '🫤' => 'ihu nwere onụ ufodụ',
    '😟' => 'ihu nwere nchekasị ahụ',
    '🙁' => 'nwa obere mgbarụ ihu',
    '☹' => 'na-agbarụ ihu',
    '😮' => 'ihu nwere mmepe ọnụ',
    '😯' => 'ihu dara jụụ',
    '😲' => 'ihu nwere ịtụnanya',
    '😳' => 'ihu nchagharị ọbara',
    '🫪' => 'ihu gbagọrọ agbagọ',
    '🥺' => 'ihu na-ayọ ayiyọ',
    '🥹' => 'ihu choro ị be akwà',
    '😦' => 'ihu mgbarụ nwere mmepe ọnụ',
    '😧' => 'ihu nwere ọnụma',
    '😨' => 'ihu ujọ',
    '😰' => 'ihu nwere mmepe ọnụ & okpofufu oyi',
    '😥' => 'ihu ngharịpụ mana nwere nkuda ume',
    '😢' => 'ihu na-ebe akwa',
    '😭' => 'ihu akwa mkpu',
    '😱' => 'ihu na-eti n’ụjọ',
    '😖' => 'ihu nwere mgbagwoju anya',
    '😣' => 'ihu na-enwe ntachi obi',
    '😞' => 'ihu nwere ngharịpụ',
    '😓' => 'ihu nwere okpofufu oyi',
    '😩' => 'ihu ike ọgwụgwụ',
    '😫' => 'ihu ume ọgwụgwụ',
    '🥱' => 'ihu na-asụ ude',
    '😤' => 'ihu nwere mpụta anwụrụ ọkụ n’imi',
    '😡' => 'ihu nsụpụta iwe',
    '😠' => 'ihu iwe',
    '🤬' => 'ihu nwere akara n’elu onụ',
    '😈' => 'ihu amụ nwere mpi',
    '👿' => 'ihu iwe nwere mpi',
    '💀' => 'okpokoro isi',
    '☠' => 'okpokoroisi na ndochiọkpụkpụ',
    '💩' => 'ikpo nke nsi',
    '🤡' => 'ihu njakịrị',
    '👹' => 'ihe egwu',
    '👺' => 'gọblịn',
    '👻' => 'mmụọ',
    '👽' => 'ihe nsina mba ọzọ',
    '👾' => 'ihe egwu ihe nsina mba ọzọ',
    '🤖' => 'ihu rọbọtụ',
    '😺' => 'nwamba na-achị ọchị',
    '😸' => 'ihu ọchị nwamba nwere anya amụ',
    '😹' => 'ihu nwamba nwere anya mmiri anụrị',
    '😻' => 'ihu ọchị nwamba nwere obi ebere',
    '😼' => 'ihu nwamba nwere amụ pụrụiche',
    '😽' => 'nsusu ihu nwamba nwere mmechi anya',
    '🙀' => 'ihu ike ọgwụgwụ nwamba',
    '😿' => 'ihu akwa nwamba',
    '😾' => 'na-asụpụta ọnụ nwamba',
    '🙈' => 'ahụkwala-ènwè-ọjọọ',
    '🙉' => 'anụkwala-ènwè-ọjọọ',
    '🙊' => 'ekwukwala-ènwè-ọjọọ',
    '💌' => 'leta ihụ̀nanya',
    '💘' => 'obi nwere akụ',
    '💝' => 'obi nwere ọmarịcha eriri',
    '💖' => 'obi mmuke',
    '💗' => 'obi na-eto eto',
    '💓' => 'obi na-akụ akụ',
    '💞' => 'obi na-agba okirikiri',
    '💕' => 'obi àbụọ',
    '💟' => 'ịchọ mma obi',
    '❣' => 'nnukwu obi ntimkpu',
    '💔' => 'obi ntiwa',
    '❤' => 'obi ọbara',
    '🩷' => 'obi na-acha pink',
    '🧡' => 'obi orenji',
    '💛' => 'obi na-acha èdò èdò',
    '💚' => 'obi na-acha ndụ ndụ',
    '💙' => 'obi na-acha anụnụ anụnụ',
    '🩵' => 'obi na-acha blụ',
    '💜' => 'obi na-acha pọpụl',
    '🤎' => 'obi na-acha brown',
    '🖤' => 'obi ojii',
    '🩶' => 'obi na-acha gré',
    '🤍' => 'obi na-acha ọcha',
    '💋' => 'akara nsusu',
    '💯' => 'pọịntị narị gasị',
    '💢' => 'akara iwe',
    '🫯' => 'igwe ojii ọgụ',
    '💥' => 'nkụkọrịta',
    '💫' => 'ajụ',
    '💦' => 'ntụpụta okpoofù',
    '💨' => 'na-apụ apụ',
    '🕳' => 'ọnụ oghere',
    '💬' => 'blonblon okwu',
    '🗨' => 'blonblo okwu akaèkpè',
    '🗯' => 'blonblo iwe akanri',
    '💭' => 'blonblon echichè',
    '💤' => 'ZZZ',
    '👋' => 'na-efe aka',
    '🤚' => 'azụ aka nke ewelitere elu',
    '🖐' => 'welitere aka elu n’iji mgbasa mkpịsịaka',
    '✋' => 'aka ewèliri',
    '🖖' => 'ajọọ èkèle',
    '🫱' => 'aka nri',
    '🫲' => 'uzo aka ekpe',
    '🫳' => 'aka l’ara ala',
    '🫴' => 'aka l’ara elu',
    '🫷' => 'aka na-aga n’aka ekpe',
    '🫸' => 'uzo aka nri na-kwaa aka',
    '👌' => 'AKA dị mma',
    '🤌' => 'itu mkpịsị aka',
    '🤏' => 'tuo aka',
    '✌' => 'aka mmeri',
    '🤞' => 'mkpịakọ mkpịsịaka gasị',
    '🫰' => 'aka',
    '🤟' => 'ogbugbu-ịhụnanya',
    '🤘' => 'akara nke mpi gasị',
    '🤙' => 'kpọọ mụ aka',
    '👈' => 'àzụaka na-arụ aka akaèkpè',
    '👉' => 'àzụaka na-arụ aka akanri',
    '👆' => 'àzụaka na-arụ aka n’elu',
    '🖕' => 'mkpịsịaka etiti',
    '👇' => 'àzụaka na-arụ aka n’ala',
    '☝' => 'na-arụ aka n’elu',
    '🫵' => 'mkpịsị aka na-atu na mmadu',
    '👍' => 'oboaka n’elu',
    '👎' => 'oboaka n’ala',
    '✊' => 'aka ọkpọ ewelitere',
    '👊' => 'aka ọkpọ na-abịa abịa',
    '🤛' => 'aka ọkpọ chewere-akaèkpè',
    '🤜' => 'aka ọkpọ chewere-akanri',
    '👏' => 'na-akụ aka',
    '🙌' => 'aka ndị eweliri elu',
    '🫶' => 'obi aka',
    '👐' => 'aka mepere emepe',
    '🤲' => 'nchịkọta aka abụọ ọnụ',
    '🤝' => 'nkwenaka',
    '🙏' => 'aka ejikọrọ ọnụ',
    '✍' => 'aka na-ede ihe',
    '💅' => 'nteji mbọaka',
    '🤳' => 'selfi',
    '💪' => 'akpụ̀ aka',
    '🦾' => 'aka igwe',
    '🦿' => 'ukwu ụkwụ',
    '🦵' => 'ụkwụ',
    '🦶' => 'ukwu',
    '👂' => 'nti',
    '🦻' => 'nti na hearing aid',
    '👃' => 'imi',
    '🧠' => 'ụbụrụ',
    '🫀' => 'obi',
    '🫁' => 'nkuume',
    '🦷' => 'eze',
    '🦴' => 'ọkpụkpụ',
    '👀' => 'anya gasị',
    '👁' => 'anya',
    '👅' => 'ire',
    '👄' => 'ọnụ',
    '🫦' => 'egbugbere ọnụ',
    '👶' => 'nwata ọhụrụ',
    '🧒' => 'nwata',
    '👦' => 'nwa nwoke',
    '👧' => 'nwata nwaanyị',
    '🧑' => 'okenye',
    '👱' => 'Onye-isi awọ',
    '👨' => 'nwoke',
    '🧔' => 'onye nwere ahụọnụ',
    '👩' => 'nwanyị',
    '🧓' => 'kara dị okenye',
    '👴' => 'okenye nwoke',
    '👵' => 'okenye nwaanyị',
    '🙍' => 'onye na-agbarụ ihu',
    '🙎' => 'onye na-asọpụta ọnụ',
    '🙅' => 'onye na-egosipta MBÀ',
    '🙆' => 'onye na-egosipta Ọ DỊ MMA',
    '💁' => 'onye na-ehulata aka',
    '🙋' => 'onye na-ewelite aka',
    '🧏' => 'onye ntị chiri',
    '🙇' => 'onye na-ehulata ala',
    '🤦' => 'onye na-ezo ihu ya èzo',
    '🤷' => 'onye ngosipụta nhatanha aka',
    '👮' => 'onye uweojii',
    '🕵' => 'nchọpụta',
    '💂' => 'nche',
    '🥷' => 'ninja',
    '👷' => 'onye ọrụ ụzọ',
    '🫅' => 'onye ji okpueze',
    '🤴' => 'ọkparaeze',
    '👸' => 'àdaeze',
    '👳' => 'onye yi turban',
    '👲' => 'nwoke kpu okpu ndị China',
    '🧕' => 'nwanyị nwere ichafùisi',
    '🤵' => 'nwoke yi uwe agbamụakwụkwọ',
    '👰' => 'nwanyị na-agba akwụkwọ yi akwa nkochi ihu',
    '🤰' => 'nwanyị dị ime',
    '🫃' => 'nwoke di ime',
    '🫄' => 'onye di ime',
    '🤱' => 'enyemụara',
    '👼' => 'mụo ọma nwata ọhụrụ',
    '🎅' => 'Nna Ekeresìmesi',
    '🤶' => 'Nne Ekeresìmesi',
    '🦸' => 'dike',
    '🦹' => 'onye ọjọọ',
    '🧙' => 'onye abrakatabra',
    '🧚' => 'akụkọ',
    '🧛' => 'ọmị ọbara',
    '🧜' => 'onyewọta',
    '🧝' => 'elfụ',
    '🧞' => 'nwa mmegbu',
    '🧟' => 'onye nwụrụ anwụ na-aga ije',
    '🧌' => 'ihe na-eyi egwu',
    '🫈' => 'anụ nwere ajị',
    '💆' => 'onye na-anata ozi',
    '💇' => 'Onye na-enweta ọkpụkpụisi',
    '🚶' => 'onye na-aga ije',
    '🧍' => 'onye na-e guzo',
    '🧎' => 'onye gbu ikpere n’ala',
    '🏃' => 'onye na-agba ọsọ',
    '💃' => 'nwanyị na-agba egwu',
    '🕺' => 'nwoke na-agba egwu',
    '🕴' => 'nwoke yi akwà azụmaahịa na-efe n’elu',
    '👯' => 'ndị mmadụ ndị na-agba egwu nwere nti ogologo',
    '🧖' => 'onye nọ n’ụlọ okpomọọkụ mmiri ahụ',
    '🧗' => 'onye na-arị elu',
    '🤺' => 'onye na-eme egwuregwu akparakpa mma',
    '🏇' => 'egwuregwu inyinyà',
    '⛷' => 'onye egwuregwu mkpọda ugwu',
    '🏂' => 'onye egwuregwu akụrụ mmiri',
    '🏌' => 'onye na-akụ gọfụ',
    '🏄' => 'onye egwuregwu oshimiri',
    '🚣' => 'onye na-akwọ ụgbọ epepe',
    '🏊' => 'onye na-egwu mmiri',
    '⛹' => 'onye na-atụ bọolụ',
    '🏋' => 'onye na-ebuli ihe elu',
    '🚴' => 'Onye egwuregwu ịgba Igwe',
    '🚵' => 'onye egwuregwu ịrị ugwu',
    '🤸' => 'onye na-eme egwuntụgharị onwe',
    '🤼' => 'ndị mmadụ ndị na-agba m̀gba',
    '🤽' => 'onye na-egwu egwuregwu bọọlụ mmiri',
    '🤾' => 'onye na-egwu egwuregwu bọọlụ aka',
    '🤹' => 'onye na-eme egwuregwu aka',
    '🧘' => 'onye chịkọrọ ụkwụ ya abụọ ọnụ',
    '🛀' => 'onye na-asa ahụ',
    '🛌' => 'onye nọ n’àkwà',
    '👭' => 'ụmụ nwanyị abụọ jikọtara aka',
    '👫' => 'nwoke na nwaanyị jikọtara aka',
    '👬' => 'ụmụ nwoke abụọ jikọtara aka',
    '💏' => 'nsusò ọnụ',
    '💑' => 'di na nwunye nwere obi',
    '🗣' => 'isi na-ekwu okwu',
    '👤' => 'isi na ubu mmadụ atụrụ atụ dị na ọchịchịrị',
    '👥' => 'isi na ubu mmadụ atụrụ atụ dị na ọchịchịrị gasị',
    '🫂' => 'ndi na-makọ',
    '👪' => 'ezinaụlọ',
    '👣' => 'ụzọụkwụ gasị',
    '🫆' => 'mbipụta aka',
    '🦰' => 'ntutu isi uhie',
    '🦱' => 'ntutu isi gbakọrọ agbakọ',
    '🦳' => 'ntutu isi ocha',
    '🦲' => 'isi nkwọcha',
    '🐵' => 'ihu ènwè',
    '🐒' => 'ènwè',
    '🦍' => 'ọzọdịmgba',
    '🦧' => 'orangutan',
    '🐶' => 'ihu nkịta',
    '🐕' => 'nkịta',
    '🦮' => 'nkịta ndumoodu',
    '🐩' => 'nkịta ajị ajị',
    '🐺' => 'nkịta ọhịa',
    '🦊' => 'ihu ihu nkịta ọhịa na-awụ̀ ọsọ',
    '🦝' => 'akukonta',
    '🐱' => 'ihu nwaologbo',
    '🐈' => 'nwaologbo',
    '🦁' => 'ọdụm',
    '🐯' => 'ihu taịga',
    '🐅' => 'taịga',
    '🐆' => 'agụ àgwagwà',
    '🐴' => 'ihu ịnyịnya',
    '🫎' => 'anụ ọhịa',
    '🫏' => 'inyinya ibu',
    '🐎' => 'inyinya',
    '🦄' => 'ihu inyinya nwere mpi',
    '🦓' => 'zebra',
    '🦌' => 'Atụ́',
    '🦬' => 'bison',
    '🐮' => 'ihu ehi',
    '🐂' => 'oke ehi',
    '🐃' => 'ehi ọhịa mmiri',
    '🐄' => 'nne ehi',
    '🐷' => 'ihu ezì',
    '🐖' => 'ezì',
    '🐗' => 'oke ezì',
    '🐽' => 'imi ezì',
    '🐏' => 'èbùlà',
    '🐑' => 'nne atụrụ',
    '🐐' => 'ewu',
    '🐪' => 'inyinya ọ̀zàrà',
    '🐫' => 'inyinya ọ̀zàrà nwere mkpumkpu abụọ',
    '🦙' => 'ilama',
    '🦒' => 'giraafụ',
    '🐘' => 'enyi',
    '🦣' => 'mammot',
    '🦏' => 'ehi ọhịa otu mpì',
    '🦛' => 'hipopotamos',
    '🐭' => 'ihu obere oke',
    '🐁' => 'obere oke',
    '🐀' => 'oke',
    '🐹' => 'òke bèkee',
    '🐰' => 'ihu òke bèkee nti ogologo',
    '🐇' => 'òke bèkee nti ogologo',
    '🐿' => 'uzè',
    '🦫' => 'nwambē',
    '🦔' => 'mpama',
    '🦇' => 'ụsụ',
    '🐻' => 'biya',
    '🐨' => 'anụmanụ koala',
    '🐼' => 'ihu panda',
    '🦥' => 'sloth',
    '🦦' => 'otter',
    '🦨' => 'skunk',
    '🦘' => 'kangaruu',
    '🦡' => 'ewi',
    '🐾' => 'mbipụta nzọụkwụ anụmanụ',
    '🦃' => 'torotoro',
    '🐔' => 'ọkụkọ',
    '🐓' => 'àkwamakwa',
    '🐣' => 'nwa ọkụkụ na-apụta n’àkwa',
    '🐤' => 'nwa ọkụkọ',
    '🐥' => 'chewe ihu na nwa ọkụkọ',
    '🐦' => 'nnụnụ',
    '🐧' => 'nnụnụ sno',
    '🕊' => 'nduri',
    '🦅' => 'ugo',
    '🦆' => 'udele igbo',
    '🦢' => 'ọbọgwụ',
    '🦉' => 'ikwikwi',
    '🦤' => 'dodo',
    '🪶' => 'nku',
    '🦩' => 'flamingo',
    '🦚' => 'okeopka',
    '🦜' => 'icheku',
    '🪽' => 'nkunnunu',
    '🪿' => 'ọgazị',
    '🐸' => 'awọ',
    '🐊' => 'agụiyi',
    '🐢' => 'mbè',
    '🦎' => 'ngwere',
    '🐍' => 'agwọ',
    '🐲' => 'ihu dragọn',
    '🐉' => 'dragọn',
    '🦕' => 'saropọd',
    '🦖' => 'T-Rex',
    '🐳' => 'nnukwu azụ whelụ na-agbọpụ mmiri',
    '🐋' => 'nnukwu azụ whelụ',
    '🐬' => 'nnukwu azụ dọlphịnụ',
    '🫍' => 'azụ ọka',
    '🦭' => 'nnukwu anụ mmiri',
    '🐟' => 'azụ̀',
    '🐠' => 'azụ̀ mmiri',
    '🐡' => 'azụ̀ nwere ike itóó abụba',
    '🦈' => 'akụm',
    '🐙' => 'ọktopus',
    '🐚' => 'okpokoro okirikiri',
    '🪸' => 'koral',
    '🪼' => 'azụjelii',
    '🦀' => 'nshịkọ',
    '🦞' => 'oporo',
    '🦐' => 'ayịya',
    '🦑' => 'Azụ sụkwịdị',
    '🦪' => 'oporo gbarampi',
    '🐌' => 'ejù',
    '🦋' => 'mbubara',
    '🐛' => 'Chinchi',
    '🐜' => 'agbịsị',
    '🐝' => 'aṅụ́ mmanụaṅụ',
    '🪲' => 'ebe',
    '🐞' => 'ebe nwanyi',
    '🦗' => 'ụ̀kpàlà',
    '🪳' => 'ochicha',
    '🕷' => 'ududo',
    '🕸' => 'ọnyà ududo',
    '🦂' => 'akpị',
    '🦟' => 'anwụnta',
    '🪰' => 'ofufe',
    '🪱' => 'irighiri',
    '🦠' => 'microbe',
    '💐' => 'ọyọkọ ifuru',
    '🌸' => 'nchapụta cheri',
    '💮' => 'okooko ọcha',
    '🪷' => 'lotus',
    '🏵' => 'akwụkwọ ndịka okooko',
    '🌹' => 'rozu',
    '🥀' => 'okooko kpọnwụrụ akpọnwụ',
    '🌺' => 'okooko bibuskus',
    '🌻' => 'okookoanwụ',
    '🌼' => 'nchapụta',
    '🌷' => 'tulip',
    '🪻' => 'hyacinth',
    '🌱' => 'mkpụrụ',
    '🪴' => 'ite osisi',
    '🌲' => 'osisi na-adị ndụ kwa mgbe',
    '🌳' => 'osisi nke dị ụtọ',
    '🌴' => 'osisi nkwụ',
    '🌵' => 'kaktus',
    '🌾' => 'ngwù nke òsikapa',
    '🌿' => 'mgbọrọgwụ̀',
    '☘' => 'akwụkwọnri shamrock',
    '🍀' => 'akwụkwọnri mgba anọ',
    '🍁' => 'akwụkwọnri mgbe ise',
    '🍂' => 'akwụkwọ dara àdà',
    '🍃' => 'akwụkwọ na-efesasi n’ikukù',
    '🪹' => 'akwụ efu',
    '🪺' => 'akwụ nwere akwa',
    '🍄' => 'ero',
    '🪾' => 'osisi na-enweghị akwụkwọ',
    '🍇' => 'grepụ gasị',
    '🍈' => 'mkpụrụosisi melọn',
    '🍉' => 'mkpụrụosisi mmirimelọn',
    '🍊' => 'Tangerinụ',
    '🍋' => 'oroma lemọn',
    '🍌' => 'unerè',
    '🍍' => 'ọkwụrụ bekee',
    '🥭' => 'mango',
    '🍎' => 'apùl ọbara ọbara',
    '🍏' => 'apùl ndụ ndụ',
    '🍐' => 'ùbe bèkee',
    '🍑' => 'ụtụ',
    '🍒' => 'ụdara gasị',
    '🍓' => 'strawberi',
    '🫐' => 'bluberị',
    '🥝' => 'mkpụrụosisi kiwi',
    '🍅' => 'otuboala',
    '🫒' => 'olive',
    '🥥' => 'akị bèkee',
    '🥑' => 'ube bèkee',
    '🍆' => 'mkpụrụosisi ndịka akwa',
    '🥔' => 'ji bèkee',
    '🥕' => 'Karọt',
    '🌽' => 'ogbo nke ọkà',
    '🌶' => 'ọsọ ọkụ',
    '🫑' => 'ose ose',
    '🥒' => 'mkpụrụakwụkwọnri',
    '🥬' => 'akwukwo nri',
    '🥦' => 'akwụkwọnri bèkee',
    '🧄' => 'galiki',
    '🧅' => 'yabasị',
    '🥜' => 'ahụekere',
    '🫘' => 'agwa',
    '🌰' => 'chestnọt',
    '🫚' => 'mgbọrọgwụ ginger',
    '🫛' => 'azama',
    '🫜' => 'akwụkwọ nri mgbọrọgwụ',
    '🍞' => 'achịcha nkịtị',
    '🥐' => 'achịcha akpụrụ akpụ',
    '🥖' => 'achịcha ogologo',
    '🫓' => 'achịcha dị larịị',
    '🥨' => 'achịcha ekere eke',
    '🥯' => 'achịcha',
    '🥞' => 'achịchanri gasị',
    '🧇' => 'waffle',
    '🧀' => 'achịcha ụtọ ebere ebè',
    '🍖' => 'anụ n’ọkpụkpụ',
    '🍗' => 'ụkwụ ụlọ ọkụkọ',
    '🥩' => 'bepụta anụ',
    '🥓' => 'nri anụ',
    '🍔' => 'achịcha nwere akwa',
    '🍟' => 'ènyèrè eye frenchị',
    '🍕' => 'pizzà',
    '🌭' => 'achịchanri anụ',
    '🥪' => 'nri achịcha na anụ',
    '🌮' => 'achịcha anụ',
    '🌯' => 'achịcha nrianụ na akwụkwọnri',
    '🫔' => 'tamale',
    '🥙' => 'achịcha akwụkwọnri nwụrụ anwụ',
    '🧆' => 'falafel',
    '🥚' => 'àkwa',
    '🍳' => 'na-esi nri',
    '🥘' => 'efere nri dabara n’ime',
    '🍲' => 'itè nri',
    '🫕' => 'fondue',
    '🥣' => 'efere ofe na ngaji',
    '🥗' => 'saladị ndụ ndụ',
    '🍿' => 'ọkà',
    '🧈' => 'bọta',
    '🧂' => 'nnu',
    '🥫' => 'nri etinyere na kanụ̀',
    '🍱' => 'efere ntinye nri',
    '🍘' => 'achịcha òsìkapa',
    '🍙' => 'òsìkapa àkpụrụakpụ',
    '🍚' => 'òsìkapa esiri èsi',
    '🍛' => 'òsìkapa nwere ofe',
    '🍜' => 'ite na-asụ asụ',
    '🍝' => 'òsìkapa ogologo',
    '🍠' => 'ji bèkee ahụrụ àhụ́',
    '🍢' => 'efere nri',
    '🍣' => 'àchịcha nwere akwa etere ofe',
    '🍤' => 'ayịya eghèrè èghe',
    '🍥' => 'àchịcha azụ nwere nka okirikiri',
    '🥮' => 'achicha ọnwa',
    '🍡' => 'nri dango',
    '🥟' => 'nri achịcha',
    '🥠' => 'kuki achịcha',
    '🥡' => 'igbe were lawa',
    '🍦' => 'ihe nracha dị nrọ',
    '🍧' => 'ihe aracha na-akpụchara akpụcha',
    '🍨' => 'ihe nracha',
    '🍩' => 'donọt',
    '🍪' => 'kuki',
    '🎂' => 'àchịcha ncheta ọmụmụ',
    '🍰' => 'àchịchaobere',
    '🧁' => 'àchịcha iko',
    '🥧' => 'achịcha na anụ',
    '🍫' => 'ogwe chọkọleti',
    '🍬' => 'kandị',
    '🍭' => 'Lọlịpọpụ',
    '🍮' => 'akamụ bèkee',
    '🍯' => 'ite mmanụ aṅụ',
    '🍼' => 'karama nwata ọhụrụ',
    '🥛' => 'Iko nkụwa Nke Mmiri ara Ehi',
    '☕' => 'ihe ọṅụṅụ dị ọkụ',
    '🫖' => 'ite tii',
    '🍵' => 'iko na-enweghị aka',
    '🍶' => 'maghaa',
    '🍾' => 'karama nwere mkpuchi',
    '🍷' => 'iko nkụwa',
    '🍸' => 'iko mmanya ọgbụgbụ',
    '🍹' => 'mmanya ebe okpomọọkụ',
    '🍺' => 'iko mmanya biya',
    '🍻' => 'na-akụkọta iko biya',
    '🥂' => 'Na-akụkọta iko gasị',
    '🥃' => 'ikọ nkụwa',
    '🫗' => 'na-agbapụta mmiri',
    '🥤' => 'iko nwere osisi rọba ọmịmị',
    '🧋' => 'tii ufufo',
    '🧃' => 'igbe ihe ọṅụṅụ',
    '🧉' => 'mate',
    '🧊' => 'aiz',
    '🥢' => 'osisi nri',
    '🍽' => 'ngaji ndụdụ na mma na efere',
    '🍴' => 'ndụdụ na mma',
    '🥄' => 'ngaji',
    '🔪' => 'mma usekwu',
    '🫙' => 'ite',
    '🏺' => 'iko nwere aka àbụọ',
    '🌍' => 'ụwa na-egosi Europe-Afrika',
    '🌎' => 'ụwa dum na-egosi Amerikansị',
    '🌏' => 'ụwa dum na-egosi Asia-Australia',
    '🌐' => 'ụwa nwere meridiansị',
    '🗺' => 'maapụ ụwa',
    '🗾' => 'mappụ nke Japan',
    '🧭' => 'kọmpas',
    '🏔' => 'ugwu akụrụ mmiri-kpuchiri',
    '⛰' => 'ugwu',
    '🛘' => 'oké ọdịda aja',
    '🌋' => 'mgbawa ugwu',
    '🗻' => 'ugwu fuji',
    '🏕' => 'ọgbakọ nzuruike',
    '🏖' => 'akụkụ mmiri nwere umbrali',
    '🏜' => 'ọ̀zàrà',
    '🏝' => 'àgwaetiti ọ̀zàrà',
    '🏞' => 'ọdụ̀ obodo',
    '🏟' => 'ama ọgbakọ obodo',
    '🏛' => 'ụlọ klasịkalụ',
    '🏗' => 'ọrụ arụmụụlọ',
    '🧱' => 'brik',
    '🪨' => 'okwute',
    '🪵' => 'osisi',
    '🛖' => 'ụlọ akịrịka',
    '🏘' => 'ụlọ gasị',
    '🏚' => 'ụlọ dara ada',
    '🏠' => 'ụlọ',
    '🏡' => 'ụlọ nwere ubì',
    '🏢' => 'ụlọ ụlọọrụ',
    '🏣' => 'ụlọ nzipu ozi Ndị Japan',
    '🏤' => 'ụlọ nzipu ozi',
    '🏥' => 'ụlọ ọgwụ',
    '🏦' => 'ụlọakụ̀',
    '🏨' => 'ụlọ nkwari',
    '🏩' => 'ụlọ nkwari ịhụnanya',
    '🏪' => 'ụlọ ahịa ihe ụlọ',
    '🏫' => 'ụlọakwụkwọ',
    '🏬' => 'ngalaba ụlọ ahịa',
    '🏭' => 'ụlọ ọrụ',
    '🏯' => 'nnukwu ụlọ Ndị Japan',
    '🏰' => 'nnukwu ụlọ',
    '💒' => 'àgbamụakwụkwọ',
    '🗼' => 'ụlọ elu Tokyo',
    '🗽' => 'Akpụrụakpụ nke Nnwereonwe',
    '⛪' => 'ụlọụkà',
    '🕌' => 'ụlọ ekpere ndị Alakụba',
    '🛕' => 'ulo hindu',
    '🕍' => 'ụlọ ekpere',
    '⛩' => 'ụlọ ekpere shinto',
    '🕋' => 'kaaba',
    '⛲' => 'ebe mgbapụta mmiri',
    '⛺' => 'ụlọ akwà',
    '🌁' => 'igirigi obere',
    '🌃' => 'abalị nwere kpakpando',
    '🏙' => 'akaranhụcha obodo',
    '🌄' => 'ọwụwa anyanwụ n’elu ugwu',
    '🌅' => 'ọwụwa anyawụ',
    '🌆' => 'ihe nkiri obodo n’abalị',
    '🌇' => 'ọdịda-anyanwụ',
    '🌉' => 'àkwà mmiri n’abalị',
    '♨' => 'mmiri ọkụ',
    '🎠' => 'inyịnya igwe okirikiri',
    '🛝' => 'ihe egwuregwu mmida',
    '🎡' => 'ụkwụ ferris',
    '🎢' => 'igwe egwuregwu mkpọda',
    '💈' => 'osisi onye ọkpụ isi',
    '🎪' => 'ụlọ akanya ihe nkiri',
    '🚂' => 'igwe ọgịga',
    '🚃' => 'ụgbọnta okporoigwe',
    '🚄' => 'ụgbọokporoigwe oke ọsọ',
    '🚅' => 'ụgbọokporoigwe oke ọsọ nwere imi mgbọ',
    '🚆' => 'ụgbọ okporoigwe',
    '🚇' => 'Metiro',
    '🚈' => 'nwa obere ọkụ okporoigwe',
    '🚉' => 'ọdụ ụgbọ',
    '🚊' => 'tramụ',
    '🚝' => 'otù okporoigwe',
    '🚞' => 'ugwu okporoigwe',
    '🚋' => 'ụgbọala ogologo tramụ',
    '🚌' => 'ụgbọala ogologo',
    '🚍' => 'ụgbọala ogologo na-apụta apụta',
    '🚎' => 'ogologo ụgbọala',
    '🚐' => 'obere ụgbọala',
    '🚑' => 'ụgbọala ụlọọgwụ̀',
    '🚒' => 'injin ọkụ',
    '🚓' => 'ụgbọala ndị uweojii',
    '🚔' => 'ụgbọala ndị uweojii na-apụta apụta',
    '🚕' => 'ụgbọala njem',
    '🚖' => 'ụgbọala njem na-apụta apụta',
    '🚗' => 'ụgbọala',
    '🚘' => 'ụgbọala na-apụta apụta',
    '🚙' => 'ụgbọala ọkwụ̀ ọtọ ekène eze',
    '🛻' => 'gwongworo ozi',
    '🚚' => 'ụgbọala nnyefe ibu',
    '🚛' => 'nnukwu ụgbọala ahàziri nke ọma',
    '🚜' => 'ụgbọalaugbo',
    '🏎' => 'ụgbọala na-agba osọ egwuregwu',
    '🏍' => 'ọgbaatumtum',
    '🛵' => 'igwe ụgbọ egwuregwu',
    '🦽' => 'oche nkwagharị manual',
    '🦼' => 'oche nkwagharị ji motor',
    '🛺' => 'keke napep',
    '🚲' => 'igwe',
    '🛴' => 'igwe egwuregwu',
    '🛹' => 'skatebọọdụ',
    '🛼' => 'akpụkpọ ụkwụ nwere wiil',
    '🚏' => 'ebe nkwụsị ụgbọ',
    '🛣' => 'ụzọụgbọala',
    '🛤' => 'ụzọ okporoigwe',
    '🛢' => 'mmanụ ịgba',
    '⛽' => 'igwe mgbanye mmanụ',
    '🛞' => 'ukwu ụgbọala',
    '🚨' => 'ọkụ ụgbọala ndị uwe ojii',
    '🚥' => 'ọkụ ngafè ụgbọala uhie',
    '🚦' => 'ọkụ ngafè ụgbọala kwụọtọ',
    '🛑' => 'akara kwụsị',
    '🚧' => 'ọrụụzọ',
    '⚓' => 'mkpọrọ',
    '🛟' => 'rọba ọkirikiri mmiri',
    '⛵' => 'egwuregwu ụgbọmmiri',
    '🛶' => 'ụgbọ epepe',
    '🚤' => 'ụgbọmmiri oke ọsọ',
    '🛳' => 'ụgbọmmiri ndị njem',
    '⛴' => 'ụgbọ mmiri njem',
    '🛥' => 'ụgbọmmiri ụgbọala',
    '🚢' => 'ụgbọmmiri',
    '✈' => 'ụgbọelu',
    '🛩' => 'obere ụgbọelu',
    '🛫' => 'oge ọpụpụ ụgbọelu',
    '🛬' => 'oge mbata ụgbọelu',
    '🪂' => 'parachuutu',
    '💺' => 'oche ụgbọelu',
    '🚁' => 'ụgbọelu nta',
    '🚟' => 'nkwụsị okporoigwe',
    '🚠' => 'ụgwu ụzọwaya',
    '🚡' => 'elu obere okporoigwe',
    '🛰' => 'satịlịtị',
    '🚀' => 'ụgbọelu ọnwa',
    '🛸' => 'ihe na-efe efe',
    '🛎' => 'mgbịrịgba igweibu',
    '🧳' => 'akpa',
    '⌛' => 'ngwaoge',
    '⏳' => 'ugogbe oge emechabeghị',
    '⌚' => 'elekere aka',
    '⏰' => 'elekere mgbaama',
    '⏱' => 'elekerenkwụsị',
    '⏲' => 'elekere ngụoge',
    '🕰' => 'elekere nkwụrụonwe',
    '🕛' => 'elekere iri na abụọ',
    '🕧' => 'elekere iri na abụọ- ọkara',
    '🕐' => 'otu elekere',
    '🕜' => 'elekere mbụ-ọkara',
    '🕑' => 'elekere abụọ',
    '🕝' => 'elekere abụọ-ọkara',
    '🕒' => 'elekere atọ',
    '🕞' => 'elekere atọ-ọkara',
    '🕓' => 'elekere anọ',
    '🕟' => 'elekere anọ-ọkara',
    '🕔' => 'elekere ise',
    '🕠' => 'elekere ise-ọkara',
    '🕕' => 'elekere isii',
    '🕡' => 'elekere isii-ọkara',
    '🕖' => 'elekere asaa',
    '🕢' => 'elekere asaa-ọkara',
    '🕗' => 'elekere asatọ',
    '🕣' => 'elekere asatọ-ọkara',
    '🕘' => 'elekere itoolu',
    '🕤' => 'elekere itoolu-ọkara',
    '🕙' => 'elekere iri',
    '🕥' => 'elekere iri-ọkara',
    '🕚' => 'elekere iri na otù',
    '🕦' => 'elekere iri na otù-ọkara',
    '🌑' => 'ọnwa ọhụrụ',
    '🌒' => 'imelite ọnwa gburu uhie',
    '🌓' => 'ọnwa mbụ nke mmalite-afọ',
    '🌔' => 'ọnwa na-achawapụta ọkara ọnwa',
    '🌕' => 'ọnwa zuru òkè',
    '🌖' => 'imelata ọnwa ọkara',
    '🌗' => 'ọnwa ikpeazu nke ọgwụgwụ-afọ',
    '🌘' => 'imelata ọnwa gburu uhie',
    '🌙' => 'ọnwa elu-ugwu',
    '🌚' => 'ihu ọnwa ọhụrụ',
    '🌛' => 'ọnwa mbụ nke mmalite-afọ nwere ihu',
    '🌜' => 'ọnwa ikpeazu nke ọgwụgwụ-afọ nwere ihu',
    '🌡' => 'tamomịta',
    '☀' => 'anyanwụ',
    '🌝' => 'ọnwa zuru òkè nwere ihu',
    '🌞' => 'anyanwụ nwere ihu',
    '🪐' => 'mbara ụwa nwere okirikiri',
    '⭐' => 'kpakpando ọcha',
    '🌟' => 'kpakpando na-amụke amụke',
    '🌠' => 'Kpakpando na-ada ada',
    '🌌' => 'ụzọ igwe kpakpando',
    '☁' => 'urukpu',
    '⛅' => 'anyanwụ n’àzụ urukpu',
    '⛈' => 'urukpu nwere àmụ̀mà na mmiri òzùzò',
    '🌤' => 'anyanwụ n’àzụ obere urukpu',
    '🌥' => 'anyanwụ n’àzụ nnukwu urukpu',
    '🌦' => 'anyanwụ n’àzụ urukpu mmiri òzùzò',
    '🌧' => 'urukpu nwere mmiri òzùzò',
    '🌨' => 'urukpu nwere akwụrụ mmiri',
    '🌩' => 'urukpu nwere àmụ̀mà',
    '🌪' => 'ajọọ ìkùkù',
    '🌫' => 'igirigi nnukwu',
    '🌬' => 'ihu ìkùkù',
    '🌀' => 'oke ìkùkù okirikiri',
    '🌈' => 'egwurugwu',
    '🌂' => 'ụmbrali mechiri emechi',
    '☂' => 'ụmbrali',
    '☔' => 'ụmbrali na-atụsị mmiri',
    '⛱' => 'ụmbrali nọ n’ala',
    '⚡' => 'akara volteji dị elu',
    '❄' => 'nchakaakụrụ mmiri igwe',
    '☃' => 'nwoke akụrụmmiri igwe',
    '⛄' => 'nwoke akụ mmiri igwe na-enweghị akụ mmiri igwe',
    '☄' => 'ire ọkụ igwe',
    '🔥' => 'ọkụ',
    '💧' => 'ntụsa',
    '🌊' => 'ìkùkù mmiri',
    '🎃' => 'Jack-o-lantern',
    '🎄' => 'osisi Ekeresìmesì',
    '🎆' => 'ọrụọkụ',
    '🎇' => 'ihe icheku ọkụ',
    '🧨' => 'ọkụ ọkụ',
    '✨' => 'icheku ọkụ gasị',
    '🎈' => 'Blonblo',
    '🎉' => 'ihe mmapụta erimeri',
    '🎊' => 'bọọlụ kọnfeti',
    '🎋' => 'osisi tanabata',
    '🎍' => 'ọchọ mma ukwu osisi',
    '🎎' => 'dọlụ ndị Japan',
    '🎏' => 'ọkọlọtọ azụ iyi',
    '🎐' => 'ìkùkù ndakọrịta ụda',
    '🎑' => 'emume nlele ọnwa',
    '🧧' => 'envelopu uhie',
    '🎀' => 'ribọn',
    '🎁' => 'onyinye ekere èke',
    '🎗' => 'ihe ncheta ribọn',
    '🎟' => 'tiketi nnabata gasị',
    '🎫' => 'tiketi',
    '🎖' => 'ihe nrite iheolu ndị agha',
    '🏆' => 'iko mmeri',
    '🏅' => 'iheolu mmeri',
    '🥇' => 'iheolu mmeri 1st',
    '🥈' => 'iheolu mmeri 2nd',
    '🥉' => 'iheolu mmeri 3rd',
    '⚽' => 'bọọlụ egwuregwu',
    '⚾' => 'bọọlụ nkụosisi',
    '🥎' => 'bọọlụ dị nro',
    '🏀' => 'bọọlụ èkète',
    '🏐' => 'bọọlụaka',
    '🏈' => 'bọọlụụkwụ Amerikan',
    '🏉' => 'bọọlụụkwụ rugby',
    '🎾' => 'tenis',
    '🥏' => 'efere na-efe efe',
    '🎳' => 'egwuregwu ịkpọ bọọlụ',
    '🏏' => 'egwuregwu kriketi',
    '🏑' => 'họkị fild',
    '🏒' => 'họkị ịzị',
    '🥍' => 'lakrọs',
    '🏓' => 'egwuregwu ping pong',
    '🏸' => 'egwuregwu badminton',
    '🥊' => 'Mgbanaka oti ọkpọ',
    '🥋' => 'akwà ndị kàrati',
    '🥅' => 'èkètè ọgba nche bọọlụ',
    '⛳' => 'ọkọlọtọ n’ọnụ oghere',
    '⛸' => 'egwuregwu ịzị',
    '🎣' => 'osisi àkọmaazụ̀',
    '🤿' => 'ihe nkpuchi mmiri',
    '🎽' => 'uwe elu eji agba ọsọ',
    '🎿' => 'egwuregwu mkpọda ugwu',
    '🛷' => 'ngwa nga n’akụrụ mmiri igwe',
    '🥌' => 'okwute eji akwọ ihe',
    '🎯' => 'gara ka atụ̀rụ̀',
    '🪀' => 'yo-yo',
    '🪁' => 'kitee',
    '🔫' => 'egbe mmiri',
    '🎱' => 'Poolu 8 bọọlụ',
    '🔮' => 'bọọlụ enyo',
    '🪄' => 'wand majiiki',
    '🎮' => 'egwuregwu vidio',
    '🕹' => 'ngwa egwuregwu kọmputa',
    '🎰' => 'igwe ntinye ihe',
    '🎲' => 'ọnwụ egwuregwu',
    '🧩' => 'ihe egwuregwu',
    '🧸' => 'ihe egwuregwu ụmụaka',
    '🪅' => 'piñata',
    '🪩' => 'egwu ugegbe',
    '🪆' => 'ntinye nwa bebi n’ime',
    '♠' => 'joka spedi',
    '♥' => 'egwuregwu joka ịhụnanya',
    '♦' => 'egwuregwu joka dịamọn',
    '♣' => 'egwuregwu joka klọb',
    '♟' => 'pọnu chess',
    '🃏' => 'kaadi joka',
    '🀄' => 'dragọn ọbara mahjong',
    '🎴' => 'kaadị okooko eji egwu egwu',
    '🎭' => 'na-egosipụta ihe ǹkà',
    '🖼' => 'fòto nwere fremụ',
    '🎨' => 'obosara osisi onye ǹkà',
    '🧵' => 'eriri',
    '🪡' => 'agịga eji akwa àkwà',
    '🧶' => 'eriri owu',
    '🪢' => 'akpụ',
    '👓' => 'ènyò gasị',
    '🕶' => 'ugogbeanya',
    '🥽' => 'enyo anya',
    '🥼' => 'uwe lab',
    '🦺' => 'uwe nchekwa',
    '👔' => 'mmaolu akwà',
    '👕' => 'akwa-t',
    '👖' => 'Jinsi',
    '🧣' => 'ichafù',
    '🧤' => 'mgbaaka gasị',
    '🧥' => 'kotu',
    '🧦' => 'sọọsụ',
    '👗' => 'uwe',
    '👘' => 'kimono',
    '🥻' => 'sari',
    '🩱' => 'otu uwe igwu mmiri',
    '🩲' => 'uwe ime',
    '🩳' => 'uwe ime ahu',
    '👙' => 'bikini',
    '👚' => 'akwà ụmụnwanyị',
    '🪭' => 'ofufe aka',
    '👛' => 'obere àkpà ntinye ego',
    '👜' => 'àgbankò n’aka',
    '👝' => 'àkpà njina n’aka',
    '🛍' => 'àkpà azụmaahịa gasị',
    '🎒' => 'àkpà akwụkwọ nkwọ̀ n’azụ',
    '🩴' => 'akpụkpọ ụkwụ',
    '👞' => 'akpụkpọụkwụ nwoke',
    '👟' => 'akpụkpọụkwụ eji àgba ọsọ',
    '🥾' => 'akpụkpọụkwụ ugwu',
    '🥿' => 'akpụkpọụkwụ di n’ala',
    '👠' => 'akpụkpọụkwụ pịrị ọnụ',
    '👡' => 'akpụkpọụkwụ nkechi ụmụnwanyị',
    '🩰' => 'akpụkpọụkwụ ballet',
    '👢' => 'akpụkpọụkwụ akpụkpọanụ ụmụnwanyị',
    '🪮' => 'ntutu isi',
    '👑' => 'òkpueze',
    '👒' => 'òkpu nwaanyị',
    '🎩' => 'òkpu dị elu',
    '🎓' => 'òkpu nzere',
    '🧢' => 'okpu edere ihe',
    '🪖' => 'okpu nke ogu',
    '⛑' => 'okpu igwe ndị ọrụ mgbapụta',
    '📿' => 'chapụleti ekpere',
    '💄' => 'ọtanjele mbiribeọnụ',
    '💍' => 'mgbaaka',
    '💎' => 'okwute mpụrụ iche',
    '🔇' => 'òkwù okwu emere-ògbì',
    '🔈' => 'òkwù okwu ụhàraụdà dị ala',
    '🔉' => 'òkwù okwu ụhàraụdà ndịna etiti',
    '🔊' => 'òkwù okwu ụhàraụdà dị elu',
    '📢' => 'ụda egwu',
    '📣' => 'igweokwu',
    '📯' => 'opi mkpọte',
    '🔔' => 'mgbịrịgba',
    '🔕' => 'mgbịrịgba nwere mgbawa',
    '🎼' => 'akara egwu',
    '🎵' => 'ederede ụdà-egwu',
    '🎶' => 'ederede ụdà-egwu gasị',
    '🎙' => 'igweokwu nkwụrụonwe ụlọegwu',
    '🎚' => 'ogo mkpọmbufè',
    '🎛' => 'njizi kọbụ gasị',
    '🎤' => 'igweokwu nkwụrụonwe',
    '🎧' => 'ekwentịisi',
    '📻' => 'redio',
    '🎷' => 'opi egwu',
    '🎺' => 'òpì ike',
    '🪊' => 'opi',
    '🪗' => 'akọdịọn',
    '🎸' => 'ụbọ',
    '🎹' => 'ụgbọọtụgwo ụdà-egwu',
    '🎻' => 'ụbọ nta',
    '🪕' => 'banjo',
    '🥁' => 'ìgbà',
    '🪘' => 'ogologo igba',
    '🪇' => 'marakas',
    '🪈' => 'ọjà',
    '🪉' => 'ụbọ akwara',
    '📱' => 'ekwentị kengaghari',
    '📲' => 'ekwentị kengaghari nwere ube',
    '☎' => 'ekwentị',
    '📞' => 'onye nnataozi ekwenti',
    '📟' => 'ozi ekwentị',
    '📠' => 'igwe ozi faasị',
    '🔋' => 'batrị',
    '🪫' => 'obere batrị',
    '🔌' => 'ihe nkwụnye latriki',
    '💻' => 'kọmpụtà nkunụkwụ',
    '🖥' => 'desktọọp kọmpụta',
    '🖨' => 'igwe mbipụta',
    '⌨' => 'ụgbọọtụgwo',
    '🖱' => 'nwambe kọmpụta',
    '🖲' => 'bọọlụtraakị',
    '💽' => 'diiski kọmpụta',
    '💾' => 'flọpi diiski',
    '💿' => 'diiski ọptịkal',
    '📀' => 'dvd',
    '🧮' => 'abakus',
    '🎥' => 'ihe nkiri igwefòto',
    '🎞' => 'fremụ ihe nkiri gasị',
    '📽' => 'ihe nkiri ahụ aja',
    '🎬' => 'ngwa nkụpụta ụda',
    '📺' => 'ihe onyonyo',
    '📷' => 'igwefòto',
    '📸' => 'igwefòto nwere ọkụ',
    '📹' => 'igwefòto vidio',
    '📼' => 'vidiokaseeti',
    '🔍' => 'ènyò mbawanye na-atụga akaekpe',
    '🔎' => 'ènyò mbawanye na-atụga akanri',
    '🕯' => 'kandụ̀l',
    '💡' => 'ọkụ bọlbụ',
    '🔦' => 'nchaọkụ',
    '🏮' => 'mpanaka akwụkwọ ọbara',
    '🪔' => 'lampu diya',
    '📔' => 'akwụkwọnoòtù nwere mkpuchi ichọ mma',
    '📕' => 'akwukwọ emechiri',
    '📖' => 'akwukwọ emepere',
    '📗' => 'akwukwọ ndụ ndụ',
    '📘' => 'akwukwọ blu',
    '📙' => 'akwukwọ oroma',
    '📚' => 'akwukwọ gasị',
    '📓' => 'akwukwọnoòtù',
    '📒' => 'leja',
    '📃' => 'ihuakwụkwọ nwere mpịaji',
    '📜' => 'kpụ̀gharị̀a',
    '📄' => 'ihuakwụkwọ chewara ihu elu',
    '📰' => 'akwụkwọ akụkọ',
    '🗞' => 'akwụkwọ akụkọ kpọghariri elu',
    '📑' => 'taabụ bukumakị',
    '🔖' => 'bukumakị',
    '🏷' => 'nnyeaha',
    '🪙' => 'mkpụrụ ego',
    '💰' => 'àkpà ego',
    '🪎' => 'igbe akụ̀',
    '💴' => 'akwụkwọego yen',
    '💵' => 'akwụkwọego dọlla',
    '💶' => 'akwụkwọego euro',
    '💷' => 'akwụkwọego pound',
    '💸' => 'ego nwere ǹkù',
    '💳' => 'kaadị njiakwụụgwọ',
    '🧾' => 'akwukwo ngwa ahia',
    '💹' => 'mmụba chaatị nwere yen',
    '✉' => 'emvelop',
    '📧' => 'ozi-e',
    '📨' => 'emvelop na-abị abịa',
    '📩' => 'emvelop nwere akụ',
    '📤' => 'efere igbe ọpụpụ',
    '📥' => 'efere ozi mbata',
    '📦' => 'ngwugwu',
    '📫' => 'igbe ozi mechiri emechi n’iji ọkọlọtọ welitere elu',
    '📪' => 'igbe ozi mechiri emechi nwere ọkọlọtọ ewedara eweda',
    '📬' => 'igbe ozi mepere emepe nwere ọkọlọtọ welitere elu',
    '📭' => 'igbe ozi mepere emepe nwere ọkọlọtọ ewedara eweda',
    '📮' => 'igbeozi',
    '🗳' => 'igbe ngụ nwere igbe ngụ',
    '✏' => 'pensụl',
    '✒' => 'ọnụ ojii',
    '🖋' => 'mkpisiodèè fountaịnụ',
    '🖊' => 'mkpisiodèè',
    '🖌' => 'ngwa ǹteàgbà',
    '🖍' => 'kreyọn',
    '📝' => 'memọ',
    '💼' => 'igbe mpanaka',
    '📁' => 'foldà faịlị̀',
    '📂' => 'mepee foldà faịlụ',
    '🗂' => 'indek ihe nkewa kaadị',
    '📅' => 'kalịnda',
    '📆' => 'dọkapụ kalịnda',
    '🗒' => 'noòtùpaadị akpachiri',
    '🗓' => 'kalịnda paadị akpachiri',
    '📇' => 'kaadị indek',
    '📈' => 'mmụba chaati',
    '📉' => 'mmèlata chaatị',
    '📊' => 'chaàtị ogwe',
    '📋' => 'klipbọọdụ',
    '📌' => 'pushpinụ̀',
    '📍' => 'pushpinụ̀ okirikiri',
    '📎' => 'kliipụ-akwụkwọ',
    '🖇' => 'kliipụ-akwụkwọ nwere njikọ',
    '📏' => 'rulà ogologo',
    '📐' => 'rulà trayangulụ',
    '✂' => 'mkpà',
    '🗃' => 'igbe kaadị faịlụ',
    '🗄' => 'kabineti failụ',
    '🗑' => 'nkata mkpofu',
    '🔒' => 'akpọchiri',
    '🔓' => 'akpọghere',
    '🔏' => 'akpọchiri n’iji mkpịsịodee',
    '🔐' => 'akpọchiri n’iji ọtụgwo',
    '🔑' => 'ọtụgwo',
    '🗝' => 'ọtụgwo ochie',
    '🔨' => 'nkụigwe',
    '🪓' => 'anyụike',
    '⛏' => 'họrọ',
    '⚒' => 'nkụigwe na nhọrọ',
    '🛠' => 'nkụigwe na igwe ndọpụta',
    '🗡' => 'nwa obere mma',
    '⚔' => 'mma agha nwere ngabichi',
    '💣' => 'ogbunigwe',
    '🪃' => 'boomerang',
    '🏹' => 'ụta na àkụ',
    '🛡' => 'ọta',
    '🪚' => 'ọwa osisi',
    '🔧' => 'igwe ndọpụta',
    '🪛' => 'screwdriver',
    '🔩' => 'mkpụrụ igwe na okporo igwe',
    '⚙' => 'giya',
    '🗜' => 'ngwa mkpabi',
    '⚖' => 'nsialọ nhatanha',
    '🦯' => 'mkipisi ocha',
    '🔗' => 'njikọ',
    '⛓' => 'agbụ igwe gasị',
    '🪝' => 'ngu',
    '🧰' => 'igbe ngwaọrụ',
    '🧲' => 'magnet',
    '🪜' => 'lada',
    '🪏' => 'shọvel',
    '⚗' => 'ngwaọrụ sayensi',
    '🧪' => 'ule tube',
    '🧫' => 'efere petri',
    '🧬' => 'dna',
    '🔬' => 'ugogbe nnyota nje',
    '🔭' => 'ngwa sọfịa',
    '📡' => 'akara satịlitị',
    '💉' => 'ntụtụ',
    '🩸' => 'obara',
    '💊' => 'mkpụrụ ọgwụ',
    '🩹' => 'bandeeji',
    '🩼' => 'kroochi',
    '🩺' => 'stetoscope',
    '🩻' => 'x-ray',
    '🚪' => 'ụzọ',
    '🛗' => 'mbugo',
    '🪞' => 'enyo',
    '🪟' => 'windo',
    '🛏' => 'àkwà',
    '🛋' => 'oche na mpanaka',
    '🪑' => 'oche',
    '🚽' => 'ụlọ mpochi',
    '🪠' => 'plọnga',
    '🚿' => 'igwe asamụahụ',
    '🛁' => 'ngwa asamụahụ',
    '🪤' => 'ọnyà òké',
    '🪒' => 'rezo',
    '🧴' => 'ude botulu',
    '🧷' => 'ntụtụ nchekwa',
    '🧹' => 'aziza',
    '🧺' => 'ekete',
    '🧻' => 'akwụkwọ ụlọ mposhi',
    '🪣' => 'bokeeti',
    '🧼' => 'ncha',
    '🫧' => 'afụfu ncha',
    '🪥' => 'atu',
    '🧽' => 'sapo',
    '🧯' => 'ihe mgbanyụ ọkụ',
    '🛒' => 'ịzụ ahịa karti',
    '🚬' => 'ciga',
    '⚰' => 'igbe ozu',
    '🪦' => 'okwute alaili',
    '⚱' => 'akpụrụ akpụ olili ozu',
    '🧿' => 'ọtụmọkpọ nazar',
    '🪬' => 'hamsa',
    '🗿' => 'Akpụrụ akpụ isi mmadụ',
    '🪧' => 'akara ngosi',
    '🪪' => 'Kaadị njirimara',
    '🏧' => 'akara ATM',
    '🚮' => 'ntụsasị n’akara nkata',
    '🚰' => 'mmiri ọṅụṅụ dị mma',
    '♿' => 'akara ocheigwe',
    '🚹' => 'ọnụ ụlọ ụmụnwoke',
    '🚺' => 'ọnụ ụlọ ụmụnwaanyị',
    '🚻' => 'ụlọ maamịrị',
    '🚼' => 'akara nwata ọhụrụ',
    '🚾' => 'nchekwa mmiri',
    '🛂' => 'njizi passpọtụ',
    '🛃' => 'pụrụiche',
    '🛄' => 'ibu enwere',
    '🛅' => 'ibu akaèkpè',
    '⚠' => 'Ịdọ àka na ntị',
    '🚸' => 'ụmụaka na-agbafèụzọ',
    '⛔' => 'enweghị mbanye',
    '🚫' => 'egbochiri',
    '🚳' => 'enweghị igwe',
    '🚭' => 'enweghị ọkụ',
    '🚯' => 'enweghị ntụsasị',
    '🚱' => 'enweghị mmiri ọṅụṅụ dị mma',
    '🚷' => 'enweghị àkwà ngafe',
    '📵' => 'enweghị ekwenti kengagharị gasị',
    '🔞' => 'enweghị onye erubeghị afo iri na asatọ',
    '☢' => 'dị njọ',
    '☣' => 'nje dị njọ',
    '⬆' => 'ube dị elu',
    '↗' => 'ube akanri dị elu',
    '➡' => 'ube akanri',
    '↘' => 'ube-ala akanri',
    '⬇' => 'ube ala',
    '↙' => 'ube-ala akaekpe',
    '⬅' => 'ube akaekpe',
    '↖' => 'ube akaekpe-dị elu',
    '↕' => 'ube-dị ala dị elu',
    '↔' => 'ube-akanri akaekpe',
    '↩' => 'ube-akanri gbagọrọ akaekpe',
    '↪' => 'ube-akaekpe gbagọrọ akanri',
    '⤴' => 'ube-akanri na-eme mgbagọ dị elu',
    '⤵' => 'ube-akanri na-eme mgbagọ dị ala',
    '🔃' => 'njem okirikiri àkụ kwụọtọ',
    '🔄' => 'ọdụmbi ube nke mgbochi ǹjem elekere',
    '🔙' => 'ube AZU',
    '🔚' => 'ube NGWỤCHA',
    '🔛' => 'ube NA!',
    '🔜' => 'ube MGBE ADỊGHỊ ANYA',
    '🔝' => 'ube N’ELU',
    '🛐' => 'ebe nke okpukperechi',
    '⚛' => 'Ọdịmara atọm',
    '🕉' => 'om',
    '✡' => 'kpakpando nke David',
    '☸' => 'wiilị nke dharma',
    '☯' => 'yin yang',
    '✝' => 'obe latin',
    '☦' => 'obe ọthọdọsụ',
    '☪' => 'kpakpando na ọnwa',
    '☮' => 'akara udo',
    '🕎' => 'menorah',
    '🔯' => 'kpakpando-isii nwere ntụpọ',
    '🪯' => 'khanda',
    '♈' => 'Ariis',
    '♉' => 'Tọrus',
    '♊' => 'Gemini',
    '♋' => 'Ịzi ọbara',
    '♌' => 'Lio',
    '♍' => 'Vigo',
    '♎' => 'Libra',
    '♏' => 'Akpì',
    '♐' => 'Sagịtarius',
    '♑' => 'Kaprịkọn',
    '♒' => 'Akwarius',
    '♓' => 'Paịces',
    '⛎' => 'Ofiukus',
    '🔀' => 'gwakọrịta traakị ọdụmbi',
    '🔁' => 'megharịa ọdụmbi',
    '🔂' => 'megharịa ọdụmbi nge',
    '▶' => 'ọdụmbi kpọọ',
    '⏩' => 'ọdụmbi gbaga ihū',
    '⏭' => 'ọdụmbi traakị na-esote',
    '⏯' => 'kpọọ maọbụ cheretụ ọdụmbi',
    '◀' => 'weghàchie ọdụmbi àzụ',
    '⏪' => 'mweghàchie ọdụmbi àzụ ọsọ ọsọ',
    '⏮' => 'ọdụmbi traakị ikpeazụ',
    '🔼' => 'ọdụmbi elu',
    '⏫' => 'ọdụmbi elu ọsọ ọsọ',
    '🔽' => 'ọdụmbi ala',
    '⏬' => 'ọdụmbi ala ọsọ ọsọ',
    '⏸' => 'ọdụmbi cheretụ',
    '⏹' => 'kwụsị ọdụmbi',
    '⏺' => 'ọdụmbi ndekọ',
    '⏏' => 'ọdụmbi wepụta',
    '🎦' => 'ụlọ ihe ngosi onyonyo',
    '🔅' => 'ọdụmbi ọyụnyụ',
    '🔆' => 'ọdụmbi nchawàpụ̀',
    '📶' => 'akara ogwe gasị',
    '🛜' => 'enwēwayà',
    '📳' => 'moòdù ọma jijiji',
    '📴' => 'mgbanyụ ekwenti kengagharị',
    '♀' => 'akàrà nwanyị',
    '♂' => 'akara oke',
    '⚧' => 'akara ndi transgender',
    '✖' => 'nnukwu mgbakọ x',
    '➕' => 'mgbakwunye',
    '➖' => 'mwepụ',
    '➗' => 'nkewa',
    '🟰' => 'nnukwu akara nhata',
    '♾' => 'ebiyebi',
    '‼' => 'akara ntimkpu mkpị',
    '⁉' => 'akara njụajụjụ ntimkpu',
    '❓' => 'akara njụajụjụ',
    '❔' => 'akara njụajụjụ dị ọcha',
    '❕' => 'Akara Mkpu dị Ọcha',
    '❗' => 'akara ntimkpu',
    '〰' => 'akara mgbagọ',
    '💱' => 'mgbanwe ego',
    '💲' => 'nnukwu akara dọlla',
    '⚕' => 'ọdịmara ngwaọrụ ụlọ ọgwụ',
    '♻' => 'akara mmegharịa',
    '⚜' => 'fleur-de-lis',
    '🔱' => 'ihe mmado ube akụkụ atọ',
    '📛' => 'aha baajị',
    '🔰' => 'akara Japan maka nke isimbìdo',
    '⭕' => 'okirikiri uhie nwere oghere',
    '✅' => 'nnukwu ntule akara ọcha',
    '☑' => 'igbe igbe ngụ nwere ntule',
    '✔' => 'akara emechara',
    '❌' => 'akara nkachi',
    '❎' => 'ọdụmbị akara nkachi',
    '➰' => 'memmenwè gbagọrọ agbagọ',
    '➿' => 'mkpị memmenwè gbagọrọ agbagọ',
    '〽' => 'akụkụ akara ọzọ',
    '✳' => 'otù n’ime akàràmmùke-asatọ',
    '✴' => 'kpakpando asatọ-arụtụrụ aka',
    '❇' => 'icheku ọkụ',
    '™' => 'akara-ụlọọrụ',
    '🫟' => 'nfesasị',
    '🔠' => 'tinye mkpụrụedemede latin nnukwu',
    '🔡' => 'tinye obere mkpụrụedemede latin',
    '🔢' => 'tinye nọmbà gasị',
    '🔣' => 'tinye akara gasị',
    '🔤' => 'tinye mkpụrụedemede latin gasị',
    '🅰' => 'Ọdụmbi (ụdị ọbara)',
    '🆎' => 'Ọdụmbi AB (ụdị ọbara)',
    '🅱' => 'Ọdụmbi B (ụdị ọbara)',
    '🆑' => 'Ọdụmbi CL',
    '🆒' => 'ọdụmbi COOL',
    '🆓' => 'ọdụmbị EFU',
    'ℹ' => 'ozi',
    '🆔' => 'ọdụmbị ID',
    'Ⓜ' => 'M nwere okirikiri',
    '🆕' => 'ọdụmbị ỌHỤRỤ',
    '🆖' => 'ọdụmbị NG',
    '🅾' => 'O ọdụmbi (ụdị ọbara)',
    '🆗' => 'ọdụmbi OK',
    '🅿' => 'Ọdụmbi P',
    '🆘' => 'ọdụmbị SOS',
    '🆙' => 'ELU! ọdụmbi',
    '🆚' => 'ọdụmbi VS',
    '🈁' => 'Ọdụmbi Ndị Japan “ebe a”',
    '🈂' => 'Ọdụmbi “ụgwọ ọrụ” Ndị Japan',
    '🈷' => 'Ọdụmbi Ndị Japan “ọnụego kwa onwa”',
    '🈶' => 'Ọdụmbi Ndị Japan “abụghị nke efù”',
    '🈯' => 'Ọdụmbi Ndị Japan “chekwara”',
    '🉐' => 'Ọdụmbi “ekwemụọnụ” Ndị Japan',
    '🈹' => 'Ọdụmbi Ndị Japan “agụpụrụ”',
    '🈚' => 'Ọdụmbi Ndị Japan “bụ nke efù”',
    '🈲' => 'Ọdụmbi Ndị Japan “egbochiri”',
    '🉑' => 'Ọdụmbi Ndị Japan “anabatara”',
    '🈸' => 'Ọdụmbi Ndị Japan “ntinye akwụkwọ”',
    '🈴' => 'Ọdụmbi “nzere ngafe” Ndị Japan',
    '🈳' => 'Ọdụmbi “anamachọọrụ” Ndị Japan',
    '㊗' => 'Ọdụmbi “ekele” Ndị Japan',
    '㊙' => 'Ọdụmbi “nzuzo” Ndị Japan',
    '🈺' => 'Ọdụmbi ’“mmepe maka azụmaahịa” Ndị Japan',
    '🈵' => 'Ọdụmbi “enweghị ọrụ” Ndị Japan',
    '🔴' => 'okirikiri uhie',
    '🟠' => 'okirikiri oroma',
    '🟡' => 'okirikiri odo',
    '🟢' => 'okirikiri ndụ ndụ',
    '🔵' => 'okirikiri anụnụ',
    '🟣' => 'okirikiri odo odo',
    '🟤' => 'okirikiri aja aja',
    '⚫' => 'okirikiri ojii',
    '⚪' => 'okirikiri ọcha',
    '🟥' => 'sukwia uhie',
    '🟧' => 'sukwia oroma',
    '🟨' => 'sukwia odo',
    '🟩' => 'sukwia ndụ ndụ',
    '🟦' => 'sukwia blu',
    '🟪' => 'sukwia odo odo',
    '🟫' => 'sukwia aja aja',
    '⬛' => 'sukwia nnukwu ojii',
    '⬜' => 'sukwia nnukwu ọcha',
    '◼' => 'sukwia keetiti ojii',
    '◻' => 'sukwia keetiti ọcha',
    '◾' => 'sukwia obere-etiti ojii',
    '◽' => 'sukwia obere-etiti ọcha',
    '▪' => 'obere sukwia ojii',
    '▫' => 'obere sukwia ọcha',
    '🔶' => 'nnukwu orenji diamond',
    '🔷' => 'nnukwu dayamọnd anụnụ',
    '🔸' => 'obere dayamọnd oroma',
    '🔹' => 'obere anụnụ dayamọnd',
    '🔺' => 'akomgbà-atọ uhie chewara ihu elu',
    '🔻' => 'akomgbà-atọ uhie chewara ihu ala',
    '💠' => 'dayamọnd nwere kpọm',
    '🔘' => 'ọdụmbi redio',
    '🔳' => 'ọdụmbi sukwia ọcha',
    '🔲' => 'ọdụmbi sukwia ojii',
    '🏁' => 'ọkọlọtọ nwere eserese',
    '🚩' => 'ọkọlọtọ nwere akomgbà-atọ',
    '🎌' => 'ọkọlọtọ nwere nkachi',
    '🏴' => 'ọkọlọtọ ojii',
    '🏳' => 'ọkọlọtọ ọcha',
];
