<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'sărut: adult, adult, ton deschis al pielii, ton semi‑deschis al pielii',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'sărut: adult, adult, ton deschis al pielii, ton mediu al pielii',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'sărut: adult, adult, ton deschis al pielii, ton semi‑închis al pielii',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'sărut: adult, adult, ton deschis al pielii, ton închis al pielii',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'sărut: adult, adult, ton semi‑deschis al pielii, ton deschis al pielii',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'sărut: adult, adult, ton semi‑deschis al pielii, ton mediu al pielii',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'sărut: adult, adult, ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'sărut: adult, adult, ton semi‑deschis al pielii, ton închis al pielii',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'sărut: adult, adult, ton mediu al pielii, ton deschis al pielii',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'sărut: adult, adult, ton mediu al pielii, ton semi‑deschis al pielii',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'sărut: adult, adult, ton mediu al pielii, ton semi‑închis al pielii',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'sărut: adult, adult, ton mediu al pielii, ton închis al pielii',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'sărut: adult, adult, ton semi‑închis al pielii, ton deschis al pielii',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'sărut: adult, adult, ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'sărut: adult, adult, ton semi‑închis al pielii, ton mediu al pielii',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'sărut: adult, adult, ton semi‑închis al pielii, ton închis al pielii',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'sărut: adult, adult, ton închis al pielii, ton deschis al pielii',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'sărut: adult, adult, ton închis al pielii, ton semi‑deschis al pielii',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'sărut: adult, adult, ton închis al pielii, ton mediu al pielii',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'sărut: adult, adult, ton închis al pielii, ton semi‑închis al pielii',
    '👨🏻‍❤‍💋‍👨🏻' => 'sărut: bărbat, bărbat, ton deschis al pielii',
    '👨🏻‍❤‍💋‍👨🏼' => 'sărut: bărbat, bărbat, ton deschis al pielii, ton semi‑deschis al pielii',
    '👨🏻‍❤‍💋‍👨🏽' => 'sărut: bărbat, bărbat, ton deschis al pielii, ton mediu al pielii',
    '👨🏻‍❤‍💋‍👨🏾' => 'sărut: bărbat, bărbat, ton deschis al pielii, ton semi‑închis al pielii',
    '👨🏻‍❤‍💋‍👨🏿' => 'sărut: bărbat, bărbat, ton deschis al pielii, ton închis al pielii',
    '👨🏼‍❤‍💋‍👨🏻' => 'sărut: bărbat, bărbat, ton semi‑deschis al pielii, ton deschis al pielii',
    '👨🏼‍❤‍💋‍👨🏼' => 'sărut: bărbat, bărbat, ton semi‑deschis al pielii',
    '👨🏼‍❤‍💋‍👨🏽' => 'sărut: bărbat, bărbat, ton semi‑deschis al pielii, ton mediu al pielii',
    '👨🏼‍❤‍💋‍👨🏾' => 'sărut: bărbat, bărbat, ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👨🏼‍❤‍💋‍👨🏿' => 'sărut: bărbat, bărbat, ton semi‑deschis al pielii, ton închis al pielii',
    '👨🏽‍❤‍💋‍👨🏻' => 'sărut: bărbat, bărbat, ton mediu al pielii, ton deschis al pielii',
    '👨🏽‍❤‍💋‍👨🏼' => 'sărut: bărbat, bărbat, ton mediu al pielii, ton semi‑deschis al pielii',
    '👨🏽‍❤‍💋‍👨🏽' => 'sărut: bărbat, bărbat, ton mediu al pielii',
    '👨🏽‍❤‍💋‍👨🏾' => 'sărut: bărbat, bărbat, ton mediu al pielii, ton semi‑închis al pielii',
    '👨🏽‍❤‍💋‍👨🏿' => 'sărut: bărbat, bărbat, ton mediu al pielii, ton închis al pielii',
    '👨🏾‍❤‍💋‍👨🏻' => 'sărut: bărbat, bărbat, ton semi‑închis al pielii, ton deschis al pielii',
    '👨🏾‍❤‍💋‍👨🏼' => 'sărut: bărbat, bărbat, ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👨🏾‍❤‍💋‍👨🏽' => 'sărut: bărbat, bărbat, ton semi‑închis al pielii, ton mediu al pielii',
    '👨🏾‍❤‍💋‍👨🏾' => 'sărut: bărbat, bărbat, ton semi‑închis al pielii',
    '👨🏾‍❤‍💋‍👨🏿' => 'sărut: bărbat, bărbat, ton semi‑închis al pielii, ton închis al pielii',
    '👨🏿‍❤‍💋‍👨🏻' => 'sărut: bărbat, bărbat, ton închis al pielii, ton deschis al pielii',
    '👨🏿‍❤‍💋‍👨🏼' => 'sărut: bărbat, bărbat, ton închis al pielii, ton semi‑deschis al pielii',
    '👨🏿‍❤‍💋‍👨🏽' => 'sărut: bărbat, bărbat, ton închis al pielii, ton mediu al pielii',
    '👨🏿‍❤‍💋‍👨🏾' => 'sărut: bărbat, bărbat, ton închis al pielii, ton semi‑închis al pielii',
    '👨🏿‍❤‍💋‍👨🏿' => 'sărut: bărbat, bărbat, ton închis al pielii',
    '👩🏻‍❤‍💋‍👨🏻' => 'sărut: femeie, bărbat, ton deschis al pielii',
    '👩🏻‍❤‍💋‍👨🏼' => 'sărut: femeie, bărbat, ton deschis al pielii, ton semi‑deschis al pielii',
    '👩🏻‍❤‍💋‍👨🏽' => 'sărut: femeie, bărbat, ton deschis al pielii, ton mediu al pielii',
    '👩🏻‍❤‍💋‍👨🏾' => 'sărut: femeie, bărbat, ton deschis al pielii, ton semi‑închis al pielii',
    '👩🏻‍❤‍💋‍👨🏿' => 'sărut: femeie, bărbat, ton deschis al pielii, ton închis al pielii',
    '👩🏼‍❤‍💋‍👨🏻' => 'sărut: femeie, bărbat, ton semi‑deschis al pielii, ton deschis al pielii',
    '👩🏼‍❤‍💋‍👨🏼' => 'sărut: femeie, bărbat, ton semi‑deschis al pielii',
    '👩🏼‍❤‍💋‍👨🏽' => 'sărut: femeie, bărbat, ton semi‑deschis al pielii, ton mediu al pielii',
    '👩🏼‍❤‍💋‍👨🏾' => 'sărut: femeie, bărbat, ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👩🏼‍❤‍💋‍👨🏿' => 'sărut: femeie, bărbat, ton semi‑deschis al pielii, ton închis al pielii',
    '👩🏽‍❤‍💋‍👨🏻' => 'sărut: femeie, bărbat, ton mediu al pielii, ton deschis al pielii',
    '👩🏽‍❤‍💋‍👨🏼' => 'sărut: femeie, bărbat, ton mediu al pielii, ton semi‑deschis al pielii',
    '👩🏽‍❤‍💋‍👨🏽' => 'sărut: femeie, bărbat, ton mediu al pielii',
    '👩🏽‍❤‍💋‍👨🏾' => 'sărut: femeie, bărbat, ton mediu al pielii, ton semi‑închis al pielii',
    '👩🏽‍❤‍💋‍👨🏿' => 'sărut: femeie, bărbat, ton mediu al pielii, ton închis al pielii',
    '👩🏾‍❤‍💋‍👨🏻' => 'sărut: femeie, bărbat, ton semi‑închis al pielii, ton deschis al pielii',
    '👩🏾‍❤‍💋‍👨🏼' => 'sărut: femeie, bărbat, ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👩🏾‍❤‍💋‍👨🏽' => 'sărut: femeie, bărbat, ton semi‑închis al pielii, ton mediu al pielii',
    '👩🏾‍❤‍💋‍👨🏾' => 'sărut: femeie, bărbat, ton semi‑închis al pielii',
    '👩🏾‍❤‍💋‍👨🏿' => 'sărut: femeie, bărbat, ton semi‑închis al pielii, ton închis al pielii',
    '👩🏿‍❤‍💋‍👨🏻' => 'sărut: femeie, bărbat, ton închis al pielii, ton deschis al pielii',
    '👩🏿‍❤‍💋‍👨🏼' => 'sărut: femeie, bărbat, ton închis al pielii, ton semi‑deschis al pielii',
    '👩🏿‍❤‍💋‍👨🏽' => 'sărut: femeie, bărbat, ton închis al pielii, ton mediu al pielii',
    '👩🏿‍❤‍💋‍👨🏾' => 'sărut: femeie, bărbat, ton închis al pielii, ton semi‑închis al pielii',
    '👩🏿‍❤‍💋‍👨🏿' => 'sărut: femeie, bărbat, ton închis al pielii',
    '👩🏻‍❤‍💋‍👩🏻' => 'sărut: femeie, femeie, ton deschis al pielii',
    '👩🏻‍❤‍💋‍👩🏼' => 'sărut: femeie, femeie, ton deschis al pielii, ton semi‑deschis al pielii',
    '👩🏻‍❤‍💋‍👩🏽' => 'sărut: femeie, femeie, ton deschis al pielii, ton mediu al pielii',
    '👩🏻‍❤‍💋‍👩🏾' => 'sărut: femeie, femeie, ton deschis al pielii, ton semi‑închis al pielii',
    '👩🏻‍❤‍💋‍👩🏿' => 'sărut: femeie, femeie, ton deschis al pielii, ton închis al pielii',
    '👩🏼‍❤‍💋‍👩🏻' => 'sărut: femeie, femeie, ton semi‑deschis al pielii, ton deschis al pielii',
    '👩🏼‍❤‍💋‍👩🏼' => 'sărut: femeie, femeie, ton semi‑deschis al pielii',
    '👩🏼‍❤‍💋‍👩🏽' => 'sărut: femeie, femeie, ton semi‑deschis al pielii, ton mediu al pielii',
    '👩🏼‍❤‍💋‍👩🏾' => 'sărut: femeie, femeie, ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👩🏼‍❤‍💋‍👩🏿' => 'sărut: femeie, femeie, ton semi‑deschis al pielii, ton închis al pielii',
    '👩🏽‍❤‍💋‍👩🏻' => 'sărut: femeie, femeie, ton mediu al pielii, ton deschis al pielii',
    '👩🏽‍❤‍💋‍👩🏼' => 'sărut: femeie, femeie, ton mediu al pielii, ton semi‑deschis al pielii',
    '👩🏽‍❤‍💋‍👩🏽' => 'sărut: femeie, femeie, ton mediu al pielii',
    '👩🏽‍❤‍💋‍👩🏾' => 'sărut: femeie, femeie, ton mediu al pielii, ton semi‑închis al pielii',
    '👩🏽‍❤‍💋‍👩🏿' => 'sărut: femeie, femeie, ton mediu al pielii, ton închis al pielii',
    '👩🏾‍❤‍💋‍👩🏻' => 'sărut: femeie, femeie, ton semi‑închis al pielii, ton deschis al pielii',
    '👩🏾‍❤‍💋‍👩🏼' => 'sărut: femeie, femeie, ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👩🏾‍❤‍💋‍👩🏽' => 'sărut: femeie, femeie, ton semi‑închis al pielii, ton mediu al pielii',
    '👩🏾‍❤‍💋‍👩🏾' => 'sărut: femeie, femeie, ton semi‑închis al pielii',
    '👩🏾‍❤‍💋‍👩🏿' => 'sărut: femeie, femeie, ton semi‑închis al pielii, ton închis al pielii',
    '👩🏿‍❤‍💋‍👩🏻' => 'sărut: femeie, femeie, ton închis al pielii, ton deschis al pielii',
    '👩🏿‍❤‍💋‍👩🏼' => 'sărut: femeie, femeie, ton închis al pielii, ton semi‑deschis al pielii',
    '👩🏿‍❤‍💋‍👩🏽' => 'sărut: femeie, femeie, ton închis al pielii, ton mediu al pielii',
    '👩🏿‍❤‍💋‍👩🏾' => 'sărut: femeie, femeie, ton închis al pielii, ton semi‑închis al pielii',
    '👩🏿‍❤‍💋‍👩🏿' => 'sărut: femeie, femeie, ton închis al pielii',
    '🧑🏻‍🫯‍🧑🏼' => 'persoane care practică wrestling: ton deschis al pielii, ton semi‑deschis al pielii',
    '🧑🏻‍🫯‍🧑🏽' => 'persoane care practică wrestling: ton deschis al pielii, ton mediu al pielii',
    '🧑🏻‍🫯‍🧑🏾' => 'persoane care practică wrestling: ton deschis al pielii, ton semi‑închis al pielii',
    '🧑🏻‍🫯‍🧑🏿' => 'persoane care practică wrestling: ton deschis al pielii, ton închis al pielii',
    '🧑🏼‍🫯‍🧑🏻' => 'persoane care practică wrestling: ton semi‑deschis al pielii, ton deschis al pielii',
    '🧑🏼‍🫯‍🧑🏽' => 'persoane care practică wrestling: ton semi‑deschis al pielii, ton mediu al pielii',
    '🧑🏼‍🫯‍🧑🏾' => 'persoane care practică wrestling: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '🧑🏼‍🫯‍🧑🏿' => 'persoane care practică wrestling: ton semi‑deschis al pielii, ton închis al pielii',
    '🧑🏽‍🫯‍🧑🏻' => 'persoane care practică wrestling: ton mediu al pielii, ton deschis al pielii',
    '🧑🏽‍🫯‍🧑🏼' => 'persoane care practică wrestling: ton mediu al pielii, ton semi‑deschis al pielii',
    '🧑🏽‍🫯‍🧑🏾' => 'persoane care practică wrestling: ton mediu al pielii, ton semi‑închis al pielii',
    '🧑🏽‍🫯‍🧑🏿' => 'persoane care practică wrestling: ton mediu al pielii, ton închis al pielii',
    '🧑🏾‍🫯‍🧑🏻' => 'persoane care practică wrestling: ton semi‑închis al pielii, ton deschis al pielii',
    '🧑🏾‍🫯‍🧑🏼' => 'persoane care practică wrestling: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '🧑🏾‍🫯‍🧑🏽' => 'persoane care practică wrestling: ton semi‑închis al pielii, ton mediu al pielii',
    '🧑🏾‍🫯‍🧑🏿' => 'persoane care practică wrestling: ton semi‑închis al pielii, ton închis al pielii',
    '🧑🏿‍🫯‍🧑🏻' => 'persoane care practică wrestling: ton închis al pielii, ton deschis al pielii',
    '🧑🏿‍🫯‍🧑🏼' => 'persoane care practică wrestling: ton închis al pielii, ton semi‑deschis al pielii',
    '🧑🏿‍🫯‍🧑🏽' => 'persoane care practică wrestling: ton închis al pielii, ton mediu al pielii',
    '🧑🏿‍🫯‍🧑🏾' => 'persoane care practică wrestling: ton închis al pielii, ton semi‑închis al pielii',
    '🧑🏻‍❤‍🧑🏼' => 'cuplu cu inimă: adult, adult, ton deschis al pielii, ton semi‑deschis al pielii',
    '🧑🏻‍❤‍🧑🏽' => 'cuplu cu inimă: adult, adult, ton deschis al pielii, ton mediu al pielii',
    '🧑🏻‍❤‍🧑🏾' => 'cuplu cu inimă: adult, adult, ton deschis al pielii, ton semi‑închis al pielii',
    '🧑🏻‍❤‍🧑🏿' => 'cuplu cu inimă: adult, adult, ton deschis al pielii, ton închis al pielii',
    '🧑🏼‍❤‍🧑🏻' => 'cuplu cu inimă: adult, adult, ton semi‑deschis al pielii, ton deschis al pielii',
    '🧑🏼‍❤‍🧑🏽' => 'cuplu cu inimă: adult, adult, ton semi‑deschis al pielii, ton mediu al pielii',
    '🧑🏼‍❤‍🧑🏾' => 'cuplu cu inimă: adult, adult, ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '🧑🏼‍❤‍🧑🏿' => 'cuplu cu inimă: adult, adult, ton semi‑deschis al pielii, ton închis al pielii',
    '🧑🏽‍❤‍🧑🏻' => 'cuplu cu inimă: adult, adult, ton mediu al pielii, ton deschis al pielii',
    '🧑🏽‍❤‍🧑🏼' => 'cuplu cu inimă: adult, adult, ton mediu al pielii, ton semi‑deschis al pielii',
    '🧑🏽‍❤‍🧑🏾' => 'cuplu cu inimă: adult, adult, ton mediu al pielii, ton semi‑închis al pielii',
    '🧑🏽‍❤‍🧑🏿' => 'cuplu cu inimă: adult, adult, ton mediu al pielii, ton închis al pielii',
    '🧑🏾‍❤‍🧑🏻' => 'cuplu cu inimă: adult, adult, ton semi‑închis al pielii, ton deschis al pielii',
    '🧑🏾‍❤‍🧑🏼' => 'cuplu cu inimă: adult, adult, ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '🧑🏾‍❤‍🧑🏽' => 'cuplu cu inimă: adult, adult, ton semi‑închis al pielii, ton mediu al pielii',
    '🧑🏾‍❤‍🧑🏿' => 'cuplu cu inimă: adult, adult, ton semi‑închis al pielii, ton închis al pielii',
    '🧑🏿‍❤‍🧑🏻' => 'cuplu cu inimă: adult, adult, ton închis al pielii, ton deschis al pielii',
    '🧑🏿‍❤‍🧑🏼' => 'cuplu cu inimă: adult, adult, ton închis al pielii, ton semi‑deschis al pielii',
    '🧑🏿‍❤‍🧑🏽' => 'cuplu cu inimă: adult, adult, ton închis al pielii, ton mediu al pielii',
    '🧑🏿‍❤‍🧑🏾' => 'cuplu cu inimă: adult, adult, ton închis al pielii, ton semi‑închis al pielii',
    '🧑🏻‍🐰‍🧑🏼' => 'persoane care poartă urechi de iepuraș: ton deschis al pielii, ton semi‑deschis al pielii',
    '🧑🏻‍🐰‍🧑🏽' => 'persoane care poartă urechi de iepuraș: ton deschis al pielii, ton mediu al pielii',
    '🧑🏻‍🐰‍🧑🏾' => 'persoane care poartă urechi de iepuraș: ton deschis al pielii, ton semi‑închis al pielii',
    '🧑🏻‍🐰‍🧑🏿' => 'persoane care poartă urechi de iepuraș: ton deschis al pielii, ton închis al pielii',
    '🧑🏼‍🐰‍🧑🏻' => 'persoane care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton deschis al pielii',
    '🧑🏼‍🐰‍🧑🏽' => 'persoane care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton mediu al pielii',
    '🧑🏼‍🐰‍🧑🏾' => 'persoane care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '🧑🏼‍🐰‍🧑🏿' => 'persoane care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton închis al pielii',
    '🧑🏽‍🐰‍🧑🏻' => 'persoane care poartă urechi de iepuraș: ton mediu al pielii, ton deschis al pielii',
    '🧑🏽‍🐰‍🧑🏼' => 'persoane care poartă urechi de iepuraș: ton mediu al pielii, ton semi‑deschis al pielii',
    '🧑🏽‍🐰‍🧑🏾' => 'persoane care poartă urechi de iepuraș: ton mediu al pielii, ton semi‑închis al pielii',
    '🧑🏽‍🐰‍🧑🏿' => 'persoane care poartă urechi de iepuraș: ton mediu al pielii, ton închis al pielii',
    '🧑🏾‍🐰‍🧑🏻' => 'persoane care poartă urechi de iepuraș: ton semi‑închis al pielii, ton deschis al pielii',
    '🧑🏾‍🐰‍🧑🏼' => 'persoane care poartă urechi de iepuraș: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '🧑🏾‍🐰‍🧑🏽' => 'persoane care poartă urechi de iepuraș: ton semi‑închis al pielii, ton mediu al pielii',
    '🧑🏾‍🐰‍🧑🏿' => 'persoane care poartă urechi de iepuraș: ton semi‑închis al pielii, ton închis al pielii',
    '🧑🏿‍🐰‍🧑🏻' => 'persoane care poartă urechi de iepuraș: ton închis al pielii, ton deschis al pielii',
    '🧑🏿‍🐰‍🧑🏼' => 'persoane care poartă urechi de iepuraș: ton închis al pielii, ton semi‑deschis al pielii',
    '🧑🏿‍🐰‍🧑🏽' => 'persoane care poartă urechi de iepuraș: ton închis al pielii, ton mediu al pielii',
    '🧑🏿‍🐰‍🧑🏾' => 'persoane care poartă urechi de iepuraș: ton închis al pielii, ton semi‑închis al pielii',
    '👨🏻‍🫯‍👨🏼' => 'bărbat care practică wrestling: ton deschis al pielii, ton semi‑deschis al pielii',
    '👨🏻‍🫯‍👨🏽' => 'bărbat care practică wrestling: ton deschis al pielii, ton mediu al pielii',
    '👨🏻‍🫯‍👨🏾' => 'bărbat care practică wrestling: ton deschis al pielii, ton semi‑închis al pielii',
    '👨🏻‍🫯‍👨🏿' => 'bărbat care practică wrestling: ton deschis al pielii, ton închis al pielii',
    '👨🏼‍🫯‍👨🏻' => 'bărbat care practică wrestling: ton semi‑deschis al pielii, ton deschis al pielii',
    '👨🏼‍🫯‍👨🏽' => 'bărbat care practică wrestling: ton semi‑deschis al pielii, ton mediu al pielii',
    '👨🏼‍🫯‍👨🏾' => 'bărbat care practică wrestling: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👨🏼‍🫯‍👨🏿' => 'bărbat care practică wrestling: ton semi‑deschis al pielii, ton închis al pielii',
    '👨🏽‍🫯‍👨🏻' => 'bărbat care practică wrestling: ton mediu al pielii, ton deschis al pielii',
    '👨🏽‍🫯‍👨🏼' => 'bărbat care practică wrestling: ton mediu al pielii, ton semi‑deschis al pielii',
    '👨🏽‍🫯‍👨🏾' => 'bărbat care practică wrestling: ton mediu al pielii, ton semi‑închis al pielii',
    '👨🏽‍🫯‍👨🏿' => 'bărbat care practică wrestling: ton mediu al pielii, ton închis al pielii',
    '👨🏾‍🫯‍👨🏻' => 'bărbat care practică wrestling: ton semi‑închis al pielii, ton deschis al pielii',
    '👨🏾‍🫯‍👨🏼' => 'bărbat care practică wrestling: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👨🏾‍🫯‍👨🏽' => 'bărbat care practică wrestling: ton semi‑închis al pielii, ton mediu al pielii',
    '👨🏾‍🫯‍👨🏿' => 'bărbat care practică wrestling: ton semi‑închis al pielii, ton închis al pielii',
    '👨🏿‍🫯‍👨🏻' => 'bărbat care practică wrestling: ton închis al pielii, ton deschis al pielii',
    '👨🏿‍🫯‍👨🏼' => 'bărbat care practică wrestling: ton închis al pielii, ton semi‑deschis al pielii',
    '👨🏿‍🫯‍👨🏽' => 'bărbat care practică wrestling: ton închis al pielii, ton mediu al pielii',
    '👨🏿‍🫯‍👨🏾' => 'bărbat care practică wrestling: ton închis al pielii, ton semi‑închis al pielii',
    '👨🏻‍❤‍👨🏻' => 'cuplu cu inimă: bărbat, bărbat, ton deschis al pielii',
    '👨🏻‍❤‍👨🏼' => 'cuplu cu inimă: bărbat, bărbat, ton deschis al pielii, ton semi‑deschis al pielii',
    '👨🏻‍❤‍👨🏽' => 'cuplu cu inimă: bărbat, bărbat, ton deschis al pielii, ton mediu al pielii',
    '👨🏻‍❤‍👨🏾' => 'cuplu cu inimă: bărbat, bărbat, ton deschis al pielii, ton semi‑închis al pielii',
    '👨🏻‍❤‍👨🏿' => 'cuplu cu inimă: bărbat, bărbat, ton deschis al pielii, ton închis al pielii',
    '👨🏼‍❤‍👨🏻' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑deschis al pielii, ton deschis al pielii',
    '👨🏼‍❤‍👨🏼' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑deschis al pielii',
    '👨🏼‍❤‍👨🏽' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑deschis al pielii, ton mediu al pielii',
    '👨🏼‍❤‍👨🏾' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👨🏼‍❤‍👨🏿' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑deschis al pielii, ton închis al pielii',
    '👨🏽‍❤‍👨🏻' => 'cuplu cu inimă: bărbat, bărbat, ton mediu al pielii, ton deschis al pielii',
    '👨🏽‍❤‍👨🏼' => 'cuplu cu inimă: bărbat, bărbat, ton mediu al pielii, ton semi‑deschis al pielii',
    '👨🏽‍❤‍👨🏽' => 'cuplu cu inimă: bărbat, bărbat, ton mediu al pielii',
    '👨🏽‍❤‍👨🏾' => 'cuplu cu inimă: bărbat, bărbat, ton mediu al pielii, ton semi‑închis al pielii',
    '👨🏽‍❤‍👨🏿' => 'cuplu cu inimă: bărbat, bărbat, ton mediu al pielii, ton închis al pielii',
    '👨🏾‍❤‍👨🏻' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑închis al pielii, ton deschis al pielii',
    '👨🏾‍❤‍👨🏼' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👨🏾‍❤‍👨🏽' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑închis al pielii, ton mediu al pielii',
    '👨🏾‍❤‍👨🏾' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑închis al pielii',
    '👨🏾‍❤‍👨🏿' => 'cuplu cu inimă: bărbat, bărbat, ton semi‑închis al pielii, ton închis al pielii',
    '👨🏿‍❤‍👨🏻' => 'cuplu cu inimă: bărbat, bărbat, ton închis al pielii, ton deschis al pielii',
    '👨🏿‍❤‍👨🏼' => 'cuplu cu inimă: bărbat, bărbat, ton închis al pielii, ton semi‑deschis al pielii',
    '👨🏿‍❤‍👨🏽' => 'cuplu cu inimă: bărbat, bărbat, ton închis al pielii, ton mediu al pielii',
    '👨🏿‍❤‍👨🏾' => 'cuplu cu inimă: bărbat, bărbat, ton închis al pielii, ton semi‑închis al pielii',
    '👨🏿‍❤‍👨🏿' => 'cuplu cu inimă: bărbat, bărbat, ton închis al pielii',
    '👨🏻‍🐰‍👨🏼' => 'bărbați care poartă urechi de iepuraș: ton deschis al pielii, ton semi‑deschis al pielii',
    '👨🏻‍🐰‍👨🏽' => 'bărbați care poartă urechi de iepuraș: ton deschis al pielii, ton mediu al pielii',
    '👨🏻‍🐰‍👨🏾' => 'bărbați care poartă urechi de iepuraș: ton deschis al pielii, ton semi‑închis al pielii',
    '👨🏻‍🐰‍👨🏿' => 'bărbați care poartă urechi de iepuraș: ton deschis al pielii, ton închis al pielii',
    '👨🏼‍🐰‍👨🏻' => 'bărbați care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton deschis al pielii',
    '👨🏼‍🐰‍👨🏽' => 'bărbați care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton mediu al pielii',
    '👨🏼‍🐰‍👨🏾' => 'bărbați care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👨🏼‍🐰‍👨🏿' => 'bărbați care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton închis al pielii',
    '👨🏽‍🐰‍👨🏻' => 'bărbați care poartă urechi de iepuraș: ton mediu al pielii, ton deschis al pielii',
    '👨🏽‍🐰‍👨🏼' => 'bărbați care poartă urechi de iepuraș: ton mediu al pielii, ton semi‑deschis al pielii',
    '👨🏽‍🐰‍👨🏾' => 'bărbați care poartă urechi de iepuraș: ton mediu al pielii, ton semi‑închis al pielii',
    '👨🏽‍🐰‍👨🏿' => 'bărbați care poartă urechi de iepuraș: ton mediu al pielii, ton închis al pielii',
    '👨🏾‍🐰‍👨🏻' => 'bărbați care poartă urechi de iepuraș: ton semi‑închis al pielii, ton deschis al pielii',
    '👨🏾‍🐰‍👨🏼' => 'bărbați care poartă urechi de iepuraș: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👨🏾‍🐰‍👨🏽' => 'bărbați care poartă urechi de iepuraș: ton semi‑închis al pielii, ton mediu al pielii',
    '👨🏾‍🐰‍👨🏿' => 'bărbați care poartă urechi de iepuraș: ton semi‑închis al pielii, ton închis al pielii',
    '👨🏿‍🐰‍👨🏻' => 'bărbați care poartă urechi de iepuraș: ton închis al pielii, ton deschis al pielii',
    '👨🏿‍🐰‍👨🏼' => 'bărbați care poartă urechi de iepuraș: ton închis al pielii, ton semi‑deschis al pielii',
    '👨🏿‍🐰‍👨🏽' => 'bărbați care poartă urechi de iepuraș: ton închis al pielii, ton mediu al pielii',
    '👨🏿‍🐰‍👨🏾' => 'bărbați care poartă urechi de iepuraș: ton închis al pielii, ton semi‑închis al pielii',
    '👩🏻‍🫯‍👩🏼' => 'femeie care practică wrestling: ton deschis al pielii, ton semi‑deschis al pielii',
    '👩🏻‍🫯‍👩🏽' => 'femeie care practică wrestling: ton deschis al pielii, ton mediu al pielii',
    '👩🏻‍🫯‍👩🏾' => 'femeie care practică wrestling: ton deschis al pielii, ton semi‑închis al pielii',
    '👩🏻‍🫯‍👩🏿' => 'femeie care practică wrestling: ton deschis al pielii, ton închis al pielii',
    '👩🏼‍🫯‍👩🏻' => 'femeie care practică wrestling: ton semi‑deschis al pielii, ton deschis al pielii',
    '👩🏼‍🫯‍👩🏽' => 'femeie care practică wrestling: ton semi‑deschis al pielii, ton mediu al pielii',
    '👩🏼‍🫯‍👩🏾' => 'femeie care practică wrestling: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👩🏼‍🫯‍👩🏿' => 'femeie care practică wrestling: ton semi‑deschis al pielii, ton închis al pielii',
    '👩🏽‍🫯‍👩🏻' => 'femeie care practică wrestling: ton mediu al pielii, ton deschis al pielii',
    '👩🏽‍🫯‍👩🏼' => 'femeie care practică wrestling: ton mediu al pielii, ton semi‑deschis al pielii',
    '👩🏽‍🫯‍👩🏾' => 'femeie care practică wrestling: ton mediu al pielii, ton semi‑închis al pielii',
    '👩🏽‍🫯‍👩🏿' => 'femeie care practică wrestling: ton mediu al pielii, ton închis al pielii',
    '👩🏾‍🫯‍👩🏻' => 'femeie care practică wrestling: ton semi‑închis al pielii, ton deschis al pielii',
    '👩🏾‍🫯‍👩🏼' => 'femeie care practică wrestling: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👩🏾‍🫯‍👩🏽' => 'femeie care practică wrestling: ton semi‑închis al pielii, ton mediu al pielii',
    '👩🏾‍🫯‍👩🏿' => 'femeie care practică wrestling: ton semi‑închis al pielii, ton închis al pielii',
    '👩🏿‍🫯‍👩🏻' => 'femeie care practică wrestling: ton închis al pielii, ton deschis al pielii',
    '👩🏿‍🫯‍👩🏼' => 'femeie care practică wrestling: ton închis al pielii, ton semi‑deschis al pielii',
    '👩🏿‍🫯‍👩🏽' => 'femeie care practică wrestling: ton închis al pielii, ton mediu al pielii',
    '👩🏿‍🫯‍👩🏾' => 'femeie care practică wrestling: ton închis al pielii, ton semi‑închis al pielii',
    '👩🏻‍❤‍👨🏻' => 'cuplu cu inimă: femeie, bărbat, ton deschis al pielii',
    '👩🏻‍❤‍👨🏼' => 'cuplu cu inimă: femeie, bărbat, ton deschis al pielii, ton semi‑deschis al pielii',
    '👩🏻‍❤‍👨🏽' => 'cuplu cu inimă: femeie, bărbat, ton deschis al pielii, ton mediu al pielii',
    '👩🏻‍❤‍👨🏾' => 'cuplu cu inimă: femeie, bărbat, ton deschis al pielii, ton semi‑închis al pielii',
    '👩🏻‍❤‍👨🏿' => 'cuplu cu inimă: femeie, bărbat, ton deschis al pielii, ton închis al pielii',
    '👩🏼‍❤‍👨🏻' => 'cuplu cu inimă: femeie, bărbat, ton semi‑deschis al pielii, ton deschis al pielii',
    '👩🏼‍❤‍👨🏼' => 'cuplu cu inimă: femeie, bărbat, ton semi‑deschis al pielii',
    '👩🏼‍❤‍👨🏽' => 'cuplu cu inimă: femeie, bărbat, ton semi‑deschis al pielii, ton mediu al pielii',
    '👩🏼‍❤‍👨🏾' => 'cuplu cu inimă: femeie, bărbat, ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👩🏼‍❤‍👨🏿' => 'cuplu cu inimă: femeie, bărbat, ton semi‑deschis al pielii, ton închis al pielii',
    '👩🏽‍❤‍👨🏻' => 'cuplu cu inimă: femeie, bărbat, ton mediu al pielii, ton deschis al pielii',
    '👩🏽‍❤‍👨🏼' => 'cuplu cu inimă: femeie, bărbat, ton mediu al pielii, ton semi‑deschis al pielii',
    '👩🏽‍❤‍👨🏽' => 'cuplu cu inimă: femeie, bărbat, ton mediu al pielii',
    '👩🏽‍❤‍👨🏾' => 'cuplu cu inimă: femeie, bărbat, ton mediu al pielii, ton semi‑închis al pielii',
    '👩🏽‍❤‍👨🏿' => 'cuplu cu inimă: femeie, bărbat, ton mediu al pielii, ton închis al pielii',
    '👩🏾‍❤‍👨🏻' => 'cuplu cu inimă: femeie, bărbat, ton semi‑închis al pielii, ton deschis al pielii',
    '👩🏾‍❤‍👨🏼' => 'cuplu cu inimă: femeie, bărbat, ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👩🏾‍❤‍👨🏽' => 'cuplu cu inimă: femeie, bărbat, ton semi‑închis al pielii, ton mediu al pielii',
    '👩🏾‍❤‍👨🏾' => 'cuplu cu inimă: femeie, bărbat, ton semi‑închis al pielii',
    '👩🏾‍❤‍👨🏿' => 'cuplu cu inimă: femeie, bărbat, ton semi‑închis al pielii, ton închis al pielii',
    '👩🏿‍❤‍👨🏻' => 'cuplu cu inimă: femeie, bărbat, ton închis al pielii, ton deschis al pielii',
    '👩🏿‍❤‍👨🏼' => 'cuplu cu inimă: femeie, bărbat, ton închis al pielii, ton semi‑deschis al pielii',
    '👩🏿‍❤‍👨🏽' => 'cuplu cu inimă: femeie, bărbat, ton închis al pielii, ton mediu al pielii',
    '👩🏿‍❤‍👨🏾' => 'cuplu cu inimă: femeie, bărbat, ton închis al pielii, ton semi‑închis al pielii',
    '👩🏿‍❤‍👨🏿' => 'cuplu cu inimă: femeie, bărbat, ton închis al pielii',
    '👩🏻‍❤‍👩🏻' => 'cuplu cu inimă: femeie, femeie, ton deschis al pielii',
    '👩🏻‍❤‍👩🏼' => 'cuplu cu inimă: femeie, femeie, ton deschis al pielii, ton semi‑deschis al pielii',
    '👩🏻‍❤‍👩🏽' => 'cuplu cu inimă: femeie, femeie, ton deschis al pielii, ton mediu al pielii',
    '👩🏻‍❤‍👩🏾' => 'cuplu cu inimă: femeie, femeie, ton deschis al pielii, ton semi‑închis al pielii',
    '👩🏻‍❤‍👩🏿' => 'cuplu cu inimă: femeie, femeie, ton deschis al pielii, ton închis al pielii',
    '👩🏼‍❤‍👩🏻' => 'cuplu cu inimă: femeie, femeie, ton semi‑deschis al pielii, ton deschis al pielii',
    '👩🏼‍❤‍👩🏼' => 'cuplu cu inimă: femeie, femeie, ton semi‑deschis al pielii',
    '👩🏼‍❤‍👩🏽' => 'cuplu cu inimă: femeie, femeie, ton semi‑deschis al pielii, ton mediu al pielii',
    '👩🏼‍❤‍👩🏾' => 'cuplu cu inimă: femeie, femeie, ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👩🏼‍❤‍👩🏿' => 'cuplu cu inimă: femeie, femeie, ton semi‑deschis al pielii, ton închis al pielii',
    '👩🏽‍❤‍👩🏻' => 'cuplu cu inimă: femeie, femeie, ton mediu al pielii, ton deschis al pielii',
    '👩🏽‍❤‍👩🏼' => 'cuplu cu inimă: femeie, femeie, ton mediu al pielii, ton semi‑deschis al pielii',
    '👩🏽‍❤‍👩🏽' => 'cuplu cu inimă: femeie, femeie, ton mediu al pielii',
    '👩🏽‍❤‍👩🏾' => 'cuplu cu inimă: femeie, femeie, ton mediu al pielii, ton semi‑închis al pielii',
    '👩🏽‍❤‍👩🏿' => 'cuplu cu inimă: femeie, femeie, ton mediu al pielii, ton închis al pielii',
    '👩🏾‍❤‍👩🏻' => 'cuplu cu inimă: femeie, femeie, ton semi‑închis al pielii, ton deschis al pielii',
    '👩🏾‍❤‍👩🏼' => 'cuplu cu inimă: femeie, femeie, ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👩🏾‍❤‍👩🏽' => 'cuplu cu inimă: femeie, femeie, ton semi‑închis al pielii, ton mediu al pielii',
    '👩🏾‍❤‍👩🏾' => 'cuplu cu inimă: femeie, femeie, ton semi‑închis al pielii',
    '👩🏾‍❤‍👩🏿' => 'cuplu cu inimă: femeie, femeie, ton semi‑închis al pielii, ton închis al pielii',
    '👩🏿‍❤‍👩🏻' => 'cuplu cu inimă: femeie, femeie, ton închis al pielii, ton deschis al pielii',
    '👩🏿‍❤‍👩🏼' => 'cuplu cu inimă: femeie, femeie, ton închis al pielii, ton semi‑deschis al pielii',
    '👩🏿‍❤‍👩🏽' => 'cuplu cu inimă: femeie, femeie, ton închis al pielii, ton mediu al pielii',
    '👩🏿‍❤‍👩🏾' => 'cuplu cu inimă: femeie, femeie, ton închis al pielii, ton semi‑închis al pielii',
    '👩🏿‍❤‍👩🏿' => 'cuplu cu inimă: femeie, femeie, ton închis al pielii',
    '👩🏻‍🐰‍👩🏼' => 'femei care poartă urechi de iepuraș: ton deschis al pielii, ton semi‑deschis al pielii',
    '👩🏻‍🐰‍👩🏽' => 'femei care poartă urechi de iepuraș: ton deschis al pielii, ton mediu al pielii',
    '👩🏻‍🐰‍👩🏾' => 'femei care poartă urechi de iepuraș: ton deschis al pielii, ton semi‑închis al pielii',
    '👩🏻‍🐰‍👩🏿' => 'femei care poartă urechi de iepuraș: ton deschis al pielii, ton închis al pielii',
    '👩🏼‍🐰‍👩🏻' => 'femei care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton deschis al pielii',
    '👩🏼‍🐰‍👩🏽' => 'femei care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton mediu al pielii',
    '👩🏼‍🐰‍👩🏾' => 'femei care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👩🏼‍🐰‍👩🏿' => 'femei care poartă urechi de iepuraș: ton semi‑deschis al pielii, ton închis al pielii',
    '👩🏽‍🐰‍👩🏻' => 'femei care poartă urechi de iepuraș: ton mediu al pielii, ton deschis al pielii',
    '👩🏽‍🐰‍👩🏼' => 'femei care poartă urechi de iepuraș: ton mediu al pielii, ton semi‑deschis al pielii',
    '👩🏽‍🐰‍👩🏾' => 'femei care poartă urechi de iepuraș: ton mediu al pielii, ton semi‑închis al pielii',
    '👩🏽‍🐰‍👩🏿' => 'femei care poartă urechi de iepuraș: ton mediu al pielii, ton închis al pielii',
    '👩🏾‍🐰‍👩🏻' => 'femei care poartă urechi de iepuraș: ton semi‑închis al pielii, ton deschis al pielii',
    '👩🏾‍🐰‍👩🏼' => 'femei care poartă urechi de iepuraș: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👩🏾‍🐰‍👩🏽' => 'femei care poartă urechi de iepuraș: ton semi‑închis al pielii, ton mediu al pielii',
    '👩🏾‍🐰‍👩🏿' => 'femei care poartă urechi de iepuraș: ton semi‑închis al pielii, ton închis al pielii',
    '👩🏿‍🐰‍👩🏻' => 'femei care poartă urechi de iepuraș: ton închis al pielii, ton deschis al pielii',
    '👩🏿‍🐰‍👩🏼' => 'femei care poartă urechi de iepuraș: ton închis al pielii, ton semi‑deschis al pielii',
    '👩🏿‍🐰‍👩🏽' => 'femei care poartă urechi de iepuraș: ton închis al pielii, ton mediu al pielii',
    '👩🏿‍🐰‍👩🏾' => 'femei care poartă urechi de iepuraș: ton închis al pielii, ton semi‑închis al pielii',
    '🧑🏻‍🤝‍🧑🏻' => 'persoane ținându-se de mână: ton deschis al pielii',
    '🧑🏻‍🤝‍🧑🏼' => 'persoane ținându-se de mână: ton deschis al pielii, ton semi‑deschis al pielii',
    '🧑🏻‍🤝‍🧑🏽' => 'persoane ținându-se de mână: ton deschis al pielii, ton mediu al pielii',
    '🧑🏻‍🤝‍🧑🏾' => 'persoane ținându-se de mână: ton deschis al pielii, ton semi‑închis al pielii',
    '🧑🏻‍🤝‍🧑🏿' => 'persoane ținându-se de mână: ton deschis al pielii, ton închis al pielii',
    '🧑🏼‍🤝‍🧑🏻' => 'persoane ținându-se de mână: ton semi‑deschis al pielii, ton deschis al pielii',
    '🧑🏼‍🤝‍🧑🏼' => 'persoane ținându-se de mână: ton semi‑deschis al pielii',
    '🧑🏼‍🤝‍🧑🏽' => 'persoane ținându-se de mână: ton semi‑deschis al pielii, ton mediu al pielii',
    '🧑🏼‍🤝‍🧑🏾' => 'persoane ținându-se de mână: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '🧑🏼‍🤝‍🧑🏿' => 'persoane ținându-se de mână: ton semi‑deschis al pielii, ton închis al pielii',
    '🧑🏽‍🤝‍🧑🏻' => 'persoane ținându-se de mână: ton mediu al pielii, ton deschis al pielii',
    '🧑🏽‍🤝‍🧑🏼' => 'persoane ținându-se de mână: ton mediu al pielii, ton semi‑deschis al pielii',
    '🧑🏽‍🤝‍🧑🏽' => 'persoane ținându-se de mână: ton mediu al pielii',
    '🧑🏽‍🤝‍🧑🏾' => 'persoane ținându-se de mână: ton mediu al pielii, ton semi‑închis al pielii',
    '🧑🏽‍🤝‍🧑🏿' => 'persoane ținându-se de mână: ton mediu al pielii, ton închis al pielii',
    '🧑🏾‍🤝‍🧑🏻' => 'persoane ținându-se de mână: ton semi‑închis al pielii, ton deschis al pielii',
    '🧑🏾‍🤝‍🧑🏼' => 'persoane ținându-se de mână: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '🧑🏾‍🤝‍🧑🏽' => 'persoane ținându-se de mână: ton semi‑închis al pielii, ton mediu al pielii',
    '🧑🏾‍🤝‍🧑🏾' => 'persoane ținându-se de mână: ton semi‑închis al pielii',
    '🧑🏾‍🤝‍🧑🏿' => 'persoane ținându-se de mână: ton semi‑închis al pielii, ton închis al pielii',
    '🧑🏿‍🤝‍🧑🏻' => 'persoane ținându-se de mână: ton închis al pielii, ton deschis al pielii',
    '🧑🏿‍🤝‍🧑🏼' => 'persoane ținându-se de mână: ton închis al pielii, ton semi‑deschis al pielii',
    '🧑🏿‍🤝‍🧑🏽' => 'persoane ținându-se de mână: ton închis al pielii, ton mediu al pielii',
    '🧑🏿‍🤝‍🧑🏾' => 'persoane ținându-se de mână: ton închis al pielii, ton semi‑închis al pielii',
    '🧑🏿‍🤝‍🧑🏿' => 'persoane ținându-se de mână: ton închis al pielii',
    '👩🏻‍🤝‍👩🏼' => 'femei ținându-se de mână: ton deschis al pielii, ton semi‑deschis al pielii',
    '👩🏻‍🤝‍👩🏽' => 'femei ținându-se de mână: ton deschis al pielii, ton mediu al pielii',
    '👩🏻‍🤝‍👩🏾' => 'femei ținându-se de mână: ton deschis al pielii, ton semi‑închis al pielii',
    '👩🏻‍🤝‍👩🏿' => 'femei ținându-se de mână: ton deschis al pielii, ton închis al pielii',
    '👩🏼‍🤝‍👩🏻' => 'femei ținându-se de mână: ton semi‑deschis al pielii, ton deschis al pielii',
    '👩🏼‍🤝‍👩🏽' => 'femei ținându-se de mână: ton semi‑deschis al pielii, ton mediu al pielii',
    '👩🏼‍🤝‍👩🏾' => 'femei ținându-se de mână: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👩🏼‍🤝‍👩🏿' => 'femei ținându-se de mână: ton semi‑deschis al pielii, ton închis al pielii',
    '👩🏽‍🤝‍👩🏻' => 'femei ținându-se de mână: ton mediu al pielii, ton deschis al pielii',
    '👩🏽‍🤝‍👩🏼' => 'femei ținându-se de mână: ton mediu al pielii, ton semi‑deschis al pielii',
    '👩🏽‍🤝‍👩🏾' => 'femei ținându-se de mână: ton mediu al pielii, ton semi‑închis al pielii',
    '👩🏽‍🤝‍👩🏿' => 'femei ținându-se de mână: ton mediu al pielii, ton închis al pielii',
    '👩🏾‍🤝‍👩🏻' => 'femei ținându-se de mână: ton semi‑închis al pielii, ton deschis al pielii',
    '👩🏾‍🤝‍👩🏼' => 'femei ținându-se de mână: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👩🏾‍🤝‍👩🏽' => 'femei ținându-se de mână: ton semi‑închis al pielii, ton mediu al pielii',
    '👩🏾‍🤝‍👩🏿' => 'femei ținându-se de mână: ton semi‑închis al pielii, ton închis al pielii',
    '👩🏿‍🤝‍👩🏻' => 'femei ținându-se de mână: ton închis al pielii, ton deschis al pielii',
    '👩🏿‍🤝‍👩🏼' => 'femei ținându-se de mână: ton închis al pielii, ton semi‑deschis al pielii',
    '👩🏿‍🤝‍👩🏽' => 'femei ținându-se de mână: ton închis al pielii, ton mediu al pielii',
    '👩🏿‍🤝‍👩🏾' => 'femei ținându-se de mână: ton închis al pielii, ton semi‑închis al pielii',
    '👩🏻‍🤝‍👨🏼' => 'bărbat și femeie ținându-se de mână: ton deschis al pielii, ton semi‑deschis al pielii',
    '👩🏻‍🤝‍👨🏽' => 'bărbat și femeie ținându-se de mână: ton deschis al pielii, ton mediu al pielii',
    '👩🏻‍🤝‍👨🏾' => 'bărbat și femeie ținându-se de mână: ton deschis al pielii, ton semi‑închis al pielii',
    '👩🏻‍🤝‍👨🏿' => 'bărbat și femeie ținându-se de mână: ton deschis al pielii, ton închis al pielii',
    '👩🏼‍🤝‍👨🏻' => 'bărbat și femeie ținându-se de mână: ton semi‑deschis al pielii, ton deschis al pielii',
    '👩🏼‍🤝‍👨🏽' => 'bărbat și femeie ținându-se de mână: ton semi‑deschis al pielii, ton mediu al pielii',
    '👩🏼‍🤝‍👨🏾' => 'bărbat și femeie ținându-se de mână: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👩🏼‍🤝‍👨🏿' => 'bărbat și femeie ținându-se de mână: ton semi‑deschis al pielii, ton închis al pielii',
    '👩🏽‍🤝‍👨🏻' => 'bărbat și femeie ținându-se de mână: ton mediu al pielii, ton deschis al pielii',
    '👩🏽‍🤝‍👨🏼' => 'bărbat și femeie ținându-se de mână: ton mediu al pielii, ton semi‑deschis al pielii',
    '👩🏽‍🤝‍👨🏾' => 'bărbat și femeie ținându-se de mână: ton mediu al pielii, ton semi‑închis al pielii',
    '👩🏽‍🤝‍👨🏿' => 'bărbat și femeie ținându-se de mână: ton mediu al pielii, ton închis al pielii',
    '👩🏾‍🤝‍👨🏻' => 'bărbat și femeie ținându-se de mână: ton semi‑închis al pielii, ton deschis al pielii',
    '👩🏾‍🤝‍👨🏼' => 'bărbat și femeie ținându-se de mână: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👩🏾‍🤝‍👨🏽' => 'bărbat și femeie ținându-se de mână: ton semi‑închis al pielii, ton mediu al pielii',
    '👩🏾‍🤝‍👨🏿' => 'bărbat și femeie ținându-se de mână: ton semi‑închis al pielii, ton închis al pielii',
    '👩🏿‍🤝‍👨🏻' => 'bărbat și femeie ținându-se de mână: ton închis al pielii, ton deschis al pielii',
    '👩🏿‍🤝‍👨🏼' => 'bărbat și femeie ținându-se de mână: ton închis al pielii, ton semi‑deschis al pielii',
    '👩🏿‍🤝‍👨🏽' => 'bărbat și femeie ținându-se de mână: ton închis al pielii, ton mediu al pielii',
    '👩🏿‍🤝‍👨🏾' => 'bărbat și femeie ținându-se de mână: ton închis al pielii, ton semi‑închis al pielii',
    '👨🏻‍🤝‍👨🏼' => 'bărbați ținându-se de mână: ton deschis al pielii, ton semi‑deschis al pielii',
    '👨🏻‍🤝‍👨🏽' => 'bărbați ținându-se de mână: ton deschis al pielii, ton mediu al pielii',
    '👨🏻‍🤝‍👨🏾' => 'bărbați ținându-se de mână: ton deschis al pielii, ton semi‑închis al pielii',
    '👨🏻‍🤝‍👨🏿' => 'bărbați ținându-se de mână: ton deschis al pielii, ton închis al pielii',
    '👨🏼‍🤝‍👨🏻' => 'bărbați ținându-se de mână: ton semi‑deschis al pielii, ton deschis al pielii',
    '👨🏼‍🤝‍👨🏽' => 'bărbați ținându-se de mână: ton semi‑deschis al pielii, ton mediu al pielii',
    '👨🏼‍🤝‍👨🏾' => 'bărbați ținându-se de mână: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '👨🏼‍🤝‍👨🏿' => 'bărbați ținându-se de mână: ton semi‑deschis al pielii, ton închis al pielii',
    '👨🏽‍🤝‍👨🏻' => 'bărbați ținându-se de mână: ton mediu al pielii, ton deschis al pielii',
    '👨🏽‍🤝‍👨🏼' => 'bărbați ținându-se de mână: ton mediu al pielii, ton semi‑deschis al pielii',
    '👨🏽‍🤝‍👨🏾' => 'bărbați ținându-se de mână: ton mediu al pielii, ton semi‑închis al pielii',
    '👨🏽‍🤝‍👨🏿' => 'bărbați ținându-se de mână: ton mediu al pielii, ton închis al pielii',
    '👨🏾‍🤝‍👨🏻' => 'bărbați ținându-se de mână: ton semi‑închis al pielii, ton deschis al pielii',
    '👨🏾‍🤝‍👨🏼' => 'bărbați ținându-se de mână: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '👨🏾‍🤝‍👨🏽' => 'bărbați ținându-se de mână: ton semi‑închis al pielii, ton mediu al pielii',
    '👨🏾‍🤝‍👨🏿' => 'bărbați ținându-se de mână: ton semi‑închis al pielii, ton închis al pielii',
    '👨🏿‍🤝‍👨🏻' => 'bărbați ținându-se de mână: ton închis al pielii, ton deschis al pielii',
    '👨🏿‍🤝‍👨🏼' => 'bărbați ținându-se de mână: ton închis al pielii, ton semi‑deschis al pielii',
    '👨🏿‍🤝‍👨🏽' => 'bărbați ținându-se de mână: ton închis al pielii, ton mediu al pielii',
    '👨🏿‍🤝‍👨🏾' => 'bărbați ținându-se de mână: ton închis al pielii, ton semi‑închis al pielii',
    '👩‍❤‍💋‍👨' => 'sărut: femeie, bărbat',
    '👨‍❤‍💋‍👨' => 'sărut: bărbat, bărbat',
    '👩‍❤‍💋‍👩' => 'sărut: femeie, femeie',
    '👨‍👩‍👧‍👦' => 'familie: bărbat, femeie, fată, băiat',
    '👨‍👩‍👦‍👦' => 'familie: bărbat, femeie, băiat, băiat',
    '👨‍👩‍👧‍👧' => 'familie: bărbat, femeie, fată, fată',
    '👨‍👨‍👧‍👦' => 'familie: bărbat, bărbat, fată, băiat',
    '👨‍👨‍👦‍👦' => 'familie: bărbat, bărbat, băiat, băiat',
    '👨‍👨‍👧‍👧' => 'familie: bărbat, bărbat, fată, fată',
    '👩‍👩‍👧‍👦' => 'familie: femeie, femeie, fată, băiat',
    '👩‍👩‍👦‍👦' => 'familie: femeie, femeie, băiat, băiat',
    '👩‍👩‍👧‍👧' => 'familie: femeie, femeie, fată, fată',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'steag: Anglia',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'steag: Scoția',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'steag: Țara Galilor',
    '🧑‍🧑‍🧒‍🧒' => 'familie: adult, adult, copil, copil',
    '🚶🏻‍♀‍➡' => 'femeie care merge: ton deschis al pielii, orientate spre dreapta',
    '🚶🏼‍♀‍➡' => 'femeie care merge: ton semi‑deschis al pielii, orientate spre dreapta',
    '🚶🏽‍♀‍➡' => 'femeie care merge: ton mediu al pielii, orientate spre dreapta',
    '🚶🏾‍♀‍➡' => 'femeie care merge: ton semi‑închis al pielii, orientate spre dreapta',
    '🚶🏿‍♀‍➡' => 'femeie care merge: ton închis al pielii, orientate spre dreapta',
    '🚶🏻‍♂‍➡' => 'bărbat care merge: ton deschis al pielii, orientate spre dreapta',
    '🚶🏼‍♂‍➡' => 'bărbat care merge: ton semi‑deschis al pielii, orientate spre dreapta',
    '🚶🏽‍♂‍➡' => 'bărbat care merge: ton mediu al pielii, orientate spre dreapta',
    '🚶🏾‍♂‍➡' => 'bărbat care merge: ton semi‑închis al pielii, orientate spre dreapta',
    '🚶🏿‍♂‍➡' => 'bărbat care merge: ton închis al pielii, orientate spre dreapta',
    '🧎🏻‍♀‍➡' => 'femeie în genunchi: ton deschis al pielii, orientate spre dreapta',
    '🧎🏼‍♀‍➡' => 'femeie în genunchi: ton semi‑deschis al pielii, orientate spre dreapta',
    '🧎🏽‍♀‍➡' => 'femeie în genunchi: ton mediu al pielii, orientate spre dreapta',
    '🧎🏾‍♀‍➡' => 'femeie în genunchi: ton semi‑închis al pielii, orientate spre dreapta',
    '🧎🏿‍♀‍➡' => 'femeie în genunchi: ton închis al pielii, orientate spre dreapta',
    '🧎🏻‍♂‍➡' => 'bărbat în genunchi: ton deschis al pielii, orientate spre dreapta',
    '🧎🏼‍♂‍➡' => 'bărbat în genunchi: ton semi‑deschis al pielii, orientate spre dreapta',
    '🧎🏽‍♂‍➡' => 'bărbat în genunchi: ton mediu al pielii, orientate spre dreapta',
    '🧎🏾‍♂‍➡' => 'bărbat în genunchi: ton semi‑închis al pielii, orientate spre dreapta',
    '🧎🏿‍♂‍➡' => 'bărbat în genunchi: ton închis al pielii, orientate spre dreapta',
    '🧑🏻‍🦯‍➡' => 'persoană cu baston pentru nevăzători: ton deschis al pielii, orientate spre dreapta',
    '🧑🏼‍🦯‍➡' => 'persoană cu baston pentru nevăzători: ton semi‑deschis al pielii, orientate spre dreapta',
    '🧑🏽‍🦯‍➡' => 'persoană cu baston pentru nevăzători: ton mediu al pielii, orientate spre dreapta',
    '🧑🏾‍🦯‍➡' => 'persoană cu baston pentru nevăzători: ton semi‑închis al pielii, orientate spre dreapta',
    '🧑🏿‍🦯‍➡' => 'persoană cu baston pentru nevăzători: ton închis al pielii, orientate spre dreapta',
    '👨🏻‍🦯‍➡' => 'bărbat cu baston pentru nevăzători: ton deschis al pielii, orientate spre dreapta',
    '👨🏼‍🦯‍➡' => 'bărbat cu baston pentru nevăzători: ton semi‑deschis al pielii, orientate spre dreapta',
    '👨🏽‍🦯‍➡' => 'bărbat cu baston pentru nevăzători: ton mediu al pielii, orientate spre dreapta',
    '👨🏾‍🦯‍➡' => 'bărbat cu baston pentru nevăzători: ton semi‑închis al pielii, orientate spre dreapta',
    '👨🏿‍🦯‍➡' => 'bărbat cu baston pentru nevăzători: ton închis al pielii, orientate spre dreapta',
    '👩🏻‍🦯‍➡' => 'femeie cu baston pentru nevăzători: ton deschis al pielii, orientate spre dreapta',
    '👩🏼‍🦯‍➡' => 'femeie cu baston pentru nevăzători: ton semi‑deschis al pielii, orientate spre dreapta',
    '👩🏽‍🦯‍➡' => 'femeie cu baston pentru nevăzători: ton mediu al pielii, orientate spre dreapta',
    '👩🏾‍🦯‍➡' => 'femeie cu baston pentru nevăzători: ton semi‑închis al pielii, orientate spre dreapta',
    '👩🏿‍🦯‍➡' => 'femeie cu baston pentru nevăzători: ton închis al pielii, orientate spre dreapta',
    '🧑🏻‍🦼‍➡' => 'persoană în scaun cu rotile motorizat: ton deschis al pielii, orientate spre dreapta',
    '🧑🏼‍🦼‍➡' => 'persoană în scaun cu rotile motorizat: ton semi‑deschis al pielii, orientate spre dreapta',
    '🧑🏽‍🦼‍➡' => 'persoană în scaun cu rotile motorizat: ton mediu al pielii, orientate spre dreapta',
    '🧑🏾‍🦼‍➡' => 'persoană în scaun cu rotile motorizat: ton semi‑închis al pielii, orientate spre dreapta',
    '🧑🏿‍🦼‍➡' => 'persoană în scaun cu rotile motorizat: ton închis al pielii, orientate spre dreapta',
    '👨🏻‍🦼‍➡' => 'bărbat în scaun cu rotile motorizat: ton deschis al pielii, orientate spre dreapta',
    '👨🏼‍🦼‍➡' => 'bărbat în scaun cu rotile motorizat: ton semi‑deschis al pielii, orientate spre dreapta',
    '👨🏽‍🦼‍➡' => 'bărbat în scaun cu rotile motorizat: ton mediu al pielii, orientate spre dreapta',
    '👨🏾‍🦼‍➡' => 'bărbat în scaun cu rotile motorizat: ton semi‑închis al pielii, orientate spre dreapta',
    '👨🏿‍🦼‍➡' => 'bărbat în scaun cu rotile motorizat: ton închis al pielii, orientate spre dreapta',
    '👩🏻‍🦼‍➡' => 'femeie în scaun cu rotile motorizat: ton deschis al pielii, orientate spre dreapta',
    '👩🏼‍🦼‍➡' => 'femeie în scaun cu rotile motorizat: ton semi‑deschis al pielii, orientate spre dreapta',
    '👩🏽‍🦼‍➡' => 'femeie în scaun cu rotile motorizat: ton mediu al pielii, orientate spre dreapta',
    '👩🏾‍🦼‍➡' => 'femeie în scaun cu rotile motorizat: ton semi‑închis al pielii, orientate spre dreapta',
    '👩🏿‍🦼‍➡' => 'femeie în scaun cu rotile motorizat: ton închis al pielii, orientate spre dreapta',
    '🧑🏻‍🦽‍➡' => 'persoană în scaun cu rotile manual: ton deschis al pielii, orientate spre dreapta',
    '🧑🏼‍🦽‍➡' => 'persoană în scaun cu rotile manual: ton semi‑deschis al pielii, orientate spre dreapta',
    '🧑🏽‍🦽‍➡' => 'persoană în scaun cu rotile manual: ton mediu al pielii, orientate spre dreapta',
    '🧑🏾‍🦽‍➡' => 'persoană în scaun cu rotile manual: ton semi‑închis al pielii, orientate spre dreapta',
    '🧑🏿‍🦽‍➡' => 'persoană în scaun cu rotile manual: ton închis al pielii, orientate spre dreapta',
    '👨🏻‍🦽‍➡' => 'bărbat în scaun cu rotile manual: ton deschis al pielii, orientate spre dreapta',
    '👨🏼‍🦽‍➡' => 'bărbat în scaun cu rotile manual: ton semi‑deschis al pielii, orientate spre dreapta',
    '👨🏽‍🦽‍➡' => 'bărbat în scaun cu rotile manual: ton mediu al pielii, orientate spre dreapta',
    '👨🏾‍🦽‍➡' => 'bărbat în scaun cu rotile manual: ton semi‑închis al pielii, orientate spre dreapta',
    '👨🏿‍🦽‍➡' => 'bărbat în scaun cu rotile manual: ton închis al pielii, orientate spre dreapta',
    '👩🏻‍🦽‍➡' => 'femeie în scaun cu rotile manual: ton deschis al pielii, orientate spre dreapta',
    '👩🏼‍🦽‍➡' => 'femeie în scaun cu rotile manual: ton semi‑deschis al pielii, orientate spre dreapta',
    '👩🏽‍🦽‍➡' => 'femeie în scaun cu rotile manual: ton mediu al pielii, orientate spre dreapta',
    '👩🏾‍🦽‍➡' => 'femeie în scaun cu rotile manual: ton semi‑închis al pielii, orientate spre dreapta',
    '👩🏿‍🦽‍➡' => 'femeie în scaun cu rotile manual: ton închis al pielii, orientate spre dreapta',
    '🏃🏻‍♀‍➡' => 'femeie care aleargă: ton deschis al pielii, orientate spre dreapta',
    '🏃🏼‍♀‍➡' => 'femeie care aleargă: ton semi‑deschis al pielii, orientate spre dreapta',
    '🏃🏽‍♀‍➡' => 'femeie care aleargă: ton mediu al pielii, orientate spre dreapta',
    '🏃🏾‍♀‍➡' => 'femeie care aleargă: ton semi‑închis al pielii, orientate spre dreapta',
    '🏃🏿‍♀‍➡' => 'femeie care aleargă: ton închis al pielii, orientate spre dreapta',
    '🏃🏻‍♂‍➡' => 'bărbat care aleargă: ton deschis al pielii, orientate spre dreapta',
    '🏃🏼‍♂‍➡' => 'bărbat care aleargă: ton semi‑deschis al pielii, orientate spre dreapta',
    '🏃🏽‍♂‍➡' => 'bărbat care aleargă: ton mediu al pielii, orientate spre dreapta',
    '🏃🏾‍♂‍➡' => 'bărbat care aleargă: ton semi‑închis al pielii, orientate spre dreapta',
    '🏃🏿‍♂‍➡' => 'bărbat care aleargă: ton închis al pielii, orientate spre dreapta',
    '🫱🏻‍🫲🏼' => 'strângere de mână: ton deschis al pielii, ton semi‑deschis al pielii',
    '🫱🏻‍🫲🏽' => 'strângere de mână: ton deschis al pielii, ton mediu al pielii',
    '🫱🏻‍🫲🏾' => 'strângere de mână: ton deschis al pielii, ton semi‑închis al pielii',
    '🫱🏻‍🫲🏿' => 'strângere de mână: ton deschis al pielii, ton închis al pielii',
    '🫱🏼‍🫲🏻' => 'strângere de mână: ton semi‑deschis al pielii, ton deschis al pielii',
    '🫱🏼‍🫲🏽' => 'strângere de mână: ton semi‑deschis al pielii, ton mediu al pielii',
    '🫱🏼‍🫲🏾' => 'strângere de mână: ton semi‑deschis al pielii, ton semi‑închis al pielii',
    '🫱🏼‍🫲🏿' => 'strângere de mână: ton semi‑deschis al pielii, ton închis al pielii',
    '🫱🏽‍🫲🏻' => 'strângere de mână: ton mediu al pielii, ton deschis al pielii',
    '🫱🏽‍🫲🏼' => 'strângere de mână: ton mediu al pielii, ton semi‑deschis al pielii',
    '🫱🏽‍🫲🏾' => 'strângere de mână: ton mediu al pielii, ton semi‑închis al pielii',
    '🫱🏽‍🫲🏿' => 'strângere de mână: ton mediu al pielii, ton închis al pielii',
    '🫱🏾‍🫲🏻' => 'strângere de mână: ton semi‑închis al pielii, ton deschis al pielii',
    '🫱🏾‍🫲🏼' => 'strângere de mână: ton semi‑închis al pielii, ton semi‑deschis al pielii',
    '🫱🏾‍🫲🏽' => 'strângere de mână: ton semi‑închis al pielii, ton mediu al pielii',
    '🫱🏾‍🫲🏿' => 'strângere de mână: ton semi‑închis al pielii, ton închis al pielii',
    '🫱🏿‍🫲🏻' => 'strângere de mână: ton închis al pielii, ton deschis al pielii',
    '🫱🏿‍🫲🏼' => 'strângere de mână: ton închis al pielii, ton semi‑deschis al pielii',
    '🫱🏿‍🫲🏽' => 'strângere de mână: ton închis al pielii, ton mediu al pielii',
    '🫱🏿‍🫲🏾' => 'strângere de mână: ton închis al pielii, ton semi‑închis al pielii',
    '🚶‍♀‍➡' => 'femeie care merge: orientate spre dreapta',
    '🚶‍♂‍➡' => 'bărbat care merge: orientate spre dreapta',
    '🧎‍♀‍➡' => 'femeie în genunchi: orientate spre dreapta',
    '🧎‍♂‍➡' => 'bărbat în genunchi: orientate spre dreapta',
    '🧑‍🦯‍➡' => 'persoană cu baston pentru nevăzători: orientate spre dreapta',
    '👨‍🦯‍➡' => 'bărbat cu baston pentru nevăzători: orientate spre dreapta',
    '👩‍🦯‍➡' => 'femeie cu baston pentru nevăzători: orientate spre dreapta',
    '🧑‍🦼‍➡' => 'persoană în scaun cu rotile motorizat: orientate spre dreapta',
    '👨‍🦼‍➡' => 'bărbat în scaun cu rotile motorizat: orientate spre dreapta',
    '👩‍🦼‍➡' => 'femeie în scaun cu rotile motorizat: orientate spre dreapta',
    '🧑‍🦽‍➡' => 'persoană în scaun cu rotile manual: orientate spre dreapta',
    '👨‍🦽‍➡' => 'bărbat în scaun cu rotile manual: orientate spre dreapta',
    '👩‍🦽‍➡' => 'femeie în scaun cu rotile manual: orientate spre dreapta',
    '🏃‍♀‍➡' => 'femeie care aleargă: orientate spre dreapta',
    '🏃‍♂‍➡' => 'bărbat care aleargă: orientate spre dreapta',
    '👩‍❤‍👨' => 'cuplu cu inimă: femeie, bărbat',
    '👨‍❤‍👨' => 'cuplu cu inimă: bărbat, bărbat',
    '👩‍❤‍👩' => 'cuplu cu inimă: femeie, femeie',
    '👨‍👩‍👦' => 'familie: bărbat, femeie, băiat',
    '👨‍👩‍👧' => 'familie: bărbat, femeie, fată',
    '👨‍👨‍👦' => 'familie: bărbat, bărbat, băiat',
    '👨‍👨‍👧' => 'familie: bărbat, bărbat, fată',
    '👩‍👩‍👦' => 'familie: femeie, femeie, băiat',
    '👩‍👩‍👧' => 'familie: femeie, femeie, fată',
    '👨‍👦‍👦' => 'familie: bărbat, băiat, băiat',
    '👨‍👧‍👦' => 'familie: bărbat, fată, băiat',
    '👨‍👧‍👧' => 'familie: bărbat, fată, fată',
    '👩‍👦‍👦' => 'familie: femeie, băiat, băiat',
    '👩‍👧‍👦' => 'familie: femeie, fată, băiat',
    '👩‍👧‍👧' => 'familie: femeie, fată, fată',
    '🧑‍🤝‍🧑' => 'persoane ținându-se de mână',
    '🧑‍🧑‍🧒' => 'familie: adult, adult, copil',
    '🧑‍🧒‍🧒' => 'familie: adult, copil, copil',
    '🧑🏻‍🦰' => 'adult: ton deschis al pielii, păr roșcat',
    '🧑🏼‍🦰' => 'adult: ton semi‑deschis al pielii, păr roșcat',
    '🧑🏽‍🦰' => 'adult: ton mediu al pielii, păr roșcat',
    '🧑🏾‍🦰' => 'adult: ton semi‑închis al pielii, păr roșcat',
    '🧑🏿‍🦰' => 'adult: ton închis al pielii, păr roșcat',
    '🧑🏻‍🦱' => 'adult: ton deschis al pielii, păr creț',
    '🧑🏼‍🦱' => 'adult: ton semi‑deschis al pielii, păr creț',
    '🧑🏽‍🦱' => 'adult: ton mediu al pielii, păr creț',
    '🧑🏾‍🦱' => 'adult: ton semi‑închis al pielii, păr creț',
    '🧑🏿‍🦱' => 'adult: ton închis al pielii, păr creț',
    '🧑🏻‍🦳' => 'adult: ton deschis al pielii, păr alb',
    '🧑🏼‍🦳' => 'adult: ton semi‑deschis al pielii, păr alb',
    '🧑🏽‍🦳' => 'adult: ton mediu al pielii, păr alb',
    '🧑🏾‍🦳' => 'adult: ton semi‑închis al pielii, păr alb',
    '🧑🏿‍🦳' => 'adult: ton închis al pielii, păr alb',
    '🧑🏻‍🦲' => 'adult: ton deschis al pielii, chelie',
    '🧑🏼‍🦲' => 'adult: ton semi‑deschis al pielii, chelie',
    '🧑🏽‍🦲' => 'adult: ton mediu al pielii, chelie',
    '🧑🏾‍🦲' => 'adult: ton semi‑închis al pielii, chelie',
    '🧑🏿‍🦲' => 'adult: ton închis al pielii, chelie',
    '🧑🏻‍🩰' => 'balerin sau balerină: ton deschis al pielii',
    '🧑🏼‍🩰' => 'balerin sau balerină: ton semi‑deschis al pielii',
    '🧑🏽‍🩰' => 'balerin sau balerină: ton mediu al pielii',
    '🧑🏾‍🩰' => 'balerin sau balerină: ton semi‑închis al pielii',
    '🧑🏿‍🩰' => 'balerin sau balerină: ton închis al pielii',
    '🧔🏻‍♂' => 'bărbat: ton deschis al pielii, barbă',
    '🧔🏼‍♂' => 'bărbat: ton semi‑deschis al pielii, barbă',
    '🧔🏽‍♂' => 'bărbat: ton mediu al pielii, barbă',
    '🧔🏾‍♂' => 'bărbat: ton semi‑închis al pielii, barbă',
    '🧔🏿‍♂' => 'bărbat: ton închis al pielii, barbă',
    '👱🏻‍♂' => 'bărbat blond: ton deschis al pielii',
    '👱🏼‍♂' => 'bărbat blond: ton semi‑deschis al pielii',
    '👱🏽‍♂' => 'bărbat blond: ton mediu al pielii',
    '👱🏾‍♂' => 'bărbat blond: ton semi‑închis al pielii',
    '👱🏿‍♂' => 'bărbat blond: ton închis al pielii',
    '👨🏻‍🦰' => 'bărbat: ton deschis al pielii, păr roșcat',
    '👨🏼‍🦰' => 'bărbat: ton semi‑deschis al pielii, păr roșcat',
    '👨🏽‍🦰' => 'bărbat: ton mediu al pielii, păr roșcat',
    '👨🏾‍🦰' => 'bărbat: ton semi‑închis al pielii, păr roșcat',
    '👨🏿‍🦰' => 'bărbat: ton închis al pielii, păr roșcat',
    '👨🏻‍🦱' => 'bărbat: ton deschis al pielii, păr creț',
    '👨🏼‍🦱' => 'bărbat: ton semi‑deschis al pielii, păr creț',
    '👨🏽‍🦱' => 'bărbat: ton mediu al pielii, păr creț',
    '👨🏾‍🦱' => 'bărbat: ton semi‑închis al pielii, păr creț',
    '👨🏿‍🦱' => 'bărbat: ton închis al pielii, păr creț',
    '👨🏻‍🦳' => 'bărbat: ton deschis al pielii, păr alb',
    '👨🏼‍🦳' => 'bărbat: ton semi‑deschis al pielii, păr alb',
    '👨🏽‍🦳' => 'bărbat: ton mediu al pielii, păr alb',
    '👨🏾‍🦳' => 'bărbat: ton semi‑închis al pielii, păr alb',
    '👨🏿‍🦳' => 'bărbat: ton închis al pielii, păr alb',
    '👨🏻‍🦲' => 'bărbat: ton deschis al pielii, chelie',
    '👨🏼‍🦲' => 'bărbat: ton semi‑deschis al pielii, chelie',
    '👨🏽‍🦲' => 'bărbat: ton mediu al pielii, chelie',
    '👨🏾‍🦲' => 'bărbat: ton semi‑închis al pielii, chelie',
    '👨🏿‍🦲' => 'bărbat: ton închis al pielii, chelie',
    '🧔🏻‍♀' => 'femeie: ton deschis al pielii, barbă',
    '🧔🏼‍♀' => 'femeie: ton semi‑deschis al pielii, barbă',
    '🧔🏽‍♀' => 'femeie: ton mediu al pielii, barbă',
    '🧔🏾‍♀' => 'femeie: ton semi‑închis al pielii, barbă',
    '🧔🏿‍♀' => 'femeie: ton închis al pielii, barbă',
    '👱🏻‍♀' => 'femeie blondă: ton deschis al pielii',
    '👱🏼‍♀' => 'femeie blondă: ton semi‑deschis al pielii',
    '👱🏽‍♀' => 'femeie blondă: ton mediu al pielii',
    '👱🏾‍♀' => 'femeie blondă: ton semi‑închis al pielii',
    '👱🏿‍♀' => 'femeie blondă: ton închis al pielii',
    '👩🏻‍🦰' => 'femeie: ton deschis al pielii, păr roșcat',
    '👩🏼‍🦰' => 'femeie: ton semi‑deschis al pielii, păr roșcat',
    '👩🏽‍🦰' => 'femeie: ton mediu al pielii, păr roșcat',
    '👩🏾‍🦰' => 'femeie: ton semi‑închis al pielii, păr roșcat',
    '👩🏿‍🦰' => 'femeie: ton închis al pielii, păr roșcat',
    '👩🏻‍🦱' => 'femeie: ton deschis al pielii, păr creț',
    '👩🏼‍🦱' => 'femeie: ton semi‑deschis al pielii, păr creț',
    '👩🏽‍🦱' => 'femeie: ton mediu al pielii, păr creț',
    '👩🏾‍🦱' => 'femeie: ton semi‑închis al pielii, păr creț',
    '👩🏿‍🦱' => 'femeie: ton închis al pielii, păr creț',
    '👩🏻‍🦳' => 'femeie: ton deschis al pielii, păr alb',
    '👩🏼‍🦳' => 'femeie: ton semi‑deschis al pielii, păr alb',
    '👩🏽‍🦳' => 'femeie: ton mediu al pielii, păr alb',
    '👩🏾‍🦳' => 'femeie: ton semi‑închis al pielii, păr alb',
    '👩🏿‍🦳' => 'femeie: ton închis al pielii, păr alb',
    '👩🏻‍🦲' => 'femeie: ton deschis al pielii, chelie',
    '👩🏼‍🦲' => 'femeie: ton semi‑deschis al pielii, chelie',
    '👩🏽‍🦲' => 'femeie: ton mediu al pielii, chelie',
    '👩🏾‍🦲' => 'femeie: ton semi‑închis al pielii, chelie',
    '👩🏿‍🦲' => 'femeie: ton închis al pielii, chelie',
    '🙍🏻‍♂' => 'bărbat întristat: ton deschis al pielii',
    '🙍🏼‍♂' => 'bărbat întristat: ton semi‑deschis al pielii',
    '🙍🏽‍♂' => 'bărbat întristat: ton mediu al pielii',
    '🙍🏾‍♂' => 'bărbat întristat: ton semi‑închis al pielii',
    '🙍🏿‍♂' => 'bărbat întristat: ton închis al pielii',
    '🙍🏻‍♀' => 'femeie întristată: ton deschis al pielii',
    '🙍🏼‍♀' => 'femeie întristată: ton semi‑deschis al pielii',
    '🙍🏽‍♀' => 'femeie întristată: ton mediu al pielii',
    '🙍🏾‍♀' => 'femeie întristată: ton semi‑închis al pielii',
    '🙍🏿‍♀' => 'femeie întristată: ton închis al pielii',
    '🙎🏻‍♂' => 'bărbat bosumflat: ton deschis al pielii',
    '🙎🏼‍♂' => 'bărbat bosumflat: ton semi‑deschis al pielii',
    '🙎🏽‍♂' => 'bărbat bosumflat: ton mediu al pielii',
    '🙎🏾‍♂' => 'bărbat bosumflat: ton semi‑închis al pielii',
    '🙎🏿‍♂' => 'bărbat bosumflat: ton închis al pielii',
    '🙎🏻‍♀' => 'femeie bosumflată: ton deschis al pielii',
    '🙎🏼‍♀' => 'femeie bosumflată: ton semi‑deschis al pielii',
    '🙎🏽‍♀' => 'femeie bosumflată: ton mediu al pielii',
    '🙎🏾‍♀' => 'femeie bosumflată: ton semi‑închis al pielii',
    '🙎🏿‍♀' => 'femeie bosumflată: ton închis al pielii',
    '🙅🏻‍♂' => 'bărbat făcând un gest de negație: ton deschis al pielii',
    '🙅🏼‍♂' => 'bărbat făcând un gest de negație: ton semi‑deschis al pielii',
    '🙅🏽‍♂' => 'bărbat făcând un gest de negație: ton mediu al pielii',
    '🙅🏾‍♂' => 'bărbat făcând un gest de negație: ton semi‑închis al pielii',
    '🙅🏿‍♂' => 'bărbat făcând un gest de negație: ton închis al pielii',
    '🙅🏻‍♀' => 'femeie făcând un gest de negație: ton deschis al pielii',
    '🙅🏼‍♀' => 'femeie făcând un gest de negație: ton semi‑deschis al pielii',
    '🙅🏽‍♀' => 'femeie făcând un gest de negație: ton mediu al pielii',
    '🙅🏾‍♀' => 'femeie făcând un gest de negație: ton semi‑închis al pielii',
    '🙅🏿‍♀' => 'femeie făcând un gest de negație: ton închis al pielii',
    '🙆🏻‍♂' => 'bărbat făcând un gest de OK: ton deschis al pielii',
    '🙆🏼‍♂' => 'bărbat făcând un gest de OK: ton semi‑deschis al pielii',
    '🙆🏽‍♂' => 'bărbat făcând un gest de OK: ton mediu al pielii',
    '🙆🏾‍♂' => 'bărbat făcând un gest de OK: ton semi‑închis al pielii',
    '🙆🏿‍♂' => 'bărbat făcând un gest de OK: ton închis al pielii',
    '🙆🏻‍♀' => 'femeie făcând un gest de OK: ton deschis al pielii',
    '🙆🏼‍♀' => 'femeie făcând un gest de OK: ton semi‑deschis al pielii',
    '🙆🏽‍♀' => 'femeie făcând un gest de OK: ton mediu al pielii',
    '🙆🏾‍♀' => 'femeie făcând un gest de OK: ton semi‑închis al pielii',
    '🙆🏿‍♀' => 'femeie făcând un gest de OK: ton închis al pielii',
    '💁🏻‍♂' => 'bărbat care explică: ton deschis al pielii',
    '💁🏼‍♂' => 'bărbat care explică: ton semi‑deschis al pielii',
    '💁🏽‍♂' => 'bărbat care explică: ton mediu al pielii',
    '💁🏾‍♂' => 'bărbat care explică: ton semi‑închis al pielii',
    '💁🏿‍♂' => 'bărbat care explică: ton închis al pielii',
    '💁🏻‍♀' => 'femeie care explică: ton deschis al pielii',
    '💁🏼‍♀' => 'femeie care explică: ton semi‑deschis al pielii',
    '💁🏽‍♀' => 'femeie care explică: ton mediu al pielii',
    '💁🏾‍♀' => 'femeie care explică: ton semi‑închis al pielii',
    '💁🏿‍♀' => 'femeie care explică: ton închis al pielii',
    '🙋🏻‍♂' => 'bărbat care ridică mâna: ton deschis al pielii',
    '🙋🏼‍♂' => 'bărbat care ridică mâna: ton semi‑deschis al pielii',
    '🙋🏽‍♂' => 'bărbat care ridică mâna: ton mediu al pielii',
    '🙋🏾‍♂' => 'bărbat care ridică mâna: ton semi‑închis al pielii',
    '🙋🏿‍♂' => 'bărbat care ridică mâna: ton închis al pielii',
    '🙋🏻‍♀' => 'femeie care ridică mâna: ton deschis al pielii',
    '🙋🏼‍♀' => 'femeie care ridică mâna: ton semi‑deschis al pielii',
    '🙋🏽‍♀' => 'femeie care ridică mâna: ton mediu al pielii',
    '🙋🏾‍♀' => 'femeie care ridică mâna: ton semi‑închis al pielii',
    '🙋🏿‍♀' => 'femeie care ridică mâna: ton închis al pielii',
    '🧏🏻‍♂' => 'bărbat surd: ton deschis al pielii',
    '🧏🏼‍♂' => 'bărbat surd: ton semi‑deschis al pielii',
    '🧏🏽‍♂' => 'bărbat surd: ton mediu al pielii',
    '🧏🏾‍♂' => 'bărbat surd: ton semi‑închis al pielii',
    '🧏🏿‍♂' => 'bărbat surd: ton închis al pielii',
    '🧏🏻‍♀' => 'femeie surdă: ton deschis al pielii',
    '🧏🏼‍♀' => 'femeie surdă: ton semi‑deschis al pielii',
    '🧏🏽‍♀' => 'femeie surdă: ton mediu al pielii',
    '🧏🏾‍♀' => 'femeie surdă: ton semi‑închis al pielii',
    '🧏🏿‍♀' => 'femeie surdă: ton închis al pielii',
    '🙇🏻‍♂' => 'bărbat care se înclină: ton deschis al pielii',
    '🙇🏼‍♂' => 'bărbat care se înclină: ton semi‑deschis al pielii',
    '🙇🏽‍♂' => 'bărbat care se înclină: ton mediu al pielii',
    '🙇🏾‍♂' => 'bărbat care se înclină: ton semi‑închis al pielii',
    '🙇🏿‍♂' => 'bărbat care se înclină: ton închis al pielii',
    '🙇🏻‍♀' => 'femeie care se înclină: ton deschis al pielii',
    '🙇🏼‍♀' => 'femeie care se înclină: ton semi‑deschis al pielii',
    '🙇🏽‍♀' => 'femeie care se înclină: ton mediu al pielii',
    '🙇🏾‍♀' => 'femeie care se înclină: ton semi‑închis al pielii',
    '🙇🏿‍♀' => 'femeie care se înclină: ton închis al pielii',
    '🤦🏻‍♂' => 'bărbat care își acoperă fața cu o palmă: ton deschis al pielii',
    '🤦🏼‍♂' => 'bărbat care își acoperă fața cu o palmă: ton semi‑deschis al pielii',
    '🤦🏽‍♂' => 'bărbat care își acoperă fața cu o palmă: ton mediu al pielii',
    '🤦🏾‍♂' => 'bărbat care își acoperă fața cu o palmă: ton semi‑închis al pielii',
    '🤦🏿‍♂' => 'bărbat care își acoperă fața cu o palmă: ton închis al pielii',
    '🤦🏻‍♀' => 'femeie care își acoperă fața cu o palmă: ton deschis al pielii',
    '🤦🏼‍♀' => 'femeie care își acoperă fața cu o palmă: ton semi‑deschis al pielii',
    '🤦🏽‍♀' => 'femeie care își acoperă fața cu o palmă: ton mediu al pielii',
    '🤦🏾‍♀' => 'femeie care își acoperă fața cu o palmă: ton semi‑închis al pielii',
    '🤦🏿‍♀' => 'femeie care își acoperă fața cu o palmă: ton închis al pielii',
    '🤷🏻‍♂' => 'bărbat care ridică din umeri: ton deschis al pielii',
    '🤷🏼‍♂' => 'bărbat care ridică din umeri: ton semi‑deschis al pielii',
    '🤷🏽‍♂' => 'bărbat care ridică din umeri: ton mediu al pielii',
    '🤷🏾‍♂' => 'bărbat care ridică din umeri: ton semi‑închis al pielii',
    '🤷🏿‍♂' => 'bărbat care ridică din umeri: ton închis al pielii',
    '🤷🏻‍♀' => 'femeie care ridică din umeri: ton deschis al pielii',
    '🤷🏼‍♀' => 'femeie care ridică din umeri: ton semi‑deschis al pielii',
    '🤷🏽‍♀' => 'femeie care ridică din umeri: ton mediu al pielii',
    '🤷🏾‍♀' => 'femeie care ridică din umeri: ton semi‑închis al pielii',
    '🤷🏿‍♀' => 'femeie care ridică din umeri: ton închis al pielii',
    '🧑🏻‍⚕' => 'persoană lucrătoare în domeniul sănătății: ton deschis al pielii',
    '🧑🏼‍⚕' => 'persoană lucrătoare în domeniul sănătății: ton semi‑deschis al pielii',
    '🧑🏽‍⚕' => 'persoană lucrătoare în domeniul sănătății: ton mediu al pielii',
    '🧑🏾‍⚕' => 'persoană lucrătoare în domeniul sănătății: ton semi‑închis al pielii',
    '🧑🏿‍⚕' => 'persoană lucrătoare în domeniul sănătății: ton închis al pielii',
    '👨🏻‍⚕' => 'lucrător în domeniul sănătății: ton deschis al pielii',
    '👨🏼‍⚕' => 'lucrător în domeniul sănătății: ton semi‑deschis al pielii',
    '👨🏽‍⚕' => 'lucrător în domeniul sănătății: ton mediu al pielii',
    '👨🏾‍⚕' => 'lucrător în domeniul sănătății: ton semi‑închis al pielii',
    '👨🏿‍⚕' => 'lucrător în domeniul sănătății: ton închis al pielii',
    '👩🏻‍⚕' => 'lucrătoare în domeniul sănătății: ton deschis al pielii',
    '👩🏼‍⚕' => 'lucrătoare în domeniul sănătății: ton semi‑deschis al pielii',
    '👩🏽‍⚕' => 'lucrătoare în domeniul sănătății: ton mediu al pielii',
    '👩🏾‍⚕' => 'lucrătoare în domeniul sănătății: ton semi‑închis al pielii',
    '👩🏿‍⚕' => 'lucrătoare în domeniul sănătății: ton închis al pielii',
    '🧑🏻‍🎓' => 'student sau studentă: ton deschis al pielii',
    '🧑🏼‍🎓' => 'student sau studentă: ton semi‑deschis al pielii',
    '🧑🏽‍🎓' => 'student sau studentă: ton mediu al pielii',
    '🧑🏾‍🎓' => 'student sau studentă: ton semi‑închis al pielii',
    '🧑🏿‍🎓' => 'student sau studentă: ton închis al pielii',
    '👨🏻‍🎓' => 'student: ton deschis al pielii',
    '👨🏼‍🎓' => 'student: ton semi‑deschis al pielii',
    '👨🏽‍🎓' => 'student: ton mediu al pielii',
    '👨🏾‍🎓' => 'student: ton semi‑închis al pielii',
    '👨🏿‍🎓' => 'student: ton închis al pielii',
    '👩🏻‍🎓' => 'studentă: ton deschis al pielii',
    '👩🏼‍🎓' => 'studentă: ton semi‑deschis al pielii',
    '👩🏽‍🎓' => 'studentă: ton mediu al pielii',
    '👩🏾‍🎓' => 'studentă: ton semi‑închis al pielii',
    '👩🏿‍🎓' => 'studentă: ton închis al pielii',
    '🧑🏻‍🏫' => 'profesor sau profesoară: ton deschis al pielii',
    '🧑🏼‍🏫' => 'profesor sau profesoară: ton semi‑deschis al pielii',
    '🧑🏽‍🏫' => 'profesor sau profesoară: ton mediu al pielii',
    '🧑🏾‍🏫' => 'profesor sau profesoară: ton semi‑închis al pielii',
    '🧑🏿‍🏫' => 'profesor sau profesoară: ton închis al pielii',
    '👨🏻‍🏫' => 'profesor: ton deschis al pielii',
    '👨🏼‍🏫' => 'profesor: ton semi‑deschis al pielii',
    '👨🏽‍🏫' => 'profesor: ton mediu al pielii',
    '👨🏾‍🏫' => 'profesor: ton semi‑închis al pielii',
    '👨🏿‍🏫' => 'profesor: ton închis al pielii',
    '👩🏻‍🏫' => 'profesoară: ton deschis al pielii',
    '👩🏼‍🏫' => 'profesoară: ton semi‑deschis al pielii',
    '👩🏽‍🏫' => 'profesoară: ton mediu al pielii',
    '👩🏾‍🏫' => 'profesoară: ton semi‑închis al pielii',
    '👩🏿‍🏫' => 'profesoară: ton închis al pielii',
    '🧑🏻‍⚖' => 'judecător sau judecătoare: ton deschis al pielii',
    '🧑🏼‍⚖' => 'judecător sau judecătoare: ton semi‑deschis al pielii',
    '🧑🏽‍⚖' => 'judecător sau judecătoare: ton mediu al pielii',
    '🧑🏾‍⚖' => 'judecător sau judecătoare: ton semi‑închis al pielii',
    '🧑🏿‍⚖' => 'judecător sau judecătoare: ton închis al pielii',
    '👨🏻‍⚖' => 'judecător: ton deschis al pielii',
    '👨🏼‍⚖' => 'judecător: ton semi‑deschis al pielii',
    '👨🏽‍⚖' => 'judecător: ton mediu al pielii',
    '👨🏾‍⚖' => 'judecător: ton semi‑închis al pielii',
    '👨🏿‍⚖' => 'judecător: ton închis al pielii',
    '👩🏻‍⚖' => 'judecătoare: ton deschis al pielii',
    '👩🏼‍⚖' => 'judecătoare: ton semi‑deschis al pielii',
    '👩🏽‍⚖' => 'judecătoare: ton mediu al pielii',
    '👩🏾‍⚖' => 'judecătoare: ton semi‑închis al pielii',
    '👩🏿‍⚖' => 'judecătoare: ton închis al pielii',
    '🧑🏻‍🌾' => 'fermier sau fermieră: ton deschis al pielii',
    '🧑🏼‍🌾' => 'fermier sau fermieră: ton semi‑deschis al pielii',
    '🧑🏽‍🌾' => 'fermier sau fermieră: ton mediu al pielii',
    '🧑🏾‍🌾' => 'fermier sau fermieră: ton semi‑închis al pielii',
    '🧑🏿‍🌾' => 'fermier sau fermieră: ton închis al pielii',
    '👨🏻‍🌾' => 'fermier: ton deschis al pielii',
    '👨🏼‍🌾' => 'fermier: ton semi‑deschis al pielii',
    '👨🏽‍🌾' => 'fermier: ton mediu al pielii',
    '👨🏾‍🌾' => 'fermier: ton semi‑închis al pielii',
    '👨🏿‍🌾' => 'fermier: ton închis al pielii',
    '👩🏻‍🌾' => 'fermieră: ton deschis al pielii',
    '👩🏼‍🌾' => 'fermieră: ton semi‑deschis al pielii',
    '👩🏽‍🌾' => 'fermieră: ton mediu al pielii',
    '👩🏾‍🌾' => 'fermieră: ton semi‑închis al pielii',
    '👩🏿‍🌾' => 'fermieră: ton închis al pielii',
    '🧑🏻‍🍳' => 'bucătar sau bucătăreasă: ton deschis al pielii',
    '🧑🏼‍🍳' => 'bucătar sau bucătăreasă: ton semi‑deschis al pielii',
    '🧑🏽‍🍳' => 'bucătar sau bucătăreasă: ton mediu al pielii',
    '🧑🏾‍🍳' => 'bucătar sau bucătăreasă: ton semi‑închis al pielii',
    '🧑🏿‍🍳' => 'bucătar sau bucătăreasă: ton închis al pielii',
    '👨🏻‍🍳' => 'bucătar: ton deschis al pielii',
    '👨🏼‍🍳' => 'bucătar: ton semi‑deschis al pielii',
    '👨🏽‍🍳' => 'bucătar: ton mediu al pielii',
    '👨🏾‍🍳' => 'bucătar: ton semi‑închis al pielii',
    '👨🏿‍🍳' => 'bucătar: ton închis al pielii',
    '👩🏻‍🍳' => 'bucătăreasă: ton deschis al pielii',
    '👩🏼‍🍳' => 'bucătăreasă: ton semi‑deschis al pielii',
    '👩🏽‍🍳' => 'bucătăreasă: ton mediu al pielii',
    '👩🏾‍🍳' => 'bucătăreasă: ton semi‑închis al pielii',
    '👩🏿‍🍳' => 'bucătăreasă: ton închis al pielii',
    '🧑🏻‍🔧' => 'mecanic: ton deschis al pielii',
    '🧑🏼‍🔧' => 'mecanic: ton semi‑deschis al pielii',
    '🧑🏽‍🔧' => 'mecanic: ton mediu al pielii',
    '🧑🏾‍🔧' => 'mecanic: ton semi‑închis al pielii',
    '🧑🏿‍🔧' => 'mecanic: ton închis al pielii',
    '👨🏻‍🔧' => 'mecanic bărbat: ton deschis al pielii',
    '👨🏼‍🔧' => 'mecanic bărbat: ton semi‑deschis al pielii',
    '👨🏽‍🔧' => 'mecanic bărbat: ton mediu al pielii',
    '👨🏾‍🔧' => 'mecanic bărbat: ton semi‑închis al pielii',
    '👨🏿‍🔧' => 'mecanic bărbat: ton închis al pielii',
    '👩🏻‍🔧' => 'mecanic femeie: ton deschis al pielii',
    '👩🏼‍🔧' => 'mecanic femeie: ton semi‑deschis al pielii',
    '👩🏽‍🔧' => 'mecanic femeie: ton mediu al pielii',
    '👩🏾‍🔧' => 'mecanic femeie: ton semi‑închis al pielii',
    '👩🏿‍🔧' => 'mecanic femeie: ton închis al pielii',
    '🧑🏻‍🏭' => 'muncitor sau muncitoare în fabrică: ton deschis al pielii',
    '🧑🏼‍🏭' => 'muncitor sau muncitoare în fabrică: ton semi‑deschis al pielii',
    '🧑🏽‍🏭' => 'muncitor sau muncitoare în fabrică: ton mediu al pielii',
    '🧑🏾‍🏭' => 'muncitor sau muncitoare în fabrică: ton semi‑închis al pielii',
    '🧑🏿‍🏭' => 'muncitor sau muncitoare în fabrică: ton închis al pielii',
    '👨🏻‍🏭' => 'muncitor în fabrică: ton deschis al pielii',
    '👨🏼‍🏭' => 'muncitor în fabrică: ton semi‑deschis al pielii',
    '👨🏽‍🏭' => 'muncitor în fabrică: ton mediu al pielii',
    '👨🏾‍🏭' => 'muncitor în fabrică: ton semi‑închis al pielii',
    '👨🏿‍🏭' => 'muncitor în fabrică: ton închis al pielii',
    '👩🏻‍🏭' => 'muncitoare în fabrică: ton deschis al pielii',
    '👩🏼‍🏭' => 'muncitoare în fabrică: ton semi‑deschis al pielii',
    '👩🏽‍🏭' => 'muncitoare în fabrică: ton mediu al pielii',
    '👩🏾‍🏭' => 'muncitoare în fabrică: ton semi‑închis al pielii',
    '👩🏿‍🏭' => 'muncitoare în fabrică: ton închis al pielii',
    '🧑🏻‍💼' => 'funcționar sau funcționară: ton deschis al pielii',
    '🧑🏼‍💼' => 'funcționar sau funcționară: ton semi‑deschis al pielii',
    '🧑🏽‍💼' => 'funcționar sau funcționară: ton mediu al pielii',
    '🧑🏾‍💼' => 'funcționar sau funcționară: ton semi‑închis al pielii',
    '🧑🏿‍💼' => 'funcționar sau funcționară: ton închis al pielii',
    '👨🏻‍💼' => 'funcționar: ton deschis al pielii',
    '👨🏼‍💼' => 'funcționar: ton semi‑deschis al pielii',
    '👨🏽‍💼' => 'funcționar: ton mediu al pielii',
    '👨🏾‍💼' => 'funcționar: ton semi‑închis al pielii',
    '👨🏿‍💼' => 'funcționar: ton închis al pielii',
    '👩🏻‍💼' => 'funcționară: ton deschis al pielii',
    '👩🏼‍💼' => 'funcționară: ton semi‑deschis al pielii',
    '👩🏽‍💼' => 'funcționară: ton mediu al pielii',
    '👩🏾‍💼' => 'funcționară: ton semi‑închis al pielii',
    '👩🏿‍💼' => 'funcționară: ton închis al pielii',
    '🧑🏻‍🔬' => 'om de știință: ton deschis al pielii',
    '🧑🏼‍🔬' => 'om de știință: ton semi‑deschis al pielii',
    '🧑🏽‍🔬' => 'om de știință: ton mediu al pielii',
    '🧑🏾‍🔬' => 'om de știință: ton semi‑închis al pielii',
    '🧑🏿‍🔬' => 'om de știință: ton închis al pielii',
    '👨🏻‍🔬' => 'om de știință bărbat: ton deschis al pielii',
    '👨🏼‍🔬' => 'om de știință bărbat: ton semi‑deschis al pielii',
    '👨🏽‍🔬' => 'om de știință bărbat: ton mediu al pielii',
    '👨🏾‍🔬' => 'om de știință bărbat: ton semi‑închis al pielii',
    '👨🏿‍🔬' => 'om de știință bărbat: ton închis al pielii',
    '👩🏻‍🔬' => 'om de știință femeie: ton deschis al pielii',
    '👩🏼‍🔬' => 'om de știință femeie: ton semi‑deschis al pielii',
    '👩🏽‍🔬' => 'om de știință femeie: ton mediu al pielii',
    '👩🏾‍🔬' => 'om de știință femeie: ton semi‑închis al pielii',
    '👩🏿‍🔬' => 'om de știință femeie: ton închis al pielii',
    '🧑🏻‍💻' => 'specialist sau specialistă IT: ton deschis al pielii',
    '🧑🏼‍💻' => 'specialist sau specialistă IT: ton semi‑deschis al pielii',
    '🧑🏽‍💻' => 'specialist sau specialistă IT: ton mediu al pielii',
    '🧑🏾‍💻' => 'specialist sau specialistă IT: ton semi‑închis al pielii',
    '🧑🏿‍💻' => 'specialist sau specialistă IT: ton închis al pielii',
    '👨🏻‍💻' => 'specialist IT: ton deschis al pielii',
    '👨🏼‍💻' => 'specialist IT: ton semi‑deschis al pielii',
    '👨🏽‍💻' => 'specialist IT: ton mediu al pielii',
    '👨🏾‍💻' => 'specialist IT: ton semi‑închis al pielii',
    '👨🏿‍💻' => 'specialist IT: ton închis al pielii',
    '👩🏻‍💻' => 'specialistă IT: ton deschis al pielii',
    '👩🏼‍💻' => 'specialistă IT: ton semi‑deschis al pielii',
    '👩🏽‍💻' => 'specialistă IT: ton mediu al pielii',
    '👩🏾‍💻' => 'specialistă IT: ton semi‑închis al pielii',
    '👩🏿‍💻' => 'specialistă IT: ton închis al pielii',
    '🧑🏻‍🎤' => 'cântăreț sau cântăreață: ton deschis al pielii',
    '🧑🏼‍🎤' => 'cântăreț sau cântăreață: ton semi‑deschis al pielii',
    '🧑🏽‍🎤' => 'cântăreț sau cântăreață: ton mediu al pielii',
    '🧑🏾‍🎤' => 'cântăreț sau cântăreață: ton semi‑închis al pielii',
    '🧑🏿‍🎤' => 'cântăreț sau cântăreață: ton închis al pielii',
    '👨🏻‍🎤' => 'cântăreț: ton deschis al pielii',
    '👨🏼‍🎤' => 'cântăreț: ton semi‑deschis al pielii',
    '👨🏽‍🎤' => 'cântăreț: ton mediu al pielii',
    '👨🏾‍🎤' => 'cântăreț: ton semi‑închis al pielii',
    '👨🏿‍🎤' => 'cântăreț: ton închis al pielii',
    '👩🏻‍🎤' => 'cântăreață: ton deschis al pielii',
    '👩🏼‍🎤' => 'cântăreață: ton semi‑deschis al pielii',
    '👩🏽‍🎤' => 'cântăreață: ton mediu al pielii',
    '👩🏾‍🎤' => 'cântăreață: ton semi‑închis al pielii',
    '👩🏿‍🎤' => 'cântăreață: ton închis al pielii',
    '🧑🏻‍🎨' => 'artist sau artistă: ton deschis al pielii',
    '🧑🏼‍🎨' => 'artist sau artistă: ton semi‑deschis al pielii',
    '🧑🏽‍🎨' => 'artist sau artistă: ton mediu al pielii',
    '🧑🏾‍🎨' => 'artist sau artistă: ton semi‑închis al pielii',
    '🧑🏿‍🎨' => 'artist sau artistă: ton închis al pielii',
    '👨🏻‍🎨' => 'artist: ton deschis al pielii',
    '👨🏼‍🎨' => 'artist: ton semi‑deschis al pielii',
    '👨🏽‍🎨' => 'artist: ton mediu al pielii',
    '👨🏾‍🎨' => 'artist: ton semi‑închis al pielii',
    '👨🏿‍🎨' => 'artist: ton închis al pielii',
    '👩🏻‍🎨' => 'artistă: ton deschis al pielii',
    '👩🏼‍🎨' => 'artistă: ton semi‑deschis al pielii',
    '👩🏽‍🎨' => 'artistă: ton mediu al pielii',
    '👩🏾‍🎨' => 'artistă: ton semi‑închis al pielii',
    '👩🏿‍🎨' => 'artistă: ton închis al pielii',
    '🧑🏻‍✈' => 'pilot: ton deschis al pielii',
    '🧑🏼‍✈' => 'pilot: ton semi‑deschis al pielii',
    '🧑🏽‍✈' => 'pilot: ton mediu al pielii',
    '🧑🏾‍✈' => 'pilot: ton semi‑închis al pielii',
    '🧑🏿‍✈' => 'pilot: ton închis al pielii',
    '👨🏻‍✈' => 'pilot bărbat: ton deschis al pielii',
    '👨🏼‍✈' => 'pilot bărbat: ton semi‑deschis al pielii',
    '👨🏽‍✈' => 'pilot bărbat: ton mediu al pielii',
    '👨🏾‍✈' => 'pilot bărbat: ton semi‑închis al pielii',
    '👨🏿‍✈' => 'pilot bărbat: ton închis al pielii',
    '👩🏻‍✈' => 'pilot femeie: ton deschis al pielii',
    '👩🏼‍✈' => 'pilot femeie: ton semi‑deschis al pielii',
    '👩🏽‍✈' => 'pilot femeie: ton mediu al pielii',
    '👩🏾‍✈' => 'pilot femeie: ton semi‑închis al pielii',
    '👩🏿‍✈' => 'pilot femeie: ton închis al pielii',
    '🧑🏻‍🚀' => 'astronaut sau astronaută: ton deschis al pielii',
    '🧑🏼‍🚀' => 'astronaut sau astronaută: ton semi‑deschis al pielii',
    '🧑🏽‍🚀' => 'astronaut sau astronaută: ton mediu al pielii',
    '🧑🏾‍🚀' => 'astronaut sau astronaută: ton semi‑închis al pielii',
    '🧑🏿‍🚀' => 'astronaut sau astronaută: ton închis al pielii',
    '👨🏻‍🚀' => 'astronaut: ton deschis al pielii',
    '👨🏼‍🚀' => 'astronaut: ton semi‑deschis al pielii',
    '👨🏽‍🚀' => 'astronaut: ton mediu al pielii',
    '👨🏾‍🚀' => 'astronaut: ton semi‑închis al pielii',
    '👨🏿‍🚀' => 'astronaut: ton închis al pielii',
    '👩🏻‍🚀' => 'astronaută: ton deschis al pielii',
    '👩🏼‍🚀' => 'astronaută: ton semi‑deschis al pielii',
    '👩🏽‍🚀' => 'astronaută: ton mediu al pielii',
    '👩🏾‍🚀' => 'astronaută: ton semi‑închis al pielii',
    '👩🏿‍🚀' => 'astronaută: ton închis al pielii',
    '🧑🏻‍🚒' => 'pompier: ton deschis al pielii',
    '🧑🏼‍🚒' => 'pompier: ton semi‑deschis al pielii',
    '🧑🏽‍🚒' => 'pompier: ton mediu al pielii',
    '🧑🏾‍🚒' => 'pompier: ton semi‑închis al pielii',
    '🧑🏿‍🚒' => 'pompier: ton închis al pielii',
    '👨🏻‍🚒' => 'pompier bărbat: ton deschis al pielii',
    '👨🏼‍🚒' => 'pompier bărbat: ton semi‑deschis al pielii',
    '👨🏽‍🚒' => 'pompier bărbat: ton mediu al pielii',
    '👨🏾‍🚒' => 'pompier bărbat: ton semi‑închis al pielii',
    '👨🏿‍🚒' => 'pompier bărbat: ton închis al pielii',
    '👩🏻‍🚒' => 'pompier femeie: ton deschis al pielii',
    '👩🏼‍🚒' => 'pompier femeie: ton semi‑deschis al pielii',
    '👩🏽‍🚒' => 'pompier femeie: ton mediu al pielii',
    '👩🏾‍🚒' => 'pompier femeie: ton semi‑închis al pielii',
    '👩🏿‍🚒' => 'pompier femeie: ton închis al pielii',
    '👮🏻‍♂' => 'polițist: ton deschis al pielii',
    '👮🏼‍♂' => 'polițist: ton semi‑deschis al pielii',
    '👮🏽‍♂' => 'polițist: ton mediu al pielii',
    '👮🏾‍♂' => 'polițist: ton semi‑închis al pielii',
    '👮🏿‍♂' => 'polițist: ton închis al pielii',
    '👮🏻‍♀' => 'polițistă: ton deschis al pielii',
    '👮🏼‍♀' => 'polițistă: ton semi‑deschis al pielii',
    '👮🏽‍♀' => 'polițistă: ton mediu al pielii',
    '👮🏾‍♀' => 'polițistă: ton semi‑închis al pielii',
    '👮🏿‍♀' => 'polițistă: ton închis al pielii',
    '🕵🏻‍♂' => 'detectiv bărbat: ton deschis al pielii',
    '🕵🏼‍♂' => 'detectiv bărbat: ton semi‑deschis al pielii',
    '🕵🏽‍♂' => 'detectiv bărbat: ton mediu al pielii',
    '🕵🏾‍♂' => 'detectiv bărbat: ton semi‑închis al pielii',
    '🕵🏿‍♂' => 'detectiv bărbat: ton închis al pielii',
    '🕵🏻‍♀' => 'detectiv femeie: ton deschis al pielii',
    '🕵🏼‍♀' => 'detectiv femeie: ton semi‑deschis al pielii',
    '🕵🏽‍♀' => 'detectiv femeie: ton mediu al pielii',
    '🕵🏾‍♀' => 'detectiv femeie: ton semi‑închis al pielii',
    '🕵🏿‍♀' => 'detectiv femeie: ton închis al pielii',
    '💂🏻‍♂' => 'gardian bărbat: ton deschis al pielii',
    '💂🏼‍♂' => 'gardian bărbat: ton semi‑deschis al pielii',
    '💂🏽‍♂' => 'gardian bărbat: ton mediu al pielii',
    '💂🏾‍♂' => 'gardian bărbat: ton semi‑închis al pielii',
    '💂🏿‍♂' => 'gardian bărbat: ton închis al pielii',
    '💂🏻‍♀' => 'gardian femeie: ton deschis al pielii',
    '💂🏼‍♀' => 'gardian femeie: ton semi‑deschis al pielii',
    '💂🏽‍♀' => 'gardian femeie: ton mediu al pielii',
    '💂🏾‍♀' => 'gardian femeie: ton semi‑închis al pielii',
    '💂🏿‍♀' => 'gardian femeie: ton închis al pielii',
    '👷🏻‍♂' => 'muncitor în construcții: ton deschis al pielii',
    '👷🏼‍♂' => 'muncitor în construcții: ton semi‑deschis al pielii',
    '👷🏽‍♂' => 'muncitor în construcții: ton mediu al pielii',
    '👷🏾‍♂' => 'muncitor în construcții: ton semi‑închis al pielii',
    '👷🏿‍♂' => 'muncitor în construcții: ton închis al pielii',
    '👷🏻‍♀' => 'muncitoare în construcții: ton deschis al pielii',
    '👷🏼‍♀' => 'muncitoare în construcții: ton semi‑deschis al pielii',
    '👷🏽‍♀' => 'muncitoare în construcții: ton mediu al pielii',
    '👷🏾‍♀' => 'muncitoare în construcții: ton semi‑închis al pielii',
    '👷🏿‍♀' => 'muncitoare în construcții: ton închis al pielii',
    '👳🏻‍♂' => 'bărbat cu turban: ton deschis al pielii',
    '👳🏼‍♂' => 'bărbat cu turban: ton semi‑deschis al pielii',
    '👳🏽‍♂' => 'bărbat cu turban: ton mediu al pielii',
    '👳🏾‍♂' => 'bărbat cu turban: ton semi‑închis al pielii',
    '👳🏿‍♂' => 'bărbat cu turban: ton închis al pielii',
    '👳🏻‍♀' => 'femeie cu turban: ton deschis al pielii',
    '👳🏼‍♀' => 'femeie cu turban: ton semi‑deschis al pielii',
    '👳🏽‍♀' => 'femeie cu turban: ton mediu al pielii',
    '👳🏾‍♀' => 'femeie cu turban: ton semi‑închis al pielii',
    '👳🏿‍♀' => 'femeie cu turban: ton închis al pielii',
    '🤵🏻‍♂' => 'bărbat în smoching: ton deschis al pielii',
    '🤵🏼‍♂' => 'bărbat în smoching: ton semi‑deschis al pielii',
    '🤵🏽‍♂' => 'bărbat în smoching: ton mediu al pielii',
    '🤵🏾‍♂' => 'bărbat în smoching: ton semi‑închis al pielii',
    '🤵🏿‍♂' => 'bărbat în smoching: ton închis al pielii',
    '🤵🏻‍♀' => 'femeie în smoching: ton deschis al pielii',
    '🤵🏼‍♀' => 'femeie în smoching: ton semi‑deschis al pielii',
    '🤵🏽‍♀' => 'femeie în smoching: ton mediu al pielii',
    '🤵🏾‍♀' => 'femeie în smoching: ton semi‑închis al pielii',
    '🤵🏿‍♀' => 'femeie în smoching: ton închis al pielii',
    '👰🏻‍♂' => 'bărbat cu voal: ton deschis al pielii',
    '👰🏼‍♂' => 'bărbat cu voal: ton semi‑deschis al pielii',
    '👰🏽‍♂' => 'bărbat cu voal: ton mediu al pielii',
    '👰🏾‍♂' => 'bărbat cu voal: ton semi‑închis al pielii',
    '👰🏿‍♂' => 'bărbat cu voal: ton închis al pielii',
    '👰🏻‍♀' => 'femeie cu voal: ton deschis al pielii',
    '👰🏼‍♀' => 'femeie cu voal: ton semi‑deschis al pielii',
    '👰🏽‍♀' => 'femeie cu voal: ton mediu al pielii',
    '👰🏾‍♀' => 'femeie cu voal: ton semi‑închis al pielii',
    '👰🏿‍♀' => 'femeie cu voal: ton închis al pielii',
    '👩🏻‍🍼' => 'femeie hrănind un bebeluș: ton deschis al pielii',
    '👩🏼‍🍼' => 'femeie hrănind un bebeluș: ton semi‑deschis al pielii',
    '👩🏽‍🍼' => 'femeie hrănind un bebeluș: ton mediu al pielii',
    '👩🏾‍🍼' => 'femeie hrănind un bebeluș: ton semi‑închis al pielii',
    '👩🏿‍🍼' => 'femeie hrănind un bebeluș: ton închis al pielii',
    '👨🏻‍🍼' => 'bărbat hrănind un bebeluș: ton deschis al pielii',
    '👨🏼‍🍼' => 'bărbat hrănind un bebeluș: ton semi‑deschis al pielii',
    '👨🏽‍🍼' => 'bărbat hrănind un bebeluș: ton mediu al pielii',
    '👨🏾‍🍼' => 'bărbat hrănind un bebeluș: ton semi‑închis al pielii',
    '👨🏿‍🍼' => 'bărbat hrănind un bebeluș: ton închis al pielii',
    '🧑🏻‍🍼' => 'persoană hrănind un bebeluș: ton deschis al pielii',
    '🧑🏼‍🍼' => 'persoană hrănind un bebeluș: ton semi‑deschis al pielii',
    '🧑🏽‍🍼' => 'persoană hrănind un bebeluș: ton mediu al pielii',
    '🧑🏾‍🍼' => 'persoană hrănind un bebeluș: ton semi‑închis al pielii',
    '🧑🏿‍🍼' => 'persoană hrănind un bebeluș: ton închis al pielii',
    '🧑🏻‍🎄' => 'Crăciun: ton deschis al pielii',
    '🧑🏼‍🎄' => 'Crăciun: ton semi‑deschis al pielii',
    '🧑🏽‍🎄' => 'Crăciun: ton mediu al pielii',
    '🧑🏾‍🎄' => 'Crăciun: ton semi‑închis al pielii',
    '🧑🏿‍🎄' => 'Crăciun: ton închis al pielii',
    '🦸🏻‍♂' => 'supererou bărbat: ton deschis al pielii',
    '🦸🏼‍♂' => 'supererou bărbat: ton semi‑deschis al pielii',
    '🦸🏽‍♂' => 'supererou bărbat: ton mediu al pielii',
    '🦸🏾‍♂' => 'supererou bărbat: ton semi‑închis al pielii',
    '🦸🏿‍♂' => 'supererou bărbat: ton închis al pielii',
    '🦸🏻‍♀' => 'supererou femeie: ton deschis al pielii',
    '🦸🏼‍♀' => 'supererou femeie: ton semi‑deschis al pielii',
    '🦸🏽‍♀' => 'supererou femeie: ton mediu al pielii',
    '🦸🏾‍♀' => 'supererou femeie: ton semi‑închis al pielii',
    '🦸🏿‍♀' => 'supererou femeie: ton închis al pielii',
    '🦹🏻‍♂' => 'super-ticălos bărbat: ton deschis al pielii',
    '🦹🏼‍♂' => 'super-ticălos bărbat: ton semi‑deschis al pielii',
    '🦹🏽‍♂' => 'super-ticălos bărbat: ton mediu al pielii',
    '🦹🏾‍♂' => 'super-ticălos bărbat: ton semi‑închis al pielii',
    '🦹🏿‍♂' => 'super-ticălos bărbat: ton închis al pielii',
    '🦹🏻‍♀' => 'super-ticălos femeie: ton deschis al pielii',
    '🦹🏼‍♀' => 'super-ticălos femeie: ton semi‑deschis al pielii',
    '🦹🏽‍♀' => 'super-ticălos femeie: ton mediu al pielii',
    '🦹🏾‍♀' => 'super-ticălos femeie: ton semi‑închis al pielii',
    '🦹🏿‍♀' => 'super-ticălos femeie: ton închis al pielii',
    '🧙🏻‍♂' => 'bărbat mag: ton deschis al pielii',
    '🧙🏼‍♂' => 'bărbat mag: ton semi‑deschis al pielii',
    '🧙🏽‍♂' => 'bărbat mag: ton mediu al pielii',
    '🧙🏾‍♂' => 'bărbat mag: ton semi‑închis al pielii',
    '🧙🏿‍♂' => 'bărbat mag: ton închis al pielii',
    '🧙🏻‍♀' => 'femeie mag: ton deschis al pielii',
    '🧙🏼‍♀' => 'femeie mag: ton semi‑deschis al pielii',
    '🧙🏽‍♀' => 'femeie mag: ton mediu al pielii',
    '🧙🏾‍♀' => 'femeie mag: ton semi‑închis al pielii',
    '🧙🏿‍♀' => 'femeie mag: ton închis al pielii',
    '🧚🏻‍♂' => 'bărbat zână: ton deschis al pielii',
    '🧚🏼‍♂' => 'bărbat zână: ton semi‑deschis al pielii',
    '🧚🏽‍♂' => 'bărbat zână: ton mediu al pielii',
    '🧚🏾‍♂' => 'bărbat zână: ton semi‑închis al pielii',
    '🧚🏿‍♂' => 'bărbat zână: ton închis al pielii',
    '🧚🏻‍♀' => 'femeie zână: ton deschis al pielii',
    '🧚🏼‍♀' => 'femeie zână: ton semi‑deschis al pielii',
    '🧚🏽‍♀' => 'femeie zână: ton mediu al pielii',
    '🧚🏾‍♀' => 'femeie zână: ton semi‑închis al pielii',
    '🧚🏿‍♀' => 'femeie zână: ton închis al pielii',
    '🧛🏻‍♂' => 'bărbat vampir: ton deschis al pielii',
    '🧛🏼‍♂' => 'bărbat vampir: ton semi‑deschis al pielii',
    '🧛🏽‍♂' => 'bărbat vampir: ton mediu al pielii',
    '🧛🏾‍♂' => 'bărbat vampir: ton semi‑închis al pielii',
    '🧛🏿‍♂' => 'bărbat vampir: ton închis al pielii',
    '🧛🏻‍♀' => 'femeie vampir: ton deschis al pielii',
    '🧛🏼‍♀' => 'femeie vampir: ton semi‑deschis al pielii',
    '🧛🏽‍♀' => 'femeie vampir: ton mediu al pielii',
    '🧛🏾‍♀' => 'femeie vampir: ton semi‑închis al pielii',
    '🧛🏿‍♀' => 'femeie vampir: ton închis al pielii',
    '🧜🏻‍♂' => 'bărbat sirenă: ton deschis al pielii',
    '🧜🏼‍♂' => 'bărbat sirenă: ton semi‑deschis al pielii',
    '🧜🏽‍♂' => 'bărbat sirenă: ton mediu al pielii',
    '🧜🏾‍♂' => 'bărbat sirenă: ton semi‑închis al pielii',
    '🧜🏿‍♂' => 'bărbat sirenă: ton închis al pielii',
    '🧜🏻‍♀' => 'sirenă: ton deschis al pielii',
    '🧜🏼‍♀' => 'sirenă: ton semi‑deschis al pielii',
    '🧜🏽‍♀' => 'sirenă: ton mediu al pielii',
    '🧜🏾‍♀' => 'sirenă: ton semi‑închis al pielii',
    '🧜🏿‍♀' => 'sirenă: ton închis al pielii',
    '🧝🏻‍♂' => 'bărbat elf: ton deschis al pielii',
    '🧝🏼‍♂' => 'bărbat elf: ton semi‑deschis al pielii',
    '🧝🏽‍♂' => 'bărbat elf: ton mediu al pielii',
    '🧝🏾‍♂' => 'bărbat elf: ton semi‑închis al pielii',
    '🧝🏿‍♂' => 'bărbat elf: ton închis al pielii',
    '🧝🏻‍♀' => 'femeie elf: ton deschis al pielii',
    '🧝🏼‍♀' => 'femeie elf: ton semi‑deschis al pielii',
    '🧝🏽‍♀' => 'femeie elf: ton mediu al pielii',
    '🧝🏾‍♀' => 'femeie elf: ton semi‑închis al pielii',
    '🧝🏿‍♀' => 'femeie elf: ton închis al pielii',
    '💆🏻‍♂' => 'bărbat care primește un masaj facial: ton deschis al pielii',
    '💆🏼‍♂' => 'bărbat care primește un masaj facial: ton semi‑deschis al pielii',
    '💆🏽‍♂' => 'bărbat care primește un masaj facial: ton mediu al pielii',
    '💆🏾‍♂' => 'bărbat care primește un masaj facial: ton semi‑închis al pielii',
    '💆🏿‍♂' => 'bărbat care primește un masaj facial: ton închis al pielii',
    '💆🏻‍♀' => 'femeie care primește un masaj facial: ton deschis al pielii',
    '💆🏼‍♀' => 'femeie care primește un masaj facial: ton semi‑deschis al pielii',
    '💆🏽‍♀' => 'femeie care primește un masaj facial: ton mediu al pielii',
    '💆🏾‍♀' => 'femeie care primește un masaj facial: ton semi‑închis al pielii',
    '💆🏿‍♀' => 'femeie care primește un masaj facial: ton închis al pielii',
    '💇🏻‍♂' => 'bărbat care se tunde: ton deschis al pielii',
    '💇🏼‍♂' => 'bărbat care se tunde: ton semi‑deschis al pielii',
    '💇🏽‍♂' => 'bărbat care se tunde: ton mediu al pielii',
    '💇🏾‍♂' => 'bărbat care se tunde: ton semi‑închis al pielii',
    '💇🏿‍♂' => 'bărbat care se tunde: ton închis al pielii',
    '💇🏻‍♀' => 'femeie care se tunde: ton deschis al pielii',
    '💇🏼‍♀' => 'femeie care se tunde: ton semi‑deschis al pielii',
    '💇🏽‍♀' => 'femeie care se tunde: ton mediu al pielii',
    '💇🏾‍♀' => 'femeie care se tunde: ton semi‑închis al pielii',
    '💇🏿‍♀' => 'femeie care se tunde: ton închis al pielii',
    '🚶🏻‍♂' => 'bărbat care merge: ton deschis al pielii',
    '🚶🏼‍♂' => 'bărbat care merge: ton semi‑deschis al pielii',
    '🚶🏽‍♂' => 'bărbat care merge: ton mediu al pielii',
    '🚶🏾‍♂' => 'bărbat care merge: ton semi‑închis al pielii',
    '🚶🏿‍♂' => 'bărbat care merge: ton închis al pielii',
    '🚶🏻‍♀' => 'femeie care merge: ton deschis al pielii',
    '🚶🏼‍♀' => 'femeie care merge: ton semi‑deschis al pielii',
    '🚶🏽‍♀' => 'femeie care merge: ton mediu al pielii',
    '🚶🏾‍♀' => 'femeie care merge: ton semi‑închis al pielii',
    '🚶🏿‍♀' => 'femeie care merge: ton închis al pielii',
    '🚶🏻‍➡' => 'persoană care merge: ton deschis al pielii, orientate spre dreapta',
    '🚶🏼‍➡' => 'persoană care merge: ton semi‑deschis al pielii, orientate spre dreapta',
    '🚶🏽‍➡' => 'persoană care merge: ton mediu al pielii, orientate spre dreapta',
    '🚶🏾‍➡' => 'persoană care merge: ton semi‑închis al pielii, orientate spre dreapta',
    '🚶🏿‍➡' => 'persoană care merge: ton închis al pielii, orientate spre dreapta',
    '🧍🏻‍♂' => 'bărbat în picioare: ton deschis al pielii',
    '🧍🏼‍♂' => 'bărbat în picioare: ton semi‑deschis al pielii',
    '🧍🏽‍♂' => 'bărbat în picioare: ton mediu al pielii',
    '🧍🏾‍♂' => 'bărbat în picioare: ton semi‑închis al pielii',
    '🧍🏿‍♂' => 'bărbat în picioare: ton închis al pielii',
    '🧍🏻‍♀' => 'femeie în picioare: ton deschis al pielii',
    '🧍🏼‍♀' => 'femeie în picioare: ton semi‑deschis al pielii',
    '🧍🏽‍♀' => 'femeie în picioare: ton mediu al pielii',
    '🧍🏾‍♀' => 'femeie în picioare: ton semi‑închis al pielii',
    '🧍🏿‍♀' => 'femeie în picioare: ton închis al pielii',
    '🧎🏻‍♂' => 'bărbat în genunchi: ton deschis al pielii',
    '🧎🏼‍♂' => 'bărbat în genunchi: ton semi‑deschis al pielii',
    '🧎🏽‍♂' => 'bărbat în genunchi: ton mediu al pielii',
    '🧎🏾‍♂' => 'bărbat în genunchi: ton semi‑închis al pielii',
    '🧎🏿‍♂' => 'bărbat în genunchi: ton închis al pielii',
    '🧎🏻‍♀' => 'femeie în genunchi: ton deschis al pielii',
    '🧎🏼‍♀' => 'femeie în genunchi: ton semi‑deschis al pielii',
    '🧎🏽‍♀' => 'femeie în genunchi: ton mediu al pielii',
    '🧎🏾‍♀' => 'femeie în genunchi: ton semi‑închis al pielii',
    '🧎🏿‍♀' => 'femeie în genunchi: ton închis al pielii',
    '🧎🏻‍➡' => 'persoană în genunchi: ton deschis al pielii, orientate spre dreapta',
    '🧎🏼‍➡' => 'persoană în genunchi: ton semi‑deschis al pielii, orientate spre dreapta',
    '🧎🏽‍➡' => 'persoană în genunchi: ton mediu al pielii, orientate spre dreapta',
    '🧎🏾‍➡' => 'persoană în genunchi: ton semi‑închis al pielii, orientate spre dreapta',
    '🧎🏿‍➡' => 'persoană în genunchi: ton închis al pielii, orientate spre dreapta',
    '🧑🏻‍🦯' => 'persoană cu baston pentru nevăzători: ton deschis al pielii',
    '🧑🏼‍🦯' => 'persoană cu baston pentru nevăzători: ton semi‑deschis al pielii',
    '🧑🏽‍🦯' => 'persoană cu baston pentru nevăzători: ton mediu al pielii',
    '🧑🏾‍🦯' => 'persoană cu baston pentru nevăzători: ton semi‑închis al pielii',
    '🧑🏿‍🦯' => 'persoană cu baston pentru nevăzători: ton închis al pielii',
    '👨🏻‍🦯' => 'bărbat cu baston pentru nevăzători: ton deschis al pielii',
    '👨🏼‍🦯' => 'bărbat cu baston pentru nevăzători: ton semi‑deschis al pielii',
    '👨🏽‍🦯' => 'bărbat cu baston pentru nevăzători: ton mediu al pielii',
    '👨🏾‍🦯' => 'bărbat cu baston pentru nevăzători: ton semi‑închis al pielii',
    '👨🏿‍🦯' => 'bărbat cu baston pentru nevăzători: ton închis al pielii',
    '👩🏻‍🦯' => 'femeie cu baston pentru nevăzători: ton deschis al pielii',
    '👩🏼‍🦯' => 'femeie cu baston pentru nevăzători: ton semi‑deschis al pielii',
    '👩🏽‍🦯' => 'femeie cu baston pentru nevăzători: ton mediu al pielii',
    '👩🏾‍🦯' => 'femeie cu baston pentru nevăzători: ton semi‑închis al pielii',
    '👩🏿‍🦯' => 'femeie cu baston pentru nevăzători: ton închis al pielii',
    '🧑🏻‍🦼' => 'persoană în scaun cu rotile motorizat: ton deschis al pielii',
    '🧑🏼‍🦼' => 'persoană în scaun cu rotile motorizat: ton semi‑deschis al pielii',
    '🧑🏽‍🦼' => 'persoană în scaun cu rotile motorizat: ton mediu al pielii',
    '🧑🏾‍🦼' => 'persoană în scaun cu rotile motorizat: ton semi‑închis al pielii',
    '🧑🏿‍🦼' => 'persoană în scaun cu rotile motorizat: ton închis al pielii',
    '👨🏻‍🦼' => 'bărbat în scaun cu rotile motorizat: ton deschis al pielii',
    '👨🏼‍🦼' => 'bărbat în scaun cu rotile motorizat: ton semi‑deschis al pielii',
    '👨🏽‍🦼' => 'bărbat în scaun cu rotile motorizat: ton mediu al pielii',
    '👨🏾‍🦼' => 'bărbat în scaun cu rotile motorizat: ton semi‑închis al pielii',
    '👨🏿‍🦼' => 'bărbat în scaun cu rotile motorizat: ton închis al pielii',
    '👩🏻‍🦼' => 'femeie în scaun cu rotile motorizat: ton deschis al pielii',
    '👩🏼‍🦼' => 'femeie în scaun cu rotile motorizat: ton semi‑deschis al pielii',
    '👩🏽‍🦼' => 'femeie în scaun cu rotile motorizat: ton mediu al pielii',
    '👩🏾‍🦼' => 'femeie în scaun cu rotile motorizat: ton semi‑închis al pielii',
    '👩🏿‍🦼' => 'femeie în scaun cu rotile motorizat: ton închis al pielii',
    '🧑🏻‍🦽' => 'persoană în scaun cu rotile manual: ton deschis al pielii',
    '🧑🏼‍🦽' => 'persoană în scaun cu rotile manual: ton semi‑deschis al pielii',
    '🧑🏽‍🦽' => 'persoană în scaun cu rotile manual: ton mediu al pielii',
    '🧑🏾‍🦽' => 'persoană în scaun cu rotile manual: ton semi‑închis al pielii',
    '🧑🏿‍🦽' => 'persoană în scaun cu rotile manual: ton închis al pielii',
    '👨🏻‍🦽' => 'bărbat în scaun cu rotile manual: ton deschis al pielii',
    '👨🏼‍🦽' => 'bărbat în scaun cu rotile manual: ton semi‑deschis al pielii',
    '👨🏽‍🦽' => 'bărbat în scaun cu rotile manual: ton mediu al pielii',
    '👨🏾‍🦽' => 'bărbat în scaun cu rotile manual: ton semi‑închis al pielii',
    '👨🏿‍🦽' => 'bărbat în scaun cu rotile manual: ton închis al pielii',
    '👩🏻‍🦽' => 'femeie în scaun cu rotile manual: ton deschis al pielii',
    '👩🏼‍🦽' => 'femeie în scaun cu rotile manual: ton semi‑deschis al pielii',
    '👩🏽‍🦽' => 'femeie în scaun cu rotile manual: ton mediu al pielii',
    '👩🏾‍🦽' => 'femeie în scaun cu rotile manual: ton semi‑închis al pielii',
    '👩🏿‍🦽' => 'femeie în scaun cu rotile manual: ton închis al pielii',
    '🏃🏻‍♂' => 'bărbat care aleargă: ton deschis al pielii',
    '🏃🏼‍♂' => 'bărbat care aleargă: ton semi‑deschis al pielii',
    '🏃🏽‍♂' => 'bărbat care aleargă: ton mediu al pielii',
    '🏃🏾‍♂' => 'bărbat care aleargă: ton semi‑închis al pielii',
    '🏃🏿‍♂' => 'bărbat care aleargă: ton închis al pielii',
    '🏃🏻‍♀' => 'femeie care aleargă: ton deschis al pielii',
    '🏃🏼‍♀' => 'femeie care aleargă: ton semi‑deschis al pielii',
    '🏃🏽‍♀' => 'femeie care aleargă: ton mediu al pielii',
    '🏃🏾‍♀' => 'femeie care aleargă: ton semi‑închis al pielii',
    '🏃🏿‍♀' => 'femeie care aleargă: ton închis al pielii',
    '🏃🏻‍➡' => 'persoană care aleargă: ton deschis al pielii, orientate spre dreapta',
    '🏃🏼‍➡' => 'persoană care aleargă: ton semi‑deschis al pielii, orientate spre dreapta',
    '🏃🏽‍➡' => 'persoană care aleargă: ton mediu al pielii, orientate spre dreapta',
    '🏃🏾‍➡' => 'persoană care aleargă: ton semi‑închis al pielii, orientate spre dreapta',
    '🏃🏿‍➡' => 'persoană care aleargă: ton închis al pielii, orientate spre dreapta',
    '👯🏻‍♀' => 'femei care poartă urechi de iepuraș: ton deschis al pielii',
    '👯🏼‍♀' => 'femei care poartă urechi de iepuraș: ton semi‑deschis al pielii',
    '👯🏽‍♀' => 'femei care poartă urechi de iepuraș: ton mediu al pielii',
    '👯🏾‍♀' => 'femei care poartă urechi de iepuraș: ton semi‑închis al pielii',
    '👯🏿‍♀' => 'femei care poartă urechi de iepuraș: ton închis al pielii',
    '👯🏻‍♂' => 'bărbați care poartă urechi de iepuraș: ton deschis al pielii',
    '👯🏼‍♂' => 'bărbați care poartă urechi de iepuraș: ton semi‑deschis al pielii',
    '👯🏽‍♂' => 'bărbați care poartă urechi de iepuraș: ton mediu al pielii',
    '👯🏾‍♂' => 'bărbați care poartă urechi de iepuraș: ton semi‑închis al pielii',
    '👯🏿‍♂' => 'bărbați care poartă urechi de iepuraș: ton închis al pielii',
    '🧖🏻‍♂' => 'bărbat în saună: ton deschis al pielii',
    '🧖🏼‍♂' => 'bărbat în saună: ton semi‑deschis al pielii',
    '🧖🏽‍♂' => 'bărbat în saună: ton mediu al pielii',
    '🧖🏾‍♂' => 'bărbat în saună: ton semi‑închis al pielii',
    '🧖🏿‍♂' => 'bărbat în saună: ton închis al pielii',
    '🧖🏻‍♀' => 'femeie în saună: ton deschis al pielii',
    '🧖🏼‍♀' => 'femeie în saună: ton semi‑deschis al pielii',
    '🧖🏽‍♀' => 'femeie în saună: ton mediu al pielii',
    '🧖🏾‍♀' => 'femeie în saună: ton semi‑închis al pielii',
    '🧖🏿‍♀' => 'femeie în saună: ton închis al pielii',
    '🧗🏻‍♂' => 'bărbat care se cațără: ton deschis al pielii',
    '🧗🏼‍♂' => 'bărbat care se cațără: ton semi‑deschis al pielii',
    '🧗🏽‍♂' => 'bărbat care se cațără: ton mediu al pielii',
    '🧗🏾‍♂' => 'bărbat care se cațără: ton semi‑închis al pielii',
    '🧗🏿‍♂' => 'bărbat care se cațără: ton închis al pielii',
    '🧗🏻‍♀' => 'femeie care se cațără: ton deschis al pielii',
    '🧗🏼‍♀' => 'femeie care se cațără: ton semi‑deschis al pielii',
    '🧗🏽‍♀' => 'femeie care se cațără: ton mediu al pielii',
    '🧗🏾‍♀' => 'femeie care se cațără: ton semi‑închis al pielii',
    '🧗🏿‍♀' => 'femeie care se cațără: ton închis al pielii',
    '🏌🏻‍♂' => 'bărbat care joacă golf: ton deschis al pielii',
    '🏌🏼‍♂' => 'bărbat care joacă golf: ton semi‑deschis al pielii',
    '🏌🏽‍♂' => 'bărbat care joacă golf: ton mediu al pielii',
    '🏌🏾‍♂' => 'bărbat care joacă golf: ton semi‑închis al pielii',
    '🏌🏿‍♂' => 'bărbat care joacă golf: ton închis al pielii',
    '🏌🏻‍♀' => 'femeie care joacă golf: ton deschis al pielii',
    '🏌🏼‍♀' => 'femeie care joacă golf: ton semi‑deschis al pielii',
    '🏌🏽‍♀' => 'femeie care joacă golf: ton mediu al pielii',
    '🏌🏾‍♀' => 'femeie care joacă golf: ton semi‑închis al pielii',
    '🏌🏿‍♀' => 'femeie care joacă golf: ton închis al pielii',
    '🏄🏻‍♂' => 'bărbat care practică surfing: ton deschis al pielii',
    '🏄🏼‍♂' => 'bărbat care practică surfing: ton semi‑deschis al pielii',
    '🏄🏽‍♂' => 'bărbat care practică surfing: ton mediu al pielii',
    '🏄🏾‍♂' => 'bărbat care practică surfing: ton semi‑închis al pielii',
    '🏄🏿‍♂' => 'bărbat care practică surfing: ton închis al pielii',
    '🏄🏻‍♀' => 'femeie care practică surfing: ton deschis al pielii',
    '🏄🏼‍♀' => 'femeie care practică surfing: ton semi‑deschis al pielii',
    '🏄🏽‍♀' => 'femeie care practică surfing: ton mediu al pielii',
    '🏄🏾‍♀' => 'femeie care practică surfing: ton semi‑închis al pielii',
    '🏄🏿‍♀' => 'femeie care practică surfing: ton închis al pielii',
    '🚣🏻‍♂' => 'bărbat care vâslește în barcă: ton deschis al pielii',
    '🚣🏼‍♂' => 'bărbat care vâslește în barcă: ton semi‑deschis al pielii',
    '🚣🏽‍♂' => 'bărbat care vâslește în barcă: ton mediu al pielii',
    '🚣🏾‍♂' => 'bărbat care vâslește în barcă: ton semi‑închis al pielii',
    '🚣🏿‍♂' => 'bărbat care vâslește în barcă: ton închis al pielii',
    '🚣🏻‍♀' => 'femeie care vâslește în barcă: ton deschis al pielii',
    '🚣🏼‍♀' => 'femeie care vâslește în barcă: ton semi‑deschis al pielii',
    '🚣🏽‍♀' => 'femeie care vâslește în barcă: ton mediu al pielii',
    '🚣🏾‍♀' => 'femeie care vâslește în barcă: ton semi‑închis al pielii',
    '🚣🏿‍♀' => 'femeie care vâslește în barcă: ton închis al pielii',
    '🏊🏻‍♂' => 'bărbat care înoată: ton deschis al pielii',
    '🏊🏼‍♂' => 'bărbat care înoată: ton semi‑deschis al pielii',
    '🏊🏽‍♂' => 'bărbat care înoată: ton mediu al pielii',
    '🏊🏾‍♂' => 'bărbat care înoată: ton semi‑închis al pielii',
    '🏊🏿‍♂' => 'bărbat care înoată: ton închis al pielii',
    '🏊🏻‍♀' => 'femeie care înoată: ton deschis al pielii',
    '🏊🏼‍♀' => 'femeie care înoată: ton semi‑deschis al pielii',
    '🏊🏽‍♀' => 'femeie care înoată: ton mediu al pielii',
    '🏊🏾‍♀' => 'femeie care înoată: ton semi‑închis al pielii',
    '🏊🏿‍♀' => 'femeie care înoată: ton închis al pielii',
    '⛹🏻‍♂' => 'bărbat care bate mingea: ton deschis al pielii',
    '⛹🏼‍♂' => 'bărbat care bate mingea: ton semi‑deschis al pielii',
    '⛹🏽‍♂' => 'bărbat care bate mingea: ton mediu al pielii',
    '⛹🏾‍♂' => 'bărbat care bate mingea: ton semi‑închis al pielii',
    '⛹🏿‍♂' => 'bărbat care bate mingea: ton închis al pielii',
    '⛹🏻‍♀' => 'femeie care bate mingea: ton deschis al pielii',
    '⛹🏼‍♀' => 'femeie care bate mingea: ton semi‑deschis al pielii',
    '⛹🏽‍♀' => 'femeie care bate mingea: ton mediu al pielii',
    '⛹🏾‍♀' => 'femeie care bate mingea: ton semi‑închis al pielii',
    '⛹🏿‍♀' => 'femeie care bate mingea: ton închis al pielii',
    '🏋🏻‍♂' => 'bărbat care ridică greutăți: ton deschis al pielii',
    '🏋🏼‍♂' => 'bărbat care ridică greutăți: ton semi‑deschis al pielii',
    '🏋🏽‍♂' => 'bărbat care ridică greutăți: ton mediu al pielii',
    '🏋🏾‍♂' => 'bărbat care ridică greutăți: ton semi‑închis al pielii',
    '🏋🏿‍♂' => 'bărbat care ridică greutăți: ton închis al pielii',
    '🏋🏻‍♀' => 'femeie care ridică greutăți: ton deschis al pielii',
    '🏋🏼‍♀' => 'femeie care ridică greutăți: ton semi‑deschis al pielii',
    '🏋🏽‍♀' => 'femeie care ridică greutăți: ton mediu al pielii',
    '🏋🏾‍♀' => 'femeie care ridică greutăți: ton semi‑închis al pielii',
    '🏋🏿‍♀' => 'femeie care ridică greutăți: ton închis al pielii',
    '🚴🏻‍♂' => 'bărbat pe bicicletă: ton deschis al pielii',
    '🚴🏼‍♂' => 'bărbat pe bicicletă: ton semi‑deschis al pielii',
    '🚴🏽‍♂' => 'bărbat pe bicicletă: ton mediu al pielii',
    '🚴🏾‍♂' => 'bărbat pe bicicletă: ton semi‑închis al pielii',
    '🚴🏿‍♂' => 'bărbat pe bicicletă: ton închis al pielii',
    '🚴🏻‍♀' => 'femeie pe bicicletă: ton deschis al pielii',
    '🚴🏼‍♀' => 'femeie pe bicicletă: ton semi‑deschis al pielii',
    '🚴🏽‍♀' => 'femeie pe bicicletă: ton mediu al pielii',
    '🚴🏾‍♀' => 'femeie pe bicicletă: ton semi‑închis al pielii',
    '🚴🏿‍♀' => 'femeie pe bicicletă: ton închis al pielii',
    '🚵🏻‍♂' => 'bărbat pe bicicletă montană: ton deschis al pielii',
    '🚵🏼‍♂' => 'bărbat pe bicicletă montană: ton semi‑deschis al pielii',
    '🚵🏽‍♂' => 'bărbat pe bicicletă montană: ton mediu al pielii',
    '🚵🏾‍♂' => 'bărbat pe bicicletă montană: ton semi‑închis al pielii',
    '🚵🏿‍♂' => 'bărbat pe bicicletă montană: ton închis al pielii',
    '🚵🏻‍♀' => 'femeie pe bicicletă montană: ton deschis al pielii',
    '🚵🏼‍♀' => 'femeie pe bicicletă montană: ton semi‑deschis al pielii',
    '🚵🏽‍♀' => 'femeie pe bicicletă montană: ton mediu al pielii',
    '🚵🏾‍♀' => 'femeie pe bicicletă montană: ton semi‑închis al pielii',
    '🚵🏿‍♀' => 'femeie pe bicicletă montană: ton închis al pielii',
    '🤸🏻‍♂' => 'bărbat care face roata: ton deschis al pielii',
    '🤸🏼‍♂' => 'bărbat care face roata: ton semi‑deschis al pielii',
    '🤸🏽‍♂' => 'bărbat care face roata: ton mediu al pielii',
    '🤸🏾‍♂' => 'bărbat care face roata: ton semi‑închis al pielii',
    '🤸🏿‍♂' => 'bărbat care face roata: ton închis al pielii',
    '🤸🏻‍♀' => 'femeie care face roata: ton deschis al pielii',
    '🤸🏼‍♀' => 'femeie care face roata: ton semi‑deschis al pielii',
    '🤸🏽‍♀' => 'femeie care face roata: ton mediu al pielii',
    '🤸🏾‍♀' => 'femeie care face roata: ton semi‑închis al pielii',
    '🤸🏿‍♀' => 'femeie care face roata: ton închis al pielii',
    '🤼🏻‍♀' => 'femeie care practică wrestling: ton deschis al pielii',
    '🤼🏼‍♀' => 'femeie care practică wrestling: ton semi‑deschis al pielii',
    '🤼🏽‍♀' => 'femeie care practică wrestling: ton mediu al pielii',
    '🤼🏾‍♀' => 'femeie care practică wrestling: ton semi‑închis al pielii',
    '🤼🏿‍♀' => 'femeie care practică wrestling: ton închis al pielii',
    '🤼🏻‍♂' => 'bărbat care practică wrestling: ton deschis al pielii',
    '🤼🏼‍♂' => 'bărbat care practică wrestling: ton semi‑deschis al pielii',
    '🤼🏽‍♂' => 'bărbat care practică wrestling: ton mediu al pielii',
    '🤼🏾‍♂' => 'bărbat care practică wrestling: ton semi‑închis al pielii',
    '🤼🏿‍♂' => 'bărbat care practică wrestling: ton închis al pielii',
    '🤽🏻‍♂' => 'bărbat care joacă polo pe apă: ton deschis al pielii',
    '🤽🏼‍♂' => 'bărbat care joacă polo pe apă: ton semi‑deschis al pielii',
    '🤽🏽‍♂' => 'bărbat care joacă polo pe apă: ton mediu al pielii',
    '🤽🏾‍♂' => 'bărbat care joacă polo pe apă: ton semi‑închis al pielii',
    '🤽🏿‍♂' => 'bărbat care joacă polo pe apă: ton închis al pielii',
    '🤽🏻‍♀' => 'femeie care joacă polo pe apă: ton deschis al pielii',
    '🤽🏼‍♀' => 'femeie care joacă polo pe apă: ton semi‑deschis al pielii',
    '🤽🏽‍♀' => 'femeie care joacă polo pe apă: ton mediu al pielii',
    '🤽🏾‍♀' => 'femeie care joacă polo pe apă: ton semi‑închis al pielii',
    '🤽🏿‍♀' => 'femeie care joacă polo pe apă: ton închis al pielii',
    '🤾🏻‍♂' => 'bărbat care joacă handbal: ton deschis al pielii',
    '🤾🏼‍♂' => 'bărbat care joacă handbal: ton semi‑deschis al pielii',
    '🤾🏽‍♂' => 'bărbat care joacă handbal: ton mediu al pielii',
    '🤾🏾‍♂' => 'bărbat care joacă handbal: ton semi‑închis al pielii',
    '🤾🏿‍♂' => 'bărbat care joacă handbal: ton închis al pielii',
    '🤾🏻‍♀' => 'femeie care joacă handbal: ton deschis al pielii',
    '🤾🏼‍♀' => 'femeie care joacă handbal: ton semi‑deschis al pielii',
    '🤾🏽‍♀' => 'femeie care joacă handbal: ton mediu al pielii',
    '🤾🏾‍♀' => 'femeie care joacă handbal: ton semi‑închis al pielii',
    '🤾🏿‍♀' => 'femeie care joacă handbal: ton închis al pielii',
    '🤹🏻‍♂' => 'bărbat care jongleză: ton deschis al pielii',
    '🤹🏼‍♂' => 'bărbat care jongleză: ton semi‑deschis al pielii',
    '🤹🏽‍♂' => 'bărbat care jongleză: ton mediu al pielii',
    '🤹🏾‍♂' => 'bărbat care jongleză: ton semi‑închis al pielii',
    '🤹🏿‍♂' => 'bărbat care jongleză: ton închis al pielii',
    '🤹🏻‍♀' => 'femeie care jonglează: ton deschis al pielii',
    '🤹🏼‍♀' => 'femeie care jonglează: ton semi‑deschis al pielii',
    '🤹🏽‍♀' => 'femeie care jonglează: ton mediu al pielii',
    '🤹🏾‍♀' => 'femeie care jonglează: ton semi‑închis al pielii',
    '🤹🏿‍♀' => 'femeie care jonglează: ton închis al pielii',
    '🧘🏻‍♂' => 'bărbat în poziția lotus: ton deschis al pielii',
    '🧘🏼‍♂' => 'bărbat în poziția lotus: ton semi‑deschis al pielii',
    '🧘🏽‍♂' => 'bărbat în poziția lotus: ton mediu al pielii',
    '🧘🏾‍♂' => 'bărbat în poziția lotus: ton semi‑închis al pielii',
    '🧘🏿‍♂' => 'bărbat în poziția lotus: ton închis al pielii',
    '🧘🏻‍♀' => 'femeie în poziția lotus: ton deschis al pielii',
    '🧘🏼‍♀' => 'femeie în poziția lotus: ton semi‑deschis al pielii',
    '🧘🏽‍♀' => 'femeie în poziția lotus: ton mediu al pielii',
    '🧘🏾‍♀' => 'femeie în poziția lotus: ton semi‑închis al pielii',
    '🧘🏿‍♀' => 'femeie în poziția lotus: ton închis al pielii',
    '🧑‍🦰' => 'adult: păr roșcat',
    '🧑‍🦱' => 'adult: păr creț',
    '🧑‍🦳' => 'adult: păr alb',
    '🧑‍🦲' => 'adult: chelie',
    '👨‍🦰' => 'bărbat: păr roșcat',
    '👨‍🦱' => 'bărbat: păr creț',
    '👨‍🦳' => 'bărbat: păr alb',
    '👨‍🦲' => 'bărbat: chelie',
    '👩‍🦰' => 'femeie: păr roșcat',
    '👩‍🦱' => 'femeie: păr creț',
    '👩‍🦳' => 'femeie: păr alb',
    '👩‍🦲' => 'femeie: chelie',
    '🚶‍➡' => 'persoană care merge: orientate spre dreapta',
    '🧎‍➡' => 'persoană în genunchi: orientate spre dreapta',
    '🏃‍➡' => 'persoană care aleargă: orientate spre dreapta',
    '👨‍👦' => 'familie: bărbat, băiat',
    '👨‍👧' => 'familie: bărbat, fată',
    '👩‍👦' => 'familie: femeie, băiat',
    '👩‍👧' => 'familie: femeie, fată',
    '😶‍🌫' => 'față în nori',
    '😮‍💨' => 'față care expiră',
    '🙂‍↕' => 'cap care se clatină pe verticală',
    '😵‍💫' => 'față cu ochi în spirală',
    '❤‍🔥' => 'inimă în flăcări',
    '❤‍🩹' => 'inimă în convalescență',
    '👁‍🗨' => 'ochi în balon de dialog',
    '🧔‍♂' => 'bărbat: barbă',
    '👱‍♂' => 'bărbat blond',
    '🧔‍♀' => 'femeie: barbă',
    '👱‍♀' => 'femeie blondă',
    '🙍‍♂' => 'bărbat întristat',
    '🙍‍♀' => 'femeie întristată',
    '🙎‍♂' => 'bărbat bosumflat',
    '🙎‍♀' => 'femeie bosumflată',
    '🙅‍♂' => 'bărbat făcând un gest de negație',
    '🙅‍♀' => 'femeie făcând un gest de negație',
    '🙆‍♂' => 'bărbat făcând un gest de OK',
    '🙆‍♀' => 'femeie făcând un gest de OK',
    '💁‍♂' => 'bărbat care explică',
    '💁‍♀' => 'femeie care explică',
    '🙋‍♂' => 'bărbat care ridică mâna',
    '🙋‍♀' => 'femeie care ridică mâna',
    '🧏‍♂' => 'bărbat surd',
    '🧏‍♀' => 'femeie surdă',
    '🙇‍♂' => 'bărbat care se înclină',
    '🙇‍♀' => 'femeie care se înclină',
    '🤦‍♂' => 'bărbat care își acoperă fața cu o palmă',
    '🤦‍♀' => 'femeie care își acoperă fața cu o palmă',
    '🤷‍♂' => 'bărbat care ridică din umeri',
    '🤷‍♀' => 'femeie care ridică din umeri',
    '🧑‍⚕' => 'persoană lucrătoare în domeniul sănătății',
    '👨‍⚕' => 'lucrător în domeniul sănătății',
    '👩‍⚕' => 'lucrătoare în domeniul sănătății',
    '🧑‍🎓' => 'student sau studentă',
    '👨‍🎓' => 'student',
    '👩‍🎓' => 'studentă',
    '🧑‍🏫' => 'profesor sau profesoară',
    '👨‍🏫' => 'profesor',
    '👩‍🏫' => 'profesoară',
    '🧑‍⚖' => 'judecător sau judecătoare',
    '👨‍⚖' => 'judecător',
    '👩‍⚖' => 'judecătoare',
    '🧑‍🌾' => 'fermier sau fermieră',
    '👨‍🌾' => 'fermier',
    '👩‍🌾' => 'fermieră',
    '🧑‍🍳' => 'bucătar sau bucătăreasă',
    '👨‍🍳' => 'bucătar',
    '👩‍🍳' => 'bucătăreasă',
    '🧑‍🔧' => 'mecanic',
    '👨‍🔧' => 'mecanic bărbat',
    '👩‍🔧' => 'mecanic femeie',
    '🧑‍🏭' => 'muncitor sau muncitoare în fabrică',
    '👨‍🏭' => 'muncitor în fabrică',
    '👩‍🏭' => 'muncitoare în fabrică',
    '🧑‍💼' => 'funcționar sau funcționară',
    '👨‍💼' => 'funcționar',
    '👩‍💼' => 'funcționară',
    '🧑‍🔬' => 'om de știință',
    '👨‍🔬' => 'om de știință bărbat',
    '👩‍🔬' => 'om de știință femeie',
    '🧑‍💻' => 'specialist sau specialistă IT',
    '👨‍💻' => 'specialist IT',
    '👩‍💻' => 'specialistă IT',
    '🧑‍🎤' => 'cântăreț sau cântăreață',
    '👨‍🎤' => 'cântăreț',
    '👩‍🎤' => 'cântăreață',
    '🧑‍🎨' => 'artist sau artistă',
    '👨‍🎨' => 'artist',
    '👩‍🎨' => 'artistă',
    '🧑‍✈' => 'pilot',
    '👨‍✈' => 'pilot bărbat',
    '👩‍✈' => 'pilot femeie',
    '🧑‍🚀' => 'astronaut sau astronaută',
    '👨‍🚀' => 'astronaut',
    '👩‍🚀' => 'astronaută',
    '🧑‍🚒' => 'pompier',
    '👨‍🚒' => 'pompier bărbat',
    '👩‍🚒' => 'pompier femeie',
    '👮‍♂' => 'polițist',
    '👮‍♀' => 'polițistă',
    '🕵‍♂' => 'detectiv bărbat',
    '🕵‍♀' => 'detectiv femeie',
    '💂‍♂' => 'gardian bărbat',
    '💂‍♀' => 'gardian femeie',
    '👷‍♂' => 'muncitor în construcții',
    '👷‍♀' => 'muncitoare în construcții',
    '👳‍♂' => 'bărbat cu turban',
    '👳‍♀' => 'femeie cu turban',
    '🤵‍♂' => 'bărbat în smoching',
    '🤵‍♀' => 'femeie în smoching',
    '👰‍♂' => 'bărbat cu voal',
    '👰‍♀' => 'femeie cu voal',
    '👩‍🍼' => 'femeie hrănind un bebeluș',
    '👨‍🍼' => 'bărbat hrănind un bebeluș',
    '🧑‍🍼' => 'persoană hrănind un bebeluș',
    '🧑‍🎄' => 'Crăciun',
    '🦸‍♂' => 'supererou bărbat',
    '🦸‍♀' => 'supererou femeie',
    '🦹‍♂' => 'super-ticălos bărbat',
    '🦹‍♀' => 'super-ticălos femeie',
    '🧙‍♂' => 'bărbat mag',
    '🧙‍♀' => 'femeie mag',
    '🧚‍♂' => 'bărbat zână',
    '🧚‍♀' => 'femeie zână',
    '🧛‍♂' => 'bărbat vampir',
    '🧛‍♀' => 'femeie vampir',
    '🧜‍♂' => 'bărbat sirenă',
    '🧜‍♀' => 'sirenă',
    '🧝‍♂' => 'bărbat elf',
    '🧝‍♀' => 'femeie elf',
    '🧞‍♂' => 'bărbat duh',
    '🧞‍♀' => 'femeie duh',
    '🧟‍♂' => 'bărbat zombi',
    '🧟‍♀' => 'femeie zombi',
    '💆‍♂' => 'bărbat care primește un masaj facial',
    '💆‍♀' => 'femeie care primește un masaj facial',
    '💇‍♂' => 'bărbat care se tunde',
    '💇‍♀' => 'femeie care se tunde',
    '🚶‍♂' => 'bărbat care merge',
    '🚶‍♀' => 'femeie care merge',
    '🧍‍♂' => 'bărbat în picioare',
    '🧍‍♀' => 'femeie în picioare',
    '🧎‍♂' => 'bărbat în genunchi',
    '🧎‍♀' => 'femeie în genunchi',
    '🧑‍🦯' => 'persoană cu baston pentru nevăzători',
    '👨‍🦯' => 'bărbat cu baston pentru nevăzători',
    '👩‍🦯' => 'femeie cu baston pentru nevăzători',
    '🧑‍🦼' => 'persoană în scaun cu rotile motorizat',
    '👨‍🦼' => 'bărbat în scaun cu rotile motorizat',
    '👩‍🦼' => 'femeie în scaun cu rotile motorizat',
    '🧑‍🦽' => 'persoană în scaun cu rotile manual',
    '👨‍🦽' => 'bărbat în scaun cu rotile manual',
    '👩‍🦽' => 'femeie în scaun cu rotile manual',
    '🏃‍♂' => 'bărbat care aleargă',
    '🏃‍♀' => 'femeie care aleargă',
    '🧑‍🩰' => 'balerin sau balerină',
    '👯‍♂' => 'bărbați care poartă urechi de iepuraș',
    '👯‍♀' => 'femei care poartă urechi de iepuraș',
    '🧖‍♂' => 'bărbat în saună',
    '🧖‍♀' => 'femeie în saună',
    '🧗‍♂' => 'bărbat care se cațără',
    '🧗‍♀' => 'femeie care se cațără',
    '🏌‍♂' => 'bărbat care joacă golf',
    '🏌‍♀' => 'femeie care joacă golf',
    '🏄‍♂' => 'bărbat care practică surfing',
    '🏄‍♀' => 'femeie care practică surfing',
    '🚣‍♂' => 'bărbat care vâslește în barcă',
    '🚣‍♀' => 'femeie care vâslește în barcă',
    '🏊‍♂' => 'bărbat care înoată',
    '🏊‍♀' => 'femeie care înoată',
    '⛹‍♂' => 'bărbat care bate mingea',
    '⛹‍♀' => 'femeie care bate mingea',
    '🏋‍♂' => 'bărbat care ridică greutăți',
    '🏋‍♀' => 'femeie care ridică greutăți',
    '🚴‍♂' => 'bărbat pe bicicletă',
    '🚴‍♀' => 'femeie pe bicicletă',
    '🚵‍♂' => 'bărbat pe bicicletă montană',
    '🚵‍♀' => 'femeie pe bicicletă montană',
    '🤸‍♂' => 'bărbat care face roata',
    '🤸‍♀' => 'femeie care face roata',
    '🤼‍♂' => 'bărbat care practică wrestling',
    '🤼‍♀' => 'femeie care practică wrestling',
    '🤽‍♂' => 'bărbat care joacă polo pe apă',
    '🤽‍♀' => 'femeie care joacă polo pe apă',
    '🤾‍♂' => 'bărbat care joacă handbal',
    '🤾‍♀' => 'femeie care joacă handbal',
    '🤹‍♂' => 'bărbat care jongleză',
    '🤹‍♀' => 'femeie care jonglează',
    '🧘‍♂' => 'bărbat în poziția lotus',
    '🧘‍♀' => 'femeie în poziția lotus',
    '🧑‍🧒' => 'familie: adult, copil',
    '🐕‍🦺' => 'câine de asistență',
    '🐈‍⬛' => 'pisică neagră',
    '🐻‍❄' => 'urs polar',
    '🐦‍⬛' => 'pasăre neagră',
    '🐦‍🔥' => 'phoenix',
    '🍋‍🟩' => 'limetă',
    '🍄‍🟫' => 'ciupercă maro',
    '⛓‍💥' => 'lanț rupt',
    '🏳‍🌈' => 'steag curcubeu',
    '🏳‍⚧' => 'steag transgender',
    '🏴‍☠' => 'steagul piraților',
    '👋🏻' => 'mână fluturată: ton deschis al pielii',
    '👋🏼' => 'mână fluturată: ton semi‑deschis al pielii',
    '👋🏽' => 'mână fluturată: ton mediu al pielii',
    '👋🏾' => 'mână fluturată: ton semi‑închis al pielii',
    '👋🏿' => 'mână fluturată: ton închis al pielii',
    '🤚🏻' => 'dosul palmei ridicat: ton deschis al pielii',
    '🤚🏼' => 'dosul palmei ridicat: ton semi‑deschis al pielii',
    '🤚🏽' => 'dosul palmei ridicat: ton mediu al pielii',
    '🤚🏾' => 'dosul palmei ridicat: ton semi‑închis al pielii',
    '🤚🏿' => 'dosul palmei ridicat: ton închis al pielii',
    '🖐🏻' => 'mână ridicată cu degetele depărtate: ton deschis al pielii',
    '🖐🏼' => 'mână ridicată cu degetele depărtate: ton semi‑deschis al pielii',
    '🖐🏽' => 'mână ridicată cu degetele depărtate: ton mediu al pielii',
    '🖐🏾' => 'mână ridicată cu degetele depărtate: ton semi‑închis al pielii',
    '🖐🏿' => 'mână ridicată cu degetele depărtate: ton închis al pielii',
    '✋🏻' => 'mână ridicată: ton deschis al pielii',
    '✋🏼' => 'mână ridicată: ton semi‑deschis al pielii',
    '✋🏽' => 'mână ridicată: ton mediu al pielii',
    '✋🏾' => 'mână ridicată: ton semi‑închis al pielii',
    '✋🏿' => 'mână ridicată: ton închis al pielii',
    '🖖🏻' => 'salut vulcanian: ton deschis al pielii',
    '🖖🏼' => 'salut vulcanian: ton semi‑deschis al pielii',
    '🖖🏽' => 'salut vulcanian: ton mediu al pielii',
    '🖖🏾' => 'salut vulcanian: ton semi‑închis al pielii',
    '🖖🏿' => 'salut vulcanian: ton închis al pielii',
    '🫱🏻' => 'mână spre dreapta: ton deschis al pielii',
    '🫱🏼' => 'mână spre dreapta: ton semi‑deschis al pielii',
    '🫱🏽' => 'mână spre dreapta: ton mediu al pielii',
    '🫱🏾' => 'mână spre dreapta: ton semi‑închis al pielii',
    '🫱🏿' => 'mână spre dreapta: ton închis al pielii',
    '🫲🏻' => 'mână spre stânga: ton deschis al pielii',
    '🫲🏼' => 'mână spre stânga: ton semi‑deschis al pielii',
    '🫲🏽' => 'mână spre stânga: ton mediu al pielii',
    '🫲🏾' => 'mână spre stânga: ton semi‑închis al pielii',
    '🫲🏿' => 'mână spre stânga: ton închis al pielii',
    '🫳🏻' => 'mână cu palma în jos: ton deschis al pielii',
    '🫳🏼' => 'mână cu palma în jos: ton semi‑deschis al pielii',
    '🫳🏽' => 'mână cu palma în jos: ton mediu al pielii',
    '🫳🏾' => 'mână cu palma în jos: ton semi‑închis al pielii',
    '🫳🏿' => 'mână cu palma în jos: ton închis al pielii',
    '🫴🏻' => 'mână cu palma în sus: ton deschis al pielii',
    '🫴🏼' => 'mână cu palma în sus: ton semi‑deschis al pielii',
    '🫴🏽' => 'mână cu palma în sus: ton mediu al pielii',
    '🫴🏾' => 'mână cu palma în sus: ton semi‑închis al pielii',
    '🫴🏿' => 'mână cu palma în sus: ton închis al pielii',
    '🫷🏻' => 'mână care împinge spre stânga: ton deschis al pielii',
    '🫷🏼' => 'mână care împinge spre stânga: ton semi‑deschis al pielii',
    '🫷🏽' => 'mână care împinge spre stânga: ton mediu al pielii',
    '🫷🏾' => 'mână care împinge spre stânga: ton semi‑închis al pielii',
    '🫷🏿' => 'mână care împinge spre stânga: ton închis al pielii',
    '🫸🏻' => 'mână care împinge spre dreapta: ton deschis al pielii',
    '🫸🏼' => 'mână care împinge spre dreapta: ton semi‑deschis al pielii',
    '🫸🏽' => 'mână care împinge spre dreapta: ton mediu al pielii',
    '🫸🏾' => 'mână care împinge spre dreapta: ton semi‑închis al pielii',
    '🫸🏿' => 'mână care împinge spre dreapta: ton închis al pielii',
    '👌🏻' => 'semnul ok: ton deschis al pielii',
    '👌🏼' => 'semnul ok: ton semi‑deschis al pielii',
    '👌🏽' => 'semnul ok: ton mediu al pielii',
    '👌🏾' => 'semnul ok: ton semi‑închis al pielii',
    '👌🏿' => 'semnul ok: ton închis al pielii',
    '🤌🏻' => 'degete strânse: ton deschis al pielii',
    '🤌🏼' => 'degete strânse: ton semi‑deschis al pielii',
    '🤌🏽' => 'degete strânse: ton mediu al pielii',
    '🤌🏾' => 'degete strânse: ton semi‑închis al pielii',
    '🤌🏿' => 'degete strânse: ton închis al pielii',
    '🤏🏻' => 'mână cu două degete apropiate: ton deschis al pielii',
    '🤏🏼' => 'mână cu două degete apropiate: ton semi‑deschis al pielii',
    '🤏🏽' => 'mână cu două degete apropiate: ton mediu al pielii',
    '🤏🏾' => 'mână cu două degete apropiate: ton semi‑închis al pielii',
    '🤏🏿' => 'mână cu două degete apropiate: ton închis al pielii',
    '✌🏻' => 'semnul victoriei: ton deschis al pielii',
    '✌🏼' => 'semnul victoriei: ton semi‑deschis al pielii',
    '✌🏽' => 'semnul victoriei: ton mediu al pielii',
    '✌🏾' => 'semnul victoriei: ton semi‑închis al pielii',
    '✌🏿' => 'semnul victoriei: ton închis al pielii',
    '🤞🏻' => 'degete încrucișate: ton deschis al pielii',
    '🤞🏼' => 'degete încrucișate: ton semi‑deschis al pielii',
    '🤞🏽' => 'degete încrucișate: ton mediu al pielii',
    '🤞🏾' => 'degete încrucișate: ton semi‑închis al pielii',
    '🤞🏿' => 'degete încrucișate: ton închis al pielii',
    '🫰🏻' => 'mână cu degetul mare și arătătorul încrucișate: ton deschis al pielii',
    '🫰🏼' => 'mână cu degetul mare și arătătorul încrucișate: ton semi‑deschis al pielii',
    '🫰🏽' => 'mână cu degetul mare și arătătorul încrucișate: ton mediu al pielii',
    '🫰🏾' => 'mână cu degetul mare și arătătorul încrucișate: ton semi‑închis al pielii',
    '🫰🏿' => 'mână cu degetul mare și arătătorul încrucișate: ton închis al pielii',
    '🤟🏻' => 'gest cu semnificația te iubesc: ton deschis al pielii',
    '🤟🏼' => 'gest cu semnificația te iubesc: ton semi‑deschis al pielii',
    '🤟🏽' => 'gest cu semnificația te iubesc: ton mediu al pielii',
    '🤟🏾' => 'gest cu semnificația te iubesc: ton semi‑închis al pielii',
    '🤟🏿' => 'gest cu semnificația te iubesc: ton închis al pielii',
    '🤘🏻' => 'semnul cu coarne: ton deschis al pielii',
    '🤘🏼' => 'semnul cu coarne: ton semi‑deschis al pielii',
    '🤘🏽' => 'semnul cu coarne: ton mediu al pielii',
    '🤘🏾' => 'semnul cu coarne: ton semi‑închis al pielii',
    '🤘🏿' => 'semnul cu coarne: ton închis al pielii',
    '🤙🏻' => 'semnul sună-mă: ton deschis al pielii',
    '🤙🏼' => 'semnul sună-mă: ton semi‑deschis al pielii',
    '🤙🏽' => 'semnul sună-mă: ton mediu al pielii',
    '🤙🏾' => 'semnul sună-mă: ton semi‑închis al pielii',
    '🤙🏿' => 'semnul sună-mă: ton închis al pielii',
    '👈🏻' => 'dos de mână cu arătătorul spre stânga: ton deschis al pielii',
    '👈🏼' => 'dos de mână cu arătătorul spre stânga: ton semi‑deschis al pielii',
    '👈🏽' => 'dos de mână cu arătătorul spre stânga: ton mediu al pielii',
    '👈🏾' => 'dos de mână cu arătătorul spre stânga: ton semi‑închis al pielii',
    '👈🏿' => 'dos de mână cu arătătorul spre stânga: ton închis al pielii',
    '👉🏻' => 'dos de mână cu arătătorul spre dreapta: ton deschis al pielii',
    '👉🏼' => 'dos de mână cu arătătorul spre dreapta: ton semi‑deschis al pielii',
    '👉🏽' => 'dos de mână cu arătătorul spre dreapta: ton mediu al pielii',
    '👉🏾' => 'dos de mână cu arătătorul spre dreapta: ton semi‑închis al pielii',
    '👉🏿' => 'dos de mână cu arătătorul spre dreapta: ton închis al pielii',
    '👆🏻' => 'dos de mână cu arătătorul în sus: ton deschis al pielii',
    '👆🏼' => 'dos de mână cu arătătorul în sus: ton semi‑deschis al pielii',
    '👆🏽' => 'dos de mână cu arătătorul în sus: ton mediu al pielii',
    '👆🏾' => 'dos de mână cu arătătorul în sus: ton semi‑închis al pielii',
    '👆🏿' => 'dos de mână cu arătătorul în sus: ton închis al pielii',
    '🖕🏻' => 'degetul mijlociu: ton deschis al pielii',
    '🖕🏼' => 'degetul mijlociu: ton semi‑deschis al pielii',
    '🖕🏽' => 'degetul mijlociu: ton mediu al pielii',
    '🖕🏾' => 'degetul mijlociu: ton semi‑închis al pielii',
    '🖕🏿' => 'degetul mijlociu: ton închis al pielii',
    '👇🏻' => 'dos de mână cu arătătorul în jos: ton deschis al pielii',
    '👇🏼' => 'dos de mână cu arătătorul în jos: ton semi‑deschis al pielii',
    '👇🏽' => 'dos de mână cu arătătorul în jos: ton mediu al pielii',
    '👇🏾' => 'dos de mână cu arătătorul în jos: ton semi‑închis al pielii',
    '👇🏿' => 'dos de mână cu arătătorul în jos: ton închis al pielii',
    '☝🏻' => 'deget arătător îndreptat în sus: ton deschis al pielii',
    '☝🏼' => 'deget arătător îndreptat în sus: ton semi‑deschis al pielii',
    '☝🏽' => 'deget arătător îndreptat în sus: ton mediu al pielii',
    '☝🏾' => 'deget arătător îndreptat în sus: ton semi‑închis al pielii',
    '☝🏿' => 'deget arătător îndreptat în sus: ton închis al pielii',
    '🫵🏻' => 'deget arătător îndreptat spre privitor: ton deschis al pielii',
    '🫵🏼' => 'deget arătător îndreptat spre privitor: ton semi‑deschis al pielii',
    '🫵🏽' => 'deget arătător îndreptat spre privitor: ton mediu al pielii',
    '🫵🏾' => 'deget arătător îndreptat spre privitor: ton semi‑închis al pielii',
    '🫵🏿' => 'deget arătător îndreptat spre privitor: ton închis al pielii',
    '👍🏻' => 'semn de aprobare: ton deschis al pielii',
    '👍🏼' => 'semn de aprobare: ton semi‑deschis al pielii',
    '👍🏽' => 'semn de aprobare: ton mediu al pielii',
    '👍🏾' => 'semn de aprobare: ton semi‑închis al pielii',
    '👍🏿' => 'semn de aprobare: ton închis al pielii',
    '👎🏻' => 'semn de dezaprobare: ton deschis al pielii',
    '👎🏼' => 'semn de dezaprobare: ton semi‑deschis al pielii',
    '👎🏽' => 'semn de dezaprobare: ton mediu al pielii',
    '👎🏾' => 'semn de dezaprobare: ton semi‑închis al pielii',
    '👎🏿' => 'semn de dezaprobare: ton închis al pielii',
    '✊🏻' => 'pumn ridicat: ton deschis al pielii',
    '✊🏼' => 'pumn ridicat: ton semi‑deschis al pielii',
    '✊🏽' => 'pumn ridicat: ton mediu al pielii',
    '✊🏾' => 'pumn ridicat: ton semi‑închis al pielii',
    '✊🏿' => 'pumn ridicat: ton închis al pielii',
    '👊🏻' => 'lovitură de pumn: ton deschis al pielii',
    '👊🏼' => 'lovitură de pumn: ton semi‑deschis al pielii',
    '👊🏽' => 'lovitură de pumn: ton mediu al pielii',
    '👊🏾' => 'lovitură de pumn: ton semi‑închis al pielii',
    '👊🏿' => 'lovitură de pumn: ton închis al pielii',
    '🤛🏻' => 'pumn spre stânga: ton deschis al pielii',
    '🤛🏼' => 'pumn spre stânga: ton semi‑deschis al pielii',
    '🤛🏽' => 'pumn spre stânga: ton mediu al pielii',
    '🤛🏾' => 'pumn spre stânga: ton semi‑închis al pielii',
    '🤛🏿' => 'pumn spre stânga: ton închis al pielii',
    '🤜🏻' => 'pumn spre dreapta: ton deschis al pielii',
    '🤜🏼' => 'pumn spre dreapta: ton semi‑deschis al pielii',
    '🤜🏽' => 'pumn spre dreapta: ton mediu al pielii',
    '🤜🏾' => 'pumn spre dreapta: ton semi‑închis al pielii',
    '🤜🏿' => 'pumn spre dreapta: ton închis al pielii',
    '👏🏻' => 'mâini care aplaudă: ton deschis al pielii',
    '👏🏼' => 'mâini care aplaudă: ton semi‑deschis al pielii',
    '👏🏽' => 'mâini care aplaudă: ton mediu al pielii',
    '👏🏾' => 'mâini care aplaudă: ton semi‑închis al pielii',
    '👏🏿' => 'mâini care aplaudă: ton închis al pielii',
    '🙌🏻' => 'mâini ridicate: ton deschis al pielii',
    '🙌🏼' => 'mâini ridicate: ton semi‑deschis al pielii',
    '🙌🏽' => 'mâini ridicate: ton mediu al pielii',
    '🙌🏾' => 'mâini ridicate: ton semi‑închis al pielii',
    '🙌🏿' => 'mâini ridicate: ton închis al pielii',
    '🫶🏻' => 'mâini care formează o inimă: ton deschis al pielii',
    '🫶🏼' => 'mâini care formează o inimă: ton semi‑deschis al pielii',
    '🫶🏽' => 'mâini care formează o inimă: ton mediu al pielii',
    '🫶🏾' => 'mâini care formează o inimă: ton semi‑închis al pielii',
    '🫶🏿' => 'mâini care formează o inimă: ton închis al pielii',
    '👐🏻' => 'palme deschise: ton deschis al pielii',
    '👐🏼' => 'palme deschise: ton semi‑deschis al pielii',
    '👐🏽' => 'palme deschise: ton mediu al pielii',
    '👐🏾' => 'palme deschise: ton semi‑închis al pielii',
    '👐🏿' => 'palme deschise: ton închis al pielii',
    '🤲🏻' => 'palme ridicate împreună: ton deschis al pielii',
    '🤲🏼' => 'palme ridicate împreună: ton semi‑deschis al pielii',
    '🤲🏽' => 'palme ridicate împreună: ton mediu al pielii',
    '🤲🏾' => 'palme ridicate împreună: ton semi‑închis al pielii',
    '🤲🏿' => 'palme ridicate împreună: ton închis al pielii',
    '🤝🏻' => 'strângere de mână: ton deschis al pielii',
    '🤝🏼' => 'strângere de mână: ton semi‑deschis al pielii',
    '🤝🏽' => 'strângere de mână: ton mediu al pielii',
    '🤝🏾' => 'strângere de mână: ton semi‑închis al pielii',
    '🤝🏿' => 'strângere de mână: ton închis al pielii',
    '🙏🏻' => 'mâini unite: ton deschis al pielii',
    '🙏🏼' => 'mâini unite: ton semi‑deschis al pielii',
    '🙏🏽' => 'mâini unite: ton mediu al pielii',
    '🙏🏾' => 'mâini unite: ton semi‑închis al pielii',
    '🙏🏿' => 'mâini unite: ton închis al pielii',
    '✍🏻' => 'mână scriind: ton deschis al pielii',
    '✍🏼' => 'mână scriind: ton semi‑deschis al pielii',
    '✍🏽' => 'mână scriind: ton mediu al pielii',
    '✍🏾' => 'mână scriind: ton semi‑închis al pielii',
    '✍🏿' => 'mână scriind: ton închis al pielii',
    '💅🏻' => 'ojă pe unghii: ton deschis al pielii',
    '💅🏼' => 'ojă pe unghii: ton semi‑deschis al pielii',
    '💅🏽' => 'ojă pe unghii: ton mediu al pielii',
    '💅🏾' => 'ojă pe unghii: ton semi‑închis al pielii',
    '💅🏿' => 'ojă pe unghii: ton închis al pielii',
    '🤳🏻' => 'selfie: ton deschis al pielii',
    '🤳🏼' => 'selfie: ton semi‑deschis al pielii',
    '🤳🏽' => 'selfie: ton mediu al pielii',
    '🤳🏾' => 'selfie: ton semi‑închis al pielii',
    '🤳🏿' => 'selfie: ton închis al pielii',
    '💪🏻' => 'biceps flexat: ton deschis al pielii',
    '💪🏼' => 'biceps flexat: ton semi‑deschis al pielii',
    '💪🏽' => 'biceps flexat: ton mediu al pielii',
    '💪🏾' => 'biceps flexat: ton semi‑închis al pielii',
    '💪🏿' => 'biceps flexat: ton închis al pielii',
    '🦵🏻' => 'picior: ton deschis al pielii',
    '🦵🏼' => 'picior: ton semi‑deschis al pielii',
    '🦵🏽' => 'picior: ton mediu al pielii',
    '🦵🏾' => 'picior: ton semi‑închis al pielii',
    '🦵🏿' => 'picior: ton închis al pielii',
    '🦶🏻' => 'laba piciorului: ton deschis al pielii',
    '🦶🏼' => 'laba piciorului: ton semi‑deschis al pielii',
    '🦶🏽' => 'laba piciorului: ton mediu al pielii',
    '🦶🏾' => 'laba piciorului: ton semi‑închis al pielii',
    '🦶🏿' => 'laba piciorului: ton închis al pielii',
    '👂🏻' => 'ureche: ton deschis al pielii',
    '👂🏼' => 'ureche: ton semi‑deschis al pielii',
    '👂🏽' => 'ureche: ton mediu al pielii',
    '👂🏾' => 'ureche: ton semi‑închis al pielii',
    '👂🏿' => 'ureche: ton închis al pielii',
    '🦻🏻' => 'ureche cu proteză auditivă: ton deschis al pielii',
    '🦻🏼' => 'ureche cu proteză auditivă: ton semi‑deschis al pielii',
    '🦻🏽' => 'ureche cu proteză auditivă: ton mediu al pielii',
    '🦻🏾' => 'ureche cu proteză auditivă: ton semi‑închis al pielii',
    '🦻🏿' => 'ureche cu proteză auditivă: ton închis al pielii',
    '👃🏻' => 'nas: ton deschis al pielii',
    '👃🏼' => 'nas: ton semi‑deschis al pielii',
    '👃🏽' => 'nas: ton mediu al pielii',
    '👃🏾' => 'nas: ton semi‑închis al pielii',
    '👃🏿' => 'nas: ton închis al pielii',
    '👶🏻' => 'bebeluș: ton deschis al pielii',
    '👶🏼' => 'bebeluș: ton semi‑deschis al pielii',
    '👶🏽' => 'bebeluș: ton mediu al pielii',
    '👶🏾' => 'bebeluș: ton semi‑închis al pielii',
    '👶🏿' => 'bebeluș: ton închis al pielii',
    '🧒🏻' => 'copil: ton deschis al pielii',
    '🧒🏼' => 'copil: ton semi‑deschis al pielii',
    '🧒🏽' => 'copil: ton mediu al pielii',
    '🧒🏾' => 'copil: ton semi‑închis al pielii',
    '🧒🏿' => 'copil: ton închis al pielii',
    '👦🏻' => 'băiat: ton deschis al pielii',
    '👦🏼' => 'băiat: ton semi‑deschis al pielii',
    '👦🏽' => 'băiat: ton mediu al pielii',
    '👦🏾' => 'băiat: ton semi‑închis al pielii',
    '👦🏿' => 'băiat: ton închis al pielii',
    '👧🏻' => 'fată: ton deschis al pielii',
    '👧🏼' => 'fată: ton semi‑deschis al pielii',
    '👧🏽' => 'fată: ton mediu al pielii',
    '👧🏾' => 'fată: ton semi‑închis al pielii',
    '👧🏿' => 'fată: ton închis al pielii',
    '🧑🏻' => 'adult: ton deschis al pielii',
    '🧑🏼' => 'adult: ton semi‑deschis al pielii',
    '🧑🏽' => 'adult: ton mediu al pielii',
    '🧑🏾' => 'adult: ton semi‑închis al pielii',
    '🧑🏿' => 'adult: ton închis al pielii',
    '👱🏻' => 'persoană blondă: ton deschis al pielii',
    '👱🏼' => 'persoană blondă: ton semi‑deschis al pielii',
    '👱🏽' => 'persoană blondă: ton mediu al pielii',
    '👱🏾' => 'persoană blondă: ton semi‑închis al pielii',
    '👱🏿' => 'persoană blondă: ton închis al pielii',
    '👨🏻' => 'bărbat: ton deschis al pielii',
    '👨🏼' => 'bărbat: ton semi‑deschis al pielii',
    '👨🏽' => 'bărbat: ton mediu al pielii',
    '👨🏾' => 'bărbat: ton semi‑închis al pielii',
    '👨🏿' => 'bărbat: ton închis al pielii',
    '🧔🏻' => 'bărbat cu barbă: ton deschis al pielii',
    '🧔🏼' => 'bărbat cu barbă: ton semi‑deschis al pielii',
    '🧔🏽' => 'bărbat cu barbă: ton mediu al pielii',
    '🧔🏾' => 'bărbat cu barbă: ton semi‑închis al pielii',
    '🧔🏿' => 'bărbat cu barbă: ton închis al pielii',
    '👩🏻' => 'femeie: ton deschis al pielii',
    '👩🏼' => 'femeie: ton semi‑deschis al pielii',
    '👩🏽' => 'femeie: ton mediu al pielii',
    '👩🏾' => 'femeie: ton semi‑închis al pielii',
    '👩🏿' => 'femeie: ton închis al pielii',
    '🧓🏻' => 'persoană în vârstă: ton deschis al pielii',
    '🧓🏼' => 'persoană în vârstă: ton semi‑deschis al pielii',
    '🧓🏽' => 'persoană în vârstă: ton mediu al pielii',
    '🧓🏾' => 'persoană în vârstă: ton semi‑închis al pielii',
    '🧓🏿' => 'persoană în vârstă: ton închis al pielii',
    '👴🏻' => 'bătrân: ton deschis al pielii',
    '👴🏼' => 'bătrân: ton semi‑deschis al pielii',
    '👴🏽' => 'bătrân: ton mediu al pielii',
    '👴🏾' => 'bătrân: ton semi‑închis al pielii',
    '👴🏿' => 'bătrân: ton închis al pielii',
    '👵🏻' => 'bătrână: ton deschis al pielii',
    '👵🏼' => 'bătrână: ton semi‑deschis al pielii',
    '👵🏽' => 'bătrână: ton mediu al pielii',
    '👵🏾' => 'bătrână: ton semi‑închis al pielii',
    '👵🏿' => 'bătrână: ton închis al pielii',
    '🙍🏻' => 'persoană întristată: ton deschis al pielii',
    '🙍🏼' => 'persoană întristată: ton semi‑deschis al pielii',
    '🙍🏽' => 'persoană întristată: ton mediu al pielii',
    '🙍🏾' => 'persoană întristată: ton semi‑închis al pielii',
    '🙍🏿' => 'persoană întristată: ton închis al pielii',
    '🙎🏻' => 'persoană bosumflată: ton deschis al pielii',
    '🙎🏼' => 'persoană bosumflată: ton semi‑deschis al pielii',
    '🙎🏽' => 'persoană bosumflată: ton mediu al pielii',
    '🙎🏾' => 'persoană bosumflată: ton semi‑închis al pielii',
    '🙎🏿' => 'persoană bosumflată: ton închis al pielii',
    '🙅🏻' => 'persoană făcând un gest de negație: ton deschis al pielii',
    '🙅🏼' => 'persoană făcând un gest de negație: ton semi‑deschis al pielii',
    '🙅🏽' => 'persoană făcând un gest de negație: ton mediu al pielii',
    '🙅🏾' => 'persoană făcând un gest de negație: ton semi‑închis al pielii',
    '🙅🏿' => 'persoană făcând un gest de negație: ton închis al pielii',
    '🙆🏻' => 'persoană făcând un gest de OK: ton deschis al pielii',
    '🙆🏼' => 'persoană făcând un gest de OK: ton semi‑deschis al pielii',
    '🙆🏽' => 'persoană făcând un gest de OK: ton mediu al pielii',
    '🙆🏾' => 'persoană făcând un gest de OK: ton semi‑închis al pielii',
    '🙆🏿' => 'persoană făcând un gest de OK: ton închis al pielii',
    '💁🏻' => 'persoană care explică: ton deschis al pielii',
    '💁🏼' => 'persoană care explică: ton semi‑deschis al pielii',
    '💁🏽' => 'persoană care explică: ton mediu al pielii',
    '💁🏾' => 'persoană care explică: ton semi‑închis al pielii',
    '💁🏿' => 'persoană care explică: ton închis al pielii',
    '🙋🏻' => 'persoană care ridică mâna: ton deschis al pielii',
    '🙋🏼' => 'persoană care ridică mâna: ton semi‑deschis al pielii',
    '🙋🏽' => 'persoană care ridică mâna: ton mediu al pielii',
    '🙋🏾' => 'persoană care ridică mâna: ton semi‑închis al pielii',
    '🙋🏿' => 'persoană care ridică mâna: ton închis al pielii',
    '🧏🏻' => 'persoană surdă: ton deschis al pielii',
    '🧏🏼' => 'persoană surdă: ton semi‑deschis al pielii',
    '🧏🏽' => 'persoană surdă: ton mediu al pielii',
    '🧏🏾' => 'persoană surdă: ton semi‑închis al pielii',
    '🧏🏿' => 'persoană surdă: ton închis al pielii',
    '🙇🏻' => 'persoană care se înclină: ton deschis al pielii',
    '🙇🏼' => 'persoană care se înclină: ton semi‑deschis al pielii',
    '🙇🏽' => 'persoană care se înclină: ton mediu al pielii',
    '🙇🏾' => 'persoană care se înclină: ton semi‑închis al pielii',
    '🙇🏿' => 'persoană care se înclină: ton închis al pielii',
    '🤦🏻' => 'persoană care își acoperă fața cu o palmă: ton deschis al pielii',
    '🤦🏼' => 'persoană care își acoperă fața cu o palmă: ton semi‑deschis al pielii',
    '🤦🏽' => 'persoană care își acoperă fața cu o palmă: ton mediu al pielii',
    '🤦🏾' => 'persoană care își acoperă fața cu o palmă: ton semi‑închis al pielii',
    '🤦🏿' => 'persoană care își acoperă fața cu o palmă: ton închis al pielii',
    '🤷🏻' => 'persoană care ridică din umeri: ton deschis al pielii',
    '🤷🏼' => 'persoană care ridică din umeri: ton semi‑deschis al pielii',
    '🤷🏽' => 'persoană care ridică din umeri: ton mediu al pielii',
    '🤷🏾' => 'persoană care ridică din umeri: ton semi‑închis al pielii',
    '🤷🏿' => 'persoană care ridică din umeri: ton închis al pielii',
    '👮🏻' => 'polițist sau polițistă: ton deschis al pielii',
    '👮🏼' => 'polițist sau polițistă: ton semi‑deschis al pielii',
    '👮🏽' => 'polițist sau polițistă: ton mediu al pielii',
    '👮🏾' => 'polițist sau polițistă: ton semi‑închis al pielii',
    '👮🏿' => 'polițist sau polițistă: ton închis al pielii',
    '🕵🏻' => 'detectiv: ton deschis al pielii',
    '🕵🏼' => 'detectiv: ton semi‑deschis al pielii',
    '🕵🏽' => 'detectiv: ton mediu al pielii',
    '🕵🏾' => 'detectiv: ton semi‑închis al pielii',
    '🕵🏿' => 'detectiv: ton închis al pielii',
    '💂🏻' => 'gardian: ton deschis al pielii',
    '💂🏼' => 'gardian: ton semi‑deschis al pielii',
    '💂🏽' => 'gardian: ton mediu al pielii',
    '💂🏾' => 'gardian: ton semi‑închis al pielii',
    '💂🏿' => 'gardian: ton închis al pielii',
    '🥷🏻' => 'ninja: ton deschis al pielii',
    '🥷🏼' => 'ninja: ton semi‑deschis al pielii',
    '🥷🏽' => 'ninja: ton mediu al pielii',
    '🥷🏾' => 'ninja: ton semi‑închis al pielii',
    '🥷🏿' => 'ninja: ton închis al pielii',
    '👷🏻' => 'constructor: ton deschis al pielii',
    '👷🏼' => 'constructor: ton semi‑deschis al pielii',
    '👷🏽' => 'constructor: ton mediu al pielii',
    '👷🏾' => 'constructor: ton semi‑închis al pielii',
    '👷🏿' => 'constructor: ton închis al pielii',
    '🫅🏻' => 'persoană cu coroană: ton deschis al pielii',
    '🫅🏼' => 'persoană cu coroană: ton semi‑deschis al pielii',
    '🫅🏽' => 'persoană cu coroană: ton mediu al pielii',
    '🫅🏾' => 'persoană cu coroană: ton semi‑închis al pielii',
    '🫅🏿' => 'persoană cu coroană: ton închis al pielii',
    '🤴🏻' => 'prinț: ton deschis al pielii',
    '🤴🏼' => 'prinț: ton semi‑deschis al pielii',
    '🤴🏽' => 'prinț: ton mediu al pielii',
    '🤴🏾' => 'prinț: ton semi‑închis al pielii',
    '🤴🏿' => 'prinț: ton închis al pielii',
    '👸🏻' => 'prințesă: ton deschis al pielii',
    '👸🏼' => 'prințesă: ton semi‑deschis al pielii',
    '👸🏽' => 'prințesă: ton mediu al pielii',
    '👸🏾' => 'prințesă: ton semi‑închis al pielii',
    '👸🏿' => 'prințesă: ton închis al pielii',
    '👳🏻' => 'persoană cu turban: ton deschis al pielii',
    '👳🏼' => 'persoană cu turban: ton semi‑deschis al pielii',
    '👳🏽' => 'persoană cu turban: ton mediu al pielii',
    '👳🏾' => 'persoană cu turban: ton semi‑închis al pielii',
    '👳🏿' => 'persoană cu turban: ton închis al pielii',
    '👲🏻' => 'bărbat cu bonetă chinezească: ton deschis al pielii',
    '👲🏼' => 'bărbat cu bonetă chinezească: ton semi‑deschis al pielii',
    '👲🏽' => 'bărbat cu bonetă chinezească: ton mediu al pielii',
    '👲🏾' => 'bărbat cu bonetă chinezească: ton semi‑închis al pielii',
    '👲🏿' => 'bărbat cu bonetă chinezească: ton închis al pielii',
    '🧕🏻' => 'femeie cu năframă: ton deschis al pielii',
    '🧕🏼' => 'femeie cu năframă: ton semi‑deschis al pielii',
    '🧕🏽' => 'femeie cu năframă: ton mediu al pielii',
    '🧕🏾' => 'femeie cu năframă: ton semi‑închis al pielii',
    '🧕🏿' => 'femeie cu năframă: ton închis al pielii',
    '🤵🏻' => 'persoană în smoching: ton deschis al pielii',
    '🤵🏼' => 'persoană în smoching: ton semi‑deschis al pielii',
    '🤵🏽' => 'persoană în smoching: ton mediu al pielii',
    '🤵🏾' => 'persoană în smoching: ton semi‑închis al pielii',
    '🤵🏿' => 'persoană în smoching: ton închis al pielii',
    '👰🏻' => 'persoană cu voal: ton deschis al pielii',
    '👰🏼' => 'persoană cu voal: ton semi‑deschis al pielii',
    '👰🏽' => 'persoană cu voal: ton mediu al pielii',
    '👰🏾' => 'persoană cu voal: ton semi‑închis al pielii',
    '👰🏿' => 'persoană cu voal: ton închis al pielii',
    '🤰🏻' => 'femeie însărcinată: ton deschis al pielii',
    '🤰🏼' => 'femeie însărcinată: ton semi‑deschis al pielii',
    '🤰🏽' => 'femeie însărcinată: ton mediu al pielii',
    '🤰🏾' => 'femeie însărcinată: ton semi‑închis al pielii',
    '🤰🏿' => 'femeie însărcinată: ton închis al pielii',
    '🫃🏻' => 'bărbat însărcinat: ton deschis al pielii',
    '🫃🏼' => 'bărbat însărcinat: ton semi‑deschis al pielii',
    '🫃🏽' => 'bărbat însărcinat: ton mediu al pielii',
    '🫃🏾' => 'bărbat însărcinat: ton semi‑închis al pielii',
    '🫃🏿' => 'bărbat însărcinat: ton închis al pielii',
    '🫄🏻' => 'persoană însărcinată: ton deschis al pielii',
    '🫄🏼' => 'persoană însărcinată: ton semi‑deschis al pielii',
    '🫄🏽' => 'persoană însărcinată: ton mediu al pielii',
    '🫄🏾' => 'persoană însărcinată: ton semi‑închis al pielii',
    '🫄🏿' => 'persoană însărcinată: ton închis al pielii',
    '🤱🏻' => 'alăptare la sân: ton deschis al pielii',
    '🤱🏼' => 'alăptare la sân: ton semi‑deschis al pielii',
    '🤱🏽' => 'alăptare la sân: ton mediu al pielii',
    '🤱🏾' => 'alăptare la sân: ton semi‑închis al pielii',
    '🤱🏿' => 'alăptare la sân: ton închis al pielii',
    '👼🏻' => 'bebeluș îngeraș: ton deschis al pielii',
    '👼🏼' => 'bebeluș îngeraș: ton semi‑deschis al pielii',
    '👼🏽' => 'bebeluș îngeraș: ton mediu al pielii',
    '👼🏾' => 'bebeluș îngeraș: ton semi‑închis al pielii',
    '👼🏿' => 'bebeluș îngeraș: ton închis al pielii',
    '🎅🏻' => 'Moș Crăciun: ton deschis al pielii',
    '🎅🏼' => 'Moș Crăciun: ton semi‑deschis al pielii',
    '🎅🏽' => 'Moș Crăciun: ton mediu al pielii',
    '🎅🏾' => 'Moș Crăciun: ton semi‑închis al pielii',
    '🎅🏿' => 'Moș Crăciun: ton închis al pielii',
    '🤶🏻' => 'Doamna Crăciun: ton deschis al pielii',
    '🤶🏼' => 'Doamna Crăciun: ton semi‑deschis al pielii',
    '🤶🏽' => 'Doamna Crăciun: ton mediu al pielii',
    '🤶🏾' => 'Doamna Crăciun: ton semi‑închis al pielii',
    '🤶🏿' => 'Doamna Crăciun: ton închis al pielii',
    '🦸🏻' => 'supererou: ton deschis al pielii',
    '🦸🏼' => 'supererou: ton semi‑deschis al pielii',
    '🦸🏽' => 'supererou: ton mediu al pielii',
    '🦸🏾' => 'supererou: ton semi‑închis al pielii',
    '🦸🏿' => 'supererou: ton închis al pielii',
    '🦹🏻' => 'super-ticălos: ton deschis al pielii',
    '🦹🏼' => 'super-ticălos: ton semi‑deschis al pielii',
    '🦹🏽' => 'super-ticălos: ton mediu al pielii',
    '🦹🏾' => 'super-ticălos: ton semi‑închis al pielii',
    '🦹🏿' => 'super-ticălos: ton închis al pielii',
    '🧙🏻' => 'mag: ton deschis al pielii',
    '🧙🏼' => 'mag: ton semi‑deschis al pielii',
    '🧙🏽' => 'mag: ton mediu al pielii',
    '🧙🏾' => 'mag: ton semi‑închis al pielii',
    '🧙🏿' => 'mag: ton închis al pielii',
    '🧚🏻' => 'zână: ton deschis al pielii',
    '🧚🏼' => 'zână: ton semi‑deschis al pielii',
    '🧚🏽' => 'zână: ton mediu al pielii',
    '🧚🏾' => 'zână: ton semi‑închis al pielii',
    '🧚🏿' => 'zână: ton închis al pielii',
    '🧛🏻' => 'vampir: ton deschis al pielii',
    '🧛🏼' => 'vampir: ton semi‑deschis al pielii',
    '🧛🏽' => 'vampir: ton mediu al pielii',
    '🧛🏾' => 'vampir: ton semi‑închis al pielii',
    '🧛🏿' => 'vampir: ton închis al pielii',
    '🧜🏻' => 'persoană sirenă: ton deschis al pielii',
    '🧜🏼' => 'persoană sirenă: ton semi‑deschis al pielii',
    '🧜🏽' => 'persoană sirenă: ton mediu al pielii',
    '🧜🏾' => 'persoană sirenă: ton semi‑închis al pielii',
    '🧜🏿' => 'persoană sirenă: ton închis al pielii',
    '🧝🏻' => 'elf: ton deschis al pielii',
    '🧝🏼' => 'elf: ton semi‑deschis al pielii',
    '🧝🏽' => 'elf: ton mediu al pielii',
    '🧝🏾' => 'elf: ton semi‑închis al pielii',
    '🧝🏿' => 'elf: ton închis al pielii',
    '💆🏻' => 'persoană care primește un masaj facial: ton deschis al pielii',
    '💆🏼' => 'persoană care primește un masaj facial: ton semi‑deschis al pielii',
    '💆🏽' => 'persoană care primește un masaj facial: ton mediu al pielii',
    '💆🏾' => 'persoană care primește un masaj facial: ton semi‑închis al pielii',
    '💆🏿' => 'persoană care primește un masaj facial: ton închis al pielii',
    '💇🏻' => 'persoană care se tunde: ton deschis al pielii',
    '💇🏼' => 'persoană care se tunde: ton semi‑deschis al pielii',
    '💇🏽' => 'persoană care se tunde: ton mediu al pielii',
    '💇🏾' => 'persoană care se tunde: ton semi‑închis al pielii',
    '💇🏿' => 'persoană care se tunde: ton închis al pielii',
    '🚶🏻' => 'persoană care merge: ton deschis al pielii',
    '🚶🏼' => 'persoană care merge: ton semi‑deschis al pielii',
    '🚶🏽' => 'persoană care merge: ton mediu al pielii',
    '🚶🏾' => 'persoană care merge: ton semi‑închis al pielii',
    '🚶🏿' => 'persoană care merge: ton închis al pielii',
    '🧍🏻' => 'persoană în picioare: ton deschis al pielii',
    '🧍🏼' => 'persoană în picioare: ton semi‑deschis al pielii',
    '🧍🏽' => 'persoană în picioare: ton mediu al pielii',
    '🧍🏾' => 'persoană în picioare: ton semi‑închis al pielii',
    '🧍🏿' => 'persoană în picioare: ton închis al pielii',
    '🧎🏻' => 'persoană în genunchi: ton deschis al pielii',
    '🧎🏼' => 'persoană în genunchi: ton semi‑deschis al pielii',
    '🧎🏽' => 'persoană în genunchi: ton mediu al pielii',
    '🧎🏾' => 'persoană în genunchi: ton semi‑închis al pielii',
    '🧎🏿' => 'persoană în genunchi: ton închis al pielii',
    '🏃🏻' => 'persoană care aleargă: ton deschis al pielii',
    '🏃🏼' => 'persoană care aleargă: ton semi‑deschis al pielii',
    '🏃🏽' => 'persoană care aleargă: ton mediu al pielii',
    '🏃🏾' => 'persoană care aleargă: ton semi‑închis al pielii',
    '🏃🏿' => 'persoană care aleargă: ton închis al pielii',
    '💃🏻' => 'dansatoare: ton deschis al pielii',
    '💃🏼' => 'dansatoare: ton semi‑deschis al pielii',
    '💃🏽' => 'dansatoare: ton mediu al pielii',
    '💃🏾' => 'dansatoare: ton semi‑închis al pielii',
    '💃🏿' => 'dansatoare: ton închis al pielii',
    '🕺🏻' => 'dansator: ton deschis al pielii',
    '🕺🏼' => 'dansator: ton semi‑deschis al pielii',
    '🕺🏽' => 'dansator: ton mediu al pielii',
    '🕺🏾' => 'dansator: ton semi‑închis al pielii',
    '🕺🏿' => 'dansator: ton închis al pielii',
    '🕴🏻' => 'persoană în costum, levitând: ton deschis al pielii',
    '🕴🏼' => 'persoană în costum, levitând: ton semi‑deschis al pielii',
    '🕴🏽' => 'persoană în costum, levitând: ton mediu al pielii',
    '🕴🏾' => 'persoană în costum, levitând: ton semi‑închis al pielii',
    '🕴🏿' => 'persoană în costum, levitând: ton închis al pielii',
    '👯🏻' => 'persoane care poartă urechi de iepuraș: ton deschis al pielii',
    '👯🏼' => 'persoane care poartă urechi de iepuraș: ton semi‑deschis al pielii',
    '👯🏽' => 'persoane care poartă urechi de iepuraș: ton mediu al pielii',
    '👯🏾' => 'persoane care poartă urechi de iepuraș: ton semi‑închis al pielii',
    '👯🏿' => 'persoane care poartă urechi de iepuraș: ton închis al pielii',
    '🧖🏻' => 'persoană în saună: ton deschis al pielii',
    '🧖🏼' => 'persoană în saună: ton semi‑deschis al pielii',
    '🧖🏽' => 'persoană în saună: ton mediu al pielii',
    '🧖🏾' => 'persoană în saună: ton semi‑închis al pielii',
    '🧖🏿' => 'persoană în saună: ton închis al pielii',
    '🧗🏻' => 'persoană care se cațără: ton deschis al pielii',
    '🧗🏼' => 'persoană care se cațără: ton semi‑deschis al pielii',
    '🧗🏽' => 'persoană care se cațără: ton mediu al pielii',
    '🧗🏾' => 'persoană care se cațără: ton semi‑închis al pielii',
    '🧗🏿' => 'persoană care se cațără: ton închis al pielii',
    '🏇🏻' => 'curse de cai: ton deschis al pielii',
    '🏇🏼' => 'curse de cai: ton semi‑deschis al pielii',
    '🏇🏽' => 'curse de cai: ton mediu al pielii',
    '🏇🏾' => 'curse de cai: ton semi‑închis al pielii',
    '🏇🏿' => 'curse de cai: ton închis al pielii',
    '🏂🏻' => 'persoană care practică snow-board: ton deschis al pielii',
    '🏂🏼' => 'persoană care practică snow-board: ton semi‑deschis al pielii',
    '🏂🏽' => 'persoană care practică snow-board: ton mediu al pielii',
    '🏂🏾' => 'persoană care practică snow-board: ton semi‑închis al pielii',
    '🏂🏿' => 'persoană care practică snow-board: ton închis al pielii',
    '🏌🏻' => 'persoană care joacă golf: ton deschis al pielii',
    '🏌🏼' => 'persoană care joacă golf: ton semi‑deschis al pielii',
    '🏌🏽' => 'persoană care joacă golf: ton mediu al pielii',
    '🏌🏾' => 'persoană care joacă golf: ton semi‑închis al pielii',
    '🏌🏿' => 'persoană care joacă golf: ton închis al pielii',
    '🏄🏻' => 'persoană care practică surfing: ton deschis al pielii',
    '🏄🏼' => 'persoană care practică surfing: ton semi‑deschis al pielii',
    '🏄🏽' => 'persoană care practică surfing: ton mediu al pielii',
    '🏄🏾' => 'persoană care practică surfing: ton semi‑închis al pielii',
    '🏄🏿' => 'persoană care practică surfing: ton închis al pielii',
    '🚣🏻' => 'persoană care vâslește în barcă: ton deschis al pielii',
    '🚣🏼' => 'persoană care vâslește în barcă: ton semi‑deschis al pielii',
    '🚣🏽' => 'persoană care vâslește în barcă: ton mediu al pielii',
    '🚣🏾' => 'persoană care vâslește în barcă: ton semi‑închis al pielii',
    '🚣🏿' => 'persoană care vâslește în barcă: ton închis al pielii',
    '🏊🏻' => 'persoană care înoată: ton deschis al pielii',
    '🏊🏼' => 'persoană care înoată: ton semi‑deschis al pielii',
    '🏊🏽' => 'persoană care înoată: ton mediu al pielii',
    '🏊🏾' => 'persoană care înoată: ton semi‑închis al pielii',
    '🏊🏿' => 'persoană care înoată: ton închis al pielii',
    '⛹🏻' => 'persoană care bate mingea: ton deschis al pielii',
    '⛹🏼' => 'persoană care bate mingea: ton semi‑deschis al pielii',
    '⛹🏽' => 'persoană care bate mingea: ton mediu al pielii',
    '⛹🏾' => 'persoană care bate mingea: ton semi‑închis al pielii',
    '⛹🏿' => 'persoană care bate mingea: ton închis al pielii',
    '🏋🏻' => 'persoană care ridică greutăți: ton deschis al pielii',
    '🏋🏼' => 'persoană care ridică greutăți: ton semi‑deschis al pielii',
    '🏋🏽' => 'persoană care ridică greutăți: ton mediu al pielii',
    '🏋🏾' => 'persoană care ridică greutăți: ton semi‑închis al pielii',
    '🏋🏿' => 'persoană care ridică greutăți: ton închis al pielii',
    '🚴🏻' => 'persoană pe bicicletă: ton deschis al pielii',
    '🚴🏼' => 'persoană pe bicicletă: ton semi‑deschis al pielii',
    '🚴🏽' => 'persoană pe bicicletă: ton mediu al pielii',
    '🚴🏾' => 'persoană pe bicicletă: ton semi‑închis al pielii',
    '🚴🏿' => 'persoană pe bicicletă: ton închis al pielii',
    '🚵🏻' => 'persoană pe bicicletă montană: ton deschis al pielii',
    '🚵🏼' => 'persoană pe bicicletă montană: ton semi‑deschis al pielii',
    '🚵🏽' => 'persoană pe bicicletă montană: ton mediu al pielii',
    '🚵🏾' => 'persoană pe bicicletă montană: ton semi‑închis al pielii',
    '🚵🏿' => 'persoană pe bicicletă montană: ton închis al pielii',
    '🤸🏻' => 'persoană care face roata: ton deschis al pielii',
    '🤸🏼' => 'persoană care face roata: ton semi‑deschis al pielii',
    '🤸🏽' => 'persoană care face roata: ton mediu al pielii',
    '🤸🏾' => 'persoană care face roata: ton semi‑închis al pielii',
    '🤸🏿' => 'persoană care face roata: ton închis al pielii',
    '🤼🏻' => 'persoane care practică wrestling: ton deschis al pielii',
    '🤼🏼' => 'persoane care practică wrestling: ton semi‑deschis al pielii',
    '🤼🏽' => 'persoane care practică wrestling: ton mediu al pielii',
    '🤼🏾' => 'persoane care practică wrestling: ton semi‑închis al pielii',
    '🤼🏿' => 'persoane care practică wrestling: ton închis al pielii',
    '🤽🏻' => 'persoană care joacă polo pe apă: ton deschis al pielii',
    '🤽🏼' => 'persoană care joacă polo pe apă: ton semi‑deschis al pielii',
    '🤽🏽' => 'persoană care joacă polo pe apă: ton mediu al pielii',
    '🤽🏾' => 'persoană care joacă polo pe apă: ton semi‑închis al pielii',
    '🤽🏿' => 'persoană care joacă polo pe apă: ton închis al pielii',
    '🤾🏻' => 'persoană care joacă handbal: ton deschis al pielii',
    '🤾🏼' => 'persoană care joacă handbal: ton semi‑deschis al pielii',
    '🤾🏽' => 'persoană care joacă handbal: ton mediu al pielii',
    '🤾🏾' => 'persoană care joacă handbal: ton semi‑închis al pielii',
    '🤾🏿' => 'persoană care joacă handbal: ton închis al pielii',
    '🤹🏻' => 'persoană care jonglează: ton deschis al pielii',
    '🤹🏼' => 'persoană care jonglează: ton semi‑deschis al pielii',
    '🤹🏽' => 'persoană care jonglează: ton mediu al pielii',
    '🤹🏾' => 'persoană care jonglează: ton semi‑închis al pielii',
    '🤹🏿' => 'persoană care jonglează: ton închis al pielii',
    '🧘🏻' => 'persoană în poziția lotus: ton deschis al pielii',
    '🧘🏼' => 'persoană în poziția lotus: ton semi‑deschis al pielii',
    '🧘🏽' => 'persoană în poziția lotus: ton mediu al pielii',
    '🧘🏾' => 'persoană în poziția lotus: ton semi‑închis al pielii',
    '🧘🏿' => 'persoană în poziția lotus: ton închis al pielii',
    '🛀🏻' => 'persoană care face baie: ton deschis al pielii',
    '🛀🏼' => 'persoană care face baie: ton semi‑deschis al pielii',
    '🛀🏽' => 'persoană care face baie: ton mediu al pielii',
    '🛀🏾' => 'persoană care face baie: ton semi‑închis al pielii',
    '🛀🏿' => 'persoană care face baie: ton închis al pielii',
    '🛌🏻' => 'persoană în pat: ton deschis al pielii',
    '🛌🏼' => 'persoană în pat: ton semi‑deschis al pielii',
    '🛌🏽' => 'persoană în pat: ton mediu al pielii',
    '🛌🏾' => 'persoană în pat: ton semi‑închis al pielii',
    '🛌🏿' => 'persoană în pat: ton închis al pielii',
    '👭🏻' => 'femei ținându-se de mână: ton deschis al pielii',
    '👭🏼' => 'femei ținându-se de mână: ton semi‑deschis al pielii',
    '👭🏽' => 'femei ținându-se de mână: ton mediu al pielii',
    '👭🏾' => 'femei ținându-se de mână: ton semi‑închis al pielii',
    '👭🏿' => 'femei ținându-se de mână: ton închis al pielii',
    '👫🏻' => 'bărbat și femeie ținându-se de mână: ton deschis al pielii',
    '👫🏼' => 'bărbat și femeie ținându-se de mână: ton semi‑deschis al pielii',
    '👫🏽' => 'bărbat și femeie ținându-se de mână: ton mediu al pielii',
    '👫🏾' => 'bărbat și femeie ținându-se de mână: ton semi‑închis al pielii',
    '👫🏿' => 'bărbat și femeie ținându-se de mână: ton închis al pielii',
    '👬🏻' => 'bărbați ținându-se de mână: ton deschis al pielii',
    '👬🏼' => 'bărbați ținându-se de mână: ton semi‑deschis al pielii',
    '👬🏽' => 'bărbați ținându-se de mână: ton mediu al pielii',
    '👬🏾' => 'bărbați ținându-se de mână: ton semi‑închis al pielii',
    '👬🏿' => 'bărbați ținându-se de mână: ton închis al pielii',
    '💏🏻' => 'sărut: ton deschis al pielii',
    '💏🏼' => 'sărut: ton semi‑deschis al pielii',
    '💏🏽' => 'sărut: ton mediu al pielii',
    '💏🏾' => 'sărut: ton semi‑închis al pielii',
    '💏🏿' => 'sărut: ton închis al pielii',
    '💑🏻' => 'cuplu cu inimă: ton deschis al pielii',
    '💑🏼' => 'cuplu cu inimă: ton semi‑deschis al pielii',
    '💑🏽' => 'cuplu cu inimă: ton mediu al pielii',
    '💑🏾' => 'cuplu cu inimă: ton semi‑închis al pielii',
    '💑🏿' => 'cuplu cu inimă: ton închis al pielii',
    '🇦🇨' => 'steag: Insula Ascension',
    '🇦🇩' => 'steag: Andorra',
    '🇦🇪' => 'steag: Emiratele Arabe Unite',
    '🇦🇫' => 'steag: Afganistan',
    '🇦🇬' => 'steag: Antigua și Barbuda',
    '🇦🇮' => 'steag: Anguilla',
    '🇦🇱' => 'steag: Albania',
    '🇦🇲' => 'steag: Armenia',
    '🇦🇴' => 'steag: Angola',
    '🇦🇶' => 'steag: Antarctica',
    '🇦🇷' => 'steag: Argentina',
    '🇦🇸' => 'steag: Samoa Americană',
    '🇦🇹' => 'steag: Austria',
    '🇦🇺' => 'steag: Australia',
    '🇦🇼' => 'steag: Aruba',
    '🇦🇽' => 'steag: Insulele Åland',
    '🇦🇿' => 'steag: Azerbaidjan',
    '🇧🇦' => 'steag: Bosnia și Herțegovina',
    '🇧🇧' => 'steag: Barbados',
    '🇧🇩' => 'steag: Bangladesh',
    '🇧🇪' => 'steag: Belgia',
    '🇧🇫' => 'steag: Burkina Faso',
    '🇧🇬' => 'steag: Bulgaria',
    '🇧🇭' => 'steag: Bahrain',
    '🇧🇮' => 'steag: Burundi',
    '🇧🇯' => 'steag: Benin',
    '🇧🇱' => 'steag: Saint-Barthélemy',
    '🇧🇲' => 'steag: Bermuda',
    '🇧🇳' => 'steag: Brunei',
    '🇧🇴' => 'steag: Bolivia',
    '🇧🇶' => 'steag: Insulele Caraibe Olandeze',
    '🇧🇷' => 'steag: Brazilia',
    '🇧🇸' => 'steag: Bahamas',
    '🇧🇹' => 'steag: Bhutan',
    '🇧🇻' => 'steag: Insula Bouvet',
    '🇧🇼' => 'steag: Botswana',
    '🇧🇾' => 'steag: Belarus',
    '🇧🇿' => 'steag: Belize',
    '🇨🇦' => 'steag: Canada',
    '🇨🇨' => 'steag: Insulele Cocos (Keeling)',
    '🇨🇩' => 'steag: Congo - Kinshasa',
    '🇨🇫' => 'steag: Republica Centrafricană',
    '🇨🇬' => 'steag: Congo - Brazzaville',
    '🇨🇭' => 'steag: Elveția',
    '🇨🇮' => 'steag: Côte d’Ivoire',
    '🇨🇰' => 'steag: Insulele Cook',
    '🇨🇱' => 'steag: Chile',
    '🇨🇲' => 'steag: Camerun',
    '🇨🇳' => 'steag: China',
    '🇨🇴' => 'steag: Columbia',
    '🇨🇵' => 'steag: Insula Clipperton',
    '🇨🇶' => 'steag: Sark',
    '🇨🇷' => 'steag: Costa Rica',
    '🇨🇺' => 'steag: Cuba',
    '🇨🇻' => 'steag: Capul Verde',
    '🇨🇼' => 'steag: Curaçao',
    '🇨🇽' => 'steag: Insula Christmas',
    '🇨🇾' => 'steag: Cipru',
    '🇨🇿' => 'steag: Cehia',
    '🇩🇪' => 'steag: Germania',
    '🇩🇬' => 'steag: Diego Garcia',
    '🇩🇯' => 'steag: Djibouti',
    '🇩🇰' => 'steag: Danemarca',
    '🇩🇲' => 'steag: Dominica',
    '🇩🇴' => 'steag: Republica Dominicană',
    '🇩🇿' => 'steag: Algeria',
    '🇪🇦' => 'steag: Ceuta și Melilla',
    '🇪🇨' => 'steag: Ecuador',
    '🇪🇪' => 'steag: Estonia',
    '🇪🇬' => 'steag: Egipt',
    '🇪🇭' => 'steag: Sahara Occidentală',
    '🇪🇷' => 'steag: Eritreea',
    '🇪🇸' => 'steag: Spania',
    '🇪🇹' => 'steag: Etiopia',
    '🇪🇺' => 'steag: Uniunea Europeană',
    '🇫🇮' => 'steag: Finlanda',
    '🇫🇯' => 'steag: Fiji',
    '🇫🇰' => 'steag: Insulele Falkland',
    '🇫🇲' => 'steag: Micronezia',
    '🇫🇴' => 'steag: Insulele Feroe',
    '🇫🇷' => 'steag: Franța',
    '🇬🇦' => 'steag: Gabon',
    '🇬🇧' => 'steag: Regatul Unit',
    '🇬🇩' => 'steag: Grenada',
    '🇬🇪' => 'steag: Georgia',
    '🇬🇫' => 'steag: Guyana Franceză',
    '🇬🇬' => 'steag: Guernsey',
    '🇬🇭' => 'steag: Ghana',
    '🇬🇮' => 'steag: Gibraltar',
    '🇬🇱' => 'steag: Groenlanda',
    '🇬🇲' => 'steag: Gambia',
    '🇬🇳' => 'steag: Guineea',
    '🇬🇵' => 'steag: Guadelupa',
    '🇬🇶' => 'steag: Guineea Ecuatorială',
    '🇬🇷' => 'steag: Grecia',
    '🇬🇸' => 'steag: Georgia de Sud și Insulele Sandwich de Sud',
    '🇬🇹' => 'steag: Guatemala',
    '🇬🇺' => 'steag: Guam',
    '🇬🇼' => 'steag: Guineea-Bissau',
    '🇬🇾' => 'steag: Guyana',
    '🇭🇰' => 'steag: R.A.S. Hong Kong, China',
    '🇭🇲' => 'steag: Insula Heard și Insulele McDonald',
    '🇭🇳' => 'steag: Honduras',
    '🇭🇷' => 'steag: Croația',
    '🇭🇹' => 'steag: Haiti',
    '🇭🇺' => 'steag: Ungaria',
    '🇮🇨' => 'steag: Insulele Canare',
    '🇮🇩' => 'steag: Indonezia',
    '🇮🇪' => 'steag: Irlanda',
    '🇮🇱' => 'steag: Israel',
    '🇮🇲' => 'steag: Insula Man',
    '🇮🇳' => 'steag: India',
    '🇮🇴' => 'steag: Teritoriul Britanic din Oceanul Indian',
    '🇮🇶' => 'steag: Irak',
    '🇮🇷' => 'steag: Iran',
    '🇮🇸' => 'steag: Islanda',
    '🇮🇹' => 'steag: Italia',
    '🇯🇪' => 'steag: Jersey',
    '🇯🇲' => 'steag: Jamaica',
    '🇯🇴' => 'steag: Iordania',
    '🇯🇵' => 'steag: Japonia',
    '🇰🇪' => 'steag: Kenya',
    '🇰🇬' => 'steag: Kârgâzstan',
    '🇰🇭' => 'steag: Cambodgia',
    '🇰🇮' => 'steag: Kiribati',
    '🇰🇲' => 'steag: Comore',
    '🇰🇳' => 'steag: Saint Kitts și Nevis',
    '🇰🇵' => 'steag: Coreea de Nord',
    '🇰🇷' => 'steag: Coreea de Sud',
    '🇰🇼' => 'steag: Kuweit',
    '🇰🇾' => 'steag: Insulele Cayman',
    '🇰🇿' => 'steag: Kazahstan',
    '🇱🇦' => 'steag: Laos',
    '🇱🇧' => 'steag: Liban',
    '🇱🇨' => 'steag: Sfânta Lucia',
    '🇱🇮' => 'steag: Liechtenstein',
    '🇱🇰' => 'steag: Sri Lanka',
    '🇱🇷' => 'steag: Liberia',
    '🇱🇸' => 'steag: Lesotho',
    '🇱🇹' => 'steag: Lituania',
    '🇱🇺' => 'steag: Luxemburg',
    '🇱🇻' => 'steag: Letonia',
    '🇱🇾' => 'steag: Libia',
    '🇲🇦' => 'steag: Maroc',
    '🇲🇨' => 'steag: Monaco',
    '🇲🇩' => 'steag: Republica Moldova',
    '🇲🇪' => 'steag: Muntenegru',
    '🇲🇫' => 'steag: Sfântul Martin',
    '🇲🇬' => 'steag: Madagascar',
    '🇲🇭' => 'steag: Insulele Marshall',
    '🇲🇰' => 'steag: Macedonia de Nord',
    '🇲🇱' => 'steag: Mali',
    '🇲🇲' => 'steag: Myanmar (Birmania)',
    '🇲🇳' => 'steag: Mongolia',
    '🇲🇴' => 'steag: R.A.S. Macao, China',
    '🇲🇵' => 'steag: Insulele Mariane de Nord',
    '🇲🇶' => 'steag: Martinica',
    '🇲🇷' => 'steag: Mauritania',
    '🇲🇸' => 'steag: Montserrat',
    '🇲🇹' => 'steag: Malta',
    '🇲🇺' => 'steag: Mauritius',
    '🇲🇻' => 'steag: Maldive',
    '🇲🇼' => 'steag: Malawi',
    '🇲🇽' => 'steag: Mexic',
    '🇲🇾' => 'steag: Malaysia',
    '🇲🇿' => 'steag: Mozambic',
    '🇳🇦' => 'steag: Namibia',
    '🇳🇨' => 'steag: Noua Caledonie',
    '🇳🇪' => 'steag: Niger',
    '🇳🇫' => 'steag: Insula Norfolk',
    '🇳🇬' => 'steag: Nigeria',
    '🇳🇮' => 'steag: Nicaragua',
    '🇳🇱' => 'steag: Țările de Jos',
    '🇳🇴' => 'steag: Norvegia',
    '🇳🇵' => 'steag: Nepal',
    '🇳🇷' => 'steag: Nauru',
    '🇳🇺' => 'steag: Niue',
    '🇳🇿' => 'steag: Noua Zeelandă',
    '🇴🇲' => 'steag: Oman',
    '🇵🇦' => 'steag: Panama',
    '🇵🇪' => 'steag: Peru',
    '🇵🇫' => 'steag: Polinezia Franceză',
    '🇵🇬' => 'steag: Papua-Noua Guinee',
    '🇵🇭' => 'steag: Filipine',
    '🇵🇰' => 'steag: Pakistan',
    '🇵🇱' => 'steag: Polonia',
    '🇵🇲' => 'steag: Saint-Pierre și Miquelon',
    '🇵🇳' => 'steag: Insulele Pitcairn',
    '🇵🇷' => 'steag: Puerto Rico',
    '🇵🇸' => 'steag: Teritoriile Palestiniene',
    '🇵🇹' => 'steag: Portugalia',
    '🇵🇼' => 'steag: Palau',
    '🇵🇾' => 'steag: Paraguay',
    '🇶🇦' => 'steag: Qatar',
    '🇷🇪' => 'steag: Réunion',
    '🇷🇴' => 'steag: România',
    '🇷🇸' => 'steag: Serbia',
    '🇷🇺' => 'steag: Rusia',
    '🇷🇼' => 'steag: Rwanda',
    '🇸🇦' => 'steag: Arabia Saudită',
    '🇸🇧' => 'steag: Insulele Solomon',
    '🇸🇨' => 'steag: Seychelles',
    '🇸🇩' => 'steag: Sudan',
    '🇸🇪' => 'steag: Suedia',
    '🇸🇬' => 'steag: Singapore',
    '🇸🇭' => 'steag: Sfânta Elena',
    '🇸🇮' => 'steag: Slovenia',
    '🇸🇯' => 'steag: Svalbard și Jan Mayen',
    '🇸🇰' => 'steag: Slovacia',
    '🇸🇱' => 'steag: Sierra Leone',
    '🇸🇲' => 'steag: San Marino',
    '🇸🇳' => 'steag: Senegal',
    '🇸🇴' => 'steag: Somalia',
    '🇸🇷' => 'steag: Suriname',
    '🇸🇸' => 'steag: Sudanul de Sud',
    '🇸🇹' => 'steag: São Tomé și Príncipe',
    '🇸🇻' => 'steag: El Salvador',
    '🇸🇽' => 'steag: Sint-Maarten',
    '🇸🇾' => 'steag: Siria',
    '🇸🇿' => 'steag: Eswatini',
    '🇹🇦' => 'steag: Tristan da Cunha',
    '🇹🇨' => 'steag: Insulele Turks și Caicos',
    '🇹🇩' => 'steag: Ciad',
    '🇹🇫' => 'steag: Teritoriile Australe și Antarctice Franceze',
    '🇹🇬' => 'steag: Togo',
    '🇹🇭' => 'steag: Thailanda',
    '🇹🇯' => 'steag: Tadjikistan',
    '🇹🇰' => 'steag: Tokelau',
    '🇹🇱' => 'steag: Timor-Leste',
    '🇹🇲' => 'steag: Turkmenistan',
    '🇹🇳' => 'steag: Tunisia',
    '🇹🇴' => 'steag: Tonga',
    '🇹🇷' => 'steag: Turcia',
    '🇹🇹' => 'steag: Trinidad și Tobago',
    '🇹🇻' => 'steag: Tuvalu',
    '🇹🇼' => 'steag: Taiwan',
    '🇹🇿' => 'steag: Tanzania',
    '🇺🇦' => 'steag: Ucraina',
    '🇺🇬' => 'steag: Uganda',
    '🇺🇲' => 'steag: Insulele Îndepărtate ale S.U.A.',
    '🇺🇳' => 'steag: Națiunile Unite',
    '🇺🇸' => 'steag: Statele Unite ale Americii',
    '🇺🇾' => 'steag: Uruguay',
    '🇺🇿' => 'steag: Uzbekistan',
    '🇻🇦' => 'steag: Statul Cetății Vaticanului',
    '🇻🇨' => 'steag: Saint Vincent și Grenadinele',
    '🇻🇪' => 'steag: Venezuela',
    '🇻🇬' => 'steag: Insulele Virgine Britanice',
    '🇻🇮' => 'steag: Insulele Virgine Americane',
    '🇻🇳' => 'steag: Vietnam',
    '🇻🇺' => 'steag: Vanuatu',
    '🇼🇫' => 'steag: Wallis și Futuna',
    '🇼🇸' => 'steag: Samoa',
    '🇽🇰' => 'steag: Kosovo',
    '🇾🇪' => 'steag: Yemen',
    '🇾🇹' => 'steag: Mayotte',
    '🇿🇦' => 'steag: Africa de Sud',
    '🇿🇲' => 'steag: Zambia',
    '🇿🇼' => 'steag: Zimbabwe',
    '🔟' => 'tastă: 10',
    '🏻' => 'ton deschis al pielii',
    '🏼' => 'ton semi‑deschis al pielii',
    '🏽' => 'ton mediu al pielii',
    '🏾' => 'ton semi‑închis al pielii',
    '🏿' => 'ton închis al pielii',
    '😀' => 'față încântată',
    '😃' => 'față încântată cu ochii mari',
    '😄' => 'față încântată cu ochi zâmbitori',
    '😁' => 'față radioasă cu ochi zâmbitori',
    '😆' => 'față încântată cu ochii întredeschiși',
    '😅' => 'față încântată cu sudoare rece',
    '🤣' => 'tăvălindu-se pe jos de râs',
    '😂' => 'față cu lacrimi de bucurie',
    '🙂' => 'față ușor zâmbitoare',
    '🙃' => 'față cu susul în jos',
    '🫠' => 'față care se topește',
    '😉' => 'față care face cu ochiul',
    '😊' => 'față zâmbitoare cu ochi zâmbitori',
    '😇' => 'față zâmbitoare cu aură',
    '🥰' => 'față zâmbitoare cu inimioare',
    '😍' => 'față zâmbitoare cu inimioare la ochi',
    '🤩' => 'față cu steluțe la ochi',
    '😘' => 'față care trimite un pupic',
    '😗' => 'față pupăcioasă',
    '☺' => 'față zâmbitoare',
    '😚' => 'față pupăcioasă cu ochi închiși',
    '😙' => 'față pupăcioasă cu ochi zâmbitori',
    '🥲' => 'față zâmbind cu lacrimă',
    '😋' => 'față savurând mâncare delicioasă',
    '😛' => 'față cu limba scoasă',
    '😜' => 'față cu limba scoasă, făcând cu ochiul',
    '🤪' => 'față nebună',
    '😝' => 'față cu limba scoasă și ochii întredeschiși',
    '🤑' => 'față încântată de bani',
    '🤗' => 'față cu gest de îmbrățișare',
    '🤭' => 'față cu mâna peste gură',
    '🫢' => 'față cu ochii deschiși și palma la gură',
    '🫣' => 'față care trage cu ochiul',
    '🤫' => 'față care șâșâie',
    '🤔' => 'față gânditoare',
    '🫡' => 'față care salută',
    '🤐' => 'față cu fermoar la buze',
    '🤨' => 'față cu sprânceană ridicată',
    '😐' => 'față neutră',
    '😑' => 'față fără expresie',
    '😶' => 'față fără gură',
    '🫥' => 'față cu contur punctat',
    '😏' => 'față cu zâmbet superior',
    '😒' => 'față morocănoasă',
    '🙄' => 'față care dă ochii peste cap',
    '😬' => 'față cu grimasă',
    '🤥' => 'fața mincinoasă',
    '🫨' => 'față zgâlțâită',
    '😌' => 'față ușurată',
    '😔' => 'față îngândurată',
    '😪' => 'față somnoroasă',
    '🤤' => 'față care salivează',
    '😴' => 'față adormită',
    '🫩' => 'față cu cearcăne',
    '😷' => 'față cu mască medicală',
    '🤒' => 'față cu termometru',
    '🤕' => 'față cu capul bandajat',
    '🤢' => 'față îngrețoșată',
    '🤮' => 'față vomitând',
    '🤧' => 'față care strănută',
    '🥵' => 'față fierbinte',
    '🥶' => 'față înghețată',
    '🥴' => 'față cherchelită',
    '😵' => 'față amețită',
    '🤯' => 'cap care explodează',
    '🤠' => 'față cu pălărie de cowboy',
    '🥳' => 'față de petrecere',
    '🥸' => 'față deghizată',
    '😎' => 'față zâmbitoare cu ochelari de soare',
    '🤓' => 'față de tocilar',
    '🧐' => 'față cu monoclu',
    '😕' => 'față confuză',
    '🫤' => 'față cu gura pe diagonală',
    '😟' => 'față îngrijorată',
    '🙁' => 'față ușor tristă',
    '☹' => 'față tristă',
    '😮' => 'față cu gura deschisă',
    '😯' => 'față amuțită',
    '😲' => 'față uimită',
    '😳' => 'față îmbujorată',
    '🫪' => 'față distorsionată',
    '🥺' => 'față rugătoare',
    '🥹' => 'față cu lacrimi în ochi',
    '😦' => 'față tristă cu gura deschisă',
    '😧' => 'față angoasată',
    '😨' => 'față înfricoșată',
    '😰' => 'față neliniștită cu sudoare rece',
    '😥' => 'față dezamăgită, dar ușurată',
    '😢' => 'față plângând',
    '😭' => 'față plângând zgomotos',
    '😱' => 'față țipând de frică',
    '😖' => 'față derutată',
    '😣' => 'față neajutorată',
    '😞' => 'față dezamăgită',
    '😓' => 'față abătută cu sudoare rece',
    '😩' => 'față extenuată',
    '😫' => 'față obosită',
    '🥱' => 'față care cască',
    '😤' => 'față care scoate fum pe nări',
    '😡' => 'față îmbufnată',
    '😠' => 'față furioasă',
    '🤬' => 'față cu simboluri la gură',
    '😈' => 'față zâmbitoare încornorată',
    '👿' => 'față mânioasă încornorată',
    '💀' => 'craniu',
    '☠' => 'craniu cu oase încrucișate',
    '💩' => 'răhățel',
    '🤡' => 'față de clovn',
    '👹' => 'căpcăun',
    '👺' => 'spiriduș',
    '👻' => 'fantomă',
    '👽' => 'extraterestru',
    '👾' => 'monstru extraterestru',
    '🤖' => 'robot',
    '😺' => 'pisică încântată',
    '😸' => 'pisică încântată cu ochi zâmbitori',
    '😹' => 'pisică cu lacrimi de bucurie',
    '😻' => 'pisică zâmbitoare cu inimioare la ochi',
    '😼' => 'pisică cu zâmbet ironic',
    '😽' => 'pisică pupăcioasă',
    '🙀' => 'pisică surprinsă',
    '😿' => 'pisică plângând',
    '😾' => 'pisică îmbufnată',
    '🙈' => 'nu văd nimic rău',
    '🙉' => 'nu aud nimic rău',
    '🙊' => 'nu spun nimic rău',
    '💌' => 'scrisoare de dragoste',
    '💘' => 'inimă săgetată',
    '💝' => 'inimă cu fundiță',
    '💖' => 'inimă strălucitoare',
    '💗' => 'inimă care crește',
    '💓' => 'inimă palpitând',
    '💞' => 'inimi învârtindu-se în cerc',
    '💕' => 'două inimioare',
    '💟' => 'decorațiune inimă',
    '❣' => 'semnul exclamării cu inimioară',
    '💔' => 'inimă zdrobită',
    '❤' => 'inimă roșie',
    '🩷' => 'inimă roz',
    '🧡' => 'inimă portocalie',
    '💛' => 'inimă galbenă',
    '💚' => 'inimă verde',
    '💙' => 'inimă albastră',
    '🩵' => 'inimă albastru-deschis',
    '💜' => 'inimă mov',
    '🤎' => 'inimă maro',
    '🖤' => 'inimă neagră',
    '🩶' => 'inimă gri',
    '🤍' => 'inimă albă',
    '💋' => 'urme de buze',
    '💯' => 'o sută de puncte',
    '💢' => 'simbol mânie',
    '🫯' => 'nor de bătaie',
    '💥' => 'coliziune',
    '💫' => 'amețit',
    '💦' => 'picături de transpirație',
    '💨' => 'ștergând-o rapid',
    '🕳' => 'gaură',
    '💬' => 'balon de dialog',
    '🗨' => 'balon de dialog la stânga',
    '🗯' => 'balon de dialog furios la dreapta',
    '💭' => 'balon de gândire',
    '💤' => 'sfor',
    '👋' => 'mână fluturată',
    '🤚' => 'dosul palmei ridicat',
    '🖐' => 'mână ridicată cu degetele depărtate',
    '✋' => 'mână ridicată',
    '🖖' => 'salut vulcanian',
    '🫱' => 'mână spre dreapta',
    '🫲' => 'mână spre stânga',
    '🫳' => 'mână cu palma în jos',
    '🫴' => 'mână cu palma în sus',
    '🫷' => 'mână care împinge spre stânga',
    '🫸' => 'mână care împinge spre dreapta',
    '👌' => 'semnul ok',
    '🤌' => 'degete strânse',
    '🤏' => 'mână cu două degete apropiate',
    '✌' => 'semnul victoriei',
    '🤞' => 'degete încrucișate',
    '🫰' => 'mână cu degetul mare și arătătorul încrucișate',
    '🤟' => 'gest cu semnificația te iubesc',
    '🤘' => 'semnul cu coarne',
    '🤙' => 'semnul sună-mă',
    '👈' => 'dos de mână cu arătătorul spre stânga',
    '👉' => 'dos de mână cu arătătorul spre dreapta',
    '👆' => 'dos de mână cu arătătorul în sus',
    '🖕' => 'degetul mijlociu',
    '👇' => 'dos de mână cu arătătorul în jos',
    '☝' => 'deget arătător îndreptat în sus',
    '🫵' => 'deget arătător îndreptat spre privitor',
    '👍' => 'semn de aprobare',
    '👎' => 'semn de dezaprobare',
    '✊' => 'pumn ridicat',
    '👊' => 'lovitură de pumn',
    '🤛' => 'pumn spre stânga',
    '🤜' => 'pumn spre dreapta',
    '👏' => 'mâini care aplaudă',
    '🙌' => 'mâini ridicate',
    '🫶' => 'mâini care formează o inimă',
    '👐' => 'palme deschise',
    '🤲' => 'palme ridicate împreună',
    '🤝' => 'strângere de mână',
    '🙏' => 'mâini unite',
    '✍' => 'mână scriind',
    '💅' => 'ojă pe unghii',
    '🤳' => 'selfie',
    '💪' => 'biceps flexat',
    '🦾' => 'braț mecanic',
    '🦿' => 'picior mecanic',
    '🦵' => 'picior',
    '🦶' => 'laba piciorului',
    '👂' => 'ureche',
    '🦻' => 'ureche cu proteză auditivă',
    '👃' => 'nas',
    '🧠' => 'creier',
    '🫀' => 'inimă',
    '🫁' => 'plămâni',
    '🦷' => 'dinte',
    '🦴' => 'os',
    '👀' => 'doi ochi',
    '👁' => 'un ochi',
    '👅' => 'limbă',
    '👄' => 'gură',
    '🫦' => 'buză mușcată',
    '👶' => 'bebeluș',
    '🧒' => 'copil',
    '👦' => 'băiat',
    '👧' => 'fată',
    '🧑' => 'adult',
    '👱' => 'persoană blondă',
    '👨' => 'bărbat',
    '🧔' => 'bărbat cu barbă',
    '👩' => 'femeie',
    '🧓' => 'persoană în vârstă',
    '👴' => 'bătrân',
    '👵' => 'bătrână',
    '🙍' => 'persoană întristată',
    '🙎' => 'persoană bosumflată',
    '🙅' => 'persoană făcând un gest de negație',
    '🙆' => 'persoană făcând un gest de OK',
    '💁' => 'persoană care explică',
    '🙋' => 'persoană care ridică mâna',
    '🧏' => 'persoană surdă',
    '🙇' => 'persoană care se înclină',
    '🤦' => 'persoană care își acoperă fața cu o palmă',
    '🤷' => 'persoană care ridică din umeri',
    '👮' => 'polițist sau polițistă',
    '🕵' => 'detectiv',
    '💂' => 'gardian',
    '🥷' => 'ninja',
    '👷' => 'constructor',
    '🫅' => 'persoană cu coroană',
    '🤴' => 'prinț',
    '👸' => 'prințesă',
    '👳' => 'persoană cu turban',
    '👲' => 'bărbat cu bonetă chinezească',
    '🧕' => 'femeie cu năframă',
    '🤵' => 'persoană în smoching',
    '👰' => 'persoană cu voal',
    '🤰' => 'femeie însărcinată',
    '🫃' => 'bărbat însărcinat',
    '🫄' => 'persoană însărcinată',
    '🤱' => 'alăptare la sân',
    '👼' => 'bebeluș îngeraș',
    '🎅' => 'Moș Crăciun',
    '🤶' => 'Doamna Crăciun',
    '🦸' => 'supererou',
    '🦹' => 'super-ticălos',
    '🧙' => 'mag',
    '🧚' => 'zână',
    '🧛' => 'vampir',
    '🧜' => 'persoană sirenă',
    '🧝' => 'elf',
    '🧞' => 'duh',
    '🧟' => 'zombi',
    '🧌' => 'trol',
    '🫈' => 'creatură păroasă',
    '💆' => 'persoană care primește un masaj facial',
    '💇' => 'persoană care se tunde',
    '🚶' => 'persoană care merge',
    '🧍' => 'persoană în picioare',
    '🧎' => 'persoană în genunchi',
    '🏃' => 'persoană care aleargă',
    '💃' => 'dansatoare',
    '🕺' => 'dansator',
    '🕴' => 'persoană în costum, levitând',
    '👯' => 'persoane care poartă urechi de iepuraș',
    '🧖' => 'persoană în saună',
    '🧗' => 'persoană care se cațără',
    '🤺' => 'persoană care practică scrima',
    '🏇' => 'curse de cai',
    '⛷' => 'persoană care schiază',
    '🏂' => 'persoană care practică snow-board',
    '🏌' => 'persoană care joacă golf',
    '🏄' => 'persoană care practică surfing',
    '🚣' => 'persoană care vâslește în barcă',
    '🏊' => 'persoană care înoată',
    '⛹' => 'persoană care bate mingea',
    '🏋' => 'persoană care ridică greutăți',
    '🚴' => 'persoană pe bicicletă',
    '🚵' => 'persoană pe bicicletă montană',
    '🤸' => 'persoană care face roata',
    '🤼' => 'persoane care practică wrestling',
    '🤽' => 'persoană care joacă polo pe apă',
    '🤾' => 'persoană care joacă handbal',
    '🤹' => 'persoană care jonglează',
    '🧘' => 'persoană în poziția lotus',
    '🛀' => 'persoană care face baie',
    '🛌' => 'persoană în pat',
    '👭' => 'femei ținându-se de mână',
    '👫' => 'bărbat și femeie ținându-se de mână',
    '👬' => 'bărbați ținându-se de mână',
    '💏' => 'sărut',
    '💑' => 'cuplu cu inimă',
    '🗣' => 'cap vorbitor',
    '👤' => 'siluetă bust',
    '👥' => 'siluete busturi',
    '🫂' => 'persoane îmbrățișate',
    '👪' => 'familie',
    '👣' => 'urme de pași',
    '🫆' => 'amprentă',
    '🦰' => 'păr roșcat',
    '🦱' => 'păr creț',
    '🦳' => 'păr alb',
    '🦲' => 'chelie',
    '🐵' => 'față de maimuță',
    '🐒' => 'maimuță',
    '🦍' => 'gorilă',
    '🦧' => 'urangutan',
    '🐶' => 'față de câine',
    '🐕' => 'câine',
    '🦮' => 'câine ghid',
    '🐩' => 'pudel',
    '🐺' => 'lup',
    '🦊' => 'vulpe',
    '🦝' => 'raton',
    '🐱' => 'față de pisică',
    '🐈' => 'pisică',
    '🦁' => 'leu',
    '🐯' => 'față de tigru',
    '🐅' => 'tigru',
    '🐆' => 'leopard',
    '🐴' => 'față de cal',
    '🫎' => 'elan',
    '🫏' => 'măgar',
    '🐎' => 'cal',
    '🦄' => 'unicorn',
    '🦓' => 'zebră',
    '🦌' => 'cerb',
    '🦬' => 'bizon',
    '🐮' => 'cap de vacă',
    '🐂' => 'bou',
    '🐃' => 'bivol',
    '🐄' => 'vacă',
    '🐷' => 'cap de porc',
    '🐖' => 'porc',
    '🐗' => 'mistreț',
    '🐽' => 'rât',
    '🐏' => 'berbec',
    '🐑' => 'oaie',
    '🐐' => 'capră',
    '🐪' => 'dromader',
    '🐫' => 'cămilă',
    '🦙' => 'lamă',
    '🦒' => 'girafă',
    '🐘' => 'elefant',
    '🦣' => 'mamut',
    '🦏' => 'rinocer',
    '🦛' => 'hipopotam',
    '🐭' => 'față de șoarece',
    '🐁' => 'șoarece',
    '🐀' => 'șobolan',
    '🐹' => 'hamster',
    '🐰' => 'față de iepure',
    '🐇' => 'iepure',
    '🐿' => 'veveriță',
    '🦫' => 'castor',
    '🦔' => 'arici',
    '🦇' => 'liliac',
    '🐻' => 'urs',
    '🐨' => 'koala',
    '🐼' => 'panda',
    '🦥' => 'leneș',
    '🦦' => 'vidră',
    '🦨' => 'sconcs',
    '🦘' => 'cangur',
    '🦡' => 'bursuc',
    '🐾' => 'urme de lăbuțe',
    '🦃' => 'curcan',
    '🐔' => 'găină',
    '🐓' => 'cocoș',
    '🐣' => 'pui în găoace',
    '🐤' => 'pui de găină',
    '🐥' => 'pui de găină din față',
    '🐦' => 'pasăre',
    '🐧' => 'pinguin',
    '🕊' => 'porumbiță',
    '🦅' => 'vultur',
    '🦆' => 'rață',
    '🦢' => 'lebădă',
    '🦉' => 'bufniță',
    '🦤' => 'dodo',
    '🪶' => 'pană',
    '🦩' => 'flamingo',
    '🦚' => 'păun',
    '🦜' => 'papagal mare',
    '🪽' => 'aripă',
    '🪿' => 'gâscă',
    '🐸' => 'broască',
    '🐊' => 'crocodil',
    '🐢' => 'broască țestoasă',
    '🦎' => 'șopârlă',
    '🐍' => 'șarpe',
    '🐲' => 'față de dragon',
    '🐉' => 'dragon',
    '🦕' => 'sauropod',
    '🦖' => 'T-Rex',
    '🐳' => 'balenă împroșcând apă',
    '🐋' => 'balenă',
    '🐬' => 'delfin',
    '🫍' => 'orca',
    '🦭' => 'focă',
    '🐟' => 'pește',
    '🐠' => 'pește tropical',
    '🐡' => 'pește balon',
    '🦈' => 'rechin',
    '🐙' => 'caracatiță',
    '🐚' => 'cochilie spiralată',
    '🪸' => 'coral',
    '🪼' => 'meduză',
    '🦀' => 'rac',
    '🦞' => 'homar',
    '🦐' => 'crevete',
    '🦑' => 'calmar',
    '🦪' => 'stridie',
    '🐌' => 'melc',
    '🦋' => 'fluture',
    '🐛' => 'gândac',
    '🐜' => 'furnică',
    '🐝' => 'albină',
    '🪲' => 'cărăbuș',
    '🐞' => 'buburuză',
    '🦗' => 'greier',
    '🪳' => 'gândac de bucătărie',
    '🕷' => 'păianjen',
    '🕸' => 'pânză de păianjen',
    '🦂' => 'scorpion',
    '🦟' => 'țânțar',
    '🪰' => 'muscă',
    '🪱' => 'vierme',
    '🦠' => 'microb',
    '💐' => 'buchet de flori',
    '🌸' => 'floare de cireș',
    '💮' => 'floare albă',
    '🪷' => 'lotus',
    '🏵' => 'rozetă',
    '🌹' => 'trandafir',
    '🥀' => 'floare ofilită',
    '🌺' => 'hibiscus',
    '🌻' => 'floarea soarelui',
    '🌼' => 'boboc',
    '🌷' => 'lalea',
    '🪻' => 'zambilă',
    '🌱' => 'răsad',
    '🪴' => 'plantă în ghiveci',
    '🌲' => 'arbore conifer',
    '🌳' => 'arbore foios',
    '🌴' => 'palmier',
    '🌵' => 'cactus',
    '🌾' => 'snop de orez',
    '🌿' => 'plantă aromatică',
    '☘' => 'trifoi',
    '🍀' => 'trifoi cu patru foi',
    '🍁' => 'frunză de arțar',
    '🍂' => 'frunză în cădere',
    '🍃' => 'frunză plutind în aer',
    '🪹' => 'cuib gol',
    '🪺' => 'cuib cu ouă',
    '🍄' => 'ciupercă',
    '🪾' => 'copac desfrunzit',
    '🍇' => 'struguri',
    '🍈' => 'pepene galben',
    '🍉' => 'pepene verde',
    '🍊' => 'mandarină',
    '🍋' => 'lămâie',
    '🍌' => 'banană',
    '🍍' => 'ananas',
    '🥭' => 'mango',
    '🍎' => 'măr roșu',
    '🍏' => 'măr verde',
    '🍐' => 'pară',
    '🍑' => 'piersică',
    '🍒' => 'cireșe',
    '🍓' => 'căpșună',
    '🫐' => 'afine',
    '🥝' => 'kiwi',
    '🍅' => 'roșie',
    '🫒' => 'măslină',
    '🥥' => 'nucă de cocos',
    '🥑' => 'avocado',
    '🍆' => 'vânătă',
    '🥔' => 'cartof',
    '🥕' => 'morcov',
    '🌽' => 'știulete de porumb',
    '🌶' => 'ardei iute',
    '🫑' => 'ardei gras',
    '🥒' => 'castravete',
    '🥬' => 'verdețuri',
    '🥦' => 'broccoli',
    '🧄' => 'usturoi',
    '🧅' => 'ceapă',
    '🥜' => 'arahide',
    '🫘' => 'fasole',
    '🌰' => 'castană',
    '🫚' => 'rădăcină de ghimbir',
    '🫛' => 'păstaie de mazăre',
    '🫜' => 'legumă rădăcinoasă',
    '🍞' => 'pâine',
    '🥐' => 'croasant',
    '🥖' => 'baghetă de pâine',
    '🫓' => 'pită',
    '🥨' => 'covrig',
    '🥯' => 'bagel',
    '🥞' => 'clătite',
    '🧇' => 'gofră',
    '🧀' => 'bucată de brânză',
    '🍖' => 'os cu carne',
    '🍗' => 'pulpă de pasăre',
    '🥩' => 'bucată de carne',
    '🥓' => 'bacon',
    '🍔' => 'hamburger',
    '🍟' => 'cartofi prăjiți',
    '🍕' => 'pizza',
    '🌭' => 'hot dog',
    '🥪' => 'sandvici',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'lipie umplută',
    '🧆' => 'falafel',
    '🥚' => 'ou',
    '🍳' => 'gătit',
    '🥘' => 'cratiță cu mâncare',
    '🍲' => 'oală cu mâncare',
    '🫕' => 'fondue',
    '🥣' => 'castron cu lingură',
    '🥗' => 'salată verde',
    '🍿' => 'popcorn',
    '🧈' => 'unt',
    '🧂' => 'sare',
    '🥫' => 'mâncare la conservă',
    '🍱' => 'mâncare japoneză la pachet',
    '🍘' => 'biscuit de orez',
    '🍙' => 'chifteluțe de orez',
    '🍚' => 'orez gătit',
    '🍛' => 'orez cu curry',
    '🍜' => 'castron aburind',
    '🍝' => 'spaghete',
    '🍠' => 'cartof dulce copt',
    '🍢' => 'frigăruie japoneză',
    '🍣' => 'sushi',
    '🍤' => 'crevete prăjit',
    '🍥' => 'ruladă japoneză cu pește',
    '🥮' => 'prăjitura lunii',
    '🍡' => 'găluște japoneze pe băț',
    '🥟' => 'găluște chinezești',
    '🥠' => 'prăjiturele cu răvaș',
    '🥡' => 'mâncare la pachet',
    '🍦' => 'înghețată cremă',
    '🍧' => 'desert din fulgi de gheață',
    '🍨' => 'înghețată',
    '🍩' => 'gogoașă americană',
    '🍪' => 'fursec',
    '🎂' => 'tort aniversar',
    '🍰' => 'tartă',
    '🧁' => 'brioșă',
    '🥧' => 'plăcintă',
    '🍫' => 'baton de ciocolată',
    '🍬' => 'bomboană',
    '🍭' => 'acadea',
    '🍮' => 'șarlotă',
    '🍯' => 'borcan cu miere',
    '🍼' => 'biberon',
    '🥛' => 'pahar cu lapte',
    '☕' => 'băutură fierbinte',
    '🫖' => 'ceainic',
    '🍵' => 'ceașcă fără mâner',
    '🍶' => 'sake',
    '🍾' => 'sticlă căreia îi sare dopul',
    '🍷' => 'pahar de vin',
    '🍸' => 'pahar de cocktail',
    '🍹' => 'băutură tropicală',
    '🍺' => 'halbă de bere',
    '🍻' => 'halbe de bere ciocnite',
    '🥂' => 'pahare ciocnite',
    '🥃' => 'pahar de whisky',
    '🫗' => 'lichid turnat',
    '🥤' => 'pahar cu pai',
    '🧋' => 'ceai cu perle',
    '🧃' => 'cutie de băutură',
    '🧉' => 'mate',
    '🧊' => 'cub de gheață',
    '🥢' => 'bețișoare japoneze',
    '🍽' => 'furculiță și cuțit cu farfurie',
    '🍴' => 'furculiță și cuțit',
    '🥄' => 'lingură',
    '🔪' => 'cuțit de bucătărie',
    '🫙' => 'borcan',
    '🏺' => 'amforă',
    '🌍' => 'Europa și Africa pe glob',
    '🌎' => 'Americile pe glob',
    '🌏' => 'Asia și Australia pe glob',
    '🌐' => 'glob cu meridiane',
    '🗺' => 'harta lumii',
    '🗾' => 'harta Japoniei',
    '🧭' => 'busolă',
    '🏔' => 'vârf de munte înzăpezit',
    '⛰' => 'munte',
    '🛘' => 'alunecare de teren',
    '🌋' => 'vulcan',
    '🗻' => 'muntele Fuji',
    '🏕' => 'camping',
    '🏖' => 'umbrelă pe plajă',
    '🏜' => 'deșert',
    '🏝' => 'insulă pustie',
    '🏞' => 'parc național',
    '🏟' => 'stadion',
    '🏛' => 'clădire clasică',
    '🏗' => 'clădire în construcție',
    '🧱' => 'cărămidă',
    '🪨' => 'piatră',
    '🪵' => 'lemn',
    '🛖' => 'colibă',
    '🏘' => 'case',
    '🏚' => 'casă părăsită',
    '🏠' => 'casă',
    '🏡' => 'casă cu grădină',
    '🏢' => 'clădire de birouri',
    '🏣' => 'oficiu poștal japonez',
    '🏤' => 'oficiu poștal',
    '🏥' => 'spital',
    '🏦' => 'bancă',
    '🏨' => 'hotel',
    '🏩' => 'hotel de dragoste',
    '🏪' => 'magazin non-stop',
    '🏫' => 'școală',
    '🏬' => 'magazin universal',
    '🏭' => 'fabrică',
    '🏯' => 'castel japonez',
    '🏰' => 'castel',
    '💒' => 'nuntă',
    '🗼' => 'turnul Tokio',
    '🗽' => 'Statuia Libertății',
    '⛪' => 'biserică',
    '🕌' => 'moschee',
    '🛕' => 'templu hindus',
    '🕍' => 'sinagogă',
    '⛩' => 'altar shinto',
    '🕋' => 'lăcaș de cult islamic kaaba',
    '⛲' => 'fântână arteziană',
    '⛺' => 'cort',
    '🌁' => 'încețoșat',
    '🌃' => 'noapte înstelată',
    '🏙' => 'peisaj urban',
    '🌄' => 'răsărit după munți',
    '🌅' => 'răsărit',
    '🌆' => 'peisaj urban la apus',
    '🌇' => 'apus',
    '🌉' => 'pod luminat noaptea',
    '♨' => 'izvoare termale',
    '🎠' => 'căluț de carusel',
    '🛝' => 'tobogan pentru joacă',
    '🎡' => 'roata mare',
    '🎢' => 'montagne russe',
    '💈' => 'semn de frizerie',
    '🎪' => 'cort de circ',
    '🚂' => 'locomotivă',
    '🚃' => 'vagon feroviar',
    '🚄' => 'tren de mare viteză',
    '🚅' => 'tren de mare viteză cu vârf aerodinamic',
    '🚆' => 'tren',
    '🚇' => 'metrou',
    '🚈' => 'tren ușor',
    '🚉' => 'gară',
    '🚊' => 'tramvai',
    '🚝' => 'monorai',
    '🚞' => 'cale ferată montană',
    '🚋' => 'vagon de tramvai',
    '🚌' => 'autobuz',
    '🚍' => 'autobuz care se apropie',
    '🚎' => 'troleibuz',
    '🚐' => 'microbuz',
    '🚑' => 'ambulanță',
    '🚒' => 'mașină de pompieri',
    '🚓' => 'mașină de poliție',
    '🚔' => 'mașină de poliție care se apropie',
    '🚕' => 'taxi',
    '🚖' => 'taxi care se apropie',
    '🚗' => 'automobil',
    '🚘' => 'automobil care se apropie',
    '🚙' => 'vehicul recreațional',
    '🛻' => 'camionetă',
    '🚚' => 'camion de marfă',
    '🚛' => 'camion articulat',
    '🚜' => 'tractor',
    '🏎' => 'mașină de curse',
    '🏍' => 'motocicletă',
    '🛵' => 'scuter',
    '🦽' => 'scaun cu rotile manual',
    '🦼' => 'scaun cu rotile motorizat',
    '🛺' => 'autoricșă',
    '🚲' => 'bicicletă',
    '🛴' => 'trotinetă',
    '🛹' => 'skateboard',
    '🛼' => 'patină cu rotile',
    '🚏' => 'stație de autobuz',
    '🛣' => 'autostradă',
    '🛤' => 'cale ferată',
    '🛢' => 'butoi de combustibil',
    '⛽' => 'pompă de combustibil',
    '🛞' => 'roată',
    '🚨' => 'girofar de poliție',
    '🚥' => 'semafor orizontal',
    '🚦' => 'semafor vertical',
    '🛑' => 'semnul stop',
    '🚧' => 'șantier',
    '⚓' => 'ancoră',
    '🛟' => 'colac de salvare',
    '⛵' => 'barcă cu pânze',
    '🛶' => 'canoe',
    '🚤' => 'barcă de viteză',
    '🛳' => 'vas de pasageri',
    '⛴' => 'feribot',
    '🛥' => 'barcă cu motor',
    '🚢' => 'vapor',
    '✈' => 'avion',
    '🛩' => 'aeronavă mică',
    '🛫' => 'plecare avion',
    '🛬' => 'sosire avion',
    '🪂' => 'parașută',
    '💺' => 'loc în mijloc de transport',
    '🚁' => 'elicopter',
    '🚟' => 'cale ferată suspendată',
    '🚠' => 'telecabină montană',
    '🚡' => 'tramvai aerian',
    '🛰' => 'satelit',
    '🚀' => 'rachetă',
    '🛸' => 'farfurie zburătoare',
    '🛎' => 'sonerie de recepție',
    '🧳' => 'bagaj',
    '⌛' => 'clepsidră cu nisipul scurs',
    '⏳' => 'clepsidră cu nisip care se scurge',
    '⌚' => 'ceas de mână',
    '⏰' => 'ceas deșteptător',
    '⏱' => 'cronometru',
    '⏲' => 'temporizator',
    '🕰' => 'ceas pentru etajeră',
    '🕛' => 'ora douăsprezece fix',
    '🕧' => 'ora douăsprezece și jumătate',
    '🕐' => 'ora unu fix',
    '🕜' => 'ora unu și jumătate',
    '🕑' => 'ora două fix',
    '🕝' => 'ora două și jumătate',
    '🕒' => 'ora trei fix',
    '🕞' => 'ora trei și jumătate',
    '🕓' => 'ora patru fix',
    '🕟' => 'ora patru și jumătate',
    '🕔' => 'ora cinci fix',
    '🕠' => 'ora cinci și jumătate',
    '🕕' => 'ora șase fix',
    '🕡' => 'ora șase și jumătate',
    '🕖' => 'ora șapte fix',
    '🕢' => 'ora șapte și jumătate',
    '🕗' => 'ora opt fix',
    '🕣' => 'ora opt și jumătate',
    '🕘' => 'ora nouă fix',
    '🕤' => 'ora nouă și jumătate',
    '🕙' => 'ora zece fix',
    '🕥' => 'ora zece și jumătate',
    '🕚' => 'ora unsprezece fix',
    '🕦' => 'ora unsprezece și jumătate',
    '🌑' => 'lună nouă',
    '🌒' => 'lună concavă în creștere',
    '🌓' => 'lună în primul pătrar',
    '🌔' => 'lună convexă în creștere',
    '🌕' => 'lună plină',
    '🌖' => 'lună convexă în descreștere',
    '🌗' => 'lună în ultimul pătrar',
    '🌘' => 'lună concavă în descreștere',
    '🌙' => 'semilună',
    '🌚' => 'lună nouă cu față',
    '🌛' => 'lună cu față în primul pătrar',
    '🌜' => 'lună în ultimul pătrar cu față',
    '🌡' => 'termometru',
    '☀' => 'soare',
    '🌝' => 'lună plină cu față',
    '🌞' => 'soare cu față',
    '🪐' => 'planetă cu inele',
    '⭐' => 'stea',
    '🌟' => 'stea strălucitoare',
    '🌠' => 'stea căzătoare',
    '🌌' => 'Calea Lactee',
    '☁' => 'nor',
    '⛅' => 'soare în nori',
    '⛈' => 'nor cu fulger și ploaie',
    '🌤' => 'soare după un nor mic',
    '🌥' => 'soare după un nor mare',
    '🌦' => 'soare după nor cu ploaie',
    '🌧' => 'nor cu ploaie',
    '🌨' => 'nor de ninsoare',
    '🌩' => 'nor cu fulger',
    '🌪' => 'tornadă',
    '🌫' => 'ceață',
    '🌬' => 'față suflând vânt',
    '🌀' => 'ciclon',
    '🌈' => 'curcubeu',
    '🌂' => 'umbrelă închisă',
    '☂' => 'umbrelă',
    '☔' => 'umbrelă cu picături de ploaie',
    '⛱' => 'umbrelă pe sol',
    '⚡' => 'înaltă tensiune',
    '❄' => 'fulg de nea',
    '☃' => 'om de zăpadă',
    '⛄' => 'om de zăpadă fără zăpadă',
    '☄' => 'cometă',
    '🔥' => 'foc',
    '💧' => 'picătură',
    '🌊' => 'val',
    '🎃' => 'dovleac cu felinar',
    '🎄' => 'brad de Crăciun',
    '🎆' => 'artificii',
    '🎇' => 'foc bengal',
    '🧨' => 'petardă',
    '✨' => 'steluțe',
    '🎈' => 'balon',
    '🎉' => 'tun cu confetti',
    '🎊' => 'minge cu confetti',
    '🎋' => 'copac tanabata',
    '🎍' => 'decorațiune japoneză de pin',
    '🎎' => 'păpuși japoneze',
    '🎏' => 'crap decorativ în vânt',
    '🎐' => 'clopoței de vânt',
    '🎑' => 'ceremonia lunii',
    '🧧' => 'plic roșu',
    '🎀' => 'fundă',
    '🎁' => 'cadou împachetat',
    '🎗' => 'panglică „in memoriam”',
    '🎟' => 'bilete de intrare',
    '🎫' => 'bilet',
    '🎖' => 'medalie militară',
    '🏆' => 'trofeu',
    '🏅' => 'medalie sportivă',
    '🥇' => 'medalie locul I',
    '🥈' => 'medalie locul II',
    '🥉' => 'medalie locul III',
    '⚽' => 'minge de fotbal',
    '⚾' => 'baseball',
    '🥎' => 'softball',
    '🏀' => 'baschet',
    '🏐' => 'volei',
    '🏈' => 'fotbal american',
    '🏉' => 'rugby',
    '🎾' => 'tenis',
    '🥏' => 'disc zburător',
    '🎳' => 'bowling',
    '🏏' => 'crichet',
    '🏑' => 'hochei de câmp',
    '🏒' => 'hochei pe gheață',
    '🥍' => 'lacrosse',
    '🏓' => 'ping pong',
    '🏸' => 'badminton',
    '🥊' => 'mănușă de box',
    '🥋' => 'costum arte marțiale',
    '🥅' => 'plasa porții',
    '⛳' => 'steag în gaură la golf',
    '⛸' => 'patină de gheață',
    '🎣' => 'undiță',
    '🤿' => 'mască de scufundări',
    '🎽' => 'tricou de alegare',
    '🎿' => 'schiuri',
    '🛷' => 'sanie',
    '🥌' => 'piatră de curling',
    '🎯' => 'fix la țintă',
    '🪀' => 'yo-yo',
    '🪁' => 'zmeu',
    '🔫' => 'pistol cu apă',
    '🎱' => 'biliard',
    '🔮' => 'glob de cristal',
    '🪄' => 'baghetă magică',
    '🎮' => 'joc video',
    '🕹' => 'joystick',
    '🎰' => 'jocuri mecanice',
    '🎲' => 'zar',
    '🧩' => 'piesă de puzzle',
    '🧸' => 'ursuleț de pluș',
    '🪅' => 'piñata',
    '🪩' => 'glob cu oglinzi',
    '🪆' => 'matrioșka',
    '♠' => 'pică',
    '♥' => 'cupă',
    '♦' => 'caro',
    '♣' => 'treflă',
    '♟' => 'pion de șah',
    '🃏' => 'joker',
    '🀄' => 'dragon roșu la mahjong',
    '🎴' => 'cărți de joc cu flori',
    '🎭' => 'arte interpretative',
    '🖼' => 'tablou înrămat',
    '🎨' => 'paletă de pictor',
    '🧵' => 'ață',
    '🪡' => 'ac de cusut',
    '🧶' => 'fir textil',
    '🪢' => 'nod',
    '👓' => 'ochelari',
    '🕶' => 'ochelari de soare',
    '🥽' => 'ochelari de protecție',
    '🥼' => 'halat de laborator',
    '🦺' => 'vestă de siguranță',
    '👔' => 'cravată',
    '👕' => 'tricou',
    '👖' => 'blugi',
    '🧣' => 'eșarfă',
    '🧤' => 'mănuși',
    '🧥' => 'palton',
    '🧦' => 'șosete',
    '👗' => 'rochie',
    '👘' => 'chimono',
    '🥻' => 'sari',
    '🩱' => 'costum de înot întreg',
    '🩲' => 'slip',
    '🩳' => 'șort',
    '👙' => 'costum de baie',
    '👚' => 'haine de damă',
    '🪭' => 'eventai pliabil',
    '👛' => 'poșetă',
    '👜' => 'geantă de mână',
    '👝' => 'gentuță',
    '🛍' => 'sacoșe de cumpărături',
    '🎒' => 'rucsac',
    '🩴' => 'șlap',
    '👞' => 'pantof bărbătesc',
    '👟' => 'pantof sport',
    '🥾' => 'bocanc',
    '🥿' => 'pantof fără toc',
    '👠' => 'pantof cu toc',
    '👡' => 'sanda de damă',
    '🩰' => 'pantofi de balet',
    '👢' => 'cizmă de damă',
    '🪮' => 'pieptene cu dinți lungi',
    '👑' => 'coroană',
    '👒' => 'pălărie de damă',
    '🎩' => 'joben',
    '🎓' => 'tichie de absolvent',
    '🧢' => 'șapcă',
    '🪖' => 'cască militară',
    '⛑' => 'cască de pompier salvator',
    '📿' => 'mătănii',
    '💄' => 'ruj',
    '💍' => 'inel',
    '💎' => 'piatră prețioasă',
    '🔇' => 'difuzor fără sunet',
    '🔈' => 'volum scăzut al difuzorului',
    '🔉' => 'volum mediu al difuzorului',
    '🔊' => 'volum ridicat al difuzorului',
    '📢' => 'portavoce',
    '📣' => 'megafon',
    '📯' => 'corn poștal',
    '🔔' => 'clopoțel',
    '🔕' => 'clopoțel tăiat',
    '🎼' => 'partitură',
    '🎵' => 'notă muzicală',
    '🎶' => 'note muzicale',
    '🎙' => 'microfon de studio',
    '🎚' => 'glisor de nivel',
    '🎛' => 'butoane de control',
    '🎤' => 'microfon',
    '🎧' => 'cască audio',
    '📻' => 'radio',
    '🎷' => 'saxofon',
    '🎺' => 'trompetă',
    '🪊' => 'trombon',
    '🪗' => 'acordeon',
    '🎸' => 'chitară',
    '🎹' => 'claviatură muzicală',
    '🎻' => 'vioară',
    '🪕' => 'banjo',
    '🥁' => 'tobă',
    '🪘' => 'tobă înaltă',
    '🪇' => 'maracas',
    '🪈' => 'flaut',
    '🪉' => 'harpă',
    '📱' => 'telefon mobil',
    '📲' => 'telefon mobil cu săgeată',
    '☎' => 'telefon',
    '📞' => 'receptor de telefon',
    '📟' => 'pager',
    '📠' => 'echipament fax',
    '🔋' => 'baterie',
    '🪫' => 'baterie slabă',
    '🔌' => 'fișă electrică',
    '💻' => 'computer laptop',
    '🖥' => 'computer desktop',
    '🖨' => 'imprimantă',
    '⌨' => 'tastatură',
    '🖱' => 'maus',
    '🖲' => 'trackball',
    '💽' => 'disc de computer',
    '💾' => 'dischetă',
    '💿' => 'cd',
    '📀' => 'dvd',
    '🧮' => 'abac',
    '🎥' => 'aparat de filmat',
    '🎞' => 'peliculă de film',
    '📽' => 'proiector de film',
    '🎬' => 'clachetă',
    '📺' => 'televizor',
    '📷' => 'cameră foto',
    '📸' => 'cameră foto cu bliț',
    '📹' => 'cameră video',
    '📼' => 'casetă video',
    '🔍' => 'lupă înclinată spre stânga',
    '🔎' => 'lupă înclinată spre dreapta',
    '🕯' => 'lumânare',
    '💡' => 'bec',
    '🔦' => 'lanternă',
    '🏮' => 'felinar din hârtie roșie',
    '🪔' => 'lampă diya',
    '📔' => 'caiet cu copertă decorativă',
    '📕' => 'carte închisă',
    '📖' => 'carte deschisă',
    '📗' => 'carte verde',
    '📘' => 'carte albastră',
    '📙' => 'carte portocalie',
    '📚' => 'cărți',
    '📓' => 'carnet',
    '📒' => 'registru',
    '📃' => 'pagină rulată',
    '📜' => 'pergament',
    '📄' => 'pagină cu fața în sus',
    '📰' => 'ziar',
    '🗞' => 'ziar rulat',
    '📑' => 'marcatoare de pagini',
    '🔖' => 'semn de carte',
    '🏷' => 'etichetă',
    '🪙' => 'monedă',
    '💰' => 'sac cu bani',
    '🪎' => 'cufăr de comori',
    '💴' => 'bancnotă yen',
    '💵' => 'bancnotă dolar',
    '💶' => 'bancnotă euro',
    '💷' => 'bancnotă liră sterlină',
    '💸' => 'bani înaripați',
    '💳' => 'card de credit',
    '🧾' => 'chitanță',
    '💹' => 'grafic ascendent cu yen',
    '✉' => 'plic',
    '📧' => 'e-mail',
    '📨' => 'sosire plic',
    '📩' => 'plic cu săgeată',
    '📤' => 'tăviță de ieșire',
    '📥' => 'tăviță de intrare',
    '📦' => 'pachet',
    '📫' => 'cutie poștală închisă cu steagul sus',
    '📪' => 'cutie poștală închisă cu steagul jos',
    '📬' => 'cutie poștală deschisă cu steagul sus',
    '📭' => 'cutie poștală deschisă cu steagul jos',
    '📮' => 'cutie poștală',
    '🗳' => 'urnă de votare cu vot',
    '✏' => 'creion',
    '✒' => 'peniță neagră',
    '🖋' => 'stilou',
    '🖊' => 'pix',
    '🖌' => 'pensulă',
    '🖍' => 'creion colorat',
    '📝' => 'notă',
    '💼' => 'servietă',
    '📁' => 'dosar de arhivare',
    '📂' => 'dosar de arhivare deschis',
    '🗂' => 'separatoare de dosare',
    '📅' => 'calendar',
    '📆' => 'calendar cu file detașabile',
    '🗒' => 'blocnotes cu spirală',
    '🗓' => 'calendar cu spirală',
    '📇' => 'repertoriu',
    '📈' => 'grafic ascendent',
    '📉' => 'grafic descendent',
    '📊' => 'diagramă cu bare',
    '📋' => 'planșetă',
    '📌' => 'piuneză',
    '📍' => 'ac cu gămălie',
    '📎' => 'agrafă de hârtie',
    '🖇' => 'agrafe de hârtie înlănțuite',
    '📏' => 'riglă',
    '📐' => 'echer',
    '✂' => 'foarfece',
    '🗃' => 'cutie de îndosariere',
    '🗄' => 'fișet',
    '🗑' => 'coș de gunoi',
    '🔒' => 'lacăt închis',
    '🔓' => 'lacăt deschis',
    '🔏' => 'lacăt cu stilou',
    '🔐' => 'lacăt închis cu cheie',
    '🔑' => 'cheie',
    '🗝' => 'cheie veche',
    '🔨' => 'ciocan',
    '🪓' => 'topor',
    '⛏' => 'târnăcop',
    '⚒' => 'ciocan și daltă',
    '🛠' => 'ciocan și cheie fixă',
    '🗡' => 'pumnal',
    '⚔' => 'săbii încrucișate',
    '💣' => 'bombă',
    '🪃' => 'bumerang',
    '🏹' => 'arc și săgeată',
    '🛡' => 'scut',
    '🪚' => 'fierăstrău pentru tămplărie',
    '🔧' => 'cheie fixă',
    '🪛' => 'șurubelniță',
    '🔩' => 'șurub și piuliță',
    '⚙' => 'rotiță zimțată',
    '🗜' => 'menghină',
    '⚖' => 'balanță',
    '🦯' => 'baston pentru nevăzători',
    '🔗' => 'za',
    '⛓' => 'lanț',
    '🪝' => 'cârlig',
    '🧰' => 'trusă de scule',
    '🧲' => 'magnet',
    '🪜' => 'scară',
    '🪏' => 'lopată',
    '⚗' => 'alambic',
    '🧪' => 'eprubetă',
    '🧫' => 'vas Petri',
    '🧬' => 'ADN',
    '🔬' => 'microscop',
    '🔭' => 'telescop',
    '📡' => 'antenă satelit',
    '💉' => 'seringă',
    '🩸' => 'picătură de sânge',
    '💊' => 'pastilă',
    '🩹' => 'leucoplast',
    '🩼' => 'cârjă',
    '🩺' => 'stetoscop',
    '🩻' => 'radiografie',
    '🚪' => 'ușă',
    '🛗' => 'lift',
    '🪞' => 'oglindă',
    '🪟' => 'fereastră',
    '🛏' => 'pat',
    '🛋' => 'canapea și lampă',
    '🪑' => 'scaun',
    '🚽' => 'toaletă',
    '🪠' => 'pompă de aspirare',
    '🚿' => 'duș',
    '🛁' => 'cadă',
    '🪤' => 'cursă de șoareci',
    '🪒' => 'brici',
    '🧴' => 'flacon de loțiune',
    '🧷' => 'ac de siguranță',
    '🧹' => 'mătură',
    '🧺' => 'coș',
    '🧻' => 'sul de hârtie',
    '🪣' => 'găleată',
    '🧼' => 'săpun',
    '🫧' => 'balonașe',
    '🪥' => 'periuță de dinți',
    '🧽' => 'burete',
    '🧯' => 'stingător de incendiu',
    '🛒' => 'cărucior de cumpărături',
    '🚬' => 'țigară',
    '⚰' => 'coșciug',
    '🪦' => 'piatră funerară',
    '⚱' => 'urnă funerară',
    '🧿' => 'amuletă nazar',
    '🪬' => 'hamsa',
    '🗿' => 'statuie moai',
    '🪧' => 'placardă',
    '🪪' => 'carte de identitate',
    '🏧' => 'simbol pentru bancomat',
    '🚮' => 'simbol pentru folosiți coșul de gunoi',
    '🚰' => 'apă potabilă',
    '♿' => 'simbol pentru scaun cu rotile',
    '🚹' => 'toaletă bărbați',
    '🚺' => 'toaletă femei',
    '🚻' => 'toaletă mixtă',
    '🚼' => 'simbol bebeluș',
    '🚾' => 'wc',
    '🛂' => 'control pașapoarte',
    '🛃' => 'vamă',
    '🛄' => 'recuperare bagaje',
    '🛅' => 'depozitare bagaje',
    '⚠' => 'avertisment',
    '🚸' => 'trecere copii',
    '⛔' => 'acces interzis',
    '🚫' => 'interzis',
    '🚳' => 'interzis accesul cu bicicleta',
    '🚭' => 'fumatul interzis',
    '🚯' => 'nu aruncați gunoi pe jos',
    '🚱' => 'apă nepotabilă',
    '🚷' => 'interzis accesul pietonilor',
    '📵' => 'telefoanele mobile sunt interzise',
    '🔞' => 'interzis sub 18 ani',
    '☢' => 'radioactiv',
    '☣' => 'risc biologic',
    '⬆' => 'săgeată orientată în sus',
    '↗' => 'săgeată orientată în dreapta-sus',
    '➡' => 'săgeată orientată în dreapta',
    '↘' => 'săgeată orientată în dreapta-jos',
    '⬇' => 'săgeată orientată în jos',
    '↙' => 'săgeată orientată în stânga jos',
    '⬅' => 'săgeată orientată în stânga',
    '↖' => 'săgeată orientată în stânga-sus',
    '↕' => 'săgeată sus-jos',
    '↔' => 'săgeată dreapta-stânga',
    '↩' => 'săgeată dreapta curbată spre stânga',
    '↪' => 'săgeată stânga curbată spre dreapta',
    '⤴' => 'săgeată dreapta curbată în sus',
    '⤵' => 'săgeată dreapta curbată în jos',
    '🔃' => 'săgeți verticale în sens orar',
    '🔄' => 'buton cu săgeți în sens antiorar',
    '🔙' => 'săgeată cu textul BACK',
    '🔚' => 'săgeată cu textul END',
    '🔛' => 'săgeată cu textul ON!',
    '🔜' => 'săgeată cu textul SOON',
    '🔝' => 'săgeată cu textul TOP',
    '🛐' => 'lăcaș de cult',
    '⚛' => 'simbol pentru atom',
    '🕉' => 'simbol hindus om',
    '✡' => 'steaua lui David',
    '☸' => 'roata dharmei',
    '☯' => 'yin yang',
    '✝' => 'cruce latină',
    '☦' => 'cruce ortodoxă',
    '☪' => 'stea și semilună',
    '☮' => 'semnul păcii',
    '🕎' => 'menorah',
    '🔯' => 'stea cu șase colțuri și punct în centru',
    '🪯' => 'khanda',
    '♈' => 'zodia Berbec',
    '♉' => 'zodia Taur',
    '♊' => 'zodia Gemeni',
    '♋' => 'zodia Rac',
    '♌' => 'zodia Leu',
    '♍' => 'zodia Fecioară',
    '♎' => 'zodia Balanță',
    '♏' => 'zodia Scorpion',
    '♐' => 'zodia Săgetător',
    '♑' => 'zodia Capricorn',
    '♒' => 'zodia Vărsător',
    '♓' => 'zodia Pești',
    '⛎' => 'zodia Ofiucus',
    '🔀' => 'buton de redare aleatorie',
    '🔁' => 'buton de repetare',
    '🔂' => 'buton de repetare unică',
    '▶' => 'buton de redare',
    '⏩' => 'buton de derulare rapidă înainte',
    '⏭' => 'buton pentru melodia următoare',
    '⏯' => 'buton de redare sau suspendare',
    '◀' => 'buton de inversare',
    '⏪' => 'buton de derulare rapidă înapoi',
    '⏮' => 'buton pentru melodia anterioară',
    '🔼' => 'buton pentru sus',
    '⏫' => 'buton pentru repede sus',
    '🔽' => 'buton pentru jos',
    '⏬' => 'buton pentru repede jos',
    '⏸' => 'buton de suspendare',
    '⏹' => 'buton de oprire',
    '⏺' => 'buton de înregistrare',
    '⏏' => 'buton de ejectare',
    '🎦' => 'cinema',
    '🔅' => 'buton de scădere a luminozității',
    '🔆' => 'buton de creștere a luminozității',
    '📶' => 'bare de semnal',
    '🛜' => 'wireless',
    '📳' => 'modul vibrare',
    '📴' => 'închidere telefoane mobile',
    '♀' => 'semn feminin',
    '♂' => 'semn masculin',
    '⚧' => 'transgender',
    '✖' => 'înmulțire',
    '➕' => 'plus',
    '➖' => 'minus',
    '➗' => 'împărțire',
    '🟰' => 'semn gros de egal',
    '♾' => 'infinit',
    '‼' => 'semn dublu de exclamare',
    '⁉' => 'semn de exclamare și întrebare',
    '❓' => 'semnul întrebării roșu',
    '❔' => 'semnul întrebării alb',
    '❕' => 'semnul exclamării alb',
    '❗' => 'semnul exclamării',
    '〰' => 'liniuță ondulată',
    '💱' => 'schimb valutar',
    '💲' => 'semnul dolar îngroșat',
    '⚕' => 'simbol medical',
    '♻' => 'simbolul pentru reciclare',
    '⚜' => 'floare de crin stilizată',
    '🔱' => 'emblemă trident',
    '📛' => 'ecuson cu nume',
    '🔰' => 'simbol japonez pentru începător',
    '⭕' => 'cerc roșu gol',
    '✅' => 'buton de bifă',
    '☑' => 'casetă de votare bifată',
    '✔' => 'bifă îngroșată',
    '❌' => 'semnul x',
    '❎' => 'buton x',
    '➰' => 'buclă ondulată',
    '➿' => 'buclă ondulată dublă',
    '〽' => 'alternare cântăreț',
    '✳' => 'asterisc cu opt colțuri',
    '✴' => 'stea cu opt colțuri',
    '❇' => 'strălucire',
    '™' => 'marcă comercială',
    '🫟' => 'împroșcare',
    '🔠' => 'introducere majuscule latine',
    '🔡' => 'introducere minuscule latine',
    '🔢' => 'introducere numere',
    '🔣' => 'introducere simboluri',
    '🔤' => 'introducere litere latine',
    '🅰' => 'buton A (grupă sanguină)',
    '🆎' => 'buton AB (grupă sanguină)',
    '🅱' => 'buton B (grupă sanguină)',
    '🆑' => 'buton CL',
    '🆒' => 'buton cu textul COOL',
    '🆓' => 'buton cu textul FREE',
    'ℹ' => 'informații',
    '🆔' => 'buton ID',
    'Ⓜ' => 'litera M într-un cerc',
    '🆕' => 'buton cu textul NEW',
    '🆖' => 'buton NG',
    '🅾' => 'buton 0 (grupă sanguină)',
    '🆗' => 'buton cu textul OK',
    '🅿' => 'buton P',
    '🆘' => 'buton S.O.S.',
    '🆙' => 'buton cu textul UP!',
    '🆚' => 'buton cu textul VS',
    '🈁' => 'buton cu semnificația „aici” în japoneză',
    '🈂' => 'buton cu semnificația „taxă pentru serviciu” în japoneză',
    '🈷' => 'buton cu semnificația „valoare lunară” în japoneză',
    '🈶' => 'buton cu semnificația „contra cost” japoneză',
    '🈯' => 'buton cu semnificația „rezervat” în japoneză',
    '🉐' => 'buton cu semnificația „ocazie” în japoneză',
    '🈹' => 'buton cu semnificația „reducere” în japoneză',
    '🈚' => 'buton cu semnificația „gratis” în japoneză',
    '🈲' => 'buton cu semnificația „interzis” în japoneză',
    '🉑' => 'buton cu semnificația „acceptabil” în japoneză',
    '🈸' => 'buton cu semnificația „aplicare” în japoneză',
    '🈴' => 'buton cu semnificația „notă de trecere” în japoneză',
    '🈳' => 'buton cu semnificația „locuri libere” în japoneză',
    '㊗' => 'buton cu semnificația „felicitări” în japoneză',
    '㊙' => 'buton cu semnificația „secret” în japoneză',
    '🈺' => 'buton cu semnificația „deschis pentru afaceri” în japoneză',
    '🈵' => 'buton cu semnificația „fără locuri libere” în japoneză',
    '🔴' => 'cerc roșu',
    '🟠' => 'cerc portocaliu',
    '🟡' => 'cerc galben',
    '🟢' => 'cerc verde',
    '🔵' => 'cerc albastru',
    '🟣' => 'cerc violet',
    '🟤' => 'cerc maro',
    '⚫' => 'cerc negru',
    '⚪' => 'cerc alb',
    '🟥' => 'pătrat roșu',
    '🟧' => 'pătrat portocaliu',
    '🟨' => 'pătrat galben',
    '🟩' => 'pătrat verde',
    '🟦' => 'pătrat albastru',
    '🟪' => 'pătrat violet',
    '🟫' => 'pătrat maro',
    '⬛' => 'pătrat negru mare',
    '⬜' => 'pătrat alb mare',
    '◼' => 'pătrat negru mediu',
    '◻' => 'pătrat alb mediu',
    '◾' => 'pătrat negru mediu spre mic',
    '◽' => 'pătrat alb mediu spre mic',
    '▪' => 'pătrat negru mic',
    '▫' => 'pătrat alb mic',
    '🔶' => 'romb portocaliu mare',
    '🔷' => 'romb albastru mare',
    '🔸' => 'romb portocaliu mic',
    '🔹' => 'romb albastru mic',
    '🔺' => 'triunghi roșu cu vârful în sus',
    '🔻' => 'triunghi roșu cu vârful în jos',
    '💠' => 'romb cu punct în centru',
    '🔘' => 'buton radio',
    '🔳' => 'buton pătrat alb',
    '🔲' => 'buton pătrat negru',
    '🏁' => 'steag cu pătrățele',
    '🚩' => 'steag triunghiular',
    '🎌' => 'steaguri încrucișate',
    '🏴' => 'steag negru',
    '🏳' => 'steag alb',
];
